# coding: utf8
"""
All wordforms are extracted from Norsk Ordbank in Norwegian Bokmål 2005
(CLARINO NB - Språkbanken), Nasjonalbiblioteket, Norway:
https://www.nb.no/sprakbanken/show?serial=oai%3Anb.no%3Asbr-5&lang=en
License:
Creative_Commons-BY (CC-BY) (https://creativecommons.org/licenses/by/4.0/)
"""

from __future__ import unicode_literals

NOUNS_WORDFORMS = {
'à la carte-serveringene': ('à la carte-servering',),
'à la carte-serveringer': ('à la carte-servering',),
'à la carte-servering': ('à la carte-servering',),
'à la carte-serveringa': ('à la carte-servering',),
'à la carte-serveringen': ('à la carte-servering',),
'à la carte-serveringene': ('à la carte-servering',),
'14C-datering': ('14C-datering',),
'14C-dateringa': ('14C-datering',),
'14C-dateringen': ('14C-datering',),
'14C-dateringene': ('14C-datering',),
'14C-dateringer': ('14C-datering',),
'A': ('A',),
'A\'en': ('A',),
'A-en': ('A',),
'A-ene': ('A',),
'A-er': ('A',),
'A-dur': ('A-dur',),
'A-duren': ('A-dur',),
'A-durene': ('A-dur',),
'A-durer': ('A-dur',),
'A-egg': ('A-egg',),
'A-egga': ('A-egg',),
'A-eggene': ('A-egg',),
'A-egget': ('A-egg',),
'A-lag': ('A-lag',),
'A-laga': ('A-lag',),
'A-lagene': ('A-lag',),
'A-laget': ('A-lag',),
'A-menneska': ('A-menneske',),
'A-menneske': ('A-menneske',),
'A-menneskene': ('A-menneske',),
'A-mennesker': ('A-menneske',),
'A-mennesket': ('A-menneske',),
'A-moment': ('A-moment',),
'A-momenta': ('A-moment',),
'A-momentene': ('A-moment',),
'A-momenter': ('A-moment',),
'A-momentet': ('A-moment',),
'A-språk': ('A-språk',),
'A-språka': ('A-språk',),
'A-språkene': ('A-språk',),
'A-språket': ('A-språk',),
'A-vitamin': ('A-vitamin',),
'A-vitamina': ('A-vitamin',),
'A-vitaminene': ('A-vitamin',),
'A-vitaminer': ('A-vitamin',),
'A-vitaminet': ('A-vitamin',),
'A4-format': ('A4-format',),
'A4-formata': ('A4-format',),
'A4-formatene': ('A4-format',),
'A4-formater': ('A4-format',),
'A4-formatet': ('A4-format',),
'A5-format': ('A5-format',),
'A5-formata': ('A5-format',),
'A5-formatene': ('A5-format',),
'A5-formater': ('A5-format',),
'A5-formatet': ('A5-format',),
'ADB-operatør': ('ADB-operatør',),
'ADB-operatøren': ('ADB-operatør',),
'ADB-operatørene': ('ADB-operatør',),
'ADB-operatører': ('ADB-operatør',),
'AIDS': ('AIDS',),
'AIDSen': ('AIDS',),
'AIDSene': ('AIDS',),
'AIDSer': ('AIDS',),
'AIDS-smitte': ('AIDS-smitte',),
'AIDS-smitten': ('AIDS-smitte',),
'AIDS-smittene': ('AIDS-smitte',),
'AIDS-smitter': ('AIDS-smitte',),
'AV-middel': ('AV-middel',),
'AV-middelet': ('AV-middel',),
'AV-midla': ('AV-middel',),
'AV-midlene': ('AV-middel',),
'AV-midler': ('AV-middel',),
'AV-midlet': ('AV-middel',),
'Algol': ('Algol',),
'Ass': ('Ass',),
'Assen': ('Ass',),
'Assene': ('Ass',),
'Asser': ('Ass',),
'Ass-dur': ('Ass-dur',),
'Ass-duren': ('Ass-dur',),
'Ass-durene': ('Ass-dur',),
'Ass-durer': ('Ass-dur',),
'B': ('B',),
'B\'en': ('B',),
'B-en': ('B',),
'B-ene': ('B',),
'B-er': ('B',),
'B-dur': ('B-dur',),
'B-duren': ('B-dur',),
'B-durene': ('B-dur',),
'B-durer': ('B-dur',),
'B-film': ('B-film',),
'B-filmen': ('B-film',),
'B-filmene': ('B-film',),
'B-filmer': ('B-film',),
'B-kvalitet': ('B-kvalitet',),
'B-kvaliteten': ('B-kvalitet',),
'B-kvalitetene': ('B-kvalitet',),
'B-kvaliteter': ('B-kvalitet',),
'B-lag': ('B-lag',),
'B-laga': ('B-lag',),
'B-lagene': ('B-lag',),
'B-laget': ('B-lag',),
'B-menneska': ('B-menneske',),
'B-menneske': ('B-menneske',),
'B-menneskene': ('B-menneske',),
'B-mennesker': ('B-menneske',),
'B-mennesket': ('B-menneske',),
'B-moment': ('B-moment',),
'B-momenta': ('B-moment',),
'B-momentene': ('B-moment',),
'B-momenter': ('B-moment',),
'B-momentet': ('B-moment',),
'B-språk': ('B-språk',),
'B-språka': ('B-språk',),
'B-språkene': ('B-språk',),
'B-språket': ('B-språk',),
'B-vitamin': ('B-vitamin',),
'B-vitamina': ('B-vitamin',),
'B-vitaminene': ('B-vitamin',),
'B-vitaminer': ('B-vitamin',),
'B-vitaminet': ('B-vitamin',),
'BCG-vaksina': ('BCG-vaksine',),
'BCG-vaksine': ('BCG-vaksine',),
'BCG-vaksinen': ('BCG-vaksine',),
'BCG-vaksinene': ('BCG-vaksine',),
'BCG-vaksiner': ('BCG-vaksine',),
'BH': ('BH',),
'BHen': ('BH',),
'BHene': ('BH',),
'BHer': ('BH',),
'Basedows sjukdom': ('Basedows sjukdom',),
'Basedows sjukdommen': ('Basedows sjukdom',),
'Basedows sjukdommene': ('Basedows sjukdom',),
'Basedows sjukdommer': ('Basedows sjukdom',),
'Basedows sykdom': ('Basedows sykdom',),
'Basedows sykdommen': ('Basedows sykdom',),
'Basedows sykdommene': ('Basedows sykdom',),
'Basedows sykdommer': ('Basedows sykdom',),
'Beaufort-skala': ('Beaufort-skala',),
'Beaufort-skalaen': ('Beaufort-skala',),
'Beaufort-skalaene': ('Beaufort-skala',),
'Beaufort-skalaer': ('Beaufort-skala',),
'Blakka': ('Blakka',),
'Blakken': ('Blakken',),
'Borka': ('Borka',),
'Borken': ('Borken',),
'Bruna': ('Bruna',),
'Brunen': ('Brunen',),
'C': ('C',),
'C\'en': ('C',),
'C-en': ('C',),
'C-ene': ('C',),
'C-er': ('C',),
'C-dur': ('C-dur',),
'C-duren': ('C-dur',),
'C-durene': ('C-dur',),
'C-durer': ('C-dur',),
'C-moment': ('C-moment',),
'C-momenta': ('C-moment',),
'C-momentene': ('C-moment',),
'C-momenter': ('C-moment',),
'C-momentet': ('C-moment',),
'C-språk': ('C-språk',),
'C-språka': ('C-språk',),
'C-språkene': ('C-språk',),
'C-språket': ('C-språk',),
'C-vitamin': ('C-vitamin',),
'C-vitamina': ('C-vitamin',),
'C-vitaminene': ('C-vitamin',),
'C-vitaminer': ('C-vitamin',),
'C-vitaminet': ('C-vitamin',),
'CD': ('CD',),
'CDen': ('CD',),
'CDene': ('CD',),
'CDer': ('CD',),
'CD-plata': ('CD-plate',),
'CD-plate': ('CD-plate',),
'CD-platen': ('CD-plate',),
'CD-platene': ('CD-plate',),
'CD-plater': ('CD-plate',),
'CD-speller': ('CD-speller',),
'CD-spellere': ('CD-speller',),
'CD-spelleren': ('CD-speller',),
'CD-spellerer': ('CD-speller',),
'CD-spellerne': ('CD-speller',),
'CD-spiller': ('CD-spiller',),
'CD-spillere': ('CD-spiller',),
'CD-spilleren': ('CD-spiller',),
'CD-spillerer': ('CD-spiller',),
'CD-spillerne': ('CD-spiller',),
'Cess': ('Cess',),
'Cessen': ('Cess',),
'Cessene': ('Cess',),
'Cesser': ('Cess',),
'Ciss': ('Ciss',),
'Cissen': ('Ciss',),
'Cissene': ('Ciss',),
'Cisser': ('Ciss',),
'Ciss-dur': ('Ciss-dur',),
'Ciss-duren': ('Ciss-dur',),
'Ciss-durene': ('Ciss-dur',),
'Ciss-durer': ('Ciss-dur',),
'Cobol': ('Cobol',),
'D': ('D',),
'D\'en': ('D',),
'D-en': ('D',),
'D-ene': ('D',),
'D-er': ('D',),
'D-dag': ('D-dag',),
'D-dagen': ('D-dag',),
'D-dagene': ('D-dag',),
'D-dager': ('D-dag',),
'D-dur': ('D-dur',),
'D-duren': ('D-dur',),
'D-durene': ('D-dur',),
'D-durer': ('D-dur',),
'D-vitamin': ('D-vitamin',),
'D-vitamina': ('D-vitamin',),
'D-vitaminene': ('D-vitamin',),
'D-vitaminer': ('D-vitamin',),
'D-vitaminet': ('D-vitamin',),
'DDT': ('DDT',),
'DDTen': ('DDT',),
'DDTene': ('DDT',),
'DDTer': ('DDT',),
'DNA': ('DNA',),
'DNAa': ('DNA',),
'DNAene': ('DNA',),
'DNAet': ('DNA',),
'DNA-molekyl': ('DNA-molekyl',),
'DNA-molekyla': ('DNA-molekyl',),
'DNA-molekylene': ('DNA-molekyl',),
'DNA-molekyler': ('DNA-molekyl',),
'DNA-molekylet': ('DNA-molekyl',),
'Dess': ('Dess',),
'Dessen': ('Dess',),
'Dessene': ('Dess',),
'Desser': ('Dess',),
'Dess-dur': ('Dess-dur',),
'Dess-duren': ('Dess-dur',),
'Dess-durene': ('Dess-dur',),
'Dess-durer': ('Dess-dur',),
'Diss': ('Diss',),
'Dissen': ('Diss',),
'Dissene': ('Diss',),
'Disser': ('Diss',),
'Downs syndrom': ('Downs syndrom',),
'Downs syndroma': ('Downs syndrom',),
'Downs syndromene': ('Downs syndrom',),
'Downs syndromer': ('Downs syndrom',),
'Downs syndromet': ('Downs syndrom',),
'E': ('E',),
'E\'en': ('E',),
'E-en': ('E',),
'E-ene': ('E',),
'E-er': ('E',),
'E-dur': ('E-dur',),
'E-duren': ('E-dur',),
'E-durene': ('E-dur',),
'E-durer': ('E-dur',),
'EDB-anlegg': ('EDB-anlegg',),
'EDB-anlegga': ('EDB-anlegg',),
'EDB-anleggene': ('EDB-anlegg',),
'EDB-anlegget': ('EDB-anlegg',),
'EDB-operatør': ('EDB-operatør',),
'EDB-operatøren': ('EDB-operatør',),
'EDB-operatørene': ('EDB-operatør',),
'EDB-operatører': ('EDB-operatør',),
'EDB-senter': ('EDB-senter',),
'EDB-senteret': ('EDB-senter',),
'EDB-sentra': ('EDB-senter',),
'EDB-sentre': ('EDB-senter',),
'EDB-sentrene': ('EDB-senter',),
'EDB-sentret': ('EDB-senter',),
'EDB-sentral': ('EDB-sentral',),
'EDB-sentralen': ('EDB-sentral',),
'EDB-sentralene': ('EDB-sentral',),
'EDB-sentraler': ('EDB-sentral',),
'EDB-terminal': ('EDB-terminal',),
'EDB-terminalen': ('EDB-terminal',),
'EDB-terminalene': ('EDB-terminal',),
'EDB-terminaler': ('EDB-terminal',),
'EDB-utstyr': ('EDB-utstyr',),
'EDB-utstyra': ('EDB-utstyr',),
'EDB-utstyrene': ('EDB-utstyr',),
'EDB-utstyret': ('EDB-utstyr',),
'EF-land': ('EF-land',),
'EF-landa': ('EF-land',),
'EF-landene': ('EF-land',),
'EF-landet': ('EF-land',),
'EF-medlemskap': ('EF-medlemskap',),
'EF-medlemskapa': ('EF-medlemskap',),
'EF-medlemskapene': ('EF-medlemskap',),
'EF-medlemskapet': ('EF-medlemskap',),
'EM': ('EM',),
'EM-a': ('EM',),
'EM-ene': ('EM',),
'EM-et': ('EM',),
'EP': ('EP',),
'EPen': ('EP',),
'EPene': ('EP',),
'EPer': ('EP',),
'EP-plata': ('EP-plate',),
'EP-plate': ('EP-plate',),
'EP-platen': ('EP-plate',),
'EP-platene': ('EP-plate',),
'EP-plater': ('EP-plate',),
'Ess': ('Ess',),
'Essen': ('Ess',),
'Essene': ('Ess',),
'Esser': ('Ess',),
'Ess-dur': ('Ess-dur',),
'Ess-duren': ('Ess-dur',),
'Ess-durene': ('Ess-dur',),
'Ess-durer': ('Ess-dur',),
'EØS-avtale': ('EØS-avtale',),
'EØS-avtalen': ('EØS-avtale',),
'EØS-avtalene': ('EØS-avtale',),
'EØS-avtaler': ('EØS-avtale',),
'EØS-avtale': ('EØS-avtale',),
'EØS-avtalen': ('EØS-avtale',),
'EØS-avtalene': ('EØS-avtale',),
'EØS-avtaler': ('EØS-avtale',),
'F': ('F',),
'F\'en': ('F',),
'F-en': ('F',),
'F-ene': ('F',),
'F-er': ('F',),
'F-dur': ('F-dur',),
'F-duren': ('F-dur',),
'F-durene': ('F-dur',),
'F-durer': ('F-dur',),
'FM-band': ('FM-band',),
'FM-banda': ('FM-band',),
'FM-bandene': ('FM-band',),
'FM-bandet': ('FM-band',),
'FM-bånd': ('FM-bånd',),
'FM-bånda': ('FM-bånd',),
'FM-båndene': ('FM-bånd',),
'FM-båndet': ('FM-bånd',),
'FM-kringkasting': ('FM-kringkasting',),
'FM-kringkastinga': ('FM-kringkasting',),
'FM-kringkastingen': ('FM-kringkasting',),
'FM-kringkastingene': ('FM-kringkasting',),
'FM-kringkastinger': ('FM-kringkasting',),
'FM-sender': ('FM-sender',),
'FM-sendere': ('FM-sender',),
'FM-senderen': ('FM-sender',),
'FM-senderer': ('FM-sender',),
'FM-senderne': ('FM-sender',),
'Fess': ('Fess',),
'Fessen': ('Fess',),
'Fessene': ('Fess',),
'Fesser': ('Fess',),
'Fiss': ('Fiss',),
'Fissen': ('Fiss',),
'Fissene': ('Fiss',),
'Fisser': ('Fiss',),
'Fiss-dur': ('Fiss-dur',),
'Fiss-duren': ('Fiss-dur',),
'Fiss-durene': ('Fiss-dur',),
'Fiss-durer': ('Fiss-dur',),
'Fortran': ('Fortran',),
'G': ('G',),
'G\'en': ('G',),
'G-en': ('G',),
'G-ene': ('G',),
'G-er': ('G',),
'G-dur': ('G-dur',),
'G-duren': ('G-dur',),
'G-durene': ('G-dur',),
'G-durer': ('G-dur',),
'Gauss-kurve': ('Gauss-kurve',),
'Gauss-kurven': ('Gauss-kurve',),
'Gauss-kurvene': ('Gauss-kurve',),
'Gauss-kurver': ('Gauss-kurve',),
'Gess': ('Gess',),
'Gessen': ('Gess',),
'Gessene': ('Gess',),
'Gesser': ('Gess',),
'Gess-dur': ('Gess-dur',),
'Gess-duren': ('Gess-dur',),
'Gess-durene': ('Gess-dur',),
'Gess-durer': ('Gess-dur',),
'Giss': ('Giss',),
'Gissen': ('Giss',),
'Gissene': ('Giss',),
'Gisser': ('Giss',),
'Giss-dur': ('Giss-dur',),
'Giss-duren': ('Giss-dur',),
'Giss-durene': ('Giss-dur',),
'Giss-durer': ('Giss-dur',),
'H': ('H',),
'H\'en': ('H',),
'H-en': ('H',),
'H-ene': ('H',),
'H-er': ('H',),
'H-bjelke': ('H-bjelke',),
'H-bjelken': ('H-bjelke',),
'H-bjelkene': ('H-bjelke',),
'H-bjelker': ('H-bjelke',),
'H-dur': ('H-dur',),
'H-duren': ('H-dur',),
'H-durene': ('H-dur',),
'H-durer': ('H-dur',),
'H-melk': ('H-melk',),
'H-melka': ('H-melk',),
'H-melken': ('H-melk',),
'H-melkene': ('H-melk',),
'H-melker': ('H-melk',),
'H-melkkartong': ('H-melkkartong',),
'H-melkkartongen': ('H-melkkartong',),
'H-melkkartongene': ('H-melkkartong',),
'H-melkkartonger': ('H-melkkartong',),
'H-mjølk': ('H-mjølk',),
'H-mjølka': ('H-mjølk',),
'H-mjølken': ('H-mjølk',),
'H-mjølkene': ('H-mjølk',),
'H-mjølker': ('H-mjølk',),
'H-mjølkkartong': ('H-mjølkkartong',),
'H-mjølkkartongen': ('H-mjølkkartong',),
'H-mjølkkartongene': ('H-mjølkkartong',),
'H-mjølkkartonger': ('H-mjølkkartong',),
'HB-apparat': ('HB-apparat',),
'HB-apparata': ('HB-apparat',),
'HB-apparatene': ('HB-apparat',),
'HB-apparater': ('HB-apparat',),
'HB-apparatet': ('HB-apparat',),
'HIV': ('HIV',),
'HIV-smitte': ('HIV-smitte',),
'HIV-smitten': ('HIV-smitte',),
'HIV-smittene': ('HIV-smitte',),
'HIV-smitter': ('HIV-smitte',),
'HIV-virus': ('HIV-virus',),
'HIV-virusa': ('HIV-virus',),
'HIV-virusene': ('HIV-virus',),
'HIV-viruset': ('HIV-virus',),
'Hi-Fi': ('Hi-Fi',),
'Hi-Fien': ('Hi-Fi',),
'Hi-Fiene': ('Hi-Fi',),
'Hi-Fier': ('Hi-Fi',),
'I': ('I',),
'I\'en': ('I',),
'I-en': ('I',),
'I-ene': ('I',),
'I-er': ('I',),
'J': ('J',),
'J\'en': ('J',),
'J-en': ('J',),
'J-ene': ('J',),
'J-er': ('J',),
'Jesusbilda': ('Jesusbilde',),
'Jesusbilde': ('Jesusbilde',),
'Jesusbildene': ('Jesusbilde',),
'Jesusbilder': ('Jesusbilde',),
'Jesusbildet': ('Jesusbilde',),
'K': ('K',),
'K\'en': ('K',),
'K-en': ('K',),
'K-ene': ('K',),
'K-er': ('K',),
'KM': ('KM',),
'KM-a': ('KM',),
'KM-ene': ('KM',),
'KM-et': ('KM',),
'L': ('L',),
'L\'en': ('L',),
'L-en': ('L',),
'L-ene': ('L',),
'L-er': ('L',),
'LP': ('LP',),
'LPen': ('LP',),
'LPene': ('LP',),
'LPer': ('LP',),
'LP-plata': ('LP-plate',),
'LP-plate': ('LP-plate',),
'LP-platen': ('LP-plate',),
'LP-platene': ('LP-plate',),
'LP-plater': ('LP-plate',),
'LSD': ('LSD',),
'LSDen': ('LSD',),
'LSDene': ('LSD',),
'LSDer': ('LSD',),
'LSD-rus': ('LSD-rus',),
'LSD-rusa': ('LSD-rus',),
'LSD-rusen': ('LSD-rus',),
'LSD-rusene': ('LSD-rus',),
'LSD-ruser': ('LSD-rus',),
'LSD-ruset': ('LSD-rus',),
'M': ('M',),
'M\'en': ('M',),
'M-en': ('M',),
'M-ene': ('M',),
'M-er': ('M',),
'MS-pasient': ('MS-pasient',),
'MS-pasienten': ('MS-pasient',),
'MS-pasientene': ('MS-pasient',),
'MS-pasienter': ('MS-pasient',),
'MTB': ('MTB',),
'MTBen': ('MTB',),
'MTBene': ('MTB',),
'MTBer': ('MTB',),
'N': ('N',),
'N\'en': ('N',),
'N-en': ('N',),
'N-ene': ('N',),
'N-er': ('N',),
'NATO-land': ('NATO-land',),
'NATO-landa': ('NATO-land',),
'NATO-landene': ('NATO-land',),
'NATO-landet': ('NATO-land',),
'NM': ('NM',),
'NM-a': ('NM',),
'NM-ene': ('NM',),
'NM-et': ('NM',),
'NN-fange': ('NN-fange',),
'NN-fangen': ('NN-fange',),
'NN-fangene': ('NN-fange',),
'NN-fanger': ('NN-fange',),
'NS-medlem': ('NS-medlem',),
'NS-medlemma': ('NS-medlem',),
'NS-medlemmene': ('NS-medlem',),
'NS-medlemmer': ('NS-medlem',),
'NS-medlemmet': ('NS-medlem',),
'Nato-land': ('Nato-land',),
'Nato-landa': ('Nato-land',),
'Nato-landene': ('Nato-land',),
'Nato-landet': ('Nato-land',),
'Norden': ('Norden',),
'O': ('O',),
'O\'en': ('O',),
'O-en': ('O',),
'O-ene': ('O',),
'O-er': ('O',),
'OL': ('OL',),
'OL-a': ('OL',),
'OL-ene': ('OL',),
'OL-et': ('OL',),
'OL-pins': ('OL-pins',),
'OL-pinsen': ('OL-pins',),
'OL-pinsene': ('OL-pins',),
'OL-pinser': ('OL-pins',),
'Oksidenten': ('Oksidenten',),
'Ola': ('Ola',),
'P': ('P',),
'P\'en': ('P',),
'P-en': ('P',),
'P-ene': ('P',),
'P-er': ('P',),
'PC': ('PC',),
'PC-en': ('PC',),
'PC-ene': ('PC',),
'PC-er': ('PC',),
'PD': ('PD',),
'PDen': ('PD',),
'PDene': ('PD',),
'PDer': ('PD',),
'PD-setting': ('PD-setting',),
'PD-settinga': ('PD-setting',),
'PD-settingen': ('PD-setting',),
'PD-settingene': ('PD-setting',),
'PD-settinger': ('PD-setting',),
'PM': ('PM',),
'PMa': ('PM',),
'PMene': ('PM',),
'PMer': ('PM',),
'PMet': ('PM',),
'PR': ('PR',),
'PR-en': ('PR',),
'PR-ene': ('PR',),
'PR-er': ('PR',),
'PR-mann': ('PR-mann',),
'PR-mannen': ('PR-mann',),
'PR-menn': ('PR-mann',),
'PR-mennene': ('PR-mann',),
'PS': ('PS',),
'PSa': ('PS',),
'PSene': ('PS',),
'PSer': ('PS',),
'PSet': ('PS',),
'Parkinsons sjukdom': ('Parkinsons sjukdom',),
'Parkinsons sjukdommen': ('Parkinsons sjukdom',),
'Parkinsons sjukdommene': ('Parkinsons sjukdom',),
'Parkinsons sjukdommer': ('Parkinsons sjukdom',),
'Parkinsons sykdom': ('Parkinsons sykdom',),
'Parkinsons sykdommen': ('Parkinsons sykdom',),
'Parkinsons sykdommene': ('Parkinsons sykdom',),
'Parkinsons sykdommer': ('Parkinsons sykdom',),
'Pascal': ('Pascal',),
'Per': ('Per',),
'Peren': ('Per',),
'Perene': ('Per',),
'Perer': ('Per',),
'Q': ('Q',),
'Q\'en': ('Q',),
'Q-en': ('Q',),
'Q-ene': ('Q',),
'Q-er': ('Q',),
'Q-verdi': ('Q-verdi',),
'Q-verdien': ('Q-verdi',),
'Q-verdiene': ('Q-verdi',),
'Q-verdier': ('Q-verdi',),
'R': ('R',),
'R\'en': ('R',),
'R-en': ('R',),
'R-ene': ('R',),
'R-er': ('R',),
'Rh-faktor': ('Rh-faktor',),
'Rh-faktoren': ('Rh-faktor',),
'Rh-faktorene': ('Rh-faktor',),
'Rh-faktorer': ('Rh-faktor',),
'S': ('S',),
'S\'en': ('S',),
'S-en': ('S',),
'S-ene': ('S',),
'S-er': ('S',),
'SI-system': ('SI-system',),
'SI-systema': ('SI-system',),
'SI-systemene': ('SI-system',),
'SI-systemer': ('SI-system',),
'SI-systemet': ('SI-system',),
'SOS': ('SOS',),
'SOS-a': ('SOS',),
'SOS-ene': ('SOS',),
'SOS-et': ('SOS',),
'Sankt Elms eld': ('Sankt Elms eld',),
'Sankt Elms ild': ('Sankt Elms ild',),
'Simula': ('Simula',),
'Syden': ('Syden',),
'T': ('T',),
'T\'en': ('T',),
'T-en': ('T',),
'T-ene': ('T',),
'T-er': ('T',),
'T-bane': ('T-bane',),
'T-banen': ('T-bane',),
'T-banene': ('T-bane',),
'T-baner': ('T-bane',),
'T-beinsteik': ('T-beinsteik',),
'T-beinsteika': ('T-beinsteik',),
'T-beinsteiken': ('T-beinsteik',),
'T-beinsteikene': ('T-beinsteik',),
'T-beinsteiker': ('T-beinsteik',),
'T-beinstek': ('T-beinstek',),
'T-beinsteka': ('T-beinstek',),
'T-beinsteken': ('T-beinstek',),
'T-beinstekene': ('T-beinstek',),
'T-beinsteker': ('T-beinstek',),
'T-bensteik': ('T-bensteik',),
'T-bensteika': ('T-bensteik',),
'T-bensteiken': ('T-bensteik',),
'T-bensteikene': ('T-bensteik',),
'T-bensteiker': ('T-bensteik',),
'T-benstek': ('T-benstek',),
'T-bensteka': ('T-benstek',),
'T-bensteken': ('T-benstek',),
'T-benstekene': ('T-benstek',),
'T-bensteker': ('T-benstek',),
'T-bjelke': ('T-bjelke',),
'T-bjelken': ('T-bjelke',),
'T-bjelkene': ('T-bjelke',),
'T-bjelker': ('T-bjelke',),
'T-jern': ('T-jern',),
'T-jerna': ('T-jern',),
'T-jernene': ('T-jern',),
'T-jernet': ('T-jern',),
'T-kryss': ('T-kryss',),
'T-kryssa': ('T-kryss',),
'T-kryssene': ('T-kryss',),
'T-krysset': ('T-kryss',),
'T-skjorta': ('T-skjorte',),
'T-skjorte': ('T-skjorte',),
'T-skjorten': ('T-skjorte',),
'T-skjortene': ('T-skjorte',),
'T-skjorter': ('T-skjorte',),
'T-stål': ('T-stål',),
'T-ståla': ('T-stål',),
'T-stålene': ('T-stål',),
'T-stålet': ('T-stål',),
'TG-grammatikk': ('TG-grammatikk',),
'TG-grammatikken': ('TG-grammatikk',),
'TG-grammatikkene': ('TG-grammatikk',),
'TG-grammatikker': ('TG-grammatikk',),
'TV': ('TV',),
'TV-en': ('TV',),
'TV-ene': ('TV',),
'TV-er': ('TV',),
'TV-antenna': ('TV-antenne',),
'TV-antenne': ('TV-antenne',),
'TV-antennen': ('TV-antenne',),
'TV-antennene': ('TV-antenne',),
'TV-antenner': ('TV-antenne',),
'TV-apparat': ('TV-apparat',),
'TV-apparata': ('TV-apparat',),
'TV-apparatene': ('TV-apparat',),
'TV-apparater': ('TV-apparat',),
'TV-apparatet': ('TV-apparat',),
'TV-film': ('TV-film',),
'TV-filmen': ('TV-film',),
'TV-filmene': ('TV-film',),
'TV-filmer': ('TV-film',),
'TV-kanna': ('TV-kanne',),
'TV-kanne': ('TV-kanne',),
'TV-kannen': ('TV-kanne',),
'TV-kannene': ('TV-kanne',),
'TV-kanner': ('TV-kanne',),
'TV-kjendis': ('TV-kjendis',),
'TV-kjendisen': ('TV-kjendis',),
'TV-kjendisene': ('TV-kjendis',),
'TV-kjendiser': ('TV-kjendis',),
'TV-overføring': ('TV-overføring',),
'TV-overføringa': ('TV-overføring',),
'TV-overføringen': ('TV-overføring',),
'TV-overføringene': ('TV-overføring',),
'TV-overføringer': ('TV-overføring',),
'TV-overvåking': ('TV-overvåking',),
'TV-overvåkinga': ('TV-overvåking',),
'TV-overvåkingen': ('TV-overvåking',),
'TV-overvåkingene': ('TV-overvåking',),
'TV-overvåkinger': ('TV-overvåking',),
'TV-overvåkning': ('TV-overvåkning',),
'TV-overvåkninga': ('TV-overvåkning',),
'TV-overvåkningen': ('TV-overvåkning',),
'TV-overvåkningene': ('TV-overvåkning',),
'TV-overvåkninger': ('TV-overvåkning',),
'TV-program': ('TV-program',),
'TV-programma': ('TV-program',),
'TV-programmene': ('TV-program',),
'TV-programmer': ('TV-program',),
'TV-programmet': ('TV-program',),
'TV-skjerm': ('TV-skjerm',),
'TV-skjermen': ('TV-skjerm',),
'TV-skjermene': ('TV-skjerm',),
'TV-skjermer': ('TV-skjerm',),
'TV-vert': ('TV-vert',),
'TV-verten': ('TV-vert',),
'TV-vertene': ('TV-vert',),
'TV-verter': ('TV-vert',),
'TV-vertinna': ('TV-vertinne',),
'TV-vertinne': ('TV-vertinne',),
'TV-vertinnen': ('TV-vertinne',),
'TV-vertinnene': ('TV-vertinne',),
'TV-vertinner': ('TV-vertinne',),
'Tellus': ('Tellus',),
'Thalia': ('Thalia',),
'U': ('U',),
'U\'en': ('U',),
'U-en': ('U',),
'U-ene': ('U',),
'U-er': ('U',),
'U-dal': ('U-dal',),
'U-dalen': ('U-dal',),
'U-dalene': ('U-dal',),
'U-daler': ('U-dal',),
'U-jern': ('U-jern',),
'U-jerna': ('U-jern',),
'U-jernene': ('U-jern',),
'U-jernet': ('U-jern',),
'U-stål': ('U-stål',),
'U-ståla': ('U-stål',),
'U-stålene': ('U-stål',),
'U-stålet': ('U-stål',),
'UFO': ('UFO',),
'UFOen': ('UFO',),
'UFOene': ('UFO',),
'UFOer': ('UFO',),
'V': ('V',),
'V\'en': ('V',),
'V-en': ('V',),
'V-ene': ('V',),
'V-er': ('V',),
'V-bomba': ('V-bombe',),
'V-bombe': ('V-bombe',),
'V-bomben': ('V-bombe',),
'V-bombene': ('V-bombe',),
'V-bomber': ('V-bombe',),
'V-dag': ('V-dag',),
'V-dagen': ('V-dag',),
'V-dagene': ('V-dag',),
'V-dager': ('V-dag',),
'V-dal': ('V-dal',),
'V-dalen': ('V-dal',),
'V-dalene': ('V-dal',),
'V-daler': ('V-dal',),
'V-genser': ('V-genser',),
'V-gensere': ('V-genser',),
'V-genseren': ('V-genser',),
'V-genserer': ('V-genser',),
'V-genserne': ('V-genser',),
'V-utringning': ('V-utringning',),
'V-utringninga': ('V-utringning',),
'V-utringningen': ('V-utringning',),
'V-utringningene': ('V-utringning',),
'V-utringninger': ('V-utringning',),
'V6-kupong': ('V6-kupong',),
'V6-kupongen': ('V6-kupong',),
'V6-kupongene': ('V6-kupong',),
'V6-kuponger': ('V6-kupong',),
'V6-løp': ('V6-løp',),
'V6-løpa': ('V6-løp',),
'V6-løpene': ('V6-løp',),
'V6-løpet': ('V6-løp',),
'V6-rekka': ('V6-rekke',),
'V6-rekke': ('V6-rekke',),
'V6-rekken': ('V6-rekke',),
'V6-rekkene': ('V6-rekke',),
'V6-rekker': ('V6-rekke',),
'VIP': ('VIP',),
'VIPen': ('VIP',),
'VIPene': ('VIP',),
'VIPer': ('VIP',),
'VM': ('VM',),
'VM-a': ('VM',),
'VM-ene': ('VM',),
'VM-et': ('VM',),
'VVS-ingeniør': ('VVS-ingeniør',),
'VVS-ingeniøren': ('VVS-ingeniør',),
'VVS-ingeniørene': ('VVS-ingeniør',),
'VVS-ingeniører': ('VVS-ingeniør',),
'Vesten': ('Vesten',),
'Vårherre': ('Vårherre',),
'W': ('W',),
'W\'en': ('W',),
'W-en': ('W',),
'W-ene': ('W',),
'W-er': ('W',),
'WC': ('WC',),
'WCa': ('WC',),
'WCene': ('WC',),
'WCer': ('WC',),
'WCet': ('WC',),
'X': ('X',),
'X\'en': ('X',),
'X-en': ('X',),
'X-ene': ('X',),
'X-er': ('X',),
'Y': ('Y',),
'Y\'en': ('Y',),
'Y-en': ('Y',),
'Y-ene': ('Y',),
'Y-er': ('Y',),
'Z': ('Z',),
'Z\'en': ('Z',),
'Z-en': ('Z',),
'Z-ene': ('Z',),
'Z-er': ('Z',),
'Zodiak': ('Zodiak',),
'Zodiaken': ('Zodiak',),
'Zodiakene': ('Zodiak',),
'Zodiaker': ('Zodiak',),
'Zodiakus': ('Zodiakus',),
'Zodiakusen': ('Zodiakus',),
'Zodiakusene': ('Zodiakus',),
'Zodiakuser': ('Zodiakus',),
'a': ('a',),
'a\'en': ('a',),
'a-en': ('a',),
'a-ene': ('a',),
'a-er': ('a',),
'a': ('a',),
'a cappella-kor': ('a cappella-kor',),
'a cappella-kora': ('a cappella-kor',),
'a cappella-korene': ('a cappella-kor',),
'a cappella-koret': ('a cappella-kor',),
'a cappella-sang': ('a cappella-sang',),
'a cappella-sangen': ('a cappella-sang',),
'a cappella-sangene': ('a cappella-sang',),
'a cappella-sanger': ('a cappella-sang',),
'a konto-betaling': ('a konto-betaling',),
'a konto-betalinga': ('a konto-betaling',),
'a konto-betalingen': ('a konto-betaling',),
'a konto-betalingene': ('a konto-betaling',),
'a konto-betalinger': ('a konto-betaling',),
'a-bomba': ('a-bombe',),
'a-bombe': ('a-bombe',),
'a-bomben': ('a-bombe',),
'a-bombene': ('a-bombe',),
'a-bomber': ('a-bombe',),
'a-egg': ('a-egg',),
'a-egga': ('a-egg',),
'a-eggene': ('a-egg',),
'a-egget': ('a-egg',),
'a-endelse': ('a-endelse',),
'a-endelsen': ('a-endelse',),
'a-endelsene': ('a-endelse',),
'a-endelser': ('a-endelse',),
'a-ending': ('a-ending',),
'a-endinga': ('a-ending',),
'a-endingen': ('a-ending',),
'a-endingene': ('a-ending',),
'a-endinger': ('a-ending',),
'a-form': ('a-form',),
'a-forma': ('a-form',),
'a-formen': ('a-form',),
'a-formene': ('a-form',),
'a-former': ('a-form',),
'a-lag': ('a-lag',),
'a-laga': ('a-lag',),
'a-lagene': ('a-lag',),
'a-laget': ('a-lag',),
'a-menneska': ('a-menneske',),
'a-menneske': ('a-menneske',),
'a-menneskene': ('a-menneske',),
'a-mennesker': ('a-menneske',),
'a-mennesket': ('a-menneske',),
'a-moll': ('a-moll',),
'a-mollen': ('a-moll',),
'a-mollene': ('a-moll',),
'a-moller': ('a-moll',),
'a-mollkonsert': ('a-mollkonsert',),
'a-mollkonserten': ('a-mollkonsert',),
'a-mollkonsertene': ('a-mollkonsert',),
'a-mollkonserter': ('a-mollkonsert',),
'a-mål': ('a-mål',),
'a-måla': ('a-mål',),
'a-målene': ('a-mål',),
'a-målet': ('a-mål',),
'a-våpen': ('a-våpen',),
'a-våpenet': ('a-våpen',),
'a-våpna': ('a-våpen',),
'a-våpnene': ('a-våpen',),
'ab-kjøp': ('ab-kjøp',),
'ab-kjøpa': ('ab-kjøp',),
'ab-kjøpene': ('ab-kjøp',),
'ab-kjøpet': ('ab-kjøp',),
'ab-kontrakt': ('ab-kontrakt',),
'ab-kontrakten': ('ab-kontrakt',),
'ab-kontraktene': ('ab-kontrakt',),
'ab-kontrakter': ('ab-kontrakt',),
'abbed': ('abbed',),
'abbeden': ('abbed',),
'abbedene': ('abbed',),
'abbeder': ('abbed',),
'abbedi': ('abbedi',),
'abbedia': ('abbedi',),
'abbediene': ('abbedi',),
'abbedier': ('abbedi',),
'abbediet': ('abbedi',),
'abbedissa': ('abbedisse',),
'abbedisse': ('abbedisse',),
'abbedissen': ('abbedisse',),
'abbedissene': ('abbedisse',),
'abbedisser': ('abbedisse',),
'abbor': ('abbor',),
'abboren': ('abbor',),
'abborene': ('abbor',),
'abborer': ('abbor',),
'abbor': ('abbor',),
'abboren': ('abbor',),
'abborene': ('abbor',),
'abborer': ('abbor',),
'abbreviasjon': ('abbreviasjon',),
'abbreviasjonen': ('abbreviasjon',),
'abbreviasjonene': ('abbreviasjon',),
'abbreviasjoner': ('abbreviasjon',),
'abbreviatur': ('abbreviatur',),
'abbreviaturen': ('abbreviatur',),
'abbreviaturene': ('abbreviatur',),
'abbreviaturer': ('abbreviatur',),
'abc': ('abc',),
'abca': ('abc',),
'abcen': ('abc',),
'abcene': ('abc',),
'abcer': ('abc',),
'abc-bok': ('abc-bok',),
'abc-boka': ('abc-bok',),
'abc-boken': ('abc-bok',),
'abc-bøkene': ('abc-bok',),
'abc-bøker': ('abc-bok',),
'abc-krigføring': ('abc-krigføring',),
'abc-krigføringa': ('abc-krigføring',),
'abc-krigføringen': ('abc-krigføring',),
'abc-krigføringene': ('abc-krigføring',),
'abc-krigføringer': ('abc-krigføring',),
'abc-våpen': ('abc-våpen',),
'abc-våpenet': ('abc-våpen',),
'abc-våpna': ('abc-våpen',),
'abc-våpnene': ('abc-våpen',),
'abdikasjon': ('abdikasjon',),
'abdikasjonen': ('abdikasjon',),
'abdikasjonene': ('abdikasjon',),
'abdikasjoner': ('abdikasjon',),
'abdomen': ('abdomen',),
'abdomena': ('abdomen',),
'abdomenene': ('abdomen',),
'abdomenet': ('abdomen',),
'abdomina': ('abdomen',),
'abdominaene': ('abdomen',),
'aber': ('aber',),
'abera': ('aber',),
'abere': ('aber',),
'aberet': ('aber',),
'aberne': ('aber',),
'aberrasjon': ('aberrasjon',),
'aberrasjonen': ('aberrasjon',),
'aberrasjonene': ('aberrasjon',),
'aberrasjoner': ('aberrasjon',),
'abessinier': ('abessinier',),
'abessiniere': ('abessinier',),
'abessinieren': ('abessinier',),
'abessinierer': ('abessinier',),
'abessinierne': ('abessinier',),
'abkhaser': ('abkhaser',),
'abkhasere': ('abkhaser',),
'abkhaseren': ('abkhaser',),
'abkhaserer': ('abkhaser',),
'abkhaserne': ('abkhaser',),
'ablativ': ('ablativ',),
'ablativen': ('ablativ',),
'ablativene': ('ablativ',),
'ablativer': ('ablativ',),
'ablegøyene': ('ablegøyer',),
'ablegøyer': ('ablegøyer',),
'abnormitet': ('abnormitet',),
'abnormiteten': ('abnormitet',),
'abnormitetene': ('abnormitet',),
'abnormiteter': ('abnormitet',),
'abolisjon': ('abolisjon',),
'abolisjonen': ('abolisjon',),
'abolisjonene': ('abolisjon',),
'abolisjoner': ('abolisjon',),
'abolisjonist': ('abolisjonist',),
'abolisjonisten': ('abolisjonist',),
'abolisjonistene': ('abolisjonist',),
'abolisjonister': ('abolisjonist',),
'abonnement': ('abonnement',),
'abonnementa': ('abonnement',),
'abonnementene': ('abonnement',),
'abonnementer': ('abonnement',),
'abonnementet': ('abonnement',),
'abonnementsavgift': ('abonnementsavgift',),
'abonnementsavgifta': ('abonnementsavgift',),
'abonnementsavgiften': ('abonnementsavgift',),
'abonnementsavgiftene': ('abonnementsavgift',),
'abonnementsavgifter': ('abonnementsavgift',),
'abonnementskonsert': ('abonnementskonsert',),
'abonnementskonserten': ('abonnementskonsert',),
'abonnementskonsertene': ('abonnementskonsert',),
'abonnementskonserter': ('abonnementskonsert',),
'abonnementspris': ('abonnementspris',),
'abonnementsprisen': ('abonnementspris',),
'abonnementsprisene': ('abonnementspris',),
'abonnementspriser': ('abonnementspris',),
'abonnementssalg': ('abonnementssalg',),
'abonnementssalga': ('abonnementssalg',),
'abonnementssalgene': ('abonnementssalg',),
'abonnementssalget': ('abonnementssalg',),
'abonnent': ('abonnent',),
'abonnenten': ('abonnent',),
'abonnentene': ('abonnent',),
'abonnenter': ('abonnent',),
'aborigin': ('aborigin',),
'aboriginen': ('aborigin',),
'aboriginene': ('aborigin',),
'aboriginer': ('aborigin',),
'abort': ('abort',),
'aborten': ('abort',),
'abortene': ('abort',),
'aborter': ('abort',),
'abortiv': ('abortiv',),
'abortiva': ('abortiv',),
'abortivene': ('abortiv',),
'abortiver': ('abortiv',),
'abortivet': ('abortiv',),
'abortivkur': ('abortivkur',),
'abortivkuren': ('abortivkur',),
'abortivkurene': ('abortivkur',),
'abortivkurer': ('abortivkur',),
'abortivmiddel': ('abortivmiddel',),
'abortivmiddelet': ('abortivmiddel',),
'abortivmidla': ('abortivmiddel',),
'abortivmidlene': ('abortivmiddel',),
'abortivmidler': ('abortivmiddel',),
'abortivmidlet': ('abortivmiddel',),
'abortlov': ('abortlov',),
'abortloven': ('abortlov',),
'abortlovene': ('abortlov',),
'abortlover': ('abortlov',),
'abortsøker': ('abortsøker',),
'abortsøkere': ('abortsøker',),
'abortsøkeren': ('abortsøker',),
'abortsøkerer': ('abortsøker',),
'abortsøkerne': ('abortsøker',),
'abortus provocatus': ('abortus provocatus',),
'abrakadabra': ('abrakadabra',),
'abrakadabraa': ('abrakadabra',),
'abrakadabraene': ('abrakadabra',),
'abrakadabraet': ('abrakadabra',),
'abrodd': ('abrodd',),
'abrodden': ('abrodd',),
'abroddene': ('abrodd',),
'abrodder': ('abrodd',),
'abrot': ('abrot',),
'abroten': ('abrot',),
'abrotene': ('abrot',),
'abroter': ('abrot',),
'abscess': ('abscess',),
'abscessen': ('abscess',),
'abscessene': ('abscess',),
'abscesser': ('abscess',),
'abscisse': ('abscisse',),
'abscissen': ('abscisse',),
'abscissene': ('abscisse',),
'abscisser': ('abscisse',),
'abscisseakse': ('abscisseakse',),
'abscisseaksen': ('abscisseakse',),
'abscisseaksene': ('abscisseakse',),
'abscisseakser': ('abscisseakse',),
'absentia': ('absentia',),
'absint': ('absint',),
'absinten': ('absint',),
'absintene': ('absint',),
'absinter': ('absint',),
'absolusjon': ('absolusjon',),
'absolusjonen': ('absolusjon',),
'absolusjonene': ('absolusjon',),
'absolusjoner': ('absolusjon',),
'absolutisme': ('absolutisme',),
'absolutismen': ('absolutisme',),
'absolutismene': ('absolutisme',),
'absolutismer': ('absolutisme',),
'absolutist': ('absolutist',),
'absolutisten': ('absolutist',),
'absolutistene': ('absolutist',),
'absolutister': ('absolutist',),
'absolutt': ('absolutt',),
'absolutta': ('absolutt',),
'absoluttene': ('absolutt',),
'absolutter': ('absolutt',),
'absoluttet': ('absolutt',),
'absorbent': ('absorbent',),
'absorbenten': ('absorbent',),
'absorbentene': ('absorbent',),
'absorbenter': ('absorbent',),
'absorbering': ('absorbering',),
'absorberinga': ('absorbering',),
'absorberingen': ('absorbering',),
'absorberingene': ('absorbering',),
'absorberinger': ('absorbering',),
'absorberingsevna': ('absorberingsevne',),
'absorberingsevne': ('absorberingsevne',),
'absorberingsevnen': ('absorberingsevne',),
'absorberingsevnene': ('absorberingsevne',),
'absorberingsevner': ('absorberingsevne',),
'absorberingskoeffisient': ('absorberingskoeffisient',),
'absorberingskoeffisienten': ('absorberingskoeffisient',),
'absorberingskoeffisientene': ('absorberingskoeffisient',),
'absorberingskoeffisienter': ('absorberingskoeffisient',),
'absorpsjon': ('absorpsjon',),
'absorpsjonen': ('absorpsjon',),
'absorpsjonene': ('absorpsjon',),
'absorpsjoner': ('absorpsjon',),
'absorpsjonsevna': ('absorpsjonsevne',),
'absorpsjonsevne': ('absorpsjonsevne',),
'absorpsjonsevnen': ('absorpsjonsevne',),
'absorpsjonsevnene': ('absorpsjonsevne',),
'absorpsjonsevner': ('absorpsjonsevne',),
'absorpsjonskoeffisient': ('absorpsjonskoeffisient',),
'absorpsjonskoeffisienten': ('absorpsjonskoeffisient',),
'absorpsjonskoeffisientene': ('absorpsjonskoeffisient',),
'absorpsjonskoeffisienter': ('absorpsjonskoeffisient',),
'abstinens': ('abstinens',),
'abstinensen': ('abstinens',),
'abstinensene': ('abstinens',),
'abstinenser': ('abstinens',),
'abstinenssymptom': ('abstinenssymptom',),
'abstinenssymptoma': ('abstinenssymptom',),
'abstinenssymptomene': ('abstinenssymptom',),
'abstinenssymptomer': ('abstinenssymptom',),
'abstinenssymptomet': ('abstinenssymptom',),
'abstinensvanske': ('abstinensvanske',),
'abstinensvansken': ('abstinensvanske',),
'abstinensvanskene': ('abstinensvanske',),
'abstinensvansker': ('abstinensvanske',),
'abstrahering': ('abstrahering',),
'abstraheringa': ('abstrahering',),
'abstraheringen': ('abstrahering',),
'abstraheringene': ('abstrahering',),
'abstraheringer': ('abstrahering',),
'abstraksjon': ('abstraksjon',),
'abstraksjonen': ('abstraksjon',),
'abstraksjonene': ('abstraksjon',),
'abstraksjoner': ('abstraksjon',),
'abstraksjonsevna': ('abstraksjonsevne',),
'abstraksjonsevne': ('abstraksjonsevne',),
'abstraksjonsevnen': ('abstraksjonsevne',),
'abstraksjonsevnene': ('abstraksjonsevne',),
'abstraksjonsevner': ('abstraksjonsevne',),
'abstraksjonsnivå': ('abstraksjonsnivå',),
'abstraksjonsnivåa': ('abstraksjonsnivå',),
'abstraksjonsnivåene': ('abstraksjonsnivå',),
'abstraksjonsnivåer': ('abstraksjonsnivå',),
'abstraksjonsnivået': ('abstraksjonsnivå',),
'abstrakt': ('abstrakt',),
'abstrakta': ('abstrakt',),
'abstraktene': ('abstrakt',),
'abstrakter': ('abstrakt',),
'abstraktet': ('abstrakt',),
'absurdisme': ('absurdisme',),
'absurdismen': ('absurdisme',),
'absurdismene': ('absurdisme',),
'absurdismer': ('absurdisme',),
'absurditet': ('absurditet',),
'absurditeten': ('absurditet',),
'absurditetene': ('absurditet',),
'absurditeter': ('absurditet',),
'accent aigu': ('accent aigu',),
'accent aiguen': ('accent aigu',),
'accent aiguene': ('accent aigu',),
'accent aiguer': ('accent aigu',),
'accent circonflexe': ('accent circonflexe',),
'accent circonflexen': ('accent circonflexe',),
'accent circonflexene': ('accent circonflexe',),
'accent circonflexer': ('accent circonflexe',),
'accent grave': ('accent grave',),
'accent graven': ('accent grave',),
'accent gravene': ('accent grave',),
'accent graver': ('accent grave',),
'accessoirene': ('accessoirer',),
'accessoirer': ('accessoirer',),
'acetat': ('acetat',),
'acetata': ('acetat',),
'acetatene': ('acetat',),
'acetater': ('acetat',),
'acetatet': ('acetat',),
'aceton': ('aceton',),
'acetona': ('aceton',),
'acetonene': ('aceton',),
'acetonet': ('aceton',),
'acetyl': ('acetyl',),
'acetyla': ('acetyl',),
'acetylene': ('acetyl',),
'acetylet': ('acetyl',),
'acetylen': ('acetylen',),
'acetylena': ('acetylen',),
'acetylenene': ('acetylen',),
'acetylenet': ('acetylen',),
'acetylsalisylsyra': ('acetylsalisylsyre',),
'acetylsalisylsyre': ('acetylsalisylsyre',),
'acetylsalisylsyren': ('acetylsalisylsyre',),
'acetylsalisylsyrene': ('acetylsalisylsyre',),
'acetylsalisylsyrer': ('acetylsalisylsyre',),
'acre': ('acre',),
'acren': ('acre',),
'acrene': ('acre',),
'acres': ('acre',),
'actinium': ('actinium',),
'actiniuma': ('actinium',),
'actiniumene': ('actinium',),
'actiniumet': ('actinium',),
'acyl': ('acyl',),
'acyla': ('acyl',),
'acylene': ('acyl',),
'acylet': ('acyl',),
'ad hoc-definisjon': ('ad hoc-definisjon',),
'ad hoc-definisjonen': ('ad hoc-definisjon',),
'ad hoc-definisjonene': ('ad hoc-definisjon',),
'ad hoc-definisjoner': ('ad hoc-definisjon',),
'adagio': ('adagio',),
'adagioen': ('adagio',),
'adagioene': ('adagio',),
'adagioer': ('adagio',),
'adagio': ('adagio',),
'adagioa': ('adagio',),
'adagioene': ('adagio',),
'adagioer': ('adagio',),
'adagioet': ('adagio',),
'adam': ('adam',),
'adamen': ('adam',),
'adamene': ('adam',),
'adamer': ('adam',),
'adamsdrakt': ('adamsdrakt',),
'adamsdrakta': ('adamsdrakt',),
'adamsdrakten': ('adamsdrakt',),
'adamsdraktene': ('adamsdrakt',),
'adamsdrakter': ('adamsdrakt',),
'adamsepla': ('adamseple',),
'adamseple': ('adamseple',),
'adamseplene': ('adamseple',),
'adamsepler': ('adamseple',),
'adamseplet': ('adamseple',),
'adamsnatur': ('adamsnatur',),
'adamsnaturen': ('adamsnatur',),
'adamsnaturene': ('adamsnatur',),
'adamsnaturer': ('adamsnatur',),
'adamsslekt': ('adamsslekt',),
'adamsslekta': ('adamsslekt',),
'adamsslekten': ('adamsslekt',),
'adamsslektene': ('adamsslekt',),
'adamsslekter': ('adamsslekt',),
'adapsjon': ('adapsjon',),
'adapsjonen': ('adapsjon',),
'adapsjonene': ('adapsjon',),
'adapsjoner': ('adapsjon',),
'adapsjonsevna': ('adapsjonsevne',),
'adapsjonsevne': ('adapsjonsevne',),
'adapsjonsevnen': ('adapsjonsevne',),
'adapsjonsevnene': ('adapsjonsevne',),
'adapsjonsevner': ('adapsjonsevne',),
'adaptasjon': ('adaptasjon',),
'adaptasjonen': ('adaptasjon',),
'adaptasjonene': ('adaptasjon',),
'adaptasjoner': ('adaptasjon',),
'adapter': ('adapter',),
'adaptere': ('adapter',),
'adapteren': ('adapter',),
'adapterer': ('adapter',),
'adapterne': ('adapter',),
'adb-operatør': ('adb-operatør',),
'adb-operatøren': ('adb-operatør',),
'adb-operatørene': ('adb-operatør',),
'adb-operatører': ('adb-operatør',),
'addend': ('addend',),
'addenden': ('addend',),
'addendene': ('addend',),
'addender': ('addend',),
'addering': ('addering',),
'adderinga': ('addering',),
'adderingen': ('addering',),
'adderingene': ('addering',),
'adderinger': ('addering',),
'addisjon': ('addisjon',),
'addisjonen': ('addisjon',),
'addisjonene': ('addisjon',),
'addisjoner': ('addisjon',),
'addisjonsfeil': ('addisjonsfeil',),
'addisjonsfeilen': ('addisjonsfeil',),
'addisjonsfeilene': ('addisjonsfeil',),
'addisjonsoppgava': ('addisjonsoppgave',),
'addisjonsoppgave': ('addisjonsoppgave',),
'addisjonsoppgaven': ('addisjonsoppgave',),
'addisjonsoppgavene': ('addisjonsoppgave',),
'addisjonsoppgaver': ('addisjonsoppgave',),
'addisjonsreaksjon': ('addisjonsreaksjon',),
'addisjonsreaksjonen': ('addisjonsreaksjon',),
'addisjonsreaksjonene': ('addisjonsreaksjon',),
'addisjonsreaksjoner': ('addisjonsreaksjon',),
'addisjonsstykka': ('addisjonsstykke',),
'addisjonsstykke': ('addisjonsstykke',),
'addisjonsstykkene': ('addisjonsstykke',),
'addisjonsstykker': ('addisjonsstykke',),
'addisjonsstykket': ('addisjonsstykke',),
'addisjonstegn': ('addisjonstegn',),
'addisjonstegna': ('addisjonstegn',),
'addisjonstegnene': ('addisjonstegn',),
'addisjonstegnet': ('addisjonstegn',),
'additiv': ('additiv',),
'additiva': ('additiv',),
'additivene': ('additiv',),
'additiver': ('additiv',),
'additivet': ('additiv',),
'adel': ('adel',),
'adelen': ('adel',),
'adlene': ('adel',),
'adler': ('adel',),
'adelsbrev': ('adelsbrev',),
'adelsbreva': ('adelsbrev',),
'adelsbrevene': ('adelsbrev',),
'adelsbrever': ('adelsbrev',),
'adelsbrevet': ('adelsbrev',),
'adelsdiplom': ('adelsdiplom',),
'adelsdiploma': ('adelsdiplom',),
'adelsdiplomene': ('adelsdiplom',),
'adelsdiplomer': ('adelsdiplom',),
'adelsdiplomet': ('adelsdiplom',),
'adelskalender': ('adelskalender',),
'adelskalendere': ('adelskalender',),
'adelskalenderen': ('adelskalender',),
'adelskalenderer': ('adelskalender',),
'adelskalenderne': ('adelskalender',),
'adelskalendre': ('adelskalender',),
'adelskalendrene': ('adelskalender',),
'adelskalendrer': ('adelskalender',),
'adelskap': ('adelskap',),
'adelskapa': ('adelskap',),
'adelskapen': ('adelskap',),
'adelskapene': ('adelskap',),
'adelskaper': ('adelskap',),
'adelskapet': ('adelskap',),
'adelsmann': ('adelsmann',),
'adelsmannen': ('adelsmann',),
'adelsmenn': ('adelsmann',),
'adelsmennene': ('adelsmann',),
'adelsmerka': ('adelsmerke',),
'adelsmerke': ('adelsmerke',),
'adelsmerkene': ('adelsmerke',),
'adelsmerker': ('adelsmerke',),
'adelsmerket': ('adelsmerke',),
'adelsprivileg': ('adelsprivileg',),
'adelsprivilega': ('adelsprivileg',),
'adelsprivilegene': ('adelsprivileg',),
'adelsprivileger': ('adelsprivileg',),
'adelsprivileget': ('adelsprivileg',),
'adelsprivilegia': ('adelsprivilegium',),
'adelsprivilegiene': ('adelsprivilegium',),
'adelsprivilegier': ('adelsprivilegium',),
'adelsprivilegiet': ('adelsprivilegium',),
'adelsprivilegium': ('adelsprivilegium',),
'adelsskjold': ('adelsskjold',),
'adelsskjolda': ('adelsskjold',),
'adelsskjoldene': ('adelsskjold',),
'adelsskjoldet': ('adelsskjold',),
'adelsslekt': ('adelsslekt',),
'adelsslekta': ('adelsslekt',),
'adelsslekten': ('adelsslekt',),
'adelsslektene': ('adelsslekt',),
'adelsslekter': ('adelsslekt',),
'adelsstand': ('adelsstand',),
'adelsstanden': ('adelsstand',),
'adelsstandene': ('adelsstand',),
'adelsstander': ('adelsstand',),
'adelstitlene': ('adelstittel',),
'adelstitler': ('adelstittel',),
'adelstittel': ('adelstittel',),
'adelstittelen': ('adelstittel',),
'adelsætt': ('adelsætt',),
'adelsætta': ('adelsætt',),
'adelsætten': ('adelsætt',),
'adelsættene': ('adelsætt',),
'adelsætter': ('adelsætt',),
'adenitt': ('adenitt',),
'adenitten': ('adenitt',),
'adenittene': ('adenitt',),
'adenitter': ('adenitt',),
'adept': ('adept',),
'adepten': ('adept',),
'adeptene': ('adept',),
'adepter': ('adept',),
'adgang': ('adgang',),
'adgangen': ('adgang',),
'adgangene': ('adgang',),
'adganger': ('adgang',),
'adgangsbillett': ('adgangsbillett',),
'adgangsbilletten': ('adgangsbillett',),
'adgangsbillettene': ('adgangsbillett',),
'adgangsbilletter': ('adgangsbillett',),
'adgangskort': ('adgangskort',),
'adgangskorta': ('adgangskort',),
'adgangskortene': ('adgangskort',),
'adgangskortet': ('adgangskort',),
'adgangstegn': ('adgangstegn',),
'adgangstegna': ('adgangstegn',),
'adgangstegnene': ('adgangstegn',),
'adgangstegnet': ('adgangstegn',),
'adherens': ('adherens',),
'adherensen': ('adherens',),
'adherensene': ('adherens',),
'adherenser': ('adherens',),
'adhesjon': ('adhesjon',),
'adhesjonen': ('adhesjon',),
'adhesjonene': ('adhesjon',),
'adhesjoner': ('adhesjon',),
'adiafora': ('adiaforon',),
'adiaforaene': ('adiaforon',),
'adiaforon': ('adiaforon',),
'adiaforonet': ('adiaforon',),
'adjektiv': ('adjektiv',),
'adjektiva': ('adjektiv',),
'adjektivene': ('adjektiv',),
'adjektiver': ('adjektiv',),
'adjektivet': ('adjektiv',),
'adjunkt': ('adjunkt',),
'adjunkten': ('adjunkt',),
'adjunktene': ('adjunkt',),
'adjunkter': ('adjunkt',),
'adjunkteksamen': ('adjunkteksamen',),
'adjunkteksamenen': ('adjunkteksamen',),
'adjunkteksamenene': ('adjunkteksamen',),
'adjunkteksamener': ('adjunkteksamen',),
'adjunktkompetanse': ('adjunktkompetanse',),
'adjunktkompetansen': ('adjunktkompetanse',),
'adjunktkompetansene': ('adjunktkompetanse',),
'adjunktkompetanser': ('adjunktkompetanse',),
'adjutant': ('adjutant',),
'adjutanten': ('adjutant',),
'adjutantene': ('adjutant',),
'adjutanter': ('adjutant',),
'adjutantstab': ('adjutantstab',),
'adjutantstaben': ('adjutantstab',),
'adjutantstabene': ('adjutantstab',),
'adjutantstaber': ('adjutantstab',),
'adjutantur': ('adjutantur',),
'adjutanturen': ('adjutantur',),
'adjutanturene': ('adjutantur',),
'adjutanturer': ('adjutantur',),
'adjø': ('adjø',),
'adjøa': ('adjø',),
'adjøene': ('adjø',),
'adjøer': ('adjø',),
'adjøet': ('adjø',),
'administrasjon': ('administrasjon',),
'administrasjonen': ('administrasjon',),
'administrasjonene': ('administrasjon',),
'administrasjoner': ('administrasjon',),
'administrasjonsbygning': ('administrasjonsbygning',),
'administrasjonsbygninga': ('administrasjonsbygning',),
'administrasjonsbygningen': ('administrasjonsbygning',),
'administrasjonsbygningene': ('administrasjonsbygning',),
'administrasjonsbygninger': ('administrasjonsbygning',),
'administrasjonssekretær': ('administrasjonssekretær',),
'administrasjonssekretæren': ('administrasjonssekretær',),
'administrasjonssekretærene': ('administrasjonssekretær',),
'administrasjonssekretærer': ('administrasjonssekretær',),
'administrasjonsstyra': ('administrasjonsstyre',),
'administrasjonsstyre': ('administrasjonsstyre',),
'administrasjonsstyrene': ('administrasjonsstyre',),
'administrasjonsstyrer': ('administrasjonsstyre',),
'administrasjonsstyret': ('administrasjonsstyre',),
'administrasjonstalent': ('administrasjonstalent',),
'administrasjonstalenta': ('administrasjonstalent',),
'administrasjonstalentene': ('administrasjonstalent',),
'administrasjonstalentet': ('administrasjonstalent',),
'administrasjonsutgift': ('administrasjonsutgift',),
'administrasjonsutgifta': ('administrasjonsutgift',),
'administrasjonsutgiften': ('administrasjonsutgift',),
'administrasjonsutgiftene': ('administrasjonsutgift',),
'administrasjonsutgifter': ('administrasjonsutgift',),
'administrator': ('administrator',),
'administratoren': ('administrator',),
'administratorene': ('administrator',),
'administratorer': ('administrator',),
'admiral': ('admiral',),
'admiralen': ('admiral',),
'admiralene': ('admiral',),
'admiraler': ('admiral',),
'admiralflagg': ('admiralflagg',),
'admiralflagga': ('admiralflagg',),
'admiralflaggene': ('admiralflagg',),
'admiralflagget': ('admiralflagg',),
'admiralitet': ('admiralitet',),
'admiraliteta': ('admiralitet',),
'admiralitetene': ('admiralitet',),
'admiralitetet': ('admiralitet',),
'admiralsflagg': ('admiralsflagg',),
'admiralsflagga': ('admiralsflagg',),
'admiralsflaggene': ('admiralsflagg',),
'admiralsflagget': ('admiralsflagg',),
'admiralskip': ('admiralskip',),
'admiralskipa': ('admiralskip',),
'admiralskipene': ('admiralskip',),
'admiralskipet': ('admiralskip',),
'admiralsskip': ('admiralsskip',),
'admiralsskipa': ('admiralsskip',),
'admiralsskipene': ('admiralsskip',),
'admiralsskipet': ('admiralsskip',),
'admiralsstab': ('admiralsstab',),
'admiralsstaben': ('admiralsstab',),
'admiralsstabene': ('admiralsstab',),
'admiralsstaber': ('admiralsstab',),
'admiralstab': ('admiralstab',),
'admiralstaben': ('admiralstab',),
'admiralstabene': ('admiralstab',),
'admiralstaber': ('admiralstab',),
'adonis': ('adonis',),
'adonisen': ('adonis',),
'adonisene': ('adonis',),
'adoniser': ('adonis',),
'adopsjon': ('adopsjon',),
'adopsjonen': ('adopsjon',),
'adopsjonene': ('adopsjon',),
'adopsjoner': ('adopsjon',),
'adopsjonskontor': ('adopsjonskontor',),
'adopsjonskontora': ('adopsjonskontor',),
'adopsjonskontorene': ('adopsjonskontor',),
'adopsjonskontorer': ('adopsjonskontor',),
'adopsjonskontoret': ('adopsjonskontor',),
'adopsjonstillatelse': ('adopsjonstillatelse',),
'adopsjonstillatelsen': ('adopsjonstillatelse',),
'adopsjonstillatelsene': ('adopsjonstillatelse',),
'adopsjonstillatelser': ('adopsjonstillatelse',),
'adoptant': ('adoptant',),
'adoptanten': ('adoptant',),
'adoptantene': ('adoptant',),
'adoptanter': ('adoptant',),
'adoptivbarn': ('adoptivbarn',),
'adoptivbarna': ('adoptivbarn',),
'adoptivbarnene': ('adoptivbarn',),
'adoptivbarnet': ('adoptivbarn',),
'adrenalin': ('adrenalin',),
'adrenalina': ('adrenalin',),
'adrenalinene': ('adrenalin',),
'adrenalinet': ('adrenalin',),
'adressant': ('adressant',),
'adressanten': ('adressant',),
'adressantene': ('adressant',),
'adressanter': ('adressant',),
'adressat': ('adressat',),
'adressaten': ('adressat',),
'adressatene': ('adressat',),
'adressater': ('adressat',),
'adressa': ('adresse',),
'adresse': ('adresse',),
'adressen': ('adresse',),
'adressene': ('adresse',),
'adresser': ('adresse',),
'adresseavis': ('adresseavis',),
'adresseavisa': ('adresseavis',),
'adresseavisen': ('adresseavis',),
'adresseavisene': ('adresseavis',),
'adresseaviser': ('adresseavis',),
'adresseforandring': ('adresseforandring',),
'adresseforandringa': ('adresseforandring',),
'adresseforandringen': ('adresseforandring',),
'adresseforandringene': ('adresseforandring',),
'adresseforandringer': ('adresseforandring',),
'adressekalender': ('adressekalender',),
'adressekalendere': ('adressekalender',),
'adressekalenderen': ('adressekalender',),
'adressekalenderer': ('adressekalender',),
'adressekalenderne': ('adressekalender',),
'adressekalendre': ('adressekalender',),
'adressekalendrene': ('adressekalender',),
'adressekalendrer': ('adressekalender',),
'adressekort': ('adressekort',),
'adressekorta': ('adressekort',),
'adressekortene': ('adressekort',),
'adressekortet': ('adressekort',),
'adressemegler': ('adressemegler',),
'adressemeglere': ('adressemegler',),
'adressemegleren': ('adressemegler',),
'adressemeglerer': ('adressemegler',),
'adressemeglerne': ('adressemegler',),
'adressemegling': ('adressemegling',),
'adressemeglinga': ('adressemegling',),
'adressemeglingen': ('adressemegling',),
'adressemeglingene': ('adressemegling',),
'adressemeglinger': ('adressemegling',),
'adressemekler': ('adressemekler',),
'adressemeklere': ('adressemekler',),
'adressemekleren': ('adressemekler',),
'adressemeklerer': ('adressemekler',),
'adressemeklerne': ('adressemekler',),
'adressemekling': ('adressemekling',),
'adressemeklinga': ('adressemekling',),
'adressemeklingen': ('adressemekling',),
'adressemeklingene': ('adressemekling',),
'adressemeklinger': ('adressemekling',),
'adresseringsmaskin': ('adresseringsmaskin',),
'adresseringsmaskina': ('adresseringsmaskin',),
'adresseringsmaskinen': ('adresseringsmaskin',),
'adresseringsmaskinene': ('adresseringsmaskin',),
'adresseringsmaskiner': ('adresseringsmaskin',),
'adsorpsjon': ('adsorpsjon',),
'adsorpsjonen': ('adsorpsjon',),
'adsorpsjonene': ('adsorpsjon',),
'adsorpsjoner': ('adsorpsjon',),
'advarsel': ('advarsel',),
'advarselen': ('advarsel',),
'advarslene': ('advarsel',),
'advarsler': ('advarsel',),
'advent': ('advent',),
'adventen': ('advent',),
'adventene': ('advent',),
'adventer': ('advent',),
'adventist': ('adventist',),
'adventisten': ('adventist',),
'adventistene': ('adventist',),
'adventister': ('adventist',),
'adventskalender': ('adventskalender',),
'adventskalendere': ('adventskalender',),
'adventskalenderen': ('adventskalender',),
'adventskalenderer': ('adventskalender',),
'adventskalenderne': ('adventskalender',),
'adventskalendre': ('adventskalender',),
'adventskalendrene': ('adventskalender',),
'adventskalendrer': ('adventskalender',),
'adventsstake': ('adventsstake',),
'adventsstaken': ('adventsstake',),
'adventsstakene': ('adventsstake',),
'adventsstaker': ('adventsstake',),
'adventssøndag': ('adventssøndag',),
'adventssøndagen': ('adventssøndag',),
'adventssøndagene': ('adventssøndag',),
'adventssøndager': ('adventssøndag',),
'adventstid': ('adventstid',),
'adventstida': ('adventstid',),
'adventstiden': ('adventstid',),
'adventstidene': ('adventstid',),
'adventstider': ('adventstid',),
'adverb': ('adverb',),
'adverba': ('adverb',),
'adverbene': ('adverb',),
'adverber': ('adverb',),
'adverbet': ('adverb',),
'adverb': ('adverb',),
'adverba': ('adverb',),
'adverbene': ('adverb',),
'adverber': ('adverb',),
'adverbet': ('adverb',),
'adverbial': ('adverbial',),
'adverbiala': ('adverbial',),
'adverbialene': ('adverbial',),
'adverbialer': ('adverbial',),
'adverbialet': ('adverbial',),
'adverbia': ('adverbium',),
'adverbiene': ('adverbium',),
'adverbier': ('adverbium',),
'adverbiet': ('adverbium',),
'adverbium': ('adverbium',),
'adverbia': ('adverbium',),
'adverbiene': ('adverbium',),
'adverbier': ('adverbium',),
'adverbiet': ('adverbium',),
'adverbium': ('adverbium',),
'advis': ('advis',),
'advisen': ('advis',),
'advisene': ('advis',),
'advokat': ('advokat',),
'advokaten': ('advokat',),
'advokatene': ('advokat',),
'advokater': ('advokat',),
'advokatbevilling': ('advokatbevilling',),
'advokatbevillingen': ('advokatbevilling',),
'advokatbevillingene': ('advokatbevilling',),
'advokatbevillinger': ('advokatbevilling',),
'advokatfirma': ('advokatfirma',),
'advokatfirmaene': ('advokatfirma',),
'advokatfirmaer': ('advokatfirma',),
'advokatfirmaet': ('advokatfirma',),
'advokatur': ('advokatur',),
'advokaturen': ('advokatur',),
'advokaturene': ('advokatur',),
'advokaturer': ('advokatur',),
'aerobic': ('aerobic',),
'aerobicen': ('aerobic',),
'aerobicene': ('aerobic',),
'aerobicer': ('aerobic',),
'aerodrom': ('aerodrom',),
'aerodromen': ('aerodrom',),
'aerodromene': ('aerodrom',),
'aerodromer': ('aerodrom',),
'aerodynamikk': ('aerodynamikk',),
'aerodynamikken': ('aerodynamikk',),
'aerodynamikkene': ('aerodynamikk',),
'aerodynamikker': ('aerodynamikk',),
'aerogram': ('aerogram',),
'aerogramma': ('aerogram',),
'aerogrammene': ('aerogram',),
'aerogrammer': ('aerogram',),
'aerogrammet': ('aerogram',),
'aeroklubb': ('aeroklubb',),
'aeroklubben': ('aeroklubb',),
'aeroklubbene': ('aeroklubb',),
'aeroklubber': ('aeroklubb',),
'aerolitt': ('aerolitt',),
'aerolitten': ('aerolitt',),
'aerolittene': ('aerolitt',),
'aerolitter': ('aerolitt',),
'aerologi': ('aerologi',),
'aerologien': ('aerologi',),
'aerologiene': ('aerologi',),
'aerologier': ('aerologi',),
'aeronaut': ('aeronaut',),
'aeronauten': ('aeronaut',),
'aeronautene': ('aeronaut',),
'aeronauter': ('aeronaut',),
'aeroplan': ('aeroplan',),
'aeroplana': ('aeroplan',),
'aeroplanene': ('aeroplan',),
'aeroplaner': ('aeroplan',),
'aeroplanet': ('aeroplan',),
'aerosol': ('aerosol',),
'aerosolen': ('aerosol',),
'aerosolene': ('aerosol',),
'aerosoler': ('aerosol',),
'aerosolboks': ('aerosolboks',),
'aerosolboksen': ('aerosolboks',),
'aerosolboksene': ('aerosolboks',),
'aerosolbokser': ('aerosolboks',),
'afasi': ('afasi',),
'afasien': ('afasi',),
'afasiene': ('afasi',),
'afasier': ('afasi',),
'afatiker': ('afatiker',),
'afatikere': ('afatiker',),
'afatikeren': ('afatiker',),
'afatikerer': ('afatiker',),
'afatikerne': ('afatiker',),
'affeksjon': ('affeksjon',),
'affeksjonen': ('affeksjon',),
'affeksjonene': ('affeksjon',),
'affeksjoner': ('affeksjon',),
'affeksjonsverdi': ('affeksjonsverdi',),
'affeksjonsverdien': ('affeksjonsverdi',),
'affeksjonsverdiene': ('affeksjonsverdi',),
'affeksjonsverdier': ('affeksjonsverdi',),
'affekt': ('affekt',),
'affekten': ('affekt',),
'affektene': ('affekt',),
'affekter': ('affekt',),
'affektasjon': ('affektasjon',),
'affektasjonen': ('affektasjon',),
'affektasjonene': ('affektasjon',),
'affektasjoner': ('affektasjon',),
'affiks': ('affiks',),
'affiksa': ('affiks',),
'affiksene': ('affiks',),
'affikser': ('affiks',),
'affikset': ('affiks',),
'affinitet': ('affinitet',),
'affiniteten': ('affinitet',),
'affinitetene': ('affinitet',),
'affiniteter': ('affinitet',),
'affrikat': ('affrikat',),
'affrikaten': ('affrikat',),
'affrikatene': ('affrikat',),
'affrikater': ('affrikat',),
'affutasje': ('affutasje',),
'affutasjen': ('affutasje',),
'affutasjene': ('affutasje',),
'affutasjer': ('affutasje',),
'affære': ('affære',),
'affæren': ('affære',),
'affærene': ('affære',),
'affærer': ('affære',),
'afghaner': ('afghaner',),
'afghanere': ('afghaner',),
'afghaneren': ('afghaner',),
'afghanerer': ('afghaner',),
'afghanerne': ('afghaner',),
'afghani': ('afghani',),
'afghanien': ('afghani',),
'afghaniene': ('afghani',),
'aforisme': ('aforisme',),
'aforismen': ('aforisme',),
'aforismene': ('aforisme',),
'aforismer': ('aforisme',),
'afrikaans': ('afrikaans',),
'afrikander': ('afrikander',),
'afrikandere': ('afrikander',),
'afrikanderen': ('afrikander',),
'afrikanderer': ('afrikander',),
'afrikanderne': ('afrikander',),
'afrikaner': ('afrikaner',),
'afrikanere': ('afrikaner',),
'afrikaneren': ('afrikaner',),
'afrikanerer': ('afrikaner',),
'afrikanerne': ('afrikaner',),
'afroamerikaner': ('afroamerikaner',),
'afroamerikanere': ('afroamerikaner',),
'afroamerikaneren': ('afroamerikaner',),
'afroamerikanerer': ('afroamerikaner',),
'afroamerikanerne': ('afroamerikaner',),
'afrodisi': ('afrodisi',),
'afrodisien': ('afrodisi',),
'afrodisiene': ('afrodisi',),
'afrodisier': ('afrodisi',),
'afroditt': ('afroditt',),
'afroditten': ('afroditt',),
'afrodittene': ('afroditt',),
'afroditter': ('afroditt',),
'afrofrisyre': ('afrofrisyre',),
'afrofrisyren': ('afrofrisyre',),
'afrofrisyrene': ('afrofrisyre',),
'afrofrisyrer': ('afrofrisyre',),
'aften': ('aften',),
'aftenen': ('aften',),
'aftenene': ('aften',),
'aftener': ('aften',),
'aftenantrekk': ('aftenantrekk',),
'aftenantrekka': ('aftenantrekk',),
'aftenantrekkene': ('aftenantrekk',),
'aftenantrekket': ('aftenantrekk',),
'aftenavis': ('aftenavis',),
'aftenavisa': ('aftenavis',),
'aftenavisen': ('aftenavis',),
'aftenavisene': ('aftenavis',),
'aftenaviser': ('aftenavis',),
'aftenbruk': ('aftenbruk',),
'aftenbruka': ('aftenbruk',),
'aftenbruken': ('aftenbruk',),
'aftenbrukene': ('aftenbruk',),
'aftenbruker': ('aftenbruk',),
'aftenbruket': ('aftenbruk',),
'aftenbønn': ('aftenbønn',),
'aftenbønna': ('aftenbønn',),
'aftenbønnen': ('aftenbønn',),
'aftenbønnene': ('aftenbønn',),
'aftenbønner': ('aftenbønn',),
'aftennummer': ('aftennummer',),
'aftennummeret': ('aftennummer',),
'aftennumra': ('aftennummer',),
'aftennumre': ('aftennummer',),
'aftennumrene': ('aftennummer',),
'aftenrøde': ('aftenrøde',),
'aftenrøden': ('aftenrøde',),
'aftenrødene': ('aftenrøde',),
'aftenrøder': ('aftenrøde',),
'aftens': ('aftens',),
'aftensang': ('aftensang',),
'aftensangen': ('aftensang',),
'aftensangene': ('aftensang',),
'aftensanger': ('aftensang',),
'aftensbord': ('aftensbord',),
'aftensborda': ('aftensbord',),
'aftensbordene': ('aftensbord',),
'aftensborder': ('aftensbord',),
'aftensbordet': ('aftensbord',),
'aftenskumring': ('aftenskumring',),
'aftenskumringa': ('aftenskumring',),
'aftenskumringen': ('aftenskumring',),
'aftenskumringene': ('aftenskumring',),
'aftenskumringer': ('aftenskumring',),
'aftensmat': ('aftensmat',),
'aftensmaten': ('aftensmat',),
'aftensmatene': ('aftensmat',),
'aftensmater': ('aftensmat',),
'aftenstemning': ('aftenstemning',),
'aftenstemninga': ('aftenstemning',),
'aftenstemningen': ('aftenstemning',),
'aftenstemningene': ('aftenstemning',),
'aftenstemninger': ('aftenstemning',),
'aftenstjerna': ('aftenstjerne',),
'aftenstjerne': ('aftenstjerne',),
'aftenstjernen': ('aftenstjerne',),
'aftenstjernene': ('aftenstjerne',),
'aftenstjerner': ('aftenstjerne',),
'aftentrekning': ('aftentrekning',),
'aftentrekninga': ('aftentrekning',),
'aftentrekningen': ('aftentrekning',),
'aftentrekningene': ('aftentrekning',),
'aftentrekninger': ('aftentrekning',),
'aftentur': ('aftentur',),
'aftenturen': ('aftentur',),
'aftenturene': ('aftentur',),
'aftenturer': ('aftentur',),
'agape': ('agape',),
'agapen': ('agape',),
'agapene': ('agape',),
'agaper': ('agape',),
'agat': ('agat',),
'agaten': ('agat',),
'agatene': ('agat',),
'agater': ('agat',),
'agatring': ('agatring',),
'agatringen': ('agatring',),
'agatringene': ('agatring',),
'agatringer': ('agatring',),
'agatstein': ('agatstein',),
'agatsteinen': ('agatstein',),
'agatsteinene': ('agatstein',),
'agatsteiner': ('agatstein',),
'age': ('age',),
'agen': ('age',),
'agene': ('age',),
'ager': ('age',),
'agenda': ('agenda',),
'agendaen': ('agenda',),
'agendaene': ('agenda',),
'agendaer': ('agenda',),
'agende': ('agende',),
'agenden': ('agende',),
'agendene': ('agende',),
'agender': ('agende',),
'agens': ('agens',),
'agensa': ('agens',),
'agensen': ('agens',),
'agensene': ('agens',),
'agenser': ('agens',),
'agenset': ('agens',),
'agensledd': ('agensledd',),
'agensledda': ('agensledd',),
'agensleddene': ('agensledd',),
'agensleddet': ('agensledd',),
'agent': ('agent',),
'agenten': ('agent',),
'agentene': ('agent',),
'agenter': ('agent',),
'agentfilm': ('agentfilm',),
'agentfilmen': ('agentfilm',),
'agentfilmene': ('agentfilm',),
'agentfilmer': ('agentfilm',),
'agentprovisjon': ('agentprovisjon',),
'agentprovisjonen': ('agentprovisjon',),
'agentprovisjonene': ('agentprovisjon',),
'agentprovisjoner': ('agentprovisjon',),
'agentroman': ('agentroman',),
'agentromanen': ('agentroman',),
'agentromanene': ('agentroman',),
'agentromaner': ('agentroman',),
'agentur': ('agentur',),
'agentura': ('agentur',),
'agenturene': ('agentur',),
'agenturer': ('agentur',),
'agenturet': ('agentur',),
'agenturfirma': ('agenturfirma',),
'agenturfirmaene': ('agenturfirma',),
'agenturfirmaer': ('agenturfirma',),
'agenturfirmaet': ('agenturfirma',),
'agenturforretning': ('agenturforretning',),
'agenturforretninga': ('agenturforretning',),
'agenturforretningen': ('agenturforretning',),
'agenturforretningene': ('agenturforretning',),
'agenturforretninger': ('agenturforretning',),
'agg': ('agg',),
'agga': ('agg',),
'aggene': ('agg',),
'agget': ('agg',),
'agglutinasjon': ('agglutinasjon',),
'agglutinasjonen': ('agglutinasjon',),
'agglutinasjonene': ('agglutinasjon',),
'agglutinasjoner': ('agglutinasjon',),
'agglutinering': ('agglutinering',),
'agglutineringa': ('agglutinering',),
'agglutineringen': ('agglutinering',),
'agglutineringene': ('agglutinering',),
'agglutineringer': ('agglutinering',),
'aggregat': ('aggregat',),
'aggregata': ('aggregat',),
'aggregatene': ('aggregat',),
'aggregater': ('aggregat',),
'aggregatet': ('aggregat',),
'aggregatform': ('aggregatform',),
'aggregatforma': ('aggregatform',),
'aggregatformen': ('aggregatform',),
'aggregatformene': ('aggregatform',),
'aggregatformer': ('aggregatform',),
'aggregattilstand': ('aggregattilstand',),
'aggregattilstanden': ('aggregattilstand',),
'aggregattilstandene': ('aggregattilstand',),
'aggregattilstander': ('aggregattilstand',),
'aggresjon': ('aggresjon',),
'aggresjonen': ('aggresjon',),
'aggresjonene': ('aggresjon',),
'aggresjoner': ('aggresjon',),
'aggressivitet': ('aggressivitet',),
'aggressiviteten': ('aggressivitet',),
'aggressivitetene': ('aggressivitet',),
'aggressiviteter': ('aggressivitet',),
'agio': ('agio',),
'agioen': ('agio',),
'agioene': ('agio',),
'agioer': ('agio',),
'agiotap': ('agiotap',),
'agiotapa': ('agiotap',),
'agiotapene': ('agiotap',),
'agiotapet': ('agiotap',),
'agiovinning': ('agiovinning',),
'agiovinninga': ('agiovinning',),
'agiovinningen': ('agiovinning',),
'agiovinningene': ('agiovinning',),
'agiovinninger': ('agiovinning',),
'agitasjon': ('agitasjon',),
'agitasjonen': ('agitasjon',),
'agitasjonene': ('agitasjon',),
'agitasjoner': ('agitasjon',),
'agitator': ('agitator',),
'agitatoren': ('agitator',),
'agitatorene': ('agitator',),
'agitatorer': ('agitator',),
'agn': ('agn',),
'agna': ('agn',),
'agnene': ('agn',),
'agnet': ('agn',),
'agn': ('agn',),
'agna': ('agn',),
'agnen': ('agn',),
'agnene': ('agn',),
'agner': ('agn',),
'agnat': ('agnat',),
'agnaten': ('agnat',),
'agnatene': ('agnat',),
'agnater': ('agnat',),
'agnfisk': ('agnfisk',),
'agnfisken': ('agnfisk',),
'agnfiskene': ('agnfisk',),
'agnfisker': ('agnfisk',),
'agnmakk': ('agnmakk',),
'agnmakken': ('agnmakk',),
'agnmakkene': ('agnmakk',),
'agnmakker': ('agnmakk',),
'agnmark': ('agnmark',),
'agnmarken': ('agnmark',),
'agnmarkene': ('agnmark',),
'agnmarker': ('agnmark',),
'agnor': ('agnor',),
'agnora': ('agnor',),
'agnoren': ('agnor',),
'agnorene': ('agnor',),
'agnorer': ('agnor',),
'agnostiker': ('agnostiker',),
'agnostikere': ('agnostiker',),
'agnostikeren': ('agnostiker',),
'agnostikerer': ('agnostiker',),
'agnostikerne': ('agnostiker',),
'agnostisisme': ('agnostisisme',),
'agnostisismen': ('agnostisisme',),
'agnostisismene': ('agnostisisme',),
'agnostisismer': ('agnostisisme',),
'agnsild': ('agnsild',),
'agnsilda': ('agnsild',),
'agnsilden': ('agnsild',),
'agnsildene': ('agnsild',),
'agnsilder': ('agnsild',),
'agnus Dei': ('agnus Dei',),
'agoni': ('agoni',),
'agonien': ('agoni',),
'agoniene': ('agoni',),
'agonier': ('agoni',),
'agorafobi': ('agorafobi',),
'agorafobien': ('agorafobi',),
'agorafobiene': ('agorafobi',),
'agorafobier': ('agorafobi',),
'agraff': ('agraff',),
'agraffen': ('agraff',),
'agraffene': ('agraff',),
'agraffer': ('agraff',),
'agrafi': ('agrafi',),
'agrafien': ('agrafi',),
'agrafiene': ('agrafi',),
'agrafier': ('agrafi',),
'agrar': ('agrar',),
'agraren': ('agrar',),
'agrarene': ('agrar',),
'agrarer': ('agrar',),
'agrarparti': ('agrarparti',),
'agrarpartia': ('agrarparti',),
'agrarpartiene': ('agrarparti',),
'agrarpartier': ('agrarparti',),
'agrarpartiet': ('agrarparti',),
'agrarpolitikk': ('agrarpolitikk',),
'agrarpolitikken': ('agrarpolitikk',),
'agrarpolitikkene': ('agrarpolitikk',),
'agrarpolitikker': ('agrarpolitikk',),
'agreement': ('agreement',),
'agrement': ('agrement',),
'agrementa': ('agrement',),
'agrementene': ('agrement',),
'agrementer': ('agrement',),
'agrementet': ('agrement',),
'agrikultur': ('agrikultur',),
'agrikulturen': ('agrikultur',),
'agrikulturene': ('agrikultur',),
'agrikulturer': ('agrikultur',),
'agronom': ('agronom',),
'agronomen': ('agronom',),
'agronomene': ('agronom',),
'agronomer': ('agronom',),
'agronomi': ('agronomi',),
'agronomien': ('agronomi',),
'agronomiene': ('agronomi',),
'agronomier': ('agronomi',),
'agrotekniker': ('agrotekniker',),
'agroteknikere': ('agrotekniker',),
'agroteknikeren': ('agrotekniker',),
'agroteknikerer': ('agrotekniker',),
'agroteknikerne': ('agrotekniker',),
'agurk': ('agurk',),
'agurken': ('agurk',),
'agurkene': ('agurk',),
'agurker': ('agurk',),
'agurksalat': ('agurksalat',),
'agurksalaten': ('agurksalat',),
'agurksalatene': ('agurksalat',),
'agurksalater': ('agurksalat',),
'agurktid': ('agurktid',),
'agurktida': ('agurktid',),
'agurktiden': ('agurktid',),
'agurktidene': ('agurktid',),
'agurktider': ('agurktid',),
'aha-opplevelse': ('aha-opplevelse',),
'aha-opplevelsen': ('aha-opplevelse',),
'aha-opplevelsene': ('aha-opplevelse',),
'aha-opplevelser': ('aha-opplevelse',),
'aids': ('aids',),
'aidsen': ('aids',),
'aidsene': ('aids',),
'aidser': ('aids',),
'aidssmitte': ('aidssmitte',),
'aidssmitten': ('aidssmitte',),
'aidssmittene': ('aidssmitte',),
'aidssmitter': ('aidssmitte',),
'aigu': ('aigu',),
'aiguen': ('aigu',),
'aiguene': ('aigu',),
'aiguer': ('aigu',),
'aino': ('aino',),
'ainoen': ('aino',),
'ainoene': ('aino',),
'ainoer': ('aino',),
'aino': ('aino',),
'air': ('air',),
'airen': ('air',),
'airene': ('air',),
'airer': ('air',),
'air-condition': ('air-condition',),
'air-conditionen': ('air-condition',),
'air-conditionene': ('air-condition',),
'air-conditioner': ('air-condition',),
'airbag': ('airbag',),
'airbagen': ('airbag',),
'airbagene': ('airbag',),
'airbager': ('airbag',),
'aiss': ('aiss',),
'aissen': ('aiss',),
'aissene': ('aiss',),
'aisser': ('aiss',),
'akademi': ('akademi',),
'akademia': ('akademi',),
'akademiene': ('akademi',),
'akademier': ('akademi',),
'akademiet': ('akademi',),
'akademiker': ('akademiker',),
'akademikere': ('akademiker',),
'akademikeren': ('akademiker',),
'akademikerer': ('akademiker',),
'akademikerne': ('akademiker',),
'akademisme': ('akademisme',),
'akademismen': ('akademisme',),
'akademismene': ('akademisme',),
'akademismer': ('akademisme',),
'akantus': ('akantus',),
'akantusen': ('akantus',),
'akantusene': ('akantus',),
'akantuser': ('akantus',),
'akantusblad': ('akantusblad',),
'akantusblada': ('akantusblad',),
'akantusbladene': ('akantusblad',),
'akantusblader': ('akantusblad',),
'akantusbladet': ('akantusblad',),
'akantusornament': ('akantusornament',),
'akantusornamenta': ('akantusornament',),
'akantusornamentene': ('akantusornament',),
'akantusornamenter': ('akantusornament',),
'akantusornamentet': ('akantusornament',),
'akantusplanta': ('akantusplante',),
'akantusplante': ('akantusplante',),
'akantusplanten': ('akantusplante',),
'akantusplantene': ('akantusplante',),
'akantusplanter': ('akantusplante',),
'akantusranke': ('akantusranke',),
'akantusranken': ('akantusranke',),
'akantusrankene': ('akantusranke',),
'akantusranker': ('akantusranke',),
'akasie': ('akasie',),
'akasien': ('akasie',),
'akasiene': ('akasie',),
'akasier': ('akasie',),
'akebakke': ('akebakke',),
'akebakken': ('akebakke',),
'akebakkene': ('akebakke',),
'akebakker': ('akebakke',),
'akebrett': ('akebrett',),
'akebretta': ('akebrett',),
'akebrettene': ('akebrett',),
'akebretter': ('akebrett',),
'akebrettet': ('akebrett',),
'akeføra': ('akeføre',),
'akeføre': ('akeføre',),
'akeførene': ('akeføre',),
'akefører': ('akeføre',),
'akeføret': ('akeføre',),
'akekonkurranse': ('akekonkurranse',),
'akekonkurransen': ('akekonkurranse',),
'akekonkurransene': ('akekonkurranse',),
'akekonkurranser': ('akekonkurranse',),
'akeleia': ('akeleie',),
'akeleie': ('akeleie',),
'akeleien': ('akeleie',),
'akeleiene': ('akeleie',),
'akeleier': ('akeleie',),
'aketur': ('aketur',),
'aketuren': ('aketur',),
'aketurene': ('aketur',),
'aketurer': ('aketur',),
'akevitt': ('akevitt',),
'akevitten': ('akevitt',),
'akevittene': ('akevitt',),
'akevitter': ('akevitt',),
'akevitter': ('akevitter',),
'akevittere': ('akevitter',),
'akevitteren': ('akevitter',),
'akevitterer': ('akevitter',),
'akevitterne': ('akevitter',),
'akilleshæl': ('akilleshæl',),
'akilleshælen': ('akilleshæl',),
'akilleshælene': ('akilleshæl',),
'akilleshæler': ('akilleshæl',),
'akillessena': ('akillessene',),
'akillessene': ('akillessene',),
'akillessenen': ('akillessene',),
'akillessenene': ('akillessene',),
'akillessener': ('akillessene',),
'akk': ('akk',),
'akka': ('akk',),
'akkene': ('akk',),
'akket': ('akk',),
'akkar': ('akkar',),
'akkaren': ('akkar',),
'akkarene': ('akkar',),
'akkarer': ('akkar',),
'akkedas': ('akkedas',),
'akkedasen': ('akkedas',),
'akkedasene': ('akkedas',),
'akkedaser': ('akkedas',),
'akkedering': ('akkedering',),
'akkederinga': ('akkedering',),
'akkederingen': ('akkedering',),
'akkederingene': ('akkedering',),
'akkederinger': ('akkedering',),
'akklamasjon': ('akklamasjon',),
'akklamasjonen': ('akklamasjon',),
'akklamasjonene': ('akklamasjon',),
'akklamasjoner': ('akklamasjon',),
'akkommodasjon': ('akkommodasjon',),
'akkommodasjonen': ('akkommodasjon',),
'akkommodasjonene': ('akkommodasjon',),
'akkommodasjoner': ('akkommodasjon',),
'akkompagnatør': ('akkompagnatør',),
'akkompagnatøren': ('akkompagnatør',),
'akkompagnatørene': ('akkompagnatør',),
'akkompagnatører': ('akkompagnatør',),
'akkompagnement': ('akkompagnement',),
'akkompagnementa': ('akkompagnement',),
'akkompagnementene': ('akkompagnement',),
'akkompagnementer': ('akkompagnement',),
'akkompagnementet': ('akkompagnement',),
'akkord': ('akkord',),
'akkorden': ('akkord',),
'akkordene': ('akkord',),
'akkorder': ('akkord',),
'akkordant': ('akkordant',),
'akkordanten': ('akkordant',),
'akkordantene': ('akkordant',),
'akkordanter': ('akkordant',),
'akkordarbeid': ('akkordarbeid',),
'akkordarbeida': ('akkordarbeid',),
'akkordarbeidene': ('akkordarbeid',),
'akkordarbeider': ('akkordarbeid',),
'akkordarbeidet': ('akkordarbeid',),
'akkordbetaling': ('akkordbetaling',),
'akkordbetalinga': ('akkordbetaling',),
'akkordbetalingen': ('akkordbetaling',),
'akkordbetalingene': ('akkordbetaling',),
'akkordbetalinger': ('akkordbetaling',),
'akkordbo': ('akkordbo',),
'akkordboa': ('akkordbo',),
'akkordboene': ('akkordbo',),
'akkordboet': ('akkordbo',),
'akkordbu': ('akkordbu',),
'akkordbua': ('akkordbu',),
'akkordbuene': ('akkordbu',),
'akkordbuet': ('akkordbu',),
'akkordforhandling': ('akkordforhandling',),
'akkordforhandlinga': ('akkordforhandling',),
'akkordforhandlingen': ('akkordforhandling',),
'akkordforhandlingene': ('akkordforhandling',),
'akkordforhandlinger': ('akkordforhandling',),
'akkordlønn': ('akkordlønn',),
'akkordlønna': ('akkordlønn',),
'akkordlønnen': ('akkordlønn',),
'akkordlønnene': ('akkordlønn',),
'akkordlønner': ('akkordlønn',),
'akkordstyra': ('akkordstyre',),
'akkordstyre': ('akkordstyre',),
'akkordstyrene': ('akkordstyre',),
'akkordstyrer': ('akkordstyre',),
'akkordstyret': ('akkordstyre',),
'akkordstyrer': ('akkordstyrer',),
'akkordstyrere': ('akkordstyrer',),
'akkordstyreren': ('akkordstyrer',),
'akkordstyrerer': ('akkordstyrer',),
'akkordstyrerne': ('akkordstyrer',),
'akkordtariff': ('akkordtariff',),
'akkordtariffen': ('akkordtariff',),
'akkordtariffene': ('akkordtariff',),
'akkordtariffer': ('akkordtariff',),
'akkrediteringsbrev': ('akkrediteringsbrev',),
'akkrediteringsbreva': ('akkrediteringsbrev',),
'akkrediteringsbrevene': ('akkrediteringsbrev',),
'akkrediteringsbrever': ('akkrediteringsbrev',),
'akkrediteringsbrevet': ('akkrediteringsbrev',),
'akkreditiv': ('akkreditiv',),
'akkreditiva': ('akkreditiv',),
'akkreditivene': ('akkreditiv',),
'akkreditiver': ('akkreditiv',),
'akkreditivet': ('akkreditiv',),
'akkumulasjon': ('akkumulasjon',),
'akkumulasjonen': ('akkumulasjon',),
'akkumulasjonene': ('akkumulasjon',),
'akkumulasjoner': ('akkumulasjon',),
'akkumulator': ('akkumulator',),
'akkumulatoren': ('akkumulator',),
'akkumulatorene': ('akkumulator',),
'akkumulatorer': ('akkumulator',),
'akkumulatorbatteri': ('akkumulatorbatteri',),
'akkumulatorbatteria': ('akkumulatorbatteri',),
'akkumulatorbatteriene': ('akkumulatorbatteri',),
'akkumulatorbatterier': ('akkumulatorbatteri',),
'akkumulatorbatteriet': ('akkumulatorbatteri',),
'akkumulatorcella': ('akkumulatorcelle',),
'akkumulatorcelle': ('akkumulatorcelle',),
'akkumulatorcellen': ('akkumulatorcelle',),
'akkumulatorcellene': ('akkumulatorcelle',),
'akkumulatorceller': ('akkumulatorcelle',),
'akkuratesse': ('akkuratesse',),
'akkuratessen': ('akkuratesse',),
'akkuratessene': ('akkuratesse',),
'akkuratesser': ('akkuratesse',),
'akkusativ': ('akkusativ',),
'akkusativen': ('akkusativ',),
'akkusativene': ('akkusativ',),
'akkusativer': ('akkusativ',),
'akkvisisjon': ('akkvisisjon',),
'akkvisisjonen': ('akkvisisjon',),
'akkvisisjonene': ('akkvisisjon',),
'akkvisisjoner': ('akkvisisjon',),
'akkvisitør': ('akkvisitør',),
'akkvisitøren': ('akkvisitør',),
'akkvisitørene': ('akkvisitør',),
'akkvisitører': ('akkvisitør',),
'akne': ('akne',),
'aknen': ('akne',),
'aknene': ('akne',),
'akner': ('akne',),
'akrobat': ('akrobat',),
'akrobaten': ('akrobat',),
'akrobatene': ('akrobat',),
'akrobater': ('akrobat',),
'akrobatikk': ('akrobatikk',),
'akrobatikken': ('akrobatikk',),
'akrobatikkene': ('akrobatikk',),
'akrobatikker': ('akrobatikk',),
'akrobatkunst': ('akrobatkunst',),
'akrobatkunsten': ('akrobatkunst',),
'akrobatkunstene': ('akrobatkunst',),
'akrobatkunster': ('akrobatkunst',),
'akrofobi': ('akrofobi',),
'akrofobien': ('akrofobi',),
'akrofobiene': ('akrofobi',),
'akrofobier': ('akrofobi',),
'akromegali': ('akromegali',),
'akromegalien': ('akromegali',),
'akromegaliene': ('akromegali',),
'akromegalier': ('akromegali',),
'akronym': ('akronym',),
'akronyma': ('akronym',),
'akronymene': ('akronym',),
'akronymer': ('akronym',),
'akronymet': ('akronym',),
'akrostika': ('akrostikon',),
'akrostikaene': ('akrostikon',),
'akrostikon': ('akrostikon',),
'akrostikonet': ('akrostikon',),
'akryl': ('akryl',),
'akryla': ('akryl',),
'akrylen': ('akryl',),
'akrylene': ('akryl',),
'akryler': ('akryl',),
'akrylet': ('akryl',),
'akrylfiber': ('akrylfiber',),
'akrylfibere': ('akrylfiber',),
'akrylfiberen': ('akrylfiber',),
'akrylfiberer': ('akrylfiber',),
'akrylfiberne': ('akrylfiber',),
'akrylfibre': ('akrylfiber',),
'akrylfibrene': ('akrylfiber',),
'akrylfibrer': ('akrylfiber',),
'akrylsyra': ('akrylsyre',),
'akrylsyre': ('akrylsyre',),
'akrylsyren': ('akrylsyre',),
'akrylsyrene': ('akrylsyre',),
'akrylsyrer': ('akrylsyre',),
'aks': ('aks',),
'aksa': ('aks',),
'aksene': ('aks',),
'akset': ('aks',),
'aksdannelse': ('aksdannelse',),
'aksdannelsen': ('aksdannelse',),
'aksdannelsene': ('aksdannelse',),
'aksdannelser': ('aksdannelse',),
'aksdanning': ('aksdanning',),
'aksdanninga': ('aksdanning',),
'aksdanningen': ('aksdanning',),
'aksdanningene': ('aksdanning',),
'aksdanninger': ('aksdanning',),
'akse': ('akse',),
'aksen': ('akse',),
'aksene': ('akse',),
'akser': ('akse',),
'aksel': ('aksel',),
'akselen': ('aksel',),
'akslene': ('aksel',),
'aksler': ('aksel',),
'aksel': ('aksel',),
'akselen': ('aksel',),
'aksla': ('aksel',),
'akslene': ('aksel',),
'aksler': ('aksel',),
'akselbein': ('akselbein',),
'akselbeina': ('akselbein',),
'akselbeinene': ('akselbein',),
'akselbeinet': ('akselbein',),
'akselben': ('akselben',),
'akselbena': ('akselben',),
'akselbenene': ('akselben',),
'akselbenet': ('akselben',),
'akselblad': ('akselblad',),
'akselblada': ('akselblad',),
'akselbladene': ('akselblad',),
'akselblader': ('akselblad',),
'akselbladet': ('akselblad',),
'akselerasjon': ('akselerasjon',),
'akselerasjonen': ('akselerasjon',),
'akselerasjonene': ('akselerasjon',),
'akselerasjoner': ('akselerasjon',),
'akselerasjonsevna': ('akselerasjonsevne',),
'akselerasjonsevne': ('akselerasjonsevne',),
'akselerasjonsevnen': ('akselerasjonsevne',),
'akselerasjonsevnene': ('akselerasjonsevne',),
'akselerasjonsevner': ('akselerasjonsevne',),
'akselerasjonsfelt': ('akselerasjonsfelt',),
'akselerasjonsfelta': ('akselerasjonsfelt',),
'akselerasjonsfeltene': ('akselerasjonsfelt',),
'akselerasjonsfelter': ('akselerasjonsfelt',),
'akselerasjonsfeltet': ('akselerasjonsfelt',),
'akselerator': ('akselerator',),
'akseleratoren': ('akselerator',),
'akseleratorene': ('akselerator',),
'akseleratorer': ('akselerator',),
'akselknopp': ('akselknopp',),
'akselknoppen': ('akselknopp',),
'akselknoppene': ('akselknopp',),
'akselknopper': ('akselknopp',),
'akselknupp': ('akselknupp',),
'akselknuppen': ('akselknupp',),
'akselknuppene': ('akselknupp',),
'akselknupper': ('akselknupp',),
'akselkobling': ('akselkobling',),
'akselkoblinga': ('akselkobling',),
'akselkoblingen': ('akselkobling',),
'akselkoblingene': ('akselkobling',),
'akselkoblinger': ('akselkobling',),
'akselkopling': ('akselkopling',),
'akselkoplinga': ('akselkopling',),
'akselkoplingen': ('akselkopling',),
'akselkoplingene': ('akselkopling',),
'akselkoplinger': ('akselkopling',),
'akselledning': ('akselledning',),
'akselledninga': ('akselledning',),
'akselledningen': ('akselledning',),
'akselledningene': ('akselledning',),
'akselledninger': ('akselledning',),
'akseltrykk': ('akseltrykk',),
'akseltrykka': ('akseltrykk',),
'akseltrykkene': ('akseltrykk',),
'akseltrykket': ('akseltrykk',),
'aksemakt': ('aksemakt',),
'aksemakta': ('aksemakt',),
'aksemakten': ('aksemakt',),
'aksemaktene': ('aksemakt',),
'aksemakter': ('aksemakt',),
'aksent': ('aksent',),
'aksenten': ('aksent',),
'aksentene': ('aksent',),
'aksenter': ('aksent',),
'aksenttegn': ('aksenttegn',),
'aksenttegna': ('aksenttegn',),
'aksenttegnene': ('aksenttegn',),
'aksenttegnet': ('aksenttegn',),
'aksentuasjon': ('aksentuasjon',),
'aksentuasjonen': ('aksentuasjon',),
'aksentuasjonene': ('aksentuasjon',),
'aksentuasjoner': ('aksentuasjon',),
'aksentuering': ('aksentuering',),
'aksentueringa': ('aksentuering',),
'aksentueringen': ('aksentuering',),
'aksentueringene': ('aksentuering',),
'aksentueringer': ('aksentuering',),
'aksept': ('aksept',),
'aksepten': ('aksept',),
'akseptene': ('aksept',),
'aksepter': ('aksept',),
'akseptant': ('akseptant',),
'akseptanten': ('akseptant',),
'akseptantene': ('akseptant',),
'akseptanter': ('akseptant',),
'aksesjon': ('aksesjon',),
'aksesjonen': ('aksesjon',),
'aksesjonene': ('aksesjon',),
'aksesjoner': ('aksesjon',),
'aksesjonskatalog': ('aksesjonskatalog',),
'aksesjonskatalogen': ('aksesjonskatalog',),
'aksesjonskatalogene': ('aksesjonskatalog',),
'aksesjonskataloger': ('aksesjonskatalog',),
'aksess': ('aksess',),
'aksessen': ('aksess',),
'aksessene': ('aksess',),
'aksesser': ('aksess',),
'aksessoria': ('aksessorium',),
'aksessoriene': ('aksessorium',),
'aksessorier': ('aksessorium',),
'aksessoriet': ('aksessorium',),
'aksessorium': ('aksessorium',),
'aksesstid': ('aksesstid',),
'aksesstida': ('aksesstid',),
'aksesstiden': ('aksesstid',),
'aksesstidene': ('aksesstid',),
'aksesstider': ('aksesstid',),
'aksialfjær': ('aksialfjær',),
'aksialfjæra': ('aksialfjær',),
'aksialfjæren': ('aksialfjær',),
'aksialfjærene': ('aksialfjær',),
'aksialfjærer': ('aksialfjær',),
'aksialfjør': ('aksialfjør',),
'aksialfjøra': ('aksialfjør',),
'aksialfjøren': ('aksialfjør',),
'aksialfjørene': ('aksialfjør',),
'aksialfjører': ('aksialfjør',),
'aksialkraft': ('aksialkraft',),
'aksialkrafta': ('aksialkraft',),
'aksialkraften': ('aksialkraft',),
'aksialkreftene': ('aksialkraft',),
'aksialkrefter': ('aksialkraft',),
'aksiallager': ('aksiallager',),
'aksiallageret': ('aksiallager',),
'aksiallagra': ('aksiallager',),
'aksiallagre': ('aksiallager',),
'aksiallagrene': ('aksiallager',),
'aksidens': ('aksidens',),
'aksidensen': ('aksidens',),
'aksidensene': ('aksidens',),
'aksidenser': ('aksidens',),
'aksidensarbeid': ('aksidensarbeid',),
'aksidensarbeida': ('aksidensarbeid',),
'aksidensarbeidene': ('aksidensarbeid',),
'aksidensarbeider': ('aksidensarbeid',),
'aksidensarbeidet': ('aksidensarbeid',),
'aksidenstrykkeri': ('aksidenstrykkeri',),
'aksidenstrykkeria': ('aksidenstrykkeri',),
'aksidenstrykkeriene': ('aksidenstrykkeri',),
'aksidenstrykkerier': ('aksidenstrykkeri',),
'aksidenstrykkeriet': ('aksidenstrykkeri',),
'aksiom': ('aksiom',),
'aksioma': ('aksiom',),
'aksiomene': ('aksiom',),
'aksiomer': ('aksiom',),
'aksiomet': ('aksiom',),
'aksje': ('aksje',),
'aksjen': ('aksje',),
'aksjene': ('aksje',),
'aksjer': ('aksje',),
'aksjeandel': ('aksjeandel',),
'aksjeandelen': ('aksjeandel',),
'aksjeandelene': ('aksjeandel',),
'aksjeandeler': ('aksjeandel',),
'aksjebrev': ('aksjebrev',),
'aksjebreva': ('aksjebrev',),
'aksjebrevene': ('aksjebrev',),
'aksjebrever': ('aksjebrev',),
'aksjebrevet': ('aksjebrev',),
'aksjeeier': ('aksjeeier',),
'aksjeeiere': ('aksjeeier',),
'aksjeeieren': ('aksjeeier',),
'aksjeeierer': ('aksjeeier',),
'aksjeeierne': ('aksjeeier',),
'aksjefond': ('aksjefond',),
'aksjefonda': ('aksjefond',),
'aksjefondene': ('aksjefond',),
'aksjefondet': ('aksjefond',),
'aksjekapital': ('aksjekapital',),
'aksjekapitalen': ('aksjekapital',),
'aksjekapitalene': ('aksjekapital',),
'aksjekapitaler': ('aksjekapital',),
'aksjeleilighet': ('aksjeleilighet',),
'aksjeleiligheta': ('aksjeleilighet',),
'aksjeleiligheten': ('aksjeleilighet',),
'aksjeleilighetene': ('aksjeleilighet',),
'aksjeleiligheter': ('aksjeleilighet',),
'aksjemajoritet': ('aksjemajoritet',),
'aksjemajoriteten': ('aksjemajoritet',),
'aksjemajoritetene': ('aksjemajoritet',),
'aksjemajoriteter': ('aksjemajoritet',),
'aksjemarked': ('aksjemarked',),
'aksjemarkeda': ('aksjemarked',),
'aksjemarkedene': ('aksjemarked',),
'aksjemarkeder': ('aksjemarked',),
'aksjemarkedet': ('aksjemarked',),
'aksjemarknad': ('aksjemarknad',),
'aksjemarknaden': ('aksjemarknad',),
'aksjemarknadene': ('aksjemarknad',),
'aksjemarknader': ('aksjemarknad',),
'aksjemegler': ('aksjemegler',),
'aksjemeglere': ('aksjemegler',),
'aksjemegleren': ('aksjemegler',),
'aksjemeglerer': ('aksjemegler',),
'aksjemeglerne': ('aksjemegler',),
'aksjemekler': ('aksjemekler',),
'aksjemeklere': ('aksjemekler',),
'aksjemekleren': ('aksjemekler',),
'aksjemeklerer': ('aksjemekler',),
'aksjemeklerne': ('aksjemekler',),
'aksjenotering': ('aksjenotering',),
'aksjenoteringa': ('aksjenotering',),
'aksjenoteringen': ('aksjenotering',),
'aksjenoteringene': ('aksjenotering',),
'aksjenoteringer': ('aksjenotering',),
'aksjeselskap': ('aksjeselskap',),
'aksjeselskapa': ('aksjeselskap',),
'aksjeselskapene': ('aksjeselskap',),
'aksjeselskaper': ('aksjeselskap',),
'aksjeselskapet': ('aksjeselskap',),
'aksjesum': ('aksjesum',),
'aksjesummen': ('aksjesum',),
'aksjesummene': ('aksjesum',),
'aksjesummer': ('aksjesum',),
'aksjeutbytta': ('aksjeutbytte',),
'aksjeutbytte': ('aksjeutbytte',),
'aksjeutbyttene': ('aksjeutbytte',),
'aksjeutbytter': ('aksjeutbytte',),
'aksjeutbyttet': ('aksjeutbytte',),
'aksjon': ('aksjon',),
'aksjonen': ('aksjon',),
'aksjonene': ('aksjon',),
'aksjoner': ('aksjon',),
'aksjonist': ('aksjonist',),
'aksjonisten': ('aksjonist',),
'aksjonistene': ('aksjonist',),
'aksjonister': ('aksjonist',),
'aksjonsart': ('aksjonsart',),
'aksjonsarta': ('aksjonsart',),
'aksjonsarten': ('aksjonsart',),
'aksjonsartene': ('aksjonsart',),
'aksjonsarter': ('aksjonsart',),
'aksjonsradien': ('aksjonsradius',),
'aksjonsradiene': ('aksjonsradius',),
'aksjonsradier': ('aksjonsradius',),
'aksjonsradius': ('aksjonsradius',),
'aksjonsradiusen': ('aksjonsradius',),
'aksjonstid': ('aksjonstid',),
'aksjonstida': ('aksjonstid',),
'aksjonstiden': ('aksjonstid',),
'aksjonstidene': ('aksjonstid',),
'aksjonstider': ('aksjonstid',),
'aksjonsutvalg': ('aksjonsutvalg',),
'aksjonsutvalga': ('aksjonsutvalg',),
'aksjonsutvalgene': ('aksjonsutvalg',),
'aksjonsutvalget': ('aksjonsutvalg',),
'aksjonær': ('aksjonær',),
'aksjonæren': ('aksjonær',),
'aksjonærene': ('aksjonær',),
'aksjonærer': ('aksjonær',),
'aksjonærmøta': ('aksjonærmøte',),
'aksjonærmøte': ('aksjonærmøte',),
'aksjonærmøtene': ('aksjonærmøte',),
'aksjonærmøter': ('aksjonærmøte',),
'aksjonærmøtet': ('aksjonærmøte',),
'aksling': ('aksling',),
'akslingen': ('aksling',),
'akslingene': ('aksling',),
'akslinger': ('aksling',),
'akt': ('akt',),
'akta': ('akt',),
'akten': ('akt',),
'aktene': ('akt',),
'akter': ('akt',),
'aktelse': ('aktelse',),
'aktelsen': ('aktelse',),
'aktelsene': ('aktelse',),
'aktelser': ('aktelse',),
'akterdekk': ('akterdekk',),
'akterdekka': ('akterdekk',),
'akterdekkene': ('akterdekk',),
'akterdekket': ('akterdekk',),
'akterende': ('akterende',),
'akterenden': ('akterende',),
'akterendene': ('akterende',),
'akterender': ('akterende',),
'akterkant': ('akterkant',),
'akterkanten': ('akterkant',),
'akterkantene': ('akterkant',),
'akterkanter': ('akterkant',),
'akterlanterna': ('akterlanterne',),
'akterlanterne': ('akterlanterne',),
'akterlanternen': ('akterlanterne',),
'akterlanternene': ('akterlanterne',),
'akterlanterner': ('akterlanterne',),
'akterrom': ('akterrom',),
'akterromma': ('akterrom',),
'akterrommene': ('akterrom',),
'akterrommet': ('akterrom',),
'akterskott': ('akterskott',),
'akterskotten': ('akterskott',),
'akterskottene': ('akterskott',),
'akterskotter': ('akterskott',),
'akterskott': ('akterskott',),
'akterskotta': ('akterskott',),
'akterskottene': ('akterskott',),
'akterskottet': ('akterskott',),
'akterskut': ('akterskut',),
'akterskuten': ('akterskut',),
'akterskutene': ('akterskut',),
'akterskuter': ('akterskut',),
'akterspeil': ('akterspeil',),
'akterspeila': ('akterspeil',),
'akterspeilene': ('akterspeil',),
'akterspeilet': ('akterspeil',),
'akterstamn': ('akterstamn',),
'akterstamnen': ('akterstamn',),
'akterstamnene': ('akterstamn',),
'akterstamner': ('akterstamn',),
'akterstavn': ('akterstavn',),
'akterstavnen': ('akterstavn',),
'akterstavnene': ('akterstavn',),
'akterstavner': ('akterstavn',),
'aktivasida': ('aktivaside',),
'aktivaside': ('aktivaside',),
'aktivasiden': ('aktivaside',),
'aktivasidene': ('aktivaside',),
'aktivasider': ('aktivaside',),
'aktivator': ('aktivator',),
'aktivatoren': ('aktivator',),
'aktivatorene': ('aktivator',),
'aktivatorer': ('aktivator',),
'aktivering': ('aktivering',),
'aktiveringa': ('aktivering',),
'aktiveringen': ('aktivering',),
'aktiveringene': ('aktivering',),
'aktiveringer': ('aktivering',),
'aktiveringsenergi': ('aktiveringsenergi',),
'aktiveringsenergien': ('aktiveringsenergi',),
'aktiveringsenergiene': ('aktiveringsenergi',),
'aktiveringsenergier': ('aktiveringsenergi',),
'aktivisme': ('aktivisme',),
'aktivismen': ('aktivisme',),
'aktivismene': ('aktivisme',),
'aktivismer': ('aktivisme',),
'aktivist': ('aktivist',),
'aktivisten': ('aktivist',),
'aktivistene': ('aktivist',),
'aktivister': ('aktivist',),
'aktivistgruppa': ('aktivistgruppe',),
'aktivistgruppe': ('aktivistgruppe',),
'aktivistgruppen': ('aktivistgruppe',),
'aktivistgruppene': ('aktivistgruppe',),
'aktivistgrupper': ('aktivistgruppe',),
'aktivitet': ('aktivitet',),
'aktiviteten': ('aktivitet',),
'aktivitetene': ('aktivitet',),
'aktiviteter': ('aktivitet',),
'aktivitetsleder': ('aktivitetsleder',),
'aktivitetsledere': ('aktivitetsleder',),
'aktivitetslederen': ('aktivitetsleder',),
'aktivitetslederer': ('aktivitetsleder',),
'aktivitetslederne': ('aktivitetsleder',),
'aktivitetsnivå': ('aktivitetsnivå',),
'aktivitetsnivåa': ('aktivitetsnivå',),
'aktivitetsnivåene': ('aktivitetsnivå',),
'aktivitetsnivåer': ('aktivitetsnivå',),
'aktivitetsnivået': ('aktivitetsnivå',),
'aktivitetsrom': ('aktivitetsrom',),
'aktivitetsromma': ('aktivitetsrom',),
'aktivitetsrommene': ('aktivitetsrom',),
'aktivitetsrommet': ('aktivitetsrom',),
'aktivitør': ('aktivitør',),
'aktivitøren': ('aktivitør',),
'aktivitørene': ('aktivitør',),
'aktivitører': ('aktivitør',),
'aktiva': ('aktivum',),
'aktivaene': ('aktivum',),
'aktiver': ('aktivum',),
'aktivet': ('aktivum',),
'aktivum': ('aktivum',),
'aktivuma': ('aktivum',),
'aktivumene': ('aktivum',),
'aktivumer': ('aktivum',),
'aktivumet': ('aktivum',),
'aktmaling': ('aktmaling',),
'aktmalinga': ('aktmaling',),
'aktmalingen': ('aktmaling',),
'aktmalingene': ('aktmaling',),
'aktmalinger': ('aktmaling',),
'aktmodell': ('aktmodell',),
'aktmodellen': ('aktmodell',),
'aktmodellene': ('aktmodell',),
'aktmodeller': ('aktmodell',),
'aktor': ('aktor',),
'aktoren': ('aktor',),
'aktorene': ('aktor',),
'aktorer': ('aktor',),
'aktorat': ('aktorat',),
'aktorata': ('aktorat',),
'aktoratene': ('aktorat',),
'aktorater': ('aktorat',),
'aktoratet': ('aktorat',),
'aktpågivenhet': ('aktpågivenhet',),
'aktpågivenheta': ('aktpågivenhet',),
'aktpågivenheten': ('aktpågivenhet',),
'aktpågivenhetene': ('aktpågivenhet',),
'aktpågivenheter': ('aktpågivenhet',),
'aktrisa': ('aktrise',),
'aktrise': ('aktrise',),
'aktrisen': ('aktrise',),
'aktrisene': ('aktrise',),
'aktriser': ('aktrise',),
'aktsomhet': ('aktsomhet',),
'aktsomheta': ('aktsomhet',),
'aktsomheten': ('aktsomhet',),
'aktsomhetene': ('aktsomhet',),
'aktsomheter': ('aktsomhet',),
'aktstykka': ('aktstykke',),
'aktstykke': ('aktstykke',),
'aktstykkene': ('aktstykke',),
'aktstykker': ('aktstykke',),
'aktstykket': ('aktstykke',),
'akttegning': ('akttegning',),
'akttegninga': ('akttegning',),
'akttegningen': ('akttegning',),
'akttegningene': ('akttegning',),
'akttegninger': ('akttegning',),
'aktualitet': ('aktualitet',),
'aktualiteten': ('aktualitet',),
'aktualitetene': ('aktualitet',),
'aktualiteter': ('aktualitet',),
'aktuar': ('aktuar',),
'aktuaren': ('aktuar',),
'aktuarene': ('aktuar',),
'aktuarer': ('aktuar',),
'aktuareksamen': ('aktuareksamen',),
'aktuareksamenen': ('aktuareksamen',),
'aktuareksamenene': ('aktuareksamen',),
'aktuareksamener': ('aktuareksamen',),
'aktuarembetseksamen': ('aktuarembetseksamen',),
'aktuarembetseksamenen': ('aktuarembetseksamen',),
'aktuarembetseksamenene': ('aktuarembetseksamen',),
'aktuarembetseksamener': ('aktuarembetseksamen',),
'aktør': ('aktør',),
'aktøren': ('aktør',),
'aktørene': ('aktør',),
'aktører': ('aktør',),
'akupunktur': ('akupunktur',),
'akupunkturen': ('akupunktur',),
'akupunkturene': ('akupunktur',),
'akupunkturer': ('akupunktur',),
'akupunktør': ('akupunktør',),
'akupunktøren': ('akupunktør',),
'akupunktørene': ('akupunktør',),
'akupunktører': ('akupunktør',),
'akustiker': ('akustiker',),
'akustikere': ('akustiker',),
'akustikeren': ('akustiker',),
'akustikerer': ('akustiker',),
'akustikerne': ('akustiker',),
'akustikk': ('akustikk',),
'akustikken': ('akustikk',),
'akustikkene': ('akustikk',),
'akustikker': ('akustikk',),
'akutt': ('akutt',),
'akutten': ('akutt',),
'akuttene': ('akutt',),
'akutter': ('akutt',),
'akutt-tegn': ('akutt-tegn',),
'akutt-tegna': ('akutt-tegn',),
'akutt-tegnene': ('akutt-tegn',),
'akutt-tegnet': ('akutt-tegn',),
'akuttavdeling': ('akuttavdeling',),
'akuttavdelinga': ('akuttavdeling',),
'akuttavdelingen': ('akuttavdeling',),
'akuttavdelingene': ('akuttavdeling',),
'akuttavdelinger': ('akuttavdeling',),
'akuttegn': ('akuttegn',),
'akuttegna': ('akuttegn',),
'akuttegnene': ('akuttegn',),
'akuttegnet': ('akuttegn',),
'akvakultur': ('akvakultur',),
'akvakulturen': ('akvakultur',),
'akvakulturene': ('akvakultur',),
'akvakulturer': ('akvakultur',),
'akvamarin': ('akvamarin',),
'akvamarinen': ('akvamarin',),
'akvamarinene': ('akvamarin',),
'akvamariner': ('akvamarin',),
'akvanaut': ('akvanaut',),
'akvanauten': ('akvanaut',),
'akvanautene': ('akvanaut',),
'akvanauter': ('akvanaut',),
'akvarell': ('akvarell',),
'akvarellen': ('akvarell',),
'akvarellene': ('akvarell',),
'akvareller': ('akvarell',),
'akvarellfarge': ('akvarellfarge',),
'akvarellfargen': ('akvarellfarge',),
'akvarellfargene': ('akvarellfarge',),
'akvarellfarger': ('akvarellfarge',),
'akvarellkunst': ('akvarellkunst',),
'akvarellkunsten': ('akvarellkunst',),
'akvarellkunstene': ('akvarellkunst',),
'akvarellkunster': ('akvarellkunst',),
'akvarellmaler': ('akvarellmaler',),
'akvarellmalere': ('akvarellmaler',),
'akvarellmaleren': ('akvarellmaler',),
'akvarellmalerer': ('akvarellmaler',),
'akvarellmalerne': ('akvarellmaler',),
'akvariebygning': ('akvariebygning',),
'akvariebygninga': ('akvariebygning',),
'akvariebygningen': ('akvariebygning',),
'akvariebygningene': ('akvariebygning',),
'akvariebygninger': ('akvariebygning',),
'akvariefisk': ('akvariefisk',),
'akvariefisken': ('akvariefisk',),
'akvariefiskene': ('akvariefisk',),
'akvariefisker': ('akvariefisk',),
'akvaria': ('akvarium',),
'akvariene': ('akvarium',),
'akvarier': ('akvarium',),
'akvariet': ('akvarium',),
'akvarium': ('akvarium',),
'akvedukt': ('akvedukt',),
'akvedukten': ('akvedukt',),
'akveduktene': ('akvedukt',),
'akvedukter': ('akvedukt',),
'al': ('al',),
'alen': ('al',),
'alene': ('al',),
'aler': ('al',),
'al': ('al',),
'ala': ('al',),
'alene': ('al',),
'alet': ('al',),
'alabast': ('alabast',),
'alabasten': ('alabast',),
'alabastene': ('alabast',),
'alabaster': ('alabast',),
'alabastkrukka': ('alabastkrukke',),
'alabastkrukke': ('alabastkrukke',),
'alabastkrukken': ('alabastkrukke',),
'alabastkrukkene': ('alabastkrukke',),
'alabastkrukker': ('alabastkrukke',),
'alali': ('alali',),
'alalien': ('alali',),
'alaliene': ('alali',),
'alalier': ('alali',),
'alant': ('alant',),
'alanten': ('alant',),
'alantene': ('alant',),
'alanter': ('alant',),
'alantrot': ('alantrot',),
'alantrota': ('alantrot',),
'alantroten': ('alantrot',),
'alantrøttene': ('alantrot',),
'alantrøtter': ('alantrot',),
'alarm': ('alarm',),
'alarmen': ('alarm',),
'alarmene': ('alarm',),
'alarmer': ('alarm',),
'alarmapparat': ('alarmapparat',),
'alarmapparata': ('alarmapparat',),
'alarmapparatene': ('alarmapparat',),
'alarmapparater': ('alarmapparat',),
'alarmapparatet': ('alarmapparat',),
'alarmberedskap': ('alarmberedskap',),
'alarmberedskapa': ('alarmberedskap',),
'alarmberedskapen': ('alarmberedskap',),
'alarmberedskapene': ('alarmberedskap',),
'alarmberedskaper': ('alarmberedskap',),
'alarmberedskapet': ('alarmberedskap',),
'alarmklokka': ('alarmklokke',),
'alarmklokke': ('alarmklokke',),
'alarmklokken': ('alarmklokke',),
'alarmklokkene': ('alarmklokke',),
'alarmklokker': ('alarmklokke',),
'alarmsignal': ('alarmsignal',),
'alarmsignala': ('alarmsignal',),
'alarmsignalene': ('alarmsignal',),
'alarmsignaler': ('alarmsignal',),
'alarmsignalet': ('alarmsignal',),
'alarmsystem': ('alarmsystem',),
'alarmsystema': ('alarmsystem',),
'alarmsystemene': ('alarmsystem',),
'alarmsystemer': ('alarmsystem',),
'alarmsystemet': ('alarmsystem',),
'alarmtilstand': ('alarmtilstand',),
'alarmtilstanden': ('alarmtilstand',),
'alarmtilstandene': ('alarmtilstand',),
'alarmtilstander': ('alarmtilstand',),
'alaskabjørn': ('alaskabjørn',),
'alaskabjørnen': ('alaskabjørn',),
'alaskabjørnene': ('alaskabjørn',),
'alaskabjørner': ('alaskabjørn',),
'alaskasnipa': ('alaskasnipe',),
'alaskasnipe': ('alaskasnipe',),
'alaskasnipen': ('alaskasnipe',),
'alaskasnipene': ('alaskasnipe',),
'alaskasniper': ('alaskasnipe',),
'alasker': ('alasker',),
'alaskere': ('alasker',),
'alaskeren': ('alasker',),
'alaskerer': ('alasker',),
'alaskerne': ('alasker',),
'alba': ('alba',),
'albaen': ('alba',),
'albaene': ('alba',),
'albaer': ('alba',),
'albaner': ('albaner',),
'albanere': ('albaner',),
'albaneren': ('albaner',),
'albanerer': ('albaner',),
'albanerne': ('albaner',),
'albansk': ('albansk',),
'albansken': ('albansk',),
'albanskene': ('albansk',),
'albansker': ('albansk',),
'albatross': ('albatross',),
'albatrossen': ('albatross',),
'albatrossene': ('albatross',),
'albatrosser': ('albatross',),
'albinisme': ('albinisme',),
'albinismen': ('albinisme',),
'albinismene': ('albinisme',),
'albinismer': ('albinisme',),
'albino': ('albino',),
'albinoen': ('albino',),
'albinoene': ('albino',),
'albinoer': ('albino',),
'alboge': ('alboge',),
'albogen': ('alboge',),
'albogene': ('alboge',),
'alboger': ('alboge',),
'albogeledd': ('albogeledd',),
'albogeledda': ('albogeledd',),
'albogeleddene': ('albogeledd',),
'albogeleddet': ('albogeledd',),
'albogerom': ('albogerom',),
'albogeromma': ('albogerom',),
'albogerommene': ('albogerom',),
'albogerommet': ('albogerom',),
'albogesnegl': ('albogesnegl',),
'albogesneglen': ('albogesnegl',),
'albogesneglene': ('albogesnegl',),
'albogesnegler': ('albogesnegl',),
'albogesnile': ('albogesnile',),
'albogesnilen': ('albogesnile',),
'albogesnilene': ('albogesnile',),
'albogesniler': ('albogesnile',),
'albogestøt': ('albogestøt',),
'albogestøta': ('albogestøt',),
'albogestøtene': ('albogestøt',),
'albogestøtet': ('albogestøt',),
'albogestøtta': ('albogestøtte',),
'albogestøtte': ('albogestøtte',),
'albogestøtten': ('albogestøtte',),
'albogestøttene': ('albogestøtte',),
'albogestøtter': ('albogestøtte',),
'albogestøyt': ('albogestøyt',),
'albogestøyten': ('albogestøyt',),
'albogestøytene': ('albogestøyt',),
'albogestøyter': ('albogestøyt',),
'albue': ('albue',),
'albuen': ('albue',),
'albuene': ('albue',),
'albuer': ('albue',),
'albueledd': ('albueledd',),
'albueledda': ('albueledd',),
'albueleddene': ('albueledd',),
'albueleddet': ('albueledd',),
'albuerom': ('albuerom',),
'albueromma': ('albuerom',),
'albuerommene': ('albuerom',),
'albuerommet': ('albuerom',),
'albuesnegl': ('albuesnegl',),
'albuesneglen': ('albuesnegl',),
'albuesneglene': ('albuesnegl',),
'albuesnegler': ('albuesnegl',),
'albuesnile': ('albuesnile',),
'albuesnilen': ('albuesnile',),
'albuesnilene': ('albuesnile',),
'albuesniler': ('albuesnile',),
'albuestøt': ('albuestøt',),
'albuestøta': ('albuestøt',),
'albuestøtene': ('albuestøt',),
'albuestøtet': ('albuestøt',),
'albuestøtta': ('albuestøtte',),
'albuestøtte': ('albuestøtte',),
'albuestøtten': ('albuestøtte',),
'albuestøttene': ('albuestøtte',),
'albuestøtter': ('albuestøtte',),
'albuestøyt': ('albuestøyt',),
'albuestøyten': ('albuestøyt',),
'albuestøytene': ('albuestøyt',),
'albuestøyter': ('albuestøyt',),
'albuledd': ('albuledd',),
'albuledda': ('albuledd',),
'albuleddene': ('albuledd',),
'albuleddet': ('albuledd',),
'album': ('album',),
'albuma': ('album',),
'albumene': ('album',),
'albumer': ('album',),
'albumet': ('album',),
'albumin': ('albumin',),
'albumina': ('albumin',),
'albuminene': ('albumin',),
'albuminer': ('albumin',),
'albuminet': ('albumin',),
'alburom': ('alburom',),
'alburomma': ('alburom',),
'alburommene': ('alburom',),
'alburommet': ('alburom',),
'albusnegl': ('albusnegl',),
'albusneglen': ('albusnegl',),
'albusneglene': ('albusnegl',),
'albusnegler': ('albusnegl',),
'albusnile': ('albusnile',),
'albusnilen': ('albusnile',),
'albusnilene': ('albusnile',),
'albusniler': ('albusnile',),
'albustøt': ('albustøt',),
'albustøta': ('albustøt',),
'albustøtene': ('albustøt',),
'albustøtet': ('albustøt',),
'albustøtta': ('albustøtte',),
'albustøtte': ('albustøtte',),
'albustøtten': ('albustøtte',),
'albustøttene': ('albustøtte',),
'albustøtter': ('albustøtte',),
'albustøyt': ('albustøyt',),
'albustøyten': ('albustøyt',),
'albustøytene': ('albustøyt',),
'albustøyter': ('albustøyt',),
'aldehyd': ('aldehyd',),
'aldehyda': ('aldehyd',),
'aldehydene': ('aldehyd',),
'aldehyder': ('aldehyd',),
'aldehydet': ('aldehyd',),
'alder': ('alder',),
'aldere': ('alder',),
'alderen': ('alder',),
'alderer': ('alder',),
'alderne': ('alder',),
'aldre': ('alder',),
'aldrene': ('alder',),
'aldrer': ('alder',),
'alderdom': ('alderdom',),
'alderdommen': ('alderdom',),
'alderdommene': ('alderdom',),
'alderdommer': ('alderdom',),
'alderdomssjukdom': ('alderdomssjukdom',),
'alderdomssjukdommen': ('alderdomssjukdom',),
'alderdomssjukdommene': ('alderdomssjukdom',),
'alderdomssjukdommer': ('alderdomssjukdom',),
'alderdomssløvsinn': ('alderdomssløvsinn',),
'alderdomssløvsinna': ('alderdomssløvsinn',),
'alderdomssløvsinnene': ('alderdomssløvsinn',),
'alderdomssløvsinnet': ('alderdomssløvsinn',),
'alderdomssykdom': ('alderdomssykdom',),
'alderdomssykdommen': ('alderdomssykdom',),
'alderdomssykdommene': ('alderdomssykdom',),
'alderdomssykdommer': ('alderdomssykdom',),
'alderdomstegn': ('alderdomstegn',),
'alderdomstegna': ('alderdomstegn',),
'alderdomstegnene': ('alderdomstegn',),
'alderdomstegnet': ('alderdomstegn',),
'aldersattest': ('aldersattest',),
'aldersattesten': ('aldersattest',),
'aldersattestene': ('aldersattest',),
'aldersattester': ('aldersattest',),
'aldersbolig': ('aldersbolig',),
'aldersboligen': ('aldersbolig',),
'aldersboligene': ('aldersbolig',),
'aldersboliger': ('aldersbolig',),
'aldersforskjell': ('aldersforskjell',),
'aldersforskjellen': ('aldersforskjell',),
'aldersforskjellene': ('aldersforskjell',),
'aldersforskjeller': ('aldersforskjell',),
'aldersgrensa': ('aldersgrense',),
'aldersgrense': ('aldersgrense',),
'aldersgrensen': ('aldersgrense',),
'aldersgrensene': ('aldersgrense',),
'aldersgrenser': ('aldersgrense',),
'aldersgruppa': ('aldersgruppe',),
'aldersgruppe': ('aldersgruppe',),
'aldersgruppen': ('aldersgruppe',),
'aldersgruppene': ('aldersgruppe',),
'aldersgrupper': ('aldersgruppe',),
'aldersheim': ('aldersheim',),
'aldersheimen': ('aldersheim',),
'aldersheimene': ('aldersheim',),
'aldersheimer': ('aldersheim',),
'aldershjem': ('aldershjem',),
'aldershjemma': ('aldershjem',),
'aldershjemmene': ('aldershjem',),
'aldershjemmet': ('aldershjem',),
'alderspensjon': ('alderspensjon',),
'alderspensjonen': ('alderspensjon',),
'alderspensjonene': ('alderspensjon',),
'alderspensjoner': ('alderspensjon',),
'alderspensjonist': ('alderspensjonist',),
'alderspensjonisten': ('alderspensjonist',),
'alderspensjonistene': ('alderspensjonist',),
'alderspensjonister': ('alderspensjonist',),
'alderstillegg': ('alderstillegg',),
'alderstillegga': ('alderstillegg',),
'alderstilleggene': ('alderstillegg',),
'alderstillegget': ('alderstillegg',),
'alderstrinn': ('alderstrinn',),
'alderstrinna': ('alderstrinn',),
'alderstrinnene': ('alderstrinn',),
'alderstrinnet': ('alderstrinn',),
'alderstrygd': ('alderstrygd',),
'alderstrygda': ('alderstrygd',),
'alderstrygden': ('alderstrygd',),
'alderstrygdene': ('alderstrygd',),
'alderstrygder': ('alderstrygd',),
'aldring': ('aldring',),
'aldringa': ('aldring',),
'aldringen': ('aldring',),
'aldringene': ('aldring',),
'aldringer': ('aldring',),
'aleineforelder': ('aleineforelder',),
'aleineforelderen': ('aleineforelder',),
'aleineforeldra': ('aleineforelder',),
'aleineforeldre': ('aleineforelder',),
'aleineforeldrene': ('aleineforelder',),
'aleksandriner': ('aleksandriner',),
'aleksandrinere': ('aleksandriner',),
'aleksandrineren': ('aleksandriner',),
'aleksandrinerer': ('aleksandriner',),
'aleksandrinerne': ('aleksandriner',),
'aleksi': ('aleksi',),
'aleksien': ('aleksi',),
'aleksiene': ('aleksi',),
'aleksier': ('aleksi',),
'alemanner': ('alemanner',),
'alemannere': ('alemanner',),
'alemanneren': ('alemanner',),
'alemannerer': ('alemanner',),
'alemannerne': ('alemanner',),
'alemannisk': ('alemannisk',),
'alemannisken': ('alemannisk',),
'alemanniskene': ('alemannisk',),
'alemannisker': ('alemannisk',),
'alen': ('alen',),
'alenen': ('alen',),
'alna': ('alen',),
'alnene': ('alen',),
'alner': ('alen',),
'aleneforelder': ('aleneforelder',),
'aleneforelderen': ('aleneforelder',),
'aleneforeldra': ('aleneforelder',),
'aleneforeldre': ('aleneforelder',),
'aleneforeldrene': ('aleneforelder',),
'aleut': ('aleut',),
'aleuten': ('aleut',),
'aleutene': ('aleut',),
'aleuter': ('aleut',),
'aleutisk': ('aleutisk',),
'aleutisken': ('aleutisk',),
'aleutiskene': ('aleutisk',),
'aleutisker': ('aleutisk',),
'alfa': ('alfa',),
'alfaen': ('alfa',),
'alfaene': ('alfa',),
'alfaer': ('alfa',),
'alfa': ('alfa',),
'alfaen': ('alfa',),
'alfaene': ('alfa',),
'alfaer': ('alfa',),
'alfabet': ('alfabet',),
'alfabeta': ('alfabet',),
'alfabetene': ('alfabet',),
'alfabeter': ('alfabet',),
'alfabetet': ('alfabet',),
'alfabrikk': ('alfabrikk',),
'alfabrikken': ('alfabrikk',),
'alfabrikkene': ('alfabrikk',),
'alfabrikker': ('alfabrikk',),
'alfagras': ('alfagras',),
'alfagrasa': ('alfagras',),
'alfagrasene': ('alfagras',),
'alfagraset': ('alfagras',),
'alfagress': ('alfagress',),
'alfagressa': ('alfagress',),
'alfagressene': ('alfagress',),
'alfagresset': ('alfagress',),
'alfapartikkel': ('alfapartikkel',),
'alfapartikkelen': ('alfapartikkel',),
'alfapartiklene': ('alfapartikkel',),
'alfapartikler': ('alfapartikkel',),
'alfastråle': ('alfastråle',),
'alfastrålen': ('alfastråle',),
'alfastrålene': ('alfastråle',),
'alfastråler': ('alfastråle',),
'alfons': ('alfons',),
'alfonsen': ('alfons',),
'alfonsene': ('alfons',),
'alfonser': ('alfons',),
'alfonseri': ('alfonseri',),
'alfonseria': ('alfonseri',),
'alfonseriene': ('alfonseri',),
'alfonserier': ('alfonseri',),
'alfonseriet': ('alfonseri',),
'alfuru': ('alfuru',),
'alfurua': ('alfuru',),
'alfuruen': ('alfuru',),
'alfuruene': ('alfuru',),
'alfuruer': ('alfuru',),
'alge': ('alge',),
'algen': ('alge',),
'algene': ('alge',),
'alger': ('alge',),
'algebra': ('algebra',),
'algebraen': ('algebra',),
'algebraene': ('algebra',),
'algebraer': ('algebra',),
'algemiddel': ('algemiddel',),
'algemiddelet': ('algemiddel',),
'algemidla': ('algemiddel',),
'algemidlene': ('algemiddel',),
'algemidler': ('algemiddel',),
'algemidlet': ('algemiddel',),
'algerier': ('algerier',),
'algeriere': ('algerier',),
'algerieren': ('algerier',),
'algerierer': ('algerier',),
'algerierne': ('algerier',),
'algesopp': ('algesopp',),
'algesoppen': ('algesopp',),
'algesoppene': ('algesopp',),
'algesopper': ('algesopp',),
'algevekst': ('algevekst',),
'algeveksten': ('algevekst',),
'algevekstene': ('algevekst',),
'algevekster': ('algevekst',),
'algonkin': ('algonkin',),
'algonkiner': ('algonkiner',),
'algonkinere': ('algonkiner',),
'algonkineren': ('algonkiner',),
'algonkinerer': ('algonkiner',),
'algonkinerne': ('algonkiner',),
'algoritme': ('algoritme',),
'algoritmen': ('algoritme',),
'algoritmene': ('algoritme',),
'algoritmer': ('algoritme',),
'alibi': ('alibi',),
'alibia': ('alibi',),
'alibiene': ('alibi',),
'alibier': ('alibi',),
'alibiet': ('alibi',),
'alienasjon': ('alienasjon',),
'alienasjonen': ('alienasjon',),
'alienasjonene': ('alienasjon',),
'alienasjoner': ('alienasjon',),
'alindustri': ('alindustri',),
'alindustrien': ('alindustri',),
'alindustriene': ('alindustri',),
'alindustrier': ('alindustri',),
'alkali': ('alkali',),
'alkalia': ('alkali',),
'alkaliene': ('alkali',),
'alkalier': ('alkali',),
'alkaliet': ('alkali',),
'alkalimetall': ('alkalimetall',),
'alkalimetalla': ('alkalimetall',),
'alkalimetallene': ('alkalimetall',),
'alkalimetaller': ('alkalimetall',),
'alkalimetallet': ('alkalimetall',),
'alkalimeter': ('alkalimeter',),
'alkalimeteret': ('alkalimeter',),
'alkalimetra': ('alkalimeter',),
'alkalimetre': ('alkalimeter',),
'alkalimetrene': ('alkalimeter',),
'alkalimetret': ('alkalimeter',),
'alkaloid': ('alkaloid',),
'alkaloida': ('alkaloid',),
'alkaloidene': ('alkaloid',),
'alkaloider': ('alkaloid',),
'alkaloidet': ('alkaloid',),
'alkan': ('alkan',),
'alkana': ('alkan',),
'alkanene': ('alkan',),
'alkaner': ('alkan',),
'alkanet': ('alkan',),
'alka': ('alke',),
'alke': ('alke',),
'alken': ('alke',),
'alkene': ('alke',),
'alker': ('alke',),
'alkefamilie': ('alkefamilie',),
'alkefamilien': ('alkefamilie',),
'alkefamiliene': ('alkefamilie',),
'alkefamilier': ('alkefamilie',),
'alkefugl': ('alkefugl',),
'alkefuglen': ('alkefugl',),
'alkefuglene': ('alkefugl',),
'alkefugler': ('alkefugl',),
'alkekonge': ('alkekonge',),
'alkekongen': ('alkekonge',),
'alkekongene': ('alkekonge',),
'alkekonger': ('alkekonge',),
'alken': ('alken',),
'alkena': ('alken',),
'alkenene': ('alken',),
'alkener': ('alken',),
'alkenet': ('alken',),
'alkis': ('alkis',),
'alkisen': ('alkis',),
'alkisene': ('alkis',),
'alkiser': ('alkis',),
'alkohol': ('alkohol',),
'alkoholen': ('alkohol',),
'alkoholene': ('alkohol',),
'alkoholer': ('alkohol',),
'alkoholbruk': ('alkoholbruk',),
'alkoholbruka': ('alkoholbruk',),
'alkoholbruken': ('alkoholbruk',),
'alkoholbrukene': ('alkoholbruk',),
'alkoholbruker': ('alkoholbruk',),
'alkoholbruket': ('alkoholbruk',),
'alkoholdrikk': ('alkoholdrikk',),
'alkoholdrikken': ('alkoholdrikk',),
'alkoholdrikkene': ('alkoholdrikk',),
'alkoholdrikker': ('alkoholdrikk',),
'alkoholforbruk': ('alkoholforbruk',),
'alkoholforbruka': ('alkoholforbruk',),
'alkoholforbrukene': ('alkoholforbruk',),
'alkoholforbruket': ('alkoholforbruk',),
'alkoholforbud': ('alkoholforbud',),
'alkoholforbuda': ('alkoholforbud',),
'alkoholforbudene': ('alkoholforbud',),
'alkoholforbudet': ('alkoholforbud',),
'alkoholforgiftning': ('alkoholforgiftning',),
'alkoholforgiftninga': ('alkoholforgiftning',),
'alkoholforgiftningen': ('alkoholforgiftning',),
'alkoholforgiftningene': ('alkoholforgiftning',),
'alkoholforgiftninger': ('alkoholforgiftning',),
'alkoholgjæring': ('alkoholgjæring',),
'alkoholgjæringa': ('alkoholgjæring',),
'alkoholgjæringen': ('alkoholgjæring',),
'alkoholgjæringene': ('alkoholgjæring',),
'alkoholgjæringer': ('alkoholgjæring',),
'alkoholiker': ('alkoholiker',),
'alkoholikere': ('alkoholiker',),
'alkoholikeren': ('alkoholiker',),
'alkoholikerer': ('alkoholiker',),
'alkoholikerne': ('alkoholiker',),
'alkoholiker': ('alkoholiker',),
'alkoholinnhold': ('alkoholinnhold',),
'alkoholinnholda': ('alkoholinnhold',),
'alkoholinnholdene': ('alkoholinnhold',),
'alkoholinnholdet': ('alkoholinnhold',),
'alkoholisme': ('alkoholisme',),
'alkoholismen': ('alkoholisme',),
'alkoholismene': ('alkoholisme',),
'alkoholismer': ('alkoholisme',),
'alkoholist': ('alkoholist',),
'alkoholisten': ('alkoholist',),
'alkoholistene': ('alkoholist',),
'alkoholister': ('alkoholist',),
'alkoholistheim': ('alkoholistheim',),
'alkoholistheimen': ('alkoholistheim',),
'alkoholistheimene': ('alkoholistheim',),
'alkoholistheimer': ('alkoholistheim',),
'alkoholisthjem': ('alkoholisthjem',),
'alkoholisthjemma': ('alkoholisthjem',),
'alkoholisthjemmene': ('alkoholisthjem',),
'alkoholisthjemmet': ('alkoholisthjem',),
'alkoholistomsorg': ('alkoholistomsorg',),
'alkoholistomsorga': ('alkoholistomsorg',),
'alkoholistomsorgen': ('alkoholistomsorg',),
'alkoholistomsorgene': ('alkoholistomsorg',),
'alkoholistomsorger': ('alkoholistomsorg',),
'alkoholkonsentrasjon': ('alkoholkonsentrasjon',),
'alkoholkonsentrasjonen': ('alkoholkonsentrasjon',),
'alkoholkonsentrasjonene': ('alkoholkonsentrasjon',),
'alkoholkonsentrasjoner': ('alkoholkonsentrasjon',),
'alkohollovgiing': ('alkohollovgiing',),
'alkohollovgiinga': ('alkohollovgiing',),
'alkohollovgiingen': ('alkohollovgiing',),
'alkohollovgiingene': ('alkohollovgiing',),
'alkohollovgiinger': ('alkohollovgiing',),
'alkohollovgiving': ('alkohollovgiving',),
'alkohollovgivinga': ('alkohollovgiving',),
'alkohollovgivingen': ('alkohollovgiving',),
'alkohollovgivingene': ('alkohollovgiving',),
'alkohollovgivinger': ('alkohollovgiving',),
'alkohollovgivning': ('alkohollovgivning',),
'alkohollovgivninga': ('alkohollovgivning',),
'alkohollovgivningen': ('alkohollovgivning',),
'alkohollovgivningene': ('alkohollovgivning',),
'alkohollovgivninger': ('alkohollovgivning',),
'alkoholmisbruk': ('alkoholmisbruk',),
'alkoholmisbruka': ('alkoholmisbruk',),
'alkoholmisbruken': ('alkoholmisbruk',),
'alkoholmisbrukene': ('alkoholmisbruk',),
'alkoholmisbruker': ('alkoholmisbruk',),
'alkoholmisbruket': ('alkoholmisbruk',),
'alkoholnytelse': ('alkoholnytelse',),
'alkoholnytelsen': ('alkoholnytelse',),
'alkoholnytelsene': ('alkoholnytelse',),
'alkoholnytelser': ('alkoholnytelse',),
'alkoholnyting': ('alkoholnyting',),
'alkoholnytinga': ('alkoholnyting',),
'alkoholnytingen': ('alkoholnyting',),
'alkoholnytingene': ('alkoholnyting',),
'alkoholnytinger': ('alkoholnyting',),
'alkoholprosent': ('alkoholprosent',),
'alkoholprosenten': ('alkoholprosent',),
'alkoholprosentene': ('alkoholprosent',),
'alkoholprosenter': ('alkoholprosent',),
'alkoholprøva': ('alkoholprøve',),
'alkoholprøve': ('alkoholprøve',),
'alkoholprøven': ('alkoholprøve',),
'alkoholprøvene': ('alkoholprøve',),
'alkoholprøver': ('alkoholprøve',),
'alkoholskatt': ('alkoholskatt',),
'alkoholskatten': ('alkoholskatt',),
'alkoholskattene': ('alkoholskatt',),
'alkoholskatter': ('alkoholskatt',),
'alkoholtrang': ('alkoholtrang',),
'alkoholtrangen': ('alkoholtrang',),
'alkoholtrangene': ('alkoholtrang',),
'alkoholtranger': ('alkoholtrang',),
'alkotest': ('alkotest',),
'alkotesten': ('alkotest',),
'alkotestene': ('alkotest',),
'alkotester': ('alkotest',),
'alkove': ('alkove',),
'alkoven': ('alkove',),
'alkovene': ('alkove',),
'alkover': ('alkove',),
'alkyd': ('alkyd',),
'alkyda': ('alkyd',),
'alkydene': ('alkyd',),
'alkyder': ('alkyd',),
'alkydet': ('alkyd',),
'alkydharpiks': ('alkydharpiks',),
'alkydharpiksen': ('alkydharpiks',),
'alkydharpiksene': ('alkydharpiks',),
'alkydharpikser': ('alkydharpiks',),
'alkydlakk': ('alkydlakk',),
'alkydlakken': ('alkydlakk',),
'alkydlakkene': ('alkydlakk',),
'alkydlakker': ('alkydlakk',),
'alkydmaling': ('alkydmaling',),
'alkydmalinga': ('alkydmaling',),
'alkydmalingen': ('alkydmaling',),
'alkydmalingene': ('alkydmaling',),
'alkydmalinger': ('alkydmaling',),
'alkyl': ('alkyl',),
'alkyla': ('alkyl',),
'alkylene': ('alkyl',),
'alkyler': ('alkyl',),
'alkylet': ('alkyl',),
'alkymi': ('alkymi',),
'alkymien': ('alkymi',),
'alkymiene': ('alkymi',),
'alkymier': ('alkymi',),
'alkymist': ('alkymist',),
'alkymisten': ('alkymist',),
'alkymistene': ('alkymist',),
'alkymister': ('alkymist',),
'alkyn': ('alkyn',),
'alkyna': ('alkyn',),
'alkynene': ('alkyn',),
'alkyner': ('alkyn',),
'alkynet': ('alkyn',),
'all round-klassa': ('all round-klasse',),
'all round-klasse': ('all round-klasse',),
'all round-klassen': ('all round-klasse',),
'all round-klassene': ('all round-klasse',),
'all round-klasser': ('all round-klasse',),
'all round-løper': ('all round-løper',),
'all round-løpere': ('all round-løper',),
'all round-løperen': ('all round-løper',),
'all round-løperer': ('all round-løper',),
'all round-løperne': ('all round-løper',),
'all ting': ('all ting',),
'alleen': ('allé',),
'alleene': ('allé',),
'alleer': ('allé',),
'allé': ('allé',),
'alléen': ('allé',),
'alléene': ('allé',),
'alléer': ('allé',),
'alle sjelers dag': ('alle sjelers dag',),
'allegori': ('allegori',),
'allegorien': ('allegori',),
'allegoriene': ('allegori',),
'allegorier': ('allegori',),
'allegretto': ('allegretto',),
'allegrettoen': ('allegretto',),
'allegrettoene': ('allegretto',),
'allegrettoer': ('allegretto',),
'allegretto': ('allegretto',),
'allegrettoen': ('allegretto',),
'allegrettoene': ('allegretto',),
'allegrettoer': ('allegretto',),
'allegrettoet': ('allegretto',),
'allegrettosats': ('allegrettosats',),
'allegrettosatsen': ('allegrettosats',),
'allegrettosatsene': ('allegrettosats',),
'allegrettosatser': ('allegrettosats',),
'allegrettotempi': ('allegrettotempo',),
'allegrettotempiene': ('allegrettotempo',),
'allegrettotempo': ('allegrettotempo',),
'allegrettotempoa': ('allegrettotempo',),
'allegrettotempoene': ('allegrettotempo',),
'allegrettotempoer': ('allegrettotempo',),
'allegrettotempoet': ('allegrettotempo',),
'allegro': ('allegro',),
'allegroen': ('allegro',),
'allegroene': ('allegro',),
'allegroer': ('allegro',),
'allegro': ('allegro',),
'allegroen': ('allegro',),
'allegroene': ('allegro',),
'allegroer': ('allegro',),
'allegroet': ('allegro',),
'allegrosats': ('allegrosats',),
'allegrosatsen': ('allegrosats',),
'allegrosatsene': ('allegrosats',),
'allegrosatser': ('allegrosats',),
'allegrotempi': ('allegrotempo',),
'allegrotempiene': ('allegrotempo',),
'allegrotempo': ('allegrotempo',),
'allegrotempoa': ('allegrotempo',),
'allegrotempoene': ('allegrotempo',),
'allegrotempoer': ('allegrotempo',),
'allegrotempoet': ('allegrotempo',),
'allehelgensdag': ('allehelgensdag',),
'allehelgensdagen': ('allehelgensdag',),
'allehelgensdagene': ('allehelgensdag',),
'allehelgensdager': ('allehelgensdag',),
'allehånde': ('allehånde',),
'allehånden': ('allehånde',),
'allehåndene': ('allehånde',),
'allehånder': ('allehånde',),
'allel': ('allel',),
'allela': ('allel',),
'allelene': ('allel',),
'alleler': ('allel',),
'allelet': ('allel',),
'allemannseia': ('allemannseie',),
'allemannseie': ('allemannseie',),
'allemannseiene': ('allemannseie',),
'allemannseier': ('allemannseie',),
'allemannseiet': ('allemannseie',),
'allemannsvenn': ('allemannsvenn',),
'allemannsvennen': ('allemannsvenn',),
'allemannsvennene': ('allemannsvenn',),
'allemannsvenner': ('allemannsvenn',),
'allergi': ('allergi',),
'allergien': ('allergi',),
'allergiene': ('allergi',),
'allergier': ('allergi',),
'allergiker': ('allergiker',),
'allergikere': ('allergiker',),
'allergikeren': ('allergiker',),
'allergikerer': ('allergiker',),
'allergikerne': ('allergiker',),
'allfarveg': ('allfarveg',),
'allfarvegen': ('allfarveg',),
'allfarvegene': ('allfarveg',),
'allfarveger': ('allfarveg',),
'allfarvei': ('allfarvei',),
'allfarveien': ('allfarvei',),
'allfarveiene': ('allfarvei',),
'allfarveier': ('allfarvei',),
'allhær': ('allhær',),
'allhæren': ('allhær',),
'allhærene': ('allhær',),
'allhærer': ('allhær',),
'allianse': ('allianse',),
'alliansen': ('allianse',),
'alliansene': ('allianse',),
'allianser': ('allianse',),
'alligator': ('alligator',),
'alligatoren': ('alligator',),
'alligatorene': ('alligator',),
'alligatorer': ('alligator',),
'alligatorskinn': ('alligatorskinn',),
'alligatorskinna': ('alligatorskinn',),
'alligatorskinnene': ('alligatorskinn',),
'alligatorskinnet': ('alligatorskinn',),
'allitterasjon': ('allitterasjon',),
'allitterasjonen': ('allitterasjon',),
'allitterasjonene': ('allitterasjon',),
'allitterasjoner': ('allitterasjon',),
'allmakt': ('allmakt',),
'allmakta': ('allmakt',),
'allmakten': ('allmakt',),
'allmaktene': ('allmakt',),
'allmakter': ('allmakt',),
'allmaktsbud': ('allmaktsbud',),
'allmaktsbuda': ('allmaktsbud',),
'allmaktsbudene': ('allmaktsbud',),
'allmaktsbudet': ('allmaktsbud',),
'allmannamøta': ('allmannamøte',),
'allmannamøte': ('allmannamøte',),
'allmannamøtene': ('allmannamøte',),
'allmannamøter': ('allmannamøte',),
'allmannamøtet': ('allmannamøte',),
'allmenndannelse': ('allmenndannelse',),
'allmenndannelsen': ('allmenndannelse',),
'allmenndannelsene': ('allmenndannelse',),
'allmenndannelser': ('allmenndannelse',),
'allmenndanning': ('allmenndanning',),
'allmenndanninga': ('allmenndanning',),
'allmenndanningen': ('allmenndanning',),
'allmenndanningene': ('allmenndanning',),
'allmenndanninger': ('allmenndanning',),
'allmennfag': ('allmennfag',),
'allmennfaga': ('allmennfag',),
'allmennfagene': ('allmennfag',),
'allmennfaget': ('allmennfag',),
'allmennhet': ('allmennhet',),
'allmennheta': ('allmennhet',),
'allmennheten': ('allmennhet',),
'allmennhetene': ('allmennhet',),
'allmennheter': ('allmennhet',),
'allmenning': ('allmenning',),
'allmenningen': ('allmenning',),
'allmenningene': ('allmenning',),
'allmenninger': ('allmenning',),
'allmenningsrett': ('allmenningsrett',),
'allmenningsretten': ('allmenningsrett',),
'allmenningsrettene': ('allmenningsrett',),
'allmenningsretter': ('allmenningsrett',),
'allmenningsskog': ('allmenningsskog',),
'allmenningsskogen': ('allmenningsskog',),
'allmenningsskogene': ('allmenningsskog',),
'allmenningsskoger': ('allmenningsskog',),
'allmennmedisin': ('allmennmedisin',),
'allmennmedisinen': ('allmennmedisin',),
'allmennmedisinene': ('allmennmedisin',),
'allmennmedisiner': ('allmennmedisin',),
'allmennpraktiker': ('allmennpraktiker',),
'allmennpraktikere': ('allmennpraktiker',),
'allmennpraktikeren': ('allmennpraktiker',),
'allmennpraktikerer': ('allmennpraktiker',),
'allmennpraktikerne': ('allmennpraktiker',),
'allmenntilstand': ('allmenntilstand',),
'allmenntilstanden': ('allmenntilstand',),
'allmenntilstandene': ('allmenntilstand',),
'allmenntilstander': ('allmenntilstand',),
'allmennutdannelse': ('allmennutdannelse',),
'allmennutdannelsen': ('allmennutdannelse',),
'allmennutdannelsene': ('allmennutdannelse',),
'allmennutdannelser': ('allmennutdannelse',),
'allmennutdanning': ('allmennutdanning',),
'allmennutdanninga': ('allmennutdanning',),
'allmennutdanningen': ('allmennutdanning',),
'allmennutdanningene': ('allmennutdanning',),
'allmennutdanninger': ('allmennutdanning',),
'allmue': ('allmue',),
'allmuen': ('allmue',),
'allmuene': ('allmue',),
'allmuer': ('allmue',),
'allmuebibliotek': ('allmuebibliotek',),
'allmuebiblioteka': ('allmuebibliotek',),
'allmuebibliotekene': ('allmuebibliotek',),
'allmuebiblioteker': ('allmuebibliotek',),
'allmuebiblioteket': ('allmuebibliotek',),
'allmueboksamling': ('allmueboksamling',),
'allmueboksamlinga': ('allmueboksamling',),
'allmueboksamlingen': ('allmueboksamling',),
'allmueboksamlingene': ('allmueboksamling',),
'allmueboksamlinger': ('allmueboksamling',),
'allmuemål': ('allmuemål',),
'allmuemåla': ('allmuemål',),
'allmuemålene': ('allmuemål',),
'allmuemålet': ('allmuemål',),
'allmueskole': ('allmueskole',),
'allmueskolen': ('allmueskole',),
'allmueskolene': ('allmueskole',),
'allmueskoler': ('allmueskole',),
'allmuge': ('allmuge',),
'allmugen': ('allmuge',),
'allmugene': ('allmuge',),
'allmuger': ('allmuge',),
'allmugebibliotek': ('allmugebibliotek',),
'allmugebiblioteka': ('allmugebibliotek',),
'allmugebibliotekene': ('allmugebibliotek',),
'allmugebiblioteker': ('allmugebibliotek',),
'allmugebiblioteket': ('allmugebibliotek',),
'allmugeboksamling': ('allmugeboksamling',),
'allmugeboksamlinga': ('allmugeboksamling',),
'allmugeboksamlingen': ('allmugeboksamling',),
'allmugeboksamlingene': ('allmugeboksamling',),
'allmugeboksamlinger': ('allmugeboksamling',),
'allmugemål': ('allmugemål',),
'allmugemåla': ('allmugemål',),
'allmugemålene': ('allmugemål',),
'allmugemålet': ('allmugemål',),
'allmugeskole': ('allmugeskole',),
'allmugeskolen': ('allmugeskole',),
'allmugeskolene': ('allmugeskole',),
'allmugeskoler': ('allmugeskole',),
'allmøta': ('allmøte',),
'allmøte': ('allmøte',),
'allmøtene': ('allmøte',),
'allmøter': ('allmøte',),
'allmøtet': ('allmøte',),
'allnatur': ('allnatur',),
'allnaturen': ('allnatur',),
'allnaturene': ('allnatur',),
'allnaturer': ('allnatur',),
'allofon': ('allofon',),
'allofonen': ('allofon',),
'allofonene': ('allofon',),
'allofoner': ('allofon',),
'allomorf': ('allomorf',),
'allomorfen': ('allomorf',),
'allomorfene': ('allomorf',),
'allomorfer': ('allomorf',),
'allonge': ('allonge',),
'allongen': ('allonge',),
'allongene': ('allonge',),
'allonger': ('allonge',),
'allongeparykk': ('allongeparykk',),
'allongeparykken': ('allongeparykk',),
'allongeparykkene': ('allongeparykk',),
'allongeparykker': ('allongeparykk',),
'allrom': ('allrom',),
'allromma': ('allrom',),
'allrommene': ('allrom',),
'allrommet': ('allrom',),
'allrounder': ('allrounder',),
'allroundere': ('allrounder',),
'allrounderen': ('allrounder',),
'allrounderer': ('allrounder',),
'allrounderne': ('allrounder',),
'allsang': ('allsang',),
'allsangen': ('allsang',),
'allsangene': ('allsang',),
'allsanger': ('allsang',),
'allting': ('allting',),
'alltinga': ('allting',),
'alltingene': ('allting',),
'alltinget': ('allting',),
'allusjon': ('allusjon',),
'allusjonen': ('allusjon',),
'allusjonene': ('allusjon',),
'allusjoner': ('allusjon',),
'alluvialdannelse': ('alluvialdannelse',),
'alluvialdannelsen': ('alluvialdannelse',),
'alluvialdannelsene': ('alluvialdannelse',),
'alluvialdannelser': ('alluvialdannelse',),
'alluvialdanning': ('alluvialdanning',),
'alluvialdanninga': ('alluvialdanning',),
'alluvialdanningen': ('alluvialdanning',),
'alluvialdanningene': ('alluvialdanning',),
'alluvialdanninger': ('alluvialdanning',),
'alluvialtid': ('alluvialtid',),
'alluvialtida': ('alluvialtid',),
'alluvialtiden': ('alluvialtid',),
'alluvialtidene': ('alluvialtid',),
'alluvialtider': ('alluvialtid',),
'allvitenhet': ('allvitenhet',),
'allvitenheta': ('allvitenhet',),
'allvitenheten': ('allvitenhet',),
'allvitenhetene': ('allvitenhet',),
'allvitenheter': ('allvitenhet',),
'allviter': ('allviter',),
'allvitere': ('allviter',),
'allviteren': ('allviter',),
'allviterer': ('allviter',),
'allviterne': ('allviter',),
'allværsjager': ('allværsjager',),
'allværsjagere': ('allværsjager',),
'allværsjageren': ('allværsjager',),
'allværsjagerer': ('allværsjager',),
'allværsjagerne': ('allværsjager',),
'allylplast': ('allylplast',),
'allylplasten': ('allylplast',),
'allylplastene': ('allylplast',),
'allylplaster': ('allylplast',),
'alm': ('alm',),
'almen': ('alm',),
'almene': ('alm',),
'almer': ('alm',),
'alma mater': ('alma mater',),
'almanakk': ('almanakk',),
'almanakken': ('almanakk',),
'almanakkene': ('almanakk',),
'almanakker': ('almanakk',),
'alminnelighet': ('alminnelighet',),
'alminneligheta': ('alminnelighet',),
'alminneligheten': ('alminnelighet',),
'alminnelighetene': ('alminnelighet',),
'alminneligheter': ('alminnelighet',),
'almissa': ('almisse',),
'almisse': ('almisse',),
'almissen': ('almisse',),
'almissene': ('almisse',),
'almisser': ('almisse',),
'aloe': ('aloe',),
'aloen': ('aloe',),
'aloene': ('aloe',),
'aloer': ('aloe',),
'alpakka': ('alpakka',),
'alpakkaen': ('alpakka',),
'alpakkaene': ('alpakka',),
'alpakkaer': ('alpakka',),
'alpedal': ('alpedal',),
'alpedalen': ('alpedal',),
'alpedalene': ('alpedal',),
'alpedaler': ('alpedal',),
'alpefiol': ('alpefiol',),
'alpefiolen': ('alpefiol',),
'alpefiolene': ('alpefiol',),
'alpefioler': ('alpefiol',),
'alpehorn': ('alpehorn',),
'alpehorna': ('alpehorn',),
'alpehornene': ('alpehorn',),
'alpehornet': ('alpehorn',),
'alpejeger': ('alpejeger',),
'alpejegere': ('alpejeger',),
'alpejegeren': ('alpejeger',),
'alpejegerer': ('alpejeger',),
'alpejegerne': ('alpejeger',),
'alpelandskap': ('alpelandskap',),
'alpelandskapa': ('alpelandskap',),
'alpelandskapene': ('alpelandskap',),
'alpelandskaper': ('alpelandskap',),
'alpelandskapet': ('alpelandskap',),
'alpelua': ('alpelue',),
'alpelue': ('alpelue',),
'alpeluen': ('alpelue',),
'alpeluene': ('alpelue',),
'alpeluer': ('alpelue',),
'alpeluva': ('alpeluve',),
'alpeluve': ('alpeluve',),
'alpeluven': ('alpeluve',),
'alpeluvene': ('alpeluve',),
'alpeluver': ('alpeluve',),
'alperosa': ('alperose',),
'alperose': ('alperose',),
'alperosen': ('alperose',),
'alperosene': ('alperose',),
'alperoser': ('alperose',),
'alpeterreng': ('alpeterreng',),
'alpeterrenga': ('alpeterreng',),
'alpeterrengene': ('alpeterreng',),
'alpeterrenget': ('alpeterreng',),
'alpetropp': ('alpetropp',),
'alpetroppen': ('alpetropp',),
'alpetroppene': ('alpetropp',),
'alpetropper': ('alpetropp',),
'alpinanlegg': ('alpinanlegg',),
'alpinanlegga': ('alpinanlegg',),
'alpinanleggene': ('alpinanlegg',),
'alpinanlegget': ('alpinanlegg',),
'alpinbakke': ('alpinbakke',),
'alpinbakken': ('alpinbakke',),
'alpinbakkene': ('alpinbakke',),
'alpinbakker': ('alpinbakke',),
'alpinisme': ('alpinisme',),
'alpinismen': ('alpinisme',),
'alpinismene': ('alpinisme',),
'alpinismer': ('alpinisme',),
'alpinist': ('alpinist',),
'alpinisten': ('alpinist',),
'alpinistene': ('alpinist',),
'alpinister': ('alpinist',),
'alpinsenter': ('alpinsenter',),
'alpinsenteret': ('alpinsenter',),
'alpinsentra': ('alpinsenter',),
'alpinsentre': ('alpinsenter',),
'alpinsentrene': ('alpinsenter',),
'alpinsentret': ('alpinsenter',),
'alrune': ('alrune',),
'alrunen': ('alrune',),
'alrunene': ('alrune',),
'alruner': ('alrune',),
'alrunerot': ('alrunerot',),
'alrunerota': ('alrunerot',),
'alruneroten': ('alrunerot',),
'alrunerøttene': ('alrunerot',),
'alrunerøtter': ('alrunerot',),
'alsike': ('alsike',),
'alsiken': ('alsike',),
'alsikene': ('alsike',),
'alsiker': ('alsike',),
'alsikekløver': ('alsikekløver',),
'alsikekløvere': ('alsikekløver',),
'alsikekløveren': ('alsikekløver',),
'alsikekløverer': ('alsikekløver',),
'alsikekløverne': ('alsikekløver',),
'alt': ('alt',),
'alten': ('alt',),
'altene': ('alt',),
'alter': ('alt',),
'alt': ('alt',),
'alta': ('alt',),
'altene': ('alt',),
'altet': ('alt',),
'altan': ('altan',),
'altanen': ('altan',),
'altanene': ('altan',),
'altaner': ('altan',),
'altanbord': ('altanbord',),
'altanborda': ('altanbord',),
'altanbordene': ('altanbord',),
'altanborder': ('altanbord',),
'altanbordet': ('altanbord',),
'altandør': ('altandør',),
'altandøra': ('altandør',),
'altandøren': ('altandør',),
'altandørene': ('altandør',),
'altandører': ('altandør',),
'alter': ('alter',),
'altera': ('alter',),
'altere': ('alter',),
'alteret': ('alter',),
'altra': ('alter',),
'altre': ('alter',),
'altrene': ('alter',),
'altret': ('alter',),
'alter ego': ('alter ego',),
'alterasjon': ('alterasjon',),
'alterasjonen': ('alterasjon',),
'alterasjonene': ('alterasjon',),
'alterasjoner': ('alterasjon',),
'alterbilda': ('alterbilde',),
'alterbilde': ('alterbilde',),
'alterbildene': ('alterbilde',),
'alterbilder': ('alterbilde',),
'alterbildet': ('alterbilde',),
'alterbrød': ('alterbrød',),
'alterbrøda': ('alterbrød',),
'alterbrødene': ('alterbrød',),
'alterbrødet': ('alterbrød',),
'alterduk': ('alterduk',),
'alterduken': ('alterduk',),
'alterdukene': ('alterduk',),
'alterduker': ('alterduk',),
'altergang': ('altergang',),
'altergangen': ('altergang',),
'altergangene': ('altergang',),
'alterganger': ('altergang',),
'altergjest': ('altergjest',),
'altergjesten': ('altergjest',),
'altergjestene': ('altergjest',),
'altergjester': ('altergjest',),
'alterkalk': ('alterkalk',),
'alterkalken': ('alterkalk',),
'alterkalkene': ('alterkalk',),
'alterkalker': ('alterkalk',),
'alterkar': ('alterkar',),
'alterkara': ('alterkar',),
'alterkarene': ('alterkar',),
'alterkaret': ('alterkar',),
'alternasjon': ('alternasjon',),
'alternasjonen': ('alternasjon',),
'alternasjonene': ('alternasjon',),
'alternasjoner': ('alternasjon',),
'alternativ': ('alternativ',),
'alternativa': ('alternativ',),
'alternativene': ('alternativ',),
'alternativer': ('alternativ',),
'alternativet': ('alternativ',),
'alternering': ('alternering',),
'alterneringa': ('alternering',),
'alterneringen': ('alternering',),
'alterneringene': ('alternering',),
'alterneringer': ('alternering',),
'alterring': ('alterring',),
'alterringen': ('alterring',),
'alterringene': ('alterring',),
'alterringer': ('alterring',),
'altersølv': ('altersølv',),
'altersølva': ('altersølv',),
'altersølvene': ('altersølv',),
'altersølvet': ('altersølv',),
'altertavla': ('altertavle',),
'altertavle': ('altertavle',),
'altertavlen': ('altertavle',),
'altertavlene': ('altertavle',),
'altertavler': ('altertavle',),
'altertjeneste': ('altertjeneste',),
'altertjenesten': ('altertjeneste',),
'altertjenestene': ('altertjeneste',),
'altertjenester': ('altertjeneste',),
'altervin': ('altervin',),
'altervinen': ('altervin',),
'altervinene': ('altervin',),
'alterviner': ('altervin',),
'alteter': ('alteter',),
'altetere': ('alteter',),
'alteteren': ('alteter',),
'alteterer': ('alteter',),
'alteterne': ('alteter',),
'althorn': ('althorn',),
'althorna': ('althorn',),
'althornene': ('althorn',),
'althornet': ('althorn',),
'altklarinett': ('altklarinett',),
'altklarinetten': ('altklarinett',),
'altklarinettene': ('altklarinett',),
'altklarinetter': ('altklarinett',),
'altmuligmann': ('altmuligmann',),
'altmuligmannen': ('altmuligmann',),
'altmuligmenn': ('altmuligmann',),
'altmuligmennene': ('altmuligmann',),
'altnøkkel': ('altnøkkel',),
'altnøkkelen': ('altnøkkel',),
'altnøklene': ('altnøkkel',),
'altnøkler': ('altnøkkel',),
'altruisme': ('altruisme',),
'altruismen': ('altruisme',),
'altruismene': ('altruisme',),
'altruismer': ('altruisme',),
'altruist': ('altruist',),
'altruisten': ('altruist',),
'altruistene': ('altruist',),
'altruister': ('altruist',),
'altsaksofon': ('altsaksofon',),
'altsaksofonen': ('altsaksofon',),
'altsaksofonene': ('altsaksofon',),
'altsaksofoner': ('altsaksofon',),
'altsanger': ('altsanger',),
'altsangere': ('altsanger',),
'altsangeren': ('altsanger',),
'altsangerer': ('altsanger',),
'altsangerne': ('altsanger',),
'altsangerinna': ('altsangerinne',),
'altsangerinne': ('altsangerinne',),
'altsangerinnen': ('altsangerinne',),
'altsangerinnene': ('altsangerinne',),
'altsangerinner': ('altsangerinne',),
'altstemme': ('altstemme',),
'altstemmen': ('altstemme',),
'altstemmene': ('altstemme',),
'altstemmer': ('altstemme',),
'alumina': ('alumina',),
'aluminaen': ('alumina',),
'aluminaene': ('alumina',),
'aluminaer': ('alumina',),
'aluminium': ('aluminium',),
'aluminiuma': ('aluminium',),
'aluminiumen': ('aluminium',),
'aluminiumene': ('aluminium',),
'aluminiumer': ('aluminium',),
'aluminiumet': ('aluminium',),
'aluminiumfabrikk': ('aluminiumfabrikk',),
'aluminiumfabrikken': ('aluminiumfabrikk',),
'aluminiumfabrikkene': ('aluminiumfabrikk',),
'aluminiumfabrikker': ('aluminiumfabrikk',),
'aluminiumfolie': ('aluminiumfolie',),
'aluminiumfolien': ('aluminiumfolie',),
'aluminiumfoliene': ('aluminiumfolie',),
'aluminiumfolier': ('aluminiumfolie',),
'aluminiumklorid': ('aluminiumklorid',),
'aluminiumklorida': ('aluminiumklorid',),
'aluminiumkloridene': ('aluminiumklorid',),
'aluminiumklorider': ('aluminiumklorid',),
'aluminiumkloridet': ('aluminiumklorid',),
'aluminiumlegering': ('aluminiumlegering',),
'aluminiumlegeringa': ('aluminiumlegering',),
'aluminiumlegeringen': ('aluminiumlegering',),
'aluminiumlegeringene': ('aluminiumlegering',),
'aluminiumlegeringer': ('aluminiumlegering',),
'aluminiumoksid': ('aluminiumoksid',),
'aluminiumoksida': ('aluminiumoksid',),
'aluminiumoksidene': ('aluminiumoksid',),
'aluminiumoksider': ('aluminiumoksid',),
'aluminiumoksidet': ('aluminiumoksid',),
'aluminiumsfabrikk': ('aluminiumsfabrikk',),
'aluminiumsfabrikken': ('aluminiumsfabrikk',),
'aluminiumsfabrikkene': ('aluminiumsfabrikk',),
'aluminiumsfabrikker': ('aluminiumsfabrikk',),
'aluminiumsfolie': ('aluminiumsfolie',),
'aluminiumsfolien': ('aluminiumsfolie',),
'aluminiumsfoliene': ('aluminiumsfolie',),
'aluminiumsfolier': ('aluminiumsfolie',),
'aluminiumsklorid': ('aluminiumsklorid',),
'aluminiumsklorida': ('aluminiumsklorid',),
'aluminiumskloridene': ('aluminiumsklorid',),
'aluminiumsklorider': ('aluminiumsklorid',),
'aluminiumskloridet': ('aluminiumsklorid',),
'aluminiumslegering': ('aluminiumslegering',),
'aluminiumslegeringa': ('aluminiumslegering',),
'aluminiumslegeringen': ('aluminiumslegering',),
'aluminiumslegeringene': ('aluminiumslegering',),
'aluminiumslegeringer': ('aluminiumslegering',),
'aluminiumsoksid': ('aluminiumsoksid',),
'aluminiumsoksida': ('aluminiumsoksid',),
'aluminiumsoksidene': ('aluminiumsoksid',),
'aluminiumsoksider': ('aluminiumsoksid',),
'aluminiumsoksidet': ('aluminiumsoksid',),
'aluminiumsverk': ('aluminiumsverk',),
'aluminiumsverka': ('aluminiumsverk',),
'aluminiumsverkene': ('aluminiumsverk',),
'aluminiumsverker': ('aluminiumsverk',),
'aluminiumsverket': ('aluminiumsverk',),
'aluminiumverk': ('aluminiumverk',),
'aluminiumverka': ('aluminiumverk',),
'aluminiumverkene': ('aluminiumverk',),
'aluminiumverker': ('aluminiumverk',),
'aluminiumverket': ('aluminiumverk',),
'alun': ('alun',),
'aluna': ('alun',),
'alunene': ('alun',),
'aluner': ('alun',),
'alunet': ('alun',),
'alunskifer': ('alunskifer',),
'alunskifere': ('alunskifer',),
'alunskiferen': ('alunskifer',),
'alunskiferer': ('alunskifer',),
'alunskiferne': ('alunskifer',),
'alunskifre': ('alunskifer',),
'alunskifrene': ('alunskifer',),
'alunskifrer': ('alunskifer',),
'alunstein': ('alunstein',),
'alunsteinen': ('alunstein',),
'alunsteinene': ('alunstein',),
'alunsteiner': ('alunstein',),
'alv': ('alv',),
'alven': ('alv',),
'alvene': ('alv',),
'alver': ('alv',),
'alvblåst': ('alvblåst',),
'alvblåsten': ('alvblåst',),
'alvblåstene': ('alvblåst',),
'alvblåster': ('alvblåst',),
'alvblåster': ('alvblåster',),
'alvblåstere': ('alvblåster',),
'alvblåsteren': ('alvblåster',),
'alvblåsterer': ('alvblåster',),
'alvblåsterne': ('alvblåster',),
'alvblåstre': ('alvblåster',),
'alvblåstrene': ('alvblåster',),
'alvblåstrer': ('alvblåster',),
'alvedans': ('alvedans',),
'alvedansen': ('alvedans',),
'alvedansene': ('alvedans',),
'alvedanser': ('alvedans',),
'alvedronning': ('alvedronning',),
'alvedronninga': ('alvedronning',),
'alvedronningen': ('alvedronning',),
'alvedronningene': ('alvedronning',),
'alvedronninger': ('alvedronning',),
'alvekonge': ('alvekonge',),
'alvekongen': ('alvekonge',),
'alvekongene': ('alvekonge',),
'alvekonger': ('alvekonge',),
'alveland': ('alveland',),
'alvelanda': ('alveland',),
'alvelandene': ('alveland',),
'alvelandet': ('alveland',),
'alveol': ('alveol',),
'alveolen': ('alveol',),
'alveolene': ('alveol',),
'alveoler': ('alveol',),
'alveolar': ('alveolar',),
'alveolaren': ('alveolar',),
'alveolarene': ('alveolar',),
'alveolarer': ('alveolar',),
'alvnever': ('alvnever',),
'alvneveren': ('alvnever',),
'alvnevra': ('alvnever',),
'alvnevre': ('alvnever',),
'alvnevrene': ('alvnever',),
'alvnevrer': ('alvnever',),
'alvor': ('alvor',),
'alvora': ('alvor',),
'alvorene': ('alvor',),
'alvoret': ('alvor',),
'alvorsord': ('alvorsord',),
'alvorsorda': ('alvorsord',),
'alvorsordene': ('alvorsord',),
'alvorsordet': ('alvorsord',),
'alvorsstund': ('alvorsstund',),
'alvorsstunda': ('alvorsstund',),
'alvorsstunden': ('alvorsstund',),
'alvorsstundene': ('alvorsstund',),
'alvorsstunder': ('alvorsstund',),
'alvorstid': ('alvorstid',),
'alvorstida': ('alvorstid',),
'alvorstiden': ('alvorstid',),
'alvorstidene': ('alvorstid',),
'alvorstider': ('alvorstid',),
'amalgam': ('amalgam',),
'amalgama': ('amalgam',),
'amalgamene': ('amalgam',),
'amalgamer': ('amalgam',),
'amalgamet': ('amalgam',),
'amanuens': ('amanuens',),
'amanuensen': ('amanuens',),
'amanuensene': ('amanuens',),
'amanuenser': ('amanuens',),
'amanuensen': ('amanuensis',),
'amanuensene': ('amanuensis',),
'amanuenser': ('amanuensis',),
'amanuensis': ('amanuensis',),
'amaryll': ('amaryll',),
'amaryllen': ('amaryll',),
'amaryllene': ('amaryll',),
'amaryller': ('amaryll',),
'amaryllis': ('amaryllis',),
'amaryllisen': ('amaryllis',),
'amaryllisene': ('amaryllis',),
'amarylliser': ('amaryllis',),
'amasona': ('amasone',),
'amasone': ('amasone',),
'amasonen': ('amasone',),
'amasonene': ('amasone',),
'amasoner': ('amasone',),
'amatør': ('amatør',),
'amatøren': ('amatør',),
'amatørene': ('amatør',),
'amatører': ('amatør',),
'amatørbasis': ('amatørbasis',),
'amatørbasisen': ('amatørbasis',),
'amatørbasisene': ('amatørbasis',),
'amatørbasiser': ('amatørbasis',),
'amatørbilda': ('amatørbilde',),
'amatørbilde': ('amatørbilde',),
'amatørbildene': ('amatørbilde',),
'amatørbilder': ('amatørbilde',),
'amatørbildet': ('amatørbilde',),
'amatørbokser': ('amatørbokser',),
'amatørboksere': ('amatørbokser',),
'amatørbokseren': ('amatørbokser',),
'amatørbokserer': ('amatørbokser',),
'amatørbokserne': ('amatørbokser',),
'amatørfotball': ('amatørfotball',),
'amatørfotballen': ('amatørfotball',),
'amatørfotballene': ('amatørfotball',),
'amatørfotballer': ('amatørfotball',),
'amatørfotograf': ('amatørfotograf',),
'amatørfotografen': ('amatørfotograf',),
'amatørfotografene': ('amatørfotograf',),
'amatørfotografer': ('amatørfotograf',),
'amatøridrett': ('amatøridrett',),
'amatøridretten': ('amatøridrett',),
'amatøridrettene': ('amatøridrett',),
'amatøridretter': ('amatøridrett',),
'amatørisme': ('amatørisme',),
'amatørismen': ('amatørisme',),
'amatørismene': ('amatørisme',),
'amatørismer': ('amatørisme',),
'amatørskuespiller': ('amatørskuespiller',),
'amatørskuespillere': ('amatørskuespiller',),
'amatørskuespilleren': ('amatørskuespiller',),
'amatørskuespillerer': ('amatørskuespiller',),
'amatørskuespillerne': ('amatørskuespiller',),
'amatørstatus': ('amatørstatus',),
'amatørstatusen': ('amatørstatus',),
'amatørstatusene': ('amatørstatus',),
'amatørstatuser': ('amatørstatus',),
'amatørteater': ('amatørteater',),
'amatørteateret': ('amatørteater',),
'amatørteatra': ('amatørteater',),
'amatørteatre': ('amatørteater',),
'amatørteatrene': ('amatørteater',),
'amatørteatret': ('amatørteater',),
'ambar': ('ambar',),
'ambaren': ('ambar',),
'ambarene': ('ambar',),
'ambarer': ('ambar',),
'ambrene': ('ambar',),
'ambrer': ('ambar',),
'ambassade': ('ambassade',),
'ambassaden': ('ambassade',),
'ambassadene': ('ambassade',),
'ambassader': ('ambassade',),
'ambassaderåd': ('ambassaderåd',),
'ambassaderåden': ('ambassaderåd',),
'ambassaderådene': ('ambassaderåd',),
'ambassaderåder': ('ambassaderåd',),
'ambassadør': ('ambassadør',),
'ambassadøren': ('ambassadør',),
'ambassadørene': ('ambassadør',),
'ambassadører': ('ambassadør',),
'ambiguitet': ('ambiguitet',),
'ambiguiteten': ('ambiguitet',),
'ambiguitetene': ('ambiguitet',),
'ambiguiteter': ('ambiguitet',),
'ambisjon': ('ambisjon',),
'ambisjonen': ('ambisjon',),
'ambisjonene': ('ambisjon',),
'ambisjoner': ('ambisjon',),
'ambivalens': ('ambivalens',),
'ambivalensen': ('ambivalens',),
'ambivalensene': ('ambivalens',),
'ambivalenser': ('ambivalens',),
'ambolt': ('ambolt',),
'ambolten': ('ambolt',),
'amboltene': ('ambolt',),
'ambolter': ('ambolt',),
'ambra': ('ambra',),
'ambraen': ('ambra',),
'ambraene': ('ambra',),
'ambraer': ('ambra',),
'ambrosia': ('ambrosia',),
'ambrosiaen': ('ambrosia',),
'ambrosiaene': ('ambrosia',),
'ambrosiaer': ('ambrosia',),
'ambulanse': ('ambulanse',),
'ambulansen': ('ambulanse',),
'ambulansene': ('ambulanse',),
'ambulanser': ('ambulanse',),
'ambulansebil': ('ambulansebil',),
'ambulansebilen': ('ambulansebil',),
'ambulansebilene': ('ambulansebil',),
'ambulansebiler': ('ambulansebil',),
'ambulansefly': ('ambulansefly',),
'ambulanseflya': ('ambulansefly',),
'ambulanseflyene': ('ambulansefly',),
'ambulanseflyet': ('ambulansefly',),
'amen': ('amen',),
'amena': ('amen',),
'amenene': ('amen',),
'amener': ('amen',),
'amenet': ('amen',),
'amenoreen': ('amenoré',),
'amenoreene': ('amenoré',),
'amenoreer': ('amenoré',),
'amenoré': ('amenoré',),
'amenoréen': ('amenoré',),
'amenoréene': ('amenoré',),
'amenoréer': ('amenoré',),
'americium': ('americium',),
'americiuma': ('americium',),
'americiumene': ('americium',),
'americiumet': ('americium',),
'amerikabrev': ('amerikabrev',),
'amerikabreva': ('amerikabrev',),
'amerikabrevene': ('amerikabrev',),
'amerikabrever': ('amerikabrev',),
'amerikabrevet': ('amerikabrev',),
'amerikabåt': ('amerikabåt',),
'amerikabåten': ('amerikabåt',),
'amerikabåtene': ('amerikabåt',),
'amerikabåter': ('amerikabåt',),
'amerikafarer': ('amerikafarer',),
'amerikafarere': ('amerikafarer',),
'amerikafareren': ('amerikafarer',),
'amerikafarerer': ('amerikafarer',),
'amerikafarerne': ('amerikafarer',),
'amerikafeber': ('amerikafeber',),
'amerikafebere': ('amerikafeber',),
'amerikafeberen': ('amerikafeber',),
'amerikafeberne': ('amerikafeber',),
'amerikafebre': ('amerikafeber',),
'amerikafebrene': ('amerikafeber',),
'amerikafebrer': ('amerikafeber',),
'amerikaner': ('amerikaner',),
'amerikanere': ('amerikaner',),
'amerikaneren': ('amerikaner',),
'amerikanerer': ('amerikaner',),
'amerikanerne': ('amerikaner',),
'amerikanisme': ('amerikanisme',),
'amerikanismen': ('amerikanisme',),
'amerikanismene': ('amerikanisme',),
'amerikanismer': ('amerikanisme',),
'amerikanist': ('amerikanist',),
'amerikanisten': ('amerikanist',),
'amerikanistene': ('amerikanist',),
'amerikanister': ('amerikanist',),
'amerikansk': ('amerikansk',),
'amerikansken': ('amerikansk',),
'amerikanskene': ('amerikansk',),
'amerikansker': ('amerikansk',),
'amerikansk-engelsk': ('amerikansk-engelsk',),
'amerikansk-engelsken': ('amerikansk-engelsk',),
'amerikansk-engelskene': ('amerikansk-engelsk',),
'amerikansk-engelsker': ('amerikansk-engelsk',),
'amerikansk-engelsk': ('amerikansk-engelsk',),
'amerikansk-engelsken': ('amerikansk-engelsk',),
'amerikansk-engelskene': ('amerikansk-engelsk',),
'amerikansk-engelsker': ('amerikansk-engelsk',),
'ametyst': ('ametyst',),
'ametysten': ('ametyst',),
'ametystene': ('ametyst',),
'ametyster': ('ametyst',),
'amfetamin': ('amfetamin',),
'amfetamina': ('amfetamin',),
'amfetaminene': ('amfetamin',),
'amfetaminer': ('amfetamin',),
'amfetaminet': ('amfetamin',),
'amfi': ('amfi',),
'amfia': ('amfi',),
'amfiene': ('amfi',),
'amfier': ('amfi',),
'amfiet': ('amfi',),
'amfibiebil': ('amfibiebil',),
'amfibiebilen': ('amfibiebil',),
'amfibiebilene': ('amfibiebil',),
'amfibiebiler': ('amfibiebil',),
'amfibiefly': ('amfibiefly',),
'amfibieflya': ('amfibiefly',),
'amfibieflyene': ('amfibiefly',),
'amfibieflyet': ('amfibiefly',),
'amfibietank': ('amfibietank',),
'amfibietanken': ('amfibietank',),
'amfibietankene': ('amfibietank',),
'amfibietanker': ('amfibietank',),
'amfibietanks': ('amfibietanks',),
'amfibietanksen': ('amfibietanks',),
'amfibietanksene': ('amfibietanks',),
'amfibietankser': ('amfibietanks',),
'amfibia': ('amfibium',),
'amfibiene': ('amfibium',),
'amfibier': ('amfibium',),
'amfibiet': ('amfibium',),
'amfibium': ('amfibium',),
'amfiteater': ('amfiteater',),
'amfiteateret': ('amfiteater',),
'amfiteatra': ('amfiteater',),
'amfiteatre': ('amfiteater',),
'amfiteatrene': ('amfiteater',),
'amfiteatret': ('amfiteater',),
'amfolytt': ('amfolytt',),
'amfolytten': ('amfolytt',),
'amfolyttene': ('amfolytt',),
'amfolytter': ('amfolytt',),
'amfora': ('amfora',),
'amforaen': ('amfora',),
'amforaene': ('amfora',),
'amforaer': ('amfora',),
'amid': ('amid',),
'amida': ('amid',),
'amidene': ('amid',),
'amider': ('amid',),
'amidet': ('amid',),
'amin': ('amin',),
'amina': ('amin',),
'aminene': ('amin',),
'aminer': ('amin',),
'aminet': ('amin',),
'aminogruppa': ('aminogruppe',),
'aminogruppe': ('aminogruppe',),
'aminogruppen': ('aminogruppe',),
'aminogruppene': ('aminogruppe',),
'aminogrupper': ('aminogruppe',),
'aminosyra': ('aminosyre',),
'aminosyre': ('aminosyre',),
'aminosyren': ('aminosyre',),
'aminosyrene': ('aminosyre',),
'aminosyrer': ('aminosyre',),
'amma': ('amme',),
'amme': ('amme',),
'ammen': ('amme',),
'ammene': ('amme',),
'ammer': ('amme',),
'ammestuesnakk': ('ammestuesnakk',),
'ammestuesnakka': ('ammestuesnakk',),
'ammestuesnakken': ('ammestuesnakk',),
'ammestuesnakkene': ('ammestuesnakk',),
'ammestuesnakker': ('ammestuesnakk',),
'ammestuesnakket': ('ammestuesnakk',),
'ammoniakk': ('ammoniakk',),
'ammoniakken': ('ammoniakk',),
'ammoniakkene': ('ammoniakk',),
'ammoniakker': ('ammoniakk',),
'ammoniakkgass': ('ammoniakkgass',),
'ammoniakkgassen': ('ammoniakkgass',),
'ammoniakkgassene': ('ammoniakkgass',),
'ammoniakkgasser': ('ammoniakkgass',),
'ammonium': ('ammonium',),
'ammoniuma': ('ammonium',),
'ammoniumene': ('ammonium',),
'ammoniumet': ('ammonium',),
'ammoniumgjødsel': ('ammoniumgjødsel',),
'ammoniumgjødselen': ('ammoniumgjødsel',),
'ammoniumgjødsla': ('ammoniumgjødsel',),
'ammoniumgjødslene': ('ammoniumgjødsel',),
'ammoniumgjødsler': ('ammoniumgjødsel',),
'ammunisjon': ('ammunisjon',),
'ammunisjonen': ('ammunisjon',),
'ammunisjonene': ('ammunisjon',),
'ammunisjoner': ('ammunisjon',),
'ammunisjonsfabrikk': ('ammunisjonsfabrikk',),
'ammunisjonsfabrikken': ('ammunisjonsfabrikk',),
'ammunisjonsfabrikkene': ('ammunisjonsfabrikk',),
'ammunisjonsfabrikker': ('ammunisjonsfabrikk',),
'ammunisjonskassa': ('ammunisjonskasse',),
'ammunisjonskasse': ('ammunisjonskasse',),
'ammunisjonskassen': ('ammunisjonskasse',),
'ammunisjonskassene': ('ammunisjonskasse',),
'ammunisjonskasser': ('ammunisjonskasse',),
'ammunisjonskista': ('ammunisjonskiste',),
'ammunisjonskiste': ('ammunisjonskiste',),
'ammunisjonskisten': ('ammunisjonskiste',),
'ammunisjonskistene': ('ammunisjonskiste',),
'ammunisjonskister': ('ammunisjonskiste',),
'ammunisjonslager': ('ammunisjonslager',),
'ammunisjonslageret': ('ammunisjonslager',),
'ammunisjonslagra': ('ammunisjonslager',),
'ammunisjonslagre': ('ammunisjonslager',),
'ammunisjonslagrene': ('ammunisjonslager',),
'ammunisjonstilførsel': ('ammunisjonstilførsel',),
'ammunisjonstilførselen': ('ammunisjonstilførsel',),
'ammunisjonstilførslene': ('ammunisjonstilførsel',),
'ammunisjonstilførsler': ('ammunisjonstilførsel',),
'amnesi': ('amnesi',),
'amnesien': ('amnesi',),
'amnesiene': ('amnesi',),
'amnesier': ('amnesi',),
'amnesti': ('amnesti',),
'amnestia': ('amnesti',),
'amnestiene': ('amnesti',),
'amnestier': ('amnesti',),
'amnestiet': ('amnesti',),
'amor': ('amor',),
'amoren': ('amor',),
'amorene': ('amor',),
'amorer': ('amor',),
'amoralitet': ('amoralitet',),
'amoraliteten': ('amoralitet',),
'amoralitetene': ('amoralitet',),
'amoraliteter': ('amoralitet',),
'amorboge': ('amorboge',),
'amorbogen': ('amorboge',),
'amorbogene': ('amorboge',),
'amorboger': ('amorboge',),
'amorbue': ('amorbue',),
'amorbuen': ('amorbue',),
'amorbuene': ('amorbue',),
'amorbuer': ('amorbue',),
'amorin': ('amorin',),
'amorinen': ('amorin',),
'amorinene': ('amorin',),
'amoriner': ('amorin',),
'amortisasjon': ('amortisasjon',),
'amortisasjonen': ('amortisasjon',),
'amortisasjonene': ('amortisasjon',),
'amortisasjoner': ('amortisasjon',),
'amortisering': ('amortisering',),
'amortiseringa': ('amortisering',),
'amortiseringen': ('amortisering',),
'amortiseringene': ('amortisering',),
'amortiseringer': ('amortisering',),
'amortiseringsfond': ('amortiseringsfond',),
'amortiseringsfonda': ('amortiseringsfond',),
'amortiseringsfondene': ('amortiseringsfond',),
'amortiseringsfondet': ('amortiseringsfond',),
'amortiseringsplan': ('amortiseringsplan',),
'amortiseringsplanen': ('amortiseringsplan',),
'amortiseringsplanene': ('amortiseringsplan',),
'amortiseringsplaner': ('amortiseringsplan',),
'ampel': ('ampel',),
'ampelen': ('ampel',),
'amplene': ('ampel',),
'ampler': ('ampel',),
'ampelplanta': ('ampelplante',),
'ampelplante': ('ampelplante',),
'ampelplanten': ('ampelplante',),
'ampelplantene': ('ampelplante',),
'ampelplanter': ('ampelplante',),
'ampere': ('ampere',),
'amperen': ('ampere',),
'amperene': ('ampere',),
'amperemeter': ('amperemeter',),
'amperemeteret': ('amperemeter',),
'amperemetra': ('amperemeter',),
'amperemetre': ('amperemeter',),
'amperemetrene': ('amperemeter',),
'amperemetret': ('amperemeter',),
'amplitude': ('amplitude',),
'amplituden': ('amplitude',),
'amplitudene': ('amplitude',),
'amplituder': ('amplitude',),
'amplitudemodulasjon': ('amplitudemodulasjon',),
'amplitudemodulasjonen': ('amplitudemodulasjon',),
'amplitudemodulasjonene': ('amplitudemodulasjon',),
'amplitudemodulasjoner': ('amplitudemodulasjon',),
'amplitudemodulering': ('amplitudemodulering',),
'amplitudemoduleringa': ('amplitudemodulering',),
'amplitudemoduleringen': ('amplitudemodulering',),
'amplitudemoduleringene': ('amplitudemodulering',),
'amplitudemoduleringer': ('amplitudemodulering',),
'ampulle': ('ampulle',),
'ampullen': ('ampulle',),
'ampullene': ('ampulle',),
'ampuller': ('ampulle',),
'amputasjon': ('amputasjon',),
'amputasjonen': ('amputasjon',),
'amputasjonene': ('amputasjon',),
'amputasjoner': ('amputasjon',),
'amputering': ('amputering',),
'amputeringa': ('amputering',),
'amputeringen': ('amputering',),
'amputeringene': ('amputering',),
'amputeringer': ('amputering',),
'amt': ('amt',),
'amta': ('amt',),
'amtene': ('amt',),
'amter': ('amt',),
'amtet': ('amt',),
'amtmann': ('amtmann',),
'amtmannen': ('amtmann',),
'amtmenn': ('amtmann',),
'amtmennene': ('amtmann',),
'amtmanninna': ('amtmanninne',),
'amtmanninne': ('amtmanninne',),
'amtmanninnen': ('amtmanninne',),
'amtmanninnene': ('amtmanninne',),
'amtmanninner': ('amtmanninne',),
'amtskasserer': ('amtskasserer',),
'amtskasserere': ('amtskasserer',),
'amtskassereren': ('amtskasserer',),
'amtskassererer': ('amtskasserer',),
'amtskassererne': ('amtskasserer',),
'amtsskole': ('amtsskole',),
'amtsskolen': ('amtsskole',),
'amtsskolene': ('amtsskole',),
'amtsskoler': ('amtsskole',),
'amulett': ('amulett',),
'amuletten': ('amulett',),
'amulettene': ('amulett',),
'amuletter': ('amulett',),
'amylase': ('amylase',),
'amylasen': ('amylase',),
'amylasene': ('amylase',),
'amylaser': ('amylase',),
'amylum': ('amylum',),
'amyluma': ('amylum',),
'amylumene': ('amylum',),
'amylumet': ('amylum',),
'amøbe': ('amøbe',),
'amøben': ('amøbe',),
'amøbene': ('amøbe',),
'amøber': ('amøbe',),
'amøbedysenteri': ('amøbedysenteri',),
'amøbedysenterien': ('amøbedysenteri',),
'amøbedysenteriene': ('amøbedysenteri',),
'amøbedysenterier': ('amøbedysenteri',),
'anabaptist': ('anabaptist',),
'anabaptisten': ('anabaptist',),
'anabaptistene': ('anabaptist',),
'anabaptister': ('anabaptist',),
'anabolisme': ('anabolisme',),
'anabolismen': ('anabolisme',),
'anabolismene': ('anabolisme',),
'anabolismer': ('anabolisme',),
'anafor': ('anafor',),
'anaforen': ('anafor',),
'anaforene': ('anafor',),
'anaforer': ('anafor',),
'anagram': ('anagram',),
'anagramma': ('anagram',),
'anagrammene': ('anagram',),
'anagrammer': ('anagram',),
'anagrammet': ('anagram',),
'anakoluti': ('anakoluti',),
'anakolutien': ('anakoluti',),
'anakolutiene': ('anakoluti',),
'anakolutier': ('anakoluti',),
'anakolutt': ('anakolutt',),
'anakolutten': ('anakolutt',),
'anakoluttene': ('anakolutt',),
'anakolutter': ('anakolutt',),
'anakonda': ('anakonda',),
'anakondaen': ('anakonda',),
'anakondaene': ('anakonda',),
'anakondaer': ('anakonda',),
'anakoret': ('anakoret',),
'anakoreten': ('anakoret',),
'anakoretene': ('anakoret',),
'anakoreter': ('anakoret',),
'anakronisme': ('anakronisme',),
'anakronismen': ('anakronisme',),
'anakronismene': ('anakronisme',),
'anakronismer': ('anakronisme',),
'analfabet': ('analfabet',),
'analfabeten': ('analfabet',),
'analfabetene': ('analfabet',),
'analfabeter': ('analfabet',),
'analfabetisme': ('analfabetisme',),
'analfabetismen': ('analfabetisme',),
'analfabetismene': ('analfabetisme',),
'analfabetismer': ('analfabetisme',),
'analogi': ('analogi',),
'analogien': ('analogi',),
'analogiene': ('analogi',),
'analogier': ('analogi',),
'analogidannelse': ('analogidannelse',),
'analogidannelsen': ('analogidannelse',),
'analogidannelsene': ('analogidannelse',),
'analogidannelser': ('analogidannelse',),
'analogidanning': ('analogidanning',),
'analogidanninga': ('analogidanning',),
'analogidanningen': ('analogidanning',),
'analogidanningene': ('analogidanning',),
'analogidanninger': ('analogidanning',),
'analogislutning': ('analogislutning',),
'analogislutninga': ('analogislutning',),
'analogislutningen': ('analogislutning',),
'analogislutningene': ('analogislutning',),
'analogislutninger': ('analogislutning',),
'analogur': ('analogur',),
'analogura': ('analogur',),
'analogurene': ('analogur',),
'analoguret': ('analogur',),
'analysand': ('analysand',),
'analysanden': ('analysand',),
'analysandene': ('analysand',),
'analysander': ('analysand',),
'analysator': ('analysator',),
'analysatoren': ('analysator',),
'analysatorene': ('analysator',),
'analysatorer': ('analysator',),
'analysa': ('analyse',),
'analyse': ('analyse',),
'analysen': ('analyse',),
'analysene': ('analyse',),
'analyser': ('analyse',),
'analytiker': ('analytiker',),
'analytikere': ('analytiker',),
'analytikeren': ('analytiker',),
'analytikerer': ('analytiker',),
'analytikerne': ('analytiker',),
'analåpning': ('analåpning',),
'analåpninga': ('analåpning',),
'analåpningen': ('analåpning',),
'analåpningene': ('analåpning',),
'analåpninger': ('analåpning',),
'ananas': ('ananas',),
'ananasen': ('ananas',),
'ananasene': ('ananas',),
'ananaser': ('ananas',),
'ananasfamilie': ('ananasfamilie',),
'ananasfamilien': ('ananasfamilie',),
'ananasfamiliene': ('ananasfamilie',),
'ananasfamilier': ('ananasfamilie',),
'ananasjordbær': ('ananasjordbær',),
'ananasjordbæra': ('ananasjordbær',),
'ananasjordbærene': ('ananasjordbær',),
'ananasjordbæret': ('ananasjordbær',),
'ananassaft': ('ananassaft',),
'ananassafta': ('ananassaft',),
'ananassaften': ('ananassaft',),
'ananassaftene': ('ananassaft',),
'ananassafter': ('ananassaft',),
'anapest': ('anapest',),
'anapesten': ('anapest',),
'anapestene': ('anapest',),
'anapester': ('anapest',),
'anarki': ('anarki',),
'anarkia': ('anarki',),
'anarkiene': ('anarki',),
'anarkier': ('anarki',),
'anarkiet': ('anarki',),
'anarkisme': ('anarkisme',),
'anarkismen': ('anarkisme',),
'anarkismene': ('anarkisme',),
'anarkismer': ('anarkisme',),
'anarkist': ('anarkist',),
'anarkisten': ('anarkist',),
'anarkistene': ('anarkist',),
'anarkister': ('anarkist',),
'anarkosyndikalisme': ('anarkosyndikalisme',),
'anarkosyndikalismen': ('anarkosyndikalisme',),
'anarkosyndikalismene': ('anarkosyndikalisme',),
'anarkosyndikalismer': ('anarkosyndikalisme',),
'anastrofe': ('anastrofe',),
'anastrofen': ('anastrofe',),
'anastrofene': ('anastrofe',),
'anastrofer': ('anastrofe',),
'anatem': ('anatem',),
'anatema': ('anatem',),
'anatemene': ('anatem',),
'anatemer': ('anatem',),
'anatemet': ('anatem',),
'anatema': ('anatema',),
'anatemaene': ('anatema',),
'anatemaer': ('anatema',),
'anatemaet': ('anatema',),
'anatom': ('anatom',),
'anatomen': ('anatom',),
'anatomene': ('anatom',),
'anatomer': ('anatom',),
'anatomi': ('anatomi',),
'anatomien': ('anatomi',),
'anatomiene': ('anatomi',),
'anatomier': ('anatomi',),
'anbefaling': ('anbefaling',),
'anbefalinga': ('anbefaling',),
'anbefalingen': ('anbefaling',),
'anbefalingene': ('anbefaling',),
'anbefalinger': ('anbefaling',),
'anbefalingsbrev': ('anbefalingsbrev',),
'anbefalingsbreva': ('anbefalingsbrev',),
'anbefalingsbrevene': ('anbefalingsbrev',),
'anbefalingsbrever': ('anbefalingsbrev',),
'anbefalingsbrevet': ('anbefalingsbrev',),
'anbefalingsskriv': ('anbefalingsskriv',),
'anbefalingsskriva': ('anbefalingsskriv',),
'anbefalingsskrivene': ('anbefalingsskriv',),
'anbefalingsskrivet': ('anbefalingsskriv',),
'anbringelse': ('anbringelse',),
'anbringelsen': ('anbringelse',),
'anbringelsene': ('anbringelse',),
'anbringelser': ('anbringelse',),
'anbud': ('anbud',),
'anbuda': ('anbud',),
'anbudene': ('anbud',),
'anbudet': ('anbud',),
'anbudsbetingelse': ('anbudsbetingelse',),
'anbudsbetingelsen': ('anbudsbetingelse',),
'anbudsbetingelsene': ('anbudsbetingelse',),
'anbudsbetingelser': ('anbudsbetingelse',),
'anbudsfrist': ('anbudsfrist',),
'anbudsfristen': ('anbudsfrist',),
'anbudsfristene': ('anbudsfrist',),
'anbudsfrister': ('anbudsfrist',),
'anbudsgiver': ('anbudsgiver',),
'anbudsgivere': ('anbudsgiver',),
'anbudsgiveren': ('anbudsgiver',),
'anbudsgiverer': ('anbudsgiver',),
'anbudsgiverne': ('anbudsgiver',),
'anbudsinnbydelse': ('anbudsinnbydelse',),
'anbudsinnbydelsen': ('anbudsinnbydelse',),
'anbudsinnbydelsene': ('anbudsinnbydelse',),
'anbudsinnbydelser': ('anbudsinnbydelse',),
'anbudspris': ('anbudspris',),
'anbudsprisen': ('anbudspris',),
'anbudsprisene': ('anbudspris',),
'anbudspriser': ('anbudspris',),
'anbyder': ('anbyder',),
'anbydere': ('anbyder',),
'anbyderen': ('anbyder',),
'anbyderer': ('anbyder',),
'anbyderne': ('anbyder',),
'and': ('and',),
'anda': ('and',),
'anden': ('and',),
'endene': ('and',),
'ender': ('and',),
'andakt': ('andakt',),
'andakta': ('andakt',),
'andakten': ('andakt',),
'andaktene': ('andakt',),
'andakter': ('andakt',),
'andaktsbok': ('andaktsbok',),
'andaktsboka': ('andaktsbok',),
'andaktsboken': ('andaktsbok',),
'andaktsbøkene': ('andaktsbok',),
'andaktsbøker': ('andaktsbok',),
'andaktsstund': ('andaktsstund',),
'andaktsstunda': ('andaktsstund',),
'andaktsstunden': ('andaktsstund',),
'andaktsstundene': ('andaktsstund',),
'andaktsstunder': ('andaktsstund',),
'andalusier': ('andalusier',),
'andalusiere': ('andalusier',),
'andalusieren': ('andalusier',),
'andalusierer': ('andalusier',),
'andalusierne': ('andalusier',),
'andante': ('andante',),
'andanten': ('andante',),
'andantene': ('andante',),
'andanter': ('andante',),
'andanta': ('andante',),
'andante': ('andante',),
'andantene': ('andante',),
'andanter': ('andante',),
'andantet': ('andante',),
'andantesats': ('andantesats',),
'andantesatsen': ('andantesats',),
'andantesatsene': ('andantesats',),
'andantesatser': ('andantesats',),
'andantetempi': ('andantetempo',),
'andantetempiene': ('andantetempo',),
'andantetempo': ('andantetempo',),
'andantetempoa': ('andantetempo',),
'andantetempoene': ('andantetempo',),
'andantetempoer': ('andantetempo',),
'andantetempoet': ('andantetempo',),
'andantino': ('andantino',),
'andantinoen': ('andantino',),
'andantinoene': ('andantino',),
'andantinoer': ('andantino',),
'andantino': ('andantino',),
'andantinoa': ('andantino',),
'andantinoene': ('andantino',),
'andantinoer': ('andantino',),
'andantinoet': ('andantino',),
'ande': ('ande',),
'anden': ('ande',),
'andene': ('ande',),
'ander': ('ande',),
'andebryst': ('andebryst',),
'andebrysta': ('andebryst',),
'andebrystene': ('andebryst',),
'andebrystet': ('andebryst',),
'andedam': ('andedam',),
'andedammen': ('andedam',),
'andedammene': ('andedam',),
'andedammer': ('andedam',),
'andedrag': ('andedrag',),
'andedraga': ('andedrag',),
'andedragene': ('andedrag',),
'andedraget': ('andedrag',),
'andedrått': ('andedrått',),
'andedråtten': ('andedrått',),
'andedråttene': ('andedrått',),
'andedråtter': ('andedrått',),
'andefamilie': ('andefamilie',),
'andefamilien': ('andefamilie',),
'andefamiliene': ('andefamilie',),
'andefamilier': ('andefamilie',),
'andefugl': ('andefugl',),
'andefuglen': ('andefugl',),
'andefuglene': ('andefugl',),
'andefugler': ('andefugl',),
'andektighet': ('andektighet',),
'andektigheta': ('andektighet',),
'andektigheten': ('andektighet',),
'andektighetene': ('andektighet',),
'andektigheter': ('andektighet',),
'andel': ('andel',),
'andelen': ('andel',),
'andelene': ('andel',),
'andeler': ('andel',),
'andelsdrift': ('andelsdrift',),
'andelsdrifta': ('andelsdrift',),
'andelsdriften': ('andelsdrift',),
'andelsdriftene': ('andelsdrift',),
'andelsdrifter': ('andelsdrift',),
'andelseia': ('andelseie',),
'andelseie': ('andelseie',),
'andelseiene': ('andelseie',),
'andelseier': ('andelseie',),
'andelseiet': ('andelseie',),
'andelsforetak': ('andelsforetak',),
'andelsforetaka': ('andelsforetak',),
'andelsforetakene': ('andelsforetak',),
'andelsforetaket': ('andelsforetak',),
'andelshaver': ('andelshaver',),
'andelshavere': ('andelshaver',),
'andelshaveren': ('andelshaver',),
'andelshaverer': ('andelshaver',),
'andelshaverne': ('andelshaver',),
'andelshytta': ('andelshytte',),
'andelshytte': ('andelshytte',),
'andelshytten': ('andelshytte',),
'andelshyttene': ('andelshytte',),
'andelshytter': ('andelshytte',),
'andelslag': ('andelslag',),
'andelslaga': ('andelslag',),
'andelslagene': ('andelslag',),
'andelslaget': ('andelslag',),
'andelsmeieri': ('andelsmeieri',),
'andelsmeieria': ('andelsmeieri',),
'andelsmeieriene': ('andelsmeieri',),
'andelsmeierier': ('andelsmeieri',),
'andelsmeieriet': ('andelsmeieri',),
'andelsslakteri': ('andelsslakteri',),
'andelsslakteria': ('andelsslakteri',),
'andelsslakteriene': ('andelsslakteri',),
'andelsslakterier': ('andelsslakteri',),
'andelsslakteriet': ('andelsslakteri',),
'andelssystem': ('andelssystem',),
'andelssystema': ('andelssystem',),
'andelssystemene': ('andelssystem',),
'andelssystemer': ('andelssystem',),
'andelssystemet': ('andelssystem',),
'andemat': ('andemat',),
'andematen': ('andemat',),
'andematene': ('andemat',),
'andemater': ('andemat',),
'andematfamilie': ('andematfamilie',),
'andematfamilien': ('andematfamilie',),
'andematfamiliene': ('andematfamilie',),
'andematfamilier': ('andematfamilie',),
'andestegg': ('andestegg',),
'andesteggen': ('andestegg',),
'andesteggene': ('andestegg',),
'andestegger': ('andestegg',),
'andesteik': ('andesteik',),
'andesteika': ('andesteik',),
'andesteiken': ('andesteik',),
'andesteikene': ('andesteik',),
'andesteiker': ('andesteik',),
'andestek': ('andestek',),
'andesteka': ('andestek',),
'andesteken': ('andestek',),
'andestekene': ('andestek',),
'andesteker': ('andestek',),
'andføtting': ('andføtting',),
'andføttingen': ('andføtting',),
'andføttingene': ('andføtting',),
'andføttinger': ('andføtting',),
'andlet': ('andlet',),
'andleta': ('andlet',),
'andletene': ('andlet',),
'andletet': ('andlet',),
'andmat': ('andmat',),
'andmaten': ('andmat',),
'andmatene': ('andmat',),
'andmater': ('andmat',),
'andmatfamilie': ('andmatfamilie',),
'andmatfamilien': ('andmatfamilie',),
'andmatfamiliene': ('andmatfamilie',),
'andmatfamilier': ('andmatfamilie',),
'andorraner': ('andorraner',),
'andorranere': ('andorraner',),
'andorraneren': ('andorraner',),
'andorranerer': ('andorraner',),
'andorranerne': ('andorraner',),
'andragende': ('andragende',),
'andragendene': ('andragende',),
'andragender': ('andragende',),
'andragendet': ('andragende',),
'andreaskors': ('andreaskors',),
'andreaskorsa': ('andreaskors',),
'andreaskorsene': ('andreaskors',),
'andreaskorset': ('andreaskors',),
'andreasmess': ('andreasmess',),
'andreasmesse': ('andreasmesse',),
'andrefiolin': ('andrefiolin',),
'andrefiolinen': ('andrefiolin',),
'andrefiolinene': ('andrefiolin',),
'andrefioliner': ('andrefiolin',),
'andregir': ('andregir',),
'andregira': ('andregir',),
'andregirene': ('andregir',),
'andregiret': ('andregir',),
'andregradsligning': ('andregradsligning',),
'andregradsligninga': ('andregradsligning',),
'andregradsligningen': ('andregradsligning',),
'andregradsligningene': ('andregradsligning',),
'andregradsligninger': ('andregradsligning',),
'andregradslikning': ('andregradslikning',),
'andregradslikninga': ('andregradslikning',),
'andregradslikningen': ('andregradslikning',),
'andregradslikningene': ('andregradslikning',),
'andregradslikninger': ('andregradslikning',),
'andrehands': ('andrehands',),
'andrehandsen': ('andrehands',),
'andrehandsene': ('andrehands',),
'andrehandser': ('andrehands',),
'andremann': ('andremann',),
'andremannen': ('andremann',),
'andremannene': ('andremann',),
'andremanner': ('andremann',),
'andremaskinist': ('andremaskinist',),
'andremaskinisten': ('andremaskinist',),
'andremaskinistene': ('andremaskinist',),
'andremaskinister': ('andremaskinist',),
'andreplass': ('andreplass',),
'andreplassen': ('andreplass',),
'andreplassene': ('andreplass',),
'andreplasser': ('andreplass',),
'andreprioritet': ('andreprioritet',),
'andreprioriteten': ('andreprioritet',),
'andreprioritetene': ('andreprioritet',),
'andreprioriteter': ('andreprioritet',),
'andresortering': ('andresortering',),
'andresorteringa': ('andresortering',),
'andresorteringen': ('andresortering',),
'andresorteringene': ('andresortering',),
'andresorteringer': ('andresortering',),
'andrestemme': ('andrestemme',),
'andrestemmen': ('andrestemme',),
'andrestemmene': ('andrestemme',),
'andrestemmer': ('andrestemme',),
'andrestyrmann': ('andrestyrmann',),
'andrestyrmannen': ('andrestyrmann',),
'andrestyrmenn': ('andrestyrmann',),
'andrestyrmennene': ('andrestyrmann',),
'andrik': ('andrik',),
'andriken': ('andrik',),
'andrikene': ('andrik',),
'andriker': ('andrik',),
'androgen': ('androgen',),
'androgena': ('androgen',),
'androgenen': ('androgen',),
'androgenene': ('androgen',),
'androgener': ('androgen',),
'androgenet': ('androgen',),
'androgyni': ('androgyni',),
'androgynien': ('androgyni',),
'androgyniene': ('androgyni',),
'androgynier': ('androgyni',),
'andror': ('andror',),
'androren': ('andror',),
'androrene': ('andror',),
'androrer': ('andror',),
'anduvingsmerka': ('anduvingsmerke',),
'anduvingsmerke': ('anduvingsmerke',),
'anduvingsmerkene': ('anduvingsmerke',),
'anduvingsmerker': ('anduvingsmerke',),
'anduvingsmerket': ('anduvingsmerke',),
'ane': ('ane',),
'anen': ('ane',),
'anene': ('ane',),
'aner': ('ane',),
'anebilda': ('anebilde',),
'anebilde': ('anebilde',),
'anebildene': ('anebilde',),
'anebilder': ('anebilde',),
'anebildet': ('anebilde',),
'anegalleri': ('anegalleri',),
'anegalleria': ('anegalleri',),
'anegalleriene': ('anegalleri',),
'anegallerier': ('anegalleri',),
'anegalleriet': ('anegalleri',),
'anekdote': ('anekdote',),
'anekdoten': ('anekdote',),
'anekdotene': ('anekdote',),
'anekdoter': ('anekdote',),
'anelse': ('anelse',),
'anelsen': ('anelse',),
'anelsene': ('anelse',),
'anelser': ('anelse',),
'anemi': ('anemi',),
'anemien': ('anemi',),
'anemiene': ('anemi',),
'anemier': ('anemi',),
'anemofili': ('anemofili',),
'anemofilien': ('anemofili',),
'anemofiliene': ('anemofili',),
'anemofilier': ('anemofili',),
'anemologi': ('anemologi',),
'anemologien': ('anemologi',),
'anemologiene': ('anemologi',),
'anemologier': ('anemologi',),
'anemometer': ('anemometer',),
'anemometeret': ('anemometer',),
'anemometra': ('anemometer',),
'anemometre': ('anemometer',),
'anemometrene': ('anemometer',),
'anemometret': ('anemometer',),
'anemone': ('anemone',),
'anemonen': ('anemone',),
'anemonene': ('anemone',),
'anemoner': ('anemone',),
'anerkjennelse': ('anerkjennelse',),
'anerkjennelsen': ('anerkjennelse',),
'anerkjennelsene': ('anerkjennelse',),
'anerkjennelser': ('anerkjennelse',),
'aneroidbarometer': ('aneroidbarometer',),
'aneroidbarometeret': ('aneroidbarometer',),
'aneroidbarometra': ('aneroidbarometer',),
'aneroidbarometre': ('aneroidbarometer',),
'aneroidbarometrene': ('aneroidbarometer',),
'aneroidbarometret': ('aneroidbarometer',),
'anestesi': ('anestesi',),
'anestesien': ('anestesi',),
'anestesiene': ('anestesi',),
'anestesier': ('anestesi',),
'anestesilege': ('anestesilege',),
'anestesilegen': ('anestesilege',),
'anestesilegene': ('anestesilege',),
'anestesileger': ('anestesilege',),
'anestesisøster': ('anestesisøster',),
'anestesisøstera': ('anestesisøster',),
'anestesisøsteren': ('anestesisøster',),
'anestesisøstre': ('anestesisøster',),
'anestesisøstrene': ('anestesisøster',),
'anestesisøstrer': ('anestesisøster',),
'anetavla': ('anetavle',),
'anetavle': ('anetavle',),
'anetavlen': ('anetavle',),
'anetavlene': ('anetavle',),
'anetavler': ('anetavle',),
'anfall': ('anfall',),
'anfalla': ('anfall',),
'anfallene': ('anfall',),
'anfallet': ('anfall',),
'anfektelse': ('anfektelse',),
'anfektelsen': ('anfektelse',),
'anfektelsene': ('anfektelse',),
'anfektelser': ('anfektelse',),
'anfordring': ('anfordring',),
'anfordringa': ('anfordring',),
'anfordringen': ('anfordring',),
'anfordringene': ('anfordring',),
'anfordringer': ('anfordring',),
'anfører': ('anfører',),
'anførere': ('anfører',),
'anføreren': ('anfører',),
'anførerer': ('anfører',),
'anførerne': ('anfører',),
'anførsel': ('anførsel',),
'anførselen': ('anførsel',),
'anførslene': ('anførsel',),
'anførsler': ('anførsel',),
'anførselstegn': ('anførselstegn',),
'anførselstegna': ('anførselstegn',),
'anførselstegnene': ('anførselstegn',),
'anførselstegnet': ('anførselstegn',),
'angakok': ('angakok',),
'angakoken': ('angakok',),
'angakokene': ('angakok',),
'angakoker': ('angakok',),
'ange': ('ange',),
'angen': ('ange',),
'angene': ('ange',),
'anger': ('ange',),
'angel': ('angel',),
'angelen': ('angel',),
'anglene': ('angel',),
'angler': ('angel',),
'angelsakser': ('angelsakser',),
'angelsaksere': ('angelsakser',),
'angelsakseren': ('angelsakser',),
'angelsakserer': ('angelsakser',),
'angelsakserne': ('angelsakser',),
'angelsaksisk': ('angelsaksisk',),
'angelsaksisken': ('angelsaksisk',),
'angelsaksiskene': ('angelsaksisk',),
'angelsaksisker': ('angelsaksisk',),
'anger': ('anger',),
'angere': ('anger',),
'angeren': ('anger',),
'angerer': ('anger',),
'angerne': ('anger',),
'angre': ('anger',),
'angrene': ('anger',),
'angrer': ('anger',),
'angina': ('angina',),
'anginaen': ('angina',),
'anginaene': ('angina',),
'anginaer': ('angina',),
'angina pectoris': ('angina pectoris',),
'angiologi': ('angiologi',),
'angiologien': ('angiologi',),
'angiologiene': ('angiologi',),
'angiologier': ('angiologi',),
'angiosperm': ('angiosperm',),
'angiospermen': ('angiosperm',),
'angiospermene': ('angiosperm',),
'angiospermer': ('angiosperm',),
'angivelse': ('angivelse',),
'angivelsen': ('angivelse',),
'angivelsene': ('angivelse',),
'angivelser': ('angivelse',),
'angiver': ('angiver',),
'angivere': ('angiver',),
'angiveren': ('angiver',),
'angiverer': ('angiver',),
'angiverne': ('angiver',),
'angiveri': ('angiveri',),
'angiveria': ('angiveri',),
'angiveriene': ('angiveri',),
'angiverier': ('angiveri',),
'angiveriet': ('angiveri',),
'anglemakk': ('anglemakk',),
'anglemakken': ('anglemakk',),
'anglemakkene': ('anglemakk',),
'anglemakker': ('anglemakk',),
'anglemark': ('anglemark',),
'anglemarken': ('anglemark',),
'anglemarkene': ('anglemark',),
'anglemarker': ('anglemark',),
'angler': ('angler',),
'anglere': ('angler',),
'angleren': ('angler',),
'anglerer': ('angler',),
'anglerne': ('angler',),
'anglikaner': ('anglikaner',),
'anglikanere': ('anglikaner',),
'anglikaneren': ('anglikaner',),
'anglikanerer': ('anglikaner',),
'anglikanerne': ('anglikaner',),
'anglisisme': ('anglisisme',),
'anglisismen': ('anglisisme',),
'anglisismene': ('anglisisme',),
'anglisismer': ('anglisisme',),
'anglist': ('anglist',),
'anglisten': ('anglist',),
'anglistene': ('anglist',),
'anglister': ('anglist',),
'angloaraber': ('angloaraber',),
'angloarabere': ('angloaraber',),
'angloaraberen': ('angloaraber',),
'angloaraberer': ('angloaraber',),
'angloaraberne': ('angloaraber',),
'anglofob': ('anglofob',),
'anglofoben': ('anglofob',),
'anglofobene': ('anglofob',),
'anglofober': ('anglofob',),
'anglofobi': ('anglofobi',),
'anglofobien': ('anglofobi',),
'anglofobiene': ('anglofobi',),
'anglofobier': ('anglofobi',),
'angloman': ('angloman',),
'anglomanen': ('angloman',),
'anglomanene': ('angloman',),
'anglomaner': ('angloman',),
'anglomani': ('anglomani',),
'anglomanien': ('anglomani',),
'anglomaniene': ('anglomani',),
'anglomanier': ('anglomani',),
'angolaner': ('angolaner',),
'angolanere': ('angolaner',),
'angolaneren': ('angolaner',),
'angolanerer': ('angolaner',),
'angolanerne': ('angolaner',),
'angora': ('angora',),
'angoraen': ('angora',),
'angoraene': ('angora',),
'angoraer': ('angora',),
'angoragarn': ('angoragarn',),
'angoragarna': ('angoragarn',),
'angoragarnene': ('angoragarn',),
'angoragarnet': ('angoragarn',),
'angorageit': ('angorageit',),
'angorageita': ('angorageit',),
'angorageiten': ('angorageit',),
'angorageitene': ('angorageit',),
'angorageiter': ('angorageit',),
'angoragenser': ('angoragenser',),
'angoragensere': ('angoragenser',),
'angoragenseren': ('angoragenser',),
'angoragenserer': ('angoragenser',),
'angoragenserne': ('angoragenser',),
'angorakanin': ('angorakanin',),
'angorakaninen': ('angorakanin',),
'angorakaninene': ('angorakanin',),
'angorakaniner': ('angorakanin',),
'angorakatt': ('angorakatt',),
'angorakatten': ('angorakatt',),
'angorakattene': ('angorakatt',),
'angorakatter': ('angorakatt',),
'angoraull': ('angoraull',),
'angoraulla': ('angoraull',),
'angoraullen': ('angoraull',),
'angoraullene': ('angoraull',),
'angorauller': ('angoraull',),
'angrefrist': ('angrefrist',),
'angrefristen': ('angrefrist',),
'angrefristene': ('angrefrist',),
'angrefrister': ('angrefrist',),
'angrep': ('angrep',),
'angrepa': ('angrep',),
'angrepene': ('angrep',),
'angrepet': ('angrep',),
'angrepsfront': ('angrepsfront',),
'angrepsfronten': ('angrepsfront',),
'angrepsfrontene': ('angrepsfront',),
'angrepsfronter': ('angrepsfront',),
'angrepshandling': ('angrepshandling',),
'angrepshandlinga': ('angrepshandling',),
'angrepshandlingen': ('angrepshandling',),
'angrepshandlingene': ('angrepshandling',),
'angrepshandlinger': ('angrepshandling',),
'angrepskrig': ('angrepskrig',),
'angrepskrigen': ('angrepskrig',),
'angrepskrigene': ('angrepskrig',),
'angrepskriger': ('angrepskrig',),
'angrepsmål': ('angrepsmål',),
'angrepsmåla': ('angrepsmål',),
'angrepsmålene': ('angrepsmål',),
'angrepsmålet': ('angrepsmål',),
'angrepsmåte': ('angrepsmåte',),
'angrepsmåten': ('angrepsmåte',),
'angrepsmåtene': ('angrepsmåte',),
'angrepsmåter': ('angrepsmåte',),
'angrepsplan': ('angrepsplan',),
'angrepsplanen': ('angrepsplan',),
'angrepsplanene': ('angrepsplan',),
'angrepsplaner': ('angrepsplan',),
'angrepspolitikk': ('angrepspolitikk',),
'angrepspolitikken': ('angrepspolitikk',),
'angrepspolitikkene': ('angrepspolitikk',),
'angrepspolitikker': ('angrepspolitikk',),
'angrepsposisjon': ('angrepsposisjon',),
'angrepsposisjonen': ('angrepsposisjon',),
'angrepsposisjonene': ('angrepsposisjon',),
'angrepsposisjoner': ('angrepsposisjon',),
'angrepspunkt': ('angrepspunkt',),
'angrepspunkta': ('angrepspunkt',),
'angrepspunktene': ('angrepspunkt',),
'angrepspunkter': ('angrepspunkt',),
'angrepspunktet': ('angrepspunkt',),
'angrepsspeller': ('angrepsspeller',),
'angrepsspellere': ('angrepsspeller',),
'angrepsspelleren': ('angrepsspeller',),
'angrepsspellerer': ('angrepsspeller',),
'angrepsspellerne': ('angrepsspeller',),
'angrepsspiller': ('angrepsspiller',),
'angrepsspillere': ('angrepsspiller',),
'angrepsspilleren': ('angrepsspiller',),
'angrepsspillerer': ('angrepsspiller',),
'angrepsspillerne': ('angrepsspiller',),
'angrepsspiss': ('angrepsspiss',),
'angrepsspissen': ('angrepsspiss',),
'angrepsspissene': ('angrepsspiss',),
'angrepsspisser': ('angrepsspiss',),
'angriper': ('angriper',),
'angripere': ('angriper',),
'angriperen': ('angriper',),
'angriperer': ('angriper',),
'angriperne': ('angriper',),
'angriperstat': ('angriperstat',),
'angriperstaten': ('angriperstat',),
'angriperstatene': ('angriperstat',),
'angriperstater': ('angriperstat',),
'angst': ('angst',),
'angsten': ('angst',),
'angstene': ('angst',),
'angster': ('angst',),
'angstbiter': ('angstbiter',),
'angstbitere': ('angstbiter',),
'angstbiteren': ('angstbiter',),
'angstbiterer': ('angstbiter',),
'angstbiterne': ('angstbiter',),
'angstfordriver': ('angstfordriver',),
'angstfordrivere': ('angstfordriver',),
'angstfordriveren': ('angstfordriver',),
'angstfordriverer': ('angstfordriver',),
'angstfordriverne': ('angstfordriver',),
'angstneurose': ('angstneurose',),
'angstneurosen': ('angstneurose',),
'angstneurosene': ('angstneurose',),
'angstneuroser': ('angstneurose',),
'angstnevrose': ('angstnevrose',),
'angstnevrosen': ('angstnevrose',),
'angstnevrosene': ('angstnevrose',),
'angstnevroser': ('angstnevrose',),
'angstrop': ('angstrop',),
'angstropa': ('angstrop',),
'angstropene': ('angstrop',),
'angstropet': ('angstrop',),
'angstskrik': ('angstskrik',),
'angstskrika': ('angstskrik',),
'angstskrikene': ('angstskrik',),
'angstskriket': ('angstskrik',),
'angstsvette': ('angstsvette',),
'angstsvetten': ('angstsvette',),
'angstsvettene': ('angstsvette',),
'angstsvetter': ('angstsvette',),
'angsttilstand': ('angsttilstand',),
'angsttilstanden': ('angsttilstand',),
'angsttilstandene': ('angsttilstand',),
'angsttilstander': ('angsttilstand',),
'anhang': ('anhang',),
'anhanga': ('anhang',),
'anhangene': ('anhang',),
'anhanget': ('anhang',),
'anheng': ('anheng',),
'anhenga': ('anheng',),
'anhengene': ('anheng',),
'anhenget': ('anheng',),
'anholdelse': ('anholdelse',),
'anholdelsen': ('anholdelse',),
'anholdelsene': ('anholdelse',),
'anholdelser': ('anholdelse',),
'anhydrid': ('anhydrid',),
'anhydrida': ('anhydrid',),
'anhydridene': ('anhydrid',),
'anhydrider': ('anhydrid',),
'anhydridet': ('anhydrid',),
'anhydritt': ('anhydritt',),
'anhydritten': ('anhydritt',),
'anhydrittene': ('anhydritt',),
'anhydritter': ('anhydritt',),
'anilin': ('anilin',),
'anilina': ('anilin',),
'anilinene': ('anilin',),
'anilinet': ('anilin',),
'anilinblått': ('anilinblått',),
'anilinfarge': ('anilinfarge',),
'anilinfargen': ('anilinfarge',),
'anilinfargene': ('anilinfarge',),
'anilinfarger': ('anilinfarge',),
'anilinsvart': ('anilinsvart',),
'anilintrykk': ('anilintrykk',),
'anilintrykka': ('anilintrykk',),
'anilintrykkene': ('anilintrykk',),
'anilintrykket': ('anilintrykk',),
'animalisme': ('animalisme',),
'animalismen': ('animalisme',),
'animalismene': ('animalisme',),
'animalismer': ('animalisme',),
'animasjon': ('animasjon',),
'animasjonen': ('animasjon',),
'animasjonene': ('animasjon',),
'animasjoner': ('animasjon',),
'animasjonsfilm': ('animasjonsfilm',),
'animasjonsfilmen': ('animasjonsfilm',),
'animasjonsfilmene': ('animasjonsfilm',),
'animasjonsfilmer': ('animasjonsfilm',),
'animatisme': ('animatisme',),
'animatismen': ('animatisme',),
'animatismene': ('animatisme',),
'animatismer': ('animatisme',),
'animatør': ('animatør',),
'animatøren': ('animatør',),
'animatørene': ('animatør',),
'animatører': ('animatør',),
'animisme': ('animisme',),
'animismen': ('animisme',),
'animismene': ('animisme',),
'animismer': ('animisme',),
'animositet': ('animositet',),
'animositeten': ('animositet',),
'animositetene': ('animositet',),
'animositeter': ('animositet',),
'aning': ('aning',),
'aninga': ('aning',),
'aningen': ('aning',),
'aningene': ('aning',),
'aninger': ('aning',),
'anion': ('anion',),
'aniona': ('anion',),
'anionene': ('anion',),
'anioner': ('anion',),
'anionet': ('anion',),
'anis': ('anis',),
'anisen': ('anis',),
'anisene': ('anis',),
'aniser': ('anis',),
'anisbrød': ('anisbrød',),
'anisbrøda': ('anisbrød',),
'anisbrødene': ('anisbrød',),
'anisbrødet': ('anisbrød',),
'anisette': ('anisette',),
'anisetten': ('anisette',),
'anisettene': ('anisette',),
'anisetter': ('anisette',),
'anisfrø': ('anisfrø',),
'anisfrøa': ('anisfrø',),
'anisfrøene': ('anisfrø',),
'anisfrøet': ('anisfrø',),
'aniskringla': ('aniskringle',),
'aniskringle': ('aniskringle',),
'aniskringlen': ('aniskringle',),
'aniskringlene': ('aniskringle',),
'aniskringler': ('aniskringle',),
'anislakris': ('anislakris',),
'anislakrisen': ('anislakris',),
'anislakrisene': ('anislakris',),
'anislakriser': ('anislakris',),
'anislikør': ('anislikør',),
'anislikøren': ('anislikør',),
'anislikørene': ('anislikør',),
'anislikører': ('anislikør',),
'ank': ('ank',),
'anken': ('ank',),
'ankene': ('ank',),
'anker': ('ank',),
'anke': ('anke',),
'anken': ('anke',),
'ankene': ('anke',),
'anker': ('anke',),
'ankedomstol': ('ankedomstol',),
'ankedomstolen': ('ankedomstol',),
'ankedomstolene': ('ankedomstol',),
'ankedomstoler': ('ankedomstol',),
'ankefrist': ('ankefrist',),
'ankefristen': ('ankefrist',),
'ankefristene': ('ankefrist',),
'ankefrister': ('ankefrist',),
'ankeinstans': ('ankeinstans',),
'ankeinstansen': ('ankeinstans',),
'ankeinstansene': ('ankeinstans',),
'ankeinstanser': ('ankeinstans',),
'ankel': ('ankel',),
'ankelen': ('ankel',),
'anklene': ('ankel',),
'ankler': ('ankel',),
'ankelknoke': ('ankelknoke',),
'ankelknoken': ('ankelknoke',),
'ankelknokene': ('ankelknoke',),
'ankelknoker': ('ankelknoke',),
'ankelknute': ('ankelknute',),
'ankelknuten': ('ankelknute',),
'ankelknutene': ('ankelknute',),
'ankelknuter': ('ankelknute',),
'ankelledd': ('ankelledd',),
'ankelledda': ('ankelledd',),
'ankelleddene': ('ankelledd',),
'ankelleddet': ('ankelledd',),
'ankemål': ('ankemål',),
'ankemåla': ('ankemål',),
'ankemålene': ('ankemål',),
'ankemålet': ('ankemål',),
'ankenemnd': ('ankenemnd',),
'ankenemnda': ('ankenemnd',),
'ankenemnden': ('ankenemnd',),
'ankenemndene': ('ankenemnd',),
'ankenemnder': ('ankenemnd',),
'ankepunkt': ('ankepunkt',),
'ankepunkta': ('ankepunkt',),
'ankepunktene': ('ankepunkt',),
'ankepunkter': ('ankepunkt',),
'ankepunktet': ('ankepunkt',),
'anker': ('anker',),
'ankera': ('anker',),
'ankere': ('anker',),
'ankeret': ('anker',),
'ankra': ('anker',),
'ankre': ('anker',),
'ankrene': ('anker',),
'ankret': ('anker',),
'anker': ('anker',),
'ankera': ('anker',),
'ankere': ('anker',),
'ankeret': ('anker',),
'ankra': ('anker',),
'ankre': ('anker',),
'ankrene': ('anker',),
'ankret': ('anker',),
'ankerbøya': ('ankerbøye',),
'ankerbøye': ('ankerbøye',),
'ankerbøyen': ('ankerbøye',),
'ankerbøyene': ('ankerbøye',),
'ankerbøyer': ('ankerbøye',),
'ankerfesta': ('ankerfeste',),
'ankerfeste': ('ankerfeste',),
'ankerfestene': ('ankerfeste',),
'ankerfester': ('ankerfeste',),
'ankerfestet': ('ankerfeste',),
'ankerfligg': ('ankerfligg',),
'ankerfliggen': ('ankerfligg',),
'ankerfliggene': ('ankerfligg',),
'ankerfligger': ('ankerfligg',),
'ankerkjetting': ('ankerkjetting',),
'ankerkjettingen': ('ankerkjetting',),
'ankerkjettingene': ('ankerkjetting',),
'ankerkjettinger': ('ankerkjetting',),
'ankerklo': ('ankerklo',),
'ankerkloa': ('ankerklo',),
'ankerkloen': ('ankerklo',),
'ankerklør': ('ankerklo',),
'ankerklørne': ('ankerklo',),
'ankerkvinna': ('ankerkvinne',),
'ankerkvinne': ('ankerkvinne',),
'ankerkvinnen': ('ankerkvinne',),
'ankerkvinnene': ('ankerkvinne',),
'ankerkvinner': ('ankerkvinne',),
'ankerlanterna': ('ankerlanterne',),
'ankerlanterne': ('ankerlanterne',),
'ankerlanternen': ('ankerlanterne',),
'ankerlanternene': ('ankerlanterne',),
'ankerlanterner': ('ankerlanterne',),
'ankermann': ('ankermann',),
'ankermannen': ('ankermann',),
'ankermenn': ('ankermann',),
'ankermennene': ('ankermann',),
'ankerplass': ('ankerplass',),
'ankerplassen': ('ankerplass',),
'ankerplassene': ('ankerplass',),
'ankerplasser': ('ankerplass',),
'ankerspill': ('ankerspill',),
'ankerspilla': ('ankerspill',),
'ankerspillene': ('ankerspill',),
'ankerspillet': ('ankerspill',),
'ankesak': ('ankesak',),
'ankesaka': ('ankesak',),
'ankesaken': ('ankesak',),
'ankesakene': ('ankesak',),
'ankesaker': ('ankesak',),
'ankesum': ('ankesum',),
'ankesummen': ('ankesum',),
'ankesummene': ('ankesum',),
'ankesummer': ('ankesum',),
'anklage': ('anklage',),
'anklagen': ('anklage',),
'anklagene': ('anklage',),
'anklager': ('anklage',),
'anklagebenk': ('anklagebenk',),
'anklagebenken': ('anklagebenk',),
'anklagebenkene': ('anklagebenk',),
'anklagebenker': ('anklagebenk',),
'anklageprinsipp': ('anklageprinsipp',),
'anklageprinsippa': ('anklageprinsipp',),
'anklageprinsippene': ('anklageprinsipp',),
'anklageprinsipper': ('anklageprinsipp',),
'anklageprinsippet': ('anklageprinsipp',),
'anklagepunkt': ('anklagepunkt',),
'anklagepunkta': ('anklagepunkt',),
'anklagepunktene': ('anklagepunkt',),
'anklagepunkter': ('anklagepunkt',),
'anklagepunktet': ('anklagepunkt',),
'anklager': ('anklager',),
'anklagere': ('anklager',),
'anklageren': ('anklager',),
'anklagerer': ('anklager',),
'anklagerne': ('anklager',),
'anklang': ('anklang',),
'anklangen': ('anklang',),
'anklangene': ('anklang',),
'anklanger': ('anklang',),
'ankomst': ('ankomst',),
'ankomsten': ('ankomst',),
'ankomstene': ('ankomst',),
'ankomster': ('ankomst',),
'ankomstdag': ('ankomstdag',),
'ankomstdagen': ('ankomstdag',),
'ankomstdagene': ('ankomstdag',),
'ankomstdager': ('ankomstdag',),
'ankomsthall': ('ankomsthall',),
'ankomsthallen': ('ankomsthall',),
'ankomsthallene': ('ankomsthall',),
'ankomsthaller': ('ankomsthall',),
'ankomsthamn': ('ankomsthamn',),
'ankomsthamna': ('ankomsthamn',),
'ankomsthamnen': ('ankomsthamn',),
'ankomsthamnene': ('ankomsthamn',),
'ankomsthamner': ('ankomsthamn',),
'ankomsthavn': ('ankomsthavn',),
'ankomsthavna': ('ankomsthavn',),
'ankomsthavnen': ('ankomsthavn',),
'ankomsthavnene': ('ankomsthavn',),
'ankomsthavner': ('ankomsthavn',),
'ankomststed': ('ankomststed',),
'ankomststedene': ('ankomststed',),
'ankomststeder': ('ankomststed',),
'ankomststedet': ('ankomststed',),
'ankomsttavla': ('ankomsttavle',),
'ankomsttavle': ('ankomsttavle',),
'ankomsttavlen': ('ankomsttavle',),
'ankomsttavlene': ('ankomsttavle',),
'ankomsttavler': ('ankomsttavle',),
'ankomsttid': ('ankomsttid',),
'ankomsttida': ('ankomsttid',),
'ankomsttiden': ('ankomsttid',),
'ankomsttidene': ('ankomsttid',),
'ankomsttider': ('ankomsttid',),
'ankring': ('ankring',),
'ankringa': ('ankring',),
'ankringen': ('ankring',),
'ankringene': ('ankring',),
'ankringer': ('ankring',),
'ankringsplass': ('ankringsplass',),
'ankringsplassen': ('ankringsplass',),
'ankringsplassene': ('ankringsplass',),
'ankringsplasser': ('ankringsplass',),
'anledning': ('anledning',),
'anledninga': ('anledning',),
'anledningen': ('anledning',),
'anledningene': ('anledning',),
'anledninger': ('anledning',),
'anlegg': ('anlegg',),
'anlegga': ('anlegg',),
'anleggene': ('anlegg',),
'anlegget': ('anlegg',),
'anleggsaktiva': ('anleggsaktivum',),
'anleggsaktivaene': ('anleggsaktivum',),
'anleggsaktivene': ('anleggsaktivum',),
'anleggsaktiver': ('anleggsaktivum',),
'anleggsaktivum': ('anleggsaktivum',),
'anleggsaktivumet': ('anleggsaktivum',),
'anleggsarbeid': ('anleggsarbeid',),
'anleggsarbeida': ('anleggsarbeid',),
'anleggsarbeidene': ('anleggsarbeid',),
'anleggsarbeider': ('anleggsarbeid',),
'anleggsarbeidet': ('anleggsarbeid',),
'anleggsarbeider': ('anleggsarbeider',),
'anleggsarbeidere': ('anleggsarbeider',),
'anleggsarbeideren': ('anleggsarbeider',),
'anleggsarbeiderer': ('anleggsarbeider',),
'anleggsarbeiderne': ('anleggsarbeider',),
'anleggsgartner': ('anleggsgartner',),
'anleggsgartnere': ('anleggsgartner',),
'anleggsgartneren': ('anleggsgartner',),
'anleggsgartnerer': ('anleggsgartner',),
'anleggsgartnerne': ('anleggsgartner',),
'anleggskapital': ('anleggskapital',),
'anleggskapitalen': ('anleggskapital',),
'anleggskapitalene': ('anleggskapital',),
'anleggskapitaler': ('anleggskapital',),
'anleggskostnad': ('anleggskostnad',),
'anleggskostnaden': ('anleggskostnad',),
'anleggskostnadene': ('anleggskostnad',),
'anleggskostnader': ('anleggskostnad',),
'anleggsmaskin': ('anleggsmaskin',),
'anleggsmaskina': ('anleggsmaskin',),
'anleggsmaskinen': ('anleggsmaskin',),
'anleggsmaskinene': ('anleggsmaskin',),
'anleggsmaskiner': ('anleggsmaskin',),
'anleggsmiddel': ('anleggsmiddel',),
'anleggsmiddelet': ('anleggsmiddel',),
'anleggsmidla': ('anleggsmiddel',),
'anleggsmidlene': ('anleggsmiddel',),
'anleggsmidler': ('anleggsmiddel',),
'anleggsmidlet': ('anleggsmiddel',),
'anleggspreg': ('anleggspreg',),
'anleggsprega': ('anleggspreg',),
'anleggspregene': ('anleggspreg',),
'anleggspreget': ('anleggspreg',),
'anleggsslusk': ('anleggsslusk',),
'anleggsslusken': ('anleggsslusk',),
'anleggssluskene': ('anleggsslusk',),
'anleggsslusker': ('anleggsslusk',),
'anleggsvirksomhet': ('anleggsvirksomhet',),
'anleggsvirksomheta': ('anleggsvirksomhet',),
'anleggsvirksomheten': ('anleggsvirksomhet',),
'anleggsvirksomhetene': ('anleggsvirksomhet',),
'anleggsvirksomheter': ('anleggsvirksomhet',),
'anliggende': ('anliggende',),
'anliggendene': ('anliggende',),
'anliggender': ('anliggende',),
'anliggendet': ('anliggende',),
'anløp': ('anløp',),
'anløpa': ('anløp',),
'anløpene': ('anløp',),
'anløpet': ('anløp',),
'anløpshamn': ('anløpshamn',),
'anløpshamna': ('anløpshamn',),
'anløpshamnen': ('anløpshamn',),
'anløpshamnene': ('anløpshamn',),
'anløpshamner': ('anløpshamn',),
'anløpshavn': ('anløpshavn',),
'anløpshavna': ('anløpshavn',),
'anløpshavnen': ('anløpshavn',),
'anløpshavnene': ('anløpshavn',),
'anløpshavner': ('anløpshavn',),
'anløpssted': ('anløpssted',),
'anløpsstedene': ('anløpssted',),
'anløpssteder': ('anløpssted',),
'anløpsstedet': ('anløpssted',),
'anløpstid': ('anløpstid',),
'anløpstida': ('anløpstid',),
'anløpstiden': ('anløpstid',),
'anløpstidene': ('anløpstid',),
'anløpstider': ('anløpstid',),
'anmarsj': ('anmarsj',),
'anmarsjen': ('anmarsj',),
'anmarsjene': ('anmarsj',),
'anmarsjer': ('anmarsj',),
'anmasselse': ('anmasselse',),
'anmasselsen': ('anmasselse',),
'anmasselsene': ('anmasselse',),
'anmasselser': ('anmasselse',),
'anmeldelse': ('anmeldelse',),
'anmeldelsen': ('anmeldelse',),
'anmeldelsene': ('anmeldelse',),
'anmeldelser': ('anmeldelse',),
'anmeldelsesfrist': ('anmeldelsesfrist',),
'anmeldelsesfristen': ('anmeldelsesfrist',),
'anmeldelsesfristene': ('anmeldelsesfrist',),
'anmeldelsesfrister': ('anmeldelsesfrist',),
'anmelder': ('anmelder',),
'anmeldere': ('anmelder',),
'anmelderen': ('anmelder',),
'anmelderer': ('anmelder',),
'anmelderne': ('anmelder',),
'anmeldereksemplar': ('anmeldereksemplar',),
'anmeldereksemplara': ('anmeldereksemplar',),
'anmeldereksemplarene': ('anmeldereksemplar',),
'anmeldereksemplarer': ('anmeldereksemplar',),
'anmeldereksemplaret': ('anmeldereksemplar',),
'anmeldervirksomhet': ('anmeldervirksomhet',),
'anmeldervirksomheta': ('anmeldervirksomhet',),
'anmeldervirksomheten': ('anmeldervirksomhet',),
'anmeldervirksomhetene': ('anmeldervirksomhet',),
'anmeldervirksomheter': ('anmeldervirksomhet',),
'anmerkning': ('anmerkning',),
'anmerkninga': ('anmerkning',),
'anmerkningen': ('anmerkning',),
'anmerkningene': ('anmerkning',),
'anmerkninger': ('anmerkning',),
'anmodning': ('anmodning',),
'anmodninga': ('anmodning',),
'anmodningen': ('anmodning',),
'anmodningene': ('anmodning',),
'anmodninger': ('anmodning',),
'annal': ('annal',),
'annalen': ('annal',),
'annalene': ('annal',),
'annaler': ('annal',),
'annalist': ('annalist',),
'annalisten': ('annalist',),
'annalistene': ('annalist',),
'annalister': ('annalist',),
'anneks': ('anneks',),
'anneksa': ('anneks',),
'anneksene': ('anneks',),
'annekser': ('anneks',),
'annekset': ('anneks',),
'anneksbygning': ('anneksbygning',),
'anneksbygninga': ('anneksbygning',),
'anneksbygningen': ('anneksbygning',),
'anneksbygningene': ('anneksbygning',),
'anneksbygninger': ('anneksbygning',),
'anneksjon': ('anneksjon',),
'anneksjonen': ('anneksjon',),
'anneksjonene': ('anneksjon',),
'anneksjoner': ('anneksjon',),
'annekskirka': ('annekskirke',),
'annekskirke': ('annekskirke',),
'annekskirken': ('annekskirke',),
'annekskirkene': ('annekskirke',),
'annekskirker': ('annekskirke',),
'annekskjerka': ('annekskjerke',),
'annekskjerke': ('annekskjerke',),
'annekskjerken': ('annekskjerke',),
'annekskjerkene': ('annekskjerke',),
'annekskjerker': ('annekskjerke',),
'annekssogn': ('annekssogn',),
'annekssogna': ('annekssogn',),
'annekssognene': ('annekssogn',),
'annekssognet': ('annekssogn',),
'annekssokn': ('annekssokn',),
'annekssokna': ('annekssokn',),
'annekssoknen': ('annekssokn',),
'annekssoknene': ('annekssokn',),
'annekssokner': ('annekssokn',),
'annekssoknet': ('annekssokn',),
'annektering': ('annektering',),
'annekteringa': ('annektering',),
'annekteringen': ('annektering',),
'annekteringene': ('annektering',),
'annekteringer': ('annektering',),
'annendag': ('annendag',),
'annendagen': ('annendag',),
'annendagene': ('annendag',),
'annendager': ('annendag',),
'annenfiolin': ('annenfiolin',),
'annenfiolinen': ('annenfiolin',),
'annenfiolinene': ('annenfiolin',),
'annenfioliner': ('annenfiolin',),
'annengradsligning': ('annengradsligning',),
'annengradsligninga': ('annengradsligning',),
'annengradsligningen': ('annengradsligning',),
'annengradsligningene': ('annengradsligning',),
'annengradsligninger': ('annengradsligning',),
'annengradslikning': ('annengradslikning',),
'annengradslikninga': ('annengradslikning',),
'annengradslikningen': ('annengradslikning',),
'annengradslikningene': ('annengradslikning',),
'annengradslikninger': ('annengradslikning',),
'annenmann': ('annenmann',),
'annenmannen': ('annenmann',),
'annenmannene': ('annenmann',),
'annenmanner': ('annenmann',),
'annenmaskinist': ('annenmaskinist',),
'annenmaskinisten': ('annenmaskinist',),
'annenmaskinistene': ('annenmaskinist',),
'annenmaskinister': ('annenmaskinist',),
'annenplass': ('annenplass',),
'annenplassen': ('annenplass',),
'annenplassene': ('annenplass',),
'annenplasser': ('annenplass',),
'annenprioritet': ('annenprioritet',),
'annenprioriteten': ('annenprioritet',),
'annenprioritetene': ('annenprioritet',),
'annenprioriteter': ('annenprioritet',),
'annensortering': ('annensortering',),
'annensorteringa': ('annensortering',),
'annensorteringen': ('annensortering',),
'annensorteringene': ('annensortering',),
'annensorteringer': ('annensortering',),
'annenstemme': ('annenstemme',),
'annenstemmen': ('annenstemme',),
'annenstemmene': ('annenstemme',),
'annenstemmer': ('annenstemme',),
'annenstyrmann': ('annenstyrmann',),
'annenstyrmannen': ('annenstyrmann',),
'annenstyrmenn': ('annenstyrmann',),
'annenstyrmennene': ('annenstyrmann',),
'annerledestroende': ('annerledestroende',),
'annerledestroende': ('annerledestroende',),
'annetgir': ('annetgir',),
'annetgira': ('annetgir',),
'annetgirene': ('annetgir',),
'annetgiret': ('annetgir',),
'annleistroende': ('annleistroende',),
'annonsa': ('annonse',),
'annonse': ('annonse',),
'annonsen': ('annonse',),
'annonsene': ('annonse',),
'annonser': ('annonse',),
'annonseakkvisitør': ('annonseakkvisitør',),
'annonseakkvisitøren': ('annonseakkvisitør',),
'annonseakkvisitørene': ('annonseakkvisitør',),
'annonseakkvisitører': ('annonseakkvisitør',),
'annonsebyrå': ('annonsebyrå',),
'annonsebyråa': ('annonsebyrå',),
'annonsebyråene': ('annonsebyrå',),
'annonsebyråer': ('annonsebyrå',),
'annonsebyrået': ('annonsebyrå',),
'annonsekampanje': ('annonsekampanje',),
'annonsekampanjen': ('annonsekampanje',),
'annonsekampanjene': ('annonsekampanje',),
'annonsekampanjer': ('annonsekampanje',),
'annonsesida': ('annonseside',),
'annonseside': ('annonseside',),
'annonsesiden': ('annonseside',),
'annonsesidene': ('annonseside',),
'annonsesider': ('annonseside',),
'annonsespalta': ('annonsespalte',),
'annonsespalte': ('annonsespalte',),
'annonsespalten': ('annonsespalte',),
'annonsespaltene': ('annonsespalte',),
'annonsespalter': ('annonsespalte',),
'annonsør': ('annonsør',),
'annonsøren': ('annonsør',),
'annonsørene': ('annonsør',),
'annonsører': ('annonsør',),
'annuitet': ('annuitet',),
'annuiteten': ('annuitet',),
'annuitetene': ('annuitet',),
'annuiteter': ('annuitet',),
'annuitetslån': ('annuitetslån',),
'annuitetslåna': ('annuitetslån',),
'annuitetslånene': ('annuitetslån',),
'annuitetslånet': ('annuitetslån',),
'annuitetsregning': ('annuitetsregning',),
'annuitetsregninga': ('annuitetsregning',),
'annuitetsregningen': ('annuitetsregning',),
'annuitetsregningene': ('annuitetsregning',),
'annuitetsregninger': ('annuitetsregning',),
'annuitetsrekning': ('annuitetsrekning',),
'annuitetsrekninga': ('annuitetsrekning',),
'annuitetsrekningen': ('annuitetsrekning',),
'annuitetsrekningene': ('annuitetsrekning',),
'annuitetsrekninger': ('annuitetsrekning',),
'annuitetstabell': ('annuitetstabell',),
'annuitetstabellen': ('annuitetstabell',),
'annuitetstabellene': ('annuitetstabell',),
'annuitetstabeller': ('annuitetstabell',),
'annua': ('annuum',),
'annuaene': ('annuum',),
'annuum': ('annuum',),
'annuumet': ('annuum',),
'anode': ('anode',),
'anoden': ('anode',),
'anodene': ('anode',),
'anoder': ('anode',),
'anodebatteri': ('anodebatteri',),
'anodebatteria': ('anodebatteri',),
'anodebatteriene': ('anodebatteri',),
'anodebatterier': ('anodebatteri',),
'anodebatteriet': ('anodebatteri',),
'anodespenning': ('anodespenning',),
'anodespenninga': ('anodespenning',),
'anodespenningen': ('anodespenning',),
'anodespenningene': ('anodespenning',),
'anodespenninger': ('anodespenning',),
'anodestrøm': ('anodestrøm',),
'anodestrømmen': ('anodestrøm',),
'anodestrømmene': ('anodestrøm',),
'anodestrømmer': ('anodestrøm',),
'anomali': ('anomali',),
'anomalien': ('anomali',),
'anomaliene': ('anomali',),
'anomalier': ('anomali',),
'anonym': ('anonym',),
'anonyma': ('anonym',),
'anonymene': ('anonym',),
'anonymer': ('anonym',),
'anonymet': ('anonym',),
'anonymitet': ('anonymitet',),
'anonymiteten': ('anonymitet',),
'anonymitetene': ('anonymitet',),
'anonymiteter': ('anonymitet',),
'anorakk': ('anorakk',),
'anorakken': ('anorakk',),
'anorakkene': ('anorakk',),
'anorakker': ('anorakk',),
'anorakkhetta': ('anorakkhette',),
'anorakkhette': ('anorakkhette',),
'anorakkhetten': ('anorakkhette',),
'anorakkhettene': ('anorakkhette',),
'anorakkhetter': ('anorakkhette',),
'anordning': ('anordning',),
'anordninga': ('anordning',),
'anordningen': ('anordning',),
'anordningene': ('anordning',),
'anordninger': ('anordning',),
'anoreksi': ('anoreksi',),
'anoreksien': ('anoreksi',),
'anoreksiene': ('anoreksi',),
'anoreksier': ('anoreksi',),
'anorektiker': ('anorektiker',),
'anorektikere': ('anorektiker',),
'anorektikeren': ('anorektiker',),
'anorektikerer': ('anorektiker',),
'anorektikerne': ('anorektiker',),
'anorexia nervosa': ('anorexia nervosa',),
'anretning': ('anretning',),
'anretninga': ('anretning',),
'anretningen': ('anretning',),
'anretningene': ('anretning',),
'anretninger': ('anretning',),
'anretningsbord': ('anretningsbord',),
'anretningsborda': ('anretningsbord',),
'anretningsbordene': ('anretningsbord',),
'anretningsborder': ('anretningsbord',),
'anretningsbordet': ('anretningsbord',),
'anretningsfat': ('anretningsfat',),
'anretningsfata': ('anretningsfat',),
'anretningsfatene': ('anretningsfat',),
'anretningsfater': ('anretningsfat',),
'anretningsfatet': ('anretningsfat',),
'anretningsrom': ('anretningsrom',),
'anretningsromma': ('anretningsrom',),
'anretningsrommene': ('anretningsrom',),
'anretningsrommet': ('anretningsrom',),
'anrettelse': ('anrettelse',),
'anrettelsen': ('anrettelse',),
'anrettelsene': ('anrettelse',),
'anrettelser': ('anrettelse',),
'anriking': ('anriking',),
'anrikinga': ('anriking',),
'anrikingen': ('anriking',),
'anrikingene': ('anriking',),
'anrikinger': ('anriking',),
'anrikning': ('anrikning',),
'anrikninga': ('anrikning',),
'anrikningen': ('anrikning',),
'anrikningene': ('anrikning',),
'anrikninger': ('anrikning',),
'anrop': ('anrop',),
'anropa': ('anrop',),
'anropene': ('anrop',),
'anropet': ('anrop',),
'ans': ('ans',),
'ansa': ('ans',),
'ansen': ('ans',),
'ansene': ('ans',),
'anser': ('ans',),
'anset': ('ans',),
'ansamling': ('ansamling',),
'ansamlinga': ('ansamling',),
'ansamlingen': ('ansamling',),
'ansamlingene': ('ansamling',),
'ansamlinger': ('ansamling',),
'ansats': ('ansats',),
'ansatsen': ('ansats',),
'ansatsene': ('ansats',),
'ansatser': ('ansats',),
'anseelse': ('anseelse',),
'anseelsen': ('anseelse',),
'anseelsene': ('anseelse',),
'anseelser': ('anseelse',),
'ansettelse': ('ansettelse',),
'ansettelsen': ('ansettelse',),
'ansettelsene': ('ansettelse',),
'ansettelser': ('ansettelse',),
'ansettelsesmyndighet': ('ansettelsesmyndighet',),
'ansettelsesmyndigheta': ('ansettelsesmyndighet',),
'ansettelsesmyndigheten': ('ansettelsesmyndighet',),
'ansettelsesmyndighetene': ('ansettelsesmyndighet',),
'ansettelsesmyndigheter': ('ansettelsesmyndighet',),
'ansettelsesrett': ('ansettelsesrett',),
'ansettelsesretten': ('ansettelsesrett',),
'ansettelsesrettene': ('ansettelsesrett',),
'ansettelsesretter': ('ansettelsesrett',),
'ansettelsesråd': ('ansettelsesråd',),
'ansettelsesråda': ('ansettelsesråd',),
'ansettelsesrådene': ('ansettelsesråd',),
'ansettelsesrådet': ('ansettelsesråd',),
'ansettelsesstopp': ('ansettelsesstopp',),
'ansettelsesstoppa': ('ansettelsesstopp',),
'ansettelsesstoppen': ('ansettelsesstopp',),
'ansettelsesstoppene': ('ansettelsesstopp',),
'ansettelsesstoppet': ('ansettelsesstopp',),
'ansettelsesvilkår': ('ansettelsesvilkår',),
'ansettelsesvilkåra': ('ansettelsesvilkår',),
'ansettelsesvilkårene': ('ansettelsesvilkår',),
'ansettelsesvilkåret': ('ansettelsesvilkår',),
'ansiennitet': ('ansiennitet',),
'ansienniteten': ('ansiennitet',),
'ansiennitetene': ('ansiennitet',),
'ansienniteter': ('ansiennitet',),
'ansikt': ('ansikt',),
'ansikta': ('ansikt',),
'ansiktene': ('ansikt',),
'ansikter': ('ansikt',),
'ansiktet': ('ansikt',),
'ansiktsbehandling': ('ansiktsbehandling',),
'ansiktsbehandlinga': ('ansiktsbehandling',),
'ansiktsbehandlingen': ('ansiktsbehandling',),
'ansiktsbehandlingene': ('ansiktsbehandling',),
'ansiktsbehandlinger': ('ansiktsbehandling',),
'ansiktsdrag': ('ansiktsdrag',),
'ansiktsdraga': ('ansiktsdrag',),
'ansiktsdragene': ('ansiktsdrag',),
'ansiktsdraget': ('ansiktsdrag',),
'ansiktsfarge': ('ansiktsfarge',),
'ansiktsfargen': ('ansiktsfarge',),
'ansiktsfargene': ('ansiktsfarge',),
'ansiktsfarger': ('ansiktsfarge',),
'ansiktsform': ('ansiktsform',),
'ansiktsforma': ('ansiktsform',),
'ansiktsformen': ('ansiktsform',),
'ansiktsformene': ('ansiktsform',),
'ansiktsformer': ('ansiktsform',),
'ansiktsløftning': ('ansiktsløftning',),
'ansiktsløftninga': ('ansiktsløftning',),
'ansiktsløftningen': ('ansiktsløftning',),
'ansiktsløftningene': ('ansiktsløftning',),
'ansiktsløftninger': ('ansiktsløftning',),
'ansiktsmaska': ('ansiktsmaske',),
'ansiktsmaske': ('ansiktsmaske',),
'ansiktsmasken': ('ansiktsmaske',),
'ansiktsmaskene': ('ansiktsmaske',),
'ansiktsmasker': ('ansiktsmaske',),
'ansiktsmassasje': ('ansiktsmassasje',),
'ansiktsmassasjen': ('ansiktsmassasje',),
'ansiktsmassasjene': ('ansiktsmassasje',),
'ansiktsmassasjer': ('ansiktsmassasje',),
'ansiktspleia': ('ansiktspleie',),
'ansiktspleie': ('ansiktspleie',),
'ansiktspleien': ('ansiktspleie',),
'ansiktspleiene': ('ansiktspleie',),
'ansiktspleier': ('ansiktspleie',),
'ansiktsprofil': ('ansiktsprofil',),
'ansiktsprofilen': ('ansiktsprofil',),
'ansiktsprofilene': ('ansiktsprofil',),
'ansiktsprofiler': ('ansiktsprofil',),
'ansiktstrekk': ('ansiktstrekk',),
'ansiktstrekka': ('ansiktstrekk',),
'ansiktstrekkene': ('ansiktstrekk',),
'ansiktstrekket': ('ansiktstrekk',),
'ansiktsuttrykk': ('ansiktsuttrykk',),
'ansiktsuttrykka': ('ansiktsuttrykk',),
'ansiktsuttrykkene': ('ansiktsuttrykk',),
'ansiktsuttrykket': ('ansiktsuttrykk',),
'ansjos': ('ansjos',),
'ansjosen': ('ansjos',),
'ansjosene': ('ansjos',),
'ansjoser': ('ansjos',),
'ansjosboks': ('ansjosboks',),
'ansjosboksen': ('ansjosboks',),
'ansjosboksene': ('ansjosboks',),
'ansjosbokser': ('ansjosboks',),
'ansjosbrisling': ('ansjosbrisling',),
'ansjosbrislingen': ('ansjosbrisling',),
'ansjosbrislingene': ('ansjosbrisling',),
'ansjosbrislinger': ('ansjosbrisling',),
'ansjosfilet': ('ansjosfilet',),
'ansjosfileten': ('ansjosfilet',),
'ansjosfiletene': ('ansjosfilet',),
'ansjosfileter': ('ansjosfilet',),
'anskaffelse': ('anskaffelse',),
'anskaffelsen': ('anskaffelse',),
'anskaffelsene': ('anskaffelse',),
'anskaffelser': ('anskaffelse',),
'anskaffelsesomkostning': ('anskaffelsesomkostning',),
'anskaffelsesomkostninga': ('anskaffelsesomkostning',),
'anskaffelsesomkostningen': ('anskaffelsesomkostning',),
'anskaffelsesomkostningene': ('anskaffelsesomkostning',),
'anskaffelsesomkostninger': ('anskaffelsesomkostning',),
'anskaffelsespris': ('anskaffelsespris',),
'anskaffelsesprisen': ('anskaffelsespris',),
'anskaffelsesprisene': ('anskaffelsespris',),
'anskaffelsespriser': ('anskaffelsespris',),
'anskaffelsesverdi': ('anskaffelsesverdi',),
'anskaffelsesverdien': ('anskaffelsesverdi',),
'anskaffelsesverdiene': ('anskaffelsesverdi',),
'anskaffelsesverdier': ('anskaffelsesverdi',),
'anskott': ('anskott',),
'anskotta': ('anskott',),
'anskottene': ('anskott',),
'anskottet': ('anskott',),
'anskrik': ('anskrik',),
'anskrika': ('anskrik',),
'anskrikene': ('anskrik',),
'anskriket': ('anskrik',),
'anskudd': ('anskudd',),
'anskudda': ('anskudd',),
'anskuddene': ('anskudd',),
'anskuddet': ('anskudd',),
'anskuelse': ('anskuelse',),
'anskuelsen': ('anskuelse',),
'anskuelsene': ('anskuelse',),
'anskuelser': ('anskuelse',),
'anskuelsesevna': ('anskuelsesevne',),
'anskuelsesevne': ('anskuelsesevne',),
'anskuelsesevnen': ('anskuelsesevne',),
'anskuelsesevnene': ('anskuelsesevne',),
'anskuelsesevner': ('anskuelsesevne',),
'anskuelsesform': ('anskuelsesform',),
'anskuelsesforma': ('anskuelsesform',),
'anskuelsesformen': ('anskuelsesform',),
'anskuelsesformene': ('anskuelsesform',),
'anskuelsesformer': ('anskuelsesform',),
'anskuelsesmåte': ('anskuelsesmåte',),
'anskuelsesmåten': ('anskuelsesmåte',),
'anskuelsesmåtene': ('anskuelsesmåte',),
'anskuelsesmåter': ('anskuelsesmåte',),
'anskuelsesundervisning': ('anskuelsesundervisning',),
'anskuelsesundervisninga': ('anskuelsesundervisning',),
'anskuelsesundervisningen': ('anskuelsesundervisning',),
'anskuelsesundervisningene': ('anskuelsesundervisning',),
'anskuelsesundervisninger': ('anskuelsesundervisning',),
'anslag': ('anslag',),
'anslaga': ('anslag',),
'anslagene': ('anslag',),
'anslaget': ('anslag',),
'anslagshastighet': ('anslagshastighet',),
'anslagshastigheta': ('anslagshastighet',),
'anslagshastigheten': ('anslagshastighet',),
'anslagshastighetene': ('anslagshastighet',),
'anslagshastigheter': ('anslagshastighet',),
'anslagskraft': ('anslagskraft',),
'anslagskrafta': ('anslagskraft',),
'anslagskraften': ('anslagskraft',),
'anslagskreftene': ('anslagskraft',),
'anslagskrefter': ('anslagskraft',),
'anspennelse': ('anspennelse',),
'anspennelsen': ('anspennelse',),
'anspennelsene': ('anspennelse',),
'anspennelser': ('anspennelse',),
'anspenthet': ('anspenthet',),
'anspentheta': ('anspenthet',),
'anspentheten': ('anspenthet',),
'anspenthetene': ('anspenthet',),
'anspentheter': ('anspenthet',),
'anstalt': ('anstalt',),
'anstalten': ('anstalt',),
'anstaltene': ('anstalt',),
'anstalter': ('anstalt',),
'anstalthusholdning': ('anstalthusholdning',),
'anstalthusholdninga': ('anstalthusholdning',),
'anstalthusholdningen': ('anstalthusholdning',),
'anstalthusholdningene': ('anstalthusholdning',),
'anstalthusholdninger': ('anstalthusholdning',),
'anstaltmaker': ('anstaltmaker',),
'anstaltmakere': ('anstaltmaker',),
'anstaltmakeren': ('anstaltmaker',),
'anstaltmakerer': ('anstaltmaker',),
'anstaltmakerne': ('anstaltmaker',),
'anstaltmakeri': ('anstaltmakeri',),
'anstaltmakeria': ('anstaltmakeri',),
'anstaltmakeriene': ('anstaltmakeri',),
'anstaltmakerier': ('anstaltmakeri',),
'anstaltmakeriet': ('anstaltmakeri',),
'anstand': ('anstand',),
'anstanden': ('anstand',),
'anstandene': ('anstand',),
'anstander': ('anstand',),
'anstendighet': ('anstendighet',),
'anstendigheta': ('anstendighet',),
'anstendigheten': ('anstendighet',),
'anstendighetene': ('anstendighet',),
'anstendigheter': ('anstendighet',),
'anstendighetsfølelse': ('anstendighetsfølelse',),
'anstendighetsfølelsen': ('anstendighetsfølelse',),
'anstendighetsfølelsene': ('anstendighetsfølelse',),
'anstendighetsfølelser': ('anstendighetsfølelse',),
'anstendighetskjensla': ('anstendighetskjensle',),
'anstendighetskjensle': ('anstendighetskjensle',),
'anstendighetskjenslen': ('anstendighetskjensle',),
'anstendighetskjenslene': ('anstendighetskjensle',),
'anstendighetskjensler': ('anstendighetskjensle',),
'anstrengelse': ('anstrengelse',),
'anstrengelsen': ('anstrengelse',),
'anstrengelsene': ('anstrengelse',),
'anstrengelser': ('anstrengelse',),
'anstrøk': ('anstrøk',),
'anstrøka': ('anstrøk',),
'anstrøkene': ('anstrøk',),
'anstrøket': ('anstrøk',),
'anstøt': ('anstøt',),
'anstøta': ('anstøt',),
'anstøtene': ('anstøt',),
'anstøtet': ('anstøt',),
'anstøtsstein': ('anstøtsstein',),
'anstøtssteinen': ('anstøtsstein',),
'anstøtssteinene': ('anstøtsstein',),
'anstøtssteiner': ('anstøtsstein',),
'ansvar': ('ansvar',),
'ansvara': ('ansvar',),
'ansvarene': ('ansvar',),
'ansvaret': ('ansvar',),
'ansvarsforhold': ('ansvarsforhold',),
'ansvarsforholda': ('ansvarsforhold',),
'ansvarsforholdene': ('ansvarsforhold',),
'ansvarsforholdet': ('ansvarsforhold',),
'ansvarsforsikring': ('ansvarsforsikring',),
'ansvarsforsikringa': ('ansvarsforsikring',),
'ansvarsforsikringen': ('ansvarsforsikring',),
'ansvarsforsikringene': ('ansvarsforsikring',),
'ansvarsforsikringer': ('ansvarsforsikring',),
'ansvarsfølelse': ('ansvarsfølelse',),
'ansvarsfølelsen': ('ansvarsfølelse',),
'ansvarsfølelsene': ('ansvarsfølelse',),
'ansvarsfølelser': ('ansvarsfølelse',),
'ansvarsområda': ('ansvarsområde',),
'ansvarsområde': ('ansvarsområde',),
'ansvarsområdene': ('ansvarsområde',),
'ansvarsområder': ('ansvarsområde',),
'ansvarsområdet': ('ansvarsområde',),
'ansøker': ('ansøker',),
'ansøkere': ('ansøker',),
'ansøkeren': ('ansøker',),
'ansøkerer': ('ansøker',),
'ansøkerne': ('ansøker',),
'ansøkning': ('ansøkning',),
'ansøkninga': ('ansøkning',),
'ansøkningen': ('ansøkning',),
'ansøkningene': ('ansøkning',),
'ansøkninger': ('ansøkning',),
'ansøkningsskjema': ('ansøkningsskjema',),
'ansøkningsskjemaene': ('ansøkningsskjema',),
'ansøkningsskjemaer': ('ansøkningsskjema',),
'ansøkningsskjemaet': ('ansøkningsskjema',),
'antabus': ('antabus',),
'antabusen': ('antabus',),
'antabusene': ('antabus',),
'antabuser': ('antabus',),
'antabuskur': ('antabuskur',),
'antabuskuren': ('antabuskur',),
'antabuskurene': ('antabuskur',),
'antabuskurer': ('antabuskur',),
'antabuspilla': ('antabuspille',),
'antabuspille': ('antabuspille',),
'antabuspillen': ('antabuspille',),
'antabuspillene': ('antabuspille',),
'antabuspiller': ('antabuspille',),
'antabustablett': ('antabustablett',),
'antabustabletten': ('antabustablett',),
'antabustablettene': ('antabustablett',),
'antabustabletter': ('antabustablett',),
'antagonisme': ('antagonisme',),
'antagonismen': ('antagonisme',),
'antagonismene': ('antagonisme',),
'antagonismer': ('antagonisme',),
'antagonist': ('antagonist',),
'antagonisten': ('antagonist',),
'antagonistene': ('antagonist',),
'antagonister': ('antagonist',),
'antakelse': ('antakelse',),
'antakelsen': ('antakelse',),
'antakelsene': ('antakelse',),
'antakelser': ('antakelse',),
'antall': ('antall',),
'antalla': ('antall',),
'antallene': ('antall',),
'antallet': ('antall',),
'antegnelse': ('antegnelse',),
'antegnelsen': ('antegnelse',),
'antegnelsene': ('antegnelse',),
'antegnelser': ('antegnelse',),
'antegning': ('antegning',),
'antegninga': ('antegning',),
'antegningen': ('antegning',),
'antegningene': ('antegning',),
'antegninger': ('antegning',),
'antemensala': ('antemensale',),
'antemensale': ('antemensale',),
'antemensalene': ('antemensale',),
'antemensaler': ('antemensale',),
'antemensalet': ('antemensale',),
'antenna': ('antenne',),
'antenne': ('antenne',),
'antennen': ('antenne',),
'antennene': ('antenne',),
'antenner': ('antenne',),
'antennekobling': ('antennekobling',),
'antennekoblinga': ('antennekobling',),
'antennekoblingen': ('antennekobling',),
'antennekoblingene': ('antennekobling',),
'antennekoblinger': ('antennekobling',),
'antennekopling': ('antennekopling',),
'antennekoplinga': ('antennekopling',),
'antennekoplingen': ('antennekopling',),
'antennekoplingene': ('antennekopling',),
'antennekoplinger': ('antennekopling',),
'antennekrets': ('antennekrets',),
'antennekretsen': ('antennekrets',),
'antennekretsene': ('antennekrets',),
'antennekretser': ('antennekrets',),
'antenneledning': ('antenneledning',),
'antenneledninga': ('antenneledning',),
'antenneledningen': ('antenneledning',),
'antenneledningene': ('antenneledning',),
'antenneledninger': ('antenneledning',),
'antennelse': ('antennelse',),
'antennelsen': ('antennelse',),
'antennelsene': ('antennelse',),
'antennelser': ('antennelse',),
'antennelsestemperatur': ('antennelsestemperatur',),
'antennelsestemperaturen': ('antennelsestemperatur',),
'antennelsestemperaturene': ('antennelsestemperatur',),
'antennelsestemperaturer': ('antennelsestemperatur',),
'antennestøy': ('antennestøy',),
'antennestøyen': ('antennestøy',),
'antennestøyene': ('antennestøy',),
'antennestøyer': ('antennestøy',),
'antenneuttak': ('antenneuttak',),
'antenneuttaka': ('antenneuttak',),
'antenneuttakene': ('antenneuttak',),
'antenneuttaket': ('antenneuttak',),
'antependia': ('antependium',),
'antependiene': ('antependium',),
'antependier': ('antependium',),
'antependiet': ('antependium',),
'antependium': ('antependium',),
'antesipasjon': ('antesipasjon',),
'antesipasjonen': ('antesipasjon',),
'antesipasjonene': ('antesipasjon',),
'antesipasjoner': ('antesipasjon',),
'antibiotika': ('antibiotikum',),
'antibiotikaene': ('antibiotikum',),
'antibiotikum': ('antibiotikum',),
'antibiotikumet': ('antibiotikum',),
'antifebrin': ('antifebrin',),
'antifebrina': ('antifebrin',),
'antifebrinene': ('antifebrin',),
'antifebrinet': ('antifebrin',),
'antigen': ('antigen',),
'antigena': ('antigen',),
'antigenene': ('antigen',),
'antigener': ('antigen',),
'antigenet': ('antigen',),
'antiguaner': ('antiguaner',),
'antiguanere': ('antiguaner',),
'antiguaneren': ('antiguaner',),
'antiguanerer': ('antiguaner',),
'antiguanerne': ('antiguaner',),
'antihelt': ('antihelt',),
'antihelten': ('antihelt',),
'antiheltene': ('antihelt',),
'antihelter': ('antihelt',),
'antiimperialisme': ('antiimperialisme',),
'antiimperialismen': ('antiimperialisme',),
'antiimperialismene': ('antiimperialisme',),
'antiimperialismer': ('antiimperialisme',),
'antikk': ('antikk',),
'antikken': ('antikk',),
'antikkene': ('antikk',),
'antikker': ('antikk',),
'antikksamling': ('antikksamling',),
'antikksamlinga': ('antikksamling',),
'antikksamlingen': ('antikksamling',),
'antikksamlingene': ('antikksamling',),
'antikksamlinger': ('antikksamling',),
'antiklimaks': ('antiklimaks',),
'antiklimaksa': ('antiklimaks',),
'antiklimaksen': ('antiklimaks',),
'antiklimaksene': ('antiklimaks',),
'antiklimakser': ('antiklimaks',),
'antiklimakset': ('antiklimaks',),
'antikommunisme': ('antikommunisme',),
'antikommunismen': ('antikommunisme',),
'antikommunismene': ('antikommunisme',),
'antikommunismer': ('antikommunisme',),
'antikommunist': ('antikommunist',),
'antikommunisten': ('antikommunist',),
'antikommunistene': ('antikommunist',),
'antikommunister': ('antikommunist',),
'antikonsepsjon': ('antikonsepsjon',),
'antikonsepsjonen': ('antikonsepsjon',),
'antikonsepsjonene': ('antikonsepsjon',),
'antikonsepsjoner': ('antikonsepsjon',),
'antikrist': ('antikrist',),
'antikristen': ('antikrist',),
'antikristene': ('antikrist',),
'antikrister': ('antikrist',),
'antikva': ('antikva',),
'antikvaen': ('antikva',),
'antikvaene': ('antikva',),
'antikvaer': ('antikva',),
'antikvar': ('antikvar',),
'antikvaren': ('antikvar',),
'antikvarene': ('antikvar',),
'antikvarer': ('antikvar',),
'antikvarbokhandel': ('antikvarbokhandel',),
'antikvarbokhandelen': ('antikvarbokhandel',),
'antikvarbokhandlene': ('antikvarbokhandel',),
'antikvarbokhandler': ('antikvarbokhandel',),
'antikvarbokhandler': ('antikvarbokhandler',),
'antikvarbokhandlere': ('antikvarbokhandler',),
'antikvarbokhandleren': ('antikvarbokhandler',),
'antikvarbokhandlerer': ('antikvarbokhandler',),
'antikvarbokhandlerne': ('antikvarbokhandler',),
'antikvariat': ('antikvariat',),
'antikvariata': ('antikvariat',),
'antikvariatene': ('antikvariat',),
'antikvariater': ('antikvariat',),
'antikvariatet': ('antikvariat',),
'antikvitet': ('antikvitet',),
'antikviteten': ('antikvitet',),
'antikvitetene': ('antikvitet',),
'antikviteter': ('antikvitet',),
'antikvitetshandel': ('antikvitetshandel',),
'antikvitetshandelen': ('antikvitetshandel',),
'antikvitetshandlene': ('antikvitetshandel',),
'antikvitetshandler': ('antikvitetshandel',),
'antikvitetshandler': ('antikvitetshandler',),
'antikvitetshandlere': ('antikvitetshandler',),
'antikvitetshandleren': ('antikvitetshandler',),
'antikvitetshandlerer': ('antikvitetshandler',),
'antikvitetshandlerne': ('antikvitetshandler',),
'antikvitetssamler': ('antikvitetssamler',),
'antikvitetssamlere': ('antikvitetssamler',),
'antikvitetssamleren': ('antikvitetssamler',),
'antikvitetssamlerer': ('antikvitetssamler',),
'antikvitetssamlerne': ('antikvitetssamler',),
'antikvitetssamling': ('antikvitetssamling',),
'antikvitetssamlinga': ('antikvitetssamling',),
'antikvitetssamlingen': ('antikvitetssamling',),
'antikvitetssamlingene': ('antikvitetssamling',),
'antikvitetssamlinger': ('antikvitetssamling',),
'antilogaritme': ('antilogaritme',),
'antilogaritmen': ('antilogaritme',),
'antilogaritmene': ('antilogaritme',),
'antilogaritmer': ('antilogaritme',),
'antilopa': ('antilope',),
'antilope': ('antilope',),
'antilopen': ('antilope',),
'antilopene': ('antilope',),
'antiloper': ('antilope',),
'antiluftskyts': ('antiluftskyts',),
'antiluftskytsa': ('antiluftskyts',),
'antiluftskytsene': ('antiluftskyts',),
'antiluftskytset': ('antiluftskyts',),
'antimakassar': ('antimakassar',),
'antimakassaren': ('antimakassar',),
'antimakassarene': ('antimakassar',),
'antimakassarer': ('antimakassar',),
'antimilitarisme': ('antimilitarisme',),
'antimilitarismen': ('antimilitarisme',),
'antimilitarismene': ('antimilitarisme',),
'antimilitarismer': ('antimilitarisme',),
'antimilitarist': ('antimilitarist',),
'antimilitaristen': ('antimilitarist',),
'antimilitaristene': ('antimilitarist',),
'antimilitarister': ('antimilitarist',),
'antimon': ('antimon',),
'antimona': ('antimon',),
'antimonene': ('antimon',),
'antimonet': ('antimon',),
'antimonblende': ('antimonblende',),
'antimonblenden': ('antimonblende',),
'antimonblendene': ('antimonblende',),
'antimonblender': ('antimonblende',),
'antimonglans': ('antimonglans',),
'antimonglansen': ('antimonglans',),
'antimonglansene': ('antimonglans',),
'antimonglanser': ('antimonglans',),
'antinomi': ('antinomi',),
'antinomien': ('antinomi',),
'antinomiene': ('antinomi',),
'antinomier': ('antinomi',),
'antipartikkel': ('antipartikkel',),
'antipartikkelen': ('antipartikkel',),
'antipartiklene': ('antipartikkel',),
'antipartikler': ('antipartikkel',),
'antipassat': ('antipassat',),
'antipassaten': ('antipassat',),
'antipassatene': ('antipassat',),
'antipassater': ('antipassat',),
'antipati': ('antipati',),
'antipatien': ('antipati',),
'antipatiene': ('antipati',),
'antipatier': ('antipati',),
'antiperspirant': ('antiperspirant',),
'antiperspiranten': ('antiperspirant',),
'antiperspirantene': ('antiperspirant',),
'antiperspiranter': ('antiperspirant',),
'antipode': ('antipode',),
'antipoden': ('antipode',),
'antipodene': ('antipode',),
'antipoder': ('antipode',),
'antipyrin': ('antipyrin',),
'antipyrina': ('antipyrin',),
'antipyrinen': ('antipyrin',),
'antipyrinene': ('antipyrin',),
'antipyriner': ('antipyrin',),
'antipyrinet': ('antipyrin',),
'antirakettvåpen': ('antirakettvåpen',),
'antirakettvåpenet': ('antirakettvåpen',),
'antirakettvåpna': ('antirakettvåpen',),
'antirakettvåpnene': ('antirakettvåpen',),
'antisemitt': ('antisemitt',),
'antisemitten': ('antisemitt',),
'antisemittene': ('antisemitt',),
'antisemitter': ('antisemitt',),
'antisemittisme': ('antisemittisme',),
'antisemittismen': ('antisemittisme',),
'antisemittismene': ('antisemittisme',),
'antisemittismer': ('antisemittisme',),
'antiseptikk': ('antiseptikk',),
'antiseptikken': ('antiseptikk',),
'antiseptikkene': ('antiseptikk',),
'antiseptikker': ('antiseptikk',),
'antiseptika': ('antiseptikum',),
'antiseptikaene': ('antiseptikum',),
'antiseptikum': ('antiseptikum',),
'antiseptikumet': ('antiseptikum',),
'antisera': ('antiserum',),
'antiseraene': ('antiserum',),
'antiserum': ('antiserum',),
'antiseruma': ('antiserum',),
'antiserumene': ('antiserum',),
'antiserumer': ('antiserum',),
'antiserumet': ('antiserum',),
'antisionisme': ('antisionisme',),
'antisionismen': ('antisionisme',),
'antisionismene': ('antisionisme',),
'antisionismer': ('antisionisme',),
'antisionist': ('antisionist',),
'antisionisten': ('antisionist',),
'antisionistene': ('antisionist',),
'antisionister': ('antisionist',),
'antistoff': ('antistoff',),
'antistoffa': ('antistoff',),
'antistoffene': ('antistoff',),
'antistoffer': ('antistoff',),
'antistoffet': ('antistoff',),
'antitankvåpen': ('antitankvåpen',),
'antitankvåpenet': ('antitankvåpen',),
'antitankvåpna': ('antitankvåpen',),
'antitankvåpnene': ('antitankvåpen',),
'antitese': ('antitese',),
'antitesen': ('antitese',),
'antitesene': ('antitese',),
'antiteser': ('antitese',),
'antitoksin': ('antitoksin',),
'antitoksina': ('antitoksin',),
'antitoksinene': ('antitoksin',),
'antitoksiner': ('antitoksin',),
'antitoksinet': ('antitoksin',),
'antiubåtkrig': ('antiubåtkrig',),
'antiubåtkrigen': ('antiubåtkrig',),
'antiubåtkrigene': ('antiubåtkrig',),
'antiubåtkriger': ('antiubåtkrig',),
'antiubåtvåpen': ('antiubåtvåpen',),
'antiubåtvåpenet': ('antiubåtvåpen',),
'antiubåtvåpna': ('antiubåtvåpen',),
'antiubåtvåpnene': ('antiubåtvåpen',),
'antiviviseksjonist': ('antiviviseksjonist',),
'antiviviseksjonisten': ('antiviviseksjonist',),
'antiviviseksjonistene': ('antiviviseksjonist',),
'antiviviseksjonister': ('antiviviseksjonist',),
'antocyan': ('antocyan',),
'antocyana': ('antocyan',),
'antocyanene': ('antocyan',),
'antocyaner': ('antocyan',),
'antocyanet': ('antocyan',),
'antologi': ('antologi',),
'antologien': ('antologi',),
'antologiene': ('antologi',),
'antologier': ('antologi',),
'antoniuseld': ('antoniuseld',),
'antoniuselden': ('antoniuseld',),
'antoniuseldene': ('antoniuseld',),
'antoniuselder': ('antoniuseld',),
'antoniusild': ('antoniusild',),
'antoniusilden': ('antoniusild',),
'antoniusildene': ('antoniusild',),
'antoniusilder': ('antoniusild',),
'antoniuskors': ('antoniuskors',),
'antoniuskorsa': ('antoniuskors',),
'antoniuskorsene': ('antoniuskors',),
'antoniuskorset': ('antoniuskors',),
'antonsmess': ('antonsmess',),
'antonsmess': ('antonsmess',),
'antonsmesse': ('antonsmesse',),
'antonym': ('antonym',),
'antonyma': ('antonym',),
'antonymene': ('antonym',),
'antonymer': ('antonym',),
'antonymet': ('antonym',),
'antonymi': ('antonymi',),
'antonymien': ('antonymi',),
'antonymiene': ('antonymi',),
'antonymier': ('antonymi',),
'antrasitt': ('antrasitt',),
'antrasitten': ('antrasitt',),
'antrasittene': ('antrasitt',),
'antrasitter': ('antrasitt',),
'antrasittkol': ('antrasittkol',),
'antrasittkola': ('antrasittkol',),
'antrasittkolene': ('antrasittkol',),
'antrasittkolet': ('antrasittkol',),
'antrasittkull': ('antrasittkull',),
'antrasittkulla': ('antrasittkull',),
'antrasittkullene': ('antrasittkull',),
'antrasittkullet': ('antrasittkull',),
'antrekk': ('antrekk',),
'antrekka': ('antrekk',),
'antrekkene': ('antrekk',),
'antrekket': ('antrekk',),
'antropofag': ('antropofag',),
'antropofagen': ('antropofag',),
'antropofagene': ('antropofag',),
'antropofager': ('antropofag',),
'antropofobi': ('antropofobi',),
'antropofobien': ('antropofobi',),
'antropofobiene': ('antropofobi',),
'antropofobier': ('antropofobi',),
'antropolog': ('antropolog',),
'antropologen': ('antropolog',),
'antropologene': ('antropolog',),
'antropologer': ('antropolog',),
'antropologi': ('antropologi',),
'antropologien': ('antropologi',),
'antropologiene': ('antropologi',),
'antropologier': ('antropologi',),
'antropomorfisme': ('antropomorfisme',),
'antropomorfismen': ('antropomorfisme',),
'antropomorfismene': ('antropomorfisme',),
'antropomorfismer': ('antropomorfisme',),
'antroposof': ('antroposof',),
'antroposofen': ('antroposof',),
'antroposofene': ('antroposof',),
'antroposofer': ('antroposof',),
'antroposofi': ('antroposofi',),
'antroposofien': ('antroposofi',),
'antroposofiene': ('antroposofi',),
'antroposofier': ('antroposofi',),
'antydning': ('antydning',),
'antydninga': ('antydning',),
'antydningen': ('antydning',),
'antydningene': ('antydning',),
'antydninger': ('antydning',),
'anus': ('anus',),
'anusen': ('anus',),
'anusene': ('anus',),
'anuser': ('anus',),
'anuskop': ('anuskop',),
'anuskopa': ('anuskop',),
'anuskopene': ('anuskop',),
'anuskoper': ('anuskop',),
'anuskopet': ('anuskop',),
'anvendelse': ('anvendelse',),
'anvendelsen': ('anvendelse',),
'anvendelsene': ('anvendelse',),
'anvendelser': ('anvendelse',),
'anvendelsesmulighet': ('anvendelsesmulighet',),
'anvendelsesmuligheta': ('anvendelsesmulighet',),
'anvendelsesmuligheten': ('anvendelsesmulighet',),
'anvendelsesmulighetene': ('anvendelsesmulighet',),
'anvendelsesmuligheter': ('anvendelsesmulighet',),
'anvendelsesområda': ('anvendelsesområde',),
'anvendelsesområde': ('anvendelsesområde',),
'anvendelsesområdene': ('anvendelsesområde',),
'anvendelsesområder': ('anvendelsesområde',),
'anvendelsesområdet': ('anvendelsesområde',),
'anviser': ('anviser',),
'anvisere': ('anviser',),
'anviseren': ('anviser',),
'anviserer': ('anviser',),
'anviserne': ('anviser',),
'anvisning': ('anvisning',),
'anvisninga': ('anvisning',),
'anvisningen': ('anvisning',),
'anvisningene': ('anvisning',),
'anvisninger': ('anvisning',),
'aorta': ('aorta',),
'ap': ('ap',),
'apen': ('ap',),
'apene': ('ap',),
'aper': ('ap',),
'ap': ('ap',),
'apa': ('ap',),
'apene': ('ap',),
'apet': ('ap',),
'apal': ('apal',),
'apalen': ('apal',),
'apalene': ('apal',),
'apaler': ('apal',),
'apanasje': ('apanasje',),
'apanasjen': ('apanasje',),
'apanasjene': ('apanasje',),
'apanasjer': ('apanasje',),
'apartheid': ('apartheid',),
'apartheiden': ('apartheid',),
'apartheidene': ('apartheid',),
'apartheider': ('apartheid',),
'apartheidlov': ('apartheidlov',),
'apartheidloven': ('apartheidlov',),
'apartheidlovene': ('apartheidlov',),
'apartheidlover': ('apartheidlov',),
'apartheidpolitikk': ('apartheidpolitikk',),
'apartheidpolitikken': ('apartheidpolitikk',),
'apartheidpolitikkene': ('apartheidpolitikk',),
'apartheidpolitikker': ('apartheidpolitikk',),
'apartheidstyra': ('apartheidstyre',),
'apartheidstyre': ('apartheidstyre',),
'apartheidstyrene': ('apartheidstyre',),
'apartheidstyrer': ('apartheidstyre',),
'apartheidstyret': ('apartheidstyre',),
'apasje': ('apasje',),
'apasjen': ('apasje',),
'apasjene': ('apasje',),
'apasjer': ('apasje',),
'apasjeindianer': ('apasjeindianer',),
'apasjeindianere': ('apasjeindianer',),
'apasjeindianeren': ('apasjeindianer',),
'apasjeindianerer': ('apasjeindianer',),
'apasjeindianerne': ('apasjeindianer',),
'apati': ('apati',),
'apatien': ('apati',),
'apatiene': ('apati',),
'apatier': ('apati',),
'apatitt': ('apatitt',),
'apatitten': ('apatitt',),
'apatittene': ('apatitt',),
'apatitter': ('apatitt',),
'apatittgruva': ('apatittgruve',),
'apatittgruve': ('apatittgruve',),
'apatittgruven': ('apatittgruve',),
'apatittgruvene': ('apatittgruve',),
'apatittgruver': ('apatittgruve',),
'apa': ('ape',),
'ape': ('ape',),
'apen': ('ape',),
'apene': ('ape',),
'aper': ('ape',),
'apebrød': ('apebrød',),
'apebrøda': ('apebrød',),
'apebrødene': ('apebrød',),
'apebrødet': ('apebrød',),
'apebrødtre': ('apebrødtre',),
'apebrødtrea': ('apebrødtre',),
'apebrødtreet': ('apebrødtre',),
'apebrødtrær': ('apebrødtre',),
'apebrødtrærne': ('apebrødtre',),
'apekatt': ('apekatt',),
'apekatten': ('apekatt',),
'apekattene': ('apekatt',),
'apekatter': ('apekatt',),
'apemenneska': ('apemenneske',),
'apemenneske': ('apemenneske',),
'apemenneskene': ('apemenneske',),
'apemennesker': ('apemenneske',),
'apemennesket': ('apemenneske',),
'aperi': ('aperi',),
'aperia': ('aperi',),
'aperiene': ('aperi',),
'aperier': ('aperi',),
'aperiet': ('aperi',),
'aperitiff': ('aperitiff',),
'aperitiffen': ('aperitiff',),
'aperitiffene': ('aperitiff',),
'aperitiffer': ('aperitiff',),
'apestrek': ('apestrek',),
'apestreken': ('apestrek',),
'apestrekene': ('apestrek',),
'apestreker': ('apestrek',),
'apikal': ('apikal',),
'apikalen': ('apikal',),
'apikalene': ('apikal',),
'apikaler': ('apikal',),
'aplomb': ('aplomb',),
'aplomben': ('aplomb',),
'aplombene': ('aplomb',),
'aplomber': ('aplomb',),
'apoge': ('apoge',),
'apogea': ('apoge',),
'apogeene': ('apoge',),
'apogeet': ('apoge',),
'apogeet': ('apogeum',),
'apogeum': ('apogeum',),
'apogeumet': ('apogeum',),
'apokalypse': ('apokalypse',),
'apokalypsen': ('apokalypse',),
'apokalypsene': ('apokalypse',),
'apokalypser': ('apokalypse',),
'apokope': ('apokope',),
'apokopen': ('apokope',),
'apokopene': ('apokope',),
'apokoper': ('apokope',),
'apokryf': ('apokryf',),
'apokryfen': ('apokryf',),
'apokryfene': ('apokryf',),
'apokryfer': ('apokryf',),
'apollo': ('apollo',),
'apolloen': ('apollo',),
'apolloene': ('apollo',),
'apolloer': ('apollo',),
'apollosommerfugl': ('apollosommerfugl',),
'apollosommerfuglen': ('apollosommerfugl',),
'apollosommerfuglene': ('apollosommerfugl',),
'apollosommerfugler': ('apollosommerfugl',),
'apologet': ('apologet',),
'apologeten': ('apologet',),
'apologetene': ('apologet',),
'apologeter': ('apologet',),
'apologi': ('apologi',),
'apologien': ('apologi',),
'apologiene': ('apologi',),
'apologier': ('apologi',),
'apopleksi': ('apopleksi',),
'apopleksien': ('apopleksi',),
'apopleksiene': ('apopleksi',),
'apopleksier': ('apopleksi',),
'apoplektiker': ('apoplektiker',),
'apoplektikere': ('apoplektiker',),
'apoplektikeren': ('apoplektiker',),
'apoplektikerer': ('apoplektiker',),
'apoplektikerne': ('apoplektiker',),
'aposiopese': ('aposiopese',),
'aposiopesen': ('aposiopese',),
'aposiopesene': ('aposiopese',),
'aposiopeser': ('aposiopese',),
'apostasi': ('apostasi',),
'apostasien': ('apostasi',),
'apostasiene': ('apostasi',),
'apostasier': ('apostasi',),
'apostat': ('apostat',),
'apostaten': ('apostat',),
'apostatene': ('apostat',),
'apostater': ('apostat',),
'apostel': ('apostel',),
'apostelen': ('apostel',),
'apostlene': ('apostel',),
'apostler': ('apostel',),
'apostelbrev': ('apostelbrev',),
'apostelbreva': ('apostelbrev',),
'apostelbrevene': ('apostelbrev',),
'apostelbrever': ('apostelbrev',),
'apostelbrevet': ('apostelbrev',),
'aposteljern': ('aposteljern',),
'aposteljerna': ('aposteljern',),
'aposteljernene': ('aposteljern',),
'aposteljernet': ('aposteljern',),
'apostrof': ('apostrof',),
'apostrofen': ('apostrof',),
'apostrofene': ('apostrof',),
'apostrofer': ('apostrof',),
'apostrofe': ('apostrofe',),
'apostrofen': ('apostrofe',),
'apostrofene': ('apostrofe',),
'apostrofer': ('apostrofe',),
'apostroftegn': ('apostroftegn',),
'apostroftegna': ('apostroftegn',),
'apostroftegnene': ('apostroftegn',),
'apostroftegnet': ('apostroftegn',),
'apotek': ('apotek',),
'apoteka': ('apotek',),
'apotekene': ('apotek',),
'apoteker': ('apotek',),
'apoteket': ('apotek',),
'apoteker': ('apoteker',),
'apotekere': ('apoteker',),
'apotekeren': ('apoteker',),
'apotekerer': ('apoteker',),
'apotekerne': ('apoteker',),
'apotekerlatin': ('apotekerlatin',),
'apotekerlatinen': ('apotekerlatin',),
'apotekerlatinene': ('apotekerlatin',),
'apotekerlatiner': ('apotekerlatin',),
'apotekervekt': ('apotekervekt',),
'apotekervekta': ('apotekervekt',),
'apotekervekten': ('apotekervekt',),
'apotekervektene': ('apotekervekt',),
'apotekervekter': ('apotekervekt',),
'apoteose': ('apoteose',),
'apoteosen': ('apoteose',),
'apoteosene': ('apoteose',),
'apoteoser': ('apoteose',),
'apparat': ('apparat',),
'apparata': ('apparat',),
'apparatene': ('apparat',),
'apparater': ('apparat',),
'apparatet': ('apparat',),
'apparatbord': ('apparatbord',),
'apparatborda': ('apparatbord',),
'apparatbordene': ('apparatbord',),
'apparatborder': ('apparatbord',),
'apparatbordet': ('apparatbord',),
'apparatsamling': ('apparatsamling',),
'apparatsamlinga': ('apparatsamling',),
'apparatsamlingen': ('apparatsamling',),
'apparatsamlingene': ('apparatsamling',),
'apparatsamlinger': ('apparatsamling',),
'apparatsjik': ('apparatsjik',),
'apparatsjiken': ('apparatsjik',),
'apparatsjikene': ('apparatsjik',),
'apparatsjiker': ('apparatsjik',),
'apparattavla': ('apparattavle',),
'apparattavle': ('apparattavle',),
'apparattavlen': ('apparattavle',),
'apparattavlene': ('apparattavle',),
'apparattavler': ('apparattavle',),
'apparatur': ('apparatur',),
'apparaturen': ('apparatur',),
'apparaturene': ('apparatur',),
'apparaturer': ('apparatur',),
'apparisjon': ('apparisjon',),
'apparisjonen': ('apparisjon',),
'apparisjonene': ('apparisjon',),
'apparisjoner': ('apparisjon',),
'appartement': ('appartement',),
'appartementa': ('appartement',),
'appartementene': ('appartement',),
'appartementer': ('appartement',),
'appartementet': ('appartement',),
'appartementshotell': ('appartementshotell',),
'appartementshotella': ('appartementshotell',),
'appartementshotellene': ('appartementshotell',),
'appartementshoteller': ('appartementshotell',),
'appartementshotellet': ('appartementshotell',),
'appartementshus': ('appartementshus',),
'appartementshusa': ('appartementshus',),
'appartementshusene': ('appartementshus',),
'appartementshuset': ('appartementshus',),
'appell': ('appell',),
'appellen': ('appell',),
'appellene': ('appell',),
'appeller': ('appell',),
'appellant': ('appellant',),
'appellanten': ('appellant',),
'appellantene': ('appellant',),
'appellanter': ('appellant',),
'appellativ': ('appellativ',),
'appellativa': ('appellativ',),
'appellativene': ('appellativ',),
'appellativer': ('appellativ',),
'appellativet': ('appellativ',),
'appelldomstol': ('appelldomstol',),
'appelldomstolen': ('appelldomstol',),
'appelldomstolene': ('appelldomstol',),
'appelldomstoler': ('appelldomstol',),
'appellfrist': ('appellfrist',),
'appellfristen': ('appellfrist',),
'appellfristene': ('appellfrist',),
'appellfrister': ('appellfrist',),
'appellinstans': ('appellinstans',),
'appellinstansen': ('appellinstans',),
'appellinstansene': ('appellinstans',),
'appellinstanser': ('appellinstans',),
'appellrett': ('appellrett',),
'appellretten': ('appellrett',),
'appellrettene': ('appellrett',),
'appellretter': ('appellrett',),
'appelsin': ('appelsin',),
'appelsinen': ('appelsin',),
'appelsinene': ('appelsin',),
'appelsiner': ('appelsin',),
'appelsinbåt': ('appelsinbåt',),
'appelsinbåten': ('appelsinbåt',),
'appelsinbåtene': ('appelsinbåt',),
'appelsinbåter': ('appelsinbåt',),
'appelsinfromasj': ('appelsinfromasj',),
'appelsinfromasjen': ('appelsinfromasj',),
'appelsinfromasjene': ('appelsinfromasj',),
'appelsinfromasjer': ('appelsinfromasj',),
'appelsinjuice': ('appelsinjuice',),
'appelsinjuicen': ('appelsinjuice',),
'appelsinjuicene': ('appelsinjuice',),
'appelsinjuicer': ('appelsinjuice',),
'appelsinjus': ('appelsinjus',),
'appelsinjusen': ('appelsinjus',),
'appelsinjusene': ('appelsinjus',),
'appelsinjuser': ('appelsinjus',),
'appelsinmarmelade': ('appelsinmarmelade',),
'appelsinmarmeladen': ('appelsinmarmelade',),
'appelsinmarmeladene': ('appelsinmarmelade',),
'appelsinmarmelader': ('appelsinmarmelade',),
'appelsinsaft': ('appelsinsaft',),
'appelsinsafta': ('appelsinsaft',),
'appelsinsaften': ('appelsinsaft',),
'appelsinsaftene': ('appelsinsaft',),
'appelsinsafter': ('appelsinsaft',),
'appelsinskal': ('appelsinskal',),
'appelsinskala': ('appelsinskal',),
'appelsinskalene': ('appelsinskal',),
'appelsinskalet': ('appelsinskal',),
'appelsinskall': ('appelsinskall',),
'appelsinskalla': ('appelsinskall',),
'appelsinskallene': ('appelsinskall',),
'appelsinskallet': ('appelsinskall',),
'appendiks': ('appendiks',),
'appendiksen': ('appendiks',),
'appendiksene': ('appendiks',),
'appendikser': ('appendiks',),
'appendiks': ('appendiks',),
'appendiksa': ('appendiks',),
'appendiksene': ('appendiks',),
'appendikser': ('appendiks',),
'appendikset': ('appendiks',),
'appetitt': ('appetitt',),
'appetitten': ('appetitt',),
'appetittene': ('appetitt',),
'appetitter': ('appetitt',),
'appetittvekker': ('appetittvekker',),
'appetittvekkere': ('appetittvekker',),
'appetittvekkeren': ('appetittvekker',),
'appetittvekkerer': ('appetittvekker',),
'appetittvekkerne': ('appetittvekker',),
'applaus': ('applaus',),
'applausen': ('applaus',),
'applausene': ('applaus',),
'applauser': ('applaus',),
'applikasjon': ('applikasjon',),
'applikasjonen': ('applikasjon',),
'applikasjonene': ('applikasjon',),
'applikasjoner': ('applikasjon',),
'applikasjonsarbeid': ('applikasjonsarbeid',),
'applikasjonsarbeida': ('applikasjonsarbeid',),
'applikasjonsarbeidene': ('applikasjonsarbeid',),
'applikasjonsarbeider': ('applikasjonsarbeid',),
'applikasjonsarbeidet': ('applikasjonsarbeid',),
'applikasjonsområda': ('applikasjonsområde',),
'applikasjonsområde': ('applikasjonsområde',),
'applikasjonsområdene': ('applikasjonsområde',),
'applikasjonsområder': ('applikasjonsområde',),
'applikasjonsområdet': ('applikasjonsområde',),
'applikasjonssøm': ('applikasjonssøm',),
'applikasjonssømmen': ('applikasjonssøm',),
'applikasjonssømmene': ('applikasjonssøm',),
'applikasjonssømmer': ('applikasjonssøm',),
'applikatur': ('applikatur',),
'applikaturen': ('applikatur',),
'applikaturene': ('applikatur',),
'applikaturer': ('applikatur',),
'apport': ('apport',),
'apporten': ('apport',),
'apportene': ('apport',),
'apporter': ('apport',),
'apposisjon': ('apposisjon',),
'apposisjonen': ('apposisjon',),
'apposisjonene': ('apposisjon',),
'apposisjoner': ('apposisjon',),
'appretur': ('appretur',),
'appreturen': ('appretur',),
'appreturene': ('appretur',),
'appreturer': ('appretur',),
'appreturmaskin': ('appreturmaskin',),
'appreturmaskina': ('appreturmaskin',),
'appreturmaskinen': ('appreturmaskin',),
'appreturmaskinene': ('appreturmaskin',),
'appreturmaskiner': ('appreturmaskin',),
'approbasjon': ('approbasjon',),
'approbasjonen': ('approbasjon',),
'approbasjonene': ('approbasjon',),
'approbasjoner': ('approbasjon',),
'approbering': ('approbering',),
'approberinga': ('approbering',),
'approberingen': ('approbering',),
'approberingene': ('approbering',),
'approberinger': ('approbering',),
'approksimasjon': ('approksimasjon',),
'approksimasjonen': ('approksimasjon',),
'approksimasjonene': ('approksimasjon',),
'approksimasjoner': ('approksimasjon',),
'appropriasjon': ('appropriasjon',),
'appropriasjonen': ('appropriasjon',),
'appropriasjonene': ('appropriasjon',),
'appropriasjoner': ('appropriasjon',),
'aprikos': ('aprikos',),
'aprikosen': ('aprikos',),
'aprikosene': ('aprikos',),
'aprikoser': ('aprikos',),
'aprikosgraut': ('aprikosgraut',),
'aprikosgrauten': ('aprikosgraut',),
'aprikosgrautene': ('aprikosgraut',),
'aprikosgrauter': ('aprikosgraut',),
'aprikosgrøt': ('aprikosgrøt',),
'aprikosgrøten': ('aprikosgrøt',),
'aprikosgrøtene': ('aprikosgrøt',),
'aprikosgrøter': ('aprikosgrøt',),
'aprikoskompott': ('aprikoskompott',),
'aprikoskompotten': ('aprikoskompott',),
'aprikoskompottene': ('aprikoskompott',),
'aprikoskompotter': ('aprikoskompott',),
'aprikosmarmelade': ('aprikosmarmelade',),
'aprikosmarmeladen': ('aprikosmarmelade',),
'aprikosmarmeladene': ('aprikosmarmelade',),
'aprikosmarmelader': ('aprikosmarmelade',),
'aprikossyltetøy': ('aprikossyltetøy',),
'aprikossyltetøya': ('aprikossyltetøy',),
'aprikossyltetøyene': ('aprikossyltetøy',),
'aprikossyltetøyet': ('aprikossyltetøy',),
'aprikostre': ('aprikostre',),
'aprikostrea': ('aprikostre',),
'aprikostreet': ('aprikostre',),
'aprikostrær': ('aprikostre',),
'aprikostrærne': ('aprikostre',),
'april': ('april',),
'aprilsnarr': ('aprilsnarr',),
'aprilsnarren': ('aprilsnarr',),
'aprilsnarrene': ('aprilsnarr',),
'aprilsnarrer': ('aprilsnarr',),
'aprilspøk': ('aprilspøk',),
'aprilspøken': ('aprilspøk',),
'aprilspøkene': ('aprilspøk',),
'aprilspøker': ('aprilspøk',),
'aprilvær': ('aprilvær',),
'aprilværa': ('aprilvær',),
'aprilværene': ('aprilvær',),
'aprilværet': ('aprilvær',),
'apropos': ('apropos',),
'aproposa': ('apropos',),
'aproposene': ('apropos',),
'aproposer': ('apropos',),
'aproposet': ('apropos',),
'apsidene': ('apsis',),
'apsider': ('apsis',),
'apsis': ('apsis',),
'apsisen': ('apsis',),
'apsisene': ('apsis',),
'apsiser': ('apsis',),
'ar': ('ar',),
'ara': ('ar',),
'arene': ('ar',),
'aret': ('ar',),
'ara': ('ara',),
'araen': ('ara',),
'araene': ('ara',),
'araer': ('ara',),
'araber': ('araber',),
'arabere': ('araber',),
'araberen': ('araber',),
'araberer': ('araber',),
'araberne': ('araber',),
'araberhest': ('araberhest',),
'araberhesten': ('araberhest',),
'araberhestene': ('araberhest',),
'araberhester': ('araberhest',),
'araberstat': ('araberstat',),
'araberstaten': ('araberstat',),
'araberstatene': ('araberstat',),
'araberstater': ('araberstat',),
'arabertal': ('arabertal',),
'arabertala': ('arabertal',),
'arabertalene': ('arabertal',),
'arabertalet': ('arabertal',),
'arabertall': ('arabertall',),
'arabertalla': ('arabertall',),
'arabertallene': ('arabertall',),
'arabertallet': ('arabertall',),
'arabesk': ('arabesk',),
'arabesken': ('arabesk',),
'arabeskene': ('arabesk',),
'arabesker': ('arabesk',),
'arabisk': ('arabisk',),
'arabisken': ('arabisk',),
'arabiskene': ('arabisk',),
'arabisker': ('arabisk',),
'arabist': ('arabist',),
'arabisten': ('arabist',),
'arabistene': ('arabist',),
'arabister': ('arabist',),
'arak': ('arak',),
'araken': ('arak',),
'arakene': ('arak',),
'araker': ('arak',),
'arakpunsj': ('arakpunsj',),
'arakpunsjen': ('arakpunsj',),
'arakpunsjene': ('arakpunsj',),
'arakpunsjer': ('arakpunsj',),
'arameer': ('arameer',),
'arameere': ('arameer',),
'arameeren': ('arameer',),
'arameerer': ('arameer',),
'arameerne': ('arameer',),
'arameisk': ('arameisk',),
'arameisken': ('arameisk',),
'arameiskene': ('arameisk',),
'arameisker': ('arameisk',),
'arbeid': ('arbeid',),
'arbeida': ('arbeid',),
'arbeidene': ('arbeid',),
'arbeider': ('arbeid',),
'arbeidet': ('arbeid',),
'arbeider': ('arbeider',),
'arbeidere': ('arbeider',),
'arbeideren': ('arbeider',),
'arbeiderer': ('arbeider',),
'arbeiderne': ('arbeider',),
'arbeiderbevegelse': ('arbeiderbevegelse',),
'arbeiderbevegelsen': ('arbeiderbevegelse',),
'arbeiderbevegelsene': ('arbeiderbevegelse',),
'arbeiderbevegelser': ('arbeiderbevegelse',),
'arbeiderbia': ('arbeiderbie',),
'arbeiderbie': ('arbeiderbie',),
'arbeiderbien': ('arbeiderbie',),
'arbeiderbiene': ('arbeiderbie',),
'arbeiderbier': ('arbeiderbie',),
'arbeiderbolig': ('arbeiderbolig',),
'arbeiderboligen': ('arbeiderbolig',),
'arbeiderboligene': ('arbeiderbolig',),
'arbeiderboliger': ('arbeiderbolig',),
'arbeiderdikter': ('arbeiderdikter',),
'arbeiderdiktere': ('arbeiderdikter',),
'arbeiderdikteren': ('arbeiderdikter',),
'arbeiderdikterer': ('arbeiderdikter',),
'arbeiderdikterne': ('arbeiderdikter',),
'arbeiderdiktning': ('arbeiderdiktning',),
'arbeiderdiktninga': ('arbeiderdiktning',),
'arbeiderdiktningen': ('arbeiderdiktning',),
'arbeiderdiktningene': ('arbeiderdiktning',),
'arbeiderdiktninger': ('arbeiderdiktning',),
'arbeiderforening': ('arbeiderforening',),
'arbeiderforeninga': ('arbeiderforening',),
'arbeiderforeningen': ('arbeiderforening',),
'arbeiderforeningene': ('arbeiderforening',),
'arbeiderforeninger': ('arbeiderforening',),
'arbeiderfører': ('arbeiderfører',),
'arbeiderførere': ('arbeiderfører',),
'arbeiderføreren': ('arbeiderfører',),
'arbeiderførerer': ('arbeiderfører',),
'arbeiderførerne': ('arbeiderfører',),
'arbeiderklassa': ('arbeiderklasse',),
'arbeiderklasse': ('arbeiderklasse',),
'arbeiderklassen': ('arbeiderklasse',),
'arbeiderklassene': ('arbeiderklasse',),
'arbeiderklasser': ('arbeiderklasse',),
'arbeiderkvarter': ('arbeiderkvarter',),
'arbeiderkvartera': ('arbeiderkvarter',),
'arbeiderkvarterene': ('arbeiderkvarter',),
'arbeiderkvarterer': ('arbeiderkvarter',),
'arbeiderkvarteret': ('arbeiderkvarter',),
'arbeiderleder': ('arbeiderleder',),
'arbeiderledere': ('arbeiderleder',),
'arbeiderlederen': ('arbeiderleder',),
'arbeiderlederer': ('arbeiderleder',),
'arbeiderlederne': ('arbeiderleder',),
'arbeidermiljø': ('arbeidermiljø',),
'arbeidermiljøa': ('arbeidermiljø',),
'arbeidermiljøene': ('arbeidermiljø',),
'arbeidermiljøer': ('arbeidermiljø',),
'arbeidermiljøet': ('arbeidermiljø',),
'arbeideroppstand': ('arbeideroppstand',),
'arbeideroppstanden': ('arbeideroppstand',),
'arbeideroppstandene': ('arbeideroppstand',),
'arbeideroppstander': ('arbeideroppstand',),
'arbeiderparti': ('arbeiderparti',),
'arbeiderpartia': ('arbeiderparti',),
'arbeiderpartiene': ('arbeiderparti',),
'arbeiderpartier': ('arbeiderparti',),
'arbeiderpartiet': ('arbeiderparti',),
'arbeiderpartifolk': ('arbeiderpartifolk',),
'arbeiderpartifolka': ('arbeiderpartifolk',),
'arbeiderpartifolkene': ('arbeiderpartifolk',),
'arbeiderpartifolket': ('arbeiderpartifolk',),
'arbeiderpressa': ('arbeiderpresse',),
'arbeiderpresse': ('arbeiderpresse',),
'arbeiderpressen': ('arbeiderpresse',),
'arbeiderpressene': ('arbeiderpresse',),
'arbeiderpresser': ('arbeiderpresse',),
'arbeiderregjering': ('arbeiderregjering',),
'arbeiderregjeringa': ('arbeiderregjering',),
'arbeiderregjeringen': ('arbeiderregjering',),
'arbeiderregjeringene': ('arbeiderregjering',),
'arbeiderregjeringer': ('arbeiderregjering',),
'arbeiderrevolusjon': ('arbeiderrevolusjon',),
'arbeiderrevolusjonen': ('arbeiderrevolusjon',),
'arbeiderrevolusjonene': ('arbeiderrevolusjon',),
'arbeiderrevolusjoner': ('arbeiderrevolusjon',),
'arbeiderråd': ('arbeiderråd',),
'arbeiderråda': ('arbeiderråd',),
'arbeiderrådene': ('arbeiderråd',),
'arbeiderrådet': ('arbeiderråd',),
'arbeiderrørsla': ('arbeiderrørsle',),
'arbeiderrørsle': ('arbeiderrørsle',),
'arbeiderrørslen': ('arbeiderrørsle',),
'arbeiderrørslene': ('arbeiderrørsle',),
'arbeiderrørsler': ('arbeiderrørsle',),
'arbeidersamfunn': ('arbeidersamfunn',),
'arbeidersamfunna': ('arbeidersamfunn',),
'arbeidersamfunnene': ('arbeidersamfunn',),
'arbeidersamfunnet': ('arbeidersamfunn',),
'arbeidersamskipnad': ('arbeidersamskipnad',),
'arbeidersamskipnaden': ('arbeidersamskipnad',),
'arbeidersamskipnadene': ('arbeidersamskipnad',),
'arbeidersamskipnader': ('arbeidersamskipnad',),
'arbeiderstrøk': ('arbeiderstrøk',),
'arbeiderstrøka': ('arbeiderstrøk',),
'arbeiderstrøkene': ('arbeiderstrøk',),
'arbeiderstrøket': ('arbeiderstrøk',),
'arbeiderstyra': ('arbeiderstyre',),
'arbeiderstyre': ('arbeiderstyre',),
'arbeiderstyrene': ('arbeiderstyre',),
'arbeiderstyrer': ('arbeiderstyre',),
'arbeiderstyret': ('arbeiderstyre',),
'arbeidervern': ('arbeidervern',),
'arbeiderverna': ('arbeidervern',),
'arbeidervernene': ('arbeidervern',),
'arbeidervernet': ('arbeidervern',),
'arbeidervernlov': ('arbeidervernlov',),
'arbeidervernloven': ('arbeidervernlov',),
'arbeidervernlovene': ('arbeidervernlov',),
'arbeidervernlover': ('arbeidervernlov',),
'arbeidsanstalt': ('arbeidsanstalt',),
'arbeidsanstalten': ('arbeidsanstalt',),
'arbeidsanstaltene': ('arbeidsanstalt',),
'arbeidsanstalter': ('arbeidsanstalt',),
'arbeidsbenk': ('arbeidsbenk',),
'arbeidsbenken': ('arbeidsbenk',),
'arbeidsbenkene': ('arbeidsbenk',),
'arbeidsbenker': ('arbeidsbenk',),
'arbeidsbeskrivelse': ('arbeidsbeskrivelse',),
'arbeidsbeskrivelsen': ('arbeidsbeskrivelse',),
'arbeidsbeskrivelsene': ('arbeidsbeskrivelse',),
'arbeidsbeskrivelser': ('arbeidsbeskrivelse',),
'arbeidsbia': ('arbeidsbie',),
'arbeidsbie': ('arbeidsbie',),
'arbeidsbien': ('arbeidsbie',),
'arbeidsbiene': ('arbeidsbie',),
'arbeidsbier': ('arbeidsbie',),
'arbeidsbord': ('arbeidsbord',),
'arbeidsborda': ('arbeidsbord',),
'arbeidsbordene': ('arbeidsbord',),
'arbeidsborder': ('arbeidsbord',),
'arbeidsbordet': ('arbeidsbord',),
'arbeidsbyrde': ('arbeidsbyrde',),
'arbeidsbyrden': ('arbeidsbyrde',),
'arbeidsbyrdene': ('arbeidsbyrde',),
'arbeidsbyrder': ('arbeidsbyrde',),
'arbeidsdag': ('arbeidsdag',),
'arbeidsdagen': ('arbeidsdag',),
'arbeidsdagene': ('arbeidsdag',),
'arbeidsdager': ('arbeidsdag',),
'arbeidsdeling': ('arbeidsdeling',),
'arbeidsdelinga': ('arbeidsdeling',),
'arbeidsdelingen': ('arbeidsdeling',),
'arbeidsdelingene': ('arbeidsdeling',),
'arbeidsdelinger': ('arbeidsdeling',),
'arbeidsdokument': ('arbeidsdokument',),
'arbeidsdokumenta': ('arbeidsdokument',),
'arbeidsdokumentene': ('arbeidsdokument',),
'arbeidsdokumenter': ('arbeidsdokument',),
'arbeidsdokumentet': ('arbeidsdokument',),
'arbeidsdyr': ('arbeidsdyr',),
'arbeidsdyra': ('arbeidsdyr',),
'arbeidsdyrene': ('arbeidsdyr',),
'arbeidsdyret': ('arbeidsdyr',),
'arbeidsevna': ('arbeidsevne',),
'arbeidsevne': ('arbeidsevne',),
'arbeidsevnen': ('arbeidsevne',),
'arbeidsevnene': ('arbeidsevne',),
'arbeidsevner': ('arbeidsevne',),
'arbeidsfelt': ('arbeidsfelt',),
'arbeidsfelta': ('arbeidsfelt',),
'arbeidsfeltene': ('arbeidsfelt',),
'arbeidsfelter': ('arbeidsfelt',),
'arbeidsfeltet': ('arbeidsfelt',),
'arbeidsfolk': ('arbeidsfolk',),
'arbeidsfolka': ('arbeidsfolk',),
'arbeidsfolkene': ('arbeidsfolk',),
'arbeidsfolket': ('arbeidsfolk',),
'arbeidsforhold': ('arbeidsforhold',),
'arbeidsforholda': ('arbeidsforhold',),
'arbeidsforholdene': ('arbeidsforhold',),
'arbeidsforholdet': ('arbeidsforhold',),
'arbeidsformidling': ('arbeidsformidling',),
'arbeidsformidlinga': ('arbeidsformidling',),
'arbeidsformidlingen': ('arbeidsformidling',),
'arbeidsformidlingene': ('arbeidsformidling',),
'arbeidsformidlinger': ('arbeidsformidling',),
'arbeidsfortjenesta': ('arbeidsfortjeneste',),
'arbeidsfortjeneste': ('arbeidsfortjeneste',),
'arbeidsfortjenesten': ('arbeidsfortjeneste',),
'arbeidsfortjenestene': ('arbeidsfortjeneste',),
'arbeidsfortjenester': ('arbeidsfortjeneste',),
'arbeidsfred': ('arbeidsfred',),
'arbeidsfreden': ('arbeidsfred',),
'arbeidsfredene': ('arbeidsfred',),
'arbeidsfreder': ('arbeidsfred',),
'arbeidsfysiologi': ('arbeidsfysiologi',),
'arbeidsfysiologien': ('arbeidsfysiologi',),
'arbeidsfysiologiene': ('arbeidsfysiologi',),
'arbeidsfysiologier': ('arbeidsfysiologi',),
'arbeidsgamp': ('arbeidsgamp',),
'arbeidsgampen': ('arbeidsgamp',),
'arbeidsgampene': ('arbeidsgamp',),
'arbeidsgamper': ('arbeidsgamp',),
'arbeidsgang': ('arbeidsgang',),
'arbeidsgangen': ('arbeidsgang',),
'arbeidsgangene': ('arbeidsgang',),
'arbeidsganger': ('arbeidsgang',),
'arbeidsgiver': ('arbeidsgiver',),
'arbeidsgivere': ('arbeidsgiver',),
'arbeidsgiveren': ('arbeidsgiver',),
'arbeidsgiverer': ('arbeidsgiver',),
'arbeidsgiverne': ('arbeidsgiver',),
'arbeidsgiveransvar': ('arbeidsgiveransvar',),
'arbeidsgiveransvara': ('arbeidsgiveransvar',),
'arbeidsgiveransvarene': ('arbeidsgiveransvar',),
'arbeidsgiveransvaret': ('arbeidsgiveransvar',),
'arbeidsgiveravgift': ('arbeidsgiveravgift',),
'arbeidsgiveravgifta': ('arbeidsgiveravgift',),
'arbeidsgiveravgiften': ('arbeidsgiveravgift',),
'arbeidsgiveravgiftene': ('arbeidsgiveravgift',),
'arbeidsgiveravgifter': ('arbeidsgiveravgift',),
'arbeidsgjeng': ('arbeidsgjeng',),
'arbeidsgjengen': ('arbeidsgjeng',),
'arbeidsgjengene': ('arbeidsgjeng',),
'arbeidsgjenger': ('arbeidsgjeng',),
'arbeidsgleda': ('arbeidsglede',),
'arbeidsglede': ('arbeidsglede',),
'arbeidsgleden': ('arbeidsglede',),
'arbeidsgledene': ('arbeidsglede',),
'arbeidsgleder': ('arbeidsglede',),
'arbeidsgrunnlag': ('arbeidsgrunnlag',),
'arbeidsgrunnlaga': ('arbeidsgrunnlag',),
'arbeidsgrunnlagene': ('arbeidsgrunnlag',),
'arbeidsgrunnlaget': ('arbeidsgrunnlag',),
'arbeidsgruppa': ('arbeidsgruppe',),
'arbeidsgruppe': ('arbeidsgruppe',),
'arbeidsgruppen': ('arbeidsgruppe',),
'arbeidsgruppene': ('arbeidsgruppe',),
'arbeidsgrupper': ('arbeidsgruppe',),
'arbeidshastighet': ('arbeidshastighet',),
'arbeidshastigheta': ('arbeidshastighet',),
'arbeidshastigheten': ('arbeidshastighet',),
'arbeidshastighetene': ('arbeidshastighet',),
'arbeidshastigheter': ('arbeidshastighet',),
'arbeidshest': ('arbeidshest',),
'arbeidshesten': ('arbeidshest',),
'arbeidshestene': ('arbeidshest',),
'arbeidshester': ('arbeidshest',),
'arbeidshjelp': ('arbeidshjelp',),
'arbeidshjelpa': ('arbeidshjelp',),
'arbeidshjelpen': ('arbeidshjelp',),
'arbeidshjelpene': ('arbeidshjelp',),
'arbeidshjelper': ('arbeidshjelp',),
'arbeidshypotese': ('arbeidshypotese',),
'arbeidshypotesen': ('arbeidshypotese',),
'arbeidshypotesene': ('arbeidshypotese',),
'arbeidshypoteser': ('arbeidshypotese',),
'arbeidsinnsats': ('arbeidsinnsats',),
'arbeidsinnsatsen': ('arbeidsinnsats',),
'arbeidsinnsatsene': ('arbeidsinnsats',),
'arbeidsinnsatser': ('arbeidsinnsats',),
'arbeidsjern': ('arbeidsjern',),
'arbeidsjerna': ('arbeidsjern',),
'arbeidsjernene': ('arbeidsjern',),
'arbeidsjernet': ('arbeidsjern',),
'arbeidskamerat': ('arbeidskamerat',),
'arbeidskameraten': ('arbeidskamerat',),
'arbeidskameratene': ('arbeidskamerat',),
'arbeidskamerater': ('arbeidskamerat',),
'arbeidskar': ('arbeidskar',),
'arbeidskaren': ('arbeidskar',),
'arbeidskarene': ('arbeidskar',),
'arbeidskarer': ('arbeidskar',),
'arbeidskirka': ('arbeidskirke',),
'arbeidskirke': ('arbeidskirke',),
'arbeidskirken': ('arbeidskirke',),
'arbeidskirkene': ('arbeidskirke',),
'arbeidskirker': ('arbeidskirke',),
'arbeidskjerka': ('arbeidskjerke',),
'arbeidskjerke': ('arbeidskjerke',),
'arbeidskjerken': ('arbeidskjerke',),
'arbeidskjerkene': ('arbeidskjerke',),
'arbeidskjerker': ('arbeidskjerke',),
'arbeidskollektiv': ('arbeidskollektiv',),
'arbeidskollektiva': ('arbeidskollektiv',),
'arbeidskollektivene': ('arbeidskollektiv',),
'arbeidskollektiver': ('arbeidskollektiv',),
'arbeidskollektivet': ('arbeidskollektiv',),
'arbeidskonflikt': ('arbeidskonflikt',),
'arbeidskonflikten': ('arbeidskonflikt',),
'arbeidskonfliktene': ('arbeidskonflikt',),
'arbeidskonflikter': ('arbeidskonflikt',),
'arbeidskontor': ('arbeidskontor',),
'arbeidskontora': ('arbeidskontor',),
'arbeidskontorene': ('arbeidskontor',),
'arbeidskontorer': ('arbeidskontor',),
'arbeidskontoret': ('arbeidskontor',),
'arbeidskostnad': ('arbeidskostnad',),
'arbeidskostnaden': ('arbeidskostnad',),
'arbeidskostnadene': ('arbeidskostnad',),
'arbeidskostnader': ('arbeidskostnad',),
'arbeidskraft': ('arbeidskraft',),
'arbeidskrafta': ('arbeidskraft',),
'arbeidskraften': ('arbeidskraft',),
'arbeidskreftene': ('arbeidskraft',),
'arbeidskrefter': ('arbeidskraft',),
'arbeidskraftreserve': ('arbeidskraftreserve',),
'arbeidskraftreserven': ('arbeidskraftreserve',),
'arbeidskraftreservene': ('arbeidskraftreserve',),
'arbeidskraftreserver': ('arbeidskraftreserve',),
'arbeidslag': ('arbeidslag',),
'arbeidslaga': ('arbeidslag',),
'arbeidslagene': ('arbeidslag',),
'arbeidslaget': ('arbeidslag',),
'arbeidslampa': ('arbeidslampe',),
'arbeidslampe': ('arbeidslampe',),
'arbeidslampen': ('arbeidslampe',),
'arbeidslampene': ('arbeidslampe',),
'arbeidslamper': ('arbeidslampe',),
'arbeidsleder': ('arbeidsleder',),
'arbeidsledere': ('arbeidsleder',),
'arbeidslederen': ('arbeidsleder',),
'arbeidslederer': ('arbeidsleder',),
'arbeidslederne': ('arbeidsleder',),
'arbeidsledighet': ('arbeidsledighet',),
'arbeidsledigheta': ('arbeidsledighet',),
'arbeidsledigheten': ('arbeidsledighet',),
'arbeidsledighetene': ('arbeidsledighet',),
'arbeidsledigheter': ('arbeidsledighet',),
'arbeidsleir': ('arbeidsleir',),
'arbeidsleiren': ('arbeidsleir',),
'arbeidsleirene': ('arbeidsleir',),
'arbeidsleirer': ('arbeidsleir',),
'arbeidsliv': ('arbeidsliv',),
'arbeidsliva': ('arbeidsliv',),
'arbeidslivene': ('arbeidsliv',),
'arbeidslivet': ('arbeidsliv',),
'arbeidslyst': ('arbeidslyst',),
'arbeidslysta': ('arbeidslyst',),
'arbeidslysten': ('arbeidslyst',),
'arbeidslystene': ('arbeidslyst',),
'arbeidslyster': ('arbeidslyst',),
'arbeidslønn': ('arbeidslønn',),
'arbeidslønna': ('arbeidslønn',),
'arbeidslønnen': ('arbeidslønn',),
'arbeidslønnene': ('arbeidslønn',),
'arbeidslønner': ('arbeidslønn',),
'arbeidsløshet': ('arbeidsløshet',),
'arbeidsløsheta': ('arbeidsløshet',),
'arbeidsløsheten': ('arbeidsløshet',),
'arbeidsløshetene': ('arbeidsløshet',),
'arbeidsløsheter': ('arbeidsløshet',),
'arbeidsløshetstrygd': ('arbeidsløshetstrygd',),
'arbeidsløshetstrygda': ('arbeidsløshetstrygd',),
'arbeidsløshetstrygden': ('arbeidsløshetstrygd',),
'arbeidsløshetstrygdene': ('arbeidsløshetstrygd',),
'arbeidsløshetstrygder': ('arbeidsløshetstrygd',),
'arbeidsløysa': ('arbeidsløyse',),
'arbeidsløyse': ('arbeidsløyse',),
'arbeidsløysen': ('arbeidsløyse',),
'arbeidsløysene': ('arbeidsløyse',),
'arbeidsløyser': ('arbeidsløyse',),
'arbeidsløysetrygd': ('arbeidsløysetrygd',),
'arbeidsløysetrygda': ('arbeidsløysetrygd',),
'arbeidsløysetrygden': ('arbeidsløysetrygd',),
'arbeidsløysetrygdene': ('arbeidsløysetrygd',),
'arbeidsløysetrygder': ('arbeidsløysetrygd',),
'arbeidsløyva': ('arbeidsløyve',),
'arbeidsløyve': ('arbeidsløyve',),
'arbeidsløyvene': ('arbeidsløyve',),
'arbeidsløyver': ('arbeidsløyve',),
'arbeidsløyvet': ('arbeidsløyve',),
'arbeidsmarked': ('arbeidsmarked',),
'arbeidsmarkeda': ('arbeidsmarked',),
'arbeidsmarkedene': ('arbeidsmarked',),
'arbeidsmarkeder': ('arbeidsmarked',),
'arbeidsmarkedet': ('arbeidsmarked',),
'arbeidsmarknad': ('arbeidsmarknad',),
'arbeidsmarknaden': ('arbeidsmarknad',),
'arbeidsmarknadene': ('arbeidsmarknad',),
'arbeidsmarknader': ('arbeidsmarknad',),
'arbeidsmaur': ('arbeidsmaur',),
'arbeidsmauren': ('arbeidsmaur',),
'arbeidsmaurene': ('arbeidsmaur',),
'arbeidsmengd': ('arbeidsmengd',),
'arbeidsmengda': ('arbeidsmengd',),
'arbeidsmengden': ('arbeidsmengd',),
'arbeidsmengdene': ('arbeidsmengd',),
'arbeidsmengder': ('arbeidsmengd',),
'arbeidsmengde': ('arbeidsmengde',),
'arbeidsmengden': ('arbeidsmengde',),
'arbeidsmengdene': ('arbeidsmengde',),
'arbeidsmengder': ('arbeidsmengde',),
'arbeidsmenneska': ('arbeidsmenneske',),
'arbeidsmenneske': ('arbeidsmenneske',),
'arbeidsmenneskene': ('arbeidsmenneske',),
'arbeidsmennesker': ('arbeidsmenneske',),
'arbeidsmennesket': ('arbeidsmenneske',),
'arbeidsmiljø': ('arbeidsmiljø',),
'arbeidsmiljøa': ('arbeidsmiljø',),
'arbeidsmiljøene': ('arbeidsmiljø',),
'arbeidsmiljøer': ('arbeidsmiljø',),
'arbeidsmiljøet': ('arbeidsmiljø',),
'arbeidsmiljølov': ('arbeidsmiljølov',),
'arbeidsmiljøloven': ('arbeidsmiljølov',),
'arbeidsmiljølovene': ('arbeidsmiljølov',),
'arbeidsmiljølover': ('arbeidsmiljølov',),
'arbeidsnedleggelse': ('arbeidsnedleggelse',),
'arbeidsnedleggelsen': ('arbeidsnedleggelse',),
'arbeidsnedleggelsene': ('arbeidsnedleggelse',),
'arbeidsnedleggelser': ('arbeidsnedleggelse',),
'arbeidsnedlegging': ('arbeidsnedlegging',),
'arbeidsnedlegginga': ('arbeidsnedlegging',),
'arbeidsnedleggingen': ('arbeidsnedlegging',),
'arbeidsnedleggingene': ('arbeidsnedlegging',),
'arbeidsnedlegginger': ('arbeidsnedlegging',),
'arbeidsneve': ('arbeidsneve',),
'arbeidsneven': ('arbeidsneve',),
'arbeidsnevene': ('arbeidsneve',),
'arbeidsnever': ('arbeidsneve',),
'arbeidsområda': ('arbeidsområde',),
'arbeidsområde': ('arbeidsområde',),
'arbeidsområdene': ('arbeidsområde',),
'arbeidsområder': ('arbeidsområde',),
'arbeidsområdet': ('arbeidsområde',),
'arbeidsoperasjon': ('arbeidsoperasjon',),
'arbeidsoperasjonen': ('arbeidsoperasjon',),
'arbeidsoperasjonene': ('arbeidsoperasjon',),
'arbeidsoperasjoner': ('arbeidsoperasjon',),
'arbeidspress': ('arbeidspress',),
'arbeidspressa': ('arbeidspress',),
'arbeidspressene': ('arbeidspress',),
'arbeidspresset': ('arbeidspress',),
'arbeidsprogram': ('arbeidsprogram',),
'arbeidsprogramma': ('arbeidsprogram',),
'arbeidsprogrammene': ('arbeidsprogram',),
'arbeidsprogrammer': ('arbeidsprogram',),
'arbeidsprogrammet': ('arbeidsprogram',),
'arbeidsredskap': ('arbeidsredskap',),
'arbeidsredskapa': ('arbeidsredskap',),
'arbeidsredskapen': ('arbeidsredskap',),
'arbeidsredskapene': ('arbeidsredskap',),
'arbeidsredskaper': ('arbeidsredskap',),
'arbeidsredskapet': ('arbeidsredskap',),
'arbeidsrett': ('arbeidsrett',),
'arbeidsretten': ('arbeidsrett',),
'arbeidsrettene': ('arbeidsrett',),
'arbeidsretter': ('arbeidsrett',),
'arbeidsskole': ('arbeidsskole',),
'arbeidsskolen': ('arbeidsskole',),
'arbeidsskolene': ('arbeidsskole',),
'arbeidsskoler': ('arbeidsskole',),
'arbeidsstans': ('arbeidsstans',),
'arbeidsstansen': ('arbeidsstans',),
'arbeidsstansene': ('arbeidsstans',),
'arbeidsstanser': ('arbeidsstans',),
'arbeidsstilling': ('arbeidsstilling',),
'arbeidsstillinga': ('arbeidsstilling',),
'arbeidsstillingen': ('arbeidsstilling',),
'arbeidsstillingene': ('arbeidsstilling',),
'arbeidsstillinger': ('arbeidsstilling',),
'arbeidsstokk': ('arbeidsstokk',),
'arbeidsstokken': ('arbeidsstokk',),
'arbeidsstokkene': ('arbeidsstokk',),
'arbeidsstokker': ('arbeidsstokk',),
'arbeidsstudie': ('arbeidsstudie',),
'arbeidsstudien': ('arbeidsstudie',),
'arbeidsstudiene': ('arbeidsstudie',),
'arbeidsstudier': ('arbeidsstudie',),
'arbeidsstudietekniker': ('arbeidsstudietekniker',),
'arbeidsstudieteknikere': ('arbeidsstudietekniker',),
'arbeidsstudieteknikeren': ('arbeidsstudietekniker',),
'arbeidsstudieteknikerer': ('arbeidsstudietekniker',),
'arbeidsstudieteknikerne': ('arbeidsstudietekniker',),
'arbeidsstyrke': ('arbeidsstyrke',),
'arbeidsstyrken': ('arbeidsstyrke',),
'arbeidsstyrkene': ('arbeidsstyrke',),
'arbeidsstyrker': ('arbeidsstyrke',),
'arbeidssøker': ('arbeidssøker',),
'arbeidssøkere': ('arbeidssøker',),
'arbeidssøkeren': ('arbeidssøker',),
'arbeidssøkerer': ('arbeidssøker',),
'arbeidssøkerne': ('arbeidssøker',),
'arbeidstaker': ('arbeidstaker',),
'arbeidstakere': ('arbeidstaker',),
'arbeidstakeren': ('arbeidstaker',),
'arbeidstakerer': ('arbeidstaker',),
'arbeidstakerne': ('arbeidstaker',),
'arbeidstegning': ('arbeidstegning',),
'arbeidstegninga': ('arbeidstegning',),
'arbeidstegningen': ('arbeidstegning',),
'arbeidstegningene': ('arbeidstegning',),
'arbeidstegninger': ('arbeidstegning',),
'arbeidsteknikk': ('arbeidsteknikk',),
'arbeidsteknikken': ('arbeidsteknikk',),
'arbeidsteknikkene': ('arbeidsteknikk',),
'arbeidsteknikker': ('arbeidsteknikk',),
'arbeidstempi': ('arbeidstempo',),
'arbeidstempiene': ('arbeidstempo',),
'arbeidstempo': ('arbeidstempo',),
'arbeidstempoa': ('arbeidstempo',),
'arbeidstempoene': ('arbeidstempo',),
'arbeidstempoer': ('arbeidstempo',),
'arbeidstempoet': ('arbeidstempo',),
'arbeidsterapeut': ('arbeidsterapeut',),
'arbeidsterapeuten': ('arbeidsterapeut',),
'arbeidsterapeutene': ('arbeidsterapeut',),
'arbeidsterapeuter': ('arbeidsterapeut',),
'arbeidsterapi': ('arbeidsterapi',),
'arbeidsterapien': ('arbeidsterapi',),
'arbeidsterapiene': ('arbeidsterapi',),
'arbeidsterapier': ('arbeidsterapi',),
'arbeidstid': ('arbeidstid',),
'arbeidstida': ('arbeidstid',),
'arbeidstiden': ('arbeidstid',),
'arbeidstidene': ('arbeidstid',),
'arbeidstider': ('arbeidstid',),
'arbeidstillatelse': ('arbeidstillatelse',),
'arbeidstillatelsen': ('arbeidstillatelse',),
'arbeidstillatelsene': ('arbeidstillatelse',),
'arbeidstillatelser': ('arbeidstillatelse',),
'arbeidstilsyn': ('arbeidstilsyn',),
'arbeidstilsyna': ('arbeidstilsyn',),
'arbeidstilsynene': ('arbeidstilsyn',),
'arbeidstilsynet': ('arbeidstilsyn',),
'arbeidstitlene': ('arbeidstittel',),
'arbeidstitler': ('arbeidstittel',),
'arbeidstittel': ('arbeidstittel',),
'arbeidstittelen': ('arbeidstittel',),
'arbeidstrell': ('arbeidstrell',),
'arbeidstrellen': ('arbeidstrell',),
'arbeidstrellene': ('arbeidstrell',),
'arbeidstreller': ('arbeidstrell',),
'arbeidstvist': ('arbeidstvist',),
'arbeidstvisten': ('arbeidstvist',),
'arbeidstvistene': ('arbeidstvist',),
'arbeidstvister': ('arbeidstvist',),
'arbeidsuka': ('arbeidsuke',),
'arbeidsuke': ('arbeidsuke',),
'arbeidsuken': ('arbeidsuke',),
'arbeidsukene': ('arbeidsuke',),
'arbeidsuker': ('arbeidsuke',),
'arbeidsuka': ('arbeidsuke',),
'arbeidsuke': ('arbeidsuke',),
'arbeidsuken': ('arbeidsuke',),
'arbeidsukene': ('arbeidsuke',),
'arbeidsuker': ('arbeidsuke',),
'arbeidsulykka': ('arbeidsulykke',),
'arbeidsulykke': ('arbeidsulykke',),
'arbeidsulykken': ('arbeidsulykke',),
'arbeidsulykkene': ('arbeidsulykke',),
'arbeidsulykker': ('arbeidsulykke',),
'arbeidsutvalg': ('arbeidsutvalg',),
'arbeidsutvalga': ('arbeidsutvalg',),
'arbeidsutvalgene': ('arbeidsutvalg',),
'arbeidsutvalget': ('arbeidsutvalg',),
'arbeidsveka': ('arbeidsveke',),
'arbeidsveke': ('arbeidsveke',),
'arbeidsveken': ('arbeidsveke',),
'arbeidsvekene': ('arbeidsveke',),
'arbeidsveker': ('arbeidsveke',),
'arbeidsveka': ('arbeidsveke',),
'arbeidsveke': ('arbeidsveke',),
'arbeidsveken': ('arbeidsveke',),
'arbeidsvekene': ('arbeidsveke',),
'arbeidsveker': ('arbeidsveke',),
'arbeidsvilkår': ('arbeidsvilkår',),
'arbeidsvilkåra': ('arbeidsvilkår',),
'arbeidsvilkårene': ('arbeidsvilkår',),
'arbeidsvilkåret': ('arbeidsvilkår',),
'arbeidsår': ('arbeidsår',),
'arbeidsåra': ('arbeidsår',),
'arbeidsårene': ('arbeidsår',),
'arbeidsåret': ('arbeidsår',),
'arbeidsøkt': ('arbeidsøkt',),
'arbeidsøkta': ('arbeidsøkt',),
'arbeidsøkten': ('arbeidsøkt',),
'arbeidsøktene': ('arbeidsøkt',),
'arbeidsøkter': ('arbeidsøkt',),
'arbitrasje': ('arbitrasje',),
'arbitrasjen': ('arbitrasje',),
'arbitrasjene': ('arbitrasje',),
'arbitrasjer': ('arbitrasje',),
'arboret': ('arboret',),
'arboreta': ('arboret',),
'arboretene': ('arboret',),
'arboreter': ('arboret',),
'arboretet': ('arboret',),
'arboretum': ('arboretum',),
'arboretuma': ('arboretum',),
'arboretumene': ('arboretum',),
'arboretumer': ('arboretum',),
'arboretumet': ('arboretum',),
'ard': ('ard',),
'arden': ('ard',),
'ardene': ('ard',),
'arder': ('ard',),
'areal': ('areal',),
'areala': ('areal',),
'arealene': ('areal',),
'arealer': ('areal',),
'arealet': ('areal',),
'arealbruk': ('arealbruk',),
'arealbruka': ('arealbruk',),
'arealbruken': ('arealbruk',),
'arealbrukene': ('arealbruk',),
'arealbruker': ('arealbruk',),
'arealbruket': ('arealbruk',),
'arealdisponering': ('arealdisponering',),
'arealdisponeringa': ('arealdisponering',),
'arealdisponeringen': ('arealdisponering',),
'arealdisponeringene': ('arealdisponering',),
'arealdisponeringer': ('arealdisponering',),
'arealplan': ('arealplan',),
'arealplanen': ('arealplan',),
'arealplanene': ('arealplan',),
'arealplaner': ('arealplan',),
'arena': ('arena',),
'arenaen': ('arena',),
'arenaene': ('arena',),
'arenaer': ('arena',),
'areometer': ('areometer',),
'areometeret': ('areometer',),
'areometra': ('areometer',),
'areometre': ('areometer',),
'areometrene': ('areometer',),
'areometret': ('areometer',),
'argentiner': ('argentiner',),
'argentinere': ('argentiner',),
'argentineren': ('argentiner',),
'argentinerer': ('argentiner',),
'argentinerne': ('argentiner',),
'argon': ('argon',),
'argona': ('argon',),
'argonene': ('argon',),
'argonet': ('argon',),
'argot': ('argot',),
'argoten': ('argot',),
'argotene': ('argot',),
'argoter': ('argot',),
'argument': ('argument',),
'argumenta': ('argument',),
'argumentene': ('argument',),
'argumenter': ('argument',),
'argumentet': ('argument',),
'argumentasjon': ('argumentasjon',),
'argumentasjonen': ('argumentasjon',),
'argumentasjonene': ('argumentasjon',),
'argumentasjoner': ('argumentasjon',),
'argumentering': ('argumentering',),
'argumenteringa': ('argumentering',),
'argumenteringen': ('argumentering',),
'argumenteringene': ('argumentering',),
'argumenteringer': ('argumentering',),
'argusblikk': ('argusblikk',),
'argusblikka': ('argusblikk',),
'argusblikkene': ('argusblikk',),
'argusblikket': ('argusblikk',),
'argusøya': ('argusøye',),
'argusøye': ('argusøye',),
'argusøyene': ('argusøye',),
'argusøyer': ('argusøye',),
'argusøyet': ('argusøye',),
'argusøyne': ('argusøye',),
'argusøynene': ('argusøye',),
'ariadnetråd': ('ariadnetråd',),
'ariadnetråden': ('ariadnetråd',),
'ariadnetrådene': ('ariadnetråd',),
'ariadnetråder': ('ariadnetråd',),
'ariditet': ('ariditet',),
'ariditeten': ('ariditet',),
'ariditetene': ('ariditet',),
'ariditeter': ('ariditet',),
'arie': ('arie',),
'arien': ('arie',),
'ariene': ('arie',),
'arier': ('arie',),
'arier': ('arier',),
'ariere': ('arier',),
'arieren': ('arier',),
'arierer': ('arier',),
'arierne': ('arier',),
'arietta': ('arietta',),
'ariettaen': ('arietta',),
'ariettaene': ('arietta',),
'ariettaer': ('arietta',),
'arild': ('arild',),
'aristokrat': ('aristokrat',),
'aristokraten': ('aristokrat',),
'aristokratene': ('aristokrat',),
'aristokrater': ('aristokrat',),
'aristokrati': ('aristokrati',),
'aristokratia': ('aristokrati',),
'aristokratiene': ('aristokrati',),
'aristokratier': ('aristokrati',),
'aristokratiet': ('aristokrati',),
'aritmetiker': ('aritmetiker',),
'aritmetikere': ('aritmetiker',),
'aritmetikeren': ('aritmetiker',),
'aritmetikerer': ('aritmetiker',),
'aritmetikerne': ('aritmetiker',),
'aritmetikk': ('aritmetikk',),
'aritmetikken': ('aritmetikk',),
'aritmetikkene': ('aritmetikk',),
'aritmetikker': ('aritmetikk',),
'ark': ('ark',),
'arken': ('ark',),
'arkene': ('ark',),
'arker': ('ark',),
'ark': ('ark',),
'arken': ('ark',),
'arkene': ('ark',),
'arker': ('ark',),
'ark': ('ark',),
'arka': ('ark',),
'arkene': ('ark',),
'arket': ('ark',),
'arkade': ('arkade',),
'arkaden': ('arkade',),
'arkadene': ('arkade',),
'arkader': ('arkade',),
'arkaisme': ('arkaisme',),
'arkaismen': ('arkaisme',),
'arkaismene': ('arkaisme',),
'arkaismer': ('arkaisme',),
'arkebuse': ('arkebuse',),
'arkebusen': ('arkebuse',),
'arkebusene': ('arkebuse',),
'arkebuser': ('arkebuse',),
'arkeolog': ('arkeolog',),
'arkeologen': ('arkeolog',),
'arkeologene': ('arkeolog',),
'arkeologer': ('arkeolog',),
'arkeologi': ('arkeologi',),
'arkeologien': ('arkeologi',),
'arkeologiene': ('arkeologi',),
'arkeologier': ('arkeologi',),
'arketyp': ('arketyp',),
'arketypen': ('arketyp',),
'arketypene': ('arketyp',),
'arketyper': ('arketyp',),
'arkipel': ('arkipel',),
'arkipela': ('arkipel',),
'arkipelene': ('arkipel',),
'arkipeler': ('arkipel',),
'arkipelet': ('arkipel',),
'arkipelag': ('arkipelag',),
'arkipelaga': ('arkipelag',),
'arkipelagene': ('arkipelag',),
'arkipelager': ('arkipelag',),
'arkipelaget': ('arkipelag',),
'arkitekt': ('arkitekt',),
'arkitekten': ('arkitekt',),
'arkitektene': ('arkitekt',),
'arkitekter': ('arkitekt',),
'arkitekthøgskole': ('arkitekthøgskole',),
'arkitekthøgskolen': ('arkitekthøgskole',),
'arkitekthøgskolene': ('arkitekthøgskole',),
'arkitekthøgskoler': ('arkitekthøgskole',),
'arkitekthøyskole': ('arkitekthøyskole',),
'arkitekthøyskolen': ('arkitekthøyskole',),
'arkitekthøyskolene': ('arkitekthøyskole',),
'arkitekthøyskoler': ('arkitekthøyskole',),
'arkitektkontor': ('arkitektkontor',),
'arkitektkontora': ('arkitektkontor',),
'arkitektkontorene': ('arkitektkontor',),
'arkitektkontorer': ('arkitektkontor',),
'arkitektkontoret': ('arkitektkontor',),
'arkitektur': ('arkitektur',),
'arkitekturen': ('arkitektur',),
'arkitekturene': ('arkitektur',),
'arkitekturer': ('arkitektur',),
'arkiv': ('arkiv',),
'arkiva': ('arkiv',),
'arkivene': ('arkiv',),
'arkiver': ('arkiv',),
'arkivet': ('arkiv',),
'arkivalie': ('arkivalie',),
'arkivalien': ('arkivalie',),
'arkivaliene': ('arkivalie',),
'arkivalier': ('arkivalie',),
'arkivar': ('arkivar',),
'arkivaren': ('arkivar',),
'arkivarene': ('arkivar',),
'arkivarer': ('arkivar',),
'arkivnøkkel': ('arkivnøkkel',),
'arkivnøkkelen': ('arkivnøkkel',),
'arkivnøklene': ('arkivnøkkel',),
'arkivnøkler': ('arkivnøkkel',),
'arkivsak': ('arkivsak',),
'arkivsaka': ('arkivsak',),
'arkivsaken': ('arkivsak',),
'arkivsakene': ('arkivsak',),
'arkivsaker': ('arkivsak',),
'arkivsjef': ('arkivsjef',),
'arkivsjefen': ('arkivsjef',),
'arkivsjefene': ('arkivsjef',),
'arkivsjefer': ('arkivsjef',),
'arkivstyrer': ('arkivstyrer',),
'arkivstyrere': ('arkivstyrer',),
'arkivstyreren': ('arkivstyrer',),
'arkivstyrerer': ('arkivstyrer',),
'arkivstyrerne': ('arkivstyrer',),
'arkivsystem': ('arkivsystem',),
'arkivsystema': ('arkivsystem',),
'arkivsystemene': ('arkivsystem',),
'arkivsystemer': ('arkivsystem',),
'arkivsystemet': ('arkivsystem',),
'arkont': ('arkont',),
'arkonten': ('arkont',),
'arkontene': ('arkont',),
'arkonter': ('arkont',),
'arktikfront': ('arktikfront',),
'arktikfronten': ('arktikfront',),
'arktikfrontene': ('arktikfront',),
'arktikfronter': ('arktikfront',),
'arktikluft': ('arktikluft',),
'arktiklufta': ('arktikluft',),
'arktikluften': ('arktikluft',),
'arktikluftene': ('arktikluft',),
'arktiklufter': ('arktikluft',),
'arm': ('arm',),
'armen': ('arm',),
'armene': ('arm',),
'armer': ('arm',),
'armeen': ('armé',),
'armeene': ('armé',),
'armeer': ('armé',),
'armé': ('armé',),
'arméen': ('armé',),
'arméene': ('armé',),
'arméer': ('armé',),
'armégevær': ('armégevær',),
'armégeværa': ('armégevær',),
'armégeværene': ('armégevær',),
'armégeværer': ('armégevær',),
'armégeværet': ('armégevær',),
'armégruppa': ('armégruppe',),
'armégruppe': ('armégruppe',),
'armégruppen': ('armégruppe',),
'armégruppene': ('armégruppe',),
'armégrupper': ('armégruppe',),
'armada': ('armada',),
'armadaen': ('armada',),
'armadaene': ('armada',),
'armadaer': ('armada',),
'armatur': ('armatur',),
'armaturen': ('armatur',),
'armaturene': ('armatur',),
'armaturer': ('armatur',),
'armaturdel': ('armaturdel',),
'armaturdelen': ('armaturdel',),
'armaturdelene': ('armaturdel',),
'armaturdeler': ('armaturdel',),
'armaturfabrikk': ('armaturfabrikk',),
'armaturfabrikken': ('armaturfabrikk',),
'armaturfabrikkene': ('armaturfabrikk',),
'armaturfabrikker': ('armaturfabrikk',),
'armband': ('armband',),
'armbanda': ('armband',),
'armbandene': ('armband',),
'armbandet': ('armband',),
'armbandsur': ('armbandsur',),
'armbandsura': ('armbandsur',),
'armbandsurene': ('armbandsur',),
'armbandsuret': ('armbandsur',),
'armbind': ('armbind',),
'armbinda': ('armbind',),
'armbindene': ('armbind',),
'armbindet': ('armbind',),
'armbrott': ('armbrott',),
'armbrotta': ('armbrott',),
'armbrottene': ('armbrott',),
'armbrottet': ('armbrott',),
'armbrudd': ('armbrudd',),
'armbrudda': ('armbrudd',),
'armbruddene': ('armbrudd',),
'armbruddet': ('armbrudd',),
'armbrøst': ('armbrøst',),
'armbrøsten': ('armbrøst',),
'armbrøstene': ('armbrøst',),
'armbrøster': ('armbrøst',),
'armbånd': ('armbånd',),
'armbånda': ('armbånd',),
'armbåndene': ('armbånd',),
'armbåndet': ('armbånd',),
'armbåndsur': ('armbåndsur',),
'armbåndsura': ('armbåndsur',),
'armbåndsurene': ('armbåndsur',),
'armbåndsuret': ('armbåndsur',),
'armener': ('armener',),
'armenere': ('armener',),
'armeneren': ('armener',),
'armenerer': ('armener',),
'armenerne': ('armener',),
'armenier': ('armenier',),
'armeniere': ('armenier',),
'armenieren': ('armenier',),
'armenierer': ('armenier',),
'armenierne': ('armenier',),
'armensk': ('armensk',),
'armensken': ('armensk',),
'armenskene': ('armensk',),
'armensker': ('armensk',),
'armering': ('armering',),
'armeringa': ('armering',),
'armeringen': ('armering',),
'armeringene': ('armering',),
'armeringer': ('armering',),
'armeringsjern': ('armeringsjern',),
'armeringsjerna': ('armeringsjern',),
'armeringsjernene': ('armeringsjern',),
'armeringsjernet': ('armeringsjern',),
'armeringsstål': ('armeringsstål',),
'armeringsståla': ('armeringsstål',),
'armeringsstålene': ('armeringsstål',),
'armeringsstålet': ('armeringsstål',),
'armfoting': ('armfoting',),
'armfotingen': ('armfoting',),
'armfotingene': ('armfoting',),
'armfotinger': ('armfoting',),
'armføtting': ('armføtting',),
'armføttingen': ('armføtting',),
'armføttingene': ('armføtting',),
'armføttinger': ('armføtting',),
'armgang': ('armgang',),
'armgangen': ('armgang',),
'armgangene': ('armgang',),
'armganger': ('armgang',),
'armheving': ('armheving',),
'armhevinga': ('armheving',),
'armhevingen': ('armheving',),
'armhevingene': ('armheving',),
'armhevinger': ('armheving',),
'armhevning': ('armhevning',),
'armhevninga': ('armhevning',),
'armhevningen': ('armhevning',),
'armhevningene': ('armhevning',),
'armhevninger': ('armhevning',),
'armhola': ('armhole',),
'armhole': ('armhole',),
'armholen': ('armhole',),
'armholene': ('armhole',),
'armholer': ('armhole',),
'armhula': ('armhule',),
'armhule': ('armhule',),
'armhulen': ('armhule',),
'armhulene': ('armhule',),
'armhuler': ('armhule',),
'arming': ('arming',),
'armingen': ('arming',),
'armingene': ('arming',),
'arminger': ('arming',),
'armkrok': ('armkrok',),
'armkroken': ('armkrok',),
'armkrokene': ('armkrok',),
'armkroker': ('armkrok',),
'armlena': ('armlene',),
'armlene': ('armlene',),
'armlenene': ('armlene',),
'armlener': ('armlene',),
'armlenet': ('armlene',),
'armod': ('armod',),
'armoda': ('armod',),
'armoden': ('armod',),
'armodene': ('armod',),
'armoder': ('armod',),
'armodsdom': ('armodsdom',),
'armodsdommen': ('armodsdom',),
'armodsdommene': ('armodsdom',),
'armodsdommer': ('armodsdom',),
'armodsfolk': ('armodsfolk',),
'armodsfolka': ('armodsfolk',),
'armodsfolkene': ('armodsfolk',),
'armodsfolket': ('armodsfolk',),
'armodskrek': ('armodskrek',),
'armodskreka': ('armodskrek',),
'armodskrekene': ('armodskrek',),
'armodskreket': ('armodskrek',),
'armodskrok': ('armodskrok',),
'armodskroken': ('armodskrok',),
'armodskrokene': ('armodskrok',),
'armodskroker': ('armodskrok',),
'armodskryp': ('armodskryp',),
'armodskrypa': ('armodskryp',),
'armodskrypen': ('armodskryp',),
'armodskrypene': ('armodskryp',),
'armodskrypet': ('armodskryp',),
'armodskår': ('armodskår',),
'armodskåra': ('armodskår',),
'armodskårene': ('armodskår',),
'armodskåret': ('armodskår',),
'armring': ('armring',),
'armringen': ('armring',),
'armringene': ('armring',),
'armringer': ('armring',),
'armrom': ('armrom',),
'armromma': ('armrom',),
'armrommene': ('armrom',),
'armrommet': ('armrom',),
'armslag': ('armslag',),
'armslaga': ('armslag',),
'armslagene': ('armslag',),
'armslaget': ('armslag',),
'armsving': ('armsving',),
'armsvingen': ('armsving',),
'armsvingene': ('armsving',),
'armsvinger': ('armsving',),
'armtak': ('armtak',),
'armtaka': ('armtak',),
'armtakene': ('armtak',),
'armtaket': ('armtak',),
'arne': ('arne',),
'arnen': ('arne',),
'arnene': ('arne',),
'arner': ('arne',),
'arnested': ('arnested',),
'arnestedene': ('arnested',),
'arnesteder': ('arnested',),
'arnestedet': ('arnested',),
'aroma': ('aroma',),
'aromaen': ('aroma',),
'aromaene': ('aroma',),
'aromaer': ('aroma',),
'arr': ('arr',),
'arra': ('arr',),
'arrene': ('arr',),
'arret': ('arr',),
'arrangement': ('arrangement',),
'arrangementa': ('arrangement',),
'arrangementene': ('arrangement',),
'arrangementer': ('arrangement',),
'arrangementet': ('arrangement',),
'arrangør': ('arrangør',),
'arrangøren': ('arrangør',),
'arrangørene': ('arrangør',),
'arrangører': ('arrangør',),
'arrangørklubb': ('arrangørklubb',),
'arrangørklubben': ('arrangørklubb',),
'arrangørklubbene': ('arrangørklubb',),
'arrangørklubber': ('arrangørklubb',),
'arrest': ('arrest',),
'arresten': ('arrest',),
'arrestene': ('arrest',),
'arrester': ('arrest',),
'arrestant': ('arrestant',),
'arrestanten': ('arrestant',),
'arrestantene': ('arrestant',),
'arrestanter': ('arrestant',),
'arrestasjon': ('arrestasjon',),
'arrestasjonen': ('arrestasjon',),
'arrestasjonene': ('arrestasjon',),
'arrestasjoner': ('arrestasjon',),
'arrestering': ('arrestering',),
'arresteringa': ('arrestering',),
'arresteringen': ('arrestering',),
'arresteringene': ('arrestering',),
'arresteringer': ('arrestering',),
'arrestkrav': ('arrestkrav',),
'arrestkrava': ('arrestkrav',),
'arrestkravene': ('arrestkrav',),
'arrestkravet': ('arrestkrav',),
'arrestlokala': ('arrestlokale',),
'arrestlokale': ('arrestlokale',),
'arrestlokalene': ('arrestlokale',),
'arrestlokaler': ('arrestlokale',),
'arrestlokalet': ('arrestlokale',),
'arrestordre': ('arrestordre',),
'arrestordren': ('arrestordre',),
'arrestordrene': ('arrestordre',),
'arrestordrer': ('arrestordre',),
'arresttillatelse': ('arresttillatelse',),
'arresttillatelsen': ('arresttillatelse',),
'arresttillatelsene': ('arresttillatelse',),
'arresttillatelser': ('arresttillatelse',),
'arrighet': ('arrighet',),
'arrigheta': ('arrighet',),
'arrigheten': ('arrighet',),
'arrighetene': ('arrighet',),
'arrigheter': ('arrighet',),
'arrigskap': ('arrigskap',),
'arrigskapen': ('arrigskap',),
'arrigskapene': ('arrigskap',),
'arrigskaper': ('arrigskap',),
'arroganse': ('arroganse',),
'arrogansen': ('arroganse',),
'arrogansene': ('arroganse',),
'arroganser': ('arroganse',),
'arrondering': ('arrondering',),
'arronderinga': ('arrondering',),
'arronderingen': ('arrondering',),
'arronderingene': ('arrondering',),
'arronderinger': ('arrondering',),
'arrondissement': ('arrondissement',),
'arrondissementa': ('arrondissement',),
'arrondissementene': ('arrondissement',),
'arrondissementer': ('arrondissement',),
'arrondissementet': ('arrondissement',),
'ars': ('ars',),
'artes': ('ars',),
'arsen': ('arsen',),
'arsena': ('arsen',),
'arsenene': ('arsen',),
'arsenet': ('arsen',),
'arsenal': ('arsenal',),
'arsenala': ('arsenal',),
'arsenalene': ('arsenal',),
'arsenaler': ('arsenal',),
'arsenalet': ('arsenal',),
'arsenalforvalter': ('arsenalforvalter',),
'arsenalforvaltere': ('arsenalforvalter',),
'arsenalforvalteren': ('arsenalforvalter',),
'arsenalforvalterer': ('arsenalforvalter',),
'arsenalforvalterne': ('arsenalforvalter',),
'arsenikk': ('arsenikk',),
'arsenikken': ('arsenikk',),
'arsenikkene': ('arsenikk',),
'arsenikker': ('arsenikk',),
'arsenikkforgiftning': ('arsenikkforgiftning',),
'arsenikkforgiftninga': ('arsenikkforgiftning',),
'arsenikkforgiftningen': ('arsenikkforgiftning',),
'arsenikkforgiftningene': ('arsenikkforgiftning',),
'arsenikkforgiftninger': ('arsenikkforgiftning',),
'art': ('art',),
'arta': ('art',),
'arten': ('art',),
'artene': ('art',),
'arter': ('art',),
'art noveau': ('art noveau',),
'arterie': ('arterie',),
'arterien': ('arterie',),
'arteriene': ('arterie',),
'arterier': ('arterie',),
'arterieblod': ('arterieblod',),
'arteriebloda': ('arterieblod',),
'arterieblodene': ('arterieblod',),
'arterieblodet': ('arterieblod',),
'arterieklemma': ('arterieklemme',),
'arterieklemme': ('arterieklemme',),
'arterieklemmen': ('arterieklemme',),
'arterieklemmene': ('arterieklemme',),
'arterieklemmer': ('arterieklemme',),
'arteriosklerose': ('arteriosklerose',),
'arteriosklerosen': ('arteriosklerose',),
'arteriosklerosene': ('arteriosklerose',),
'arterioskleroser': ('arteriosklerose',),
'artianer': ('artianer',),
'artianere': ('artianer',),
'artianeren': ('artianer',),
'artianerer': ('artianer',),
'artianerne': ('artianer',),
'artighet': ('artighet',),
'artigheta': ('artighet',),
'artigheten': ('artighet',),
'artighetene': ('artighet',),
'artigheter': ('artighet',),
'artikkel': ('artikkel',),
'artikkelen': ('artikkel',),
'artiklene': ('artikkel',),
'artikler': ('artikkel',),
'artikkelforfatter': ('artikkelforfatter',),
'artikkelforfattere': ('artikkelforfatter',),
'artikkelforfatteren': ('artikkelforfatter',),
'artikkelforfatterer': ('artikkelforfatter',),
'artikkelforfatterne': ('artikkelforfatter',),
'artikkelskribent': ('artikkelskribent',),
'artikkelskribenten': ('artikkelskribent',),
'artikkelskribentene': ('artikkelskribent',),
'artikkelskribenter': ('artikkelskribent',),
'artikkelskriver': ('artikkelskriver',),
'artikkelskrivere': ('artikkelskriver',),
'artikkelskriveren': ('artikkelskriver',),
'artikkelskriverer': ('artikkelskriver',),
'artikkelskriverne': ('artikkelskriver',),
'artikulasjon': ('artikulasjon',),
'artikulasjonen': ('artikulasjon',),
'artikulasjonene': ('artikulasjon',),
'artikulasjoner': ('artikulasjon',),
'artikulasjonsorgan': ('artikulasjonsorgan',),
'artikulasjonsorgana': ('artikulasjonsorgan',),
'artikulasjonsorganene': ('artikulasjonsorgan',),
'artikulasjonsorganer': ('artikulasjonsorgan',),
'artikulasjonsorganet': ('artikulasjonsorgan',),
'artikulasjonssted': ('artikulasjonssted',),
'artikulasjonsstedene': ('artikulasjonssted',),
'artikulasjonssteder': ('artikulasjonssted',),
'artikulasjonsstedet': ('artikulasjonssted',),
'artilleri': ('artilleri',),
'artilleria': ('artilleri',),
'artilleriene': ('artilleri',),
'artillerier': ('artilleri',),
'artilleriet': ('artilleri',),
'artilleriangrep': ('artilleriangrep',),
'artilleriangrepa': ('artilleriangrep',),
'artilleriangrepene': ('artilleriangrep',),
'artilleriangrepet': ('artilleriangrep',),
'artillerield': ('artillerield',),
'artillerielden': ('artillerield',),
'artillerieldene': ('artillerield',),
'artillerielder': ('artillerield',),
'artilleriild': ('artilleriild',),
'artilleriilden': ('artilleriild',),
'artilleriildene': ('artilleriild',),
'artilleriilder': ('artilleriild',),
'artillerioffiser': ('artillerioffiser',),
'artillerioffiseren': ('artillerioffiser',),
'artillerioffiserene': ('artillerioffiser',),
'artillerioffiserer': ('artillerioffiser',),
'artilleriregiment': ('artilleriregiment',),
'artilleriregimenta': ('artilleriregiment',),
'artilleriregimentene': ('artilleriregiment',),
'artilleriregimenter': ('artilleriregiment',),
'artilleriregimentet': ('artilleriregiment',),
'artillerist': ('artillerist',),
'artilleristen': ('artillerist',),
'artilleristene': ('artillerist',),
'artillerister': ('artillerist',),
'artisjokk': ('artisjokk',),
'artisjokken': ('artisjokk',),
'artisjokkene': ('artisjokk',),
'artisjokker': ('artisjokk',),
'artiskokk': ('artiskokk',),
'artiskokken': ('artiskokk',),
'artiskokkene': ('artiskokk',),
'artiskokker': ('artiskokk',),
'artist': ('artist',),
'artisten': ('artist',),
'artistene': ('artist',),
'artister': ('artist',),
'artisteri': ('artisteri',),
'artisteria': ('artisteri',),
'artisteriene': ('artisteri',),
'artisterier': ('artisteri',),
'artisteriet': ('artisteri',),
'artistopptreden': ('artistopptreden',),
'artistopptredenen': ('artistopptreden',),
'artistopptredenene': ('artistopptreden',),
'artistopptredener': ('artistopptreden',),
'artium': ('artium',),
'artiumen': ('artium',),
'artiumene': ('artium',),
'artiumer': ('artium',),
'artiumsfag': ('artiumsfag',),
'artiumsfaga': ('artiumsfag',),
'artiumsfagene': ('artiumsfag',),
'artiumsfaget': ('artiumsfag',),
'artiumskarakter': ('artiumskarakter',),
'artiumskarakteren': ('artiumskarakter',),
'artiumskarakterene': ('artiumskarakter',),
'artiumskarakterer': ('artiumskarakter',),
'artiumskull': ('artiumskull',),
'artiumskulla': ('artiumskull',),
'artiumskullene': ('artiumskull',),
'artiumskullet': ('artiumskull',),
'artiumslinja': ('artiumslinje',),
'artiumslinje': ('artiumslinje',),
'artiumslinjen': ('artiumslinje',),
'artiumslinjene': ('artiumslinje',),
'artiumslinjer': ('artiumslinje',),
'artiumsresultat': ('artiumsresultat',),
'artiumsresultata': ('artiumsresultat',),
'artiumsresultatene': ('artiumsresultat',),
'artiumsresultater': ('artiumsresultat',),
'artiumsresultatet': ('artiumsresultat',),
'artiumsvitnesbyrd': ('artiumsvitnesbyrd',),
'artiumsvitnesbyrda': ('artiumsvitnesbyrd',),
'artiumsvitnesbyrdene': ('artiumsvitnesbyrd',),
'artiumsvitnesbyrdet': ('artiumsvitnesbyrd',),
'artiumsår': ('artiumsår',),
'artiumsåra': ('artiumsår',),
'artiumsårene': ('artiumsår',),
'artiumsåret': ('artiumsår',),
'artotek': ('artotek',),
'artoteka': ('artotek',),
'artotekene': ('artotek',),
'artoteker': ('artotek',),
'artoteket': ('artotek',),
'artritt': ('artritt',),
'artritten': ('artritt',),
'artrittene': ('artritt',),
'artritter': ('artritt',),
'artsbetegnelse': ('artsbetegnelse',),
'artsbetegnelsen': ('artsbetegnelse',),
'artsbetegnelsene': ('artsbetegnelse',),
'artsbetegnelser': ('artsbetegnelse',),
'artsforskjell': ('artsforskjell',),
'artsforskjellen': ('artsforskjell',),
'artsforskjellene': ('artsforskjell',),
'artsforskjeller': ('artsforskjell',),
'artsforsøk': ('artsforsøk',),
'artsforsøka': ('artsforsøk',),
'artsforsøkene': ('artsforsøk',),
'artsforsøket': ('artsforsøk',),
'artsfredning': ('artsfredning',),
'artsfredninga': ('artsfredning',),
'artsfredningen': ('artsfredning',),
'artsfredningene': ('artsfredning',),
'artsfredninger': ('artsfredning',),
'artskarakter': ('artskarakter',),
'artskarakteren': ('artskarakter',),
'artskarakterene': ('artskarakter',),
'artskarakterer': ('artskarakter',),
'artskrysning': ('artskrysning',),
'artskrysninga': ('artskrysning',),
'artskrysningen': ('artskrysning',),
'artskrysningene': ('artskrysning',),
'artskrysninger': ('artskrysning',),
'artskrysning': ('artskrysning',),
'artskrysninga': ('artskrysning',),
'artskrysningen': ('artskrysning',),
'artskrysningene': ('artskrysning',),
'artskrysninger': ('artskrysning',),
'artskryssing': ('artskryssing',),
'artskryssinga': ('artskryssing',),
'artskryssingen': ('artskryssing',),
'artskryssingene': ('artskryssing',),
'artskryssinger': ('artskryssing',),
'artsnavn': ('artsnavn',),
'artsnavna': ('artsnavn',),
'artsnavnene': ('artsnavn',),
'artsnavnet': ('artsnavn',),
'arv': ('arv',),
'arven': ('arv',),
'arvene': ('arv',),
'arver': ('arv',),
'arve': ('arve',),
'arven': ('arve',),
'arvene': ('arve',),
'arver': ('arve',),
'arveanlegg': ('arveanlegg',),
'arveanlegga': ('arveanlegg',),
'arveanleggene': ('arveanlegg',),
'arveanlegget': ('arveanlegg',),
'arveavgift': ('arveavgift',),
'arveavgifta': ('arveavgift',),
'arveavgiften': ('arveavgift',),
'arveavgiftene': ('arveavgift',),
'arveavgifter': ('arveavgift',),
'arvefall': ('arvefall',),
'arvefalla': ('arvefall',),
'arvefallene': ('arvefall',),
'arvefallet': ('arvefall',),
'arvefesta': ('arvefeste',),
'arvefeste': ('arvefeste',),
'arvefestene': ('arvefeste',),
'arvefester': ('arvefeste',),
'arvefestet': ('arvefeste',),
'arvefiende': ('arvefiende',),
'arvefienden': ('arvefiende',),
'arvefiendene': ('arvefiende',),
'arvefiender': ('arvefiende',),
'arvefyrste': ('arvefyrste',),
'arvefyrsten': ('arvefyrste',),
'arvefyrstene': ('arvefyrste',),
'arvefyrster': ('arvefyrste',),
'arvefølga': ('arvefølge',),
'arvefølge': ('arvefølge',),
'arvefølgen': ('arvefølge',),
'arvefølgene': ('arvefølge',),
'arvefølger': ('arvefølge',),
'arvefølgelov': ('arvefølgelov',),
'arvefølgeloven': ('arvefølgelov',),
'arvefølgelovene': ('arvefølgelov',),
'arvefølgelover': ('arvefølgelov',),
'arvegods': ('arvegods',),
'arvegodsa': ('arvegods',),
'arvegodsene': ('arvegods',),
'arvegodset': ('arvegods',),
'arvehygiene': ('arvehygiene',),
'arvehygienen': ('arvehygiene',),
'arvehygienene': ('arvehygiene',),
'arvehygiener': ('arvehygiene',),
'arvekonge': ('arvekonge',),
'arvekongen': ('arvekonge',),
'arvekongene': ('arvekonge',),
'arvekonger': ('arvekonge',),
'arvekrav': ('arvekrav',),
'arvekrava': ('arvekrav',),
'arvekravene': ('arvekrav',),
'arvekravet': ('arvekrav',),
'arvelater': ('arvelater',),
'arvelatere': ('arvelater',),
'arvelateren': ('arvelater',),
'arvelaterer': ('arvelater',),
'arvelaterne': ('arvelater',),
'arvelighetsforsking': ('arvelighetsforsking',),
'arvelighetsforskinga': ('arvelighetsforsking',),
'arvelighetsforskingen': ('arvelighetsforsking',),
'arvelighetsforskingene': ('arvelighetsforsking',),
'arvelighetsforskinger': ('arvelighetsforsking',),
'arvelighetsforskning': ('arvelighetsforskning',),
'arvelighetsforskninga': ('arvelighetsforskning',),
'arvelighetsforskningen': ('arvelighetsforskning',),
'arvelighetsforskningene': ('arvelighetsforskning',),
'arvelighetsforskninger': ('arvelighetsforskning',),
'arvelodd': ('arvelodd',),
'arvelodden': ('arvelodd',),
'arveloddene': ('arvelodd',),
'arvelodder': ('arvelodd',),
'arvelott': ('arvelott',),
'arvelotten': ('arvelott',),
'arvelottene': ('arvelott',),
'arvelotter': ('arvelott',),
'arvelov': ('arvelov',),
'arveloven': ('arvelov',),
'arvelovene': ('arvelov',),
'arvelover': ('arvelov',),
'arvelæra': ('arvelære',),
'arvelære': ('arvelære',),
'arvelæren': ('arvelære',),
'arvelærene': ('arvelære',),
'arvelærer': ('arvelære',),
'arveonkel': ('arveonkel',),
'arveonkelen': ('arveonkel',),
'arveonklene': ('arveonkel',),
'arveonkler': ('arveonkel',),
'arveord': ('arveord',),
'arveorda': ('arveord',),
'arveordene': ('arveord',),
'arveordet': ('arveord',),
'arvepakt': ('arvepakt',),
'arvepakta': ('arvepakt',),
'arvepakten': ('arvepakt',),
'arvepaktene': ('arvepakt',),
'arvepakter': ('arvepakt',),
'arveprins': ('arveprins',),
'arveprinsen': ('arveprins',),
'arveprinsene': ('arveprins',),
'arveprinser': ('arveprins',),
'arverett': ('arverett',),
'arveretten': ('arverett',),
'arverettene': ('arverett',),
'arveretter': ('arverett',),
'arvesmykka': ('arvesmykke',),
'arvesmykke': ('arvesmykke',),
'arvesmykkene': ('arvesmykke',),
'arvesmykker': ('arvesmykke',),
'arvesmykket': ('arvesmykke',),
'arvestykka': ('arvestykke',),
'arvestykke': ('arvestykke',),
'arvestykkene': ('arvestykke',),
'arvestykker': ('arvestykke',),
'arvestykket': ('arvestykke',),
'arvesynd': ('arvesynd',),
'arvesynda': ('arvesynd',),
'arvesynden': ('arvesynd',),
'arvesyndene': ('arvesynd',),
'arvesynder': ('arvesynd',),
'arvesølv': ('arvesølv',),
'arvesølva': ('arvesølv',),
'arvesølvene': ('arvesølv',),
'arvesølvet': ('arvesølv',),
'arvetanta': ('arvetante',),
'arvetante': ('arvetante',),
'arvetanten': ('arvetante',),
'arvetantene': ('arvetante',),
'arvetanter': ('arvetante',),
'arvetvist': ('arvetvist',),
'arvetvisten': ('arvetvist',),
'arvetvistene': ('arvetvist',),
'arvetvister': ('arvetvist',),
'arveøl': ('arveøl',),
'arveøla': ('arveøl',),
'arveølene': ('arveøl',),
'arveølet': ('arveøl',),
'arving': ('arving',),
'arvingen': ('arving',),
'arvingene': ('arving',),
'arvinger': ('arving',),
'arvtaker': ('arvtaker',),
'arvtakere': ('arvtaker',),
'arvtakeren': ('arvtaker',),
'arvtakerer': ('arvtaker',),
'arvtakerne': ('arvtaker',),
'as': ('as',),
'asa': ('as',),
'asene': ('as',),
'aset': ('as',),
'asal': ('asal',),
'asalen': ('asal',),
'asalene': ('asal',),
'asaler': ('asal',),
'asalbær': ('asalbær',),
'asalbæra': ('asalbær',),
'asalbærene': ('asalbær',),
'asalbæret': ('asalbær',),
'asalea': ('asalea',),
'asaleaen': ('asalea',),
'asaleaene': ('asalea',),
'asaleaer': ('asalea',),
'asbest': ('asbest',),
'asbesten': ('asbest',),
'asbestene': ('asbest',),
'asbester': ('asbest',),
'asbestduk': ('asbestduk',),
'asbestduken': ('asbestduk',),
'asbestdukene': ('asbestduk',),
'asbestduker': ('asbestduk',),
'asbestose': ('asbestose',),
'asbestosen': ('asbestose',),
'asbestosene': ('asbestose',),
'asbestoser': ('asbestose',),
'asbestpapp': ('asbestpapp',),
'asbestpappen': ('asbestpapp',),
'asbestpappene': ('asbestpapp',),
'asbestpapper': ('asbestpapp',),
'asbestplata': ('asbestplate',),
'asbestplate': ('asbestplate',),
'asbestplaten': ('asbestplate',),
'asbestplatene': ('asbestplate',),
'asbestplater': ('asbestplate',),
'ascendens': ('ascendens',),
'ascendensen': ('ascendens',),
'ascendensene': ('ascendens',),
'ascendenser': ('ascendens',),
'ascendent': ('ascendent',),
'ascendenten': ('ascendent',),
'ascendentene': ('ascendent',),
'ascendenter': ('ascendent',),
'asdic': ('asdic',),
'asdicen': ('asdic',),
'asdicene': ('asdic',),
'asdicer': ('asdic',),
'asen': ('asen',),
'asena': ('asen',),
'asenene': ('asen',),
'asener': ('asen',),
'asenet': ('asen',),
'aseptikk': ('aseptikk',),
'aseptikken': ('aseptikk',),
'aseptikkene': ('aseptikk',),
'aseptikker': ('aseptikk',),
'aserbajdsjaner': ('aserbajdsjaner',),
'aserbajdsjanere': ('aserbajdsjaner',),
'aserbajdsjaneren': ('aserbajdsjaner',),
'aserbajdsjanerer': ('aserbajdsjaner',),
'aserbajdsjanerne': ('aserbajdsjaner',),
'asfalt': ('asfalt',),
'asfalten': ('asfalt',),
'asfaltene': ('asfalt',),
'asfalter': ('asfalt',),
'asfaltdekka': ('asfaltdekke',),
'asfaltdekke': ('asfaltdekke',),
'asfaltdekkene': ('asfaltdekke',),
'asfaltdekker': ('asfaltdekke',),
'asfaltdekket': ('asfaltdekke',),
'asfaltjungel': ('asfaltjungel',),
'asfaltjungelen': ('asfaltjungel',),
'asfaltjunglene': ('asfaltjungel',),
'asfaltjungler': ('asfaltjungel',),
'asfaltpapp': ('asfaltpapp',),
'asfaltpappen': ('asfaltpapp',),
'asfaltpappene': ('asfaltpapp',),
'asfaltpapper': ('asfaltpapp',),
'asfaltsliter': ('asfaltsliter',),
'asfaltslitere': ('asfaltsliter',),
'asfaltsliteren': ('asfaltsliter',),
'asfaltsliterer': ('asfaltsliter',),
'asfaltsliterne': ('asfaltsliter',),
'asfalttraver': ('asfalttraver',),
'asfalttravere': ('asfalttraver',),
'asfalttraveren': ('asfalttraver',),
'asfalttraverer': ('asfalttraver',),
'asfalttraverne': ('asfalttraver',),
'asiasjuka': ('asiasjuke',),
'asiasjuke': ('asiasjuke',),
'asiasjuken': ('asiasjuke',),
'asiasjukene': ('asiasjuke',),
'asiasjuker': ('asiasjuke',),
'asiasyka': ('asiasyke',),
'asiasyke': ('asiasyke',),
'asiasyken': ('asiasyke',),
'asiasykene': ('asiasyke',),
'asiasyker': ('asiasyke',),
'asiat': ('asiat',),
'asiaten': ('asiat',),
'asiatene': ('asiat',),
'asiater': ('asiat',),
'asimut': ('asimut',),
'asimuten': ('asimut',),
'asimutene': ('asimut',),
'asimuter': ('asimut',),
'asimutspeil': ('asimutspeil',),
'asimutspeila': ('asimutspeil',),
'asimutspeilene': ('asimutspeil',),
'asimutspeilet': ('asimutspeil',),
'asjett': ('asjett',),
'asjetten': ('asjett',),
'asjettene': ('asjett',),
'asjetter': ('asjett',),
'ask': ('ask',),
'asken': ('ask',),
'askene': ('ask',),
'asker': ('ask',),
'aska': ('aske',),
'aske': ('aske',),
'asken': ('aske',),
'askene': ('aske',),
'asker': ('aske',),
'aska': ('aske',),
'aske': ('aske',),
'asken': ('aske',),
'askene': ('aske',),
'asker': ('aske',),
'askebeger': ('askebeger',),
'askebegeret': ('askebeger',),
'askebegra': ('askebeger',),
'askebegre': ('askebeger',),
'askebegrene': ('askebeger',),
'askebeger': ('askebeger',),
'askebegeret': ('askebeger',),
'askebegra': ('askebeger',),
'askebegre': ('askebeger',),
'askebegrene': ('askebeger',),
'askeladd': ('askeladd',),
'askeladden': ('askeladd',),
'askeladdene': ('askeladd',),
'askeladder': ('askeladd',),
'askeladd': ('askeladd',),
'askeladden': ('askeladd',),
'askeladdene': ('askeladd',),
'askeladder': ('askeladd',),
'askenas': ('askenas',),
'askenasen': ('askenas',),
'askenasene': ('askenas',),
'askenaser': ('askenas',),
'askenasi': ('askenasi',),
'askenasien': ('askenasi',),
'askenasim': ('askenasi',),
'askenasimene': ('askenasi',),
'askeonsdag': ('askeonsdag',),
'askeonsdagen': ('askeonsdag',),
'askeonsdagene': ('askeonsdag',),
'askeonsdager': ('askeonsdag',),
'askeonsdag': ('askeonsdag',),
'askeonsdagen': ('askeonsdag',),
'askeonsdagene': ('askeonsdag',),
'askeonsdager': ('askeonsdag',),
'askepott': ('askepott',),
'askepotten': ('askepott',),
'askepottene': ('askepott',),
'askepotter': ('askepott',),
'askepott': ('askepott',),
'askepotten': ('askepott',),
'askepottene': ('askepott',),
'askepotter': ('askepott',),
'askese': ('askese',),
'askesen': ('askese',),
'askesene': ('askese',),
'askeser': ('askese',),
'asket': ('asket',),
'asketen': ('asket',),
'asketene': ('asket',),
'asketer': ('asket',),
'asketre': ('asketre',),
'asketrea': ('asketre',),
'asketreet': ('asketre',),
'asketrær': ('asketre',),
'asketrærne': ('asketre',),
'askeved': ('askeved',),
'askeveden': ('askeved',),
'askevedene': ('askeved',),
'askeveder': ('askeved',),
'askorbinsyra': ('askorbinsyre',),
'askorbinsyre': ('askorbinsyre',),
'askorbinsyren': ('askorbinsyre',),
'askorbinsyrene': ('askorbinsyre',),
'askorbinsyrer': ('askorbinsyre',),
'asp': ('asp',),
'aspa': ('asp',),
'aspen': ('asp',),
'aspene': ('asp',),
'asper': ('asp',),
'asparges': ('asparges',),
'aspargesen': ('asparges',),
'aspargesene': ('asparges',),
'aspargeser': ('asparges',),
'aspargesbønna': ('aspargesbønne',),
'aspargesbønne': ('aspargesbønne',),
'aspargesbønnen': ('aspargesbønne',),
'aspargesbønnene': ('aspargesbønne',),
'aspargesbønner': ('aspargesbønne',),
'aspargesplanta': ('aspargesplante',),
'aspargesplante': ('aspargesplante',),
'aspargesplanten': ('aspargesplante',),
'aspargesplantene': ('aspargesplante',),
'aspargesplanter': ('aspargesplante',),
'aspargessuppa': ('aspargessuppe',),
'aspargessuppe': ('aspargessuppe',),
'aspargessuppen': ('aspargessuppe',),
'aspargessuppene': ('aspargessuppe',),
'aspargessupper': ('aspargessuppe',),
'aspekt': ('aspekt',),
'aspekta': ('aspekt',),
'aspekten': ('aspekt',),
'aspektene': ('aspekt',),
'aspekter': ('aspekt',),
'aspektet': ('aspekt',),
'aspelauv': ('aspelauv',),
'aspelauva': ('aspelauv',),
'aspelauvene': ('aspelauv',),
'aspelauvet': ('aspelauv',),
'aspeløv': ('aspeløv',),
'aspeløva': ('aspeløv',),
'aspeløvene': ('aspeløv',),
'aspeløvet': ('aspeløv',),
'aspidistra': ('aspidistra',),
'aspidistraen': ('aspidistra',),
'aspidistraene': ('aspidistra',),
'aspidistraer': ('aspidistra',),
'aspik': ('aspik',),
'aspiken': ('aspik',),
'aspikene': ('aspik',),
'aspiker': ('aspik',),
'aspirant': ('aspirant',),
'aspiranten': ('aspirant',),
'aspirantene': ('aspirant',),
'aspiranter': ('aspirant',),
'aspirasjon': ('aspirasjon',),
'aspirasjonen': ('aspirasjon',),
'aspirasjonene': ('aspirasjon',),
'aspirasjoner': ('aspirasjon',),
'aspirasjonsnivå': ('aspirasjonsnivå',),
'aspirasjonsnivåa': ('aspirasjonsnivå',),
'aspirasjonsnivåene': ('aspirasjonsnivå',),
'aspirasjonsnivåer': ('aspirasjonsnivå',),
'aspirasjonsnivået': ('aspirasjonsnivå',),
'ass': ('ass',),
'assen': ('ass',),
'assene': ('ass',),
'asser': ('ass',),
'ass-moll': ('ass-moll',),
'ass-mollen': ('ass-moll',),
'ass-mollene': ('ass-moll',),
'ass-moller': ('ass-moll',),
'assessor': ('assessor',),
'assessoren': ('assessor',),
'assessorene': ('assessor',),
'assessorer': ('assessor',),
'assimilasjon': ('assimilasjon',),
'assimilasjonen': ('assimilasjon',),
'assimilasjonene': ('assimilasjon',),
'assimilasjoner': ('assimilasjon',),
'assimilasjonsevna': ('assimilasjonsevne',),
'assimilasjonsevne': ('assimilasjonsevne',),
'assimilasjonsevnen': ('assimilasjonsevne',),
'assimilasjonsevnene': ('assimilasjonsevne',),
'assimilasjonsevner': ('assimilasjonsevne',),
'assimilasjonsorgan': ('assimilasjonsorgan',),
'assimilasjonsorgana': ('assimilasjonsorgan',),
'assimilasjonsorganene': ('assimilasjonsorgan',),
'assimilasjonsorganer': ('assimilasjonsorgan',),
'assimilasjonsorganet': ('assimilasjonsorgan',),
'assimilering': ('assimilering',),
'assimileringa': ('assimilering',),
'assimileringen': ('assimilering',),
'assimileringene': ('assimilering',),
'assimileringer': ('assimilering',),
'assistanse': ('assistanse',),
'assistansen': ('assistanse',),
'assistansene': ('assistanse',),
'assistanser': ('assistanse',),
'assistent': ('assistent',),
'assistenten': ('assistent',),
'assistentene': ('assistent',),
'assistenter': ('assistent',),
'assistentlege': ('assistentlege',),
'assistentlegen': ('assistentlege',),
'assistentlegene': ('assistentlege',),
'assistentleger': ('assistentlege',),
'assistentstilling': ('assistentstilling',),
'assistentstillinga': ('assistentstilling',),
'assistentstillingen': ('assistentstilling',),
'assistentstillingene': ('assistentstilling',),
'assistentstillinger': ('assistentstilling',),
'assonans': ('assonans',),
'assonansen': ('assonans',),
'assonansene': ('assonans',),
'assonanser': ('assonans',),
'assortiment': ('assortiment',),
'assortimenta': ('assortiment',),
'assortimentene': ('assortiment',),
'assortimenter': ('assortiment',),
'assortimentet': ('assortiment',),
'assosiasjon': ('assosiasjon',),
'assosiasjonen': ('assosiasjon',),
'assosiasjonene': ('assosiasjon',),
'assosiasjoner': ('assosiasjon',),
'assosiasjonspsykologi': ('assosiasjonspsykologi',),
'assosiasjonspsykologien': ('assosiasjonspsykologi',),
'assosiasjonspsykologiene': ('assosiasjonspsykologi',),
'assosiasjonspsykologier': ('assosiasjonspsykologi',),
'assurandør': ('assurandør',),
'assurandøren': ('assurandør',),
'assurandørene': ('assurandør',),
'assurandører': ('assurandør',),
'assuranse': ('assuranse',),
'assuransen': ('assuranse',),
'assuransene': ('assuranse',),
'assuranser': ('assuranse',),
'assuransepremie': ('assuransepremie',),
'assuransepremien': ('assuransepremie',),
'assuransepremiene': ('assuransepremie',),
'assuransepremier': ('assuransepremie',),
'assuranseselskap': ('assuranseselskap',),
'assuranseselskapa': ('assuranseselskap',),
'assuranseselskapene': ('assuranseselskap',),
'assuranseselskaper': ('assuranseselskap',),
'assuranseselskapet': ('assuranseselskap',),
'assuransesvik': ('assuransesvik',),
'assuransesvika': ('assuransesvik',),
'assuransesvikene': ('assuransesvik',),
'assuransesviket': ('assuransesvik',),
'assyrer': ('assyrer',),
'assyrere': ('assyrer',),
'assyreren': ('assyrer',),
'assyrerer': ('assyrer',),
'assyrerne': ('assyrer',),
'assyriolog': ('assyriolog',),
'assyriologen': ('assyriolog',),
'assyriologene': ('assyriolog',),
'assyriologer': ('assyriolog',),
'assyriologi': ('assyriologi',),
'assyriologien': ('assyriologi',),
'assyriologiene': ('assyriologi',),
'assyriologier': ('assyriologi',),
'astat': ('astat',),
'astata': ('astat',),
'astatene': ('astat',),
'astatet': ('astat',),
'asteni': ('asteni',),
'astenien': ('asteni',),
'asteniene': ('asteni',),
'astenier': ('asteni',),
'asteniker': ('asteniker',),
'astenikere': ('asteniker',),
'astenikeren': ('asteniker',),
'astenikerer': ('asteniker',),
'astenikerne': ('asteniker',),
'asterisk': ('asterisk',),
'asterisken': ('asterisk',),
'asteriskene': ('asterisk',),
'asterisker': ('asterisk',),
'asteroide': ('asteroide',),
'asteroiden': ('asteroide',),
'asteroidene': ('asteroide',),
'asteroider': ('asteroide',),
'asters': ('asters',),
'astersen': ('asters',),
'astersene': ('asters',),
'asterser': ('asters',),
'astersbed': ('astersbed',),
'astersbeda': ('astersbed',),
'astersbedene': ('astersbed',),
'astersbedet': ('astersbed',),
'astersbukett': ('astersbukett',),
'astersbuketten': ('astersbukett',),
'astersbukettene': ('astersbukett',),
'astersbuketter': ('astersbukett',),
'astigmatiker': ('astigmatiker',),
'astigmatikere': ('astigmatiker',),
'astigmatikeren': ('astigmatiker',),
'astigmatikerer': ('astigmatiker',),
'astigmatikerne': ('astigmatiker',),
'astigmatisme': ('astigmatisme',),
'astigmatismen': ('astigmatisme',),
'astigmatismene': ('astigmatisme',),
'astigmatismer': ('astigmatisme',),
'astma': ('astma',),
'astmaen': ('astma',),
'astmaene': ('astma',),
'astmaer': ('astma',),
'astmabarn': ('astmabarn',),
'astmabarna': ('astmabarn',),
'astmabarnene': ('astmabarn',),
'astmabarnet': ('astmabarn',),
'astmatiker': ('astmatiker',),
'astmatikere': ('astmatiker',),
'astmatikeren': ('astmatiker',),
'astmatikerer': ('astmatiker',),
'astmatikerne': ('astmatiker',),
'astrakan': ('astrakan',),
'astrakana': ('astrakan',),
'astrakanen': ('astrakan',),
'astrakanene': ('astrakan',),
'astrakaner': ('astrakan',),
'astrakanet': ('astrakan',),
'astrakanepla': ('astrakaneple',),
'astrakaneple': ('astrakaneple',),
'astrakaneplene': ('astrakaneple',),
'astrakanepler': ('astrakaneple',),
'astrakaneplet': ('astrakaneple',),
'astrakanhua': ('astrakanhue',),
'astrakanhue': ('astrakanhue',),
'astrakanhuen': ('astrakanhue',),
'astrakanhuene': ('astrakanhue',),
'astrakanhuer': ('astrakanhue',),
'astrakanhuva': ('astrakanhuve',),
'astrakanhuve': ('astrakanhuve',),
'astrakanhuven': ('astrakanhuve',),
'astrakanhuvene': ('astrakanhuve',),
'astrakanhuver': ('astrakanhuve',),
'astrakanlua': ('astrakanlue',),
'astrakanlue': ('astrakanlue',),
'astrakanluen': ('astrakanlue',),
'astrakanluene': ('astrakanlue',),
'astrakanluer': ('astrakanlue',),
'astrakanluva': ('astrakanluve',),
'astrakanluve': ('astrakanluve',),
'astrakanluven': ('astrakanluve',),
'astrakanluvene': ('astrakanluve',),
'astrakanluver': ('astrakanluve',),
'astrakanskinn': ('astrakanskinn',),
'astrakanskinna': ('astrakanskinn',),
'astrakanskinnene': ('astrakanskinn',),
'astrakanskinnet': ('astrakanskinn',),
'astrallegema': ('astrallegeme',),
'astrallegeme': ('astrallegeme',),
'astrallegemene': ('astrallegeme',),
'astrallegemer': ('astrallegeme',),
'astrallegemet': ('astrallegeme',),
'astrofotometri': ('astrofotometri',),
'astrofotometrien': ('astrofotometri',),
'astrofotometriene': ('astrofotometri',),
'astrofotometrier': ('astrofotometri',),
'astrofysikk': ('astrofysikk',),
'astrofysikken': ('astrofysikk',),
'astrofysikkene': ('astrofysikk',),
'astrofysikker': ('astrofysikk',),
'astrolog': ('astrolog',),
'astrologen': ('astrolog',),
'astrologene': ('astrolog',),
'astrologer': ('astrolog',),
'astrologi': ('astrologi',),
'astrologien': ('astrologi',),
'astrologiene': ('astrologi',),
'astrologier': ('astrologi',),
'astrometri': ('astrometri',),
'astrometrien': ('astrometri',),
'astrometriene': ('astrometri',),
'astrometrier': ('astrometri',),
'astronaut': ('astronaut',),
'astronauten': ('astronaut',),
'astronautene': ('astronaut',),
'astronauter': ('astronaut',),
'astronautikk': ('astronautikk',),
'astronautikken': ('astronautikk',),
'astronautikkene': ('astronautikk',),
'astronautikker': ('astronautikk',),
'astronom': ('astronom',),
'astronomen': ('astronom',),
'astronomene': ('astronom',),
'astronomer': ('astronom',),
'astronomi': ('astronomi',),
'astronomien': ('astronomi',),
'astronomiene': ('astronomi',),
'astronomier': ('astronomi',),
'asur': ('asur',),
'asuren': ('asur',),
'asurene': ('asur',),
'asurer': ('asur',),
'asurblått': ('asurblått',),
'asyl': ('asyl',),
'asyla': ('asyl',),
'asylene': ('asyl',),
'asyler': ('asyl',),
'asylet': ('asyl',),
'asylrett': ('asylrett',),
'asylretten': ('asylrett',),
'asylrettene': ('asylrett',),
'asylretter': ('asylrett',),
'asymmetri': ('asymmetri',),
'asymmetrien': ('asymmetri',),
'asymmetriene': ('asymmetri',),
'asymmetrier': ('asymmetri',),
'asymptote': ('asymptote',),
'asymptoten': ('asymptote',),
'asymptotene': ('asymptote',),
'asymptoter': ('asymptote',),
'asyndese': ('asyndese',),
'asyndesen': ('asyndese',),
'asyndesene': ('asyndese',),
'asyndeser': ('asyndese',),
'asynkronmotor': ('asynkronmotor',),
'asynkronmotoren': ('asynkronmotor',),
'asynkronmotorene': ('asynkronmotor',),
'asynkronmotorer': ('asynkronmotor',),
'at-setning': ('at-setning',),
'at-setninga': ('at-setning',),
'at-setningen': ('at-setning',),
'at-setningene': ('at-setning',),
'at-setninger': ('at-setning',),
'ataraksika': ('ataraksikum',),
'ataraksikaene': ('ataraksikum',),
'ataraksikum': ('ataraksikum',),
'ataraksikumet': ('ataraksikum',),
'atavisme': ('atavisme',),
'atavismen': ('atavisme',),
'atavismene': ('atavisme',),
'atavismer': ('atavisme',),
'ateisme': ('ateisme',),
'ateismen': ('ateisme',),
'ateismene': ('ateisme',),
'ateismer': ('ateisme',),
'ateist': ('ateist',),
'ateisten': ('ateist',),
'ateistene': ('ateist',),
'ateister': ('ateist',),
'atelier': ('atelier',),
'ateliera': ('atelier',),
'atelierene': ('atelier',),
'atelierer': ('atelier',),
'atelieret': ('atelier',),
'atener': ('atener',),
'atenere': ('atener',),
'ateneren': ('atener',),
'atenerer': ('atener',),
'atenerne': ('atener',),
'ateneum': ('ateneum',),
'ateneuma': ('ateneum',),
'ateneumene': ('ateneum',),
'ateneumer': ('ateneum',),
'ateneumet': ('ateneum',),
'aterosklerose': ('aterosklerose',),
'aterosklerosen': ('aterosklerose',),
'aterosklerosene': ('aterosklerose',),
'ateroskleroser': ('aterosklerose',),
'atferd': ('atferd',),
'atferda': ('atferd',),
'atferden': ('atferd',),
'atferdene': ('atferd',),
'atferder': ('atferd',),
'atferdsforsking': ('atferdsforsking',),
'atferdsforskinga': ('atferdsforsking',),
'atferdsforskingen': ('atferdsforsking',),
'atferdsforskingene': ('atferdsforsking',),
'atferdsforskinger': ('atferdsforsking',),
'atferdsforskning': ('atferdsforskning',),
'atferdsforskninga': ('atferdsforskning',),
'atferdsforskningen': ('atferdsforskning',),
'atferdsforskningene': ('atferdsforskning',),
'atferdsforskninger': ('atferdsforskning',),
'atferdsforstyrrelse': ('atferdsforstyrrelse',),
'atferdsforstyrrelsen': ('atferdsforstyrrelse',),
'atferdsforstyrrelsene': ('atferdsforstyrrelse',),
'atferdsforstyrrelser': ('atferdsforstyrrelse',),
'atferdsmønster': ('atferdsmønster',),
'atferdsmønsteret': ('atferdsmønster',),
'atferdsmønstra': ('atferdsmønster',),
'atferdsmønstre': ('atferdsmønster',),
'atferdsmønstrene': ('atferdsmønster',),
'atferdsmønstret': ('atferdsmønster',),
'atferdsnorm': ('atferdsnorm',),
'atferdsnormen': ('atferdsnorm',),
'atferdsnormene': ('atferdsnorm',),
'atferdsnormer': ('atferdsnorm',),
'atferdspsykologi': ('atferdspsykologi',),
'atferdspsykologien': ('atferdspsykologi',),
'atferdspsykologiene': ('atferdspsykologi',),
'atferdspsykologier': ('atferdspsykologi',),
'atferdsterapi': ('atferdsterapi',),
'atferdsterapien': ('atferdsterapi',),
'atferdsterapiene': ('atferdsterapi',),
'atferdsterapier': ('atferdsterapi',),
'atferdsvanske': ('atferdsvanske',),
'atferdsvansken': ('atferdsvanske',),
'atferdsvanskene': ('atferdsvanske',),
'atferdsvansker': ('atferdsvanske',),
'atgeir': ('atgeir',),
'atgeiren': ('atgeir',),
'atgeirene': ('atgeir',),
'atgeirer': ('atgeir',),
'athener': ('athener',),
'athenere': ('athener',),
'atheneren': ('athener',),
'athenerer': ('athener',),
'athenerne': ('athener',),
'atkomst': ('atkomst',),
'atkomsten': ('atkomst',),
'atkomstene': ('atkomst',),
'atkomster': ('atkomst',),
'atkomstdokument': ('atkomstdokument',),
'atkomstdokumenta': ('atkomstdokument',),
'atkomstdokumentene': ('atkomstdokument',),
'atkomstdokumenter': ('atkomstdokument',),
'atkomstdokumentet': ('atkomstdokument',),
'atkomstmangel': ('atkomstmangel',),
'atkomstmangelen': ('atkomstmangel',),
'atkomstmanglene': ('atkomstmangel',),
'atkomstmangler': ('atkomstmangel',),
'atkomstveg': ('atkomstveg',),
'atkomstvegen': ('atkomstveg',),
'atkomstvegene': ('atkomstveg',),
'atkomstveger': ('atkomstveg',),
'atkomstvei': ('atkomstvei',),
'atkomstveien': ('atkomstvei',),
'atkomstveiene': ('atkomstvei',),
'atkomstveier': ('atkomstvei',),
'atlant': ('atlant',),
'atlanten': ('atlant',),
'atlantene': ('atlant',),
'atlanter': ('atlant',),
'atlas': ('atlas',),
'atlasa': ('atlas',),
'atlasene': ('atlas',),
'atlaser': ('atlas',),
'atlaset': ('atlas',),
'atlasbrokade': ('atlasbrokade',),
'atlasbrokaden': ('atlasbrokade',),
'atlasbrokadene': ('atlasbrokade',),
'atlasbrokader': ('atlasbrokade',),
'atlasbrokade': ('atlasbrokade',),
'atlasbrokaden': ('atlasbrokade',),
'atlasbrokadene': ('atlasbrokade',),
'atlasbrokader': ('atlasbrokade',),
'atlask': ('atlask',),
'atlasken': ('atlask',),
'atlaskene': ('atlask',),
'atlasker': ('atlask',),
'atlask': ('atlask',),
'atlasken': ('atlask',),
'atlaskene': ('atlask',),
'atlasker': ('atlask',),
'atlaskbrokade': ('atlaskbrokade',),
'atlaskbrokaden': ('atlaskbrokade',),
'atlaskbrokadene': ('atlaskbrokade',),
'atlaskbrokader': ('atlaskbrokade',),
'atlaskbrokade': ('atlaskbrokade',),
'atlaskbrokaden': ('atlaskbrokade',),
'atlaskbrokadene': ('atlaskbrokade',),
'atlaskbrokader': ('atlaskbrokade',),
'atlaskjole': ('atlaskjole',),
'atlaskjolen': ('atlaskjole',),
'atlaskjolene': ('atlaskjole',),
'atlaskjoler': ('atlaskjole',),
'atlaskkjole': ('atlaskkjole',),
'atlaskkjolen': ('atlaskkjole',),
'atlaskkjolene': ('atlaskkjole',),
'atlaskkjoler': ('atlaskkjole',),
'atlet': ('atlet',),
'atleten': ('atlet',),
'atletene': ('atlet',),
'atleter': ('atlet',),
'atmosfære': ('atmosfære',),
'atmosfæren': ('atmosfære',),
'atmosfærene': ('atmosfære',),
'atmosfærer': ('atmosfære',),
'atoll': ('atoll',),
'atollen': ('atoll',),
'atollene': ('atoll',),
'atoller': ('atoll',),
'atom': ('atom',),
'atoma': ('atom',),
'atomene': ('atom',),
'atomer': ('atom',),
'atomet': ('atom',),
'atomalder': ('atomalder',),
'atomaldere': ('atomalder',),
'atomalderen': ('atomalder',),
'atomalderer': ('atomalder',),
'atomalderne': ('atomalder',),
'atomaldre': ('atomalder',),
'atomaldrene': ('atomalder',),
'atomaldrer': ('atomalder',),
'atombomba': ('atombombe',),
'atombombe': ('atombombe',),
'atombomben': ('atombombe',),
'atombombene': ('atombombe',),
'atombomber': ('atombombe',),
'atomenergi': ('atomenergi',),
'atomenergien': ('atomenergi',),
'atomenergiene': ('atomenergi',),
'atomenergier': ('atomenergi',),
'atomforsker': ('atomforsker',),
'atomforskere': ('atomforsker',),
'atomforskeren': ('atomforsker',),
'atomforskerer': ('atomforsker',),
'atomforskerne': ('atomforsker',),
'atomforsking': ('atomforsking',),
'atomforskinga': ('atomforsking',),
'atomforskingen': ('atomforsking',),
'atomforskingene': ('atomforsking',),
'atomforskinger': ('atomforsking',),
'atomforskning': ('atomforskning',),
'atomforskninga': ('atomforskning',),
'atomforskningen': ('atomforskning',),
'atomforskningene': ('atomforskning',),
'atomforskninger': ('atomforskning',),
'atomfysikk': ('atomfysikk',),
'atomfysikken': ('atomfysikk',),
'atomfysikkene': ('atomfysikk',),
'atomfysikker': ('atomfysikk',),
'atomisme': ('atomisme',),
'atomismen': ('atomisme',),
'atomismene': ('atomisme',),
'atomismer': ('atomisme',),
'atomkjerne': ('atomkjerne',),
'atomkjernen': ('atomkjerne',),
'atomkjernene': ('atomkjerne',),
'atomkjerner': ('atomkjerne',),
'atomkraft': ('atomkraft',),
'atomkrafta': ('atomkraft',),
'atomkraften': ('atomkraft',),
'atomkreftene': ('atomkraft',),
'atomkrefter': ('atomkraft',),
'atomkraftverk': ('atomkraftverk',),
'atomkraftverka': ('atomkraftverk',),
'atomkraftverkene': ('atomkraftverk',),
'atomkraftverker': ('atomkraftverk',),
'atomkraftverket': ('atomkraftverk',),
'atomkrig': ('atomkrig',),
'atomkrigen': ('atomkrig',),
'atomkrigene': ('atomkrig',),
'atomkriger': ('atomkrig',),
'atomladning': ('atomladning',),
'atomladninga': ('atomladning',),
'atomladningen': ('atomladning',),
'atomladningene': ('atomladning',),
'atomladninger': ('atomladning',),
'atommasse': ('atommasse',),
'atommassen': ('atommasse',),
'atommassene': ('atommasse',),
'atommasser': ('atommasse',),
'atommila': ('atommile',),
'atommile': ('atommile',),
'atommilen': ('atommile',),
'atommilene': ('atommile',),
'atommiler': ('atommile',),
'atomnummer': ('atomnummer',),
'atomnummeret': ('atomnummer',),
'atomnumra': ('atomnummer',),
'atomnumre': ('atomnummer',),
'atomnumrene': ('atomnummer',),
'atomreaktor': ('atomreaktor',),
'atomreaktoren': ('atomreaktor',),
'atomreaktorene': ('atomreaktor',),
'atomreaktorer': ('atomreaktor',),
'atomspalting': ('atomspalting',),
'atomspaltinga': ('atomspalting',),
'atomspaltingen': ('atomspalting',),
'atomspaltingene': ('atomspalting',),
'atomspaltinger': ('atomspalting',),
'atomspaltning': ('atomspaltning',),
'atomspaltninga': ('atomspaltning',),
'atomspaltningen': ('atomspaltning',),
'atomspaltningene': ('atomspaltning',),
'atomspaltninger': ('atomspaltning',),
'atomteori': ('atomteori',),
'atomteorien': ('atomteori',),
'atomteoriene': ('atomteori',),
'atomteorier': ('atomteori',),
'atomur': ('atomur',),
'atomura': ('atomur',),
'atomurene': ('atomur',),
'atomuret': ('atomur',),
'atomvekt': ('atomvekt',),
'atomvekta': ('atomvekt',),
'atomvekten': ('atomvekt',),
'atomvektene': ('atomvekt',),
'atomvekter': ('atomvekt',),
'atomvåpen': ('atomvåpen',),
'atomvåpenet': ('atomvåpen',),
'atomvåpna': ('atomvåpen',),
'atomvåpnene': ('atomvåpen',),
'atonalitet': ('atonalitet',),
'atonaliteten': ('atonalitet',),
'atonalitetene': ('atonalitet',),
'atonaliteter': ('atonalitet',),
'atriehage': ('atriehage',),
'atriehagen': ('atriehage',),
'atriehagene': ('atriehage',),
'atriehager': ('atriehage',),
'atriehage': ('atriehage',),
'atriehagen': ('atriehage',),
'atriehagene': ('atriehage',),
'atriehager': ('atriehage',),
'atriehus': ('atriehus',),
'atriehusa': ('atriehus',),
'atriehusene': ('atriehus',),
'atriehuset': ('atriehus',),
'atriehus': ('atriehus',),
'atriehusa': ('atriehus',),
'atriehusene': ('atriehus',),
'atriehuset': ('atriehus',),
'atria': ('atrium',),
'atriene': ('atrium',),
'atrier': ('atrium',),
'atriet': ('atrium',),
'atrium': ('atrium',),
'atriumhage': ('atriumhage',),
'atriumhagen': ('atriumhage',),
'atriumhagene': ('atriumhage',),
'atriumhager': ('atriumhage',),
'atriumhage': ('atriumhage',),
'atriumhagen': ('atriumhage',),
'atriumhagene': ('atriumhage',),
'atriumhager': ('atriumhage',),
'atriumhus': ('atriumhus',),
'atriumhusa': ('atriumhus',),
'atriumhusene': ('atriumhus',),
'atriumhuset': ('atriumhus',),
'atriumhus': ('atriumhus',),
'atriumhusa': ('atriumhus',),
'atriumhusene': ('atriumhus',),
'atriumhuset': ('atriumhus',),
'atrofi': ('atrofi',),
'atrofien': ('atrofi',),
'atrofiene': ('atrofi',),
'atrofier': ('atrofi',),
'atropin': ('atropin',),
'atropina': ('atropin',),
'atropinene': ('atropin',),
'atropinet': ('atropin',),
'atropininjeksjon': ('atropininjeksjon',),
'atropininjeksjonen': ('atropininjeksjon',),
'atropininjeksjonene': ('atropininjeksjon',),
'atropininjeksjoner': ('atropininjeksjon',),
'atropintablett': ('atropintablett',),
'atropintabletten': ('atropintablett',),
'atropintablettene': ('atropintablett',),
'atropintabletter': ('atropintablett',),
'atskillelse': ('atskillelse',),
'atskillelsen': ('atskillelse',),
'atskillelsene': ('atskillelse',),
'atskillelser': ('atskillelse',),
'atspredelse': ('atspredelse',),
'atspredelsen': ('atspredelse',),
'atspredelsene': ('atspredelse',),
'atspredelser': ('atspredelse',),
'attacheen': ('attaché',),
'attacheene': ('attaché',),
'attacheer': ('attaché',),
'attaché': ('attaché',),
'attachéen': ('attaché',),
'attachéene': ('attaché',),
'attachéer': ('attaché',),
'attakk': ('attakk',),
'attakka': ('attakk',),
'attakkene': ('attakk',),
'attakker': ('attakk',),
'attakket': ('attakk',),
'attendel': ('attendel',),
'attendelen': ('attendel',),
'attendelene': ('attendel',),
'attendeler': ('attendel',),
'attenhundretal': ('attenhundretal',),
'attenhundretala': ('attenhundretal',),
'attenhundretalene': ('attenhundretal',),
'attenhundretalet': ('attenhundretal',),
'attenhundretall': ('attenhundretall',),
'attenhundretalla': ('attenhundretall',),
'attenhundretallene': ('attenhundretall',),
'attenhundretallet': ('attenhundretall',),
'attentat': ('attentat',),
'attentata': ('attentat',),
'attentatene': ('attentat',),
'attentater': ('attentat',),
'attentatet': ('attentat',),
'attentatforsøk': ('attentatforsøk',),
'attentatforsøka': ('attentatforsøk',),
'attentatforsøkene': ('attentatforsøk',),
'attentatforsøket': ('attentatforsøk',),
'attentatmann': ('attentatmann',),
'attentatmannen': ('attentatmann',),
'attentatmenn': ('attentatmann',),
'attentatmennene': ('attentatmann',),
'attenåring': ('attenåring',),
'attenåringen': ('attenåring',),
'attenåringene': ('attenåring',),
'attenåringer': ('attenåring',),
'attenårsalder': ('attenårsalder',),
'attenårsaldere': ('attenårsalder',),
'attenårsalderen': ('attenårsalder',),
'attenårsalderer': ('attenårsalder',),
'attenårsalderne': ('attenårsalder',),
'attenårsaldre': ('attenårsalder',),
'attenårsaldrene': ('attenårsalder',),
'attenårsaldrer': ('attenårsalder',),
'attenårsgrensa': ('attenårsgrense',),
'attenårsgrense': ('attenårsgrense',),
'attenårsgrensen': ('attenårsgrense',),
'attenårsgrensene': ('attenårsgrense',),
'attenårsgrenser': ('attenårsgrense',),
'atterbud': ('atterbud',),
'atterbuda': ('atterbud',),
'atterbudene': ('atterbud',),
'atterbudet': ('atterbud',),
'attergløyma': ('attergløyme',),
'attergløyme': ('attergløyme',),
'attergløymen': ('attergløyme',),
'attergløymene': ('attergløyme',),
'attergløymer': ('attergløyme',),
'attersting': ('attersting',),
'atterstinga': ('attersting',),
'atterstingene': ('attersting',),
'atterstinget': ('attersting',),
'attest': ('attest',),
'attesten': ('attest',),
'attestene': ('attest',),
'attester': ('attest',),
'attestant': ('attestant',),
'attestanten': ('attestant',),
'attestantene': ('attestant',),
'attestanter': ('attestant',),
'attestasjon': ('attestasjon',),
'attestasjonen': ('attestasjon',),
'attestasjonene': ('attestasjon',),
'attestasjoner': ('attestasjon',),
'attestering': ('attestering',),
'attesteringa': ('attestering',),
'attesteringen': ('attestering',),
'attesteringene': ('attestering',),
'attesteringer': ('attestering',),
'attestkopi': ('attestkopi',),
'attestkopien': ('attestkopi',),
'attestkopiene': ('attestkopi',),
'attestkopier': ('attestkopi',),
'attføring': ('attføring',),
'attføringa': ('attføring',),
'attføringen': ('attføring',),
'attføringene': ('attføring',),
'attføringer': ('attføring',),
'attføringsinstitutt': ('attføringsinstitutt',),
'attføringsinstitutta': ('attføringsinstitutt',),
'attføringsinstituttene': ('attføringsinstitutt',),
'attføringsinstitutter': ('attføringsinstitutt',),
'attføringsinstituttet': ('attføringsinstitutt',),
'attføringstrygd': ('attføringstrygd',),
'attføringstrygda': ('attføringstrygd',),
'attføringstrygden': ('attføringstrygd',),
'attføringstrygdene': ('attføringstrygd',),
'attføringstrygder': ('attføringstrygd',),
'attityde': ('attityde',),
'attityden': ('attityde',),
'attitydene': ('attityde',),
'attityder': ('attityde',),
'attpåklatt': ('attpåklatt',),
'attpåklatten': ('attpåklatt',),
'attpåklattene': ('attpåklatt',),
'attpåklatter': ('attpåklatt',),
'attpåsleng': ('attpåsleng',),
'attpåslenga': ('attpåsleng',),
'attpåslengene': ('attpåsleng',),
'attpåslenget': ('attpåsleng',),
'attraksjon': ('attraksjon',),
'attraksjonen': ('attraksjon',),
'attraksjonene': ('attraksjon',),
'attraksjoner': ('attraksjon',),
'attrapp': ('attrapp',),
'attrappen': ('attrapp',),
'attrappene': ('attrapp',),
'attrapper': ('attrapp',),
'attributt': ('attributt',),
'attributta': ('attributt',),
'attributtene': ('attributt',),
'attributter': ('attributt',),
'attributtet': ('attributt',),
'attrå': ('attrå',),
'attråen': ('attrå',),
'attråene': ('attrå',),
'attråer': ('attrå',),
'attåtarbeid': ('attåtarbeid',),
'attåtarbeida': ('attåtarbeid',),
'attåtarbeidene': ('attåtarbeid',),
'attåtarbeider': ('attåtarbeid',),
'attåtarbeidet': ('attåtarbeid',),
'attåtnæring': ('attåtnæring',),
'attåtnæringa': ('attåtnæring',),
'attåtnæringen': ('attåtnæring',),
'attåtnæringene': ('attåtnæring',),
'attåtnæringer': ('attåtnæring',),
'atypi': ('atypi',),
'atypien': ('atypi',),
'atypiene': ('atypi',),
'atypier': ('atypi',),
'au': ('au',),
'aua': ('au',),
'auene': ('au',),
'auet': ('au',),
'au pair': ('au pair',),
'au pair-arbeid': ('au pair-arbeid',),
'au pair-arbeida': ('au pair-arbeid',),
'au pair-arbeidene': ('au pair-arbeid',),
'au pair-arbeider': ('au pair-arbeid',),
'au pair-arbeidet': ('au pair-arbeid',),
'au pair-jenta': ('au pair-jente',),
'au pair-jente': ('au pair-jente',),
'au pair-jenten': ('au pair-jente',),
'au pair-jentene': ('au pair-jente',),
'au pair-jenter': ('au pair-jente',),
'aubergine': ('aubergine',),
'auberginen': ('aubergine',),
'auberginene': ('aubergine',),
'auberginer': ('aubergine',),
'audiens': ('audiens',),
'audiensen': ('audiens',),
'audiensene': ('audiens',),
'audienser': ('audiens',),
'audiensrom': ('audiensrom',),
'audiensromma': ('audiensrom',),
'audiensrommene': ('audiensrom',),
'audiensrommet': ('audiensrom',),
'audienssal': ('audienssal',),
'audienssalen': ('audienssal',),
'audienssalene': ('audienssal',),
'audienssaler': ('audienssal',),
'audiolog': ('audiolog',),
'audiologen': ('audiolog',),
'audiologene': ('audiolog',),
'audiologer': ('audiolog',),
'audiologi': ('audiologi',),
'audiologien': ('audiologi',),
'audiologiene': ('audiologi',),
'audiologier': ('audiologi',),
'audiometer': ('audiometer',),
'audiometeret': ('audiometer',),
'audiometra': ('audiometer',),
'audiometre': ('audiometer',),
'audiometrene': ('audiometer',),
'audiometret': ('audiometer',),
'auditoria': ('auditorium',),
'auditoriene': ('auditorium',),
'auditorier': ('auditorium',),
'auditoriet': ('auditorium',),
'auditorium': ('auditorium',),
'augiasstall': ('augiasstall',),
'augiasstallen': ('augiasstall',),
'augiasstallene': ('augiasstall',),
'augiasstaller': ('augiasstall',),
'augur': ('augur',),
'auguren': ('augur',),
'augurene': ('augur',),
'augurer': ('augur',),
'augursmil': ('augursmil',),
'augursmila': ('augursmil',),
'augursmilen': ('augursmil',),
'augursmilene': ('augursmil',),
'augursmilet': ('augursmil',),
'august': ('august',),
'augustiner': ('augustiner',),
'augustinere': ('augustiner',),
'augustineren': ('augustiner',),
'augustinerer': ('augustiner',),
'augustinerne': ('augustiner',),
'augustinerkloster': ('augustinerkloster',),
'augustinerklosteret': ('augustinerkloster',),
'augustinerklostra': ('augustinerkloster',),
'augustinerklostre': ('augustinerkloster',),
'augustinerklostrene': ('augustinerkloster',),
'augustinerklostret': ('augustinerkloster',),
'augustinermunk': ('augustinermunk',),
'augustinermunken': ('augustinermunk',),
'augustinermunkene': ('augustinermunk',),
'augustinermunker': ('augustinermunk',),
'augustinernonna': ('augustinernonne',),
'augustinernonne': ('augustinernonne',),
'augustinernonnen': ('augustinernonne',),
'augustinernonnene': ('augustinernonne',),
'augustinernonner': ('augustinernonne',),
'auke': ('auke',),
'auken': ('auke',),
'aukene': ('auke',),
'auker': ('auke',),
'auking': ('auking',),
'aukinga': ('auking',),
'aukingen': ('auking',),
'aukingene': ('auking',),
'aukinger': ('auking',),
'aukingsmonn': ('aukingsmonn',),
'aukingsmonna': ('aukingsmonn',),
'aukingsmonnen': ('aukingsmonn',),
'aukingsmonnene': ('aukingsmonn',),
'aukingsmonner': ('aukingsmonn',),
'aukingsmonnet': ('aukingsmonn',),
'auksjon': ('auksjon',),
'auksjonen': ('auksjon',),
'auksjonene': ('auksjon',),
'auksjoner': ('auksjon',),
'auksjonariene': ('auksjonarius',),
'auksjonarier': ('auksjonarius',),
'auksjonarius': ('auksjonarius',),
'auksjonariusen': ('auksjonarius',),
'auksjonsbord': ('auksjonsbord',),
'auksjonsborda': ('auksjonsbord',),
'auksjonsbordene': ('auksjonsbord',),
'auksjonsborder': ('auksjonsbord',),
'auksjonsbordet': ('auksjonsbord',),
'auksjonsforretning': ('auksjonsforretning',),
'auksjonsforretninga': ('auksjonsforretning',),
'auksjonsforretningen': ('auksjonsforretning',),
'auksjonsforretningene': ('auksjonsforretning',),
'auksjonsforretninger': ('auksjonsforretning',),
'auksjonsgrunnlag': ('auksjonsgrunnlag',),
'auksjonsgrunnlaga': ('auksjonsgrunnlag',),
'auksjonsgrunnlagene': ('auksjonsgrunnlag',),
'auksjonsgrunnlaget': ('auksjonsgrunnlag',),
'auksjonshammar': ('auksjonshammar',),
'auksjonshammaren': ('auksjonshammar',),
'auksjonshamrene': ('auksjonshammar',),
'auksjonshamrer': ('auksjonshammar',),
'auksjonshammer': ('auksjonshammer',),
'auksjonshammere': ('auksjonshammer',),
'auksjonshammeren': ('auksjonshammer',),
'auksjonshammerer': ('auksjonshammer',),
'auksjonshammerne': ('auksjonshammer',),
'auksjonshamrene': ('auksjonshammer',),
'auksjonshamrer': ('auksjonshammer',),
'auksjonskatalog': ('auksjonskatalog',),
'auksjonskatalogen': ('auksjonskatalog',),
'auksjonskatalogene': ('auksjonskatalog',),
'auksjonskataloger': ('auksjonskatalog',),
'auksjonslokala': ('auksjonslokale',),
'auksjonslokale': ('auksjonslokale',),
'auksjonslokalene': ('auksjonslokale',),
'auksjonslokaler': ('auksjonslokale',),
'auksjonslokalet': ('auksjonslokale',),
'aula': ('aula',),
'aulaen': ('aula',),
'aulaene': ('aula',),
'aulaer': ('aula',),
'aur': ('aur',),
'auren': ('aur',),
'aurene': ('aur',),
'aurer': ('aur',),
'aura': ('aura',),
'auraen': ('aura',),
'auraene': ('aura',),
'auraer': ('aura',),
'aurbakke': ('aurbakke',),
'aurbakken': ('aurbakke',),
'aurbakkene': ('aurbakke',),
'aurbakker': ('aurbakke',),
'aurbotn': ('aurbotn',),
'aurbotnen': ('aurbotn',),
'aurbotnene': ('aurbotn',),
'aurbotner': ('aurbotn',),
'aurbunn': ('aurbunn',),
'aurbunnen': ('aurbunn',),
'aurbunnene': ('aurbunn',),
'aurbunner': ('aurbunn',),
'aure': ('aure',),
'auren': ('aure',),
'aurene': ('aure',),
'aurer': ('aure',),
'aurikkel': ('aurikkel',),
'aurikkelen': ('aurikkel',),
'auriklene': ('aurikkel',),
'aurikler': ('aurikkel',),
'aurjord': ('aurjord',),
'aurjorda': ('aurjord',),
'aurjorden': ('aurjord',),
'aurjordene': ('aurjord',),
'aurjorder': ('aurjord',),
'aurora': ('aurora',),
'auroraen': ('aurora',),
'auroraene': ('aurora',),
'auroraer': ('aurora',),
'aurum': ('aurum',),
'ausa': ('ause',),
'ause': ('ause',),
'ausen': ('ause',),
'ausene': ('ause',),
'auser': ('ause',),
'ausefat': ('ausefat',),
'ausefata': ('ausefat',),
'ausefatene': ('ausefat',),
'ausefater': ('ausefat',),
'ausefatet': ('ausefat',),
'ausekar': ('ausekar',),
'ausekara': ('ausekar',),
'ausekarene': ('ausekar',),
'ausekaret': ('ausekar',),
'auspisiene': ('auspisier',),
'auspisier': ('auspisier',),
'aust': ('aust',),
'austasiat': ('austasiat',),
'austasiaten': ('austasiat',),
'austasiatene': ('austasiat',),
'austasiater': ('austasiat',),
'austavind': ('austavind',),
'austavinden': ('austavind',),
'austavindene': ('austavind',),
'austavinder': ('austavind',),
'austavær': ('austavær',),
'austaværa': ('austavær',),
'austaværene': ('austavær',),
'austaværet': ('austavær',),
'austblokk': ('austblokk',),
'austblokka': ('austblokk',),
'austblokken': ('austblokk',),
'austblokkene': ('austblokk',),
'austblokker': ('austblokk',),
'austblokkland': ('austblokkland',),
'austblokklanda': ('austblokkland',),
'austblokklandene': ('austblokkland',),
'austblokklandet': ('austblokkland',),
'austerveg': ('austerveg',),
'austeuropeer': ('austeuropeer',),
'austeuropeere': ('austeuropeer',),
'austeuropeeren': ('austeuropeer',),
'austeuropeerer': ('austeuropeer',),
'austeuropeerne': ('austeuropeer',),
'austfront': ('austfront',),
'austfronten': ('austfront',),
'austfrontene': ('austfront',),
'austfronter': ('austfront',),
'austgoter': ('austgoter',),
'austgotere': ('austgoter',),
'austgoteren': ('austgoter',),
'austgoterer': ('austgoter',),
'austgoterne': ('austgoter',),
'austhandel': ('austhandel',),
'austhandelen': ('austhandel',),
'austhandlene': ('austhandel',),
'austhandler': ('austhandel',),
'austhimlene': ('austhimmel',),
'austhimler': ('austhimmel',),
'austhimmel': ('austhimmel',),
'austhimmelen': ('austhimmel',),
'austkant': ('austkant',),
'austkanten': ('austkant',),
'austkantene': ('austkant',),
'austkanter': ('austkant',),
'austkyst': ('austkyst',),
'austkysten': ('austkyst',),
'austkystene': ('austkyst',),
'austkyster': ('austkyst',),
'austlandsk': ('austlandsk',),
'austlandsken': ('austlandsk',),
'austlandskene': ('austlandsk',),
'austlandsker': ('austlandsk',),
'austlandsmål': ('austlandsmål',),
'austlandsmåla': ('austlandsmål',),
'austlandsmålene': ('austlandsmål',),
'austlandsmålet': ('austlandsmål',),
'austlending': ('austlending',),
'austlendingen': ('austlending',),
'austlendingene': ('austlending',),
'austlendinger': ('austlending',),
'austmark': ('austmark',),
'austmarka': ('austmark',),
'austmarken': ('austmark',),
'austmarkene': ('austmark',),
'austmarker': ('austmark',),
'austnorsk': ('austnorsk',),
'austnorsken': ('austnorsk',),
'austnorskene': ('austnorsk',),
'austnorsker': ('austnorsk',),
'australier': ('australier',),
'australiere': ('australier',),
'australieren': ('australier',),
'australierer': ('australier',),
'australierne': ('australier',),
'australneger': ('australneger',),
'australnegeren': ('australneger',),
'australnegerene': ('australneger',),
'australnegerer': ('australneger',),
'austromarxisme': ('austromarxisme',),
'austromarxismen': ('austromarxisme',),
'austromarxismene': ('austromarxisme',),
'austromarxismer': ('austromarxisme',),
'austromarxist': ('austromarxist',),
'austromarxisten': ('austromarxist',),
'austromarxistene': ('austromarxist',),
'austromarxister': ('austromarxist',),
'austsida': ('austside',),
'austside': ('austside',),
'austsiden': ('austside',),
'austsidene': ('austside',),
'austsider': ('austside',),
'austtysker': ('austtysker',),
'austtyskere': ('austtysker',),
'austtyskeren': ('austtysker',),
'austtyskerer': ('austtysker',),
'austtyskerne': ('austtysker',),
'autark': ('autark',),
'autarken': ('autark',),
'autarkene': ('autark',),
'autarker': ('autark',),
'autarki': ('autarki',),
'autarkia': ('autarki',),
'autarkiene': ('autarki',),
'autarkier': ('autarki',),
'autarkiet': ('autarki',),
'autentisitet': ('autentisitet',),
'autentisiteten': ('autentisitet',),
'autentisitetene': ('autentisitet',),
'autentisiteter': ('autentisitet',),
'autisme': ('autisme',),
'autismen': ('autisme',),
'autismene': ('autisme',),
'autismer': ('autisme',),
'autist': ('autist',),
'autisten': ('autist',),
'autistene': ('autist',),
'autister': ('autist',),
'autjunksjon': ('autjunksjon',),
'autjunksjonen': ('autjunksjon',),
'autjunksjonene': ('autjunksjon',),
'autjunksjoner': ('autjunksjon',),
'auto': ('auto',),
'autobiografi': ('autobiografi',),
'autobiografien': ('autobiografi',),
'autobiografiene': ('autobiografi',),
'autobiografier': ('autobiografi',),
'autodafeen': ('autodafé',),
'autodafeene': ('autodafé',),
'autodafeer': ('autodafé',),
'autodafé': ('autodafé',),
'autodaféen': ('autodafé',),
'autodaféene': ('autodafé',),
'autodaféer': ('autodafé',),
'autodidakt': ('autodidakt',),
'autodidakten': ('autodidakt',),
'autodidaktene': ('autodidakt',),
'autodidakter': ('autodidakt',),
'autodiesel': ('autodiesel',),
'autodieselen': ('autodiesel',),
'autodieslene': ('autodiesel',),
'autodiesler': ('autodiesel',),
'autogenapparat': ('autogenapparat',),
'autogenapparata': ('autogenapparat',),
'autogenapparatene': ('autogenapparat',),
'autogenapparater': ('autogenapparat',),
'autogenapparatet': ('autogenapparat',),
'autogensveising': ('autogensveising',),
'autogensveisinga': ('autogensveising',),
'autogensveisingen': ('autogensveising',),
'autogensveisingene': ('autogensveising',),
'autogensveisinger': ('autogensveising',),
'autograf': ('autograf',),
'autografen': ('autograf',),
'autografene': ('autograf',),
'autografer': ('autograf',),
'autografjeger': ('autografjeger',),
'autografjegere': ('autografjeger',),
'autografjegeren': ('autografjeger',),
'autografjegerer': ('autografjeger',),
'autografjegerne': ('autografjeger',),
'autografsamler': ('autografsamler',),
'autografsamlere': ('autografsamler',),
'autografsamleren': ('autografsamler',),
'autografsamlerer': ('autografsamler',),
'autografsamlerne': ('autografsamler',),
'autoklav': ('autoklav',),
'autoklaven': ('autoklav',),
'autoklavene': ('autoklav',),
'autoklaver': ('autoklav',),
'autokrat': ('autokrat',),
'autokraten': ('autokrat',),
'autokratene': ('autokrat',),
'autokrater': ('autokrat',),
'autokrati': ('autokrati',),
'autokratia': ('autokrati',),
'autokratiene': ('autokrati',),
'autokratier': ('autokrati',),
'autokratiet': ('autokrati',),
'autolyse': ('autolyse',),
'autolysen': ('autolyse',),
'autolysene': ('autolyse',),
'autolyser': ('autolyse',),
'automasjon': ('automasjon',),
'automasjonen': ('automasjon',),
'automasjonene': ('automasjon',),
'automasjoner': ('automasjon',),
'automat': ('automat',),
'automaten': ('automat',),
'automatene': ('automat',),
'automater': ('automat',),
'automatgir': ('automatgir',),
'automatgira': ('automatgir',),
'automatgirene': ('automatgir',),
'automatgiret': ('automatgir',),
'automatikk': ('automatikk',),
'automatikken': ('automatikk',),
'automatikkene': ('automatikk',),
'automatikker': ('automatikk',),
'automatisering': ('automatisering',),
'automatiseringa': ('automatisering',),
'automatiseringen': ('automatisering',),
'automatiseringene': ('automatisering',),
'automatiseringer': ('automatisering',),
'automatsentral': ('automatsentral',),
'automatsentralen': ('automatsentral',),
'automatsentralene': ('automatsentral',),
'automatsentraler': ('automatsentral',),
'automattelefon': ('automattelefon',),
'automattelefonen': ('automattelefon',),
'automattelefonene': ('automattelefon',),
'automattelefoner': ('automattelefon',),
'automatvåpen': ('automatvåpen',),
'automatvåpenet': ('automatvåpen',),
'automatvåpna': ('automatvåpen',),
'automatvåpnene': ('automatvåpen',),
'automobil': ('automobil',),
'automobilen': ('automobil',),
'automobilene': ('automobil',),
'automobiler': ('automobil',),
'automobilklubb': ('automobilklubb',),
'automobilklubben': ('automobilklubb',),
'automobilklubbene': ('automobilklubb',),
'automobilklubber': ('automobilklubb',),
'autonomi': ('autonomi',),
'autonomien': ('autonomi',),
'autonomiene': ('autonomi',),
'autonomier': ('autonomi',),
'autopilot': ('autopilot',),
'autopiloten': ('autopilot',),
'autopilotene': ('autopilot',),
'autopiloter': ('autopilot',),
'autopsi': ('autopsi',),
'autopsien': ('autopsi',),
'autopsiene': ('autopsi',),
'autopsier': ('autopsi',),
'autor': ('autor',),
'autoren': ('autor',),
'autorene': ('autor',),
'autorer': ('autor',),
'autoreksemplar': ('autoreksemplar',),
'autoreksemplara': ('autoreksemplar',),
'autoreksemplarene': ('autoreksemplar',),
'autoreksemplarer': ('autoreksemplar',),
'autoreksemplaret': ('autoreksemplar',),
'autorhonorar': ('autorhonorar',),
'autorhonorara': ('autorhonorar',),
'autorhonorarene': ('autorhonorar',),
'autorhonorarer': ('autorhonorar',),
'autorhonoraret': ('autorhonorar',),
'autorisasjon': ('autorisasjon',),
'autorisasjonen': ('autorisasjon',),
'autorisasjonene': ('autorisasjon',),
'autorisasjoner': ('autorisasjon',),
'autorisasjonsprøva': ('autorisasjonsprøve',),
'autorisasjonsprøve': ('autorisasjonsprøve',),
'autorisasjonsprøven': ('autorisasjonsprøve',),
'autorisasjonsprøvene': ('autorisasjonsprøve',),
'autorisasjonsprøver': ('autorisasjonsprøve',),
'autoritet': ('autoritet',),
'autoriteten': ('autoritet',),
'autoritetene': ('autoritet',),
'autoriteter': ('autoritet',),
'autoritetsfrykt': ('autoritetsfrykt',),
'autoritetsfrykten': ('autoritetsfrykt',),
'autoritetsfryktene': ('autoritetsfrykt',),
'autoritetsfrykter': ('autoritetsfrykt',),
'autoritetstru': ('autoritetstru',),
'autoritetstrua': ('autoritetstru',),
'autoritetstruen': ('autoritetstru',),
'autoritetstruene': ('autoritetstru',),
'autoritetstruer': ('autoritetstru',),
'autostrada': ('autostrada',),
'autostradaen': ('autostrada',),
'autostradaene': ('autostrada',),
'autostradaer': ('autostrada',),
'autovern': ('autovern',),
'autoverna': ('autovern',),
'autovernene': ('autovern',),
'autovernet': ('autovern',),
'av-middel': ('av-middel',),
'av-middelet': ('av-middel',),
'av-midla': ('av-middel',),
'av-midlene': ('av-middel',),
'av-midler': ('av-middel',),
'av-midlet': ('av-middel',),
'aval': ('aval',),
'avalen': ('aval',),
'avalene': ('aval',),
'avaler': ('aval',),
'avalveksel': ('avalveksel',),
'avalvekselen': ('avalveksel',),
'avalvekslene': ('avalveksel',),
'avalveksler': ('avalveksel',),
'avanse': ('avanse',),
'avansen': ('avanse',),
'avansene': ('avanse',),
'avanser': ('avanse',),
'avansement': ('avansement',),
'avansementa': ('avansement',),
'avansementene': ('avansement',),
'avansementer': ('avansement',),
'avansementet': ('avansement',),
'avansementsmulighet': ('avansementsmulighet',),
'avansementsmuligheta': ('avansementsmulighet',),
'avansementsmuligheten': ('avansementsmulighet',),
'avansementsmulighetene': ('avansementsmulighet',),
'avansementsmuligheter': ('avansementsmulighet',),
'avansementsregel': ('avansementsregel',),
'avansementsregelen': ('avansementsregel',),
'avansementsreglene': ('avansementsregel',),
'avansementsregler': ('avansementsregel',),
'avansementsstilling': ('avansementsstilling',),
'avansementsstillinga': ('avansementsstilling',),
'avansementsstillingen': ('avansementsstilling',),
'avansementsstillingene': ('avansementsstilling',),
'avansementsstillinger': ('avansementsstilling',),
'avansementsvilkår': ('avansementsvilkår',),
'avansementsvilkåra': ('avansementsvilkår',),
'avansementsvilkårene': ('avansementsvilkår',),
'avansementsvilkåret': ('avansementsvilkår',),
'avansestopp': ('avansestopp',),
'avansestoppen': ('avansestopp',),
'avansestoppene': ('avansestopp',),
'avansestopper': ('avansestopp',),
'avansetap': ('avansetap',),
'avansetapa': ('avansetap',),
'avansetapene': ('avansetap',),
'avansetapet': ('avansetap',),
'avantgarde': ('avantgarde',),
'avantgarden': ('avantgarde',),
'avantgardene': ('avantgarde',),
'avantgarder': ('avantgarde',),
'avantgardist': ('avantgardist',),
'avantgardisten': ('avantgardist',),
'avantgardistene': ('avantgardist',),
'avantgardister': ('avantgardist',),
'avart': ('avart',),
'avarta': ('avart',),
'avarten': ('avart',),
'avartene': ('avart',),
'avarter': ('avart',),
'avbenyttelse': ('avbenyttelse',),
'avbenyttelsen': ('avbenyttelse',),
'avbenyttelsene': ('avbenyttelse',),
'avbenyttelser': ('avbenyttelse',),
'avbestilling': ('avbestilling',),
'avbestillinga': ('avbestilling',),
'avbestillingen': ('avbestilling',),
'avbestillingene': ('avbestilling',),
'avbestillinger': ('avbestilling',),
'avbestillingsgebyr': ('avbestillingsgebyr',),
'avbestillingsgebyra': ('avbestillingsgebyr',),
'avbestillingsgebyrene': ('avbestillingsgebyr',),
'avbestillingsgebyrer': ('avbestillingsgebyr',),
'avbestillingsgebyret': ('avbestillingsgebyr',),
'avbetaling': ('avbetaling',),
'avbetalinga': ('avbetaling',),
'avbetalingen': ('avbetaling',),
'avbetalingene': ('avbetaling',),
'avbetalinger': ('avbetaling',),
'avbetalingshandel': ('avbetalingshandel',),
'avbetalingshandelen': ('avbetalingshandel',),
'avbetalingshandlene': ('avbetalingshandel',),
'avbetalingshandler': ('avbetalingshandel',),
'avbetalingskontrakt': ('avbetalingskontrakt',),
'avbetalingskontrakten': ('avbetalingskontrakt',),
'avbetalingskontraktene': ('avbetalingskontrakt',),
'avbetalingskontrakter': ('avbetalingskontrakt',),
'avbetalingssalg': ('avbetalingssalg',),
'avbetalingssalga': ('avbetalingssalg',),
'avbetalingssalgene': ('avbetalingssalg',),
'avbetalingssalget': ('avbetalingssalg',),
'avbetalingssystem': ('avbetalingssystem',),
'avbetalingssystema': ('avbetalingssystem',),
'avbetalingssystemene': ('avbetalingssystem',),
'avbetalingssystemer': ('avbetalingssystem',),
'avbetalingssystemet': ('avbetalingssystem',),
'avbikt': ('avbikt',),
'avbikten': ('avbikt',),
'avbiktene': ('avbikt',),
'avbikter': ('avbikt',),
'avbilda': ('avbilde',),
'avbilde': ('avbilde',),
'avbildene': ('avbilde',),
'avbilder': ('avbilde',),
'avbildet': ('avbilde',),
'avbildning': ('avbildning',),
'avbildninga': ('avbildning',),
'avbildningen': ('avbildning',),
'avbildningene': ('avbildning',),
'avbildninger': ('avbildning',),
'avbiter': ('avbiter',),
'avbitere': ('avbiter',),
'avbiteren': ('avbiter',),
'avbiterer': ('avbiter',),
'avbiterne': ('avbiter',),
'avblåsning': ('avblåsning',),
'avblåsninga': ('avblåsning',),
'avblåsningen': ('avblåsning',),
'avblåsningene': ('avblåsning',),
'avblåsninger': ('avblåsning',),
'avbrekk': ('avbrekk',),
'avbrekka': ('avbrekk',),
'avbrekkene': ('avbrekk',),
'avbrekket': ('avbrekk',),
'avbrott': ('avbrott',),
'avbrotta': ('avbrott',),
'avbrottene': ('avbrott',),
'avbrottet': ('avbrott',),
'avbrottsforsikring': ('avbrottsforsikring',),
'avbrottsforsikringa': ('avbrottsforsikring',),
'avbrottsforsikringen': ('avbrottsforsikring',),
'avbrottsforsikringene': ('avbrottsforsikring',),
'avbrottsforsikringer': ('avbrottsforsikring',),
'avbrudd': ('avbrudd',),
'avbrudda': ('avbrudd',),
'avbruddene': ('avbrudd',),
'avbruddet': ('avbrudd',),
'avbruddsforsikring': ('avbruddsforsikring',),
'avbruddsforsikringa': ('avbruddsforsikring',),
'avbruddsforsikringen': ('avbruddsforsikring',),
'avbruddsforsikringene': ('avbruddsforsikring',),
'avbruddsforsikringer': ('avbruddsforsikring',),
'avbrytelse': ('avbrytelse',),
'avbrytelsen': ('avbrytelse',),
'avbrytelsene': ('avbrytelse',),
'avbrytelser': ('avbrytelse',),
'avbud': ('avbud',),
'avbuda': ('avbud',),
'avbudene': ('avbud',),
'avbudet': ('avbud',),
'avbygd': ('avbygd',),
'avbygda': ('avbygd',),
'avbygden': ('avbygd',),
'avbygdene': ('avbygd',),
'avbygder': ('avbygd',),
'avdal': ('avdal',),
'avdalen': ('avdal',),
'avdalene': ('avdal',),
'avdaler': ('avdal',),
'avdekking': ('avdekking',),
'avdekkinga': ('avdekking',),
'avdekkingen': ('avdekking',),
'avdekkingene': ('avdekking',),
'avdekkinger': ('avdekking',),
'avdekkingslag': ('avdekkingslag',),
'avdekkingslaga': ('avdekkingslag',),
'avdekkingslagene': ('avdekkingslag',),
'avdekkingslaget': ('avdekkingslag',),
'avdekkingssjikt': ('avdekkingssjikt',),
'avdekkingssjikta': ('avdekkingssjikt',),
'avdekkingssjiktene': ('avdekkingssjikt',),
'avdekkingssjiktet': ('avdekkingssjikt',),
'avdekning': ('avdekning',),
'avdekninga': ('avdekning',),
'avdekningen': ('avdekning',),
'avdekningene': ('avdekning',),
'avdekninger': ('avdekning',),
'avdekningslag': ('avdekningslag',),
'avdekningslaga': ('avdekningslag',),
'avdekningslagene': ('avdekningslag',),
'avdekningslaget': ('avdekningslag',),
'avdekningssjikt': ('avdekningssjikt',),
'avdekningssjikta': ('avdekningssjikt',),
'avdekningssjiktene': ('avdekningssjikt',),
'avdekningssjiktet': ('avdekningssjikt',),
'avdeling': ('avdeling',),
'avdelinga': ('avdeling',),
'avdelingen': ('avdeling',),
'avdelingene': ('avdeling',),
'avdelinger': ('avdeling',),
'avdelingskontor': ('avdelingskontor',),
'avdelingskontora': ('avdelingskontor',),
'avdelingskontorene': ('avdelingskontor',),
'avdelingskontorer': ('avdelingskontor',),
'avdelingskontoret': ('avdelingskontor',),
'avdelingsleder': ('avdelingsleder',),
'avdelingsledere': ('avdelingsleder',),
'avdelingslederen': ('avdelingsleder',),
'avdelingslederer': ('avdelingsleder',),
'avdelingslederne': ('avdelingsleder',),
'avdelingslege': ('avdelingslege',),
'avdelingslegen': ('avdelingslege',),
'avdelingslegene': ('avdelingslege',),
'avdelingsleger': ('avdelingslege',),
'avdelingssjef': ('avdelingssjef',),
'avdelingssjefen': ('avdelingssjef',),
'avdelingssjefene': ('avdelingssjef',),
'avdelingssjefer': ('avdelingssjef',),
'avdelingssjukepleier': ('avdelingssjukepleier',),
'avdelingssjukepleiere': ('avdelingssjukepleier',),
'avdelingssjukepleieren': ('avdelingssjukepleier',),
'avdelingssjukepleierer': ('avdelingssjukepleier',),
'avdelingssjukepleierne': ('avdelingssjukepleier',),
'avdelingssykepleier': ('avdelingssykepleier',),
'avdelingssykepleiere': ('avdelingssykepleier',),
'avdelingssykepleieren': ('avdelingssykepleier',),
'avdelingssykepleierer': ('avdelingssykepleier',),
'avdelingssykepleierne': ('avdelingssykepleier',),
'avdrag': ('avdrag',),
'avdraga': ('avdrag',),
'avdragene': ('avdrag',),
'avdraget': ('avdrag',),
'avdragsbeløp': ('avdragsbeløp',),
'avdragsbeløpa': ('avdragsbeløp',),
'avdragsbeløpene': ('avdragsbeløp',),
'avdragsbeløpet': ('avdragsbeløp',),
'avdragsordning': ('avdragsordning',),
'avdragsordninga': ('avdragsordning',),
'avdragsordningen': ('avdragsordning',),
'avdragsordningene': ('avdragsordning',),
'avdragsordninger': ('avdragsordning',),
'avdragssum': ('avdragssum',),
'avdragssummen': ('avdragssum',),
'avdragssummene': ('avdragssum',),
'avdragssummer': ('avdragssum',),
'avdragssystem': ('avdragssystem',),
'avdragssystema': ('avdragssystem',),
'avdragssystemene': ('avdragssystem',),
'avdragssystemer': ('avdragssystem',),
'avdragssystemet': ('avdragssystem',),
'avdrift': ('avdrift',),
'avdrifta': ('avdrift',),
'avdriften': ('avdrift',),
'avdriftene': ('avdrift',),
'avdrifter': ('avdrift',),
'avdriftskompas': ('avdriftskompas',),
'avdriftskompasa': ('avdriftskompas',),
'avdriftskompasen': ('avdriftskompas',),
'avdriftskompasene': ('avdriftskompas',),
'avdriftskompaser': ('avdriftskompas',),
'avdriftskompaset': ('avdriftskompas',),
'avdriftskompass': ('avdriftskompass',),
'avdriftskompassa': ('avdriftskompass',),
'avdriftskompassen': ('avdriftskompass',),
'avdriftskompassene': ('avdriftskompass',),
'avdriftskompasser': ('avdriftskompass',),
'avdriftskompasset': ('avdriftskompass',),
'avdrått': ('avdrått',),
'avdråtten': ('avdrått',),
'avdråttene': ('avdrått',),
'avdråtter': ('avdrått',),
'avdråttsevna': ('avdråttsevne',),
'avdråttsevne': ('avdråttsevne',),
'avdråttsevnen': ('avdråttsevne',),
'avdråttsevnene': ('avdråttsevne',),
'avdråttsevner': ('avdråttsevne',),
'avdråttskontroll': ('avdråttskontroll',),
'avdråttskontrollen': ('avdråttskontroll',),
'avdråttskontrollene': ('avdråttskontroll',),
'avdråttskontroller': ('avdråttskontroll',),
'avduking': ('avduking',),
'avdukinga': ('avduking',),
'avdukingen': ('avduking',),
'avdukingene': ('avduking',),
'avdukinger': ('avduking',),
'avdukingshøgtid': ('avdukingshøgtid',),
'avdukingshøgtida': ('avdukingshøgtid',),
'avdukingshøgtiden': ('avdukingshøgtid',),
'avdukingshøgtidene': ('avdukingshøgtid',),
'avdukingshøgtider': ('avdukingshøgtid',),
'avdukingshøytid': ('avdukingshøytid',),
'avdukingshøytida': ('avdukingshøytid',),
'avdukingshøytiden': ('avdukingshøytid',),
'avdukingshøytidene': ('avdukingshøytid',),
'avdukingshøytider': ('avdukingshøytid',),
'avdukingsseremoni': ('avdukingsseremoni',),
'avdukingsseremonien': ('avdukingsseremoni',),
'avdukingsseremoniene': ('avdukingsseremoni',),
'avdukingsseremonier': ('avdukingsseremoni',),
'ava': ('ave',),
'ave': ('ave',),
'avene': ('ave',),
'aver': ('ave',),
'avet': ('ave',),
'ave-maria': ('ave-maria',),
'ave-mariaene': ('ave-maria',),
'ave-mariaer': ('ave-maria',),
'ave-mariaet': ('ave-maria',),
'avec': ('avec',),
'aveny': ('aveny',),
'avenyen': ('aveny',),
'avenyene': ('aveny',),
'avenyer': ('aveny',),
'avers': ('avers',),
'aversen': ('avers',),
'aversene': ('avers',),
'averser': ('avers',),
'aversan': ('aversan',),
'aversana': ('aversan',),
'aversanene': ('aversan',),
'aversanet': ('aversan',),
'aversankur': ('aversankur',),
'aversankuren': ('aversankur',),
'aversankurene': ('aversankur',),
'aversankurer': ('aversankur',),
'aversjon': ('aversjon',),
'aversjonen': ('aversjon',),
'aversjonene': ('aversjon',),
'aversjoner': ('aversjon',),
'avertering': ('avertering',),
'averteringa': ('avertering',),
'averteringen': ('avertering',),
'averteringene': ('avertering',),
'averteringer': ('avertering',),
'avertissement': ('avertissement',),
'avertissementa': ('avertissement',),
'avertissementene': ('avertissement',),
'avertissementer': ('avertissement',),
'avertissementet': ('avertissement',),
'avfall': ('avfall',),
'avfalla': ('avfall',),
'avfallene': ('avfall',),
'avfallet': ('avfall',),
'avfallsbøtta': ('avfallsbøtte',),
'avfallsbøtte': ('avfallsbøtte',),
'avfallsbøtten': ('avfallsbøtte',),
'avfallsbøttene': ('avfallsbøtte',),
'avfallsbøtter': ('avfallsbøtte',),
'avfallsdunk': ('avfallsdunk',),
'avfallsdunken': ('avfallsdunk',),
'avfallsdunkene': ('avfallsdunk',),
'avfallsdunker': ('avfallsdunk',),
'avfallskvern': ('avfallskvern',),
'avfallskverna': ('avfallskvern',),
'avfallskvernen': ('avfallskvern',),
'avfallskvernene': ('avfallskvern',),
'avfallskverner': ('avfallskvern',),
'avfallsplass': ('avfallsplass',),
'avfallsplassen': ('avfallsplass',),
'avfallsplassene': ('avfallsplass',),
'avfallsplasser': ('avfallsplass',),
'avfallsprodukt': ('avfallsprodukt',),
'avfallsprodukta': ('avfallsprodukt',),
'avfallsproduktene': ('avfallsprodukt',),
'avfallsprodukter': ('avfallsprodukt',),
'avfallsproduktet': ('avfallsprodukt',),
'avfallssjakt': ('avfallssjakt',),
'avfallssjakta': ('avfallssjakt',),
'avfallssjakten': ('avfallssjakt',),
'avfallssjaktene': ('avfallssjakt',),
'avfallssjakter': ('avfallssjakt',),
'avfallsstoff': ('avfallsstoff',),
'avfallsstoffa': ('avfallsstoff',),
'avfallsstoffene': ('avfallsstoff',),
'avfallsstoffer': ('avfallsstoff',),
'avfallsstoffet': ('avfallsstoff',),
'avfolking': ('avfolking',),
'avfolkinga': ('avfolking',),
'avfolkingen': ('avfolking',),
'avfolkingene': ('avfolking',),
'avfolkinger': ('avfolking',),
'avfolkingstendens': ('avfolkingstendens',),
'avfolkingstendensen': ('avfolkingstendens',),
'avfolkingstendensene': ('avfolkingstendens',),
'avfolkingstendenser': ('avfolkingstendens',),
'avfolkning': ('avfolkning',),
'avfolkninga': ('avfolkning',),
'avfolkningen': ('avfolkning',),
'avfolkningene': ('avfolkning',),
'avfolkninger': ('avfolkning',),
'avfolkningstendens': ('avfolkningstendens',),
'avfolkningstendensen': ('avfolkningstendens',),
'avfolkningstendensene': ('avfolkningstendens',),
'avfolkningstendenser': ('avfolkningstendens',),
'avføring': ('avføring',),
'avføringa': ('avføring',),
'avføringen': ('avføring',),
'avføringene': ('avføring',),
'avføringer': ('avføring',),
'avføringsmiddel': ('avføringsmiddel',),
'avføringsmiddelet': ('avføringsmiddel',),
'avføringsmidla': ('avføringsmiddel',),
'avføringsmidlene': ('avføringsmiddel',),
'avføringsmidler': ('avføringsmiddel',),
'avføringsmidlet': ('avføringsmiddel',),
'avføringspilla': ('avføringspille',),
'avføringspille': ('avføringspille',),
'avføringspillen': ('avføringspille',),
'avføringspillene': ('avføringspille',),
'avføringspiller': ('avføringspille',),
'avføringsprøva': ('avføringsprøve',),
'avføringsprøve': ('avføringsprøve',),
'avføringsprøven': ('avføringsprøve',),
'avføringsprøvene': ('avføringsprøve',),
'avføringsprøver': ('avføringsprøve',),
'avgang': ('avgang',),
'avgangen': ('avgang',),
'avgangene': ('avgang',),
'avganger': ('avgang',),
'avgangseksamen': ('avgangseksamen',),
'avgangseksamenen': ('avgangseksamen',),
'avgangseksamenene': ('avgangseksamen',),
'avgangseksamener': ('avgangseksamen',),
'avgangsklassa': ('avgangsklasse',),
'avgangsklasse': ('avgangsklasse',),
'avgangsklassen': ('avgangsklasse',),
'avgangsklassene': ('avgangsklasse',),
'avgangsklasser': ('avgangsklasse',),
'avgangsprøva': ('avgangsprøve',),
'avgangsprøve': ('avgangsprøve',),
'avgangsprøven': ('avgangsprøve',),
'avgangsprøvene': ('avgangsprøve',),
'avgangsprøver': ('avgangsprøve',),
'avgangssignal': ('avgangssignal',),
'avgangssignala': ('avgangssignal',),
'avgangssignalene': ('avgangssignal',),
'avgangssignaler': ('avgangssignal',),
'avgangssignalet': ('avgangssignal',),
'avgangsstasjon': ('avgangsstasjon',),
'avgangsstasjonen': ('avgangsstasjon',),
'avgangsstasjonene': ('avgangsstasjon',),
'avgangsstasjoner': ('avgangsstasjon',),
'avgangstid': ('avgangstid',),
'avgangstida': ('avgangstid',),
'avgangstiden': ('avgangstid',),
'avgangstidene': ('avgangstid',),
'avgangstider': ('avgangstid',),
'avgangsvitnemål': ('avgangsvitnemål',),
'avgangsvitnemåla': ('avgangsvitnemål',),
'avgangsvitnemålene': ('avgangsvitnemål',),
'avgangsvitnemålet': ('avgangsvitnemål',),
'avgangsvitnesbyrd': ('avgangsvitnesbyrd',),
'avgangsvitnesbyrda': ('avgangsvitnesbyrd',),
'avgangsvitnesbyrdene': ('avgangsvitnesbyrd',),
'avgangsvitnesbyrdet': ('avgangsvitnesbyrd',),
'avgass': ('avgass',),
'avgassen': ('avgass',),
'avgassene': ('avgass',),
'avgasser': ('avgass',),
'avgift': ('avgift',),
'avgifta': ('avgift',),
'avgiften': ('avgift',),
'avgiftene': ('avgift',),
'avgifter': ('avgift',),
'avgifting': ('avgifting',),
'avgiftinga': ('avgifting',),
'avgiftingen': ('avgifting',),
'avgiftingene': ('avgifting',),
'avgiftinger': ('avgifting',),
'avgiftning': ('avgiftning',),
'avgiftninga': ('avgiftning',),
'avgiftningen': ('avgiftning',),
'avgiftningene': ('avgiftning',),
'avgiftninger': ('avgiftning',),
'avgiftsplikt': ('avgiftsplikt',),
'avgiftsplikta': ('avgiftsplikt',),
'avgiftsplikten': ('avgiftsplikt',),
'avgiftspliktene': ('avgiftsplikt',),
'avgiftsplikter': ('avgiftsplikt',),
'avgjerd': ('avgjerd',),
'avgjerda': ('avgjerd',),
'avgjerden': ('avgjerd',),
'avgjerdene': ('avgjerd',),
'avgjerder': ('avgjerd',),
'avgjersla': ('avgjersle',),
'avgjersle': ('avgjersle',),
'avgjerslen': ('avgjersle',),
'avgjerslene': ('avgjersle',),
'avgjersler': ('avgjersle',),
'avgjørelse': ('avgjørelse',),
'avgjørelsen': ('avgjørelse',),
'avgjørelsene': ('avgjørelse',),
'avgjørelser': ('avgjørelse',),
'avgjørelsesprosess': ('avgjørelsesprosess',),
'avgjørelsesprosessen': ('avgjørelsesprosess',),
'avgjørelsesprosessene': ('avgjørelsesprosess',),
'avgjørelsesprosesser': ('avgjørelsesprosess',),
'avglans': ('avglans',),
'avglansen': ('avglans',),
'avglansene': ('avglans',),
'avglanser': ('avglans',),
'avgrensing': ('avgrensing',),
'avgrensinga': ('avgrensing',),
'avgrensingen': ('avgrensing',),
'avgrensingene': ('avgrensing',),
'avgrensinger': ('avgrensing',),
'avgrensingsproblem': ('avgrensingsproblem',),
'avgrensingsproblema': ('avgrensingsproblem',),
'avgrensingsproblemene': ('avgrensingsproblem',),
'avgrensingsproblemer': ('avgrensingsproblem',),
'avgrensingsproblemet': ('avgrensingsproblem',),
'avgrensning': ('avgrensning',),
'avgrensninga': ('avgrensning',),
'avgrensningen': ('avgrensning',),
'avgrensningene': ('avgrensning',),
'avgrensninger': ('avgrensning',),
'avgrensningsproblem': ('avgrensningsproblem',),
'avgrensningsproblema': ('avgrensningsproblem',),
'avgrensningsproblemene': ('avgrensningsproblem',),
'avgrensningsproblemer': ('avgrensningsproblem',),
'avgrensningsproblemet': ('avgrensningsproblem',),
'avgrunn': ('avgrunn',),
'avgrunnen': ('avgrunn',),
'avgrunnene': ('avgrunn',),
'avgrunner': ('avgrunn',),
'avgud': ('avgud',),
'avguden': ('avgud',),
'avgudene': ('avgud',),
'avguder': ('avgud',),
'avguderi': ('avguderi',),
'avguderia': ('avguderi',),
'avguderiene': ('avguderi',),
'avguderier': ('avguderi',),
'avguderiet': ('avguderi',),
'avgudsbilda': ('avgudsbilde',),
'avgudsbilde': ('avgudsbilde',),
'avgudsbildene': ('avgudsbilde',),
'avgudsbilder': ('avgudsbilde',),
'avgudsbildet': ('avgudsbilde',),
'avgudsdyrkelse': ('avgudsdyrkelse',),
'avgudsdyrkelsen': ('avgudsdyrkelse',),
'avgudsdyrkelsene': ('avgudsdyrkelse',),
'avgudsdyrkelser': ('avgudsdyrkelse',),
'avgudsdyrker': ('avgudsdyrker',),
'avgudsdyrkere': ('avgudsdyrker',),
'avgudsdyrkeren': ('avgudsdyrker',),
'avgudsdyrkerer': ('avgudsdyrker',),
'avgudsdyrkerne': ('avgudsdyrker',),
'avgudsdyrking': ('avgudsdyrking',),
'avgudsdyrkinga': ('avgudsdyrking',),
'avgudsdyrkingen': ('avgudsdyrking',),
'avgudsdyrkingene': ('avgudsdyrking',),
'avgudsdyrkinger': ('avgudsdyrking',),
'avgudstempel': ('avgudstempel',),
'avgudstempelet': ('avgudstempel',),
'avgudstempla': ('avgudstempel',),
'avgudstemplene': ('avgudstempel',),
'avgudstempler': ('avgudstempel',),
'avgudstemplet': ('avgudstempel',),
'avhandling': ('avhandling',),
'avhandlinga': ('avhandling',),
'avhandlingen': ('avhandling',),
'avhandlingene': ('avhandling',),
'avhandlinger': ('avhandling',),
'avhandlingsstil': ('avhandlingsstil',),
'avhandlingsstilen': ('avhandlingsstil',),
'avhandlingsstilene': ('avhandlingsstil',),
'avhandlingsstiler': ('avhandlingsstil',),
'avhengighet': ('avhengighet',),
'avhengigheta': ('avhengighet',),
'avhengigheten': ('avhengighet',),
'avhengighetene': ('avhengighet',),
'avhengigheter': ('avhengighet',),
'avhengighetsforhold': ('avhengighetsforhold',),
'avhengighetsforholda': ('avhengighetsforhold',),
'avhengighetsforholdene': ('avhengighetsforhold',),
'avhengighetsforholdet': ('avhengighetsforhold',),
'avhengighetsform': ('avhengighetsform',),
'avhengighetsforma': ('avhengighetsform',),
'avhengighetsformen': ('avhengighetsform',),
'avhengighetsformene': ('avhengighetsform',),
'avhengighetsformer': ('avhengighetsform',),
'avhengighetsfølelse': ('avhengighetsfølelse',),
'avhengighetsfølelsen': ('avhengighetsfølelse',),
'avhengighetsfølelsene': ('avhengighetsfølelse',),
'avhengighetsfølelser': ('avhengighetsfølelse',),
'avhol': ('avhol',),
'avhola': ('avhol',),
'avholene': ('avhol',),
'avholet': ('avhol',),
'avhold': ('avhold',),
'avholda': ('avhold',),
'avholdene': ('avhold',),
'avholdet': ('avhold',),
'avholdenhet': ('avholdenhet',),
'avholdenheta': ('avholdenhet',),
'avholdenheten': ('avholdenhet',),
'avholdenhetene': ('avholdenhet',),
'avholdenheter': ('avholdenhet',),
'avholdsarbeid': ('avholdsarbeid',),
'avholdsarbeida': ('avholdsarbeid',),
'avholdsarbeidene': ('avholdsarbeid',),
'avholdsarbeider': ('avholdsarbeid',),
'avholdsarbeidet': ('avholdsarbeid',),
'avholdsbevegelse': ('avholdsbevegelse',),
'avholdsbevegelsen': ('avholdsbevegelse',),
'avholdsbevegelsene': ('avholdsbevegelse',),
'avholdsbevegelser': ('avholdsbevegelse',),
'avholdsfolk': ('avholdsfolk',),
'avholdsfolka': ('avholdsfolk',),
'avholdsfolkene': ('avholdsfolk',),
'avholdsfolket': ('avholdsfolk',),
'avholdslosje': ('avholdslosje',),
'avholdslosjen': ('avholdslosje',),
'avholdslosjene': ('avholdslosje',),
'avholdslosjer': ('avholdslosje',),
'avholdssak': ('avholdssak',),
'avholdssaka': ('avholdssak',),
'avholdssaken': ('avholdssak',),
'avholdssakene': ('avholdssak',),
'avholdssaker': ('avholdssak',),
'avhopper': ('avhopper',),
'avhoppere': ('avhopper',),
'avhopperen': ('avhopper',),
'avhopperer': ('avhopper',),
'avhopperne': ('avhopper',),
'avhull': ('avhull',),
'avhulla': ('avhull',),
'avhullene': ('avhull',),
'avhuller': ('avhull',),
'avhullet': ('avhull',),
'avhør': ('avhør',),
'avhøra': ('avhør',),
'avhørene': ('avhør',),
'avhøret': ('avhør',),
'aviaria': ('aviarium',),
'aviariene': ('aviarium',),
'aviarier': ('aviarium',),
'aviariet': ('aviarium',),
'aviarium': ('aviarium',),
'aviatiker': ('aviatiker',),
'aviatikere': ('aviatiker',),
'aviatikeren': ('aviatiker',),
'aviatikerer': ('aviatiker',),
'aviatikerne': ('aviatiker',),
'aviatikk': ('aviatikk',),
'aviatikken': ('aviatikk',),
'aviatikkene': ('aviatikk',),
'aviatikker': ('aviatikk',),
'avind': ('avind',),
'avinden': ('avind',),
'avindene': ('avind',),
'avinder': ('avind',),
'avis': ('avis',),
'avisa': ('avis',),
'avisen': ('avis',),
'avisene': ('avis',),
'aviser': ('avis',),
'avisand': ('avisand',),
'avisanda': ('avisand',),
'avisanden': ('avisand',),
'avisendene': ('avisand',),
'avisender': ('avisand',),
'avisartikkel': ('avisartikkel',),
'avisartikkelen': ('avisartikkel',),
'avisartiklene': ('avisartikkel',),
'avisartikler': ('avisartikkel',),
'avisbud': ('avisbud',),
'avisbuda': ('avisbud',),
'avisbudene': ('avisbud',),
'avisbudet': ('avisbud',),
'avisdebatt': ('avisdebatt',),
'avisdebatten': ('avisdebatt',),
'avisdebattene': ('avisdebatt',),
'avisdebatter': ('avisdebatt',),
'avisdød': ('avisdød',),
'avisdøden': ('avisdød',),
'avisdødene': ('avisdød',),
'avisdøder': ('avisdød',),
'avisekspedisjon': ('avisekspedisjon',),
'avisekspedisjonen': ('avisekspedisjon',),
'avisekspedisjonene': ('avisekspedisjon',),
'avisekspedisjoner': ('avisekspedisjon',),
'avisfeide': ('avisfeide',),
'avisfeiden': ('avisfeide',),
'avisfeidene': ('avisfeide',),
'avisfeider': ('avisfeide',),
'avisingsanlegg': ('avisingsanlegg',),
'avisingsanlegga': ('avisingsanlegg',),
'avisingsanleggene': ('avisingsanlegg',),
'avisingsanlegget': ('avisingsanlegg',),
'avisinnlegg': ('avisinnlegg',),
'avisinnlegga': ('avisinnlegg',),
'avisinnleggene': ('avisinnlegg',),
'avisinnlegget': ('avisinnlegg',),
'aviskiosk': ('aviskiosk',),
'aviskiosken': ('aviskiosk',),
'aviskioskene': ('aviskiosk',),
'aviskiosker': ('aviskiosk',),
'avisklipp': ('avisklipp',),
'avisklippa': ('avisklipp',),
'avisklippene': ('avisklipp',),
'avisklippet': ('avisklipp',),
'avisklipparkiv': ('avisklipparkiv',),
'avisklipparkiva': ('avisklipparkiv',),
'avisklipparkivene': ('avisklipparkiv',),
'avisklipparkiver': ('avisklipparkiv',),
'avisklipparkivet': ('avisklipparkiv',),
'aviskritikk': ('aviskritikk',),
'aviskritikken': ('aviskritikk',),
'aviskritikkene': ('aviskritikk',),
'aviskritikker': ('aviskritikk',),
'avisoveksel': ('avisoveksel',),
'avisovekselen': ('avisoveksel',),
'avisovekslene': ('avisoveksel',),
'avisoveksler': ('avisoveksel',),
'avisoverskrift': ('avisoverskrift',),
'avisoverskrifta': ('avisoverskrift',),
'avisoverskriften': ('avisoverskrift',),
'avisoverskriftene': ('avisoverskrift',),
'avisoverskrifter': ('avisoverskrift',),
'avispolemikk': ('avispolemikk',),
'avispolemikken': ('avispolemikk',),
'avispolemikkene': ('avispolemikk',),
'avispolemikker': ('avispolemikk',),
'avisredaktør': ('avisredaktør',),
'avisredaktøren': ('avisredaktør',),
'avisredaktørene': ('avisredaktør',),
'avisredaktører': ('avisredaktør',),
'avisreferat': ('avisreferat',),
'avisreferata': ('avisreferat',),
'avisreferatene': ('avisreferat',),
'avisreferater': ('avisreferat',),
'avisreferatet': ('avisreferat',),
'avisskribent': ('avisskribent',),
'avisskribenten': ('avisskribent',),
'avisskribentene': ('avisskribent',),
'avisskribenter': ('avisskribent',),
'avistaveksel': ('avistaveksel',),
'avistavekselen': ('avistaveksel',),
'avistavekslene': ('avistaveksel',),
'avistaveksler': ('avistaveksel',),
'avistegner': ('avistegner',),
'avistegnere': ('avistegner',),
'avistegneren': ('avistegner',),
'avistegnerer': ('avistegner',),
'avistegnerne': ('avistegner',),
'avisutklipp': ('avisutklipp',),
'avisutklippa': ('avisutklipp',),
'avisutklippene': ('avisutklipp',),
'avisutklippet': ('avisutklipp',),
'avkall': ('avkall',),
'avkalla': ('avkall',),
'avkallene': ('avkall',),
'avkallet': ('avkall',),
'avkast': ('avkast',),
'avkasta': ('avkast',),
'avkastene': ('avkast',),
'avkastet': ('avkast',),
'avkasting': ('avkasting',),
'avkastinga': ('avkasting',),
'avkastingen': ('avkasting',),
'avkastingene': ('avkasting',),
'avkastinger': ('avkasting',),
'avkastning': ('avkastning',),
'avkastninga': ('avkastning',),
'avkastningen': ('avkastning',),
'avkastningene': ('avkastning',),
'avkastninger': ('avkastning',),
'avkjøling': ('avkjøling',),
'avkjølinga': ('avkjøling',),
'avkjølingen': ('avkjøling',),
'avkjølingene': ('avkjøling',),
'avkjølinger': ('avkjøling',),
'avkjøring': ('avkjøring',),
'avkjøringa': ('avkjøring',),
'avkjøringen': ('avkjøring',),
'avkjøringene': ('avkjøring',),
'avkjøringer': ('avkjøring',),
'avkjøringsrampa': ('avkjøringsrampe',),
'avkjøringsrampe': ('avkjøringsrampe',),
'avkjøringsrampen': ('avkjøringsrampe',),
'avkjøringsrampene': ('avkjøringsrampe',),
'avkjøringsramper': ('avkjøringsrampe',),
'avkjøringsveg': ('avkjøringsveg',),
'avkjøringsvegen': ('avkjøringsveg',),
'avkjøringsvegene': ('avkjøringsveg',),
'avkjøringsveger': ('avkjøringsveg',),
'avkjøringsvei': ('avkjøringsvei',),
'avkjøringsveien': ('avkjøringsvei',),
'avkjøringsveiene': ('avkjøringsvei',),
'avkjøringsveier': ('avkjøringsvei',),
'avkjørsel': ('avkjørsel',),
'avkjørselen': ('avkjørsel',),
'avkjørsla': ('avkjørsel',),
'avkjørslene': ('avkjørsel',),
'avkjørsler': ('avkjørsel',),
'avklaring': ('avklaring',),
'avklaringa': ('avklaring',),
'avklaringen': ('avklaring',),
'avklaringene': ('avklaring',),
'avklaringer': ('avklaring',),
'avkledingsrom': ('avkledingsrom',),
'avkledingsromma': ('avkledingsrom',),
'avkledingsrommene': ('avkledingsrom',),
'avkledingsrommet': ('avkledingsrom',),
'avkledingsscene': ('avkledingsscene',),
'avkledingsscenen': ('avkledingsscene',),
'avkledingsscenene': ('avkledingsscene',),
'avkledingsscener': ('avkledingsscene',),
'avkledningsrom': ('avkledningsrom',),
'avkledningsromma': ('avkledningsrom',),
'avkledningsrommene': ('avkledningsrom',),
'avkledningsrommet': ('avkledningsrom',),
'avkledningsscene': ('avkledningsscene',),
'avkledningsscenen': ('avkledningsscene',),
'avkledningsscenene': ('avkledningsscene',),
'avkledningsscener': ('avkledningsscene',),
'avkleingsrom': ('avkleingsrom',),
'avkleingsromma': ('avkleingsrom',),
'avkleingsrommene': ('avkleingsrom',),
'avkleingsrommet': ('avkleingsrom',),
'avkleingsscene': ('avkleingsscene',),
'avkleingsscenen': ('avkleingsscene',),
'avkleingsscenene': ('avkleingsscene',),
'avkleingsscener': ('avkleingsscene',),
'avkobling': ('avkobling',),
'avkoblinga': ('avkobling',),
'avkoblingen': ('avkobling',),
'avkoblingene': ('avkobling',),
'avkoblinger': ('avkobling',),
'avkok': ('avkok',),
'avkoka': ('avkok',),
'avkokene': ('avkok',),
'avkoket': ('avkok',),
'avkom': ('avkom',),
'avkomma': ('avkom',),
'avkommene': ('avkom',),
'avkommet': ('avkom',),
'avkomsgransking': ('avkomsgransking',),
'avkomsgranskinga': ('avkomsgransking',),
'avkomsgranskingen': ('avkomsgransking',),
'avkomsgranskingene': ('avkomsgransking',),
'avkomsgranskinger': ('avkomsgransking',),
'avkopling': ('avkopling',),
'avkoplinga': ('avkopling',),
'avkoplingen': ('avkopling',),
'avkoplingene': ('avkopling',),
'avkoplinger': ('avkopling',),
'avkorting': ('avkorting',),
'avkortinga': ('avkorting',),
'avkortingen': ('avkorting',),
'avkortingene': ('avkorting',),
'avkortinger': ('avkorting',),
'avkristning': ('avkristning',),
'avkristninga': ('avkristning',),
'avkristningen': ('avkristning',),
'avkristningene': ('avkristning',),
'avkristninger': ('avkristning',),
'avkrok': ('avkrok',),
'avkroken': ('avkrok',),
'avkrokene': ('avkrok',),
'avkroker': ('avkrok',),
'avlagring': ('avlagring',),
'avlagringa': ('avlagring',),
'avlagringen': ('avlagring',),
'avlagringene': ('avlagring',),
'avlagringer': ('avlagring',),
'avlasting': ('avlasting',),
'avlastinga': ('avlasting',),
'avlastingen': ('avlasting',),
'avlastingene': ('avlasting',),
'avlastinger': ('avlasting',),
'avlastning': ('avlastning',),
'avlastninga': ('avlastning',),
'avlastningen': ('avlastning',),
'avlastningene': ('avlastning',),
'avlastninger': ('avlastning',),
'avlat': ('avlat',),
'avlaten': ('avlat',),
'avlatene': ('avlat',),
'avlater': ('avlat',),
'avlatsbrev': ('avlatsbrev',),
'avlatsbreva': ('avlatsbrev',),
'avlatsbrevene': ('avlatsbrev',),
'avlatsbrever': ('avlatsbrev',),
'avlatsbrevet': ('avlatsbrev',),
'avlatshandel': ('avlatshandel',),
'avlatshandelen': ('avlatshandel',),
'avlatshandlene': ('avlatshandel',),
'avlatshandler': ('avlatshandel',),
'avlatspengene': ('avlatspenger',),
'avlatspenger': ('avlatspenger',),
'avledning': ('avledning',),
'avledninga': ('avledning',),
'avledningen': ('avledning',),
'avledningene': ('avledning',),
'avledninger': ('avledning',),
'avledningsendelse': ('avledningsendelse',),
'avledningsendelsen': ('avledningsendelse',),
'avledningsendelsene': ('avledningsendelse',),
'avledningsendelser': ('avledningsendelse',),
'avledningsending': ('avledningsending',),
'avledningsendinga': ('avledningsending',),
'avledningsendingen': ('avledningsending',),
'avledningsendingene': ('avledningsending',),
'avledningsendinger': ('avledningsending',),
'avledningsgrøft': ('avledningsgrøft',),
'avledningsgrøfta': ('avledningsgrøft',),
'avledningsgrøften': ('avledningsgrøft',),
'avledningsgrøftene': ('avledningsgrøft',),
'avledningsgrøfter': ('avledningsgrøft',),
'avledningsmanøver': ('avledningsmanøver',),
'avledningsmanøvere': ('avledningsmanøver',),
'avledningsmanøveren': ('avledningsmanøver',),
'avledningsmanøverne': ('avledningsmanøver',),
'avledningsmanøvre': ('avledningsmanøver',),
'avledningsmanøvrene': ('avledningsmanøver',),
'avledningsmanøvrer': ('avledningsmanøver',),
'avledningsprefiks': ('avledningsprefiks',),
'avledningsprefiksa': ('avledningsprefiks',),
'avledningsprefiksene': ('avledningsprefiks',),
'avledningsprefikser': ('avledningsprefiks',),
'avledningsprefikset': ('avledningsprefiks',),
'avledningssuffiks': ('avledningssuffiks',),
'avledningssuffiksa': ('avledningssuffiks',),
'avledningssuffiksene': ('avledningssuffiks',),
'avledningssuffikser': ('avledningssuffiks',),
'avledningssuffikset': ('avledningssuffiks',),
'avleevna': ('avleevne',),
'avleevne': ('avleevne',),
'avleevnen': ('avleevne',),
'avleevnene': ('avleevne',),
'avleevner': ('avleevne',),
'avlegger': ('avlegger',),
'avleggere': ('avlegger',),
'avleggeren': ('avlegger',),
'avleggerer': ('avlegger',),
'avleggerne': ('avlegger',),
'avleiing': ('avleiing',),
'avleiinga': ('avleiing',),
'avleiingen': ('avleiing',),
'avleiingene': ('avleiing',),
'avleiinger': ('avleiing',),
'avleiingsendelse': ('avleiingsendelse',),
'avleiingsendelsen': ('avleiingsendelse',),
'avleiingsendelsene': ('avleiingsendelse',),
'avleiingsendelser': ('avleiingsendelse',),
'avleiingsending': ('avleiingsending',),
'avleiingsendinga': ('avleiingsending',),
'avleiingsendingen': ('avleiingsending',),
'avleiingsendingene': ('avleiingsending',),
'avleiingsendinger': ('avleiingsending',),
'avleiingsgrøft': ('avleiingsgrøft',),
'avleiingsgrøfta': ('avleiingsgrøft',),
'avleiingsgrøften': ('avleiingsgrøft',),
'avleiingsgrøftene': ('avleiingsgrøft',),
'avleiingsgrøfter': ('avleiingsgrøft',),
'avleiingsmanøver': ('avleiingsmanøver',),
'avleiingsmanøvere': ('avleiingsmanøver',),
'avleiingsmanøveren': ('avleiingsmanøver',),
'avleiingsmanøverne': ('avleiingsmanøver',),
'avleiingsmanøvre': ('avleiingsmanøver',),
'avleiingsmanøvrene': ('avleiingsmanøver',),
'avleiingsmanøvrer': ('avleiingsmanøver',),
'avleiingsprefiks': ('avleiingsprefiks',),
'avleiingsprefiksa': ('avleiingsprefiks',),
'avleiingsprefiksene': ('avleiingsprefiks',),
'avleiingsprefikser': ('avleiingsprefiks',),
'avleiingsprefikset': ('avleiingsprefiks',),
'avleiingssuffiks': ('avleiingssuffiks',),
'avleiingssuffiksa': ('avleiingssuffiks',),
'avleiingssuffiksene': ('avleiingssuffiks',),
'avleiingssuffikser': ('avleiingssuffiks',),
'avleiingssuffikset': ('avleiingssuffiks',),
'avleiring': ('avleiring',),
'avleiringa': ('avleiring',),
'avleiringen': ('avleiring',),
'avleiringene': ('avleiring',),
'avleiringer': ('avleiring',),
'avlelem': ('avlelem',),
'avlelemma': ('avlelem',),
'avlelemmene': ('avlelem',),
'avlelemmer': ('avlelem',),
'avlelemmet': ('avlelem',),
'avlesing': ('avlesing',),
'avlesinga': ('avlesing',),
'avlesingen': ('avlesing',),
'avlesingene': ('avlesing',),
'avlesinger': ('avlesing',),
'avlesingsfeil': ('avlesingsfeil',),
'avlesingsfeilen': ('avlesingsfeil',),
'avlesingsfeilene': ('avlesingsfeil',),
'avlesning': ('avlesning',),
'avlesninga': ('avlesning',),
'avlesningen': ('avlesning',),
'avlesningene': ('avlesning',),
'avlesninger': ('avlesning',),
'avlesningsfeil': ('avlesningsfeil',),
'avlesningsfeilen': ('avlesningsfeil',),
'avlesningsfeilene': ('avlesningsfeil',),
'avlevering': ('avlevering',),
'avleveringa': ('avlevering',),
'avleveringen': ('avlevering',),
'avleveringene': ('avlevering',),
'avleveringer': ('avlevering',),
'avling': ('avling',),
'avlinga': ('avling',),
'avlingen': ('avling',),
'avlingene': ('avling',),
'avlinger': ('avling',),
'avlingsmengde': ('avlingsmengde',),
'avlingsmengden': ('avlingsmengde',),
'avlingsmengdene': ('avlingsmengde',),
'avlingsmengder': ('avlingsmengde',),
'avlingsskade': ('avlingsskade',),
'avlingsskaden': ('avlingsskade',),
'avlingsskadene': ('avlingsskade',),
'avlingsskader': ('avlingsskade',),
'avlingssvikt': ('avlingssvikt',),
'avlingssvikten': ('avlingssvikt',),
'avlingssviktene': ('avlingssvikt',),
'avlingssvikter': ('avlingssvikt',),
'avlsbuskap': ('avlsbuskap',),
'avlsbuskapen': ('avlsbuskap',),
'avlsbuskapene': ('avlsbuskap',),
'avlsbuskaper': ('avlsbuskap',),
'avlsdyr': ('avlsdyr',),
'avlsdyra': ('avlsdyr',),
'avlsdyrene': ('avlsdyr',),
'avlsdyret': ('avlsdyr',),
'avlsegg': ('avlsegg',),
'avlsegga': ('avlsegg',),
'avlseggene': ('avlsegg',),
'avlsegget': ('avlsegg',),
'avlsgris': ('avlsgris',),
'avlsgrisen': ('avlsgris',),
'avlsgrisene': ('avlsgris',),
'avlsgriser': ('avlsgris',),
'avlshest': ('avlshest',),
'avlshesten': ('avlshest',),
'avlshestene': ('avlshest',),
'avlshester': ('avlshest',),
'avlssenter': ('avlssenter',),
'avlssenteret': ('avlssenter',),
'avlssentra': ('avlssenter',),
'avlssentre': ('avlssenter',),
'avlssentrene': ('avlssenter',),
'avlssentret': ('avlssenter',),
'avlsstamme': ('avlsstamme',),
'avlsstammen': ('avlsstamme',),
'avlsstammene': ('avlsstamme',),
'avlsstammer': ('avlsstamme',),
'avlsutvalg': ('avlsutvalg',),
'avlsutvalga': ('avlsutvalg',),
'avlsutvalgene': ('avlsutvalg',),
'avlsutvalget': ('avlsutvalg',),
'avlsverdi': ('avlsverdi',),
'avlsverdien': ('avlsverdi',),
'avlsverdiene': ('avlsverdi',),
'avlsverdier': ('avlsverdi',),
'avlukka': ('avlukke',),
'avlukke': ('avlukke',),
'avlukkene': ('avlukke',),
'avlukker': ('avlukke',),
'avlukket': ('avlukke',),
'avlyd': ('avlyd',),
'avlyden': ('avlyd',),
'avlydene': ('avlyd',),
'avlyder': ('avlyd',),
'avlydstrinn': ('avlydstrinn',),
'avlydstrinna': ('avlydstrinn',),
'avlydstrinnene': ('avlydstrinn',),
'avlydstrinnet': ('avlydstrinn',),
'avlysing': ('avlysing',),
'avlysinga': ('avlysing',),
'avlysingen': ('avlysing',),
'avlysingene': ('avlysing',),
'avlysinger': ('avlysing',),
'avlysning': ('avlysning',),
'avlysninga': ('avlysning',),
'avlysningen': ('avlysning',),
'avlysningene': ('avlysning',),
'avlysninger': ('avlysning',),
'avløp': ('avløp',),
'avløpa': ('avløp',),
'avløpene': ('avløp',),
'avløpet': ('avløp',),
'avløpsgrøft': ('avløpsgrøft',),
'avløpsgrøfta': ('avløpsgrøft',),
'avløpsgrøften': ('avløpsgrøft',),
'avløpsgrøftene': ('avløpsgrøft',),
'avløpsgrøfter': ('avløpsgrøft',),
'avløpskanal': ('avløpskanal',),
'avløpskanalen': ('avløpskanal',),
'avløpskanalene': ('avløpskanal',),
'avløpskanaler': ('avløpskanal',),
'avløpsledning': ('avløpsledning',),
'avløpsledninga': ('avløpsledning',),
'avløpsledningen': ('avløpsledning',),
'avløpsledningene': ('avløpsledning',),
'avløpsledninger': ('avløpsledning',),
'avløpsrør': ('avløpsrør',),
'avløpsrøra': ('avløpsrør',),
'avløpsrørene': ('avløpsrør',),
'avløpsrøret': ('avløpsrør',),
'avløpsventil': ('avløpsventil',),
'avløpsventilen': ('avløpsventil',),
'avløpsventilene': ('avløpsventil',),
'avløpsventiler': ('avløpsventil',),
'avløser': ('avløser',),
'avløsere': ('avløser',),
'avløseren': ('avløser',),
'avløserer': ('avløser',),
'avløserne': ('avløser',),
'avløserord': ('avløserord',),
'avløserorda': ('avløserord',),
'avløserordene': ('avløserord',),
'avløserordet': ('avløserord',),
'avløsing': ('avløsing',),
'avløsinga': ('avløsing',),
'avløsingen': ('avløsing',),
'avløsingene': ('avløsing',),
'avløsinger': ('avløsing',),
'avløsingsfører': ('avløsingsfører',),
'avløsingsførere': ('avløsingsfører',),
'avløsingsføreren': ('avløsingsfører',),
'avløsingsførerer': ('avløsingsfører',),
'avløsingsførerne': ('avløsingsfører',),
'avløsingsmannskap': ('avløsingsmannskap',),
'avløsingsmannskapa': ('avløsingsmannskap',),
'avløsingsmannskapene': ('avløsingsmannskap',),
'avløsingsmannskaper': ('avløsingsmannskap',),
'avløsingsmannskapet': ('avløsingsmannskap',),
'avløsning': ('avløsning',),
'avløsninga': ('avløsning',),
'avløsningen': ('avløsning',),
'avløsningene': ('avløsning',),
'avløsninger': ('avløsning',),
'avløsningsfører': ('avløsningsfører',),
'avløsningsførere': ('avløsningsfører',),
'avløsningsføreren': ('avløsningsfører',),
'avløsningsførerer': ('avløsningsfører',),
'avløsningsførerne': ('avløsningsfører',),
'avløsningsmannskap': ('avløsningsmannskap',),
'avløsningsmannskapa': ('avløsningsmannskap',),
'avløsningsmannskapene': ('avløsningsmannskap',),
'avløsningsmannskaper': ('avløsningsmannskap',),
'avløsningsmannskapet': ('avløsningsmannskap',),
'avløyser': ('avløyser',),
'avløysere': ('avløyser',),
'avløyseren': ('avløyser',),
'avløyserer': ('avløyser',),
'avløyserne': ('avløyser',),
'avløyserord': ('avløyserord',),
'avløyserorda': ('avløyserord',),
'avløyserordene': ('avløyserord',),
'avløyserordet': ('avløyserord',),
'avløysing': ('avløysing',),
'avløysinga': ('avløysing',),
'avløysingen': ('avløysing',),
'avløysingene': ('avløysing',),
'avløysinger': ('avløysing',),
'avløysingsfører': ('avløysingsfører',),
'avløysingsførere': ('avløysingsfører',),
'avløysingsføreren': ('avløysingsfører',),
'avløysingsførerer': ('avløysingsfører',),
'avløysingsførerne': ('avløysingsfører',),
'avløysingsmannskap': ('avløysingsmannskap',),
'avløysingsmannskapa': ('avløysingsmannskap',),
'avløysingsmannskapene': ('avløysingsmannskap',),
'avløysingsmannskaper': ('avløysingsmannskap',),
'avløysingsmannskapet': ('avløysingsmannskap',),
'avmagring': ('avmagring',),
'avmagringa': ('avmagring',),
'avmagringen': ('avmagring',),
'avmagringene': ('avmagring',),
'avmagringer': ('avmagring',),
'avmagringskur': ('avmagringskur',),
'avmagringskuren': ('avmagringskur',),
'avmagringskurene': ('avmagringskur',),
'avmagringskurer': ('avmagringskur',),
'avmagringsmiddel': ('avmagringsmiddel',),
'avmagringsmiddelet': ('avmagringsmiddel',),
'avmagringsmidla': ('avmagringsmiddel',),
'avmagringsmidlene': ('avmagringsmiddel',),
'avmagringsmidler': ('avmagringsmiddel',),
'avmagringsmidlet': ('avmagringsmiddel',),
'avmakt': ('avmakt',),
'avmakta': ('avmakt',),
'avmakten': ('avmakt',),
'avmaktene': ('avmakt',),
'avmakter': ('avmakt',),
'avmaktsfølelse': ('avmaktsfølelse',),
'avmaktsfølelsen': ('avmaktsfølelse',),
'avmaktsfølelsene': ('avmaktsfølelse',),
'avmaktsfølelser': ('avmaktsfølelse',),
'avmaktskjensla': ('avmaktskjensle',),
'avmaktskjensle': ('avmaktskjensle',),
'avmaktskjenslen': ('avmaktskjensle',),
'avmaktskjenslene': ('avmaktskjensle',),
'avmaktskjensler': ('avmaktskjensle',),
'avmarsj': ('avmarsj',),
'avmarsjen': ('avmarsj',),
'avmarsjene': ('avmarsj',),
'avmarsjer': ('avmarsj',),
'avmytologisering': ('avmytologisering',),
'avmytologiseringa': ('avmytologisering',),
'avmytologiseringen': ('avmytologisering',),
'avmytologiseringene': ('avmytologisering',),
'avmytologiseringer': ('avmytologisering',),
'avokado': ('avokado',),
'avokadoen': ('avokado',),
'avokadoene': ('avokado',),
'avokadoer': ('avokado',),
'avokadofrukt': ('avokadofrukt',),
'avokadofrukta': ('avokadofrukt',),
'avokadofrukten': ('avokadofrukt',),
'avokadofruktene': ('avokadofrukt',),
'avokadofrukter': ('avokadofrukt',),
'avokadopæra': ('avokadopære',),
'avokadopære': ('avokadopære',),
'avokadopæren': ('avokadopære',),
'avokadopærene': ('avokadopære',),
'avokadopærer': ('avokadopære',),
'avokadotre': ('avokadotre',),
'avokadotrea': ('avokadotre',),
'avokadotreet': ('avokadotre',),
'avokadotrær': ('avokadotre',),
'avokadotrærne': ('avokadotre',),
'avregning': ('avregning',),
'avregninga': ('avregning',),
'avregningen': ('avregning',),
'avregningene': ('avregning',),
'avregninger': ('avregning',),
'avregning': ('avregning',),
'avregninga': ('avregning',),
'avregningen': ('avregning',),
'avregningene': ('avregning',),
'avregninger': ('avregning',),
'avregningskontor': ('avregningskontor',),
'avregningskontora': ('avregningskontor',),
'avregningskontorene': ('avregningskontor',),
'avregningskontorer': ('avregningskontor',),
'avregningskontoret': ('avregningskontor',),
'avregningskontor': ('avregningskontor',),
'avregningskontora': ('avregningskontor',),
'avregningskontorene': ('avregningskontor',),
'avregningskontorer': ('avregningskontor',),
'avregningskontoret': ('avregningskontor',),
'avregningsordning': ('avregningsordning',),
'avregningsordninga': ('avregningsordning',),
'avregningsordningen': ('avregningsordning',),
'avregningsordningene': ('avregningsordning',),
'avregningsordninger': ('avregningsordning',),
'avregningsordning': ('avregningsordning',),
'avregningsordninga': ('avregningsordning',),
'avregningsordningen': ('avregningsordning',),
'avregningsordningene': ('avregningsordning',),
'avregningsordninger': ('avregningsordning',),
'avreisa': ('avreise',),
'avreise': ('avreise',),
'avreisen': ('avreise',),
'avreisene': ('avreise',),
'avreiser': ('avreise',),
'avreisedato': ('avreisedato',),
'avreisedatoen': ('avreisedato',),
'avreisedatoene': ('avreisedato',),
'avreisedatoer': ('avreisedato',),
'avrekning': ('avrekning',),
'avrekninga': ('avrekning',),
'avrekningen': ('avrekning',),
'avrekningene': ('avrekning',),
'avrekninger': ('avrekning',),
'avrekning': ('avrekning',),
'avrekninga': ('avrekning',),
'avrekningen': ('avrekning',),
'avrekningene': ('avrekning',),
'avrekninger': ('avrekning',),
'avrekningskontor': ('avrekningskontor',),
'avrekningskontora': ('avrekningskontor',),
'avrekningskontorene': ('avrekningskontor',),
'avrekningskontorer': ('avrekningskontor',),
'avrekningskontoret': ('avrekningskontor',),
'avrekningskontor': ('avrekningskontor',),
'avrekningskontora': ('avrekningskontor',),
'avrekningskontorene': ('avrekningskontor',),
'avrekningskontorer': ('avrekningskontor',),
'avrekningskontoret': ('avrekningskontor',),
'avrekningsordning': ('avrekningsordning',),
'avrekningsordninga': ('avrekningsordning',),
'avrekningsordningen': ('avrekningsordning',),
'avrekningsordningene': ('avrekningsordning',),
'avrekningsordninger': ('avrekningsordning',),
'avrekningsordning': ('avrekningsordning',),
'avrekningsordninga': ('avrekningsordning',),
'avrekningsordningen': ('avrekningsordning',),
'avrekningsordningene': ('avrekningsordning',),
'avrekningsordninger': ('avrekningsordning',),
'avrettelse': ('avrettelse',),
'avrettelsen': ('avrettelse',),
'avrettelsene': ('avrettelse',),
'avrettelser': ('avrettelse',),
'avretterhøvel': ('avretterhøvel',),
'avretterhøvelen': ('avretterhøvel',),
'avretterhøvlene': ('avretterhøvel',),
'avretterhøvler': ('avretterhøvel',),
'avrettermasse': ('avrettermasse',),
'avrettermassen': ('avrettermasse',),
'avrettermassene': ('avrettermasse',),
'avrettermasser': ('avrettermasse',),
'avretting': ('avretting',),
'avrettinga': ('avretting',),
'avrettingen': ('avretting',),
'avrettingene': ('avretting',),
'avrettinger': ('avretting',),
'avriss': ('avriss',),
'avrissa': ('avriss',),
'avrissene': ('avriss',),
'avrisset': ('avriss',),
'avriving': ('avriving',),
'avrivinga': ('avriving',),
'avrivingen': ('avriving',),
'avrivingene': ('avriving',),
'avrivinger': ('avriving',),
'avriving': ('avriving',),
'avrivinga': ('avriving',),
'avrivingen': ('avriving',),
'avrivingene': ('avriving',),
'avrivinger': ('avriving',),
'avrivingsblokk': ('avrivingsblokk',),
'avrivingsblokka': ('avrivingsblokk',),
'avrivingsblokken': ('avrivingsblokk',),
'avrivingsblokkene': ('avrivingsblokk',),
'avrivingsblokker': ('avrivingsblokk',),
'avrivingskalender': ('avrivingskalender',),
'avrivingskalendere': ('avrivingskalender',),
'avrivingskalenderen': ('avrivingskalender',),
'avrivingskalenderer': ('avrivingskalender',),
'avrivingskalenderne': ('avrivingskalender',),
'avrivingskalendre': ('avrivingskalender',),
'avrivingskalendrene': ('avrivingskalender',),
'avrivingskalendrer': ('avrivingskalender',),
'avrivning': ('avrivning',),
'avrivninga': ('avrivning',),
'avrivningen': ('avrivning',),
'avrivningene': ('avrivning',),
'avrivninger': ('avrivning',),
'avrivning': ('avrivning',),
'avrivninga': ('avrivning',),
'avrivningen': ('avrivning',),
'avrivningene': ('avrivning',),
'avrivninger': ('avrivning',),
'avrivningsblokk': ('avrivningsblokk',),
'avrivningsblokka': ('avrivningsblokk',),
'avrivningsblokken': ('avrivningsblokk',),
'avrivningsblokkene': ('avrivningsblokk',),
'avrivningsblokker': ('avrivningsblokk',),
'avrivningskalender': ('avrivningskalender',),
'avrivningskalendere': ('avrivningskalender',),
'avrivningskalenderen': ('avrivningskalender',),
'avrivningskalenderer': ('avrivningskalender',),
'avrivningskalenderne': ('avrivningskalender',),
'avrivningskalendre': ('avrivningskalender',),
'avrivningskalendrene': ('avrivningskalender',),
'avrivningskalendrer': ('avrivningskalender',),
'avrusing': ('avrusing',),
'avrusinga': ('avrusing',),
'avrusingen': ('avrusing',),
'avrusingene': ('avrusing',),
'avrusinger': ('avrusing',),
'avrusingsstasjon': ('avrusingsstasjon',),
'avrusingsstasjonen': ('avrusingsstasjon',),
'avrusingsstasjonene': ('avrusingsstasjon',),
'avrusingsstasjoner': ('avrusingsstasjon',),
'avrusning': ('avrusning',),
'avrusninga': ('avrusning',),
'avrusningen': ('avrusning',),
'avrusningene': ('avrusning',),
'avrusninger': ('avrusning',),
'avrusningsstasjon': ('avrusningsstasjon',),
'avrusningsstasjonen': ('avrusningsstasjon',),
'avrusningsstasjonene': ('avrusningsstasjon',),
'avrusningsstasjoner': ('avrusningsstasjon',),
'avrusting': ('avrusting',),
'avrustinga': ('avrusting',),
'avrustingen': ('avrusting',),
'avrustingene': ('avrusting',),
'avrustinger': ('avrusting',),
'avrustingsavtale': ('avrustingsavtale',),
'avrustingsavtalen': ('avrustingsavtale',),
'avrustingsavtalene': ('avrustingsavtale',),
'avrustingsavtaler': ('avrustingsavtale',),
'avrustingsforslag': ('avrustingsforslag',),
'avrustingsforslaga': ('avrustingsforslag',),
'avrustingsforslagene': ('avrustingsforslag',),
'avrustingsforslaget': ('avrustingsforslag',),
'avrustingspolitikk': ('avrustingspolitikk',),
'avrustingspolitikken': ('avrustingspolitikk',),
'avrustingspolitikkene': ('avrustingspolitikk',),
'avrustingspolitikker': ('avrustingspolitikk',),
'avrustning': ('avrustning',),
'avrustninga': ('avrustning',),
'avrustningen': ('avrustning',),
'avrustningene': ('avrustning',),
'avrustninger': ('avrustning',),
'avrustningsavtale': ('avrustningsavtale',),
'avrustningsavtalen': ('avrustningsavtale',),
'avrustningsavtalene': ('avrustningsavtale',),
'avrustningsavtaler': ('avrustningsavtale',),
'avrustningsforslag': ('avrustningsforslag',),
'avrustningsforslaga': ('avrustningsforslag',),
'avrustningsforslagene': ('avrustningsforslag',),
'avrustningsforslaget': ('avrustningsforslag',),
'avrustningspolitikk': ('avrustningspolitikk',),
'avrustningspolitikken': ('avrustningspolitikk',),
'avrustningspolitikkene': ('avrustningspolitikk',),
'avrustningspolitikker': ('avrustningspolitikk',),
'avrøysting': ('avrøysting',),
'avrøystinga': ('avrøysting',),
'avrøystingen': ('avrøysting',),
'avrøystingene': ('avrøysting',),
'avrøystinger': ('avrøysting',),
'avsats': ('avsats',),
'avsatsen': ('avsats',),
'avsatsene': ('avsats',),
'avsatser': ('avsats',),
'avsavn': ('avsavn',),
'avsavna': ('avsavn',),
'avsavnene': ('avsavn',),
'avsavnet': ('avsavn',),
'avsavnsgodtgjørelse': ('avsavnsgodtgjørelse',),
'avsavnsgodtgjørelsen': ('avsavnsgodtgjørelse',),
'avsavnsgodtgjørelsene': ('avsavnsgodtgjørelse',),
'avsavnsgodtgjørelser': ('avsavnsgodtgjørelse',),
'avsavnsgodtgjøring': ('avsavnsgodtgjøring',),
'avsavnsgodtgjøringa': ('avsavnsgodtgjøring',),
'avsavnsgodtgjøringen': ('avsavnsgodtgjøring',),
'avsavnsgodtgjøringene': ('avsavnsgodtgjøring',),
'avsavnsgodtgjøringer': ('avsavnsgodtgjøring',),
'avsender': ('avsender',),
'avsendere': ('avsender',),
'avsenderen': ('avsender',),
'avsenderer': ('avsender',),
'avsenderne': ('avsender',),
'avsenderadressa': ('avsenderadresse',),
'avsenderadresse': ('avsenderadresse',),
'avsenderadressen': ('avsenderadresse',),
'avsenderadressene': ('avsenderadresse',),
'avsenderadresser': ('avsenderadresse',),
'avsetning': ('avsetning',),
'avsetninga': ('avsetning',),
'avsetningen': ('avsetning',),
'avsetningene': ('avsetning',),
'avsetninger': ('avsetning',),
'avsetningskonti': ('avsetningskonto',),
'avsetningskontiene': ('avsetningskonto',),
'avsetningskonto': ('avsetningskonto',),
'avsetningskontoen': ('avsetningskonto',),
'avsetningskontoene': ('avsetningskonto',),
'avsetningskontoer': ('avsetningskonto',),
'avsetningsmarked': ('avsetningsmarked',),
'avsetningsmarkeda': ('avsetningsmarked',),
'avsetningsmarkedene': ('avsetningsmarked',),
'avsetningsmarkeder': ('avsetningsmarked',),
'avsetningsmarkedet': ('avsetningsmarked',),
'avsetningsmarknad': ('avsetningsmarknad',),
'avsetningsmarknaden': ('avsetningsmarknad',),
'avsetningsmarknadene': ('avsetningsmarknad',),
'avsetningsmarknader': ('avsetningsmarknad',),
'avsetningsmulighet': ('avsetningsmulighet',),
'avsetningsmuligheta': ('avsetningsmulighet',),
'avsetningsmuligheten': ('avsetningsmulighet',),
'avsetningsmulighetene': ('avsetningsmulighet',),
'avsetningsmuligheter': ('avsetningsmulighet',),
'avsetningsområda': ('avsetningsområde',),
'avsetningsområde': ('avsetningsområde',),
'avsetningsområdene': ('avsetningsområde',),
'avsetningsområder': ('avsetningsområde',),
'avsetningsområdet': ('avsetningsområde',),
'avsetningsvanske': ('avsetningsvanske',),
'avsetningsvansken': ('avsetningsvanske',),
'avsetningsvanskene': ('avsetningsvanske',),
'avsetningsvansker': ('avsetningsvanske',),
'avsetningsvanskelighet': ('avsetningsvanskelighet',),
'avsetningsvanskeligheta': ('avsetningsvanskelighet',),
'avsetningsvanskeligheten': ('avsetningsvanskelighet',),
'avsetningsvanskelighetene': ('avsetningsvanskelighet',),
'avsetningsvanskeligheter': ('avsetningsvanskelighet',),
'avsettelse': ('avsettelse',),
'avsettelsen': ('avsettelse',),
'avsettelsene': ('avsettelse',),
'avsettelser': ('avsettelse',),
'avsig': ('avsig',),
'avsiga': ('avsig',),
'avsigene': ('avsig',),
'avsiget': ('avsig',),
'avsinn': ('avsinn',),
'avsinna': ('avsinn',),
'avsinnene': ('avsinn',),
'avsinnet': ('avsinn',),
'avskaffelse': ('avskaffelse',),
'avskaffelsen': ('avskaffelse',),
'avskaffelsene': ('avskaffelse',),
'avskaffelser': ('avskaffelse',),
'avskalling': ('avskalling',),
'avskallinga': ('avskalling',),
'avskallingen': ('avskalling',),
'avskallingene': ('avskalling',),
'avskallinger': ('avskalling',),
'avskiper': ('avskiper',),
'avskipere': ('avskiper',),
'avskiperen': ('avskiper',),
'avskiperer': ('avskiper',),
'avskiperne': ('avskiper',),
'avskiping': ('avskiping',),
'avskipinga': ('avskiping',),
'avskipingen': ('avskiping',),
'avskipingene': ('avskiping',),
'avskipinger': ('avskiping',),
'avskipingshamn': ('avskipingshamn',),
'avskipingshamna': ('avskipingshamn',),
'avskipingshamnen': ('avskipingshamn',),
'avskipingshamnene': ('avskipingshamn',),
'avskipingshamner': ('avskipingshamn',),
'avskipingshavn': ('avskipingshavn',),
'avskipingshavna': ('avskipingshavn',),
'avskipingshavnen': ('avskipingshavn',),
'avskipingshavnene': ('avskipingshavn',),
'avskipingshavner': ('avskipingshavn',),
'avskipning': ('avskipning',),
'avskipninga': ('avskipning',),
'avskipningen': ('avskipning',),
'avskipningene': ('avskipning',),
'avskipninger': ('avskipning',),
'avskipningshamn': ('avskipningshamn',),
'avskipningshamna': ('avskipningshamn',),
'avskipningshamnen': ('avskipningshamn',),
'avskipningshamnene': ('avskipningshamn',),
'avskipningshamner': ('avskipningshamn',),
'avskipningshavn': ('avskipningshavn',),
'avskipningshavna': ('avskipningshavn',),
'avskipningshavnen': ('avskipningshavn',),
'avskipningshavnene': ('avskipningshavn',),
'avskipningshavner': ('avskipningshavn',),
'avskjed': ('avskjed',),
'avskjeden': ('avskjed',),
'avskjedene': ('avskjed',),
'avskjeder': ('avskjed',),
'avskjedigelse': ('avskjedigelse',),
'avskjedigelsen': ('avskjedigelse',),
'avskjedigelsene': ('avskjedigelse',),
'avskjedigelser': ('avskjedigelse',),
'avskjedsfest': ('avskjedsfest',),
'avskjedsfesten': ('avskjedsfest',),
'avskjedsfestene': ('avskjedsfest',),
'avskjedsfester': ('avskjedsfest',),
'avskjedsstund': ('avskjedsstund',),
'avskjedsstunda': ('avskjedsstund',),
'avskjedsstunden': ('avskjedsstund',),
'avskjedsstundene': ('avskjedsstund',),
'avskjedsstunder': ('avskjedsstund',),
'avskjedssøknad': ('avskjedssøknad',),
'avskjedssøknaden': ('avskjedssøknad',),
'avskjedssøknadene': ('avskjedssøknad',),
'avskjedssøknader': ('avskjedssøknad',),
'avskjedsvisitt': ('avskjedsvisitt',),
'avskjedsvisitten': ('avskjedsvisitt',),
'avskjedsvisittene': ('avskjedsvisitt',),
'avskjedsvisitter': ('avskjedsvisitt',),
'avskjær': ('avskjær',),
'avskjæra': ('avskjær',),
'avskjærene': ('avskjær',),
'avskjæret': ('avskjær',),
'avskjæring': ('avskjæring',),
'avskjæringen': ('avskjæring',),
'avskjæringene': ('avskjæring',),
'avskjæringer': ('avskjæring',),
'avskjæring': ('avskjæring',),
'avskjæringa': ('avskjæring',),
'avskjæringen': ('avskjæring',),
'avskjæringene': ('avskjæring',),
'avskjæringer': ('avskjæring',),
'avskjæringsjager': ('avskjæringsjager',),
'avskjæringsjagere': ('avskjæringsjager',),
'avskjæringsjageren': ('avskjæringsjager',),
'avskjæringsjagerer': ('avskjæringsjager',),
'avskjæringsjagerne': ('avskjæringsjager',),
'avskoging': ('avskoging',),
'avskoginga': ('avskoging',),
'avskogingen': ('avskoging',),
'avskogingene': ('avskoging',),
'avskoginger': ('avskoging',),
'avskrekk': ('avskrekk',),
'avskrekken': ('avskrekk',),
'avskrekkene': ('avskrekk',),
'avskrekker': ('avskrekk',),
'avskrekkingsvåpen': ('avskrekkingsvåpen',),
'avskrekkingsvåpenet': ('avskrekkingsvåpen',),
'avskrekkingsvåpna': ('avskrekkingsvåpen',),
'avskrekkingsvåpnene': ('avskrekkingsvåpen',),
'avskrift': ('avskrift',),
'avskrifta': ('avskrift',),
'avskriften': ('avskrift',),
'avskriftene': ('avskrift',),
'avskrifter': ('avskrift',),
'avskriver': ('avskriver',),
'avskrivere': ('avskriver',),
'avskriveren': ('avskriver',),
'avskriverer': ('avskriver',),
'avskriverne': ('avskriver',),
'avskriverarbeid': ('avskriverarbeid',),
'avskriverarbeida': ('avskriverarbeid',),
'avskriverarbeidene': ('avskriverarbeid',),
'avskriverarbeider': ('avskriverarbeid',),
'avskriverarbeidet': ('avskriverarbeid',),
'avskriverfeil': ('avskriverfeil',),
'avskriverfeilen': ('avskriverfeil',),
'avskriverfeilene': ('avskriverfeil',),
'avskriving': ('avskriving',),
'avskrivinga': ('avskriving',),
'avskrivingen': ('avskriving',),
'avskrivingene': ('avskriving',),
'avskrivinger': ('avskriving',),
'avskrivingsbidrag': ('avskrivingsbidrag',),
'avskrivingsbidraga': ('avskrivingsbidrag',),
'avskrivingsbidragene': ('avskrivingsbidrag',),
'avskrivingsbidraget': ('avskrivingsbidrag',),
'avskrivingsbyrå': ('avskrivingsbyrå',),
'avskrivingsbyråa': ('avskrivingsbyrå',),
'avskrivingsbyråene': ('avskrivingsbyrå',),
'avskrivingsbyråer': ('avskrivingsbyrå',),
'avskrivingsbyrået': ('avskrivingsbyrå',),
'avskrivingskonti': ('avskrivingskonto',),
'avskrivingskontiene': ('avskrivingskonto',),
'avskrivingskonto': ('avskrivingskonto',),
'avskrivingskontoen': ('avskrivingskonto',),
'avskrivingskontoene': ('avskrivingskonto',),
'avskrivingskontoer': ('avskrivingskonto',),
'avskrivingskontor': ('avskrivingskontor',),
'avskrivingskontora': ('avskrivingskontor',),
'avskrivingskontorene': ('avskrivingskontor',),
'avskrivingskontorer': ('avskrivingskontor',),
'avskrivingskontoret': ('avskrivingskontor',),
'avskrivning': ('avskrivning',),
'avskrivninga': ('avskrivning',),
'avskrivningen': ('avskrivning',),
'avskrivningene': ('avskrivning',),
'avskrivninger': ('avskrivning',),
'avskrivningsbidrag': ('avskrivningsbidrag',),
'avskrivningsbidraga': ('avskrivningsbidrag',),
'avskrivningsbidragene': ('avskrivningsbidrag',),
'avskrivningsbidraget': ('avskrivningsbidrag',),
'avskrivningsbyrå': ('avskrivningsbyrå',),
'avskrivningsbyråa': ('avskrivningsbyrå',),
'avskrivningsbyråene': ('avskrivningsbyrå',),
'avskrivningsbyråer': ('avskrivningsbyrå',),
'avskrivningsbyrået': ('avskrivningsbyrå',),
'avskrivningskonti': ('avskrivningskonto',),
'avskrivningskontiene': ('avskrivningskonto',),
'avskrivningskonto': ('avskrivningskonto',),
'avskrivningskontoen': ('avskrivningskonto',),
'avskrivningskontoene': ('avskrivningskonto',),
'avskrivningskontoer': ('avskrivningskonto',),
'avskrivningskontor': ('avskrivningskontor',),
'avskrivningskontora': ('avskrivningskontor',),
'avskrivningskontorene': ('avskrivningskontor',),
'avskrivningskontorer': ('avskrivningskontor',),
'avskrivningskontoret': ('avskrivningskontor',),
'avskum': ('avskum',),
'avskumma': ('avskum',),
'avskummene': ('avskum',),
'avskummet': ('avskum',),
'avsky': ('avsky',),
'avskyen': ('avsky',),
'avskyene': ('avsky',),
'avskyer': ('avsky',),
'avskygning': ('avskygning',),
'avskygninga': ('avskygning',),
'avskygningen': ('avskygning',),
'avskygningene': ('avskygning',),
'avskygninger': ('avskygning',),
'avskyresolusjon': ('avskyresolusjon',),
'avskyresolusjonen': ('avskyresolusjon',),
'avskyresolusjonene': ('avskyresolusjon',),
'avskyresolusjoner': ('avskyresolusjon',),
'avslag': ('avslag',),
'avslaga': ('avslag',),
'avslagene': ('avslag',),
'avslaget': ('avslag',),
'avslapning': ('avslapning',),
'avslapninga': ('avslapning',),
'avslapningen': ('avslapning',),
'avslapningene': ('avslapning',),
'avslapninger': ('avslapning',),
'avslapningsgymnastikk': ('avslapningsgymnastikk',),
'avslapningsgymnastikken': ('avslapningsgymnastikk',),
'avslapningsgymnastikkene': ('avslapningsgymnastikk',),
'avslapningsgymnastikker': ('avslapningsgymnastikk',),
'avslapningsterapi': ('avslapningsterapi',),
'avslapningsterapien': ('avslapningsterapi',),
'avslapningsterapiene': ('avslapningsterapi',),
'avslapningsterapier': ('avslapningsterapi',),
'avslapningsøvelse': ('avslapningsøvelse',),
'avslapningsøvelsen': ('avslapningsøvelse',),
'avslapningsøvelsene': ('avslapningsøvelse',),
'avslapningsøvelser': ('avslapningsøvelse',),
'avslapningsøving': ('avslapningsøving',),
'avslapningsøvinga': ('avslapningsøving',),
'avslapningsøvingen': ('avslapningsøving',),
'avslapningsøvingene': ('avslapningsøving',),
'avslapningsøvinger': ('avslapningsøving',),
'avslapping': ('avslapping',),
'avslappinga': ('avslapping',),
'avslappingen': ('avslapping',),
'avslappingene': ('avslapping',),
'avslappinger': ('avslapping',),
'avslappingsgymnastikk': ('avslappingsgymnastikk',),
'avslappingsgymnastikken': ('avslappingsgymnastikk',),
'avslappingsgymnastikkene': ('avslappingsgymnastikk',),
'avslappingsgymnastikker': ('avslappingsgymnastikk',),
'avslappingsterapi': ('avslappingsterapi',),
'avslappingsterapien': ('avslappingsterapi',),
'avslappingsterapiene': ('avslappingsterapi',),
'avslappingsterapier': ('avslappingsterapi',),
'avslappingsøvelse': ('avslappingsøvelse',),
'avslappingsøvelsen': ('avslappingsøvelse',),
'avslappingsøvelsene': ('avslappingsøvelse',),
'avslappingsøvelser': ('avslappingsøvelse',),
'avslappingsøving': ('avslappingsøving',),
'avslappingsøvinga': ('avslappingsøving',),
'avslappingsøvingen': ('avslappingsøving',),
'avslappingsøvingene': ('avslappingsøving',),
'avslappingsøvinger': ('avslappingsøving',),
'avslutning': ('avslutning',),
'avslutninga': ('avslutning',),
'avslutningen': ('avslutning',),
'avslutningene': ('avslutning',),
'avslutninger': ('avslutning',),
'avslutningsfest': ('avslutningsfest',),
'avslutningsfesten': ('avslutningsfest',),
'avslutningsfestene': ('avslutningsfest',),
'avslutningsfester': ('avslutningsfest',),
'avslutningstale': ('avslutningstale',),
'avslutningstalen': ('avslutningstale',),
'avslutningstalene': ('avslutningstale',),
'avslutningstaler': ('avslutningstale',),
'avsløring': ('avsløring',),
'avsløringa': ('avsløring',),
'avsløringen': ('avsløring',),
'avsløringene': ('avsløring',),
'avsløringer': ('avsløring',),
'avsmak': ('avsmak',),
'avsmaken': ('avsmak',),
'avsmakene': ('avsmak',),
'avsmaker': ('avsmak',),
'avsnitt': ('avsnitt',),
'avsnitta': ('avsnitt',),
'avsnittene': ('avsnitt',),
'avsnittet': ('avsnitt',),
'avsnittsmarkering': ('avsnittsmarkering',),
'avsnittsmarkeringa': ('avsnittsmarkering',),
'avsnittsmarkeringen': ('avsnittsmarkering',),
'avsnittsmarkeringene': ('avsnittsmarkering',),
'avsnittsmarkeringer': ('avsnittsmarkering',),
'avsnittssjef': ('avsnittssjef',),
'avsnittssjefen': ('avsnittssjef',),
'avsnittssjefene': ('avsnittssjef',),
'avsnittssjefer': ('avsnittssjef',),
'avspark': ('avspark',),
'avsparka': ('avspark',),
'avsparkene': ('avspark',),
'avsparket': ('avspark',),
'avspelling': ('avspelling',),
'avspellinga': ('avspelling',),
'avspellingen': ('avspelling',),
'avspellingene': ('avspelling',),
'avspellinger': ('avspelling',),
'avspellingsrom': ('avspellingsrom',),
'avspellingsromma': ('avspellingsrom',),
'avspellingsrommene': ('avspellingsrom',),
'avspellingsrommet': ('avspellingsrom',),
'avspenning': ('avspenning',),
'avspenninga': ('avspenning',),
'avspenningen': ('avspenning',),
'avspenningene': ('avspenning',),
'avspenninger': ('avspenning',),
'avspenningsframstøt': ('avspenningsframstøt',),
'avspenningsframstøta': ('avspenningsframstøt',),
'avspenningsframstøtene': ('avspenningsframstøt',),
'avspenningsframstøtet': ('avspenningsframstøt',),
'avspenningsframstøyt': ('avspenningsframstøyt',),
'avspenningsframstøyten': ('avspenningsframstøyt',),
'avspenningsframstøytene': ('avspenningsframstøyt',),
'avspenningsframstøyter': ('avspenningsframstøyt',),
'avspenningsgymnastikk': ('avspenningsgymnastikk',),
'avspenningsgymnastikken': ('avspenningsgymnastikk',),
'avspenningsgymnastikkene': ('avspenningsgymnastikk',),
'avspenningsgymnastikker': ('avspenningsgymnastikk',),
'avspenningspolitikk': ('avspenningspolitikk',),
'avspenningspolitikken': ('avspenningspolitikk',),
'avspenningspolitikkene': ('avspenningspolitikk',),
'avspenningspolitikker': ('avspenningspolitikk',),
'avsperring': ('avsperring',),
'avsperringa': ('avsperring',),
'avsperringen': ('avsperring',),
'avsperringene': ('avsperring',),
'avsperringer': ('avsperring',),
'avspilling': ('avspilling',),
'avspillinga': ('avspilling',),
'avspillingen': ('avspilling',),
'avspillingene': ('avspilling',),
'avspillinger': ('avspilling',),
'avspillingsrom': ('avspillingsrom',),
'avspillingsromma': ('avspillingsrom',),
'avspillingsrommene': ('avspillingsrom',),
'avspillingsrommet': ('avspillingsrom',),
'avsporing': ('avsporing',),
'avsporinga': ('avsporing',),
'avsporingen': ('avsporing',),
'avsporingene': ('avsporing',),
'avsporinger': ('avsporing',),
'avstamning': ('avstamning',),
'avstamninga': ('avstamning',),
'avstamningen': ('avstamning',),
'avstamningene': ('avstamning',),
'avstamninger': ('avstamning',),
'avstamningslæra': ('avstamningslære',),
'avstamningslære': ('avstamningslære',),
'avstamningslæren': ('avstamningslære',),
'avstamningslærene': ('avstamningslære',),
'avstamningslærer': ('avstamningslære',),
'avstand': ('avstand',),
'avstanden': ('avstand',),
'avstandene': ('avstand',),
'avstander': ('avstand',),
'avstandsbedømmelse': ('avstandsbedømmelse',),
'avstandsbedømmelsen': ('avstandsbedømmelse',),
'avstandsbedømmelsene': ('avstandsbedømmelse',),
'avstandsbedømmelser': ('avstandsbedømmelse',),
'avstandsinnstilling': ('avstandsinnstilling',),
'avstandsinnstillinga': ('avstandsinnstilling',),
'avstandsinnstillingen': ('avstandsinnstilling',),
'avstandsinnstillingene': ('avstandsinnstilling',),
'avstandsinnstillinger': ('avstandsinnstilling',),
'avstandsmåler': ('avstandsmåler',),
'avstandsmålere': ('avstandsmåler',),
'avstandsmåleren': ('avstandsmåler',),
'avstandsmålerer': ('avstandsmåler',),
'avstandsmålerne': ('avstandsmåler',),
'avstandtagen': ('avstandtagen',),
'avstandtaing': ('avstandtaing',),
'avstandtainga': ('avstandtaing',),
'avstandtaingen': ('avstandtaing',),
'avstandtaingene': ('avstandtaing',),
'avstandtainger': ('avstandtaing',),
'avstandtaken': ('avstandtaken',),
'avstandtaking': ('avstandtaking',),
'avstandtakinga': ('avstandtaking',),
'avstandtakingen': ('avstandtaking',),
'avstandtakingene': ('avstandtaking',),
'avstandtakinger': ('avstandtaking',),
'avstemning': ('avstemning',),
'avstemninga': ('avstemning',),
'avstemningen': ('avstemning',),
'avstemningene': ('avstemning',),
'avstemninger': ('avstemning',),
'avstemningsmåte': ('avstemningsmåte',),
'avstemningsmåten': ('avstemningsmåte',),
'avstemningsmåtene': ('avstemningsmåte',),
'avstemningsmåter': ('avstemningsmåte',),
'avstemningsresultat': ('avstemningsresultat',),
'avstemningsresultata': ('avstemningsresultat',),
'avstemningsresultatene': ('avstemningsresultat',),
'avstemningsresultater': ('avstemningsresultat',),
'avstemningsresultatet': ('avstemningsresultat',),
'avstenging': ('avstenging',),
'avstenginga': ('avstenging',),
'avstengingen': ('avstenging',),
'avstengingene': ('avstenging',),
'avstenginger': ('avstenging',),
'avstengingskran': ('avstengingskran',),
'avstengingskrana': ('avstengingskran',),
'avstengingskranen': ('avstengingskran',),
'avstengingskranene': ('avstengingskran',),
'avstengingskraner': ('avstengingskran',),
'avstengingsventil': ('avstengingsventil',),
'avstengingsventilen': ('avstengingsventil',),
'avstengingsventilene': ('avstengingsventil',),
'avstengingsventiler': ('avstengingsventil',),
'avstengning': ('avstengning',),
'avstengninga': ('avstengning',),
'avstengningen': ('avstengning',),
'avstengningene': ('avstengning',),
'avstengninger': ('avstengning',),
'avstengningskran': ('avstengningskran',),
'avstengningskrana': ('avstengningskran',),
'avstengningskranen': ('avstengningskran',),
'avstengningskranene': ('avstengningskran',),
'avstengningskraner': ('avstengningskran',),
'avstengningsventil': ('avstengningsventil',),
'avstengningsventilen': ('avstengningsventil',),
'avstengningsventilene': ('avstengningsventil',),
'avstengningsventiler': ('avstengningsventil',),
'avstiging': ('avstiging',),
'avstiginga': ('avstiging',),
'avstigingen': ('avstiging',),
'avstigingene': ('avstiging',),
'avstiginger': ('avstiging',),
'avstigingsperrong': ('avstigingsperrong',),
'avstigingsperrongen': ('avstigingsperrong',),
'avstigingsperrongene': ('avstigingsperrong',),
'avstigingsperronger': ('avstigingsperrong',),
'avstigingstrapp': ('avstigingstrapp',),
'avstigingstrappa': ('avstigingstrapp',),
'avstigingstrappen': ('avstigingstrapp',),
'avstigingstrappene': ('avstigingstrapp',),
'avstigingstrapper': ('avstigingstrapp',),
'avstigning': ('avstigning',),
'avstigninga': ('avstigning',),
'avstigningen': ('avstigning',),
'avstigningene': ('avstigning',),
'avstigninger': ('avstigning',),
'avstigningsperrong': ('avstigningsperrong',),
'avstigningsperrongen': ('avstigningsperrong',),
'avstigningsperrongene': ('avstigningsperrong',),
'avstigningsperronger': ('avstigningsperrong',),
'avstigningstrapp': ('avstigningstrapp',),
'avstigningstrappa': ('avstigningstrapp',),
'avstigningstrappen': ('avstigningstrapp',),
'avstigningstrappene': ('avstigningstrapp',),
'avstigningstrapper': ('avstigningstrapp',),
'avstikker': ('avstikker',),
'avstikkere': ('avstikker',),
'avstikkeren': ('avstikker',),
'avstikkerer': ('avstikker',),
'avstikkerne': ('avstikker',),
'avstiver': ('avstiver',),
'avstivere': ('avstiver',),
'avstiveren': ('avstiver',),
'avstiverer': ('avstiver',),
'avstiverne': ('avstiver',),
'avstiving': ('avstiving',),
'avstivinga': ('avstiving',),
'avstivingen': ('avstiving',),
'avstivingene': ('avstiving',),
'avstivinger': ('avstiving',),
'avstivingsbjelke': ('avstivingsbjelke',),
'avstivingsbjelken': ('avstivingsbjelke',),
'avstivingsbjelkene': ('avstivingsbjelke',),
'avstivingsbjelker': ('avstivingsbjelke',),
'avstivingsplata': ('avstivingsplate',),
'avstivingsplate': ('avstivingsplate',),
'avstivingsplaten': ('avstivingsplate',),
'avstivingsplatene': ('avstivingsplate',),
'avstivingsplater': ('avstivingsplate',),
'avstivning': ('avstivning',),
'avstivninga': ('avstivning',),
'avstivningen': ('avstivning',),
'avstivningene': ('avstivning',),
'avstivninger': ('avstivning',),
'avstivningsbjelke': ('avstivningsbjelke',),
'avstivningsbjelken': ('avstivningsbjelke',),
'avstivningsbjelkene': ('avstivningsbjelke',),
'avstivningsbjelker': ('avstivningsbjelke',),
'avstivningsplata': ('avstivningsplate',),
'avstivningsplate': ('avstivningsplate',),
'avstivningsplaten': ('avstivningsplate',),
'avstivningsplatene': ('avstivningsplate',),
'avstivningsplater': ('avstivningsplate',),
'avstraffelse': ('avstraffelse',),
'avstraffelsen': ('avstraffelse',),
'avstraffelsene': ('avstraffelse',),
'avstraffelser': ('avstraffelse',),
'avstøpning': ('avstøpning',),
'avstøpninga': ('avstøpning',),
'avstøpningen': ('avstøpning',),
'avstøpningene': ('avstøpning',),
'avstøpninger': ('avstøpning',),
'avsøker': ('avsøker',),
'avsøkere': ('avsøker',),
'avsøkeren': ('avsøker',),
'avsøkerer': ('avsøker',),
'avsøkerne': ('avsøker',),
'avtak': ('avtak',),
'avtaka': ('avtak',),
'avtakene': ('avtak',),
'avtaket': ('avtak',),
'avtaker': ('avtaker',),
'avtakere': ('avtaker',),
'avtakeren': ('avtaker',),
'avtakerer': ('avtaker',),
'avtakerne': ('avtaker',),
'avtakerland': ('avtakerland',),
'avtakerlanda': ('avtakerland',),
'avtakerlandene': ('avtakerland',),
'avtakerlandet': ('avtakerland',),
'avtale': ('avtale',),
'avtalen': ('avtale',),
'avtalene': ('avtale',),
'avtaler': ('avtale',),
'avtalebrott': ('avtalebrott',),
'avtalebrotta': ('avtalebrott',),
'avtalebrottene': ('avtalebrott',),
'avtalebrottet': ('avtalebrott',),
'avtalebrudd': ('avtalebrudd',),
'avtalebrudda': ('avtalebrudd',),
'avtalebruddene': ('avtalebrudd',),
'avtalebruddet': ('avtalebrudd',),
'avtalelov': ('avtalelov',),
'avtaleloven': ('avtalelov',),
'avtalelovene': ('avtalelov',),
'avtalelover': ('avtalelov',),
'avtaleperiode': ('avtaleperiode',),
'avtaleperioden': ('avtaleperiode',),
'avtaleperiodene': ('avtaleperiode',),
'avtaleperioder': ('avtaleperiode',),
'avtaleverk': ('avtaleverk',),
'avtaleverka': ('avtaleverk',),
'avtaleverkene': ('avtaleverk',),
'avtaleverker': ('avtaleverk',),
'avtaleverket': ('avtaleverk',),
'avtegn': ('avtegn',),
'avtegna': ('avtegn',),
'avtegnene': ('avtegn',),
'avtegnet': ('avtegn',),
'avtrapning': ('avtrapning',),
'avtrapninga': ('avtrapning',),
'avtrapningen': ('avtrapning',),
'avtrapningene': ('avtrapning',),
'avtrapninger': ('avtrapning',),
'avtrapping': ('avtrapping',),
'avtrappinga': ('avtrapping',),
'avtrappingen': ('avtrapping',),
'avtrappingene': ('avtrapping',),
'avtrappinger': ('avtrapping',),
'avtreda': ('avtrede',),
'avtrede': ('avtrede',),
'avtredene': ('avtrede',),
'avtreder': ('avtrede',),
'avtredet': ('avtrede',),
'avtrekk': ('avtrekk',),
'avtrekka': ('avtrekk',),
'avtrekkene': ('avtrekk',),
'avtrekket': ('avtrekk',),
'avtrekker': ('avtrekker',),
'avtrekkere': ('avtrekker',),
'avtrekkeren': ('avtrekker',),
'avtrekkerer': ('avtrekker',),
'avtrekkerne': ('avtrekker',),
'avtrekkshastighet': ('avtrekkshastighet',),
'avtrekkshastigheta': ('avtrekkshastighet',),
'avtrekkshastigheten': ('avtrekkshastighet',),
'avtrekkshastighetene': ('avtrekkshastighet',),
'avtrekkshastigheter': ('avtrekkshastighet',),
'avtrekkshetta': ('avtrekkshette',),
'avtrekkshette': ('avtrekkshette',),
'avtrekkshetten': ('avtrekkshette',),
'avtrekkshettene': ('avtrekkshette',),
'avtrekkshetter': ('avtrekkshette',),
'avtrekkshylsa': ('avtrekkshylse',),
'avtrekkshylse': ('avtrekkshylse',),
'avtrekkshylsen': ('avtrekkshylse',),
'avtrekkshylsene': ('avtrekkshylse',),
'avtrekkshylser': ('avtrekkshylse',),
'avtrekkskanal': ('avtrekkskanal',),
'avtrekkskanalen': ('avtrekkskanal',),
'avtrekkskanalene': ('avtrekkskanal',),
'avtrekkskanaler': ('avtrekkskanal',),
'avtrekksrør': ('avtrekksrør',),
'avtrekksrøra': ('avtrekksrør',),
'avtrekksrørene': ('avtrekksrør',),
'avtrekksrøret': ('avtrekksrør',),
'avtrekksvifta': ('avtrekksvifte',),
'avtrekksvifte': ('avtrekksvifte',),
'avtrekksviften': ('avtrekksvifte',),
'avtrekksviftene': ('avtrekksvifte',),
'avtrekksvifter': ('avtrekksvifte',),
'avtrykk': ('avtrykk',),
'avtrykka': ('avtrykk',),
'avtrykkene': ('avtrykk',),
'avtrykket': ('avtrykk',),
'avund': ('avund',),
'avunden': ('avund',),
'avundene': ('avund',),
'avunder': ('avund',),
'avveg': ('avveg',),
'avvegen': ('avveg',),
'avvegene': ('avveg',),
'avveger': ('avveg',),
'avvei': ('avvei',),
'avveien': ('avvei',),
'avveiene': ('avvei',),
'avveier': ('avvei',),
'avveksling': ('avveksling',),
'avvekslinga': ('avveksling',),
'avvekslingen': ('avveksling',),
'avvekslingene': ('avveksling',),
'avvekslinger': ('avveksling',),
'avvenning': ('avvenning',),
'avvenninga': ('avvenning',),
'avvenningen': ('avvenning',),
'avvenningene': ('avvenning',),
'avvenninger': ('avvenning',),
'avvenningsalder': ('avvenningsalder',),
'avvenningsaldere': ('avvenningsalder',),
'avvenningsalderen': ('avvenningsalder',),
'avvenningsalderer': ('avvenningsalder',),
'avvenningsalderne': ('avvenningsalder',),
'avvenningsaldre': ('avvenningsalder',),
'avvenningsaldrene': ('avvenningsalder',),
'avvenningsaldrer': ('avvenningsalder',),
'avvenningskur': ('avvenningskur',),
'avvenningskuren': ('avvenningskur',),
'avvenningskurene': ('avvenningskur',),
'avvenningskurer': ('avvenningskur',),
'avverge': ('avverge',),
'avvergen': ('avverge',),
'avvergene': ('avverge',),
'avverger': ('avverge',),
'avverging': ('avverging',),
'avverginga': ('avverging',),
'avvergingen': ('avverging',),
'avvergingene': ('avverging',),
'avverginger': ('avverging',),
'avvergingsmekanisme': ('avvergingsmekanisme',),
'avvergingsmekanismen': ('avvergingsmekanisme',),
'avvergingsmekanismene': ('avvergingsmekanisme',),
'avvergingsmekanismer': ('avvergingsmekanisme',),
'avvergingsmiddel': ('avvergingsmiddel',),
'avvergingsmiddelet': ('avvergingsmiddel',),
'avvergingsmidla': ('avvergingsmiddel',),
'avvergingsmidlene': ('avvergingsmiddel',),
'avvergingsmidler': ('avvergingsmiddel',),
'avvergingsmidlet': ('avvergingsmiddel',),
'avvik': ('avvik',),
'avvika': ('avvik',),
'avvikene': ('avvik',),
'avviket': ('avvik',),
'avvikelse': ('avvikelse',),
'avvikelsen': ('avvikelse',),
'avvikelsene': ('avvikelse',),
'avvikelser': ('avvikelse',),
'avviker': ('avviker',),
'avvikere': ('avviker',),
'avvikeren': ('avviker',),
'avvikerer': ('avviker',),
'avvikerne': ('avviker',),
'avvikling': ('avvikling',),
'avviklinga': ('avvikling',),
'avviklingen': ('avvikling',),
'avviklingene': ('avvikling',),
'avviklinger': ('avvikling',),
'avviklingsstyra': ('avviklingsstyre',),
'avviklingsstyre': ('avviklingsstyre',),
'avviklingsstyrene': ('avviklingsstyre',),
'avviklingsstyrer': ('avviklingsstyre',),
'avviklingsstyret': ('avviklingsstyre',),
'avvirking': ('avvirking',),
'avvirkinga': ('avvirking',),
'avvirkingen': ('avvirking',),
'avvirkingene': ('avvirking',),
'avvirkinger': ('avvirking',),
'avvirkingskalkyle': ('avvirkingskalkyle',),
'avvirkingskalkylen': ('avvirkingskalkyle',),
'avvirkingskalkylene': ('avvirkingskalkyle',),
'avvirkingskalkyler': ('avvirkingskalkyle',),
'avvirkingsområda': ('avvirkingsområde',),
'avvirkingsområde': ('avvirkingsområde',),
'avvirkingsområdene': ('avvirkingsområde',),
'avvirkingsområder': ('avvirkingsområde',),
'avvirkingsområdet': ('avvirkingsområde',),
'avvirkingsprosent': ('avvirkingsprosent',),
'avvirkingsprosenten': ('avvirkingsprosent',),
'avvirkingsprosentene': ('avvirkingsprosent',),
'avvirkingsprosenter': ('avvirkingsprosent',),
'avvirkning': ('avvirkning',),
'avvirkninga': ('avvirkning',),
'avvirkningen': ('avvirkning',),
'avvirkningene': ('avvirkning',),
'avvirkninger': ('avvirkning',),
'avvirkningskalkyle': ('avvirkningskalkyle',),
'avvirkningskalkylen': ('avvirkningskalkyle',),
'avvirkningskalkylene': ('avvirkningskalkyle',),
'avvirkningskalkyler': ('avvirkningskalkyle',),
'avvirkningsområda': ('avvirkningsområde',),
'avvirkningsområde': ('avvirkningsområde',),
'avvirkningsområdene': ('avvirkningsområde',),
'avvirkningsområder': ('avvirkningsområde',),
'avvirkningsområdet': ('avvirkningsområde',),
'avvirkningsprosent': ('avvirkningsprosent',),
'avvirkningsprosenten': ('avvirkningsprosent',),
'avvirkningsprosentene': ('avvirkningsprosent',),
'avvirkningsprosenter': ('avvirkningsprosent',),
'avviser': ('avviser',),
'avvisere': ('avviser',),
'avviseren': ('avviser',),
'avviserer': ('avviser',),
'avviserne': ('avviser',),
'avviserstein': ('avviserstein',),
'avvisersteinen': ('avviserstein',),
'avvisersteinene': ('avviserstein',),
'avvisersteiner': ('avviserstein',),
'avviserstolpe': ('avviserstolpe',),
'avviserstolpen': ('avviserstolpe',),
'avviserstolpene': ('avviserstolpe',),
'avviserstolper': ('avviserstolpe',),
'avvising': ('avvising',),
'avvisinga': ('avvising',),
'avvisingen': ('avvising',),
'avvisingene': ('avvising',),
'avvisinger': ('avvising',),
'avvisingsreaksjon': ('avvisingsreaksjon',),
'avvisingsreaksjonen': ('avvisingsreaksjon',),
'avvisingsreaksjonene': ('avvisingsreaksjon',),
'avvisingsreaksjoner': ('avvisingsreaksjon',),
'avvisning': ('avvisning',),
'avvisninga': ('avvisning',),
'avvisningen': ('avvisning',),
'avvisningene': ('avvisning',),
'avvisninger': ('avvisning',),
'avvisningsreaksjon': ('avvisningsreaksjon',),
'avvisningsreaksjonen': ('avvisningsreaksjon',),
'avvisningsreaksjonene': ('avvisningsreaksjon',),
'avvisningsreaksjoner': ('avvisningsreaksjon',),
'ayatolla': ('ayatolla',),
'ayatollaen': ('ayatolla',),
'ayatollaene': ('ayatolla',),
'ayatollaer': ('ayatolla',),
'azteker': ('azteker',),
'aztekere': ('azteker',),
'aztekeren': ('azteker',),
'aztekerer': ('azteker',),
'aztekerne': ('azteker',),
'b': ('b',),
'b\'en': ('b',),
'b-en': ('b',),
'b-ene': ('b',),
'b-er': ('b',),
'b-film': ('b-film',),
'b-filmen': ('b-film',),
'b-filmene': ('b-film',),
'b-filmer': ('b-film',),
'b-kvalitet': ('b-kvalitet',),
'b-kvaliteten': ('b-kvalitet',),
'b-kvalitetene': ('b-kvalitet',),
'b-kvaliteter': ('b-kvalitet',),
'b-lag': ('b-lag',),
'b-laga': ('b-lag',),
'b-lagene': ('b-lag',),
'b-laget': ('b-lag',),
'b-menneska': ('b-menneske',),
'b-menneske': ('b-menneske',),
'b-menneskene': ('b-menneske',),
'b-mennesker': ('b-menneske',),
'b-mennesket': ('b-menneske',),
'b-moll': ('b-moll',),
'b-mollen': ('b-moll',),
'b-mollene': ('b-moll',),
'b-moller': ('b-moll',),
'babbel': ('babbel',),
'babbelet': ('babbel',),
'babla': ('babbel',),
'bablene': ('babbel',),
'babler': ('babbel',),
'bablet': ('babbel',),
'babel': ('babel',),
'babl': ('babl',),
'babla': ('babl',),
'bablene': ('babl',),
'bablet': ('babl',),
'babord': ('babord',),
'baby': ('baby',),
'babyen': ('baby',),
'babyene': ('baby',),
'babyer': ('baby',),
'babyklær': ('babyklær',),
'babyklærne': ('babyklær',),
'babykorg': ('babykorg',),
'babykorga': ('babykorg',),
'babykorgen': ('babykorg',),
'babykorgene': ('babykorg',),
'babykorger': ('babykorg',),
'babykurv': ('babykurv',),
'babykurva': ('babykurv',),
'babykurven': ('babykurv',),
'babykurvene': ('babykurv',),
'babykurver': ('babykurv',),
'babyloner': ('babyloner',),
'babylonere': ('babyloner',),
'babyloneren': ('babyloner',),
'babylonerer': ('babyloner',),
'babylonerne': ('babyloner',),
'babylonier': ('babylonier',),
'babyloniere': ('babylonier',),
'babylonieren': ('babylonier',),
'babylonierer': ('babylonier',),
'babylonierne': ('babylonier',),
'babypose': ('babypose',),
'babyposen': ('babypose',),
'babyposene': ('babypose',),
'babyposer': ('babypose',),
'bacalao': ('bacalao',),
'bacalaoen': ('bacalao',),
'bacalaoene': ('bacalao',),
'bacalaoer': ('bacalao',),
'back': ('back',),
'backen': ('back',),
'backene': ('back',),
'backer': ('back',),
'backfisch': ('backfisch',),
'backfischen': ('backfisch',),
'backfischene': ('backfisch',),
'backfischer': ('backfisch',),
'backhand': ('backhand',),
'backhanden': ('backhand',),
'backhandene': ('backhand',),
'backhander': ('backhand',),
'backlash': ('backlash',),
'backlashen': ('backlash',),
'backlashene': ('backlash',),
'backlasher': ('backlash',),
'bacon': ('bacon',),
'bacona': ('bacon',),
'baconene': ('bacon',),
'baconet': ('bacon',),
'bacongris': ('bacongris',),
'bacongrisen': ('bacongris',),
'bacongrisene': ('bacongris',),
'bacongriser': ('bacongris',),
'baconost': ('baconost',),
'baconosten': ('baconost',),
'baconostene': ('baconost',),
'baconoster': ('baconost',),
'bad': ('bad',),
'bada': ('bad',),
'badene': ('bad',),
'badet': ('bad',),
'badeanstalt': ('badeanstalt',),
'badeanstalten': ('badeanstalt',),
'badeanstaltene': ('badeanstalt',),
'badeanstalter': ('badeanstalt',),
'badebalja': ('badebalje',),
'badebalje': ('badebalje',),
'badebaljen': ('badebalje',),
'badebaljene': ('badebalje',),
'badebaljer': ('badebalje',),
'badeball': ('badeball',),
'badeballen': ('badeball',),
'badeballene': ('badeball',),
'badeballer': ('badeball',),
'badebuksa': ('badebukse',),
'badebukse': ('badebukse',),
'badebuksen': ('badebukse',),
'badebuksene': ('badebukse',),
'badebukser': ('badebukse',),
'badeby': ('badeby',),
'badebyen': ('badeby',),
'badebyene': ('badeby',),
'badebyer': ('badeby',),
'badedrakt': ('badedrakt',),
'badedrakta': ('badedrakt',),
'badedrakten': ('badedrakt',),
'badedraktene': ('badedrakt',),
'badedrakter': ('badedrakt',),
'badegjest': ('badegjest',),
'badegjesten': ('badegjest',),
'badegjestene': ('badegjest',),
'badegjester': ('badegjest',),
'badehandkle': ('badehandkle',),
'badehandkleet': ('badehandkle',),
'badehandklær': ('badehandkle',),
'badehandklærne': ('badehandkle',),
'badehetta': ('badehette',),
'badehette': ('badehette',),
'badehetten': ('badehette',),
'badehettene': ('badehette',),
'badehetter': ('badehette',),
'badehåndkle': ('badehåndkle',),
'badehåndkleet': ('badehåndkle',),
'badehåndklær': ('badehåndkle',),
'badehåndklærne': ('badehåndkle',),
'badekar': ('badekar',),
'badekara': ('badekar',),
'badekarene': ('badekar',),
'badekaret': ('badekar',),
'badenymfa': ('badenymfe',),
'badenymfe': ('badenymfe',),
'badenymfen': ('badenymfe',),
'badenymfene': ('badenymfe',),
'badenymfer': ('badenymfe',),
'badeomn': ('badeomn',),
'badeomnen': ('badeomn',),
'badeomnene': ('badeomn',),
'badeomner': ('badeomn',),
'badeovn': ('badeovn',),
'badeovnen': ('badeovn',),
'badeovnene': ('badeovn',),
'badeovner': ('badeovn',),
'bader': ('bader',),
'badere': ('bader',),
'baderen': ('bader',),
'baderer': ('bader',),
'baderne': ('bader',),
'baderom': ('baderom',),
'baderomma': ('baderom',),
'baderommene': ('baderom',),
'baderommet': ('baderom',),
'badesalt': ('badesalt',),
'badesalta': ('badesalt',),
'badesaltene': ('badesalt',),
'badesalter': ('badesalt',),
'badesaltet': ('badesalt',),
'badesesong': ('badesesong',),
'badesesongen': ('badesesong',),
'badesesongene': ('badesesong',),
'badesesonger': ('badesesong',),
'badested': ('badested',),
'badestedene': ('badested',),
'badesteder': ('badested',),
'badestedet': ('badested',),
'badestrand': ('badestrand',),
'badestranda': ('badestrand',),
'badestranden': ('badestrand',),
'badestrendene': ('badestrand',),
'badestrender': ('badestrand',),
'badesvamp': ('badesvamp',),
'badesvampen': ('badesvamp',),
'badesvampene': ('badesvamp',),
'badesvamper': ('badesvamp',),
'badevann': ('badevann',),
'badevanna': ('badevann',),
'badevannene': ('badevann',),
'badevannet': ('badevann',),
'badevatn': ('badevatn',),
'badevatna': ('badevatn',),
'badevatnene': ('badevatn',),
'badevatnet': ('badevatn',),
'badminton': ('badminton',),
'badmintonen': ('badminton',),
'badmintonene': ('badminton',),
'badmintoner': ('badminton',),
'badmintonball': ('badmintonball',),
'badmintonballen': ('badmintonball',),
'badmintonballene': ('badmintonball',),
'badmintonballer': ('badmintonball',),
'badmintonbane': ('badmintonbane',),
'badmintonbanen': ('badmintonbane',),
'badmintonbanene': ('badmintonbane',),
'badmintonbaner': ('badmintonbane',),
'badmintonkamp': ('badmintonkamp',),
'badmintonkampen': ('badmintonkamp',),
'badmintonkampene': ('badmintonkamp',),
'badmintonkamper': ('badmintonkamp',),
'badstubad': ('badstubad',),
'badstubada': ('badstubad',),
'badstubadene': ('badstubad',),
'badstubadet': ('badstubad',),
'badstua': ('badstue',),
'badstue': ('badstue',),
'badstuen': ('badstue',),
'badstuene': ('badstue',),
'badstuer': ('badstue',),
'badstuomn': ('badstuomn',),
'badstuomnen': ('badstuomn',),
'badstuomnene': ('badstuomn',),
'badstuomner': ('badstuomn',),
'badstuovn': ('badstuovn',),
'badstuovnen': ('badstuovn',),
'badstuovnene': ('badstuovn',),
'badstuovner': ('badstuovn',),
'bag': ('bag',),
'bagen': ('bag',),
'bagene': ('bag',),
'bager': ('bag',),
'bagasje': ('bagasje',),
'bagasjen': ('bagasje',),
'bagasjene': ('bagasje',),
'bagasjer': ('bagasje',),
'bagasjebrett': ('bagasjebrett',),
'bagasjebretta': ('bagasjebrett',),
'bagasjebrettene': ('bagasjebrett',),
'bagasjebretter': ('bagasjebrett',),
'bagasjebrettet': ('bagasjebrett',),
'bagasjebærer': ('bagasjebærer',),
'bagasjebærere': ('bagasjebærer',),
'bagasjebæreren': ('bagasjebærer',),
'bagasjebærerer': ('bagasjebærer',),
'bagasjebærerne': ('bagasjebærer',),
'bagasjeforsikring': ('bagasjeforsikring',),
'bagasjeforsikringa': ('bagasjeforsikring',),
'bagasjeforsikringen': ('bagasjeforsikring',),
'bagasjeforsikringene': ('bagasjeforsikring',),
'bagasjeforsikringer': ('bagasjeforsikring',),
'bagasjegrind': ('bagasjegrind',),
'bagasjegrinda': ('bagasjegrind',),
'bagasjegrinden': ('bagasjegrind',),
'bagasjegrindene': ('bagasjegrind',),
'bagasjegrinder': ('bagasjegrind',),
'bagasjehylla': ('bagasjehylle',),
'bagasjehylle': ('bagasjehylle',),
'bagasjehyllen': ('bagasjehylle',),
'bagasjehyllene': ('bagasjehylle',),
'bagasjehyller': ('bagasjehylle',),
'bagasjenett': ('bagasjenett',),
'bagasjenetta': ('bagasjenett',),
'bagasjenettene': ('bagasjenett',),
'bagasjenettet': ('bagasjenett',),
'bagasjerom': ('bagasjerom',),
'bagasjeromma': ('bagasjerom',),
'bagasjerommene': ('bagasjerom',),
'bagasjerommet': ('bagasjerom',),
'bagatell': ('bagatell',),
'bagatellen': ('bagatell',),
'bagatellene': ('bagatell',),
'bagateller': ('bagatell',),
'bagett': ('bagett',),
'bagetten': ('bagett',),
'bagettene': ('bagett',),
'bagetter': ('bagett',),
'bagler': ('bagler',),
'baglere': ('bagler',),
'bagleren': ('bagler',),
'baglerer': ('bagler',),
'baglerne': ('bagler',),
'baglerbisp': ('baglerbisp',),
'baglerbispen': ('baglerbisp',),
'baglerbispene': ('baglerbisp',),
'baglerbisper': ('baglerbisp',),
'baglerflokk': ('baglerflokk',),
'baglerflokken': ('baglerflokk',),
'baglerflokkene': ('baglerflokk',),
'baglerflokker': ('baglerflokk',),
'baglerhær': ('baglerhær',),
'baglerhæren': ('baglerhær',),
'baglerhærene': ('baglerhær',),
'baglerhærer': ('baglerhær',),
'baglerkonge': ('baglerkonge',),
'baglerkongen': ('baglerkonge',),
'baglerkongene': ('baglerkonge',),
'baglerkonger': ('baglerkonge',),
'bagvogn': ('bagvogn',),
'bagvogna': ('bagvogn',),
'bagvognen': ('bagvogn',),
'bagvognene': ('bagvogn',),
'bagvogner': ('bagvogn',),
'bahaimedlem': ('bahaimedlem',),
'bahaimedlemma': ('bahaimedlem',),
'bahaimedlemmene': ('bahaimedlem',),
'bahaimedlemmer': ('bahaimedlem',),
'bahaimedlemmet': ('bahaimedlem',),
'bahaisamfunn': ('bahaisamfunn',),
'bahaisamfunna': ('bahaisamfunn',),
'bahaisamfunnene': ('bahaisamfunn',),
'bahaisamfunnet': ('bahaisamfunn',),
'bahaitro': ('bahaitro',),
'bahaitroa': ('bahaitro',),
'bahaitroen': ('bahaitro',),
'bahaitroene': ('bahaitro',),
'bahaitroer': ('bahaitro',),
'bahamaner': ('bahamaner',),
'bahamanere': ('bahamaner',),
'bahamaneren': ('bahamaner',),
'bahamanerer': ('bahamaner',),
'bahamanerne': ('bahamaner',),
'bahrainer': ('bahrainer',),
'bahrainere': ('bahrainer',),
'bahraineren': ('bahrainer',),
'bahrainerer': ('bahrainer',),
'bahrainerne': ('bahrainer',),
'baisse': ('baisse',),
'baissen': ('baisse',),
'baissene': ('baisse',),
'baisser': ('baisse',),
'baissespekulant': ('baissespekulant',),
'baissespekulanten': ('baissespekulant',),
'baissespekulantene': ('baissespekulant',),
'baissespekulanter': ('baissespekulant',),
'bajas': ('bajas',),
'bajasen': ('bajas',),
'bajasene': ('bajas',),
'bajaser': ('bajas',),
'bajasfakta': ('bajasfakte',),
'bajasfakte': ('bajasfakte',),
'bajasfakten': ('bajasfakte',),
'bajasfaktene': ('bajasfakte',),
'bajasfakter': ('bajasfakte',),
'bajasfjes': ('bajasfjes',),
'bajasfjesa': ('bajasfjes',),
'bajasfjesene': ('bajasfjes',),
'bajasfjeset': ('bajasfjes',),
'bajasstrek': ('bajasstrek',),
'bajasstreken': ('bajasstrek',),
'bajasstrekene': ('bajasstrek',),
'bajasstreker': ('bajasstrek',),
'bajazzo': ('bajazzo',),
'bajazzoen': ('bajazzo',),
'bajazzoene': ('bajazzo',),
'bajazzoer': ('bajazzo',),
'bajonett': ('bajonett',),
'bajonetten': ('bajonett',),
'bajonettene': ('bajonett',),
'bajonetter': ('bajonett',),
'bajonettkamp': ('bajonettkamp',),
'bajonettkampen': ('bajonettkamp',),
'bajonettkampene': ('bajonettkamp',),
'bajonettkamper': ('bajonettkamp',),
'bajonettlås': ('bajonettlås',),
'bajonettlåsa': ('bajonettlås',),
'bajonettlåsen': ('bajonettlås',),
'bajonettlåsene': ('bajonettlås',),
'bajonettlåser': ('bajonettlås',),
'bajonettlåset': ('bajonettlås',),
'bak': ('bak',),
'baken': ('bak',),
'bakene': ('bak',),
'baker': ('bak',),
'bak': ('bak',),
'baka': ('bak',),
'baken': ('bak',),
'bakene': ('bak',),
'baker': ('bak',),
'baket': ('bak',),
'bakaksel': ('bakaksel',),
'bakakselen': ('bakaksel',),
'bakakslene': ('bakaksel',),
'bakaksler': ('bakaksel',),
'bakbein': ('bakbein',),
'bakbeina': ('bakbein',),
'bakbeinene': ('bakbein',),
'bakbeinet': ('bakbein',),
'bakben': ('bakben',),
'bakbena': ('bakben',),
'bakbenene': ('bakben',),
'bakbenet': ('bakben',),
'bakdel': ('bakdel',),
'bakdelen': ('bakdel',),
'bakdelene': ('bakdel',),
'bakdeler': ('bakdel',),
'bakdør': ('bakdør',),
'bakdøra': ('bakdør',),
'bakdøren': ('bakdør',),
'bakdørene': ('bakdør',),
'bakdører': ('bakdør',),
'bakdørspolitikk': ('bakdørspolitikk',),
'bakdørspolitikken': ('bakdørspolitikk',),
'bakdørspolitikkene': ('bakdørspolitikk',),
'bakdørspolitikker': ('bakdørspolitikk',),
'bakelitt': ('bakelitt',),
'bakelitten': ('bakelitt',),
'bakelittene': ('bakelitt',),
'bakelitter': ('bakelitt',),
'bakende': ('bakende',),
'bakenden': ('bakende',),
'bakendene': ('bakende',),
'bakender': ('bakende',),
'bakepulver': ('bakepulver',),
'bakepulvera': ('bakepulver',),
'bakepulvere': ('bakepulver',),
'bakepulveret': ('bakepulver',),
'bakepulverne': ('bakepulver',),
'baker': ('baker',),
'bakere': ('baker',),
'bakeren': ('baker',),
'bakerer': ('baker',),
'bakerne': ('baker',),
'bakerbutikk': ('bakerbutikk',),
'bakerbutikken': ('bakerbutikk',),
'bakerbutikkene': ('bakerbutikk',),
'bakerbutikker': ('bakerbutikk',),
'bakeri': ('bakeri',),
'bakeria': ('bakeri',),
'bakeriene': ('bakeri',),
'bakerier': ('bakeri',),
'bakeriet': ('bakeri',),
'bakeromn': ('bakeromn',),
'bakeromnen': ('bakeromn',),
'bakeromnene': ('bakeromn',),
'bakeromner': ('bakeromn',),
'bakerovn': ('bakerovn',),
'bakerovnen': ('bakerovn',),
'bakerovnene': ('bakerovn',),
'bakerovner': ('bakerovn',),
'bakervara': ('bakervare',),
'bakervare': ('bakervare',),
'bakervaren': ('bakervare',),
'bakervarene': ('bakervare',),
'bakervarer': ('bakervare',),
'bakevja': ('bakevje',),
'bakevje': ('bakevje',),
'bakevjen': ('bakevje',),
'bakevjene': ('bakevje',),
'bakevjer': ('bakevje',),
'bakfjel': ('bakfjel',),
'bakfjela': ('bakfjel',),
'bakfjelen': ('bakfjel',),
'bakfjelene': ('bakfjel',),
'bakfjeler': ('bakfjel',),
'bakfjøl': ('bakfjøl',),
'bakfjøla': ('bakfjøl',),
'bakfjølen': ('bakfjøl',),
'bakfjølene': ('bakfjøl',),
'bakfjøler': ('bakfjøl',),
'bakgata': ('bakgate',),
'bakgate': ('bakgate',),
'bakgaten': ('bakgate',),
'bakgatene': ('bakgate',),
'bakgater': ('bakgate',),
'bakgrunn': ('bakgrunn',),
'bakgrunnen': ('bakgrunn',),
'bakgrunnene': ('bakgrunn',),
'bakgrunner': ('bakgrunn',),
'bakgrunnsfigur': ('bakgrunnsfigur',),
'bakgrunnsfiguren': ('bakgrunnsfigur',),
'bakgrunnsfigurene': ('bakgrunnsfigur',),
'bakgrunnsfigurer': ('bakgrunnsfigur',),
'bakgrunnsmusikk': ('bakgrunnsmusikk',),
'bakgrunnsmusikken': ('bakgrunnsmusikk',),
'bakgrunnsmusikkene': ('bakgrunnsmusikk',),
'bakgrunnsmusikker': ('bakgrunnsmusikk',),
'bakgrunnsstoff': ('bakgrunnsstoff',),
'bakgrunnsstoffa': ('bakgrunnsstoff',),
'bakgrunnsstoffene': ('bakgrunnsstoff',),
'bakgrunnsstoffet': ('bakgrunnsstoff',),
'bakgård': ('bakgård',),
'bakgården': ('bakgård',),
'bakgårdene': ('bakgård',),
'bakgårder': ('bakgård',),
'bakhandsslag': ('bakhandsslag',),
'bakhandsslaga': ('bakhandsslag',),
'bakhandsslagene': ('bakhandsslag',),
'bakhandsslaget': ('bakhandsslag',),
'bakhjul': ('bakhjul',),
'bakhjula': ('bakhjul',),
'bakhjulene': ('bakhjul',),
'bakhjulet': ('bakhjul',),
'bakhjulsdrift': ('bakhjulsdrift',),
'bakhjulsdrifta': ('bakhjulsdrift',),
'bakhjulsdriften': ('bakhjulsdrift',),
'bakhjulsdriftene': ('bakhjulsdrift',),
'bakhjulsdrifter': ('bakhjulsdrift',),
'bakhoda': ('bakhode',),
'bakhode': ('bakhode',),
'bakhodene': ('bakhode',),
'bakhoder': ('bakhode',),
'bakhodet': ('bakhode',),
'bakhold': ('bakhold',),
'bakholda': ('bakhold',),
'bakholdene': ('bakhold',),
'bakholdet': ('bakhold',),
'bakholdsangrep': ('bakholdsangrep',),
'bakholdsangrepa': ('bakholdsangrep',),
'bakholdsangrepene': ('bakholdsangrep',),
'bakholdsangrepet': ('bakholdsangrep',),
'bakhun': ('bakhun',),
'bakhunen': ('bakhun',),
'bakhunene': ('bakhun',),
'bakhuner': ('bakhun',),
'bakhunved': ('bakhunved',),
'bakhunveden': ('bakhunved',),
'bakhunvedene': ('bakhunved',),
'bakhunveder': ('bakhunved',),
'bakhendene': ('bakhånd',),
'bakhender': ('bakhånd',),
'bakhånd': ('bakhånd',),
'bakhånda': ('bakhånd',),
'bakhånden': ('bakhånd',),
'bakhåndsslag': ('bakhåndsslag',),
'bakhåndsslaga': ('bakhåndsslag',),
'bakhåndsslagene': ('bakhåndsslag',),
'bakhåndsslaget': ('bakhåndsslag',),
'bakk': ('bakk',),
'bakken': ('bakk',),
'bakkene': ('bakk',),
'bakker': ('bakk',),
'bakk': ('bakk',),
'bakken': ('bakk',),
'bakkene': ('bakk',),
'bakker': ('bakk',),
'bakkanal': ('bakkanal',),
'bakkanala': ('bakkanal',),
'bakkanalene': ('bakkanal',),
'bakkanaler': ('bakkanal',),
'bakkanalet': ('bakkanal',),
'bakkant': ('bakkant',),
'bakkanten': ('bakkant',),
'bakkantene': ('bakkant',),
'bakkanter': ('bakkant',),
'bakkant': ('bakkant',),
'bakkanten': ('bakkant',),
'bakkantene': ('bakkant',),
'bakkanter': ('bakkant',),
'bakkantinna': ('bakkantinne',),
'bakkantinne': ('bakkantinne',),
'bakkantinnen': ('bakkantinne',),
'bakkantinnene': ('bakkantinne',),
'bakkantinner': ('bakkantinne',),
'bakke': ('bakke',),
'bakken': ('bakke',),
'bakkene': ('bakke',),
'bakker': ('bakke',),
'bakke': ('bakke',),
'bakken': ('bakke',),
'bakkene': ('bakke',),
'bakker': ('bakke',),
'bakkekam': ('bakkekam',),
'bakkekammen': ('bakkekam',),
'bakkekammene': ('bakkekam',),
'bakkekammer': ('bakkekam',),
'bakkeklaring': ('bakkeklaring',),
'bakkeklaringa': ('bakkeklaring',),
'bakkeklaringen': ('bakkeklaring',),
'bakkeklaringene': ('bakkeklaring',),
'bakkeklaringer': ('bakkeklaring',),
'bakkekneik': ('bakkekneik',),
'bakkekneika': ('bakkekneik',),
'bakkekneiken': ('bakkekneik',),
'bakkekneikene': ('bakkekneik',),
'bakkekneiker': ('bakkekneik',),
'bakkekontakt': ('bakkekontakt',),
'bakkekontakten': ('bakkekontakt',),
'bakkekontaktene': ('bakkekontakt',),
'bakkekontakter': ('bakkekontakt',),
'bakkelandskap': ('bakkelandskap',),
'bakkelandskapa': ('bakkelandskap',),
'bakkelandskapene': ('bakkelandskap',),
'bakkelandskaper': ('bakkelandskap',),
'bakkelandskapet': ('bakkelandskap',),
'bakkels': ('bakkels',),
'bakkelsen': ('bakkels',),
'bakkelsene': ('bakkels',),
'bakkelser': ('bakkels',),
'bakkelse': ('bakkelse',),
'bakkelsen': ('bakkelse',),
'bakkelsene': ('bakkelse',),
'bakkelser': ('bakkelse',),
'bakkeløp': ('bakkeløp',),
'bakkeløpa': ('bakkeløp',),
'bakkeløpene': ('bakkeløp',),
'bakkeløpet': ('bakkeløp',),
'bakkemannskap': ('bakkemannskap',),
'bakkemannskapa': ('bakkemannskap',),
'bakkemannskapene': ('bakkemannskap',),
'bakkemannskaper': ('bakkemannskap',),
'bakkemannskapet': ('bakkemannskap',),
'bakkenbart': ('bakkenbart',),
'bakkenbarten': ('bakkenbart',),
'bakkenbartene': ('bakkenbart',),
'bakkenbarter': ('bakkenbart',),
'bakkepersonell': ('bakkepersonell',),
'bakkepersonella': ('bakkepersonell',),
'bakkepersonellene': ('bakkepersonell',),
'bakkepersoneller': ('bakkepersonell',),
'bakkepersonellet': ('bakkepersonell',),
'bakkeplanering': ('bakkeplanering',),
'bakkeplaneringa': ('bakkeplanering',),
'bakkeplaneringen': ('bakkeplanering',),
'bakkeplaneringene': ('bakkeplanering',),
'bakkeplaneringer': ('bakkeplanering',),
'bakkerekord': ('bakkerekord',),
'bakkerekorden': ('bakkerekord',),
'bakkerekordene': ('bakkerekord',),
'bakkerekorder': ('bakkerekord',),
'bakkeskråning': ('bakkeskråning',),
'bakkeskråninga': ('bakkeskråning',),
'bakkeskråningen': ('bakkeskråning',),
'bakkeskråningene': ('bakkeskråning',),
'bakkeskråninger': ('bakkeskråning',),
'bakkestart': ('bakkestart',),
'bakkestarten': ('bakkestart',),
'bakkestartene': ('bakkestart',),
'bakkestarter': ('bakkestart',),
'bakketjeneste': ('bakketjeneste',),
'bakketjenesten': ('bakketjeneste',),
'bakketjenestene': ('bakketjeneste',),
'bakketjenester': ('bakketjeneste',),
'bakketopp': ('bakketopp',),
'bakketoppen': ('bakketopp',),
'bakketoppene': ('bakketopp',),
'bakketopper': ('bakketopp',),
'bakkropp': ('bakkropp',),
'bakkroppen': ('bakkropp',),
'bakkroppene': ('bakkropp',),
'bakkropper': ('bakkropp',),
'bakksag': ('bakksag',),
'bakksaga': ('bakksag',),
'bakksagen': ('bakksag',),
'bakksagene': ('bakksag',),
'bakksager': ('bakksag',),
'bakkusdyrker': ('bakkusdyrker',),
'bakkusdyrkere': ('bakkusdyrker',),
'bakkusdyrkeren': ('bakkusdyrker',),
'bakkusdyrkerer': ('bakkusdyrker',),
'bakkusdyrkerne': ('bakkusdyrker',),
'bakkusfest': ('bakkusfest',),
'bakkusfesten': ('bakkusfest',),
'bakkusfestene': ('bakkusfest',),
'bakkusfester': ('bakkusfest',),
'baklader': ('baklader',),
'bakladere': ('baklader',),
'bakladeren': ('baklader',),
'bakladerer': ('baklader',),
'bakladerne': ('baklader',),
'bakladning': ('bakladning',),
'bakladninga': ('bakladning',),
'bakladningen': ('bakladning',),
'bakladningene': ('bakladning',),
'bakladninger': ('bakladning',),
'bakladningsbørsa': ('bakladningsbørse',),
'bakladningsbørse': ('bakladningsbørse',),
'bakladningsbørsen': ('bakladningsbørse',),
'bakladningsbørsene': ('bakladningsbørse',),
'bakladningsbørser': ('bakladningsbørse',),
'bakladningsgevær': ('bakladningsgevær',),
'bakladningsgeværa': ('bakladningsgevær',),
'bakladningsgeværene': ('bakladningsgevær',),
'bakladningsgeværer': ('bakladningsgevær',),
'bakladningsgeværet': ('bakladningsgevær',),
'bakladningskanon': ('bakladningskanon',),
'bakladningskanonen': ('bakladningskanon',),
'bakladningskanonene': ('bakladningskanon',),
'bakladningskanoner': ('bakladningskanon',),
'bakladningsvåpen': ('bakladningsvåpen',),
'bakladningsvåpenet': ('bakladningsvåpen',),
'bakladningsvåpna': ('bakladningsvåpen',),
'bakladningsvåpnene': ('bakladningsvåpen',),
'bakleksa': ('baklekse',),
'baklekse': ('baklekse',),
'bakleksen': ('baklekse',),
'bakleksene': ('baklekse',),
'baklekser': ('baklekse',),
'baklengsmål': ('baklengsmål',),
'baklengsmåla': ('baklengsmål',),
'baklengsmålene': ('baklengsmål',),
'baklengsmålet': ('baklengsmål',),
'bakli': ('bakli',),
'baklia': ('bakli',),
'baklien': ('bakli',),
'bakliene': ('bakli',),
'baklier': ('bakli',),
'baklomma': ('baklomme',),
'baklomme': ('baklomme',),
'baklommen': ('baklomme',),
'baklommene': ('baklomme',),
'baklommer': ('baklomme',),
'baklys': ('baklys',),
'baklysa': ('baklys',),
'baklysene': ('baklys',),
'baklyset': ('baklys',),
'baklås': ('baklås',),
'baklåsa': ('baklås',),
'baklåsen': ('baklås',),
'baklåsene': ('baklås',),
'baklåser': ('baklås',),
'baklåset': ('baklås',),
'bakmann': ('bakmann',),
'bakmannen': ('bakmann',),
'bakmenn': ('bakmann',),
'bakmennene': ('bakmann',),
'bakmeis': ('bakmeis',),
'bakmeisa': ('bakmeis',),
'bakmeisen': ('bakmeis',),
'bakmeisene': ('bakmeis',),
'bakmeiser': ('bakmeis',),
'bakol': ('bakol',),
'bakolen': ('bakol',),
'bakolene': ('bakol',),
'bakoler': ('bakol',),
'bakola': ('bakole',),
'bakole': ('bakole',),
'bakolen': ('bakole',),
'bakolene': ('bakole',),
'bakoler': ('bakole',),
'bakpart': ('bakpart',),
'bakparten': ('bakpart',),
'bakpartene': ('bakpart',),
'bakparter': ('bakpart',),
'bakparti': ('bakparti',),
'bakpartia': ('bakparti',),
'bakpartiene': ('bakparti',),
'bakpartier': ('bakparti',),
'bakpartiet': ('bakparti',),
'bakrom': ('bakrom',),
'bakromma': ('bakrom',),
'bakrommene': ('bakrom',),
'bakrommet': ('bakrom',),
'bakrus': ('bakrus',),
'bakrusa': ('bakrus',),
'bakrusen': ('bakrus',),
'bakrusene': ('bakrus',),
'bakruser': ('bakrus',),
'bakruset': ('bakrus',),
'baks': ('baks',),
'baksen': ('baks',),
'baksene': ('baks',),
'bakser': ('baks',),
'bakseta': ('baksete',),
'baksete': ('baksete',),
'baksetene': ('baksete',),
'bakseter': ('baksete',),
'baksetet': ('baksete',),
'baksida': ('bakside',),
'bakside': ('bakside',),
'baksiden': ('bakside',),
'baksidene': ('bakside',),
'baksider': ('bakside',),
'bakskjerm': ('bakskjerm',),
'bakskjermen': ('bakskjerm',),
'bakskjermene': ('bakskjerm',),
'bakskjermer': ('bakskjerm',),
'bakskott': ('bakskott',),
'bakskotten': ('bakskott',),
'bakskottene': ('bakskott',),
'bakskotter': ('bakskott',),
'bakskott': ('bakskott',),
'bakskotta': ('bakskott',),
'bakskottene': ('bakskott',),
'bakskottet': ('bakskott',),
'bakskut': ('bakskut',),
'bakskuten': ('bakskut',),
'bakskutene': ('bakskut',),
'bakskuter': ('bakskut',),
'bakslag': ('bakslag',),
'bakslaga': ('bakslag',),
'bakslagene': ('bakslag',),
'bakslaget': ('bakslag',),
'baksmell': ('baksmell',),
'baksmellen': ('baksmell',),
'baksmellene': ('baksmell',),
'baksmeller': ('baksmell',),
'baksnakk': ('baksnakk',),
'baksnakka': ('baksnakk',),
'baksnakken': ('baksnakk',),
'baksnakkene': ('baksnakk',),
'baksnakker': ('baksnakk',),
'baksnakket': ('baksnakk',),
'bakspark': ('bakspark',),
'baksparka': ('bakspark',),
'baksparkene': ('bakspark',),
'baksparket': ('bakspark',),
'bakspeller': ('bakspeller',),
'bakspellere': ('bakspeller',),
'bakspelleren': ('bakspeller',),
'bakspellerer': ('bakspeller',),
'bakspellerne': ('bakspeller',),
'bakspiller': ('bakspiller',),
'bakspillere': ('bakspiller',),
'bakspilleren': ('bakspiller',),
'bakspillerer': ('bakspiller',),
'bakspillerne': ('bakspiller',),
'bakst': ('bakst',),
'baksten': ('bakst',),
'bakstene': ('bakst',),
'bakster': ('bakst',),
'bakstamn': ('bakstamn',),
'bakstamnen': ('bakstamn',),
'bakstamnene': ('bakstamn',),
'bakstamner': ('bakstamn',),
'bakstavn': ('bakstavn',),
'bakstavnen': ('bakstavn',),
'bakstavnene': ('bakstavn',),
'bakstavner': ('bakstavn',),
'bakstebord': ('bakstebord',),
'baksteborda': ('bakstebord',),
'bakstebordene': ('bakstebord',),
'baksteborder': ('bakstebord',),
'bakstebordet': ('bakstebord',),
'bakstefjel': ('bakstefjel',),
'bakstefjela': ('bakstefjel',),
'bakstefjelen': ('bakstefjel',),
'bakstefjelene': ('bakstefjel',),
'bakstefjeler': ('bakstefjel',),
'bakstefjøl': ('bakstefjøl',),
'bakstefjøla': ('bakstefjøl',),
'bakstefjølen': ('bakstefjøl',),
'bakstefjølene': ('bakstefjøl',),
'bakstefjøler': ('bakstefjøl',),
'bakstehella': ('bakstehelle',),
'bakstehelle': ('bakstehelle',),
'bakstehellen': ('bakstehelle',),
'bakstehellene': ('bakstehelle',),
'baksteheller': ('bakstehelle',),
'bakstekona': ('bakstekone',),
'bakstekone': ('bakstekone',),
'bakstekonen': ('bakstekone',),
'bakstekonene': ('bakstekone',),
'bakstekoner': ('bakstekone',),
'bakster': ('bakster',),
'baksteren': ('bakster',),
'bakstre': ('bakster',),
'bakstrene': ('bakster',),
'bakstrer': ('bakster',),
'bakstespade': ('bakstespade',),
'bakstespaden': ('bakstespade',),
'bakstespadene': ('bakstespade',),
'bakstespader': ('bakstespade',),
'bakstrev': ('bakstrev',),
'bakstreva': ('bakstrev',),
'bakstrevene': ('bakstrev',),
'bakstrevet': ('bakstrev',),
'bakstrever': ('bakstrever',),
'bakstrevere': ('bakstrever',),
'bakstreveren': ('bakstrever',),
'bakstreverer': ('bakstrever',),
'bakstreverne': ('bakstrever',),
'bakstuss': ('bakstuss',),
'bakstussen': ('bakstuss',),
'bakstussene': ('bakstuss',),
'bakstusser': ('bakstuss',),
'bakstykka': ('bakstykke',),
'bakstykke': ('bakstykke',),
'bakstykkene': ('bakstykke',),
'bakstykker': ('bakstykke',),
'bakstykket': ('bakstykke',),
'baktalelse': ('baktalelse',),
'baktalelsen': ('baktalelse',),
'baktalelsene': ('baktalelse',),
'baktalelser': ('baktalelse',),
'baktanke': ('baktanke',),
'baktanken': ('baktanke',),
'baktankene': ('baktanke',),
'baktanker': ('baktanke',),
'baktericid': ('baktericid',),
'baktericida': ('baktericid',),
'baktericidene': ('baktericid',),
'baktericider': ('baktericid',),
'baktericidet': ('baktericid',),
'bakterie': ('bakterie',),
'bakterien': ('bakterie',),
'bakteriene': ('bakterie',),
'bakterier': ('bakterie',),
'bakterieflora': ('bakterieflora',),
'bakteriefloraen': ('bakterieflora',),
'bakteriefloraene': ('bakterieflora',),
'bakteriefloraer': ('bakterieflora',),
'bakteriekoloni': ('bakteriekoloni',),
'bakteriekolonien': ('bakteriekoloni',),
'bakteriekoloniene': ('bakteriekoloni',),
'bakteriekolonier': ('bakteriekoloni',),
'bakteriekultur': ('bakteriekultur',),
'bakteriekulturen': ('bakteriekultur',),
'bakteriekulturene': ('bakteriekultur',),
'bakteriekulturer': ('bakteriekultur',),
'bakteriesjukdom': ('bakteriesjukdom',),
'bakteriesjukdommen': ('bakteriesjukdom',),
'bakteriesjukdommene': ('bakteriesjukdom',),
'bakteriesjukdommer': ('bakteriesjukdom',),
'bakteriesykdom': ('bakteriesykdom',),
'bakteriesykdommen': ('bakteriesykdom',),
'bakteriesykdommene': ('bakteriesykdom',),
'bakteriesykdommer': ('bakteriesykdom',),
'bakteriofag': ('bakteriofag',),
'bakteriofagen': ('bakteriofag',),
'bakteriofagene': ('bakteriofag',),
'bakteriofager': ('bakteriofag',),
'bakteriolog': ('bakteriolog',),
'bakteriologen': ('bakteriolog',),
'bakteriologene': ('bakteriolog',),
'bakteriologer': ('bakteriolog',),
'bakteriologi': ('bakteriologi',),
'bakteriologien': ('bakteriologi',),
'bakteriologiene': ('bakteriologi',),
'bakteriologier': ('bakteriologi',),
'baktofta': ('baktofte',),
'baktofte': ('baktofte',),
'baktoften': ('baktofte',),
'baktoftene': ('baktofte',),
'baktofter': ('baktofte',),
'baktrapp': ('baktrapp',),
'baktrappa': ('baktrapp',),
'baktrappen': ('baktrapp',),
'baktrappene': ('baktrapp',),
'baktrapper': ('baktrapp',),
'baktropp': ('baktropp',),
'baktroppen': ('baktropp',),
'baktroppene': ('baktropp',),
'baktropper': ('baktropp',),
'baktunga': ('baktunge',),
'baktunge': ('baktunge',),
'baktungen': ('baktunge',),
'baktungene': ('baktunge',),
'baktunger': ('baktunge',),
'baktungelyd': ('baktungelyd',),
'baktungelyden': ('baktungelyd',),
'baktungelydene': ('baktungelyd',),
'baktungelyder': ('baktungelyd',),
'bakvaskelse': ('bakvaskelse',),
'bakvaskelsen': ('bakvaskelse',),
'bakvaskelsene': ('bakvaskelse',),
'bakvaskelser': ('bakvaskelse',),
'bakvasking': ('bakvasking',),
'bakvaskinga': ('bakvasking',),
'bakvaskingen': ('bakvasking',),
'bakvaskingene': ('bakvasking',),
'bakvaskinger': ('bakvasking',),
'bakveg': ('bakveg',),
'bakvegen': ('bakveg',),
'bakvegene': ('bakveg',),
'bakveger': ('bakveg',),
'bakvei': ('bakvei',),
'bakveien': ('bakvei',),
'bakveiene': ('bakvei',),
'bakveier': ('bakvei',),
'bakverk': ('bakverk',),
'bakverka': ('bakverk',),
'bakverkene': ('bakverk',),
'bakverket': ('bakverk',),
'bal': ('bal',),
'bala': ('bal',),
'balene': ('bal',),
'balet': ('bal',),
'balalaika': ('balalaika',),
'balalaikaen': ('balalaika',),
'balalaikaene': ('balalaika',),
'balalaikaer': ('balalaika',),
'balalaikamusikk': ('balalaikamusikk',),
'balalaikamusikken': ('balalaikamusikk',),
'balalaikamusikkene': ('balalaikamusikk',),
'balalaikamusikker': ('balalaikamusikk',),
'balalaikaorkester': ('balalaikaorkester',),
'balalaikaorkesteret': ('balalaikaorkester',),
'balalaikaorkestra': ('balalaikaorkester',),
'balalaikaorkestre': ('balalaikaorkester',),
'balalaikaorkestrene': ('balalaikaorkester',),
'balalaikaorkestret': ('balalaikaorkester',),
'balanse': ('balanse',),
'balansen': ('balanse',),
'balansene': ('balanse',),
'balanser': ('balanse',),
'balansegang': ('balansegang',),
'balansegangen': ('balansegang',),
'balansegangene': ('balansegang',),
'balanseganger': ('balansegang',),
'balansehjul': ('balansehjul',),
'balansehjula': ('balansehjul',),
'balansehjulene': ('balansehjul',),
'balansehjulet': ('balansehjul',),
'balansekonti': ('balansekonto',),
'balansekontiene': ('balansekonto',),
'balansekonto': ('balansekonto',),
'balansekontoen': ('balansekonto',),
'balansekontoene': ('balansekonto',),
'balansekontoer': ('balansekonto',),
'balansekunst': ('balansekunst',),
'balansekunsten': ('balansekunst',),
'balansekunstene': ('balansekunst',),
'balansekunster': ('balansekunst',),
'balansekunstner': ('balansekunstner',),
'balansekunstnere': ('balansekunstner',),
'balansekunstneren': ('balansekunstner',),
'balansekunstnerer': ('balansekunstner',),
'balansekunstnerne': ('balansekunstner',),
'balansepunkt': ('balansepunkt',),
'balansepunkta': ('balansepunkt',),
'balansepunktene': ('balansepunkt',),
'balansepunkter': ('balansepunkt',),
'balansepunktet': ('balansepunkt',),
'balanseror': ('balanseror',),
'balanserora': ('balanseror',),
'balanserorene': ('balanseror',),
'balanseroret': ('balanseror',),
'balansestang': ('balansestang',),
'balansestanga': ('balansestang',),
'balansestangen': ('balansestang',),
'balansestengene': ('balansestang',),
'balansestenger': ('balansestang',),
'baldakin': ('baldakin',),
'baldakinen': ('baldakin',),
'baldakinene': ('baldakin',),
'baldakiner': ('baldakin',),
'balderbrå': ('balderbrå',),
'balderbråa': ('balderbrå',),
'balderbråen': ('balderbrå',),
'balderbråene': ('balderbrå',),
'balderbråer': ('balderbrå',),
'baldrian': ('baldrian',),
'baldrianen': ('baldrian',),
'baldrianene': ('baldrian',),
'baldrianer': ('baldrian',),
'balineser': ('balineser',),
'balinesere': ('balineser',),
'balineseren': ('balineser',),
'balineserer': ('balineser',),
'balineserne': ('balineser',),
'balja': ('balje',),
'balje': ('balje',),
'baljen': ('balje',),
'baljene': ('balje',),
'baljer': ('balje',),
'balkong': ('balkong',),
'balkongen': ('balkong',),
'balkongene': ('balkong',),
'balkonger': ('balkong',),
'balkongkassa': ('balkongkasse',),
'balkongkasse': ('balkongkasse',),
'balkongkassen': ('balkongkasse',),
'balkongkassene': ('balkongkasse',),
'balkongkasser': ('balkongkasse',),
'ball': ('ball',),
'ballen': ('ball',),
'ballene': ('ball',),
'baller': ('ball',),
'ball': ('ball',),
'balla': ('ball',),
'ballene': ('ball',),
'baller': ('ball',),
'ballet': ('ball',),
'ballade': ('ballade',),
'balladen': ('ballade',),
'balladene': ('ballade',),
'ballader': ('ballade',),
'ballade': ('ballade',),
'balladen': ('ballade',),
'balladene': ('ballade',),
'ballader': ('ballade',),
'ballast': ('ballast',),
'ballasten': ('ballast',),
'ballastene': ('ballast',),
'ballaster': ('ballast',),
'ballastjern': ('ballastjern',),
'ballastjerna': ('ballastjern',),
'ballastjernene': ('ballastjern',),
'ballastjernet': ('ballastjern',),
'ballasttank': ('ballasttank',),
'ballasttanken': ('ballasttank',),
'ballasttankene': ('ballasttank',),
'ballasttanker': ('ballasttank',),
'ballblom': ('ballblom',),
'ballblommen': ('ballblom',),
'ballblommene': ('ballblom',),
'ballblommer': ('ballblom',),
'balle': ('balle',),
'ballen': ('balle',),
'ballene': ('balle',),
'baller': ('balle',),
'ballerina': ('ballerina',),
'ballerinaen': ('ballerina',),
'ballerinaene': ('ballerina',),
'ballerinaer': ('ballerina',),
'ballett': ('ballett',),
'balletten': ('ballett',),
'ballettene': ('ballett',),
'balletter': ('ballett',),
'ballettmester': ('ballettmester',),
'ballettmestere': ('ballettmester',),
'ballettmesteren': ('ballettmester',),
'ballettmesterer': ('ballettmester',),
'ballettmesterne': ('ballettmester',),
'ballettmestre': ('ballettmester',),
'ballettmestrene': ('ballettmester',),
'ballettmestrer': ('ballettmester',),
'ballettmusikk': ('ballettmusikk',),
'ballettmusikken': ('ballettmusikk',),
'ballettmusikkene': ('ballettmusikk',),
'ballettmusikker': ('ballettmusikk',),
'ballist': ('ballist',),
'ballisten': ('ballist',),
'ballistene': ('ballist',),
'ballister': ('ballist',),
'ballistikk': ('ballistikk',),
'ballistikken': ('ballistikk',),
'ballistikkene': ('ballistikk',),
'ballistikker': ('ballistikk',),
'ballkjole': ('ballkjole',),
'ballkjolen': ('ballkjole',),
'ballkjolene': ('ballkjole',),
'ballkjoler': ('ballkjole',),
'ballong': ('ballong',),
'ballongen': ('ballong',),
'ballongene': ('ballong',),
'ballonger': ('ballong',),
'ballongbuksa': ('ballongbukse',),
'ballongbukse': ('ballongbukse',),
'ballongbuksen': ('ballongbukse',),
'ballongbuksene': ('ballongbukse',),
'ballongbukser': ('ballongbukse',),
'ballongdekk': ('ballongdekk',),
'ballongdekka': ('ballongdekk',),
'ballongdekkene': ('ballongdekk',),
'ballongdekket': ('ballongdekk',),
'ballongferd': ('ballongferd',),
'ballongferda': ('ballongferd',),
'ballongferden': ('ballongferd',),
'ballongferdene': ('ballongferd',),
'ballongferder': ('ballongferd',),
'ballongform': ('ballongform',),
'ballongforma': ('ballongform',),
'ballongformen': ('ballongform',),
'ballongformene': ('ballongform',),
'ballongformer': ('ballongform',),
'ballongkorg': ('ballongkorg',),
'ballongkorga': ('ballongkorg',),
'ballongkorgen': ('ballongkorg',),
'ballongkorgene': ('ballongkorg',),
'ballongkorger': ('ballongkorg',),
'ballongkurv': ('ballongkurv',),
'ballongkurva': ('ballongkurv',),
'ballongkurven': ('ballongkurv',),
'ballongkurvene': ('ballongkurv',),
'ballongkurver': ('ballongkurv',),
'balloptikon': ('balloptikon',),
'balloptikona': ('balloptikon',),
'balloptikonene': ('balloptikon',),
'balloptikoner': ('balloptikon',),
'balloptikonet': ('balloptikon',),
'ballsal': ('ballsal',),
'ballsalen': ('ballsal',),
'ballsalene': ('ballsal',),
'ballsaler': ('ballsal',),
'ballspell': ('ballspell',),
'ballspella': ('ballspell',),
'ballspellene': ('ballspell',),
'ballspellet': ('ballspell',),
'ballspill': ('ballspill',),
'ballspilla': ('ballspill',),
'ballspillene': ('ballspill',),
'ballspillet': ('ballspill',),
'balsa': ('balsa',),
'balsaen': ('balsa',),
'balsaene': ('balsa',),
'balsaer': ('balsa',),
'balsaflåte': ('balsaflåte',),
'balsaflåten': ('balsaflåte',),
'balsaflåtene': ('balsaflåte',),
'balsaflåter': ('balsaflåte',),
'balsam': ('balsam',),
'balsamen': ('balsam',),
'balsamene': ('balsam',),
'balsamer': ('balsam',),
'balsamduft': ('balsamduft',),
'balsamduften': ('balsamduft',),
'balsamduftene': ('balsamduft',),
'balsamdufter': ('balsamduft',),
'balsamgran': ('balsamgran',),
'balsamgrana': ('balsamgran',),
'balsamgranen': ('balsamgran',),
'balsamgranene': ('balsamgran',),
'balsamgraner': ('balsamgran',),
'balsampoplene': ('balsampoppel',),
'balsampopler': ('balsampoppel',),
'balsampoppel': ('balsampoppel',),
'balsampoppelen': ('balsampoppel',),
'balsamtre': ('balsamtre',),
'balsamtrea': ('balsamtre',),
'balsamtreet': ('balsamtre',),
'balsamtrær': ('balsamtre',),
'balsamtrærne': ('balsamtre',),
'balsatre': ('balsatre',),
'balsatrea': ('balsatre',),
'balsatreet': ('balsatre',),
'balsatrær': ('balsatre',),
'balsatrærne': ('balsatre',),
'balter': ('balter',),
'baltere': ('balter',),
'balteren': ('balter',),
'balterer': ('balter',),
'balterne': ('balter',),
'baluster': ('baluster',),
'balustere': ('baluster',),
'balusteren': ('baluster',),
'balusterne': ('baluster',),
'balustre': ('baluster',),
'balustrene': ('baluster',),
'balustrer': ('baluster',),
'balustrade': ('balustrade',),
'balustraden': ('balustrade',),
'balustradene': ('balustrade',),
'balustrader': ('balustrade',),
'bamblesjuka': ('bamblesjuke',),
'bamblesjuke': ('bamblesjuke',),
'bamblesjuken': ('bamblesjuke',),
'bamblesjukene': ('bamblesjuke',),
'bamblesjuker': ('bamblesjuke',),
'bamblesyka': ('bamblesyke',),
'bamblesyke': ('bamblesyke',),
'bamblesyken': ('bamblesyke',),
'bamblesykene': ('bamblesyke',),
'bamblesyker': ('bamblesyke',),
'bambus': ('bambus',),
'bambusen': ('bambus',),
'bambusene': ('bambus',),
'bambuser': ('bambus',),
'bambusbjørn': ('bambusbjørn',),
'bambusbjørnen': ('bambusbjørn',),
'bambusbjørnene': ('bambusbjørn',),
'bambusbjørner': ('bambusbjørn',),
'bambusrør': ('bambusrør',),
'bambusrøra': ('bambusrør',),
'bambusrørene': ('bambusrør',),
'bambusrøret': ('bambusrør',),
'bambusskott': ('bambusskott',),
'bambusskotta': ('bambusskott',),
'bambusskottene': ('bambusskott',),
'bambusskottet': ('bambusskott',),
'bambusskudd': ('bambusskudd',),
'bambusskudda': ('bambusskudd',),
'bambusskuddene': ('bambusskudd',),
'bambusskuddet': ('bambusskudd',),
'bambusteppa': ('bambusteppe',),
'bambusteppe': ('bambusteppe',),
'bambusteppene': ('bambusteppe',),
'bambustepper': ('bambusteppe',),
'bambusteppet': ('bambusteppe',),
'bamse': ('bamse',),
'bamsen': ('bamse',),
'bamsene': ('bamse',),
'bamser': ('bamse',),
'banalitet': ('banalitet',),
'banaliteten': ('banalitet',),
'banalitetene': ('banalitet',),
'banaliteter': ('banalitet',),
'banan': ('banan',),
'bananen': ('banan',),
'bananene': ('banan',),
'bananer': ('banan',),
'bananflua': ('bananflue',),
'bananflue': ('bananflue',),
'bananfluen': ('bananflue',),
'bananfluene': ('bananflue',),
'bananfluer': ('bananflue',),
'bananmodneri': ('bananmodneri',),
'bananmodneria': ('bananmodneri',),
'bananmodneriene': ('bananmodneri',),
'bananmodnerier': ('bananmodneri',),
'bananmodneriet': ('bananmodneri',),
'bananplantasje': ('bananplantasje',),
'bananplantasjen': ('bananplantasje',),
'bananplantasjene': ('bananplantasje',),
'bananplantasjer': ('bananplantasje',),
'bananplanta': ('bananplante',),
'bananplante': ('bananplante',),
'bananplanten': ('bananplante',),
'bananplantene': ('bananplante',),
'bananplanter': ('bananplante',),
'bananplugg': ('bananplugg',),
'bananpluggen': ('bananplugg',),
'bananpluggene': ('bananplugg',),
'bananplugger': ('bananplugg',),
'bananrepublikk': ('bananrepublikk',),
'bananrepublikken': ('bananrepublikk',),
'bananrepublikkene': ('bananrepublikk',),
'bananrepublikker': ('bananrepublikk',),
'bananskal': ('bananskal',),
'bananskala': ('bananskal',),
'bananskalene': ('bananskal',),
'bananskalet': ('bananskal',),
'bananskall': ('bananskall',),
'bananskalla': ('bananskall',),
'bananskallene': ('bananskall',),
'bananskallet': ('bananskall',),
'banansplitt': ('banansplitt',),
'banansplitten': ('banansplitt',),
'banansplittene': ('banansplitt',),
'banansplitter': ('banansplitt',),
'bananstikker': ('bananstikker',),
'bananstikkere': ('bananstikker',),
'bananstikkeren': ('bananstikker',),
'bananstikkerer': ('bananstikker',),
'bananstikkerne': ('bananstikker',),
'band': ('band',),
'banda': ('band',),
'bandene': ('band',),
'bandet': ('band',),
'band': ('band',),
'banda': ('band',),
'bandene': ('band',),
'bandet': ('band',),
'bandasje': ('bandasje',),
'bandasjen': ('bandasje',),
'bandasjene': ('bandasje',),
'bandasjer': ('bandasje',),
'bandasjist': ('bandasjist',),
'bandasjisten': ('bandasjist',),
'bandasjistene': ('bandasjist',),
'bandasjister': ('bandasjist',),
'bandby': ('bandby',),
'bandbyen': ('bandby',),
'bandbyene': ('bandby',),
'bandbyer': ('bandby',),
'bande': ('bande',),
'banden': ('bande',),
'bandene': ('bande',),
'bander': ('bande',),
'bandefører': ('bandefører',),
'bandeførere': ('bandefører',),
'bandeføreren': ('bandefører',),
'bandeførerer': ('bandefører',),
'bandeførerne': ('bandefører',),
'bandemedlem': ('bandemedlem',),
'bandemedlemma': ('bandemedlem',),
'bandemedlemmene': ('bandemedlem',),
'bandemedlemmer': ('bandemedlem',),
'bandemedlemmet': ('bandemedlem',),
'bandhund': ('bandhund',),
'bandhunden': ('bandhund',),
'bandhundene': ('bandhund',),
'bandhunder': ('bandhund',),
'banditt': ('banditt',),
'banditten': ('banditt',),
'bandittene': ('banditt',),
'banditter': ('banditt',),
'bandjern': ('bandjern',),
'bandjerna': ('bandjern',),
'bandjernene': ('bandjern',),
'bandjernet': ('bandjern',),
'bandkniv': ('bandkniv',),
'bandkniven': ('bandkniv',),
'bandknivene': ('bandkniv',),
'bandkniver': ('bandkniv',),
'bandolær': ('bandolær',),
'bandolæra': ('bandolær',),
'bandolærene': ('bandolær',),
'bandolærer': ('bandolær',),
'bandolæret': ('bandolær',),
'bandopptaker': ('bandopptaker',),
'bandopptakere': ('bandopptaker',),
'bandopptakeren': ('bandopptaker',),
'bandopptakerer': ('bandopptaker',),
'bandopptakerne': ('bandopptaker',),
'bandsalat': ('bandsalat',),
'bandsalaten': ('bandsalat',),
'bandsalatene': ('bandsalat',),
'bandsalater': ('bandsalat',),
'bandspeller': ('bandspeller',),
'bandspellere': ('bandspeller',),
'bandspelleren': ('bandspeller',),
'bandspellerer': ('bandspeller',),
'bandspellerne': ('bandspeller',),
'bandspiller': ('bandspiller',),
'bandspillere': ('bandspiller',),
'bandspilleren': ('bandspiller',),
'bandspillerer': ('bandspiller',),
'bandspillerne': ('bandspiller',),
'bandstokk': ('bandstokk',),
'bandstokken': ('bandstokk',),
'bandstokkene': ('bandstokk',),
'bandstokker': ('bandstokk',),
'bandstål': ('bandstål',),
'bandståla': ('bandstål',),
'bandstålene': ('bandstål',),
'bandstålet': ('bandstål',),
'bandtvang': ('bandtvang',),
'bandtvangen': ('bandtvang',),
'bandtvangene': ('bandtvang',),
'bandtvanger': ('bandtvang',),
'bandy': ('bandy',),
'bandyen': ('bandy',),
'bandyene': ('bandy',),
'bandyer': ('bandy',),
'bandyball': ('bandyball',),
'bandyballen': ('bandyball',),
'bandyballene': ('bandyball',),
'bandyballer': ('bandyball',),
'bandykølla': ('bandykølle',),
'bandykølle': ('bandykølle',),
'bandykøllen': ('bandykølle',),
'bandykøllene': ('bandykølle',),
'bandykøller': ('bandykølle',),
'bandylag': ('bandylag',),
'bandylaga': ('bandylag',),
'bandylagene': ('bandylag',),
'bandylaget': ('bandylag',),
'banebryter': ('banebryter',),
'banebrytere': ('banebryter',),
'banebryteren': ('banebryter',),
'banebryterer': ('banebryter',),
'banebryterne': ('banebryter',),
'banefunksjonær': ('banefunksjonær',),
'banefunksjonæren': ('banefunksjonær',),
'banefunksjonærene': ('banefunksjonær',),
'banefunksjonærer': ('banefunksjonær',),
'banehalvdel': ('banehalvdel',),
'banehalvdelen': ('banehalvdel',),
'banehalvdelene': ('banehalvdel',),
'banehalvdeler': ('banehalvdel',),
'banehogg': ('banehogg',),
'banehogga': ('banehogg',),
'banehoggene': ('banehogg',),
'banehogget': ('banehogg',),
'banehugg': ('banehugg',),
'banehugga': ('banehugg',),
'banehuggene': ('banehugg',),
'banehugget': ('banehugg',),
'banelegema': ('banelegeme',),
'banelegeme': ('banelegeme',),
'banelegemene': ('banelegeme',),
'banelegemer': ('banelegeme',),
'banelegemet': ('banelegeme',),
'banemann': ('banemann',),
'banemannen': ('banemann',),
'banemenn': ('banemann',),
'banemennene': ('banemann',),
'banemann': ('banemann',),
'banemannen': ('banemann',),
'banemenn': ('banemann',),
'banemennene': ('banemann',),
'banemannskap': ('banemannskap',),
'banemannskapa': ('banemannskap',),
'banemannskapene': ('banemannskap',),
'banemannskaper': ('banemannskap',),
'banemannskapet': ('banemannskap',),
'banemester': ('banemester',),
'banemestere': ('banemester',),
'banemesteren': ('banemester',),
'banemesterer': ('banemester',),
'banemesterne': ('banemester',),
'banemestre': ('banemester',),
'banemestrene': ('banemester',),
'banemestrer': ('banemester',),
'banerekord': ('banerekord',),
'banerekorden': ('banerekord',),
'banerekordene': ('banerekord',),
'banerekorder': ('banerekord',),
'banesår': ('banesår',),
'banesåra': ('banesår',),
'banesårene': ('banesår',),
'banesåret': ('banesår',),
'banevokter': ('banevokter',),
'banevoktere': ('banevokter',),
'banevokteren': ('banevokter',),
'banevokterer': ('banevokter',),
'banevokterne': ('banevokter',),
'bangladesher': ('bangladesher',),
'bangladeshere': ('bangladesher',),
'bangladesheren': ('bangladesher',),
'bangladesherer': ('bangladesher',),
'bangladesherne': ('bangladesher',),
'banjer': ('banjer',),
'banjere': ('banjer',),
'banjeren': ('banjer',),
'banjerer': ('banjer',),
'banjerne': ('banjer',),
'banjerdekk': ('banjerdekk',),
'banjerdekka': ('banjerdekk',),
'banjerdekkene': ('banjerdekk',),
'banjerdekket': ('banjerdekk',),
'banjo': ('banjo',),
'banjoen': ('banjo',),
'banjoene': ('banjo',),
'banjoer': ('banjo',),
'banjospell': ('banjospell',),
'banjospella': ('banjospell',),
'banjospellene': ('banjospell',),
'banjospellet': ('banjospell',),
'banjospeller': ('banjospeller',),
'banjospellere': ('banjospeller',),
'banjospelleren': ('banjospeller',),
'banjospellerer': ('banjospeller',),
'banjospellerne': ('banjospeller',),
'banjospill': ('banjospill',),
'banjospilla': ('banjospill',),
'banjospillene': ('banjospill',),
'banjospillet': ('banjospill',),
'banjospiller': ('banjospiller',),
'banjospillere': ('banjospiller',),
'banjospilleren': ('banjospiller',),
'banjospillerer': ('banjospiller',),
'banjospillerne': ('banjospiller',),
'bank': ('bank',),
'banka': ('bank',),
'bankene': ('bank',),
'banket': ('bank',),
'bankaksept': ('bankaksept',),
'bankaksepten': ('bankaksept',),
'bankakseptene': ('bankaksept',),
'bankaksepter': ('bankaksept',),
'bankautomat': ('bankautomat',),
'bankautomaten': ('bankautomat',),
'bankautomatene': ('bankautomat',),
'bankautomater': ('bankautomat',),
'bankboks': ('bankboks',),
'bankboksen': ('bankboks',),
'bankboksene': ('bankboks',),
'bankbokser': ('bankboks',),
'bankdireksjon': ('bankdireksjon',),
'bankdireksjonen': ('bankdireksjon',),
'bankdireksjonene': ('bankdireksjon',),
'bankdireksjoner': ('bankdireksjon',),
'bankdirektør': ('bankdirektør',),
'bankdirektøren': ('bankdirektør',),
'bankdirektørene': ('bankdirektør',),
'bankdirektører': ('bankdirektør',),
'banke': ('banke',),
'banken': ('banke',),
'bankene': ('banke',),
'banker': ('banke',),
'bankebiff': ('bankebiff',),
'bankebiffen': ('bankebiff',),
'bankebiffene': ('bankebiff',),
'bankebiffer': ('bankebiff',),
'bankefasthet': ('bankefasthet',),
'bankefastheta': ('bankefasthet',),
'bankefastheten': ('bankefasthet',),
'bankefasthetene': ('bankefasthet',),
'bankefastheter': ('bankefasthet',),
'bankefisk': ('bankefisk',),
'bankefisken': ('bankefisk',),
'bankefiskene': ('bankefisk',),
'bankefisker': ('bankefisk',),
'bankefiska': ('bankefiske',),
'bankefiske': ('bankefiske',),
'bankefiskene': ('bankefiske',),
'bankefisker': ('bankefiske',),
'bankefisket': ('bankefiske',),
'bankefisker': ('bankefisker',),
'bankefiskere': ('bankefisker',),
'bankefiskeren': ('bankefisker',),
'bankefiskerer': ('bankefisker',),
'bankefiskerne': ('bankefisker',),
'bankekjøtt': ('bankekjøtt',),
'bankekjøtta': ('bankekjøtt',),
'bankekjøttene': ('bankekjøtt',),
'bankekjøttet': ('bankekjøtt',),
'bankemat': ('bankemat',),
'bankematen': ('bankemat',),
'bankematene': ('bankemat',),
'bankemater': ('bankemat',),
'banker': ('banker',),
'bankere': ('banker',),
'bankeren': ('banker',),
'bankerer': ('banker',),
'bankerne': ('banker',),
'bankerott': ('bankerott',),
'bankerotten': ('bankerott',),
'bankerottene': ('bankerott',),
'bankerotter': ('bankerott',),
'banketre': ('banketre',),
'banketrea': ('banketre',),
'banketreet': ('banketre',),
'banketrær': ('banketre',),
'banketrærne': ('banketre',),
'bankett': ('bankett',),
'banketten': ('bankett',),
'bankettene': ('bankett',),
'banketter': ('bankett',),
'bankett': ('bankett',),
'banketten': ('bankett',),
'bankettene': ('bankett',),
'banketter': ('bankett',),
'bankfilial': ('bankfilial',),
'bankfilialen': ('bankfilial',),
'bankfilialene': ('bankfilial',),
'bankfilialer': ('bankfilial',),
'bankfiska': ('bankfiske',),
'bankfiske': ('bankfiske',),
'bankfiskene': ('bankfiske',),
'bankfisker': ('bankfiske',),
'bankfisket': ('bankfiske',),
'bankfisker': ('bankfisker',),
'bankfiskere': ('bankfisker',),
'bankfiskeren': ('bankfisker',),
'bankfiskerer': ('bankfisker',),
'bankfiskerne': ('bankfisker',),
'bankforbindelse': ('bankforbindelse',),
'bankforbindelsen': ('bankforbindelse',),
'bankforbindelsene': ('bankforbindelse',),
'bankforbindelser': ('bankforbindelse',),
'bankfunksjonær': ('bankfunksjonær',),
'bankfunksjonæren': ('bankfunksjonær',),
'bankfunksjonærene': ('bankfunksjonær',),
'bankfunksjonærer': ('bankfunksjonær',),
'bankgiro': ('bankgiro',),
'bankgiroen': ('bankgiro',),
'bankgiroene': ('bankgiro',),
'bankgiroer': ('bankgiro',),
'bankgirokonti': ('bankgirokonto',),
'bankgirokontiene': ('bankgirokonto',),
'bankgirokonto': ('bankgirokonto',),
'bankgirokontoen': ('bankgirokonto',),
'bankgirokontoene': ('bankgirokonto',),
'bankgirokontoer': ('bankgirokonto',),
'bankgjeld': ('bankgjeld',),
'bankgjelda': ('bankgjeld',),
'bankgjelden': ('bankgjeld',),
'bankgjeldene': ('bankgjeld',),
'bankgjelder': ('bankgjeld',),
'bankhvelv': ('bankhvelv',),
'bankhvelva': ('bankhvelv',),
'bankhvelvene': ('bankhvelv',),
'bankhvelvet': ('bankhvelv',),
'bankier': ('bankier',),
'bankieren': ('bankier',),
'bankierene': ('bankier',),
'bankierer': ('bankier',),
'bankierfirma': ('bankierfirma',),
'bankierfirmaene': ('bankierfirma',),
'bankierfirmaer': ('bankierfirma',),
'bankierfirmaet': ('bankierfirma',),
'bankierprovisjon': ('bankierprovisjon',),
'bankierprovisjonen': ('bankierprovisjon',),
'bankierprovisjonene': ('bankierprovisjon',),
'bankierprovisjoner': ('bankierprovisjon',),
'bankinnskott': ('bankinnskott',),
'bankinnskotta': ('bankinnskott',),
'bankinnskottene': ('bankinnskott',),
'bankinnskottet': ('bankinnskott',),
'bankinnskudd': ('bankinnskudd',),
'bankinnskudda': ('bankinnskudd',),
'bankinnskuddene': ('bankinnskudd',),
'bankinnskuddet': ('bankinnskudd',),
'bankinspeksjon': ('bankinspeksjon',),
'bankinspeksjonen': ('bankinspeksjon',),
'bankinspeksjonene': ('bankinspeksjon',),
'bankinspeksjoner': ('bankinspeksjon',),
'bankkasserer': ('bankkasserer',),
'bankkasserere': ('bankkasserer',),
'bankkassereren': ('bankkasserer',),
'bankkassererer': ('bankkasserer',),
'bankkassererne': ('bankkasserer',),
'bankkonti': ('bankkonto',),
'bankkontiene': ('bankkonto',),
'bankkonto': ('bankkonto',),
'bankkontoen': ('bankkonto',),
'bankkontoene': ('bankkonto',),
'bankkontoer': ('bankkonto',),
'bankkreditt': ('bankkreditt',),
'bankkreditten': ('bankkreditt',),
'bankkredittene': ('bankkreditt',),
'bankkreditter': ('bankkreditt',),
'bankkunde': ('bankkunde',),
'bankkunden': ('bankkunde',),
'bankkundene': ('bankkunde',),
'bankkunder': ('bankkunde',),
'banklån': ('banklån',),
'banklåna': ('banklån',),
'banklånene': ('banklån',),
'banklånet': ('banklån',),
'banko': ('banko',),
'bankoen': ('banko',),
'bankoene': ('banko',),
'bankoer': ('banko',),
'bankobrev': ('bankobrev',),
'bankobreva': ('bankobrev',),
'bankobrevene': ('bankobrev',),
'bankobrever': ('bankobrev',),
'bankobrevet': ('bankobrev',),
'bankokonvolutt': ('bankokonvolutt',),
'bankokonvolutten': ('bankokonvolutt',),
'bankokonvoluttene': ('bankokonvolutt',),
'bankokonvolutter': ('bankokonvolutt',),
'bankopost': ('bankopost',),
'bankoposten': ('bankopost',),
'bankopostene': ('bankopost',),
'bankoposter': ('bankopost',),
'bankoverføring': ('bankoverføring',),
'bankoverføringa': ('bankoverføring',),
'bankoverføringen': ('bankoverføring',),
'bankoverføringene': ('bankoverføring',),
'bankoverføringer': ('bankoverføring',),
'bankpolitikk': ('bankpolitikk',),
'bankpolitikken': ('bankpolitikk',),
'bankpolitikkene': ('bankpolitikk',),
'bankpolitikker': ('bankpolitikk',),
'bankran': ('bankran',),
'bankrana': ('bankran',),
'bankranene': ('bankran',),
'bankranet': ('bankran',),
'bankremisse': ('bankremisse',),
'bankremissen': ('bankremisse',),
'bankremissene': ('bankremisse',),
'bankremisser': ('bankremisse',),
'bankør': ('bankør',),
'bankøren': ('bankør',),
'bankørene': ('bankør',),
'bankører': ('bankør',),
'bann': ('bann',),
'banna': ('bann',),
'bannene': ('bann',),
'bannet': ('bann',),
'bannbrev': ('bannbrev',),
'bannbreva': ('bannbrev',),
'bannbrevene': ('bannbrev',),
'bannbrever': ('bannbrev',),
'bannbrevet': ('bannbrev',),
'bannbulle': ('bannbulle',),
'bannbullen': ('bannbulle',),
'bannbullene': ('bannbulle',),
'bannbuller': ('bannbulle',),
'banneord': ('banneord',),
'banneorda': ('banneord',),
'banneordene': ('banneord',),
'banneordet': ('banneord',),
'banner': ('banner',),
'bannera': ('banner',),
'bannere': ('banner',),
'banneret': ('banner',),
'bannerne': ('banner',),
'bannerbærer': ('bannerbærer',),
'bannerbærere': ('bannerbærer',),
'bannerbæreren': ('bannerbærer',),
'bannerbærerer': ('bannerbærer',),
'bannerbærerne': ('bannerbærer',),
'bannerfører': ('bannerfører',),
'bannerførere': ('bannerfører',),
'bannerføreren': ('bannerfører',),
'bannerførerer': ('bannerfører',),
'bannerførerne': ('bannerfører',),
'banning': ('banning',),
'banninga': ('banning',),
'banningen': ('banning',),
'banningene': ('banning',),
'banninger': ('banning',),
'bannlysing': ('bannlysing',),
'bannlysinga': ('bannlysing',),
'bannlysingen': ('bannlysing',),
'bannlysingene': ('bannlysing',),
'bannlysinger': ('bannlysing',),
'bannskap': ('bannskap',),
'bannskapen': ('bannskap',),
'bannskapene': ('bannskap',),
'bannskaper': ('bannskap',),
'bannstråle': ('bannstråle',),
'bannstrålen': ('bannstråle',),
'bannstrålene': ('bannstråle',),
'bannstråler': ('bannstråle',),
'bantamer': ('bantamer',),
'bantamere': ('bantamer',),
'bantameren': ('bantamer',),
'bantamerer': ('bantamer',),
'bantamerne': ('bantamer',),
'bantamhøns': ('bantamhøns',),
'bantamhønsa': ('bantamhøns',),
'bantamhønsene': ('bantamhøns',),
'bantamhønset': ('bantamhøns',),
'bantamklassa': ('bantamklasse',),
'bantamklasse': ('bantamklasse',),
'bantamklassen': ('bantamklasse',),
'bantamklassene': ('bantamklasse',),
'bantamklasser': ('bantamklasse',),
'bantamvekt': ('bantamvekt',),
'bantamvekta': ('bantamvekt',),
'bantamvekten': ('bantamvekt',),
'bantamvektene': ('bantamvekt',),
'bantamvekter': ('bantamvekt',),
'bantu': ('bantu',),
'bantuen': ('bantu',),
'bantuene': ('bantu',),
'bantuer': ('bantu',),
'bantu': ('bantu',),
'bantuneger': ('bantuneger',),
'bantunegere': ('bantuneger',),
'bantunegeren': ('bantuneger',),
'bantunegerer': ('bantuneger',),
'bantunegerne': ('bantuneger',),
'bantunegre': ('bantuneger',),
'bantunegrene': ('bantuneger',),
'bantunegrer': ('bantuneger',),
'bantuspråk': ('bantuspråk',),
'bantuspråka': ('bantuspråk',),
'bantuspråkene': ('bantuspråk',),
'bantuspråket': ('bantuspråk',),
'bantustan': ('bantustan',),
'bantustanen': ('bantustan',),
'bantustanene': ('bantustan',),
'bantustaner': ('bantustan',),
'baptisme': ('baptisme',),
'baptismen': ('baptisme',),
'baptismene': ('baptisme',),
'baptismer': ('baptisme',),
'baptist': ('baptist',),
'baptisten': ('baptist',),
'baptistene': ('baptist',),
'baptister': ('baptist',),
'baptistkirka': ('baptistkirke',),
'baptistkirke': ('baptistkirke',),
'baptistkirken': ('baptistkirke',),
'baptistkirkene': ('baptistkirke',),
'baptistkirker': ('baptistkirke',),
'baptistkjerka': ('baptistkjerke',),
'baptistkjerke': ('baptistkjerke',),
'baptistkjerken': ('baptistkjerke',),
'baptistkjerkene': ('baptistkjerke',),
'baptistkjerker': ('baptistkjerke',),
'baptistmenighet': ('baptistmenighet',),
'baptistmenigheta': ('baptistmenighet',),
'baptistmenigheten': ('baptistmenighet',),
'baptistmenighetene': ('baptistmenighet',),
'baptistmenigheter': ('baptistmenighet',),
'baptistprest': ('baptistprest',),
'baptistpresten': ('baptistprest',),
'baptistprestene': ('baptistprest',),
'baptistprester': ('baptistprest',),
'baptistsamfunn': ('baptistsamfunn',),
'baptistsamfunna': ('baptistsamfunn',),
'baptistsamfunnene': ('baptistsamfunn',),
'baptistsamfunnet': ('baptistsamfunn',),
'bar': ('bar',),
'baren': ('bar',),
'barene': ('bar',),
'barer': ('bar',),
'bar': ('bar',),
'baren': ('bar',),
'barene': ('bar',),
'barer': ('bar',),
'bar': ('bar',),
'baren': ('bar',),
'barene': ('bar',),
'bar': ('bar',),
'bara': ('bar',),
'barene': ('bar',),
'baret': ('bar',),
'bar': ('bar',),
'bara': ('bar',),
'barene': ('bar',),
'baret': ('bar',),
'barbader': ('barbader',),
'barbadere': ('barbader',),
'barbaderen': ('barbader',),
'barbaderer': ('barbader',),
'barbaderne': ('barbader',),
'barbadier': ('barbadier',),
'barbadiere': ('barbadier',),
'barbadieren': ('barbadier',),
'barbadierer': ('barbadier',),
'barbadierne': ('barbadier',),
'barbar': ('barbar',),
'barbaren': ('barbar',),
'barbarene': ('barbar',),
'barbarer': ('barbar',),
'barbari': ('barbari',),
'barbaria': ('barbari',),
'barbariene': ('barbari',),
'barbariet': ('barbari',),
'barbarisme': ('barbarisme',),
'barbarismen': ('barbarisme',),
'barbarismene': ('barbarisme',),
'barbarismer': ('barbarisme',),
'barbecue': ('barbecue',),
'barbecuen': ('barbecue',),
'barbecuene': ('barbecue',),
'barbecuer': ('barbecue',),
'barber': ('barber',),
'barberen': ('barber',),
'barberene': ('barber',),
'barberer': ('barber',),
'barberblad': ('barberblad',),
'barberblada': ('barberblad',),
'barberbladene': ('barberblad',),
'barberblader': ('barberblad',),
'barberbladet': ('barberblad',),
'barberer': ('barberer',),
'barberere': ('barberer',),
'barbereren': ('barberer',),
'barbererer': ('barberer',),
'barbererne': ('barberer',),
'barberhøvel': ('barberhøvel',),
'barberhøvelen': ('barberhøvel',),
'barberhøvlene': ('barberhøvel',),
'barberhøvler': ('barberhøvel',),
'barberkniv': ('barberkniv',),
'barberkniven': ('barberkniv',),
'barberknivene': ('barberkniv',),
'barberkniver': ('barberkniv',),
'barberkost': ('barberkost',),
'barberkosten': ('barberkost',),
'barberkostene': ('barberkost',),
'barberkoster': ('barberkost',),
'barberkrem': ('barberkrem',),
'barberkremen': ('barberkrem',),
'barberkremene': ('barberkrem',),
'barberkremer': ('barberkrem',),
'barbermaskin': ('barbermaskin',),
'barbermaskina': ('barbermaskin',),
'barbermaskinen': ('barbermaskin',),
'barbermaskinene': ('barbermaskin',),
'barbermaskiner': ('barbermaskin',),
'barbersalong': ('barbersalong',),
'barbersalongen': ('barbersalong',),
'barbersalongene': ('barbersalong',),
'barbersalonger': ('barbersalong',),
'barberskum': ('barberskum',),
'barberskumma': ('barberskum',),
'barberskummene': ('barberskum',),
'barberskummet': ('barberskum',),
'barbersåpa': ('barbersåpe',),
'barbersåpe': ('barbersåpe',),
'barbersåpen': ('barbersåpe',),
'barbersåpene': ('barbersåpe',),
'barbersåper': ('barbersåpe',),
'barde': ('barde',),
'barden': ('barde',),
'bardene': ('barde',),
'barder': ('barde',),
'bardehval': ('bardehval',),
'bardehvalen': ('bardehval',),
'bardehvalene': ('bardehval',),
'bardehvaler': ('bardehval',),
'bardekval': ('bardekval',),
'bardekvalen': ('bardekval',),
'bardekvalene': ('bardekval',),
'bardekvaler': ('bardekval',),
'bardisk': ('bardisk',),
'bardisken': ('bardisk',),
'bardiskene': ('bardisk',),
'bardisker': ('bardisk',),
'bardun': ('bardun',),
'bardunen': ('bardun',),
'bardunene': ('bardun',),
'barduner': ('bardun',),
'bardunkrok': ('bardunkrok',),
'bardunkroken': ('bardunkrok',),
'bardunkrokene': ('bardunkrok',),
'bardunkroker': ('bardunkrok',),
'bardunstreng': ('bardunstreng',),
'bardunstrengen': ('bardunstreng',),
'bardunstrengene': ('bardunstreng',),
'bardunstrenger': ('bardunstreng',),
'barett': ('barett',),
'baretten': ('barett',),
'barettene': ('barett',),
'baretter': ('barett',),
'barfotdans': ('barfotdans',),
'barfotdansen': ('barfotdans',),
'barfotdansene': ('barfotdans',),
'barfotdanser': ('barfotdans',),
'barfotlege': ('barfotlege',),
'barfotlegen': ('barfotlege',),
'barfotlegene': ('barfotlege',),
'barfotleger': ('barfotlege',),
'barfotmunk': ('barfotmunk',),
'barfotmunken': ('barfotmunk',),
'barfotmunkene': ('barfotmunk',),
'barfotmunker': ('barfotmunk',),
'barfotnonna': ('barfotnonne',),
'barfotnonne': ('barfotnonne',),
'barfotnonnen': ('barfotnonne',),
'barfotnonnene': ('barfotnonne',),
'barfotnonner': ('barfotnonne',),
'barfrost': ('barfrost',),
'barfrosten': ('barfrost',),
'barfrostene': ('barfrost',),
'barfroster': ('barfrost',),
'barhytta': ('barhytte',),
'barhytte': ('barhytte',),
'barhytten': ('barhytte',),
'barhyttene': ('barhytte',),
'barhytter': ('barhytte',),
'barium': ('barium',),
'bariuma': ('barium',),
'bariumene': ('barium',),
'bariumet': ('barium',),
'barkarole': ('barkarole',),
'barkarolen': ('barkarole',),
'barkarolene': ('barkarole',),
'barkaroler': ('barkarole',),
'barkass': ('barkass',),
'barkassen': ('barkass',),
'barkassene': ('barkass',),
'barkasser': ('barkass',),
'barkasse': ('barkasse',),
'barkassen': ('barkasse',),
'barkassene': ('barkasse',),
'barkasser': ('barkasse',),
'barkbille': ('barkbille',),
'barkbillen': ('barkbille',),
'barkbillene': ('barkbille',),
'barkbiller': ('barkbille',),
'barkbåt': ('barkbåt',),
'barkbåten': ('barkbåt',),
'barkbåtene': ('barkbåt',),
'barkbåter': ('barkbåt',),
'barkebrød': ('barkebrød',),
'barkebrøda': ('barkebrød',),
'barkebrødene': ('barkebrød',),
'barkebrødet': ('barkebrød',),
'barkebåt': ('barkebåt',),
'barkebåten': ('barkebåt',),
'barkebåtene': ('barkebåt',),
'barkebåter': ('barkebåt',),
'barkeeper': ('barkeeper',),
'barkeepere': ('barkeeper',),
'barkeeperen': ('barkeeper',),
'barkeeperer': ('barkeeper',),
'barkeeperne': ('barkeeper',),
'barkemaskin': ('barkemaskin',),
'barkemaskina': ('barkemaskin',),
'barkemaskinen': ('barkemaskin',),
'barkemaskinene': ('barkemaskin',),
'barkemaskiner': ('barkemaskin',),
'barkespade': ('barkespade',),
'barkespaden': ('barkespade',),
'barkespadene': ('barkespade',),
'barkespader': ('barkespade',),
'barkett': ('barkett',),
'barketten': ('barkett',),
'barkettene': ('barkett',),
'barketter': ('barkett',),
'barkrakk': ('barkrakk',),
'barkrakken': ('barkrakk',),
'barkrakkene': ('barkrakk',),
'barkrakker': ('barkrakk',),
'barkvist': ('barkvist',),
'barkvisten': ('barkvist',),
'barkvistene': ('barkvist',),
'barkvister': ('barkvist',),
'barlind': ('barlind',),
'barlinda': ('barlind',),
'barlinden': ('barlind',),
'barlindene': ('barlind',),
'barlinder': ('barlind',),
'barlindfamilie': ('barlindfamilie',),
'barlindfamilien': ('barlindfamilie',),
'barlindfamiliene': ('barlindfamilie',),
'barlindfamilier': ('barlindfamilie',),
'barm': ('barm',),
'barmen': ('barm',),
'barmene': ('barm',),
'barmer': ('barm',),
'barmark': ('barmark',),
'barmarka': ('barmark',),
'barmarken': ('barmark',),
'barmarkene': ('barmark',),
'barmarker': ('barmark',),
'barmarksamling': ('barmarksamling',),
'barmarksamlinga': ('barmarksamling',),
'barmarksamlingen': ('barmarksamling',),
'barmarksamlingene': ('barmarksamling',),
'barmarksamlinger': ('barmarksamling',),
'barmhjertighet': ('barmhjertighet',),
'barmhjertigheta': ('barmhjertighet',),
'barmhjertigheten': ('barmhjertighet',),
'barmhjertighetene': ('barmhjertighet',),
'barmhjertigheter': ('barmhjertighet',),
'barmhjertighetsdrap': ('barmhjertighetsdrap',),
'barmhjertighetsdrapa': ('barmhjertighetsdrap',),
'barmhjertighetsdrapene': ('barmhjertighetsdrap',),
'barmhjertighetsdrapet': ('barmhjertighetsdrap',),
'barmhjertighetsgjerning': ('barmhjertighetsgjerning',),
'barmhjertighetsgjerninga': ('barmhjertighetsgjerning',),
'barmhjertighetsgjerningen': ('barmhjertighetsgjerning',),
'barmhjertighetsgjerningene': ('barmhjertighetsgjerning',),
'barmhjertighetsgjerninger': ('barmhjertighetsgjerning',),
'barn': ('barn',),
'barna': ('barn',),
'barnene': ('barn',),
'barnet': ('barn',),
'barndom': ('barndom',),
'barndommen': ('barndom',),
'barndommene': ('barndom',),
'barndommer': ('barndom',),
'barndomsdrøm': ('barndomsdrøm',),
'barndomsdrømmen': ('barndomsdrøm',),
'barndomsdrømmene': ('barndomsdrøm',),
'barndomsdrømmer': ('barndomsdrøm',),
'barndomsheim': ('barndomsheim',),
'barndomsheimen': ('barndomsheim',),
'barndomsheimene': ('barndomsheim',),
'barndomsheimer': ('barndomsheim',),
'barndomshjem': ('barndomshjem',),
'barndomshjemma': ('barndomshjem',),
'barndomshjemmene': ('barndomshjem',),
'barndomshjemmet': ('barndomshjem',),
'barndomsminna': ('barndomsminne',),
'barndomsminne': ('barndomsminne',),
'barndomsminnene': ('barndomsminne',),
'barndomsminner': ('barndomsminne',),
'barndomsminnet': ('barndomsminne',),
'barndomstid': ('barndomstid',),
'barndomstida': ('barndomstid',),
'barndomstiden': ('barndomstid',),
'barndomstidene': ('barndomstid',),
'barndomstider': ('barndomstid',),
'barndomsvenn': ('barndomsvenn',),
'barndomsvennen': ('barndomsvenn',),
'barndomsvennene': ('barndomsvenn',),
'barndomsvenner': ('barndomsvenn',),
'barndomsvenninna': ('barndomsvenninne',),
'barndomsvenninne': ('barndomsvenninne',),
'barndomsvenninnen': ('barndomsvenninne',),
'barndomsvenninnene': ('barndomsvenninne',),
'barndomsvenninner': ('barndomsvenninne',),
'barnearbeid': ('barnearbeid',),
'barnearbeida': ('barnearbeid',),
'barnearbeidene': ('barnearbeid',),
'barnearbeider': ('barnearbeid',),
'barnearbeidet': ('barnearbeid',),
'barnebarn': ('barnebarn',),
'barnebarna': ('barnebarn',),
'barnebarnene': ('barnebarn',),
'barnebarnet': ('barnebarn',),
'barnebegrensning': ('barnebegrensning',),
'barnebegrensninga': ('barnebegrensning',),
'barnebegrensningen': ('barnebegrensning',),
'barnebegrensningene': ('barnebegrensning',),
'barnebegrensninger': ('barnebegrensning',),
'barnebidrag': ('barnebidrag',),
'barnebidraga': ('barnebidrag',),
'barnebidragene': ('barnebidrag',),
'barnebidraget': ('barnebidrag',),
'barnebillett': ('barnebillett',),
'barnebilletten': ('barnebillett',),
'barnebillettene': ('barnebillett',),
'barnebilletter': ('barnebillett',),
'barneblad': ('barneblad',),
'barneblada': ('barneblad',),
'barnebladene': ('barneblad',),
'barneblader': ('barneblad',),
'barnebladet': ('barneblad',),
'barnedåp': ('barnedåp',),
'barnedåpen': ('barnedåp',),
'barnedåpene': ('barnedåp',),
'barnedåper': ('barnedåp',),
'barnedødelighet': ('barnedødelighet',),
'barnedødeligheta': ('barnedødelighet',),
'barnedødeligheten': ('barnedødelighet',),
'barnedødelighetene': ('barnedødelighet',),
'barnedødeligheter': ('barnedødelighet',),
'barnefamilie': ('barnefamilie',),
'barnefamilien': ('barnefamilie',),
'barnefamiliene': ('barnefamilie',),
'barnefamilier': ('barnefamilie',),
'barnefarsak': ('barnefarsak',),
'barnefarsaka': ('barnefarsak',),
'barnefarsaken': ('barnefarsak',),
'barnefarsakene': ('barnefarsak',),
'barnefarsaker': ('barnefarsak',),
'barnefarssak': ('barnefarssak',),
'barnefarssaka': ('barnefarssak',),
'barnefarssaken': ('barnefarssak',),
'barnefarssakene': ('barnefarssak',),
'barnefarssaker': ('barnefarssak',),
'barneflokk': ('barneflokk',),
'barneflokken': ('barneflokk',),
'barneflokkene': ('barneflokk',),
'barneflokker': ('barneflokk',),
'barneforestilling': ('barneforestilling',),
'barneforestillinga': ('barneforestilling',),
'barneforestillingen': ('barneforestilling',),
'barneforestillingene': ('barneforestilling',),
'barneforestillinger': ('barneforestilling',),
'barnehage': ('barnehage',),
'barnehagen': ('barnehage',),
'barnehagene': ('barnehage',),
'barnehager': ('barnehage',),
'barnehagelærer': ('barnehagelærer',),
'barnehagelærere': ('barnehagelærer',),
'barnehagelæreren': ('barnehagelærer',),
'barnehagelærerer': ('barnehagelærer',),
'barnehagelærerne': ('barnehagelærer',),
'barneheim': ('barneheim',),
'barneheimen': ('barneheim',),
'barneheimene': ('barneheim',),
'barneheimer': ('barneheim',),
'barnehjem': ('barnehjem',),
'barnehjemma': ('barnehjem',),
'barnehjemmene': ('barnehjem',),
'barnehjemmet': ('barnehjem',),
'barneklær': ('barneklær',),
'barneklærne': ('barneklær',),
'barnelammelse': ('barnelammelse',),
'barnelammelsen': ('barnelammelse',),
'barnelammelsene': ('barnelammelse',),
'barnelammelser': ('barnelammelse',),
'barnelege': ('barnelege',),
'barnelegen': ('barnelege',),
'barnelegene': ('barnelege',),
'barneleger': ('barnelege',),
'barnelærdom': ('barnelærdom',),
'barnelærdommen': ('barnelærdom',),
'barnelærdommene': ('barnelærdom',),
'barnelærdommer': ('barnelærdom',),
'barnemat': ('barnemat',),
'barnematen': ('barnemat',),
'barnematene': ('barnemat',),
'barnemater': ('barnemat',),
'barnemishandling': ('barnemishandling',),
'barnemishandlinga': ('barnemishandling',),
'barnemishandlingen': ('barnemishandling',),
'barnemishandlingene': ('barnemishandling',),
'barnemishandlinger': ('barnemishandling',),
'barneombud': ('barneombud',),
'barneombuda': ('barneombud',),
'barneombudene': ('barneombud',),
'barneombudet': ('barneombud',),
'barneoppdragelse': ('barneoppdragelse',),
'barneoppdragelsen': ('barneoppdragelse',),
'barneoppdragelsene': ('barneoppdragelse',),
'barneoppdragelser': ('barneoppdragelse',),
'barnepark': ('barnepark',),
'barneparken': ('barnepark',),
'barneparkene': ('barnepark',),
'barneparker': ('barnepark',),
'barneparkering': ('barneparkering',),
'barneparkeringa': ('barneparkering',),
'barneparkeringen': ('barneparkering',),
'barneparkeringene': ('barneparkering',),
'barneparkeringer': ('barneparkering',),
'barnepika': ('barnepike',),
'barnepike': ('barnepike',),
'barnepiken': ('barnepike',),
'barnepikene': ('barnepike',),
'barnepiker': ('barnepike',),
'barnepleia': ('barnepleie',),
'barnepleie': ('barnepleie',),
'barnepleien': ('barnepleie',),
'barnepleiene': ('barnepleie',),
'barnepleier': ('barnepleie',),
'barnepleier': ('barnepleier',),
'barnepleiere': ('barnepleier',),
'barnepleieren': ('barnepleier',),
'barnepleierer': ('barnepleier',),
'barnepleierne': ('barnepleier',),
'barnepsykiatri': ('barnepsykiatri',),
'barnepsykiatrien': ('barnepsykiatri',),
'barnepsykiatriene': ('barnepsykiatri',),
'barnepsykiatrier': ('barnepsykiatri',),
'barnepsykologi': ('barnepsykologi',),
'barnepsykologien': ('barnepsykologi',),
'barnepsykologiene': ('barnepsykologi',),
'barnepsykologier': ('barnepsykologi',),
'barneregla': ('barneregle',),
'barneregle': ('barneregle',),
'barnereglen': ('barneregle',),
'barnereglene': ('barneregle',),
'barneregler': ('barneregle',),
'barnerov': ('barnerov',),
'barnerova': ('barnerov',),
'barnerovene': ('barnerov',),
'barnerovet': ('barnerov',),
'barnerumpa': ('barnerumpe',),
'barnerumpe': ('barnerumpe',),
'barnerumpen': ('barnerumpe',),
'barnerumpene': ('barnerumpe',),
'barnerumper': ('barnerumpe',),
'barnesang': ('barnesang',),
'barnesangen': ('barnesang',),
'barnesangene': ('barnesang',),
'barnesanger': ('barnesang',),
'barneselskap': ('barneselskap',),
'barneselskapa': ('barneselskap',),
'barneselskapene': ('barneselskap',),
'barneselskaper': ('barneselskap',),
'barneselskapet': ('barneselskap',),
'barnesikring': ('barnesikring',),
'barnesikringa': ('barnesikring',),
'barnesikringen': ('barnesikring',),
'barnesikringene': ('barnesikring',),
'barnesikringer': ('barnesikring',),
'barnesjukdom': ('barnesjukdom',),
'barnesjukdommen': ('barnesjukdom',),
'barnesjukdommene': ('barnesjukdom',),
'barnesjukdommer': ('barnesjukdom',),
'barneskei': ('barneskei',),
'barneskeia': ('barneskei',),
'barneskeien': ('barneskei',),
'barneskeiene': ('barneskei',),
'barneskeier': ('barneskei',),
'barneskje': ('barneskje',),
'barneskjea': ('barneskje',),
'barneskjeen': ('barneskje',),
'barneskjeene': ('barneskje',),
'barneskjeer': ('barneskje',),
'barneskole': ('barneskole',),
'barneskolen': ('barneskole',),
'barneskolene': ('barneskole',),
'barneskoler': ('barneskole',),
'barnespråk': ('barnespråk',),
'barnespråka': ('barnespråk',),
'barnespråkene': ('barnespråk',),
'barnespråket': ('barnespråk',),
'barnesull': ('barnesull',),
'barnesullen': ('barnesull',),
'barnesullene': ('barnesull',),
'barnesuller': ('barnesull',),
'barnesykdom': ('barnesykdom',),
'barnesykdommen': ('barnesykdom',),
'barnesykdommene': ('barnesykdom',),
'barnesykdommer': ('barnesykdom',),
'barnesåpa': ('barnesåpe',),
'barnesåpe': ('barnesåpe',),
'barnesåpen': ('barnesåpe',),
'barnesåpene': ('barnesåpe',),
'barnesåper': ('barnesåpe',),
'barnetall': ('barnetall',),
'barnetalla': ('barnetall',),
'barnetallene': ('barnetall',),
'barnetallet': ('barnetall',),
'barnetekka': ('barnetekke',),
'barnetekke': ('barnetekke',),
'barnetekkene': ('barnetekke',),
'barnetekker': ('barnetekke',),
'barnetekket': ('barnetekke',),
'barnetime': ('barnetime',),
'barnetimen': ('barnetime',),
'barnetimene': ('barnetime',),
'barnetimer': ('barnetime',),
'barnetog': ('barnetog',),
'barnetoga': ('barnetog',),
'barnetogene': ('barnetog',),
'barnetoget': ('barnetog',),
'barnetrinn': ('barnetrinn',),
'barnetrinna': ('barnetrinn',),
'barnetrinnene': ('barnetrinn',),
'barnetrinnet': ('barnetrinn',),
'barnetro': ('barnetro',),
'barnetroa': ('barnetro',),
'barnetroen': ('barnetro',),
'barnetroene': ('barnetro',),
'barnetroer': ('barnetro',),
'barnetrygd': ('barnetrygd',),
'barnetrygda': ('barnetrygd',),
'barnetrygden': ('barnetrygd',),
'barnetrygdene': ('barnetrygd',),
'barnetrygder': ('barnetrygd',),
'barnevakt': ('barnevakt',),
'barnevakta': ('barnevakt',),
'barnevakten': ('barnevakt',),
'barnevaktene': ('barnevakt',),
'barnevakter': ('barnevakt',),
'barnevern': ('barnevern',),
'barneverna': ('barnevern',),
'barnevernene': ('barnevern',),
'barnevernet': ('barnevern',),
'barnevernsnemnd': ('barnevernsnemnd',),
'barnevernsnemnda': ('barnevernsnemnd',),
'barnevernsnemnden': ('barnevernsnemnd',),
'barnevernsnemndene': ('barnevernsnemnd',),
'barnevernsnemnder': ('barnevernsnemnd',),
'barnevogn': ('barnevogn',),
'barnevogna': ('barnevogn',),
'barnevognen': ('barnevogn',),
'barnevognene': ('barnevogn',),
'barnevogner': ('barnevogn',),
'barneår': ('barneår',),
'barneåra': ('barneår',),
'barneårene': ('barneår',),
'barneåret': ('barneår',),
'barnsbein': ('barnsbein',),
'barnsben': ('barnsben',),
'barnsbena': ('barnsben',),
'barnsbenene': ('barnsben',),
'barnsbenet': ('barnsben',),
'barnsnød': ('barnsnød',),
'barnsnøda': ('barnsnød',),
'barnsnøden': ('barnsnød',),
'barnsnødene': ('barnsnød',),
'barnsnøder': ('barnsnød',),
'barnål': ('barnål',),
'barnåla': ('barnål',),
'barnålen': ('barnål',),
'barnålene': ('barnål',),
'barnåler': ('barnål',),
'barokk': ('barokk',),
'barokken': ('barokk',),
'barokkene': ('barokk',),
'barokker': ('barokk',),
'barokkbygning': ('barokkbygning',),
'barokkbygninga': ('barokkbygning',),
'barokkbygningen': ('barokkbygning',),
'barokkbygningene': ('barokkbygning',),
'barokkbygninger': ('barokkbygning',),
'barokkmusikk': ('barokkmusikk',),
'barokkmusikken': ('barokkmusikk',),
'barokkmusikkene': ('barokkmusikk',),
'barokkmusikker': ('barokkmusikk',),
'barokkstil': ('barokkstil',),
'barokkstilen': ('barokkstil',),
'barokkstilene': ('barokkstil',),
'barokkstiler': ('barokkstil',),
'barometer': ('barometer',),
'barometeret': ('barometer',),
'barometra': ('barometer',),
'barometre': ('barometer',),
'barometrene': ('barometer',),
'barometret': ('barometer',),
'barometerfall': ('barometerfall',),
'barometerfalla': ('barometerfall',),
'barometerfallene': ('barometerfall',),
'barometerfallet': ('barometerfall',),
'barometerstand': ('barometerstand',),
'barometerstanden': ('barometerstand',),
'barometerstandene': ('barometerstand',),
'barometerstander': ('barometerstand',),
'barometersøyla': ('barometersøyle',),
'barometersøyle': ('barometersøyle',),
'barometersøylen': ('barometersøyle',),
'barometersøylene': ('barometersøyle',),
'barometersøyler': ('barometersøyle',),
'baron': ('baron',),
'baronen': ('baron',),
'baronene': ('baron',),
'baroner': ('baron',),
'baronessa': ('baronesse',),
'baronesse': ('baronesse',),
'baronessen': ('baronesse',),
'baronessene': ('baronesse',),
'baronesser': ('baronesse',),
'baroni': ('baroni',),
'baronia': ('baroni',),
'baroniene': ('baroni',),
'baronier': ('baroni',),
'baroniet': ('baroni',),
'barontitlene': ('barontittel',),
'barontitler': ('barontittel',),
'barontittel': ('barontittel',),
'barontittelen': ('barontittel',),
'baronverdighet': ('baronverdighet',),
'baronverdigheta': ('baronverdighet',),
'baronverdigheten': ('baronverdighet',),
'baronverdighetene': ('baronverdighet',),
'baronverdigheter': ('baronverdighet',),
'barrakuda': ('barrakuda',),
'barrakudaen': ('barrakuda',),
'barrakudaene': ('barrakuda',),
'barrakudaer': ('barrakuda',),
'barre': ('barre',),
'barren': ('barre',),
'barrene': ('barre',),
'barrer': ('barre',),
'barreform': ('barreform',),
'barreforma': ('barreform',),
'barreformen': ('barreform',),
'barreformene': ('barreform',),
'barreformer': ('barreform',),
'barregull': ('barregull',),
'barregulla': ('barregull',),
'barregullene': ('barregull',),
'barregullet': ('barregull',),
'barrel': ('barrel',),
'barrelen': ('barrel',),
'barrelene': ('barrel',),
'barrels': ('barrel',),
'barriere': ('barriere',),
'barrieren': ('barriere',),
'barrierene': ('barriere',),
'barrierer': ('barriere',),
'barriererev': ('barriererev',),
'barrierereva': ('barriererev',),
'barriererevene': ('barriererev',),
'barriererevet': ('barriererev',),
'barrikade': ('barrikade',),
'barrikaden': ('barrikade',),
'barrikadene': ('barrikade',),
'barrikader': ('barrikade',),
'barrikadekjemper': ('barrikadekjemper',),
'barrikadekjempere': ('barrikadekjemper',),
'barrikadekjemperen': ('barrikadekjemper',),
'barrikadekjemperer': ('barrikadekjemper',),
'barrikadekjemperne': ('barrikadekjemper',),
'barsel': ('barsel',),
'barselet': ('barsel',),
'barsla': ('barsel',),
'barslene': ('barsel',),
'barsler': ('barsel',),
'barslet': ('barsel',),
'barselavdeling': ('barselavdeling',),
'barselavdelinga': ('barselavdeling',),
'barselavdelingen': ('barselavdeling',),
'barselavdelingene': ('barselavdeling',),
'barselavdelinger': ('barselavdeling',),
'barselfeber': ('barselfeber',),
'barselfebere': ('barselfeber',),
'barselfeberen': ('barselfeber',),
'barselfeberer': ('barselfeber',),
'barselfeberne': ('barselfeber',),
'barselfebre': ('barselfeber',),
'barselfebrene': ('barselfeber',),
'barselfebrer': ('barselfeber',),
'barselgraut': ('barselgraut',),
'barselgrauten': ('barselgraut',),
'barselgrautene': ('barselgraut',),
'barselgrauter': ('barselgraut',),
'barselgrøt': ('barselgrøt',),
'barselgrøten': ('barselgrøt',),
'barselgrøtene': ('barselgrøt',),
'barselgrøter': ('barselgrøt',),
'barselkrampe': ('barselkrampe',),
'barselkrampen': ('barselkrampe',),
'barselkrampene': ('barselkrampe',),
'barselkramper': ('barselkrampe',),
'barselpengene': ('barselpenger',),
'barselpenger': ('barselpenger',),
'barselseng': ('barselseng',),
'barselsenga': ('barselseng',),
'barselsengen': ('barselseng',),
'barselsengene': ('barselseng',),
'barselsenger': ('barselseng',),
'barselstua': ('barselstue',),
'barselstue': ('barselstue',),
'barselstuen': ('barselstue',),
'barselstuene': ('barselstue',),
'barselstuer': ('barselstue',),
'barselvisitt': ('barselvisitt',),
'barselvisitten': ('barselvisitt',),
'barselvisittene': ('barselvisitt',),
'barselvisitter': ('barselvisitt',),
'barsking': ('barsking',),
'barskingen': ('barsking',),
'barskingene': ('barsking',),
'barskinger': ('barsking',),
'barskog': ('barskog',),
'barskogen': ('barskog',),
'barskogene': ('barskog',),
'barskoger': ('barskog',),
'barskogbelta': ('barskogbelte',),
'barskogbelte': ('barskogbelte',),
'barskogbeltene': ('barskogbelte',),
'barskogbelter': ('barskogbelte',),
'barskogbeltet': ('barskogbelte',),
'barsok': ('barsok',),
'barsoken': ('barsok',),
'barsokene': ('barsok',),
'barsoker': ('barsok',),
'bart': ('bart',),
'barten': ('bart',),
'bartene': ('bart',),
'barter': ('bart',),
'bartender': ('bartender',),
'bartendere': ('bartender',),
'bartenderen': ('bartender',),
'bartenderer': ('bartender',),
'bartenderne': ('bartender',),
'bartolomeusdag': ('bartolomeusdag',),
'bartolomeusdagen': ('bartolomeusdag',),
'bartolomeusdagene': ('bartolomeusdag',),
'bartolomeusdager': ('bartolomeusdag',),
'bartolomeusmess': ('bartolomeusmess',),
'bartolomeusmesse': ('bartolomeusmesse',),
'bartolomeusnatt': ('bartolomeusnatt',),
'bartolomeusnatta': ('bartolomeusnatt',),
'bartolomeusnatten': ('bartolomeusnatt',),
'bartolomeusnettene': ('bartolomeusnatt',),
'bartolomeusnetter': ('bartolomeusnatt',),
'bartre': ('bartre',),
'bartrea': ('bartre',),
'bartreet': ('bartre',),
'bartrær': ('bartre',),
'bartrærne': ('bartre',),
'bartrevirka': ('bartrevirke',),
'bartrevirke': ('bartrevirke',),
'bartrevirkene': ('bartrevirke',),
'bartrevirker': ('bartrevirke',),
'bartrevirket': ('bartrevirke',),
'bartskjær': ('bartskjær',),
'bartskjæren': ('bartskjær',),
'bartskjærene': ('bartskjær',),
'bartskjærer': ('bartskjær',),
'baryton': ('baryton',),
'barytonen': ('baryton',),
'barytonene': ('baryton',),
'barytoner': ('baryton',),
'barytonsaksofon': ('barytonsaksofon',),
'barytonsaksofonen': ('barytonsaksofon',),
'barytonsaksofonene': ('barytonsaksofon',),
'barytonsaksofoner': ('barytonsaksofon',),
'barytonsanger': ('barytonsanger',),
'barytonsangere': ('barytonsanger',),
'barytonsangeren': ('barytonsanger',),
'barytonsangerer': ('barytonsanger',),
'barytonsangerne': ('barytonsanger',),
'barytonstemme': ('barytonstemme',),
'barytonstemmen': ('barytonstemme',),
'barytonstemmene': ('barytonstemme',),
'barytonstemmer': ('barytonstemme',),
'bas': ('bas',),
'basen': ('bas',),
'basene': ('bas',),
'baser': ('bas',),
'basalforsking': ('basalforsking',),
'basalforskinga': ('basalforsking',),
'basalforskingen': ('basalforsking',),
'basalforskingene': ('basalforsking',),
'basalforskinger': ('basalforsking',),
'basalforskning': ('basalforskning',),
'basalforskninga': ('basalforskning',),
'basalforskningen': ('basalforskning',),
'basalforskningene': ('basalforskning',),
'basalforskninger': ('basalforskning',),
'basalt': ('basalt',),
'basalten': ('basalt',),
'basaltene': ('basalt',),
'basalter': ('basalt',),
'basaltskifer': ('basaltskifer',),
'basaltskifere': ('basaltskifer',),
'basaltskiferen': ('basaltskifer',),
'basaltskiferer': ('basaltskifer',),
'basaltskiferne': ('basaltskifer',),
'basaltskifre': ('basaltskifer',),
'basaltskifrene': ('basaltskifer',),
'basaltskifrer': ('basaltskifer',),
'basar': ('basar',),
'basaren': ('basar',),
'basarene': ('basar',),
'basarer': ('basar',),
'basbåt': ('basbåt',),
'basbåten': ('basbåt',),
'basbåtene': ('basbåt',),
'basbåter': ('basbåt',),
'base': ('base',),
'basen': ('base',),
'basene': ('base',),
'baser': ('base',),
'base': ('base',),
'basen': ('base',),
'basene': ('base',),
'baser': ('base',),
'baseball': ('baseball',),
'baseballen': ('baseball',),
'baseballene': ('baseball',),
'baseballer': ('baseball',),
'basepolitikk': ('basepolitikk',),
'basepolitikken': ('basepolitikk',),
'basepolitikkene': ('basepolitikk',),
'basepolitikker': ('basepolitikk',),
'basilik': ('basilik',),
'basiliken': ('basilik',),
'basilikene': ('basilik',),
'basiliker': ('basilik',),
'basilika': ('basilika',),
'basilikaen': ('basilika',),
'basilikaene': ('basilika',),
'basilikaer': ('basilika',),
'basilikum': ('basilikum',),
'basilikumen': ('basilikum',),
'basilikumene': ('basilikum',),
'basilikumer': ('basilikum',),
'basilisk': ('basilisk',),
'basilisken': ('basilisk',),
'basiliskene': ('basilisk',),
'basilisker': ('basilisk',),
'basill': ('basill',),
'basillen': ('basill',),
'basillene': ('basill',),
'basiller': ('basill',),
'basillbærer': ('basillbærer',),
'basillbærere': ('basillbærer',),
'basillbæreren': ('basillbærer',),
'basillbærerer': ('basillbærer',),
'basillbærerne': ('basillbærer',),
'basillkultur': ('basillkultur',),
'basillkulturen': ('basillkultur',),
'basillkulturene': ('basillkultur',),
'basillkulturer': ('basillkultur',),
'basis': ('basis',),
'basisen': ('basis',),
'basisene': ('basis',),
'basiser': ('basis',),
'basisfraktur': ('basisfraktur',),
'basisfrakturen': ('basisfraktur',),
'basisfrakturene': ('basisfraktur',),
'basisfrakturer': ('basisfraktur',),
'basisgruppa': ('basisgruppe',),
'basisgruppe': ('basisgruppe',),
'basisgruppen': ('basisgruppe',),
'basisgruppene': ('basisgruppe',),
'basisgrupper': ('basisgruppe',),
'basislinja': ('basislinje',),
'basislinje': ('basislinje',),
'basislinjen': ('basislinje',),
'basislinjene': ('basislinje',),
'basislinjer': ('basislinje',),
'basispunkt': ('basispunkt',),
'basispunkta': ('basispunkt',),
'basispunktene': ('basispunkt',),
'basispunkter': ('basispunkt',),
'basispunktet': ('basispunkt',),
'basisår': ('basisår',),
'basisåra': ('basisår',),
'basisårene': ('basisår',),
'basisåret': ('basisår',),
'basker': ('basker',),
'baskere': ('basker',),
'baskeren': ('basker',),
'baskerer': ('basker',),
'baskerne': ('basker',),
'baskerhua': ('baskerhue',),
'baskerhue': ('baskerhue',),
'baskerhuen': ('baskerhue',),
'baskerhuene': ('baskerhue',),
'baskerhuer': ('baskerhue',),
'baskerhuva': ('baskerhuve',),
'baskerhuve': ('baskerhuve',),
'baskerhuven': ('baskerhuve',),
'baskerhuvene': ('baskerhuve',),
'baskerhuver': ('baskerhuve',),
'baskerlua': ('baskerlue',),
'baskerlue': ('baskerlue',),
'baskerluen': ('baskerlue',),
'baskerluene': ('baskerlue',),
'baskerluer': ('baskerlue',),
'baskerluva': ('baskerluve',),
'baskerluve': ('baskerluve',),
'baskerluven': ('baskerluve',),
'baskerluvene': ('baskerluve',),
'baskerluver': ('baskerluve',),
'basketak': ('basketak',),
'basketaka': ('basketak',),
'basketakene': ('basketak',),
'basketaket': ('basketak',),
'basketball': ('basketball',),
'basketballen': ('basketball',),
'basketballene': ('basketball',),
'basketballer': ('basketball',),
'baskisk': ('baskisk',),
'baskisken': ('baskisk',),
'baskiskene': ('baskisk',),
'baskisker': ('baskisk',),
'basrelieff': ('basrelieff',),
'basrelieffa': ('basrelieff',),
'basrelieffene': ('basrelieff',),
'basrelieffer': ('basrelieff',),
'basrelieffet': ('basrelieff',),
'bass': ('bass',),
'bassen': ('bass',),
'bassene': ('bass',),
'basser': ('bass',),
'bass': ('bass',),
'bassen': ('bass',),
'bassene': ('bass',),
'basser': ('bass',),
'bass-sanger': ('bass-sanger',),
'bass-sangere': ('bass-sanger',),
'bass-sangeren': ('bass-sanger',),
'bass-sangerer': ('bass-sanger',),
'bass-sangerne': ('bass-sanger',),
'bass-streng': ('bass-streng',),
'bass-strengen': ('bass-streng',),
'bass-strengene': ('bass-streng',),
'bass-strenger': ('bass-streng',),
'bassanger': ('bassanger',),
'bassangere': ('bassanger',),
'bassangeren': ('bassanger',),
'bassangerer': ('bassanger',),
'bassangerne': ('bassanger',),
'bassbaryton': ('bassbaryton',),
'bassbarytonen': ('bassbaryton',),
'bassbarytonene': ('bassbaryton',),
'bassbarytoner': ('bassbaryton',),
'bassbasun': ('bassbasun',),
'bassbasunen': ('bassbasun',),
'bassbasunene': ('bassbasun',),
'bassbasuner': ('bassbasun',),
'basse': ('basse',),
'bassen': ('basse',),
'bassene': ('basse',),
'basser': ('basse',),
'basseng': ('basseng',),
'bassenga': ('basseng',),
'bassengene': ('basseng',),
'bassenger': ('basseng',),
'bassenget': ('basseng',),
'bassgitar': ('bassgitar',),
'bassgitaren': ('bassgitar',),
'bassgitarene': ('bassgitar',),
'bassgitarer': ('bassgitar',),
'bassist': ('bassist',),
'bassisten': ('bassist',),
'bassistene': ('bassist',),
'bassister': ('bassist',),
'bassnote': ('bassnote',),
'bassnoten': ('bassnote',),
'bassnotene': ('bassnote',),
'bassnoter': ('bassnote',),
'bassnøkkel': ('bassnøkkel',),
'bassnøkkelen': ('bassnøkkel',),
'bassnøklene': ('bassnøkkel',),
'bassnøkler': ('bassnøkkel',),
'basstreng': ('basstreng',),
'basstrengen': ('basstreng',),
'basstrengene': ('basstreng',),
'basstrenger': ('basstreng',),
'basstuba': ('basstuba',),
'basstubaen': ('basstuba',),
'basstubaene': ('basstuba',),
'basstubaer': ('basstuba',),
'bast': ('bast',),
'basten': ('bast',),
'bastene': ('bast',),
'baster': ('bast',),
'bastard': ('bastard',),
'bastarden': ('bastard',),
'bastardene': ('bastard',),
'bastarder': ('bastard',),
'bastardart': ('bastardart',),
'bastardarta': ('bastardart',),
'bastardarten': ('bastardart',),
'bastardartene': ('bastardart',),
'bastardarter': ('bastardart',),
'bastardisering': ('bastardisering',),
'bastardiseringa': ('bastardisering',),
'bastardiseringen': ('bastardisering',),
'bastardiseringene': ('bastardisering',),
'bastardiseringer': ('bastardisering',),
'bastardplanta': ('bastardplante',),
'bastardplante': ('bastardplante',),
'bastardplanten': ('bastardplante',),
'bastardplantene': ('bastardplante',),
'bastardplanter': ('bastardplante',),
'bastion': ('bastion',),
'bastionen': ('bastion',),
'bastionene': ('bastion',),
'bastioner': ('bastion',),
'bastmatta': ('bastmatte',),
'bastmatte': ('bastmatte',),
'bastmatten': ('bastmatte',),
'bastmattene': ('bastmatte',),
'bastmatter': ('bastmatte',),
'bastsilke': ('bastsilke',),
'bastsilken': ('bastsilke',),
'bastsilkene': ('bastsilke',),
'bastsilker': ('bastsilke',),
'bastskjørt': ('bastskjørt',),
'bastskjørta': ('bastskjørt',),
'bastskjørtene': ('bastskjørt',),
'bastskjørter': ('bastskjørt',),
'bastskjørtet': ('bastskjørt',),
'basttau': ('basttau',),
'basttaua': ('basttau',),
'basttauene': ('basttau',),
'basttauet': ('basttau',),
'basun': ('basun',),
'basunen': ('basun',),
'basunene': ('basun',),
'basuner': ('basun',),
'basunengel': ('basunengel',),
'basunengelen': ('basunengel',),
'basunenglene': ('basunengel',),
'basunengler': ('basunengel',),
'basunist': ('basunist',),
'basunisten': ('basunist',),
'basunistene': ('basunist',),
'basunister': ('basunist',),
'basunrøst': ('basunrøst',),
'basunrøsta': ('basunrøst',),
'basunrøsten': ('basunrøst',),
'basunrøstene': ('basunrøst',),
'basunrøster': ('basunrøst',),
'batalje': ('batalje',),
'bataljen': ('batalje',),
'bataljene': ('batalje',),
'bataljer': ('batalje',),
'bataljon': ('bataljon',),
'bataljonen': ('bataljon',),
'bataljonene': ('bataljon',),
'bataljoner': ('bataljon',),
'bataljonssjef': ('bataljonssjef',),
'bataljonssjefen': ('bataljonssjef',),
'bataljonssjefene': ('bataljonssjef',),
'bataljonssjefer': ('bataljonssjef',),
'batate': ('batate',),
'bataten': ('batate',),
'batatene': ('batate',),
'batater': ('batate',),
'batateplanta': ('batateplante',),
'batateplante': ('batateplante',),
'batateplanten': ('batateplante',),
'batateplantene': ('batateplante',),
'batateplanter': ('batateplante',),
'bate': ('bate',),
'baten': ('bate',),
'batene': ('bate',),
'bater': ('bate',),
'batikk': ('batikk',),
'batikken': ('batikk',),
'batikkene': ('batikk',),
'batikker': ('batikk',),
'batikktrykk': ('batikktrykk',),
'batikktrykka': ('batikktrykk',),
'batikktrykkene': ('batikktrykk',),
'batikktrykket': ('batikktrykk',),
'batist': ('batist',),
'batisten': ('batist',),
'batistene': ('batist',),
'batister': ('batist',),
'batong': ('batong',),
'batongen': ('batong',),
'batongene': ('batong',),
'batonger': ('batong',),
'batteri': ('batteri',),
'batteria': ('batteri',),
'batteriene': ('batteri',),
'batterier': ('batteri',),
'batteriet': ('batteri',),
'batteribefal': ('batteribefal',),
'batteribefala': ('batteribefal',),
'batteribefalene': ('batteribefal',),
'batteribefalet': ('batteribefal',),
'batterieliminator': ('batterieliminator',),
'batterieliminatoren': ('batterieliminator',),
'batterieliminatorene': ('batterieliminator',),
'batterieliminatorer': ('batterieliminator',),
'batterilader': ('batterilader',),
'batteriladere': ('batterilader',),
'batteriladeren': ('batterilader',),
'batteriladerer': ('batterilader',),
'batteriladerne': ('batterilader',),
'batteriradio': ('batteriradio',),
'batteriradioen': ('batteriradio',),
'batteriradioene': ('batteriradio',),
'batteriradioer': ('batteriradio',),
'batterist': ('batterist',),
'batteristen': ('batterist',),
'batteristene': ('batterist',),
'batterister': ('batterist',),
'battledress': ('battledress',),
'battledressen': ('battledress',),
'battledressene': ('battledress',),
'battledresser': ('battledress',),
'baufil': ('baufil',),
'baufila': ('baufil',),
'baufilen': ('baufil',),
'baufilene': ('baufil',),
'baufiler': ('baufil',),
'baug': ('baug',),
'baugen': ('baug',),
'baugene': ('baug',),
'bauger': ('baug',),
'bauganker': ('bauganker',),
'baugankera': ('bauganker',),
'baugankere': ('bauganker',),
'baugankeret': ('bauganker',),
'baugankra': ('bauganker',),
'baugankre': ('bauganker',),
'baugankrene': ('bauganker',),
'baugankret': ('bauganker',),
'baugspryd': ('baugspryd',),
'baugspryda': ('baugspryd',),
'baugsprydene': ('baugspryd',),
'baugsprydet': ('baugspryd',),
'bauksitt': ('bauksitt',),
'bauksitten': ('bauksitt',),
'bauksittene': ('bauksitt',),
'bauksitter': ('bauksitt',),
'baumé': ('baumé',),
'baumégrad': ('baumégrad',),
'baumégraden': ('baumégrad',),
'baumégradene': ('baumégrad',),
'baumégrader': ('baumégrad',),
'bauméskala': ('bauméskala',),
'bauméskalaen': ('bauméskala',),
'bauméskalaene': ('bauméskala',),
'bauméskalaer': ('bauméskala',),
'baun': ('baun',),
'baunen': ('baun',),
'baunene': ('baun',),
'bauner': ('baun',),
'baunbluss': ('baunbluss',),
'baunblussa': ('baunbluss',),
'baunblussene': ('baunbluss',),
'baunblusset': ('baunbluss',),
'baut': ('baut',),
'bauten': ('baut',),
'bautene': ('baut',),
'bauter': ('baut',),
'bauta': ('bauta',),
'bautaen': ('bauta',),
'bautaene': ('bauta',),
'bautaer': ('bauta',),
'bautastein': ('bautastein',),
'bautasteinen': ('bautastein',),
'bautasteinene': ('bautastein',),
'bautasteiner': ('bautastein',),
'bauxitt': ('bauxitt',),
'bauxitten': ('bauxitt',),
'bauxittene': ('bauxitt',),
'bauxitter': ('bauxitt',),
'bavian': ('bavian',),
'bavianen': ('bavian',),
'bavianene': ('bavian',),
'bavianer': ('bavian',),
'baviansvakt': ('baviansvakt',),
'baviansvakta': ('baviansvakt',),
'baviansvakten': ('baviansvakt',),
'baviansvaktene': ('baviansvakt',),
'baviansvakter': ('baviansvakt',),
'bayer': ('bayer',),
'bayere': ('bayer',),
'bayeren': ('bayer',),
'bayerer': ('bayer',),
'bayerne': ('bayer',),
'bayerøl': ('bayerøl',),
'bayerøla': ('bayerøl',),
'bayerølet': ('bayerøl',),
'bayonneskinka': ('bayonneskinke',),
'bayonneskinke': ('bayonneskinke',),
'bayonneskinken': ('bayonneskinke',),
'bayonneskinkene': ('bayonneskinke',),
'bayonneskinker': ('bayonneskinke',),
'bayrer': ('bayrer',),
'bayrere': ('bayrer',),
'bayreren': ('bayrer',),
'bayrerer': ('bayrer',),
'bayrerne': ('bayrer',),
'bazooka': ('bazooka',),
'bazookaen': ('bazooka',),
'bazookaene': ('bazooka',),
'bazookaer': ('bazooka',),
'be-bop': ('be-bop',),
'be-bopen': ('be-bop',),
'be-bopene': ('be-bop',),
'be-boper': ('be-bop',),
'bearbeidelse': ('bearbeidelse',),
'bearbeidelsen': ('bearbeidelse',),
'bearbeidelsene': ('bearbeidelse',),
'bearbeidelser': ('bearbeidelse',),
'bearbeiding': ('bearbeiding',),
'bearbeidinga': ('bearbeiding',),
'bearbeidingen': ('bearbeiding',),
'bearbeidingene': ('bearbeiding',),
'bearbeidinger': ('bearbeiding',),
'bearnés': ('bearnés',),
'bearnésen': ('bearnés',),
'bearnésene': ('bearnés',),
'bearnéser': ('bearnés',),
'bearnéssaus': ('bearnéssaus',),
'bearnéssausen': ('bearnéssaus',),
'bearnéssausene': ('bearnéssaus',),
'bearnéssauser': ('bearnéssaus',),
'beat': ('beat',),
'beaten': ('beat',),
'beatene': ('beat',),
'beater': ('beat',),
'beatmusikk': ('beatmusikk',),
'beatmusikken': ('beatmusikk',),
'beatmusikkene': ('beatmusikk',),
'beatmusikker': ('beatmusikk',),
'beatnik': ('beatnik',),
'beatniken': ('beatnik',),
'beatnikene': ('beatnik',),
'beatniker': ('beatnik',),
'beaufortskala': ('beaufortskala',),
'beaufortskalaen': ('beaufortskala',),
'beaufortskalaene': ('beaufortskala',),
'beaufortskalaer': ('beaufortskala',),
'beboelseshus': ('beboelseshus',),
'beboelseshusa': ('beboelseshus',),
'beboelseshusene': ('beboelseshus',),
'beboelseshuset': ('beboelseshus',),
'beboer': ('beboer',),
'beboere': ('beboer',),
'beboeren': ('beboer',),
'beboerer': ('beboer',),
'beboerne': ('beboer',),
'bebreidelse': ('bebreidelse',),
'bebreidelsen': ('bebreidelse',),
'bebreidelsene': ('bebreidelse',),
'bebreidelser': ('bebreidelse',),
'bebudelse': ('bebudelse',),
'bebudelsen': ('bebudelse',),
'bebudelsene': ('bebudelse',),
'bebudelser': ('bebudelse',),
'bebudelsesdag': ('bebudelsesdag',),
'bebudelsesdagen': ('bebudelsesdag',),
'bebudelsesdagene': ('bebudelsesdag',),
'bebudelsesdager': ('bebudelsesdag',),
'bebyggelse': ('bebyggelse',),
'bebyggelsen': ('bebyggelse',),
'bebyggelsene': ('bebyggelse',),
'bebyggelser': ('bebyggelse',),
'becquerel': ('becquerel',),
'becquerelen': ('becquerel',),
'becquerelene': ('becquerel',),
'bed': ('bed',),
'beda': ('bed',),
'bedene': ('bed',),
'bedet': ('bed',),
'bedding': ('bedding',),
'beddingen': ('bedding',),
'beddingene': ('bedding',),
'beddinger': ('bedding',),
'bededag': ('bededag',),
'bededagen': ('bededag',),
'bededagene': ('bededag',),
'bededager': ('bededag',),
'bedehus': ('bedehus',),
'bedehusa': ('bedehus',),
'bedehusene': ('bedehus',),
'bedehuset': ('bedehus',),
'bedehuskristendom': ('bedehuskristendom',),
'bedehuskristendommen': ('bedehuskristendom',),
'bedehuskristendommene': ('bedehuskristendom',),
'bedehuskristendommer': ('bedehuskristendom',),
'bedekker': ('bedekker',),
'bedekkere': ('bedekker',),
'bedekkeren': ('bedekker',),
'bedekkerer': ('bedekker',),
'bedekkerne': ('bedekker',),
'bedekking': ('bedekking',),
'bedekkinga': ('bedekking',),
'bedekkingen': ('bedekking',),
'bedekkingene': ('bedekking',),
'bedekkinger': ('bedekking',),
'bedekning': ('bedekning',),
'bedekninga': ('bedekning',),
'bedekningen': ('bedekning',),
'bedekningene': ('bedekning',),
'bedekninger': ('bedekning',),
'bedemann': ('bedemann',),
'bedemannen': ('bedemann',),
'bedemenn': ('bedemann',),
'bedemennene': ('bedemann',),
'bedeskammel': ('bedeskammel',),
'bedeskammelen': ('bedeskammel',),
'bedeskammlene': ('bedeskammel',),
'bedeskammler': ('bedeskammel',),
'bedeteppa': ('bedeteppe',),
'bedeteppe': ('bedeteppe',),
'bedeteppene': ('bedeteppe',),
'bedetepper': ('bedeteppe',),
'bedeteppet': ('bedeteppe',),
'bedrag': ('bedrag',),
'bedraga': ('bedrag',),
'bedragene': ('bedrag',),
'bedraget': ('bedrag',),
'bedrager': ('bedrager',),
'bedragere': ('bedrager',),
'bedrageren': ('bedrager',),
'bedragerer': ('bedrager',),
'bedragerne': ('bedrager',),
'bedrageri': ('bedrageri',),
'bedrageria': ('bedrageri',),
'bedrageriene': ('bedrageri',),
'bedragerier': ('bedrageri',),
'bedrageriet': ('bedrageri',),
'bedreviten': ('bedreviten',),
'bedrevitenen': ('bedreviten',),
'bedrevitenene': ('bedreviten',),
'bedrevitener': ('bedreviten',),
'bedreviter': ('bedreviter',),
'bedrevitere': ('bedreviter',),
'bedreviteren': ('bedreviter',),
'bedreviterer': ('bedreviter',),
'bedreviterne': ('bedreviter',),
'bedrift': ('bedrift',),
'bedriften': ('bedrift',),
'bedriftene': ('bedrift',),
'bedrifter': ('bedrift',),
'bedriftsdemokrati': ('bedriftsdemokrati',),
'bedriftsdemokratia': ('bedriftsdemokrati',),
'bedriftsdemokratiene': ('bedriftsdemokrati',),
'bedriftsdemokratier': ('bedriftsdemokrati',),
'bedriftsdemokratiet': ('bedriftsdemokrati',),
'bedriftsforsamling': ('bedriftsforsamling',),
'bedriftsforsamlinga': ('bedriftsforsamling',),
'bedriftsforsamlingen': ('bedriftsforsamling',),
'bedriftsforsamlingene': ('bedriftsforsamling',),
'bedriftsforsamlinger': ('bedriftsforsamling',),
'bedriftsidrett': ('bedriftsidrett',),
'bedriftsidretten': ('bedriftsidrett',),
'bedriftsidrettene': ('bedriftsidrett',),
'bedriftsidretter': ('bedriftsidrett',),
'bedriftsklubb': ('bedriftsklubb',),
'bedriftsklubben': ('bedriftsklubb',),
'bedriftsklubbene': ('bedriftsklubb',),
'bedriftsklubber': ('bedriftsklubb',),
'bedriftsledelse': ('bedriftsledelse',),
'bedriftsledelsen': ('bedriftsledelse',),
'bedriftsledelsene': ('bedriftsledelse',),
'bedriftsledelser': ('bedriftsledelse',),
'bedriftslege': ('bedriftslege',),
'bedriftslegen': ('bedriftslege',),
'bedriftslegene': ('bedriftslege',),
'bedriftsleger': ('bedriftslege',),
'bedriftsutvalg': ('bedriftsutvalg',),
'bedriftsutvalga': ('bedriftsutvalg',),
'bedriftsutvalgene': ('bedriftsutvalg',),
'bedriftsutvalget': ('bedriftsutvalg',),
'bedriftsøkonom': ('bedriftsøkonom',),
'bedriftsøkonomen': ('bedriftsøkonom',),
'bedriftsøkonomene': ('bedriftsøkonom',),
'bedriftsøkonomer': ('bedriftsøkonom',),
'bedriftsøkonomi': ('bedriftsøkonomi',),
'bedriftsøkonomien': ('bedriftsøkonomi',),
'bedriftsøkonomiene': ('bedriftsøkonomi',),
'bedriftsøkonomier': ('bedriftsøkonomi',),
'bedring': ('bedring',),
'bedringa': ('bedring',),
'bedringen': ('bedring',),
'bedringene': ('bedring',),
'bedringer': ('bedring',),
'bedrøvelse': ('bedrøvelse',),
'bedrøvelsen': ('bedrøvelse',),
'bedrøvelsene': ('bedrøvelse',),
'bedrøvelser': ('bedrøvelse',),
'beduin': ('beduin',),
'beduinen': ('beduin',),
'beduinene': ('beduin',),
'beduiner': ('beduin',),
'bedårer': ('bedårer',),
'bedårere': ('bedårer',),
'bedåreren': ('bedårer',),
'bedårerer': ('bedårer',),
'bedårerne': ('bedårer',),
'bedømmelse': ('bedømmelse',),
'bedømmelsen': ('bedømmelse',),
'bedømmelsene': ('bedømmelse',),
'bedømmelser': ('bedømmelse',),
'bedøvelse': ('bedøvelse',),
'bedøvelsen': ('bedøvelse',),
'bedøvelsene': ('bedøvelse',),
'bedøvelser': ('bedøvelse',),
'bedøvelsesmiddel': ('bedøvelsesmiddel',),
'bedøvelsesmiddelet': ('bedøvelsesmiddel',),
'bedøvelsesmidla': ('bedøvelsesmiddel',),
'bedøvelsesmidlene': ('bedøvelsesmiddel',),
'bedøvelsesmidler': ('bedøvelsesmiddel',),
'bedøvelsesmidlet': ('bedøvelsesmiddel',),
'bedøvelsestilstand': ('bedøvelsestilstand',),
'bedøvelsestilstanden': ('bedøvelsestilstand',),
'bedøvelsestilstandene': ('bedøvelsestilstand',),
'bedøvelsestilstander': ('bedøvelsestilstand',),
'befal': ('befal',),
'befala': ('befal',),
'befalene': ('befal',),
'befalet': ('befal',),
'befalhavende': ('befalhavende',),
'befalhavenden': ('befalhavende',),
'befalhavendene': ('befalhavende',),
'befalhavender': ('befalhavende',),
'befaling': ('befaling',),
'befalinga': ('befaling',),
'befalingen': ('befaling',),
'befalingene': ('befaling',),
'befalinger': ('befaling',),
'befalingsmann': ('befalingsmann',),
'befalingsmannen': ('befalingsmann',),
'befalingsmenn': ('befalingsmann',),
'befalingsmennene': ('befalingsmann',),
'befalselev': ('befalselev',),
'befalseleven': ('befalselev',),
'befalselevene': ('befalselev',),
'befalselever': ('befalselev',),
'befalsgrad': ('befalsgrad',),
'befalsgraden': ('befalsgrad',),
'befalsgradene': ('befalsgrad',),
'befalsgrader': ('befalsgrad',),
'befalsskole': ('befalsskole',),
'befalsskolen': ('befalsskole',),
'befalsskolene': ('befalsskole',),
'befalsskoler': ('befalsskole',),
'befaring': ('befaring',),
'befaringa': ('befaring',),
'befaringen': ('befaring',),
'befaringene': ('befaring',),
'befaringer': ('befaring',),
'befatning': ('befatning',),
'befatninga': ('befatning',),
'befatningen': ('befatning',),
'befatningene': ('befatning',),
'befatninger': ('befatning',),
'befestningskunst': ('befestningskunst',),
'befestningskunsten': ('befestningskunst',),
'befestningskunstene': ('befestningskunst',),
'befestningskunster': ('befestningskunst',),
'befinnende': ('befinnende',),
'befippelse': ('befippelse',),
'befippelsen': ('befippelse',),
'befippelsene': ('befippelse',),
'befippelser': ('befippelse',),
'befolkning': ('befolkning',),
'befolkninga': ('befolkning',),
'befolkningen': ('befolkning',),
'befolkningene': ('befolkning',),
'befolkninger': ('befolkning',),
'befolkningseksplosjon': ('befolkningseksplosjon',),
'befolkningseksplosjonen': ('befolkningseksplosjon',),
'befolkningseksplosjonene': ('befolkningseksplosjon',),
'befolkningseksplosjoner': ('befolkningseksplosjon',),
'befolkningsgruppa': ('befolkningsgruppe',),
'befolkningsgruppe': ('befolkningsgruppe',),
'befolkningsgruppen': ('befolkningsgruppe',),
'befolkningsgruppene': ('befolkningsgruppe',),
'befolkningsgrupper': ('befolkningsgruppe',),
'befolkningskontroll': ('befolkningskontroll',),
'befolkningskontrollen': ('befolkningskontroll',),
'befolkningskontrollene': ('befolkningskontroll',),
'befolkningskontroller': ('befolkningskontroll',),
'befolkningspolitikk': ('befolkningspolitikk',),
'befolkningspolitikken': ('befolkningspolitikk',),
'befolkningspolitikkene': ('befolkningspolitikk',),
'befolkningspolitikker': ('befolkningspolitikk',),
'befolkningstetthet': ('befolkningstetthet',),
'befolkningstettheta': ('befolkningstetthet',),
'befolkningstettheten': ('befolkningstetthet',),
'befolkningstetthetene': ('befolkningstetthet',),
'befolkningstettheter': ('befolkningstetthet',),
'befolkningstilvekst': ('befolkningstilvekst',),
'befolkningstilveksten': ('befolkningstilvekst',),
'befolkningstilvekstene': ('befolkningstilvekst',),
'befolkningstilvekster': ('befolkningstilvekst',),
'befordring': ('befordring',),
'befordringa': ('befordring',),
'befordringen': ('befordring',),
'befordringene': ('befordring',),
'befordringer': ('befordring',),
'befordringsmiddel': ('befordringsmiddel',),
'befordringsmiddelet': ('befordringsmiddel',),
'befordringsmidla': ('befordringsmiddel',),
'befordringsmidlene': ('befordringsmiddel',),
'befordringsmidler': ('befordringsmiddel',),
'befordringsmidlet': ('befordringsmiddel',),
'befordringsmåte': ('befordringsmåte',),
'befordringsmåten': ('befordringsmåte',),
'befordringsmåtene': ('befordringsmåte',),
'befordringsmåter': ('befordringsmåte',),
'befrakter': ('befrakter',),
'befraktere': ('befrakter',),
'befrakteren': ('befrakter',),
'befrakterer': ('befrakter',),
'befrakterne': ('befrakter',),
'befraktning': ('befraktning',),
'befraktninga': ('befraktning',),
'befraktningen': ('befraktning',),
'befraktningene': ('befraktning',),
'befraktninger': ('befraktning',),
'befrielse': ('befrielse',),
'befrielsen': ('befrielse',),
'befrielsene': ('befrielse',),
'befrielser': ('befrielse',),
'befrielseskamp': ('befrielseskamp',),
'befrielseskampen': ('befrielseskamp',),
'befrielseskampene': ('befrielseskamp',),
'befrielseskamper': ('befrielseskamp',),
'befrielseskrig': ('befrielseskrig',),
'befrielseskrigen': ('befrielseskrig',),
'befrielseskrigene': ('befrielseskrig',),
'befrielseskriger': ('befrielseskrig',),
'befrier': ('befrier',),
'befriere': ('befrier',),
'befrieren': ('befrier',),
'befrierer': ('befrier',),
'befrierne': ('befrier',),
'befruktning': ('befruktning',),
'befruktninga': ('befruktning',),
'befruktningen': ('befruktning',),
'befruktningene': ('befruktning',),
'befruktninger': ('befruktning',),
'befruktningsevna': ('befruktningsevne',),
'befruktningsevne': ('befruktningsevne',),
'befruktningsevnen': ('befruktningsevne',),
'befruktningsevnene': ('befruktningsevne',),
'befruktningsevner': ('befruktningsevne',),
'befruktningsorgan': ('befruktningsorgan',),
'befruktningsorgana': ('befruktningsorgan',),
'befruktningsorganene': ('befruktningsorgan',),
'befruktningsorganer': ('befruktningsorgan',),
'befruktningsorganet': ('befruktningsorgan',),
'begavelse': ('begavelse',),
'begavelsen': ('begavelse',),
'begavelsene': ('begavelse',),
'begavelser': ('begavelse',),
'begeistring': ('begeistring',),
'begeistringa': ('begeistring',),
'begeistringen': ('begeistring',),
'begeistringene': ('begeistring',),
'begeistringer': ('begeistring',),
'begeistringsbølga': ('begeistringsbølge',),
'begeistringsbølge': ('begeistringsbølge',),
'begeistringsbølgen': ('begeistringsbølge',),
'begeistringsbølgene': ('begeistringsbølge',),
'begeistringsbølger': ('begeistringsbølge',),
'begeistringsbølgja': ('begeistringsbølgje',),
'begeistringsbølgje': ('begeistringsbølgje',),
'begeistringsbølgjen': ('begeistringsbølgje',),
'begeistringsbølgjene': ('begeistringsbølgje',),
'begeistringsbølgjer': ('begeistringsbølgje',),
'begeistringsrus': ('begeistringsrus',),
'begeistringsrusa': ('begeistringsrus',),
'begeistringsrusen': ('begeistringsrus',),
'begeistringsrusene': ('begeistringsrus',),
'begeistringsruser': ('begeistringsrus',),
'begeistringsruset': ('begeistringsrus',),
'beger': ('beger',),
'begeret': ('beger',),
'begra': ('beger',),
'begre': ('beger',),
'begrene': ('beger',),
'begerblad': ('begerblad',),
'begerblada': ('begerblad',),
'begerbladene': ('begerblad',),
'begerblader': ('begerblad',),
'begerbladet': ('begerblad',),
'begerglas': ('begerglas',),
'begerglasa': ('begerglas',),
'begerglasene': ('begerglas',),
'begerglaset': ('begerglas',),
'begerglass': ('begerglass',),
'begerglassa': ('begerglass',),
'begerglassene': ('begerglass',),
'begerglasset': ('begerglass',),
'begersvinger': ('begersvinger',),
'begersvingere': ('begersvinger',),
'begersvingeren': ('begersvinger',),
'begersvingerer': ('begersvinger',),
'begersvingerne': ('begersvinger',),
'begivenhet': ('begivenhet',),
'begivenheta': ('begivenhet',),
'begivenheten': ('begivenhet',),
'begivenhetene': ('begivenhet',),
'begivenheter': ('begivenhet',),
'begjær': ('begjær',),
'begjæra': ('begjær',),
'begjærene': ('begjær',),
'begjæret': ('begjær',),
'begjæring': ('begjæring',),
'begjæringa': ('begjæring',),
'begjæringen': ('begjæring',),
'begjæringene': ('begjæring',),
'begjæringer': ('begjæring',),
'begonia': ('begonia',),
'begoniaen': ('begonia',),
'begoniaene': ('begonia',),
'begoniaer': ('begonia',),
'begoniene': ('begonia',),
'begonier': ('begonia',),
'begravelse': ('begravelse',),
'begravelsen': ('begravelse',),
'begravelsene': ('begravelse',),
'begravelser': ('begravelse',),
'begravelsesbyrå': ('begravelsesbyrå',),
'begravelsesbyråa': ('begravelsesbyrå',),
'begravelsesbyråene': ('begravelsesbyrå',),
'begravelsesbyråer': ('begravelsesbyrå',),
'begravelsesbyrået': ('begravelsesbyrå',),
'begrensning': ('begrensning',),
'begrensninga': ('begrensning',),
'begrensningen': ('begrensning',),
'begrensningene': ('begrensning',),
'begrensninger': ('begrensning',),
'begrep': ('begrep',),
'begrepa': ('begrep',),
'begrepene': ('begrep',),
'begreper': ('begrep',),
'begrepet': ('begrep',),
'begrepsapparat': ('begrepsapparat',),
'begrepsapparata': ('begrepsapparat',),
'begrepsapparatene': ('begrepsapparat',),
'begrepsapparater': ('begrepsapparat',),
'begrepsapparatet': ('begrepsapparat',),
'begrepsforveksling': ('begrepsforveksling',),
'begrepsforvekslinga': ('begrepsforveksling',),
'begrepsforvekslingen': ('begrepsforveksling',),
'begrepsforvekslingene': ('begrepsforveksling',),
'begrepsforvekslinger': ('begrepsforveksling',),
'begrepsforvirring': ('begrepsforvirring',),
'begrepsforvirringa': ('begrepsforvirring',),
'begrepsforvirringen': ('begrepsforvirring',),
'begrepsforvirringene': ('begrepsforvirring',),
'begrepsforvirringer': ('begrepsforvirring',),
'begrepsinnhold': ('begrepsinnhold',),
'begrepsinnholda': ('begrepsinnhold',),
'begrepsinnholdene': ('begrepsinnhold',),
'begrepsinnholdet': ('begrepsinnhold',),
'begrepsnyanse': ('begrepsnyanse',),
'begrepsnyansen': ('begrepsnyanse',),
'begrepsnyansene': ('begrepsnyanse',),
'begrepsnyanser': ('begrepsnyanse',),
'begrepsomfang': ('begrepsomfang',),
'begrepsomfanga': ('begrepsomfang',),
'begrepsomfangene': ('begrepsomfang',),
'begrepsomfanget': ('begrepsomfang',),
'begroning': ('begroning',),
'begroninga': ('begroning',),
'begroningen': ('begroning',),
'begroningene': ('begroning',),
'begroninger': ('begroning',),
'begrunnelse': ('begrunnelse',),
'begrunnelsen': ('begrunnelse',),
'begrunnelsene': ('begrunnelse',),
'begrunnelser': ('begrunnelse',),
'beguine': ('beguine',),
'beguinen': ('beguine',),
'beguinene': ('beguine',),
'beguiner': ('beguine',),
'begynnelse': ('begynnelse',),
'begynnelsen': ('begynnelse',),
'begynnelsene': ('begynnelse',),
'begynnelser': ('begynnelse',),
'begynnelsesgrunnene': ('begynnelsesgrunner',),
'begynnelsesgrunner': ('begynnelsesgrunner',),
'begynnelseshastighet': ('begynnelseshastighet',),
'begynnelseshastigheta': ('begynnelseshastighet',),
'begynnelseshastigheten': ('begynnelseshastighet',),
'begynnelseshastighetene': ('begynnelseshastighet',),
'begynnelseshastigheter': ('begynnelseshastighet',),
'begynnelsesstadia': ('begynnelsesstadium',),
'begynnelsesstadiene': ('begynnelsesstadium',),
'begynnelsesstadier': ('begynnelsesstadium',),
'begynnelsesstadiet': ('begynnelsesstadium',),
'begynnelsesstadium': ('begynnelsesstadium',),
'begynner': ('begynner',),
'begynnere': ('begynner',),
'begynneren': ('begynner',),
'begynnerer': ('begynner',),
'begynnerne': ('begynner',),
'begynnerfeil': ('begynnerfeil',),
'begynnerfeilen': ('begynnerfeil',),
'begynnerfeilene': ('begynnerfeil',),
'begynnergasje': ('begynnergasje',),
'begynnergasjen': ('begynnergasje',),
'begynnergasjene': ('begynnergasje',),
'begynnergasjer': ('begynnergasje',),
'begynnerklassa': ('begynnerklasse',),
'begynnerklasse': ('begynnerklasse',),
'begynnerklassen': ('begynnerklasse',),
'begynnerklassene': ('begynnerklasse',),
'begynnerklasser': ('begynnerklasse',),
'begynnerlønn': ('begynnerlønn',),
'begynnerlønna': ('begynnerlønn',),
'begynnerlønnen': ('begynnerlønn',),
'begynnerlønnene': ('begynnerlønn',),
'begynnerlønner': ('begynnerlønn',),
'begynnerstadia': ('begynnerstadium',),
'begynnerstadiene': ('begynnerstadium',),
'begynnerstadier': ('begynnerstadium',),
'begynnerstadiet': ('begynnerstadium',),
'begynnerstadium': ('begynnerstadium',),
'begynnervanske': ('begynnervanske',),
'begynnervansken': ('begynnervanske',),
'begynnervanskene': ('begynnervanske',),
'begynnervansker': ('begynnervanske',),
'begynnervanskelighet': ('begynnervanskelighet',),
'begynnervanskeligheta': ('begynnervanskelighet',),
'begynnervanskeligheten': ('begynnervanskelighet',),
'begynnervanskelighetene': ('begynnervanskelighet',),
'begynnervanskeligheter': ('begynnervanskelighet',),
'behag': ('behag',),
'behaga': ('behag',),
'behagene': ('behag',),
'behaget': ('behag',),
'behandler': ('behandler',),
'behandlere': ('behandler',),
'behandleren': ('behandler',),
'behandlerer': ('behandler',),
'behandlerne': ('behandler',),
'behandling': ('behandling',),
'behandlinga': ('behandling',),
'behandlingen': ('behandling',),
'behandlingene': ('behandling',),
'behandlinger': ('behandling',),
'behandlingsheim': ('behandlingsheim',),
'behandlingsheimen': ('behandlingsheim',),
'behandlingsheimene': ('behandlingsheim',),
'behandlingsheimer': ('behandlingsheim',),
'behandlingshjem': ('behandlingshjem',),
'behandlingshjemma': ('behandlingshjem',),
'behandlingshjemmene': ('behandlingshjem',),
'behandlingshjemmet': ('behandlingshjem',),
'behandlingsmåte': ('behandlingsmåte',),
'behandlingsmåten': ('behandlingsmåte',),
'behandlingsmåtene': ('behandlingsmåte',),
'behandlingsmåter': ('behandlingsmåte',),
'behandlingstilbud': ('behandlingstilbud',),
'behandlingstilbuda': ('behandlingstilbud',),
'behandlingstilbudene': ('behandlingstilbud',),
'behandlingstilbudet': ('behandlingstilbud',),
'behaviorisme': ('behaviorisme',),
'behaviorismen': ('behaviorisme',),
'behaviorismene': ('behaviorisme',),
'behaviorismer': ('behaviorisme',),
'behaviorist': ('behaviorist',),
'behavioristen': ('behaviorist',),
'behavioristene': ('behaviorist',),
'behaviorister': ('behaviorist',),
'beheng': ('beheng',),
'behenga': ('beheng',),
'behengene': ('beheng',),
'behenget': ('beheng',),
'beherskelse': ('beherskelse',),
'beherskelsen': ('beherskelse',),
'beherskelsene': ('beherskelse',),
'beherskelser': ('beherskelse',),
'behold': ('behold',),
'beholder': ('beholder',),
'beholdere': ('beholder',),
'beholderen': ('beholder',),
'beholderer': ('beholder',),
'beholderne': ('beholder',),
'beholdning': ('beholdning',),
'beholdninga': ('beholdning',),
'beholdningen': ('beholdning',),
'beholdningene': ('beholdning',),
'beholdninger': ('beholdning',),
'behov': ('behov',),
'behova': ('behov',),
'behovene': ('behov',),
'behovet': ('behov',),
'behovsanalysa': ('behovsanalyse',),
'behovsanalyse': ('behovsanalyse',),
'behovsanalysen': ('behovsanalyse',),
'behovsanalysene': ('behovsanalyse',),
'behovsanalyser': ('behovsanalyse',),
'behovsprøving': ('behovsprøving',),
'behovsprøvinga': ('behovsprøving',),
'behovsprøvingen': ('behovsprøving',),
'behovsprøvingene': ('behovsprøving',),
'behovsprøvinger': ('behovsprøving',),
'behå': ('behå',),
'behåen': ('behå',),
'behåene': ('behå',),
'behåer': ('behå',),
'behåring': ('behåring',),
'behåringa': ('behåring',),
'behåringen': ('behåring',),
'behåringene': ('behåring',),
'behåringer': ('behåring',),
'beiler': ('beiler',),
'beilere': ('beiler',),
'beileren': ('beiler',),
'beilerer': ('beiler',),
'beilerne': ('beiler',),
'bein': ('bein',),
'beina': ('bein',),
'beinene': ('bein',),
'beinet': ('bein',),
'beinarbeid': ('beinarbeid',),
'beinarbeida': ('beinarbeid',),
'beinarbeidene': ('beinarbeid',),
'beinarbeider': ('beinarbeid',),
'beinarbeidet': ('beinarbeid',),
'beinbetennelse': ('beinbetennelse',),
'beinbetennelsen': ('beinbetennelse',),
'beinbetennelsene': ('beinbetennelse',),
'beinbetennelser': ('beinbetennelse',),
'beinbrudd': ('beinbrudd',),
'beinbrudda': ('beinbrudd',),
'beinbruddene': ('beinbrudd',),
'beinbruddet': ('beinbrudd',),
'beinbygning': ('beinbygning',),
'beinbygninga': ('beinbygning',),
'beinbygningen': ('beinbygning',),
'beinbygningene': ('beinbygning',),
'beinbygninger': ('beinbygning',),
'beinfisk': ('beinfisk',),
'beinfisken': ('beinfisk',),
'beinfiskene': ('beinfisk',),
'beinfisker': ('beinfisk',),
'beingrind': ('beingrind',),
'beingrinda': ('beingrind',),
'beingrinden': ('beingrind',),
'beingrindene': ('beingrind',),
'beingrinder': ('beingrind',),
'beinklær': ('beinklær',),
'beinklærne': ('beinklær',),
'beinkrok': ('beinkrok',),
'beinkroken': ('beinkrok',),
'beinkrokene': ('beinkrok',),
'beinkroker': ('beinkrok',),
'beinlim': ('beinlim',),
'beinlima': ('beinlim',),
'beinlimene': ('beinlim',),
'beinlimet': ('beinlim',),
'beinmarg': ('beinmarg',),
'beinmargen': ('beinmarg',),
'beinmargene': ('beinmarg',),
'beinmarger': ('beinmarg',),
'beinmarg': ('beinmarg',),
'beinmargen': ('beinmarg',),
'beinmargene': ('beinmarg',),
'beinmarger': ('beinmarg',),
'beinmarg': ('beinmarg',),
'beinmargen': ('beinmarg',),
'beinmargene': ('beinmarg',),
'beinmarger': ('beinmarg',),
'beinmel': ('beinmel',),
'beinmela': ('beinmel',),
'beinmelene': ('beinmel',),
'beinmelet': ('beinmel',),
'beinmerg': ('beinmerg',),
'beinmergen': ('beinmerg',),
'beinmergene': ('beinmerg',),
'beinmerger': ('beinmerg',),
'beinmerg': ('beinmerg',),
'beinmergen': ('beinmerg',),
'beinmergene': ('beinmerg',),
'beinmerger': ('beinmerg',),
'beinmerg': ('beinmerg',),
'beinmergen': ('beinmerg',),
'beinmergene': ('beinmerg',),
'beinmerger': ('beinmerg',),
'beinmjøl': ('beinmjøl',),
'beinmjøla': ('beinmjøl',),
'beinmjølene': ('beinmjøl',),
'beinmjølet': ('beinmjøl',),
'beinpipa': ('beinpipe',),
'beinpipe': ('beinpipe',),
'beinpipen': ('beinpipe',),
'beinpipene': ('beinpipe',),
'beinpiper': ('beinpipe',),
'beinrangel': ('beinrangel',),
'beinrangelet': ('beinrangel',),
'beinrangla': ('beinrangel',),
'beinranglene': ('beinrangel',),
'beinrangler': ('beinrangel',),
'beinranglet': ('beinrangel',),
'beinskurd': ('beinskurd',),
'beinskurden': ('beinskurd',),
'beinskurdene': ('beinskurd',),
'beinskurder': ('beinskurd',),
'beinsplint': ('beinsplint',),
'beinsplinten': ('beinsplint',),
'beinsplintene': ('beinsplint',),
'beinsplinter': ('beinsplint',),
'beinsubstans': ('beinsubstans',),
'beinsubstansen': ('beinsubstans',),
'beinsubstansene': ('beinsubstans',),
'beinsubstanser': ('beinsubstans',),
'beinved': ('beinved',),
'beinveden': ('beinved',),
'beinvedene': ('beinved',),
'beinveder': ('beinved',),
'beinveg': ('beinveg',),
'beinvegen': ('beinveg',),
'beinvegene': ('beinveg',),
'beinveger': ('beinveg',),
'beinvei': ('beinvei',),
'beinveien': ('beinvei',),
'beinveiene': ('beinvei',),
'beinveier': ('beinvei',),
'beinvev': ('beinvev',),
'beinveva': ('beinvev',),
'beinvevene': ('beinvev',),
'beinvevet': ('beinvev',),
'beis': ('beis',),
'beisen': ('beis',),
'beisene': ('beis',),
'beiser': ('beis',),
'beist': ('beist',),
'beista': ('beist',),
'beistene': ('beist',),
'beistet': ('beist',),
'beit': ('beit',),
'beita': ('beit',),
'beiten': ('beit',),
'beitene': ('beit',),
'beiter': ('beit',),
'beit': ('beit',),
'beita': ('beit',),
'beiten': ('beit',),
'beitene': ('beit',),
'beiter': ('beit',),
'beita': ('beite',),
'beite': ('beite',),
'beitene': ('beite',),
'beiter': ('beite',),
'beitet': ('beite',),
'beita': ('beite',),
'beite': ('beite',),
'beiten': ('beite',),
'beitene': ('beite',),
'beiter': ('beite',),
'beitebruk': ('beitebruk',),
'beitebruka': ('beitebruk',),
'beitebrukene': ('beitebruk',),
'beitebruket': ('beitebruk',),
'beitedrift': ('beitedrift',),
'beitedrifta': ('beitedrift',),
'beitedriften': ('beitedrift',),
'beitedriftene': ('beitedrift',),
'beitedrifter': ('beitedrift',),
'beitedyr': ('beitedyr',),
'beitedyra': ('beitedyr',),
'beitedyrene': ('beitedyr',),
'beitedyret': ('beitedyr',),
'beitegras': ('beitegras',),
'beitegrasa': ('beitegras',),
'beitegrasene': ('beitegras',),
'beitegraset': ('beitegras',),
'beitegress': ('beitegress',),
'beitegressa': ('beitegress',),
'beitegressene': ('beitegress',),
'beitegresset': ('beitegress',),
'beitekonsulent': ('beitekonsulent',),
'beitekonsulenten': ('beitekonsulent',),
'beitekonsulentene': ('beitekonsulent',),
'beitekonsulenter': ('beitekonsulent',),
'beitel': ('beitel',),
'beitelen': ('beitel',),
'beitlene': ('beitel',),
'beitler': ('beitel',),
'beitemakk': ('beitemakk',),
'beitemakken': ('beitemakk',),
'beitemakkene': ('beitemakk',),
'beitemakker': ('beitemakk',),
'beitemark': ('beitemark',),
'beitemarka': ('beitemark',),
'beitemarken': ('beitemark',),
'beitemarkene': ('beitemark',),
'beitemarker': ('beitemark',),
'beitemark': ('beitemark',),
'beitemarka': ('beitemark',),
'beitemarken': ('beitemark',),
'beitemarkene': ('beitemark',),
'beitemarker': ('beitemark',),
'beiteområda': ('beiteområde',),
'beiteområde': ('beiteområde',),
'beiteområdene': ('beiteområde',),
'beiteområder': ('beiteområde',),
'beiteområdet': ('beiteområde',),
'beiterett': ('beiterett',),
'beiteretten': ('beiterett',),
'beiterettene': ('beiterett',),
'beiteretter': ('beiterett',),
'beiteslepp': ('beiteslepp',),
'beitesleppa': ('beiteslepp',),
'beitesleppene': ('beiteslepp',),
'beitesleppet': ('beiteslepp',),
'beiteslipp': ('beiteslipp',),
'beiteslippa': ('beiteslipp',),
'beiteslippene': ('beiteslipp',),
'beiteslippet': ('beiteslipp',),
'bek': ('bek',),
'beka': ('bek',),
'bekene': ('bek',),
'beket': ('bek',),
'bekblende': ('bekblende',),
'bekblenden': ('bekblende',),
'bekblendene': ('bekblende',),
'bekblender': ('bekblende',),
'bekjempelse': ('bekjempelse',),
'bekjempelsen': ('bekjempelse',),
'bekjempelsene': ('bekjempelse',),
'bekjempelser': ('bekjempelse',),
'bekjemping': ('bekjemping',),
'bekjempinga': ('bekjemping',),
'bekjempingen': ('bekjemping',),
'bekjempingene': ('bekjemping',),
'bekjempinger': ('bekjemping',),
'bekjennelse': ('bekjennelse',),
'bekjennelsen': ('bekjennelse',),
'bekjennelsene': ('bekjennelse',),
'bekjennelser': ('bekjennelse',),
'bekjennelseskirka': ('bekjennelseskirke',),
'bekjennelseskirke': ('bekjennelseskirke',),
'bekjennelseskirken': ('bekjennelseskirke',),
'bekjennelseskirkene': ('bekjennelseskirke',),
'bekjennelseskirker': ('bekjennelseskirke',),
'bekjennelseskjerka': ('bekjennelseskjerke',),
'bekjennelseskjerke': ('bekjennelseskjerke',),
'bekjennelseskjerken': ('bekjennelseskjerke',),
'bekjennelseskjerkene': ('bekjennelseskjerke',),
'bekjennelseskjerker': ('bekjennelseskjerke',),
'bekjennelsesskrift': ('bekjennelsesskrift',),
'bekjennelsesskrifta': ('bekjennelsesskrift',),
'bekjennelsesskriftene': ('bekjennelsesskrift',),
'bekjennelsesskrifter': ('bekjennelsesskrift',),
'bekjennelsesskriftet': ('bekjennelsesskrift',),
'bekjentgjørelse': ('bekjentgjørelse',),
'bekjentgjørelsen': ('bekjentgjørelse',),
'bekjentgjørelsene': ('bekjentgjørelse',),
'bekjentgjørelser': ('bekjentgjørelse',),
'bekjentskap': ('bekjentskap',),
'bekjentskapa': ('bekjentskap',),
'bekjentskapene': ('bekjentskap',),
'bekjentskaper': ('bekjentskap',),
'bekjentskapet': ('bekjentskap',),
'bekjentskapskrets': ('bekjentskapskrets',),
'bekjentskapskretsen': ('bekjentskapskrets',),
'bekjentskapskretsene': ('bekjentskapskrets',),
'bekjentskapskretser': ('bekjentskapskrets',),
'bekk': ('bekk',),
'bekken': ('bekk',),
'bekkene': ('bekk',),
'bekker': ('bekk',),
'bekkasin': ('bekkasin',),
'bekkasinen': ('bekkasin',),
'bekkasinene': ('bekkasin',),
'bekkasiner': ('bekkasin',),
'bekkeblom': ('bekkeblom',),
'bekkeblommen': ('bekkeblom',),
'bekkeblommene': ('bekkeblom',),
'bekkeblommer': ('bekkeblom',),
'bekkefar': ('bekkefar',),
'bekkefara': ('bekkefar',),
'bekkefarene': ('bekkefar',),
'bekkefaret': ('bekkefar',),
'bekkekvern': ('bekkekvern',),
'bekkekverna': ('bekkekvern',),
'bekkekvernen': ('bekkekvern',),
'bekkekvernene': ('bekkekvern',),
'bekkekverner': ('bekkekvern',),
'bekken': ('bekken',),
'bekkena': ('bekken',),
'bekkenene': ('bekken',),
'bekkener': ('bekken',),
'bekkenet': ('bekken',),
'bekkenbein': ('bekkenbein',),
'bekkenbeina': ('bekkenbein',),
'bekkenbeinene': ('bekkenbein',),
'bekkenbeinet': ('bekkenbein',),
'bekkenben': ('bekkenben',),
'bekkenbena': ('bekkenben',),
'bekkenbenene': ('bekkenben',),
'bekkenbenet': ('bekkenben',),
'bekkenhola': ('bekkenhole',),
'bekkenhole': ('bekkenhole',),
'bekkenholen': ('bekkenhole',),
'bekkenholene': ('bekkenhole',),
'bekkenholer': ('bekkenhole',),
'bekkenhula': ('bekkenhule',),
'bekkenhule': ('bekkenhule',),
'bekkenhulen': ('bekkenhule',),
'bekkenhulene': ('bekkenhule',),
'bekkenhuler': ('bekkenhule',),
'bekkenløsning': ('bekkenløsning',),
'bekkenløsninga': ('bekkenløsning',),
'bekkenløsningen': ('bekkenløsning',),
'bekkenløsningene': ('bekkenløsning',),
'bekkenløsninger': ('bekkenløsning',),
'bekkenløysing': ('bekkenløysing',),
'bekkenløysinga': ('bekkenløysing',),
'bekkenløysingen': ('bekkenløysing',),
'bekkenløysingene': ('bekkenløysing',),
'bekkenløysinger': ('bekkenløysing',),
'bekkeos': ('bekkeos',),
'bekkeosa': ('bekkeos',),
'bekkeosen': ('bekkeos',),
'bekkeosene': ('bekkeos',),
'bekkeoser': ('bekkeos',),
'bekkeoset': ('bekkeos',),
'bekkesig': ('bekkesig',),
'bekkesiga': ('bekkesig',),
'bekkesigene': ('bekkesig',),
'bekkesiget': ('bekkesig',),
'bekkesilder': ('bekkesilder',),
'bekkesilderet': ('bekkesilder',),
'bekkesildra': ('bekkesilder',),
'bekkesildrene': ('bekkesilder',),
'bekkesildrer': ('bekkesilder',),
'bekkesildret': ('bekkesilder',),
'bekkesildra': ('bekkesildre',),
'bekkesildre': ('bekkesildre',),
'bekkesildren': ('bekkesildre',),
'bekkesildrene': ('bekkesildre',),
'bekkesildrer': ('bekkesildre',),
'beklagelse': ('beklagelse',),
'beklagelsen': ('beklagelse',),
'beklagelsene': ('beklagelse',),
'beklagelser': ('beklagelse',),
'bekledning': ('bekledning',),
'bekledninga': ('bekledning',),
'bekledningene': ('bekledning',),
'bekledninger': ('bekledning',),
'bekledningsgjenstand': ('bekledningsgjenstand',),
'bekledningsgjenstanden': ('bekledningsgjenstand',),
'bekledningsgjenstandene': ('bekledningsgjenstand',),
'bekledningsgjenstander': ('bekledningsgjenstand',),
'bekledningsindustri': ('bekledningsindustri',),
'bekledningsindustrien': ('bekledningsindustri',),
'bekledningsindustriene': ('bekledningsindustri',),
'bekledningsindustrier': ('bekledningsindustri',),
'beklemmelse': ('beklemmelse',),
'beklemmelsen': ('beklemmelse',),
'beklemmelsene': ('beklemmelse',),
'beklemmelser': ('beklemmelse',),
'bekmørka': ('bekmørke',),
'bekmørke': ('bekmørke',),
'bekmørkene': ('bekmørke',),
'bekmørker': ('bekmørke',),
'bekmørket': ('bekmørke',),
'beknip': ('beknip',),
'bekomst': ('bekomst',),
'bekomsten': ('bekomst',),
'bekomstene': ('bekomst',),
'bekomster': ('bekomst',),
'bekostning': ('bekostning',),
'bekostninga': ('bekostning',),
'bekostningen': ('bekostning',),
'bekostningene': ('bekostning',),
'bekostninger': ('bekostning',),
'bekransning': ('bekransning',),
'bekransninga': ('bekransning',),
'bekransningen': ('bekransning',),
'bekransningene': ('bekransning',),
'bekransninger': ('bekransning',),
'bekreftelse': ('bekreftelse',),
'bekreftelsen': ('bekreftelse',),
'bekreftelsene': ('bekreftelse',),
'bekreftelser': ('bekreftelse',),
'beksel': ('beksel',),
'bekselet': ('beksel',),
'beksla': ('beksel',),
'bekslene': ('beksel',),
'beksler': ('beksel',),
'bekslet': ('beksel',),
'bekselring': ('bekselring',),
'bekselringen': ('bekselring',),
'bekselringene': ('bekselring',),
'bekselringer': ('bekselring',),
'bekstein': ('bekstein',),
'beksteinen': ('bekstein',),
'beksteinene': ('bekstein',),
'beksteiner': ('bekstein',),
'beksøm': ('beksøm',),
'beksømmen': ('beksøm',),
'beksømmene': ('beksøm',),
'beksømmer': ('beksøm',),
'beksømsko': ('beksømsko',),
'beksømskoa': ('beksømsko',),
'beksømskoen': ('beksømsko',),
'beksømskoene': ('beksømsko',),
'beksømskor': ('beksømsko',),
'beksømskorne': ('beksømsko',),
'beksømstøvel': ('beksømstøvel',),
'beksømstøvelen': ('beksømstøvel',),
'beksømstøvlene': ('beksømstøvel',),
'beksømstøvler': ('beksømstøvel',),
'bektråd': ('bektråd',),
'bektråden': ('bektråd',),
'bektrådene': ('bektråd',),
'bektråder': ('bektråd',),
'bekvemmelighet': ('bekvemmelighet',),
'bekvemmeligheta': ('bekvemmelighet',),
'bekvemmeligheten': ('bekvemmelighet',),
'bekvemmelighetene': ('bekvemmelighet',),
'bekvemmeligheter': ('bekvemmelighet',),
'bekvemmelighetsflagg': ('bekvemmelighetsflagg',),
'bekvemmelighetsflagga': ('bekvemmelighetsflagg',),
'bekvemmelighetsflaggene': ('bekvemmelighetsflagg',),
'bekvemmelighetsflagget': ('bekvemmelighetsflagg',),
'bekvemmelighetshensyn': ('bekvemmelighetshensyn',),
'bekvemmelighetshensyna': ('bekvemmelighetshensyn',),
'bekvemmelighetshensynene': ('bekvemmelighetshensyn',),
'bekvemmelighetshensynet': ('bekvemmelighetshensyn',),
'bekymring': ('bekymring',),
'bekymringa': ('bekymring',),
'bekymringen': ('bekymring',),
'bekymringene': ('bekymring',),
'bekymringer': ('bekymring',),
'bel': ('bel',),
'belen': ('bel',),
'belene': ('bel',),
'bel canto': ('bel canto',),
'bel cantoen': ('bel canto',),
'bel cantoene': ('bel canto',),
'bel cantoer': ('bel canto',),
'belastning': ('belastning',),
'belastninga': ('belastning',),
'belastningen': ('belastning',),
'belastningene': ('belastning',),
'belastninger': ('belastning',),
'belastningsprøva': ('belastningsprøve',),
'belastningsprøve': ('belastningsprøve',),
'belastningsprøven': ('belastningsprøve',),
'belastningsprøvene': ('belastningsprøve',),
'belastningsprøver': ('belastningsprøve',),
'belastningssjukdom': ('belastningssjukdom',),
'belastningssjukdommen': ('belastningssjukdom',),
'belastningssjukdommene': ('belastningssjukdom',),
'belastningssjukdommer': ('belastningssjukdom',),
'belastningssykdom': ('belastningssykdom',),
'belastningssykdommen': ('belastningssykdom',),
'belastningssykdommene': ('belastningssykdom',),
'belastningssykdommer': ('belastningssykdom',),
'belegg': ('belegg',),
'belegga': ('belegg',),
'beleggene': ('belegg',),
'belegget': ('belegg',),
'beleggdannelse': ('beleggdannelse',),
'beleggdannelsen': ('beleggdannelse',),
'beleggdannelsene': ('beleggdannelse',),
'beleggdannelser': ('beleggdannelse',),
'beleggdanning': ('beleggdanning',),
'beleggdanninga': ('beleggdanning',),
'beleggdanningen': ('beleggdanning',),
'beleggdanningene': ('beleggdanning',),
'beleggdanninger': ('beleggdanning',),
'beleiring': ('beleiring',),
'beleiringa': ('beleiring',),
'beleiringen': ('beleiring',),
'beleiringene': ('beleiring',),
'beleiringer': ('beleiring',),
'beleiringstilstand': ('beleiringstilstand',),
'beleiringstilstanden': ('beleiringstilstand',),
'beleiringstilstandene': ('beleiringstilstand',),
'beleiringstilstander': ('beleiringstilstand',),
'belg': ('belg',),
'belgen': ('belg',),
'belgene': ('belg',),
'belger': ('belg',),
'belgetreder': ('belgetreder',),
'belgetredere': ('belgetreder',),
'belgetrederen': ('belgetreder',),
'belgetrederer': ('belgetreder',),
'belgetrederne': ('belgetreder',),
'belgfrukt': ('belgfrukt',),
'belgfrukta': ('belgfrukt',),
'belgfrukten': ('belgfrukt',),
'belgfruktene': ('belgfrukt',),
'belgfrukter': ('belgfrukt',),
'belgier': ('belgier',),
'belgiere': ('belgier',),
'belgieren': ('belgier',),
'belgierer': ('belgier',),
'belgierne': ('belgier',),
'belgkapsel': ('belgkapsel',),
'belgkapselen': ('belgkapsel',),
'belgkapslene': ('belgkapsel',),
'belgkapsler': ('belgkapsel',),
'belgmørka': ('belgmørke',),
'belgmørke': ('belgmørke',),
'belgmørkene': ('belgmørke',),
'belgmørker': ('belgmørke',),
'belgmørket': ('belgmørke',),
'belgplanta': ('belgplante',),
'belgplante': ('belgplante',),
'belgplanten': ('belgplante',),
'belgplantene': ('belgplante',),
'belgplanter': ('belgplante',),
'belgtreder': ('belgtreder',),
'belgtredere': ('belgtreder',),
'belgtrederen': ('belgtreder',),
'belgtrederer': ('belgtreder',),
'belgtrederne': ('belgtreder',),
'beliggenhet': ('beliggenhet',),
'beliggenheta': ('beliggenhet',),
'beliggenheten': ('beliggenhet',),
'beliggenhetene': ('beliggenhet',),
'beliggenheter': ('beliggenhet',),
'belizer': ('belizer',),
'belizere': ('belizer',),
'belizeren': ('belizer',),
'belizerer': ('belizer',),
'belizerne': ('belizer',),
'belj': ('belj',),
'belja': ('belj',),
'beljen': ('belj',),
'beljene': ('belj',),
'beljet': ('belj',),
'belladonna': ('belladonna',),
'belladonnaen': ('belladonna',),
'belladonnaene': ('belladonna',),
'belladonnaer': ('belladonna',),
'belladonnablad': ('belladonnablad',),
'belladonnablada': ('belladonnablad',),
'belladonnabladene': ('belladonnablad',),
'belladonnablader': ('belladonnablad',),
'belladonnabladet': ('belladonnablad',),
'belling': ('belling',),
'bellingen': ('belling',),
'bellingene': ('belling',),
'bellinger': ('belling',),
'belt': ('belt',),
'belta': ('belt',),
'beltene': ('belt',),
'belter': ('belt',),
'beltet': ('belt',),
'belta': ('belte',),
'belte': ('belte',),
'beltene': ('belte',),
'belter': ('belte',),
'beltet': ('belte',),
'beltealge': ('beltealge',),
'beltealgen': ('beltealge',),
'beltealgene': ('beltealge',),
'beltealger': ('beltealge',),
'beltebil': ('beltebil',),
'beltebilen': ('beltebil',),
'beltebilene': ('beltebil',),
'beltebiler': ('beltebil',),
'beltedyr': ('beltedyr',),
'beltedyra': ('beltedyr',),
'beltedyrene': ('beltedyr',),
'beltedyret': ('beltedyr',),
'beltehogst': ('beltehogst',),
'beltehogsten': ('beltehogst',),
'beltehogstene': ('beltehogst',),
'beltehogster': ('beltehogst',),
'beltehugst': ('beltehugst',),
'beltehugsten': ('beltehugst',),
'beltehugstene': ('beltehugst',),
'beltehugster': ('beltehugst',),
'beltested': ('beltested',),
'beltesteda': ('beltested',),
'beltestedene': ('beltested',),
'beltestedet': ('beltested',),
'beltetraktor': ('beltetraktor',),
'beltetraktoren': ('beltetraktor',),
'beltetraktorene': ('beltetraktor',),
'beltetraktorer': ('beltetraktor',),
'belysning': ('belysning',),
'belysninga': ('belysning',),
'belysningen': ('belysning',),
'belysningene': ('belysning',),
'belysninger': ('belysning',),
'belysningsstyrke': ('belysningsstyrke',),
'belysningsstyrken': ('belysningsstyrke',),
'belysningsstyrkene': ('belysningsstyrke',),
'belysningsstyrker': ('belysningsstyrke',),
'belønning': ('belønning',),
'belønninga': ('belønning',),
'belønningen': ('belønning',),
'belønningene': ('belønning',),
'belønninger': ('belønning',),
'beløp': ('beløp',),
'beløpa': ('beløp',),
'beløpene': ('beløp',),
'beløpet': ('beløp',),
'bemanning': ('bemanning',),
'bemanninga': ('bemanning',),
'bemanningen': ('bemanning',),
'bemanningene': ('bemanning',),
'bemanninger': ('bemanning',),
'bemanningsforskrift': ('bemanningsforskrift',),
'bemanningsforskrifta': ('bemanningsforskrift',),
'bemanningsforskriftene': ('bemanningsforskrift',),
'bemanningsforskrifter': ('bemanningsforskrift',),
'bemanningsforskriftet': ('bemanningsforskrift',),
'bemanningskrisa': ('bemanningskrise',),
'bemanningskrise': ('bemanningskrise',),
'bemanningskrisen': ('bemanningskrise',),
'bemanningskrisene': ('bemanningskrise',),
'bemanningskriser': ('bemanningskrise',),
'bemanningslista': ('bemanningsliste',),
'bemanningsliste': ('bemanningsliste',),
'bemanningslisten': ('bemanningsliste',),
'bemanningslistene': ('bemanningsliste',),
'bemanningslister': ('bemanningsliste',),
'bemanningssituasjon': ('bemanningssituasjon',),
'bemanningssituasjonen': ('bemanningssituasjon',),
'bemanningssituasjonene': ('bemanningssituasjon',),
'bemanningssituasjoner': ('bemanningssituasjon',),
'bemerkning': ('bemerkning',),
'bemerkninga': ('bemerkning',),
'bemerkningen': ('bemerkning',),
'bemerkningene': ('bemerkning',),
'bemerkninger': ('bemerkning',),
'bemyndigelse': ('bemyndigelse',),
'bemyndigelsen': ('bemyndigelse',),
'bemyndigelsene': ('bemyndigelse',),
'bemyndigelser': ('bemyndigelse',),
'ben': ('ben',),
'bena': ('ben',),
'benene': ('ben',),
'benet': ('ben',),
'benarbeid': ('benarbeid',),
'benarbeida': ('benarbeid',),
'benarbeidene': ('benarbeid',),
'benarbeider': ('benarbeid',),
'benarbeidet': ('benarbeid',),
'benbetennelse': ('benbetennelse',),
'benbetennelsen': ('benbetennelse',),
'benbetennelsene': ('benbetennelse',),
'benbetennelser': ('benbetennelse',),
'benbrudd': ('benbrudd',),
'benbrudda': ('benbrudd',),
'benbruddene': ('benbrudd',),
'benbruddet': ('benbrudd',),
'benbygning': ('benbygning',),
'benbygninga': ('benbygning',),
'benbygningen': ('benbygning',),
'benbygningene': ('benbygning',),
'benbygninger': ('benbygning',),
'bend': ('bend',),
'benda': ('bend',),
'bendene': ('bend',),
'bendet': ('bend',),
'bendel': ('bendel',),
'bendelen': ('bendel',),
'bendlene': ('bendel',),
'bendler': ('bendel',),
'bendelband': ('bendelband',),
'bendelbanda': ('bendelband',),
'bendelbandene': ('bendelband',),
'bendelbandet': ('bendelband',),
'bendelbånd': ('bendelbånd',),
'bendelbånda': ('bendelbånd',),
'bendelbåndene': ('bendelbånd',),
'bendelbåndet': ('bendelbånd',),
'bendelorm': ('bendelorm',),
'bendelormen': ('bendelorm',),
'bendelormene': ('bendelorm',),
'bendelormer': ('bendelorm',),
'bendsel': ('bendsel',),
'bendselet': ('bendsel',),
'bendsla': ('bendsel',),
'bendslene': ('bendsel',),
'bendsler': ('bendsel',),
'bendslet': ('bendsel',),
'benediksjon': ('benediksjon',),
'benediksjonen': ('benediksjon',),
'benediksjonene': ('benediksjon',),
'benediksjoner': ('benediksjon',),
'benediktiner': ('benediktiner',),
'benediktinere': ('benediktiner',),
'benediktineren': ('benediktiner',),
'benediktinerer': ('benediktiner',),
'benediktinerne': ('benediktiner',),
'benediktinerkloster': ('benediktinerkloster',),
'benediktinerklosteret': ('benediktinerkloster',),
'benediktinerklostra': ('benediktinerkloster',),
'benediktinerklostre': ('benediktinerkloster',),
'benediktinerklostrene': ('benediktinerkloster',),
'benediktinerklostret': ('benediktinerkloster',),
'benediktinerlikør': ('benediktinerlikør',),
'benediktinerlikøren': ('benediktinerlikør',),
'benediktinerlikørene': ('benediktinerlikør',),
'benediktinerlikører': ('benediktinerlikør',),
'benediktinermunk': ('benediktinermunk',),
'benediktinermunken': ('benediktinermunk',),
'benediktinermunkene': ('benediktinermunk',),
'benediktinermunker': ('benediktinermunk',),
'benediktinernonna': ('benediktinernonne',),
'benediktinernonne': ('benediktinernonne',),
'benediktinernonnen': ('benediktinernonne',),
'benediktinernonnene': ('benediktinernonne',),
'benediktinernonner': ('benediktinernonne',),
'benediktinerorden': ('benediktinerorden',),
'benediktinerordenen': ('benediktinerorden',),
'benediktinerordenene': ('benediktinerorden',),
'benediktinerordener': ('benediktinerorden',),
'benefice': ('benefice',),
'beneficen': ('benefice',),
'beneficene': ('benefice',),
'beneficer': ('benefice',),
'beneficeforestilling': ('beneficeforestilling',),
'beneficeforestillinga': ('beneficeforestilling',),
'beneficeforestillingen': ('beneficeforestilling',),
'beneficeforestillingene': ('beneficeforestilling',),
'beneficeforestillinger': ('beneficeforestilling',),
'benevnelse': ('benevnelse',),
'benevnelsen': ('benevnelse',),
'benevnelsene': ('benevnelse',),
'benevnelser': ('benevnelse',),
'benevning': ('benevning',),
'benevninga': ('benevning',),
'benevningen': ('benevning',),
'benevningene': ('benevning',),
'benevninger': ('benevning',),
'benfisk': ('benfisk',),
'benfisken': ('benfisk',),
'benfiskene': ('benfisk',),
'benfisker': ('benfisk',),
'bengaler': ('bengaler',),
'bengalere': ('bengaler',),
'bengaleren': ('bengaler',),
'bengalerer': ('bengaler',),
'bengalerne': ('bengaler',),
'bengali': ('bengali',),
'bengalien': ('bengali',),
'bengaliene': ('bengali',),
'bengalier': ('bengali',),
'bengel': ('bengel',),
'bengelen': ('bengel',),
'benglene': ('bengel',),
'bengler': ('bengel',),
'beniner': ('beniner',),
'beninere': ('beniner',),
'benineren': ('beniner',),
'beninerer': ('beniner',),
'beninerne': ('beniner',),
'benjamin': ('benjamin',),
'benjaminen': ('benjamin',),
'benjaminene': ('benjamin',),
'benjaminer': ('benjamin',),
'benk': ('benk',),
'benken': ('benk',),
'benkene': ('benk',),
'benker': ('benk',),
'benkboremaskin': ('benkboremaskin',),
'benkboremaskina': ('benkboremaskin',),
'benkboremaskinen': ('benkboremaskin',),
'benkboremaskinene': ('benkboremaskin',),
'benkboremaskiner': ('benkboremaskin',),
'benkebiter': ('benkebiter',),
'benkebitere': ('benkebiter',),
'benkebiteren': ('benkebiter',),
'benkebiterer': ('benkebiter',),
'benkebiterne': ('benkebiter',),
'benkeforslag': ('benkeforslag',),
'benkeforslaga': ('benkeforslag',),
'benkeforslagene': ('benkeforslag',),
'benkeforslaget': ('benkeforslag',),
'benkeframlegg': ('benkeframlegg',),
'benkeframlegga': ('benkeframlegg',),
'benkeframleggene': ('benkeframlegg',),
'benkeframlegget': ('benkeframlegg',),
'benkerad': ('benkerad',),
'benkerada': ('benkerad',),
'benkeraden': ('benkerad',),
'benkeradene': ('benkerad',),
'benkerader': ('benkerad',),
'benkesliter': ('benkesliter',),
'benkeslitere': ('benkesliter',),
'benkesliteren': ('benkesliter',),
'benkesliterer': ('benkesliter',),
'benkesliterne': ('benkesliter',),
'benklær': ('benklær',),
'benklærne': ('benklær',),
'benkrok': ('benkrok',),
'benkroken': ('benkrok',),
'benkrokene': ('benkrok',),
'benkroker': ('benkrok',),
'benlim': ('benlim',),
'benlima': ('benlim',),
'benlimene': ('benlim',),
'benlimet': ('benlim',),
'benmarg': ('benmarg',),
'benmargen': ('benmarg',),
'benmargene': ('benmarg',),
'benmarger': ('benmarg',),
'benmarg': ('benmarg',),
'benmargen': ('benmarg',),
'benmargene': ('benmarg',),
'benmarger': ('benmarg',),
'benmarg': ('benmarg',),
'benmargen': ('benmarg',),
'benmargene': ('benmarg',),
'benmarger': ('benmarg',),
'benmel': ('benmel',),
'benmela': ('benmel',),
'benmelene': ('benmel',),
'benmelet': ('benmel',),
'benmerg': ('benmerg',),
'benmergen': ('benmerg',),
'benmergene': ('benmerg',),
'benmerger': ('benmerg',),
'benmerg': ('benmerg',),
'benmergen': ('benmerg',),
'benmergene': ('benmerg',),
'benmerger': ('benmerg',),
'benmerg': ('benmerg',),
'benmergen': ('benmerg',),
'benmergene': ('benmerg',),
'benmerger': ('benmerg',),
'benmjøl': ('benmjøl',),
'benmjøla': ('benmjøl',),
'benmjølene': ('benmjøl',),
'benmjølet': ('benmjøl',),
'benpipa': ('benpipe',),
'benpipe': ('benpipe',),
'benpipen': ('benpipe',),
'benpipene': ('benpipe',),
'benpiper': ('benpipe',),
'benrangel': ('benrangel',),
'benrangelet': ('benrangel',),
'benrangla': ('benrangel',),
'benranglene': ('benrangel',),
'benrangler': ('benrangel',),
'benranglet': ('benrangel',),
'bensin': ('bensin',),
'bensinen': ('bensin',),
'bensinene': ('bensin',),
'bensiner': ('bensin',),
'bensinavgift': ('bensinavgift',),
'bensinavgifta': ('bensinavgift',),
'bensinavgiften': ('bensinavgift',),
'bensinavgiftene': ('bensinavgift',),
'bensinavgifter': ('bensinavgift',),
'bensinfat': ('bensinfat',),
'bensinfata': ('bensinfat',),
'bensinfatene': ('bensinfat',),
'bensinfater': ('bensinfat',),
'bensinfatet': ('bensinfat',),
'bensinforbruk': ('bensinforbruk',),
'bensinforbruka': ('bensinforbruk',),
'bensinforbrukene': ('bensinforbruk',),
'bensinforbruket': ('bensinforbruk',),
'bensinmotor': ('bensinmotor',),
'bensinmotoren': ('bensinmotor',),
'bensinmotorene': ('bensinmotor',),
'bensinmotorer': ('bensinmotor',),
'bensinpumpa': ('bensinpumpe',),
'bensinpumpe': ('bensinpumpe',),
'bensinpumpen': ('bensinpumpe',),
'bensinpumpene': ('bensinpumpe',),
'bensinpumper': ('bensinpumpe',),
'bensinstasjon': ('bensinstasjon',),
'bensinstasjonen': ('bensinstasjon',),
'bensinstasjonene': ('bensinstasjon',),
'bensinstasjoner': ('bensinstasjon',),
'bensinstasjonskjede': ('bensinstasjonskjede',),
'bensinstasjonskjeden': ('bensinstasjonskjede',),
'bensinstasjonskjedene': ('bensinstasjonskjede',),
'bensinstasjonskjeder': ('bensinstasjonskjede',),
'bensintank': ('bensintank',),
'bensintanken': ('bensintank',),
'bensintankene': ('bensintank',),
'bensintanker': ('bensintank',),
'bensintilførsel': ('bensintilførsel',),
'bensintilførselen': ('bensintilførsel',),
'bensintilførslene': ('bensintilførsel',),
'bensintilførsler': ('bensintilførsel',),
'benskurd': ('benskurd',),
'benskurden': ('benskurd',),
'benskurdene': ('benskurd',),
'benskurder': ('benskurd',),
'bensplint': ('bensplint',),
'bensplinten': ('bensplint',),
'bensplintene': ('bensplint',),
'bensplinter': ('bensplint',),
'bensubstans': ('bensubstans',),
'bensubstansen': ('bensubstans',),
'bensubstansene': ('bensubstans',),
'bensubstanser': ('bensubstans',),
'benved': ('benved',),
'benveden': ('benved',),
'benvedene': ('benved',),
'benveder': ('benved',),
'benveg': ('benveg',),
'benvegen': ('benveg',),
'benvegene': ('benveg',),
'benveger': ('benveg',),
'benvei': ('benvei',),
'benveien': ('benvei',),
'benveiene': ('benvei',),
'benveier': ('benvei',),
'benvev': ('benvev',),
'benveva': ('benvev',),
'benvevene': ('benvev',),
'benvevet': ('benvev',),
'benzen': ('benzen',),
'benzena': ('benzen',),
'benzenene': ('benzen',),
'benzenet': ('benzen',),
'benzensprit': ('benzensprit',),
'benzenspriten': ('benzensprit',),
'benzenspritene': ('benzensprit',),
'benzenspriter': ('benzensprit',),
'benådning': ('benådning',),
'benådninga': ('benådning',),
'benådningen': ('benådning',),
'benådningene': ('benådning',),
'benådninger': ('benådning',),
'beplantning': ('beplantning',),
'beplantninga': ('beplantning',),
'beplantningen': ('beplantning',),
'beplantningene': ('beplantning',),
'beplantninger': ('beplantning',),
'berber': ('berber',),
'berbere': ('berber',),
'berberen': ('berber',),
'berberer': ('berber',),
'berberne': ('berber',),
'berberis': ('berberis',),
'berberisen': ('berberis',),
'berberisene': ('berberis',),
'berberiser': ('berberis',),
'berberisbusk': ('berberisbusk',),
'berberisbusken': ('berberisbusk',),
'berberisbuskene': ('berberisbusk',),
'berberisbusker': ('berberisbusk',),
'berberspråk': ('berberspråk',),
'berberspråka': ('berberspråk',),
'berberspråkene': ('berberspråk',),
'berberspråket': ('berberspråk',),
'berbisk': ('berbisk',),
'berbisken': ('berbisk',),
'berbiskene': ('berbisk',),
'berbisker': ('berbisk',),
'berceuse': ('berceuse',),
'berceusen': ('berceuse',),
'berceusene': ('berceuse',),
'berceuser': ('berceuse',),
'bereder': ('bereder',),
'beredere': ('bereder',),
'berederen': ('bereder',),
'berederer': ('bereder',),
'berederne': ('bereder',),
'beredskap': ('beredskap',),
'beredskapa': ('beredskap',),
'beredskapen': ('beredskap',),
'beredskapene': ('beredskap',),
'beredskaper': ('beredskap',),
'beredskapet': ('beredskap',),
'beredskapslager': ('beredskapslager',),
'beredskapslageret': ('beredskapslager',),
'beredskapslagra': ('beredskapslager',),
'beredskapslagre': ('beredskapslager',),
'beredskapslagrene': ('beredskapslager',),
'beredskapslov': ('beredskapslov',),
'beredskapsloven': ('beredskapslov',),
'beredskapslovene': ('beredskapslov',),
'beredskapslover': ('beredskapslov',),
'beredskapstiltak': ('beredskapstiltak',),
'beredskapstiltaka': ('beredskapstiltak',),
'beredskapstiltakene': ('beredskapstiltak',),
'beredskapstiltaket': ('beredskapstiltak',),
'beregner': ('beregner',),
'beregnere': ('beregner',),
'beregneren': ('beregner',),
'beregnerer': ('beregner',),
'beregnerne': ('beregner',),
'beregning': ('beregning',),
'beregninga': ('beregning',),
'beregningen': ('beregning',),
'beregningene': ('beregning',),
'beregninger': ('beregning',),
'beregningsfeil': ('beregningsfeil',),
'beregningsfeilen': ('beregningsfeil',),
'beregningsfeilene': ('beregningsfeil',),
'beregningsgrunnlag': ('beregningsgrunnlag',),
'beregningsgrunnlaga': ('beregningsgrunnlag',),
'beregningsgrunnlagene': ('beregningsgrunnlag',),
'beregningsgrunnlaget': ('beregningsgrunnlag',),
'beregningsmåte': ('beregningsmåte',),
'beregningsmåten': ('beregningsmåte',),
'beregningsmåtene': ('beregningsmåte',),
'beregningsmåter': ('beregningsmåte',),
'beregningssum': ('beregningssum',),
'beregningssummen': ('beregningssum',),
'beregningssummene': ('beregningssum',),
'beregningssummer': ('beregningssum',),
'berekner': ('berekner',),
'bereknere': ('berekner',),
'berekneren': ('berekner',),
'bereknerer': ('berekner',),
'bereknerne': ('berekner',),
'berekning': ('berekning',),
'berekninga': ('berekning',),
'berekningen': ('berekning',),
'berekningene': ('berekning',),
'berekninger': ('berekning',),
'berekningsfeil': ('berekningsfeil',),
'berekningsfeilen': ('berekningsfeil',),
'berekningsfeilene': ('berekningsfeil',),
'berekningsgrunnlag': ('berekningsgrunnlag',),
'berekningsgrunnlaga': ('berekningsgrunnlag',),
'berekningsgrunnlagene': ('berekningsgrunnlag',),
'berekningsgrunnlaget': ('berekningsgrunnlag',),
'berekningsmåte': ('berekningsmåte',),
'berekningsmåten': ('berekningsmåte',),
'berekningsmåtene': ('berekningsmåte',),
'berekningsmåter': ('berekningsmåte',),
'berekningssum': ('berekningssum',),
'berekningssummen': ('berekningssum',),
'berekningssummene': ('berekningssum',),
'berekningssummer': ('berekningssum',),
'beret': ('beret',),
'bereten': ('beret',),
'beretene': ('beret',),
'bereter': ('beret',),
'beretning': ('beretning',),
'beretninga': ('beretning',),
'beretningen': ('beretning',),
'beretningene': ('beretning',),
'beretninger': ('beretning',),
'beretter': ('beretter',),
'berettere': ('beretter',),
'beretteren': ('beretter',),
'beretterer': ('beretter',),
'beretterne': ('beretter',),
'berettigelse': ('berettigelse',),
'berettigelsen': ('berettigelse',),
'berettigelsene': ('berettigelse',),
'berettigelser': ('berettigelse',),
'berg': ('berg',),
'berga': ('berg',),
'bergene': ('berg',),
'berget': ('berg',),
'berg-og-dal-bane': ('berg-og-dal-bane',),
'berg-og-dal-banen': ('berg-og-dal-bane',),
'berg-og-dal-banene': ('berg-og-dal-bane',),
'berg-og-dal-baner': ('berg-og-dal-bane',),
'bergamott': ('bergamott',),
'bergamotten': ('bergamott',),
'bergamottene': ('bergamott',),
'bergamotter': ('bergamott',),
'bergamottappelsin': ('bergamottappelsin',),
'bergamottappelsinen': ('bergamottappelsin',),
'bergamottappelsinene': ('bergamottappelsin',),
'bergamottappelsiner': ('bergamottappelsin',),
'bergamottolja': ('bergamottolje',),
'bergamottolje': ('bergamottolje',),
'bergamottoljen': ('bergamottolje',),
'bergamottoljene': ('bergamottolje',),
'bergamottoljer': ('bergamottolje',),
'bergamottpæra': ('bergamottpære',),
'bergamottpære': ('bergamottpære',),
'bergamottpæren': ('bergamottpære',),
'bergamottpærene': ('bergamottpære',),
'bergamottpærer': ('bergamottpære',),
'bergand': ('bergand',),
'berganda': ('bergand',),
'berganden': ('bergand',),
'bergendene': ('bergand',),
'bergender': ('bergand',),
'bergart': ('bergart',),
'bergarta': ('bergart',),
'bergarten': ('bergart',),
'bergartene': ('bergart',),
'bergarter': ('bergart',),
'bergartilleri': ('bergartilleri',),
'bergartilleria': ('bergartilleri',),
'bergartilleriene': ('bergartilleri',),
'bergartillerier': ('bergartilleri',),
'bergartilleriet': ('bergartilleri',),
'bergelønn': ('bergelønn',),
'bergelønna': ('bergelønn',),
'bergelønnen': ('bergelønn',),
'bergelønnene': ('bergelønn',),
'bergelønner': ('bergelønn',),
'bergenser': ('bergenser',),
'bergensere': ('bergenser',),
'bergenseren': ('bergenser',),
'bergenserer': ('bergenser',),
'bergenserne': ('bergenser',),
'bergfag': ('bergfag',),
'bergfaga': ('bergfag',),
'bergfagene': ('bergfag',),
'bergfaget': ('bergfag',),
'bergfletta': ('bergflette',),
'bergflette': ('bergflette',),
'bergfletten': ('bergflette',),
'bergflettene': ('bergflette',),
'bergfletter': ('bergflette',),
'bergflettefamilie': ('bergflettefamilie',),
'bergflettefamilien': ('bergflettefamilie',),
'bergflettefamiliene': ('bergflettefamilie',),
'bergflettefamilier': ('bergflettefamilie',),
'bergfrua': ('bergfrue',),
'bergfrue': ('bergfrue',),
'bergfruen': ('bergfrue',),
'bergfruene': ('bergfrue',),
'bergfruer': ('bergfrue',),
'berggylta': ('berggylte',),
'berggylte': ('berggylte',),
'berggylten': ('berggylte',),
'berggyltene': ('berggylte',),
'berggylter': ('berggylte',),
'berghammar': ('berghammar',),
'berghammaren': ('berghammar',),
'berghamrene': ('berghammar',),
'berghamrer': ('berghammar',),
'berghammer': ('berghammer',),
'berghammere': ('berghammer',),
'berghammeren': ('berghammer',),
'berghammerer': ('berghammer',),
'berghammerne': ('berghammer',),
'berghamrene': ('berghammer',),
'berghamrer': ('berghammer',),
'berghola': ('berghole',),
'berghole': ('berghole',),
'bergholen': ('berghole',),
'bergholene': ('berghole',),
'bergholer': ('berghole',),
'berghula': ('berghule',),
'berghule': ('berghule',),
'berghulen': ('berghule',),
'berghulene': ('berghule',),
'berghuler': ('berghule',),
'berghylla': ('berghylle',),
'berghylle': ('berghylle',),
'berghyllen': ('berghylle',),
'berghyllene': ('berghylle',),
'berghyller': ('berghylle',),
'berging': ('berging',),
'berginga': ('berging',),
'bergingen': ('berging',),
'bergingene': ('berging',),
'berginger': ('berging',),
'bergingeniør': ('bergingeniør',),
'bergingeniøren': ('bergingeniør',),
'bergingeniørene': ('bergingeniør',),
'bergingeniører': ('bergingeniør',),
'bergingsarbeid': ('bergingsarbeid',),
'bergingsarbeida': ('bergingsarbeid',),
'bergingsarbeidene': ('bergingsarbeid',),
'bergingsarbeider': ('bergingsarbeid',),
'bergingsarbeidet': ('bergingsarbeid',),
'bergingsbåt': ('bergingsbåt',),
'bergingsbåten': ('bergingsbåt',),
'bergingsbåtene': ('bergingsbåt',),
'bergingsbåter': ('bergingsbåt',),
'bergingsfartøy': ('bergingsfartøy',),
'bergingsfartøya': ('bergingsfartøy',),
'bergingsfartøyene': ('bergingsfartøy',),
'bergingsfartøyer': ('bergingsfartøy',),
'bergingsfartøyet': ('bergingsfartøy',),
'bergingsforsøk': ('bergingsforsøk',),
'bergingsforsøka': ('bergingsforsøk',),
'bergingsforsøkene': ('bergingsforsøk',),
'bergingsforsøket': ('bergingsforsøk',),
'bergirisk': ('bergirisk',),
'bergirisken': ('bergirisk',),
'bergiriskene': ('bergirisk',),
'bergirisker': ('bergirisk',),
'bergknapp': ('bergknapp',),
'bergknappen': ('bergknapp',),
'bergknappene': ('bergknapp',),
'bergknapper': ('bergknapp',),
'bergknaus': ('bergknaus',),
'bergknausen': ('bergknaus',),
'bergknausene': ('bergknaus',),
'bergknauser': ('bergknaus',),
'bergkrystall': ('bergkrystall',),
'bergkrystalla': ('bergkrystall',),
'bergkrystallen': ('bergkrystall',),
'bergkrystallene': ('bergkrystall',),
'bergkrystaller': ('bergkrystall',),
'bergkrystallet': ('bergkrystall',),
'bergmann': ('bergmann',),
'bergmannen': ('bergmann',),
'bergmenn': ('bergmann',),
'bergmennene': ('bergmann',),
'bergmester': ('bergmester',),
'bergmestere': ('bergmester',),
'bergmesteren': ('bergmester',),
'bergmesterer': ('bergmester',),
'bergmesterne': ('bergmester',),
'bergmestre': ('bergmester',),
'bergmestrene': ('bergmester',),
'bergmestrer': ('bergmester',),
'bergmynta': ('bergmynte',),
'bergmynte': ('bergmynte',),
'bergmynten': ('bergmynte',),
'bergmyntene': ('bergmynte',),
'bergmynter': ('bergmynte',),
'bergnabb': ('bergnabb',),
'bergnabben': ('bergnabb',),
'bergnabbene': ('bergnabb',),
'bergnabber': ('bergnabb',),
'bergnebb': ('bergnebb',),
'bergnebben': ('bergnebb',),
'bergnebbene': ('bergnebb',),
'bergnebber': ('bergnebb',),
'bergnebba': ('bergnebbe',),
'bergnebbe': ('bergnebbe',),
'bergnebben': ('bergnebbe',),
'bergnebbene': ('bergnebbe',),
'bergnebber': ('bergnebbe',),
'bergpreken': ('bergpreken',),
'bergprekenen': ('bergpreken',),
'bergprekenene': ('bergpreken',),
'bergprekener': ('bergpreken',),
'bergsildra': ('bergsildre',),
'bergsildre': ('bergsildre',),
'bergsildren': ('bergsildre',),
'bergsildrene': ('bergsildre',),
'bergsildrer': ('bergsildre',),
'bergugla': ('bergugle',),
'bergugle': ('bergugle',),
'berguglen': ('bergugle',),
'berguglene': ('bergugle',),
'bergugler': ('bergugle',),
'bergvegg': ('bergvegg',),
'bergveggen': ('bergvegg',),
'bergveggene': ('bergvegg',),
'bergvegger': ('bergvegg',),
'bergverk': ('bergverk',),
'bergverka': ('bergverk',),
'bergverkene': ('bergverk',),
'bergverker': ('bergverk',),
'bergverket': ('bergverk',),
'bergverksdrift': ('bergverksdrift',),
'bergverksdrifta': ('bergverksdrift',),
'bergverksdriften': ('bergverksdrift',),
'bergverksdriftene': ('bergverksdrift',),
'bergverksdrifter': ('bergverksdrift',),
'bergveronika': ('bergveronika',),
'bergveronikaen': ('bergveronika',),
'bergveronikaene': ('bergveronika',),
'bergveronikaer': ('bergveronika',),
'bergvesen': ('bergvesen',),
'bergvesena': ('bergvesen',),
'bergvesenene': ('bergvesen',),
'bergvesener': ('bergvesen',),
'bergvesenet': ('bergvesen',),
'beriberi': ('beriberi',),
'beriberien': ('beriberi',),
'beriberiene': ('beriberi',),
'beriberier': ('beriberi',),
'berider': ('berider',),
'beridere': ('berider',),
'berideren': ('berider',),
'beriderer': ('berider',),
'beriderne': ('berider',),
'beriderska': ('beriderske',),
'beriderske': ('beriderske',),
'beridersken': ('beriderske',),
'beriderskene': ('beriderske',),
'beridersker': ('beriderske',),
'beriktigelse': ('beriktigelse',),
'beriktigelsen': ('beriktigelse',),
'beriktigelsene': ('beriktigelse',),
'beriktigelser': ('beriktigelse',),
'berkelium': ('berkelium',),
'berkeliuma': ('berkelium',),
'berkeliumene': ('berkelium',),
'berkeliumet': ('berkelium',),
'berlinblått': ('berlinblått',),
'berliner': ('berliner',),
'berlinere': ('berliner',),
'berlineren': ('berliner',),
'berlinerer': ('berliner',),
'berlinerne': ('berliner',),
'berlinerblått': ('berlinerblått',),
'berlinerbolle': ('berlinerbolle',),
'berlinerbollen': ('berlinerbolle',),
'berlinerbollene': ('berlinerbolle',),
'berlinerboller': ('berlinerbolle',),
'berlinerkrans': ('berlinerkrans',),
'berlinerkransen': ('berlinerkrans',),
'berlinerkransene': ('berlinerkrans',),
'berlinerkranser': ('berlinerkrans',),
'berme': ('berme',),
'bermen': ('berme',),
'bermene': ('berme',),
'bermer': ('berme',),
'bermudarigg': ('bermudarigg',),
'bermudariggen': ('bermudarigg',),
'bermudariggene': ('bermudarigg',),
'bermudarigger': ('bermudarigg',),
'bermudashorts': ('bermudashorts',),
'bermudashortsen': ('bermudashorts',),
'bermudashortsene': ('bermudashorts',),
'bermudashortser': ('bermudashorts',),
'bernhardiner': ('bernhardiner',),
'bernhardinere': ('bernhardiner',),
'bernhardineren': ('bernhardiner',),
'bernhardinerer': ('bernhardiner',),
'bernhardinerne': ('bernhardiner',),
'bero': ('bero',),
'berserk': ('berserk',),
'berserken': ('berserk',),
'berserkene': ('berserk',),
'berserker': ('berserk',),
'berserkgang': ('berserkgang',),
'berserkgangen': ('berserkgang',),
'berserkgangene': ('berserkgang',),
'berserkganger': ('berserkgang',),
'berserksgang': ('berserksgang',),
'berserksgangen': ('berserksgang',),
'berserksgangene': ('berserksgang',),
'berserksganger': ('berserksgang',),
'beryll': ('beryll',),
'beryllen': ('beryll',),
'beryllene': ('beryll',),
'beryller': ('beryll',),
'beryllium': ('beryllium',),
'berylliuma': ('beryllium',),
'berylliumene': ('beryllium',),
'berylliumet': ('beryllium',),
'berømmelse': ('berømmelse',),
'berømmelsen': ('berømmelse',),
'berømmelsene': ('berømmelse',),
'berømmelser': ('berømmelse',),
'berømthet': ('berømthet',),
'berømtheta': ('berømthet',),
'berømtheten': ('berømthet',),
'berømthetene': ('berømthet',),
'berømtheter': ('berømthet',),
'berøring': ('berøring',),
'berøringa': ('berøring',),
'berøringen': ('berøring',),
'berøringene': ('berøring',),
'berøringer': ('berøring',),
'berøringsflata': ('berøringsflate',),
'berøringsflate': ('berøringsflate',),
'berøringsflaten': ('berøringsflate',),
'berøringsflatene': ('berøringsflate',),
'berøringsflater': ('berøringsflate',),
'berøringspunkt': ('berøringspunkt',),
'berøringspunkta': ('berøringspunkt',),
'berøringspunktene': ('berøringspunkt',),
'berøringspunkter': ('berøringspunkt',),
'berøringspunktet': ('berøringspunkt',),
'berøvelse': ('berøvelse',),
'berøvelsen': ('berøvelse',),
'berøvelsene': ('berøvelse',),
'berøvelser': ('berøvelse',),
'beseirer': ('beseirer',),
'beseirere': ('beseirer',),
'beseireren': ('beseirer',),
'beseirerer': ('beseirer',),
'beseirerne': ('beseirer',),
'besetning': ('besetning',),
'besetninga': ('besetning',),
'besetningen': ('besetning',),
'besetningene': ('besetning',),
'besetninger': ('besetning',),
'besetningsband': ('besetningsband',),
'besetningsbanda': ('besetningsband',),
'besetningsbandene': ('besetningsband',),
'besetningsbandet': ('besetningsband',),
'besetningsbånd': ('besetningsbånd',),
'besetningsbånda': ('besetningsbånd',),
'besetningsbåndene': ('besetningsbånd',),
'besetningsbåndet': ('besetningsbånd',),
'besettelse': ('besettelse',),
'besettelsen': ('besettelse',),
'besettelsene': ('besettelse',),
'besettelser': ('besettelse',),
'besiktelse': ('besiktelse',),
'besiktelsen': ('besiktelse',),
'besiktelsene': ('besiktelse',),
'besiktelser': ('besiktelse',),
'besiktelsesmann': ('besiktelsesmann',),
'besiktelsesmannen': ('besiktelsesmann',),
'besiktelsesmenn': ('besiktelsesmann',),
'besiktelsesmennene': ('besiktelsesmann',),
'besiktigelse': ('besiktigelse',),
'besiktigelsen': ('besiktigelse',),
'besiktigelsene': ('besiktigelse',),
'besiktigelser': ('besiktigelse',),
'besindighet': ('besindighet',),
'besindigheta': ('besindighet',),
'besindigheten': ('besindighet',),
'besindighetene': ('besindighet',),
'besindigheter': ('besindighet',),
'besinnelse': ('besinnelse',),
'besinnelsen': ('besinnelse',),
'besinnelsene': ('besinnelse',),
'besinnelser': ('besinnelse',),
'besittelse': ('besittelse',),
'besittelsen': ('besittelse',),
'besittelsene': ('besittelse',),
'besittelser': ('besittelse',),
'besjeling': ('besjeling',),
'besjelinga': ('besjeling',),
'besjelingen': ('besjeling',),
'besjelingene': ('besjeling',),
'besjelinger': ('besjeling',),
'beskaffenhet': ('beskaffenhet',),
'beskaffenheta': ('beskaffenhet',),
'beskaffenheten': ('beskaffenhet',),
'beskaffenhetene': ('beskaffenhet',),
'beskaffenheter': ('beskaffenhet',),
'beskatning': ('beskatning',),
'beskatninga': ('beskatning',),
'beskatningen': ('beskatning',),
'beskatningene': ('beskatning',),
'beskatninger': ('beskatning',),
'beskatningsregel': ('beskatningsregel',),
'beskatningsregelen': ('beskatningsregel',),
'beskatningsreglene': ('beskatningsregel',),
'beskatningsregler': ('beskatningsregel',),
'beskjed': ('beskjed',),
'beskjeden': ('beskjed',),
'beskjedene': ('beskjed',),
'beskjeder': ('beskjed',),
'beskjedenhet': ('beskjedenhet',),
'beskjedenheta': ('beskjedenhet',),
'beskjedenheten': ('beskjedenhet',),
'beskjedenhetene': ('beskjedenhet',),
'beskjedenheter': ('beskjedenhet',),
'beskjeftigelse': ('beskjeftigelse',),
'beskjeftigelsen': ('beskjeftigelse',),
'beskjeftigelsene': ('beskjeftigelse',),
'beskjeftigelser': ('beskjeftigelse',),
'beskrivelse': ('beskrivelse',),
'beskrivelsen': ('beskrivelse',),
'beskrivelsene': ('beskrivelse',),
'beskrivelser': ('beskrivelse',),
'beskuelse': ('beskuelse',),
'beskuelsen': ('beskuelse',),
'beskuelsene': ('beskuelse',),
'beskuelser': ('beskuelse',),
'beskyldning': ('beskyldning',),
'beskyldninga': ('beskyldning',),
'beskyldningen': ('beskyldning',),
'beskyldningene': ('beskyldning',),
'beskyldninger': ('beskyldning',),
'beskyttelse': ('beskyttelse',),
'beskyttelsen': ('beskyttelse',),
'beskyttelsene': ('beskyttelse',),
'beskyttelser': ('beskyttelse',),
'beskyttelsesfarge': ('beskyttelsesfarge',),
'beskyttelsesfargen': ('beskyttelsesfarge',),
'beskyttelsesfargene': ('beskyttelsesfarge',),
'beskyttelsesfarger': ('beskyttelsesfarge',),
'beskyttelseslikhet': ('beskyttelseslikhet',),
'beskyttelseslikheta': ('beskyttelseslikhet',),
'beskyttelseslikheten': ('beskyttelseslikhet',),
'beskyttelseslikhetene': ('beskyttelseslikhet',),
'beskyttelseslikheter': ('beskyttelseslikhet',),
'beskytter': ('beskytter',),
'beskyttere': ('beskytter',),
'beskytteren': ('beskytter',),
'beskytterer': ('beskytter',),
'beskytterne': ('beskytter',),
'beskøyt': ('beskøyt',),
'beskøyten': ('beskøyt',),
'beskøytene': ('beskøyt',),
'beskøyter': ('beskøyt',),
'beslag': ('beslag',),
'beslaga': ('beslag',),
'beslagene': ('beslag',),
'beslaget': ('beslag',),
'beslutning': ('beslutning',),
'beslutninga': ('beslutning',),
'beslutningen': ('beslutning',),
'beslutningene': ('beslutning',),
'beslutninger': ('beslutning',),
'beslutningsprosess': ('beslutningsprosess',),
'beslutningsprosessen': ('beslutningsprosess',),
'beslutningsprosessene': ('beslutningsprosess',),
'beslutningsprosesser': ('beslutningsprosess',),
'besluttsomhet': ('besluttsomhet',),
'besluttsomheta': ('besluttsomhet',),
'besluttsomheten': ('besluttsomhet',),
'besluttsomhetene': ('besluttsomhet',),
'besluttsomheter': ('besluttsomhet',),
'besparelse': ('besparelse',),
'besparelsen': ('besparelse',),
'besparelsene': ('besparelse',),
'besparelser': ('besparelse',),
'bespisning': ('bespisning',),
'bespisninga': ('bespisning',),
'bespisningen': ('bespisning',),
'bespisningene': ('bespisning',),
'bespisninger': ('bespisning',),
'bessemerstål': ('bessemerstål',),
'bessemerståla': ('bessemerstål',),
'bessemerstålene': ('bessemerstål',),
'bessemerstålet': ('bessemerstål',),
'besserwissen': ('besserwissen',),
'besserwisser': ('besserwisser',),
'besserwissere': ('besserwisser',),
'besserwisseren': ('besserwisser',),
'besserwisserer': ('besserwisser',),
'besserwisserne': ('besserwisser',),
'best': ('best',),
'besta': ('best',),
'bestene': ('best',),
'bestet': ('best',),
'bestalling': ('bestalling',),
'bestallingen': ('bestalling',),
'bestallingene': ('bestalling',),
'bestallinger': ('bestalling',),
'bestand': ('bestand',),
'bestanden': ('bestand',),
'bestandene': ('bestand',),
'bestander': ('bestand',),
'bestand': ('bestand',),
'bestanda': ('bestand',),
'bestandene': ('bestand',),
'bestandet': ('bestand',),
'bestanddel': ('bestanddel',),
'bestanddelen': ('bestanddel',),
'bestanddelene': ('bestanddel',),
'bestanddeler': ('bestanddel',),
'bestandighet': ('bestandighet',),
'bestandigheta': ('bestandighet',),
'bestandigheten': ('bestandighet',),
'bestandighetene': ('bestandighet',),
'bestandigheter': ('bestandighet',),
'besteborger': ('besteborger',),
'besteborgere': ('besteborger',),
'besteborgeren': ('besteborger',),
'besteborgerer': ('besteborger',),
'besteborgerne': ('besteborger',),
'bestemann': ('bestemann',),
'bestemannen': ('bestemann',),
'bestemenn': ('bestemann',),
'bestemennene': ('bestemann',),
'bestemmelse': ('bestemmelse',),
'bestemmelsen': ('bestemmelse',),
'bestemmelsene': ('bestemmelse',),
'bestemmelser': ('bestemmelse',),
'bestemmelsessted': ('bestemmelsessted',),
'bestemmelsesstedene': ('bestemmelsessted',),
'bestemmelsessteder': ('bestemmelsessted',),
'bestemmelsesstedet': ('bestemmelsessted',),
'bestemor': ('bestemor',),
'bestemora': ('bestemor',),
'bestemoren': ('bestemor',),
'bestemødre': ('bestemor',),
'bestemødrene': ('bestemor',),
'bestemødrer': ('bestemor',),
'bestemthet': ('bestemthet',),
'bestemtheta': ('bestemthet',),
'bestemtheten': ('bestemthet',),
'bestemthetene': ('bestemthet',),
'bestemtheter': ('bestemthet',),
'bestenotering': ('bestenotering',),
'bestenoteringa': ('bestenotering',),
'bestenoteringen': ('bestenotering',),
'bestenoteringene': ('bestenotering',),
'bestenoteringer': ('bestenotering',),
'bestevenn': ('bestevenn',),
'bestevennen': ('bestevenn',),
'bestevennene': ('bestevenn',),
'bestevenner': ('bestevenn',),
'bestevenninna': ('bestevenninne',),
'bestevenninne': ('bestevenninne',),
'bestevenninnen': ('bestevenninne',),
'bestevenninnene': ('bestevenninne',),
'bestevenninner': ('bestevenninne',),
'bestevilkår': ('bestevilkår',),
'bestevilkåra': ('bestevilkår',),
'bestevilkårene': ('bestevilkår',),
'bestevilkåret': ('bestevilkår',),
'bestevilkårsavtale': ('bestevilkårsavtale',),
'bestevilkårsavtalen': ('bestevilkårsavtale',),
'bestevilkårsavtalene': ('bestevilkårsavtale',),
'bestevilkårsavtaler': ('bestevilkårsavtale',),
'bestialitet': ('bestialitet',),
'bestialiteten': ('bestialitet',),
'bestialitetene': ('bestialitet',),
'bestialiteter': ('bestialitet',),
'bestigelse': ('bestigelse',),
'bestigelsen': ('bestigelse',),
'bestigelsene': ('bestigelse',),
'bestigelser': ('bestigelse',),
'bestigning': ('bestigning',),
'bestigninga': ('bestigning',),
'bestigningen': ('bestigning',),
'bestigningene': ('bestigning',),
'bestigninger': ('bestigning',),
'bestikk': ('bestikk',),
'bestikken': ('bestikk',),
'bestikkene': ('bestikk',),
'bestikker': ('bestikk',),
'bestikkelse': ('bestikkelse',),
'bestikkelsen': ('bestikkelse',),
'bestikkelsene': ('bestikkelse',),
'bestikkelser': ('bestikkelse',),
'bestikklugar': ('bestikklugar',),
'bestikklugaren': ('bestikklugar',),
'bestikklugarene': ('bestikklugar',),
'bestikklugarer': ('bestikklugar',),
'bestikkoppgjør': ('bestikkoppgjør',),
'bestikkoppgjøra': ('bestikkoppgjør',),
'bestikkoppgjørene': ('bestikkoppgjør',),
'bestikkoppgjøret': ('bestikkoppgjør',),
'bestikktabell': ('bestikktabell',),
'bestikktabellen': ('bestikktabell',),
'bestikktabellene': ('bestikktabell',),
'bestikktabeller': ('bestikktabell',),
'bestilling': ('bestilling',),
'bestillingen': ('bestilling',),
'bestillingene': ('bestilling',),
'bestillinger': ('bestilling',),
'bestilling': ('bestilling',),
'bestillinga': ('bestilling',),
'bestillingen': ('bestilling',),
'bestillingene': ('bestilling',),
'bestillinger': ('bestilling',),
'bestillingstjuveri': ('bestillingstjuveri',),
'bestillingstjuveria': ('bestillingstjuveri',),
'bestillingstjuveriene': ('bestillingstjuveri',),
'bestillingstjuverier': ('bestillingstjuveri',),
'bestillingstjuveriet': ('bestillingstjuveri',),
'bestillingstyveri': ('bestillingstyveri',),
'bestillingstyveria': ('bestillingstyveri',),
'bestillingstyveriene': ('bestillingstyveri',),
'bestillingstyverier': ('bestillingstyveri',),
'bestillingstyveriet': ('bestillingstyveri',),
'bestillingsverk': ('bestillingsverk',),
'bestillingsverka': ('bestillingsverk',),
'bestillingsverkene': ('bestillingsverk',),
'bestillingsverker': ('bestillingsverk',),
'bestillingsverket': ('bestillingsverk',),
'bestrebelse': ('bestrebelse',),
'bestrebelsen': ('bestrebelse',),
'bestrebelsene': ('bestrebelse',),
'bestrebelser': ('bestrebelse',),
'bestselger': ('bestselger',),
'bestselgere': ('bestselger',),
'bestselgeren': ('bestselger',),
'bestselgerer': ('bestselger',),
'bestselgerne': ('bestselger',),
'bestseller': ('bestseller',),
'bestsellere': ('bestseller',),
'bestselleren': ('bestseller',),
'bestsellerer': ('bestseller',),
'bestsellerne': ('bestseller',),
'bestykning': ('bestykning',),
'bestykninga': ('bestykning',),
'bestykningen': ('bestykning',),
'bestykningene': ('bestykning',),
'bestykninger': ('bestykning',),
'bestyr': ('bestyr',),
'bestyra': ('bestyr',),
'bestyrene': ('bestyr',),
'bestyret': ('bestyr',),
'bestyrer': ('bestyrer',),
'bestyrere': ('bestyrer',),
'bestyreren': ('bestyrer',),
'bestyrerer': ('bestyrer',),
'bestyrerne': ('bestyrer',),
'bestyrtelse': ('bestyrtelse',),
'bestyrtelsen': ('bestyrtelse',),
'bestyrtelsene': ('bestyrtelse',),
'bestyrtelser': ('bestyrtelse',),
'beståen': ('beståen',),
'bestøvning': ('bestøvning',),
'bestøvninga': ('bestøvning',),
'bestøvningen': ('bestøvning',),
'bestøvningene': ('bestøvning',),
'bestøvninger': ('bestøvning',),
'besvarelse': ('besvarelse',),
'besvarelsen': ('besvarelse',),
'besvarelsene': ('besvarelse',),
'besvarelser': ('besvarelse',),
'besvergelse': ('besvergelse',),
'besvergelsen': ('besvergelse',),
'besvergelsene': ('besvergelse',),
'besvergelser': ('besvergelse',),
'besvergelsesformular': ('besvergelsesformular',),
'besvergelsesformulara': ('besvergelsesformular',),
'besvergelsesformularen': ('besvergelsesformular',),
'besvergelsesformularene': ('besvergelsesformular',),
'besvergelsesformularer': ('besvergelsesformular',),
'besvergelsesformularet': ('besvergelsesformular',),
'besvergelseskunst': ('besvergelseskunst',),
'besvergelseskunsten': ('besvergelseskunst',),
'besvergelseskunstene': ('besvergelseskunst',),
'besvergelseskunster': ('besvergelseskunst',),
'besvimelse': ('besvimelse',),
'besvimelsen': ('besvimelse',),
'besvimelsene': ('besvimelse',),
'besvimelser': ('besvimelse',),
'besvimelsesanfall': ('besvimelsesanfall',),
'besvimelsesanfalla': ('besvimelsesanfall',),
'besvimelsesanfallene': ('besvimelsesanfall',),
'besvimelsesanfallet': ('besvimelsesanfall',),
'besvær': ('besvær',),
'besværa': ('besvær',),
'besværene': ('besvær',),
'besværet': ('besvær',),
'besynderlighet': ('besynderlighet',),
'besynderligheta': ('besynderlighet',),
'besynderligheten': ('besynderlighet',),
'besynderlighetene': ('besynderlighet',),
'besynderligheter': ('besynderlighet',),
'besyv': ('besyv',),
'besyva': ('besyv',),
'besyvene': ('besyv',),
'besyvet': ('besyv',),
'besøk': ('besøk',),
'besøka': ('besøk',),
'besøkene': ('besøk',),
'besøket': ('besøk',),
'besøkelsestid': ('besøkelsestid',),
'besøkelsestida': ('besøkelsestid',),
'besøkelsestiden': ('besøkelsestid',),
'besøkelsestidene': ('besøkelsestid',),
'besøkelsestider': ('besøkelsestid',),
'besøksforbud': ('besøksforbud',),
'besøksforbuda': ('besøksforbud',),
'besøksforbudene': ('besøksforbud',),
'besøksforbudet': ('besøksforbud',),
'besøksrett': ('besøksrett',),
'besøksretten': ('besøksrett',),
'besøksrettene': ('besøksrett',),
'besøksretter': ('besøksrett',),
'beta': ('beta',),
'betaen': ('beta',),
'betaene': ('beta',),
'betaer': ('beta',),
'betaler': ('betaler',),
'betalere': ('betaler',),
'betaleren': ('betaler',),
'betalerer': ('betaler',),
'betalerne': ('betaler',),
'betaling': ('betaling',),
'betalinga': ('betaling',),
'betalingen': ('betaling',),
'betalingene': ('betaling',),
'betalinger': ('betaling',),
'betalingsbalanse': ('betalingsbalanse',),
'betalingsbalansen': ('betalingsbalanse',),
'betalingsbalansene': ('betalingsbalanse',),
'betalingsbalanser': ('betalingsbalanse',),
'betalingsfrist': ('betalingsfrist',),
'betalingsfristen': ('betalingsfrist',),
'betalingsfristene': ('betalingsfrist',),
'betalingsfrister': ('betalingsfrist',),
'betalingsmiddel': ('betalingsmiddel',),
'betalingsmiddelet': ('betalingsmiddel',),
'betalingsmidla': ('betalingsmiddel',),
'betalingsmidlene': ('betalingsmiddel',),
'betalingsmidler': ('betalingsmiddel',),
'betalingsmidlet': ('betalingsmiddel',),
'betalingsmåte': ('betalingsmåte',),
'betalingsmåten': ('betalingsmåte',),
'betalingsmåtene': ('betalingsmåte',),
'betalingsmåter': ('betalingsmåte',),
'betalingsvilkår': ('betalingsvilkår',),
'betalingsvilkåra': ('betalingsvilkår',),
'betalingsvilkårene': ('betalingsvilkår',),
'betalingsvilkåret': ('betalingsvilkår',),
'betapartikkel': ('betapartikkel',),
'betapartikkelen': ('betapartikkel',),
'betapartiklene': ('betapartikkel',),
'betapartikler': ('betapartikkel',),
'betastråle': ('betastråle',),
'betastrålen': ('betastråle',),
'betastrålene': ('betastråle',),
'betastråler': ('betastråle',),
'betasuppa': ('betasuppe',),
'betasuppe': ('betasuppe',),
'betasuppen': ('betasuppe',),
'betasuppene': ('betasuppe',),
'betasupper': ('betasuppe',),
'bete': ('bete',),
'beten': ('bete',),
'betene': ('bete',),
'beter': ('bete',),
'beta': ('bete',),
'bete': ('bete',),
'beten': ('bete',),
'betene': ('bete',),
'beter': ('bete',),
'betegnelse': ('betegnelse',),
'betegnelsen': ('betegnelse',),
'betegnelsene': ('betegnelse',),
'betegnelser': ('betegnelse',),
'betel': ('betel',),
'betelen': ('betel',),
'betlene': ('betel',),
'betler': ('betel',),
'betelpalme': ('betelpalme',),
'betelpalmen': ('betelpalme',),
'betelpalmene': ('betelpalme',),
'betelpalmer': ('betelpalme',),
'betenkelighet': ('betenkelighet',),
'betenkeligheta': ('betenkelighet',),
'betenkeligheten': ('betenkelighet',),
'betenkelighetene': ('betenkelighet',),
'betenkeligheter': ('betenkelighet',),
'betenkning': ('betenkning',),
'betenkninga': ('betenkning',),
'betenkningen': ('betenkning',),
'betenkningene': ('betenkning',),
'betenkninger': ('betenkning',),
'betenkningstid': ('betenkningstid',),
'betenkningstida': ('betenkningstid',),
'betenkningstiden': ('betenkningstid',),
'betenkningstidene': ('betenkningstid',),
'betenkningstider': ('betenkningstid',),
'betennelse': ('betennelse',),
'betennelsen': ('betennelse',),
'betennelsene': ('betennelse',),
'betennelser': ('betennelse',),
'betesukker': ('betesukker',),
'betesukkera': ('betesukker',),
'betesukkere': ('betesukker',),
'betesukkerene': ('betesukker',),
'betesukkeret': ('betesukker',),
'betesukkerne': ('betesukker',),
'betingelse': ('betingelse',),
'betingelsen': ('betingelse',),
'betingelsene': ('betingelse',),
'betingelser': ('betingelse',),
'betingelseskonjunksjon': ('betingelseskonjunksjon',),
'betingelseskonjunksjonen': ('betingelseskonjunksjon',),
'betingelseskonjunksjonene': ('betingelseskonjunksjon',),
'betingelseskonjunksjoner': ('betingelseskonjunksjon',),
'betingelsessetning': ('betingelsessetning',),
'betingelsessetninga': ('betingelsessetning',),
'betingelsessetningen': ('betingelsessetning',),
'betingelsessetningene': ('betingelsessetning',),
'betingelsessetninger': ('betingelsessetning',),
'betinging': ('betinging',),
'betinginga': ('betinging',),
'betingingen': ('betinging',),
'betingingene': ('betinging',),
'betinginger': ('betinging',),
'betjening': ('betjening',),
'betjeninga': ('betjening',),
'betjeningen': ('betjening',),
'betjeningene': ('betjening',),
'betjeninger': ('betjening',),
'betjent': ('betjent',),
'betjenten': ('betjent',),
'betjentene': ('betjent',),
'betjenter': ('betjent',),
'betler': ('betler',),
'betlere': ('betler',),
'betleren': ('betler',),
'betlerer': ('betler',),
'betlerne': ('betler',),
'betleri': ('betleri',),
'betleria': ('betleri',),
'betleriene': ('betleri',),
'betlerier': ('betleri',),
'betleriet': ('betleri',),
'betlerstav': ('betlerstav',),
'betlerstaven': ('betlerstav',),
'betlerstavene': ('betlerstav',),
'betlerstaver': ('betlerstav',),
'betong': ('betong',),
'betongen': ('betong',),
'betongene': ('betong',),
'betonger': ('betong',),
'betongblander': ('betongblander',),
'betongblandere': ('betongblander',),
'betongblanderen': ('betongblander',),
'betongblanderer': ('betongblander',),
'betongblanderne': ('betongblander',),
'betongbygning': ('betongbygning',),
'betongbygninga': ('betongbygning',),
'betongbygningen': ('betongbygning',),
'betongbygningene': ('betongbygning',),
'betongbygninger': ('betongbygning',),
'betongkonstruksjon': ('betongkonstruksjon',),
'betongkonstruksjonen': ('betongkonstruksjon',),
'betongkonstruksjonene': ('betongkonstruksjon',),
'betongkonstruksjoner': ('betongkonstruksjon',),
'betongrør': ('betongrør',),
'betongrøra': ('betongrør',),
'betongrørene': ('betongrør',),
'betongrøret': ('betongrør',),
'betongstein': ('betongstein',),
'betongsteinen': ('betongstein',),
'betongsteinene': ('betongstein',),
'betongsteiner': ('betongstein',),
'betoning': ('betoning',),
'betoninga': ('betoning',),
'betoningen': ('betoning',),
'betoningene': ('betoning',),
'betoninger': ('betoning',),
'betrakter': ('betrakter',),
'betraktere': ('betrakter',),
'betrakteren': ('betrakter',),
'betrakterer': ('betrakter',),
'betrakterne': ('betrakter',),
'betraktning': ('betraktning',),
'betraktninga': ('betraktning',),
'betraktningen': ('betraktning',),
'betraktningene': ('betraktning',),
'betraktninger': ('betraktning',),
'betraktningsapparat': ('betraktningsapparat',),
'betraktningsapparata': ('betraktningsapparat',),
'betraktningsapparatene': ('betraktningsapparat',),
'betraktningsapparater': ('betraktningsapparat',),
'betraktningsapparatet': ('betraktningsapparat',),
'betraktningsmåte': ('betraktningsmåte',),
'betraktningsmåten': ('betraktningsmåte',),
'betraktningsmåtene': ('betraktningsmåte',),
'betraktningsmåter': ('betraktningsmåte',),
'betroelse': ('betroelse',),
'betroelsen': ('betroelse',),
'betroelsene': ('betroelse',),
'betroelser': ('betroelse',),
'betryggelse': ('betryggelse',),
'betryggelsen': ('betryggelse',),
'betryggelsene': ('betryggelse',),
'betryggelser': ('betryggelse',),
'betydning': ('betydning',),
'betydninga': ('betydning',),
'betydningen': ('betydning',),
'betydningene': ('betydning',),
'betydninger': ('betydning',),
'betydningsendring': ('betydningsendring',),
'betydningsendringa': ('betydningsendring',),
'betydningsendringen': ('betydningsendring',),
'betydningsendringene': ('betydningsendring',),
'betydningsendringer': ('betydningsendring',),
'betydningsforskjell': ('betydningsforskjell',),
'betydningsforskjellen': ('betydningsforskjell',),
'betydningsforskjellene': ('betydningsforskjell',),
'betydningsforskjeller': ('betydningsforskjell',),
'betydningsinnhold': ('betydningsinnhold',),
'betydningsinnholda': ('betydningsinnhold',),
'betydningsinnholdene': ('betydningsinnhold',),
'betydningsinnholdet': ('betydningsinnhold',),
'betydningsnyanse': ('betydningsnyanse',),
'betydningsnyansen': ('betydningsnyanse',),
'betydningsnyansene': ('betydningsnyanse',),
'betydningsnyanser': ('betydningsnyanse',),
'betydningsovergang': ('betydningsovergang',),
'betydningsovergangen': ('betydningsovergang',),
'betydningsovergangene': ('betydningsovergang',),
'betydningsoverganger': ('betydningsovergang',),
'beundrer': ('beundrer',),
'beundrere': ('beundrer',),
'beundreren': ('beundrer',),
'beundrerer': ('beundrer',),
'beundrerne': ('beundrer',),
'beundring': ('beundring',),
'beundringa': ('beundring',),
'beundringen': ('beundring',),
'beundringene': ('beundring',),
'beundringer': ('beundring',),
'bevegelighet': ('bevegelighet',),
'bevegeligheta': ('bevegelighet',),
'bevegeligheten': ('bevegelighet',),
'bevegelighetene': ('bevegelighet',),
'bevegeligheter': ('bevegelighet',),
'bevegelse': ('bevegelse',),
'bevegelsen': ('bevegelse',),
'bevegelsene': ('bevegelse',),
'bevegelser': ('bevegelse',),
'bevegelsesenergi': ('bevegelsesenergi',),
'bevegelsesenergien': ('bevegelsesenergi',),
'bevegelsesenergiene': ('bevegelsesenergi',),
'bevegelsesenergier': ('bevegelsesenergi',),
'bevegelsesfrihet': ('bevegelsesfrihet',),
'bevegelsesfriheta': ('bevegelsesfrihet',),
'bevegelsesfriheten': ('bevegelsesfrihet',),
'bevegelsesfrihetene': ('bevegelsesfrihet',),
'bevegelsesfriheter': ('bevegelsesfrihet',),
'bevegelseshemning': ('bevegelseshemning',),
'bevegelseshemninga': ('bevegelseshemning',),
'bevegelseshemningen': ('bevegelseshemning',),
'bevegelseshemningene': ('bevegelseshemning',),
'bevegelseshemninger': ('bevegelseshemning',),
'bevegelsesverb': ('bevegelsesverb',),
'bevegelsesverba': ('bevegelsesverb',),
'bevegelsesverbene': ('bevegelsesverb',),
'bevegelsesverber': ('bevegelsesverb',),
'bevegelsesverbet': ('bevegelsesverb',),
'bevegelsesverba': ('bevegelsesverbum',),
'bevegelsesverbene': ('bevegelsesverbum',),
'bevegelsesverber': ('bevegelsesverbum',),
'bevegelsesverbet': ('bevegelsesverbum',),
'bevegelsesverbum': ('bevegelsesverbum',),
'bevegelsesverbumet': ('bevegelsesverbum',),
'beveggrunn': ('beveggrunn',),
'beveggrunnen': ('beveggrunn',),
'beveggrunnene': ('beveggrunn',),
'beveggrunner': ('beveggrunn',),
'beven': ('beven',),
'bever': ('bever',),
'bevere': ('bever',),
'beveren': ('bever',),
'beverer': ('bever',),
'beverne': ('bever',),
'bevre': ('bever',),
'bevrene': ('bever',),
'bevrer': ('bever',),
'bevergjel': ('bevergjel',),
'bevergjela': ('bevergjel',),
'bevergjelen': ('bevergjel',),
'bevergjelene': ('bevergjel',),
'bevergjeler': ('bevergjel',),
'bevergjelet': ('bevergjel',),
'beverhytta': ('beverhytte',),
'beverhytte': ('beverhytte',),
'beverhytten': ('beverhytte',),
'beverhyttene': ('beverhytte',),
'beverhytter': ('beverhytte',),
'beverpels': ('beverpels',),
'beverpelsen': ('beverpels',),
'beverpelsene': ('beverpels',),
'beverpelser': ('beverpels',),
'beverrotta': ('beverrotte',),
'beverrotte': ('beverrotte',),
'beverrotten': ('beverrotte',),
'beverrottene': ('beverrotte',),
'beverrotter': ('beverrotte',),
'bevertning': ('bevertning',),
'bevertninga': ('bevertning',),
'bevertningen': ('bevertning',),
'bevertningene': ('bevertning',),
'bevertninger': ('bevertning',),
'bevertningssted': ('bevertningssted',),
'bevertningsstedene': ('bevertningssted',),
'bevertningssteder': ('bevertningssted',),
'bevertningsstedet': ('bevertningssted',),
'bevilgning': ('bevilgning',),
'bevilgninga': ('bevilgning',),
'bevilgningen': ('bevilgning',),
'bevilgningene': ('bevilgning',),
'bevilgninger': ('bevilgning',),
'bevilgningsreglement': ('bevilgningsreglement',),
'bevilgningsreglementa': ('bevilgningsreglement',),
'bevilgningsreglementene': ('bevilgningsreglement',),
'bevilgningsreglementer': ('bevilgningsreglement',),
'bevilgningsreglementet': ('bevilgningsreglement',),
'bevilgningsspørsmål': ('bevilgningsspørsmål',),
'bevilgningsspørsmåla': ('bevilgningsspørsmål',),
'bevilgningsspørsmålene': ('bevilgningsspørsmål',),
'bevilgningsspørsmålet': ('bevilgningsspørsmål',),
'bevilling': ('bevilling',),
'bevillingen': ('bevilling',),
'bevillingene': ('bevilling',),
'bevillinger': ('bevilling',),
'bevillingshaver': ('bevillingshaver',),
'bevillingshavere': ('bevillingshaver',),
'bevillingshaveren': ('bevillingshaver',),
'bevillingshaverer': ('bevillingshaver',),
'bevillingshaverne': ('bevillingshaver',),
'bevillingsutsteder': ('bevillingsutsteder',),
'bevillingsutstedere': ('bevillingsutsteder',),
'bevillingsutstederen': ('bevillingsutsteder',),
'bevillingsutstederer': ('bevillingsutsteder',),
'bevillingsutstederne': ('bevillingsutsteder',),
'bevis': ('bevis',),
'bevisa': ('bevis',),
'bevisene': ('bevis',),
'beviser': ('bevis',),
'beviset': ('bevis',),
'bevisbyrde': ('bevisbyrde',),
'bevisbyrden': ('bevisbyrde',),
'bevisbyrdene': ('bevisbyrde',),
'bevisbyrder': ('bevisbyrde',),
'bevisførsel': ('bevisførsel',),
'bevisførselen': ('bevisførsel',),
'bevisførslene': ('bevisførsel',),
'bevisførsler': ('bevisførsel',),
'bevisgrunn': ('bevisgrunn',),
'bevisgrunnen': ('bevisgrunn',),
'bevisgrunnene': ('bevisgrunn',),
'bevisgrunner': ('bevisgrunn',),
'bevismateriala': ('bevismateriale',),
'bevismateriale': ('bevismateriale',),
'bevismaterialene': ('bevismateriale',),
'bevismaterialer': ('bevismateriale',),
'bevismaterialet': ('bevismateriale',),
'bevissthet': ('bevissthet',),
'bevisstheta': ('bevissthet',),
'bevisstheten': ('bevissthet',),
'bevissthetene': ('bevissthet',),
'bevisstheter': ('bevissthet',),
'bevissthetsforstyrrelse': ('bevissthetsforstyrrelse',),
'bevissthetsforstyrrelsen': ('bevissthetsforstyrrelse',),
'bevissthetsforstyrrelsene': ('bevissthetsforstyrrelse',),
'bevissthetsforstyrrelser': ('bevissthetsforstyrrelse',),
'bevissthetsterskel': ('bevissthetsterskel',),
'bevissthetsterskelen': ('bevissthetsterskel',),
'bevissthetstersklene': ('bevissthetsterskel',),
'bevissthetsterskler': ('bevissthetsterskel',),
'bevoktning': ('bevoktning',),
'bevoktninga': ('bevoktning',),
'bevoktningen': ('bevoktning',),
'bevoktningene': ('bevoktning',),
'bevoktninger': ('bevoktning',),
'bevreasp': ('bevreasp',),
'bevreaspa': ('bevreasp',),
'bevreaspen': ('bevreasp',),
'bevreaspene': ('bevreasp',),
'bevreasper': ('bevreasp',),
'bevreosp': ('bevreosp',),
'bevreospa': ('bevreosp',),
'bevreospen': ('bevreosp',),
'bevreospene': ('bevreosp',),
'bevreosper': ('bevreosp',),
'bevågenhet': ('bevågenhet',),
'bevågenheta': ('bevågenhet',),
'bevågenheten': ('bevågenhet',),
'bevågenhetene': ('bevågenhet',),
'bevågenheter': ('bevågenhet',),
'bey': ('bey',),
'beyen': ('bey',),
'beyene': ('bey',),
'beyer': ('bey',),
'bh': ('bh',),
'bh-en': ('bh',),
'bh-ene': ('bh',),
'bh-er': ('bh',),
'bhen': ('bh',),
'bhene': ('bh',),
'bher': ('bh',),
'bhutaner': ('bhutaner',),
'bhutanere': ('bhutaner',),
'bhutaneren': ('bhutaner',),
'bhutanerer': ('bhutaner',),
'bhutanerne': ('bhutaner',),
'biafraner': ('biafraner',),
'biafranere': ('biafraner',),
'biafraneren': ('biafraner',),
'biafranerer': ('biafraner',),
'biafranerne': ('biafraner',),
'bial': ('bial',),
'biala': ('bial',),
'bialene': ('bial',),
'bialet': ('bial',),
'biapparat': ('biapparat',),
'biapparata': ('biapparat',),
'biapparatene': ('biapparat',),
'biapparater': ('biapparat',),
'biapparatet': ('biapparat',),
'biarbeid': ('biarbeid',),
'biarbeida': ('biarbeid',),
'biarbeidene': ('biarbeid',),
'biarbeider': ('biarbeid',),
'biarbeidet': ('biarbeid',),
'biavl': ('biavl',),
'biavlen': ('biavl',),
'biavlene': ('biavl',),
'biavler': ('biavl',),
'bibehold': ('bibehold',),
'bibel': ('bibel',),
'bibelen': ('bibel',),
'biblene': ('bibel',),
'bibler': ('bibel',),
'bibelcamp': ('bibelcamp',),
'bibelcampen': ('bibelcamp',),
'bibelcampene': ('bibelcamp',),
'bibelcamper': ('bibelcamp',),
'bibelfortolker': ('bibelfortolker',),
'bibelfortolkere': ('bibelfortolker',),
'bibelfortolkeren': ('bibelfortolker',),
'bibelfortolkerer': ('bibelfortolker',),
'bibelfortolkerne': ('bibelfortolker',),
'bibelfortolking': ('bibelfortolking',),
'bibelfortolkinga': ('bibelfortolking',),
'bibelfortolkingen': ('bibelfortolking',),
'bibelfortolkingene': ('bibelfortolking',),
'bibelfortolkinger': ('bibelfortolking',),
'bibelfortolkning': ('bibelfortolkning',),
'bibelfortolkninga': ('bibelfortolkning',),
'bibelfortolkningen': ('bibelfortolkning',),
'bibelfortolkningene': ('bibelfortolkning',),
'bibelfortolkninger': ('bibelfortolkning',),
'bibelhandskrift': ('bibelhandskrift',),
'bibelhandskrifta': ('bibelhandskrift',),
'bibelhandskriftene': ('bibelhandskrift',),
'bibelhandskrifter': ('bibelhandskrift',),
'bibelhandskriftet': ('bibelhandskrift',),
'bibelhistoria': ('bibelhistorie',),
'bibelhistorie': ('bibelhistorie',),
'bibelhistorien': ('bibelhistorie',),
'bibelhistoriene': ('bibelhistorie',),
'bibelhistorier': ('bibelhistorie',),
'bibelhåndskrift': ('bibelhåndskrift',),
'bibelhåndskrifta': ('bibelhåndskrift',),
'bibelhåndskriftene': ('bibelhåndskrift',),
'bibelhåndskrifter': ('bibelhåndskrift',),
'bibelhåndskriftet': ('bibelhåndskrift',),
'bibelkonkordans': ('bibelkonkordans',),
'bibelkonkordansen': ('bibelkonkordans',),
'bibelkonkordansene': ('bibelkonkordans',),
'bibelkonkordanser': ('bibelkonkordans',),
'bibelkritikk': ('bibelkritikk',),
'bibelkritikken': ('bibelkritikk',),
'bibelkritikkene': ('bibelkritikk',),
'bibelkritikker': ('bibelkritikk',),
'bibelord': ('bibelord',),
'bibelorda': ('bibelord',),
'bibelordene': ('bibelord',),
'bibelordet': ('bibelord',),
'bibelordbok': ('bibelordbok',),
'bibelordboka': ('bibelordbok',),
'bibelordboken': ('bibelordbok',),
'bibelordbøkene': ('bibelordbok',),
'bibelordbøker': ('bibelordbok',),
'bibeloversettelse': ('bibeloversettelse',),
'bibeloversettelsen': ('bibeloversettelse',),
'bibeloversettelsene': ('bibeloversettelse',),
'bibeloversettelser': ('bibeloversettelse',),
'bibelselskap': ('bibelselskap',),
'bibelselskapa': ('bibelselskap',),
'bibelselskapene': ('bibelselskap',),
'bibelselskaper': ('bibelselskap',),
'bibelselskapet': ('bibelselskap',),
'bibelsitat': ('bibelsitat',),
'bibelsitata': ('bibelsitat',),
'bibelsitatene': ('bibelsitat',),
'bibelsitater': ('bibelsitat',),
'bibelsitatet': ('bibelsitat',),
'bibelskole': ('bibelskole',),
'bibelskolen': ('bibelskole',),
'bibelskolene': ('bibelskole',),
'bibelskoler': ('bibelskole',),
'bibelsmugler': ('bibelsmugler',),
'bibelsmuglere': ('bibelsmugler',),
'bibelsmugleren': ('bibelsmugler',),
'bibelsmuglerer': ('bibelsmugler',),
'bibelsmuglerne': ('bibelsmugler',),
'bibelspråk': ('bibelspråk',),
'bibelspråka': ('bibelspråk',),
'bibelspråkene': ('bibelspråk',),
'bibelspråket': ('bibelspråk',),
'bibelsted': ('bibelsted',),
'bibelstedene': ('bibelsted',),
'bibelsteder': ('bibelsted',),
'bibelstedet': ('bibelsted',),
'bibeltime': ('bibeltime',),
'bibeltimen': ('bibeltime',),
'bibeltimene': ('bibeltime',),
'bibeltimer': ('bibeltime',),
'bibelutgava': ('bibelutgave',),
'bibelutgave': ('bibelutgave',),
'bibelutgaven': ('bibelutgave',),
'bibelutgavene': ('bibelutgave',),
'bibelutgaver': ('bibelutgave',),
'bibelvitenskap': ('bibelvitenskap',),
'bibelvitenskapen': ('bibelvitenskap',),
'bibelvitenskapene': ('bibelvitenskap',),
'bibelvitenskaper': ('bibelvitenskap',),
'bibelvitskap': ('bibelvitskap',),
'bibelvitskapen': ('bibelvitskap',),
'bibelvitskapene': ('bibelvitskap',),
'bibelvitskaper': ('bibelvitskap',),
'bibetydning': ('bibetydning',),
'bibetydninga': ('bibetydning',),
'bibetydningen': ('bibetydning',),
'bibetydningene': ('bibetydning',),
'bibetydninger': ('bibetydning',),
'biblad': ('biblad',),
'biblada': ('biblad',),
'bibladene': ('biblad',),
'biblader': ('biblad',),
'bibladet': ('biblad',),
'bibliofil': ('bibliofil',),
'bibliofilen': ('bibliofil',),
'bibliofilene': ('bibliofil',),
'bibliofiler': ('bibliofil',),
'bibliofili': ('bibliofili',),
'bibliofilien': ('bibliofili',),
'bibliofiliene': ('bibliofili',),
'bibliofilier': ('bibliofili',),
'bibliofilutgava': ('bibliofilutgave',),
'bibliofilutgave': ('bibliofilutgave',),
'bibliofilutgaven': ('bibliofilutgave',),
'bibliofilutgavene': ('bibliofilutgave',),
'bibliofilutgaver': ('bibliofilutgave',),
'bibliograf': ('bibliograf',),
'bibliografen': ('bibliograf',),
'bibliografene': ('bibliograf',),
'bibliografer': ('bibliograf',),
'bibliografi': ('bibliografi',),
'bibliografien': ('bibliografi',),
'bibliografiene': ('bibliografi',),
'bibliografier': ('bibliografi',),
'bibliotek': ('bibliotek',),
'biblioteka': ('bibliotek',),
'bibliotekene': ('bibliotek',),
'biblioteker': ('bibliotek',),
'biblioteket': ('bibliotek',),
'bibliotekar': ('bibliotekar',),
'bibliotekaren': ('bibliotekar',),
'bibliotekarene': ('bibliotekar',),
'bibliotekarer': ('bibliotekar',),
'bibringe': ('bibringe',),
'bibringen': ('bibringe',),
'bibringene': ('bibringe',),
'bibringer': ('bibringe',),
'biceps': ('biceps',),
'bicepsen': ('biceps',),
'bicepsene': ('biceps',),
'bicepser': ('biceps',),
'bidea': ('bidé',),
'bideene': ('bidé',),
'bideer': ('bidé',),
'bideet': ('bidé',),
'bidé': ('bidé',),
'bidéa': ('bidé',),
'bidéene': ('bidé',),
'bidéer': ('bidé',),
'bidéet': ('bidé',),
'bidevindsegler': ('bidevindsegler',),
'bidevindseglere': ('bidevindsegler',),
'bidevindsegleren': ('bidevindsegler',),
'bidevindseglerer': ('bidevindsegler',),
'bidevindseglerne': ('bidevindsegler',),
'bidevindseiler': ('bidevindseiler',),
'bidevindseilere': ('bidevindseiler',),
'bidevindseileren': ('bidevindseiler',),
'bidevindseilerer': ('bidevindseiler',),
'bidevindseilerne': ('bidevindseiler',),
'bidevindssegler': ('bidevindssegler',),
'bidevindsseglere': ('bidevindssegler',),
'bidevindssegleren': ('bidevindssegler',),
'bidevindsseglerer': ('bidevindssegler',),
'bidevindsseglerne': ('bidevindssegler',),
'bidevindsseiler': ('bidevindsseiler',),
'bidevindsseilere': ('bidevindsseiler',),
'bidevindsseileren': ('bidevindsseiler',),
'bidevindsseilerer': ('bidevindsseiler',),
'bidevindsseilerne': ('bidevindsseiler',),
'bidrag': ('bidrag',),
'bidraga': ('bidrag',),
'bidragene': ('bidrag',),
'bidraget': ('bidrag',),
'bidragsfogd': ('bidragsfogd',),
'bidragsfogden': ('bidragsfogd',),
'bidragsfogdene': ('bidragsfogd',),
'bidragsfogder': ('bidragsfogd',),
'bidragsfut': ('bidragsfut',),
'bidragsfuten': ('bidragsfut',),
'bidragsfutene': ('bidragsfut',),
'bidragsfuter': ('bidragsfut',),
'bidragsplikt': ('bidragsplikt',),
'bidragsplikta': ('bidragsplikt',),
'bidragsplikten': ('bidragsplikt',),
'bidragspliktene': ('bidragsplikt',),
'bidragsplikter': ('bidragsplikt',),
'bidragsyter': ('bidragsyter',),
'bidragsytere': ('bidragsyter',),
'bidragsyteren': ('bidragsyter',),
'bidragsyterer': ('bidragsyter',),
'bidragsyterne': ('bidragsyter',),
'bidronning': ('bidronning',),
'bidronninga': ('bidronning',),
'bidronningen': ('bidronning',),
'bidronningene': ('bidronning',),
'bidronninger': ('bidronning',),
'bia': ('bie',),
'bie': ('bie',),
'bien': ('bie',),
'biene': ('bie',),
'bier': ('bie',),
'biedermeier': ('biedermeier',),
'biedermeieren': ('biedermeier',),
'biedermeierene': ('biedermeier',),
'biedermeierer': ('biedermeier',),
'biedermeierinteriør': ('biedermeierinteriør',),
'biedermeierinteriøra': ('biedermeierinteriør',),
'biedermeierinteriørene': ('biedermeierinteriør',),
'biedermeierinteriører': ('biedermeierinteriør',),
'biedermeierinteriøret': ('biedermeierinteriør',),
'biedermeierstil': ('biedermeierstil',),
'biedermeierstilen': ('biedermeierstil',),
'biedermeierstilene': ('biedermeierstil',),
'biedermeierstiler': ('biedermeierstil',),
'bielv': ('bielv',),
'bielva': ('bielv',),
'bielven': ('bielv',),
'bielvene': ('bielv',),
'bielver': ('bielv',),
'biennale': ('biennale',),
'biennalen': ('biennale',),
'biennalene': ('biennale',),
'biennaler': ('biennale',),
'bierverv': ('bierverv',),
'bierverva': ('bierverv',),
'biervervene': ('bierverv',),
'biervervet': ('bierverv',),
'bifag': ('bifag',),
'bifaga': ('bifag',),
'bifagene': ('bifag',),
'bifaget': ('bifag',),
'bifall': ('bifall',),
'bifalla': ('bifall',),
'bifallene': ('bifall',),
'bifallet': ('bifall',),
'bifallsklapp': ('bifallsklapp',),
'bifallsklappa': ('bifallsklapp',),
'bifallsklappen': ('bifallsklapp',),
'bifallsklappene': ('bifallsklapp',),
'bifallsklapper': ('bifallsklapp',),
'bifallsklappet': ('bifallsklapp',),
'bifallsrop': ('bifallsrop',),
'bifallsropa': ('bifallsrop',),
'bifallsropene': ('bifallsrop',),
'bifallsropet': ('bifallsrop',),
'bifallsytring': ('bifallsytring',),
'bifallsytringa': ('bifallsytring',),
'bifallsytringen': ('bifallsytring',),
'bifallsytringene': ('bifallsytring',),
'bifallsytringer': ('bifallsytring',),
'biff': ('biff',),
'biffen': ('biff',),
'biffene': ('biff',),
'biffer': ('biff',),
'bifigur': ('bifigur',),
'bifiguren': ('bifigur',),
'bifigurene': ('bifigur',),
'bifigurer': ('bifigur',),
'bifili': ('bifili',),
'bifilien': ('bifili',),
'bifiliene': ('bifili',),
'bifilier': ('bifili',),
'bifolk': ('bifolk',),
'bifolka': ('bifolk',),
'bifolkene': ('bifolk',),
'bifolket': ('bifolk',),
'bigami': ('bigami',),
'bigamia': ('bigami',),
'bigamiene': ('bigami',),
'bigamiet': ('bigami',),
'bigamist': ('bigamist',),
'bigamisten': ('bigamist',),
'bigamistene': ('bigamist',),
'bigamister': ('bigamist',),
'bigift': ('bigift',),
'bigifta': ('bigift',),
'bigiften': ('bigift',),
'bigiftene': ('bigift',),
'bigifter': ('bigift',),
'bigotteri': ('bigotteri',),
'bigotteria': ('bigotteri',),
'bigotteriene': ('bigotteri',),
'bigotterier': ('bigotteri',),
'bigotteriet': ('bigotteri',),
'bihandling': ('bihandling',),
'bihandlinga': ('bihandling',),
'bihandlingen': ('bihandling',),
'bihandlingene': ('bihandling',),
'bihandlinger': ('bihandling',),
'bihold': ('bihold',),
'biholda': ('bihold',),
'biholdene': ('bihold',),
'biholdet': ('bihold',),
'bihola': ('bihole',),
'bihole': ('bihole',),
'biholen': ('bihole',),
'biholene': ('bihole',),
'biholer': ('bihole',),
'biholebetennelse': ('biholebetennelse',),
'biholebetennelsen': ('biholebetennelse',),
'biholebetennelsene': ('biholebetennelse',),
'biholebetennelser': ('biholebetennelse',),
'bihula': ('bihule',),
'bihule': ('bihule',),
'bihulen': ('bihule',),
'bihulene': ('bihule',),
'bihuler': ('bihule',),
'bihulebetennelse': ('bihulebetennelse',),
'bihulebetennelsen': ('bihulebetennelse',),
'bihulebetennelsene': ('bihulebetennelse',),
'bihulebetennelser': ('bihulebetennelse',),
'biinntekt': ('biinntekt',),
'biinntekta': ('biinntekt',),
'biinntekten': ('biinntekt',),
'biinntektene': ('biinntekt',),
'biinntekter': ('biinntekt',),
'bijouteri': ('bijouteri',),
'bijouteria': ('bijouteri',),
'bijouteriene': ('bijouteri',),
'bijouterier': ('bijouteri',),
'bijouteriet': ('bijouteri',),
'bikini': ('bikini',),
'bikinien': ('bikini',),
'bikiniene': ('bikini',),
'bikinier': ('bikini',),
'bikk': ('bikk',),
'bikken': ('bikk',),
'bikkene': ('bikk',),
'bikker': ('bikk',),
'bikkja': ('bikkje',),
'bikkje': ('bikkje',),
'bikkjen': ('bikkje',),
'bikkjene': ('bikkje',),
'bikkjer': ('bikkje',),
'bikkjeleven': ('bikkjeleven',),
'bikkjelevena': ('bikkjeleven',),
'bikkjelevenene': ('bikkjeleven',),
'bikkjelevenet': ('bikkjeleven',),
'bikkjeslagsmål': ('bikkjeslagsmål',),
'bikkjeslagsmåla': ('bikkjeslagsmål',),
'bikkjeslagsmålene': ('bikkjeslagsmål',),
'bikkjeslagsmålet': ('bikkjeslagsmål',),
'biklang': ('biklang',),
'biklangen': ('biklang',),
'biklangene': ('biklang',),
'biklanger': ('biklang',),
'bikse': ('bikse',),
'biksen': ('bikse',),
'biksene': ('bikse',),
'bikser': ('bikse',),
'bikube': ('bikube',),
'bikuben': ('bikube',),
'bikubene': ('bikube',),
'bikuber': ('bikube',),
'bil': ('bil',),
'bilen': ('bil',),
'bilene': ('bil',),
'biler': ('bil',),
'bilabial': ('bilabial',),
'bilabialen': ('bilabial',),
'bilabialene': ('bilabial',),
'bilabialer': ('bilabial',),
'bilag': ('bilag',),
'bilaga': ('bilag',),
'bilagene': ('bilag',),
'bilaget': ('bilag',),
'bilagsrevisjon': ('bilagsrevisjon',),
'bilagsrevisjonen': ('bilagsrevisjon',),
'bilagsrevisjonene': ('bilagsrevisjon',),
'bilagsrevisjoner': ('bilagsrevisjon',),
'bilbane': ('bilbane',),
'bilbanen': ('bilbane',),
'bilbanene': ('bilbane',),
'bilbaner': ('bilbane',),
'bilbelta': ('bilbelte',),
'bilbelte': ('bilbelte',),
'bilbeltene': ('bilbelte',),
'bilbelter': ('bilbelte',),
'bilbeltet': ('bilbelte',),
'bilbrev': ('bilbrev',),
'bilbreva': ('bilbrev',),
'bilbrevene': ('bilbrev',),
'bilbrever': ('bilbrev',),
'bilbrevet': ('bilbrev',),
'bilbrukstjuveri': ('bilbrukstjuveri',),
'bilbrukstjuveria': ('bilbrukstjuveri',),
'bilbrukstjuveriene': ('bilbrukstjuveri',),
'bilbrukstjuverier': ('bilbrukstjuveri',),
'bilbrukstjuveriet': ('bilbrukstjuveri',),
'bilbrukstyveri': ('bilbrukstyveri',),
'bilbrukstyveria': ('bilbrukstyveri',),
'bilbrukstyveriene': ('bilbrukstyveri',),
'bilbrukstyverier': ('bilbrukstyveri',),
'bilbrukstyveriet': ('bilbrukstyveri',),
'bilbås': ('bilbås',),
'bilbåsen': ('bilbås',),
'bilbåsene': ('bilbås',),
'bilbåser': ('bilbås',),
'bilbølla': ('bilbølle',),
'bilbølle': ('bilbølle',),
'bilbøllen': ('bilbølle',),
'bilbøllene': ('bilbølle',),
'bilbøller': ('bilbølle',),
'bilda': ('bilde',),
'bilde': ('bilde',),
'bildene': ('bilde',),
'bilder': ('bilde',),
'bildet': ('bilde',),
'bildearkiv': ('bildearkiv',),
'bildearkiva': ('bildearkiv',),
'bildearkivene': ('bildearkiv',),
'bildearkiver': ('bildearkiv',),
'bildearkivet': ('bildearkiv',),
'bildeband': ('bildeband',),
'bildebanda': ('bildeband',),
'bildebandene': ('bildeband',),
'bildebandet': ('bildeband',),
'bildebibel': ('bildebibel',),
'bildebibelen': ('bildebibel',),
'bildebiblene': ('bildebibel',),
'bildebibler': ('bildebibel',),
'bildebånd': ('bildebånd',),
'bildebånda': ('bildebånd',),
'bildebåndene': ('bildebånd',),
'bildebåndet': ('bildebånd',),
'bildegalleri': ('bildegalleri',),
'bildegalleria': ('bildegalleri',),
'bildegalleriene': ('bildegalleri',),
'bildegallerier': ('bildegalleri',),
'bildegalleriet': ('bildegalleri',),
'bildegåta': ('bildegåte',),
'bildegåte': ('bildegåte',),
'bildegåten': ('bildegåte',),
'bildegåtene': ('bildegåte',),
'bildegåter': ('bildegåte',),
'bildehogger': ('bildehogger',),
'bildehoggere': ('bildehogger',),
'bildehoggeren': ('bildehogger',),
'bildehoggerer': ('bildehogger',),
'bildehoggerne': ('bildehogger',),
'bildehoggerkunst': ('bildehoggerkunst',),
'bildehoggerkunsten': ('bildehoggerkunst',),
'bildehoggerkunstene': ('bildehoggerkunst',),
'bildehoggerkunster': ('bildehoggerkunst',),
'bildehugger': ('bildehugger',),
'bildehuggere': ('bildehugger',),
'bildehuggeren': ('bildehugger',),
'bildehuggerer': ('bildehugger',),
'bildehuggerne': ('bildehugger',),
'bildehuggerkunst': ('bildehuggerkunst',),
'bildehuggerkunsten': ('bildehuggerkunst',),
'bildehuggerkunstene': ('bildehuggerkunst',),
'bildehuggerkunster': ('bildehuggerkunst',),
'bildekk': ('bildekk',),
'bildekka': ('bildekk',),
'bildekkene': ('bildekk',),
'bildekket': ('bildekk',),
'bildekunst': ('bildekunst',),
'bildekunsten': ('bildekunst',),
'bildekunstene': ('bildekunst',),
'bildekunster': ('bildekunst',),
'bildekunstner': ('bildekunstner',),
'bildekunstnere': ('bildekunstner',),
'bildekunstneren': ('bildekunstner',),
'bildekunstnerer': ('bildekunstner',),
'bildekunstnerne': ('bildekunstner',),
'bildereportasje': ('bildereportasje',),
'bildereportasjen': ('bildereportasje',),
'bildereportasjene': ('bildereportasje',),
'bildereportasjer': ('bildereportasje',),
'bilderør': ('bilderør',),
'bilderøra': ('bilderør',),
'bilderørene': ('bilderør',),
'bilderøret': ('bilderør',),
'bildesamband': ('bildesamband',),
'bildesambanda': ('bildesamband',),
'bildesambandene': ('bildesamband',),
'bildesambandet': ('bildesamband',),
'bildeskarphet': ('bildeskarphet',),
'bildeskarpheta': ('bildeskarphet',),
'bildeskarpheten': ('bildeskarphet',),
'bildeskarphetene': ('bildeskarphet',),
'bildeskarpheter': ('bildeskarphet',),
'bildeskjærer': ('bildeskjærer',),
'bildeskjærere': ('bildeskjærer',),
'bildeskjæreren': ('bildeskjærer',),
'bildeskjærerer': ('bildeskjærer',),
'bildeskjærerne': ('bildeskjærer',),
'bildeskjæring': ('bildeskjæring',),
'bildeskjæringa': ('bildeskjæring',),
'bildeskjæringen': ('bildeskjæring',),
'bildeskjæringene': ('bildeskjæring',),
'bildeskjæringer': ('bildeskjæring',),
'bildeskrift': ('bildeskrift',),
'bildeskrifta': ('bildeskrift',),
'bildeskriften': ('bildeskrift',),
'bildeskriftene': ('bildeskrift',),
'bildeskrifter': ('bildeskrift',),
'bildespråk': ('bildespråk',),
'bildespråka': ('bildespråk',),
'bildespråkene': ('bildespråk',),
'bildespråket': ('bildespråk',),
'bildestorm': ('bildestorm',),
'bildestormen': ('bildestorm',),
'bildestormene': ('bildestorm',),
'bildestormer': ('bildestorm',),
'bildestormer': ('bildestormer',),
'bildestormere': ('bildestormer',),
'bildestormeren': ('bildestormer',),
'bildestormerer': ('bildestormer',),
'bildestormerne': ('bildestormer',),
'bildetekst': ('bildetekst',),
'bildeteksta': ('bildetekst',),
'bildeteksten': ('bildetekst',),
'bildetekstene': ('bildetekst',),
'bildetekster': ('bildetekst',),
'bildetelegrafi': ('bildetelegrafi',),
'bildetelegrafien': ('bildetelegrafi',),
'bildetelegrafiene': ('bildetelegrafi',),
'bildetelegrafier': ('bildetelegrafi',),
'bildevev': ('bildevev',),
'bildeveven': ('bildevev',),
'bildevevene': ('bildevev',),
'bildevever': ('bildevev',),
'bildeveving': ('bildeveving',),
'bildevevinga': ('bildeveving',),
'bildevevingen': ('bildeveving',),
'bildevevingene': ('bildeveving',),
'bildevevinger': ('bildeveving',),
'bildevevning': ('bildevevning',),
'bildevevninga': ('bildevevning',),
'bildevevningen': ('bildevevning',),
'bildevevningene': ('bildevevning',),
'bildevevninger': ('bildevevning',),
'bildilla': ('bildille',),
'bildille': ('bildille',),
'bildillen': ('bildille',),
'bildillene': ('bildille',),
'bildiller': ('bildille',),
'bila': ('bile',),
'bile': ('bile',),
'bilen': ('bile',),
'bilene': ('bile',),
'biler': ('bile',),
'bileggeromn': ('bileggeromn',),
'bileggeromnen': ('bileggeromn',),
'bileggeromnene': ('bileggeromn',),
'bileggeromner': ('bileggeromn',),
'bileggerovn': ('bileggerovn',),
'bileggerovnen': ('bileggerovn',),
'bileggerovnene': ('bileggerovn',),
'bileggerovner': ('bileggerovn',),
'bileier': ('bileier',),
'bileiere': ('bileier',),
'bileieren': ('bileier',),
'bileierer': ('bileier',),
'bileierne': ('bileier',),
'bilferga': ('bilferge',),
'bilferge': ('bilferge',),
'bilfergen': ('bilferge',),
'bilfergene': ('bilferge',),
'bilferger': ('bilferge',),
'bilferja': ('bilferje',),
'bilferje': ('bilferje',),
'bilferjen': ('bilferje',),
'bilferjene': ('bilferje',),
'bilferjer': ('bilferje',),
'bilfolk': ('bilfolk',),
'bilfolka': ('bilfolk',),
'bilfolkene': ('bilfolk',),
'bilfolket': ('bilfolk',),
'bilforhandler': ('bilforhandler',),
'bilforhandlere': ('bilforhandler',),
'bilforhandleren': ('bilforhandler',),
'bilforhandlerer': ('bilforhandler',),
'bilforhandlerne': ('bilforhandler',),
'bilfører': ('bilfører',),
'bilførere': ('bilfører',),
'bilføreren': ('bilfører',),
'bilførerer': ('bilfører',),
'bilførerne': ('bilfører',),
'bilgodtgjørelse': ('bilgodtgjørelse',),
'bilgodtgjørelsen': ('bilgodtgjørelse',),
'bilgodtgjørelsene': ('bilgodtgjørelse',),
'bilgodtgjørelser': ('bilgodtgjørelse',),
'bilgodtgjøring': ('bilgodtgjøring',),
'bilgodtgjøringa': ('bilgodtgjøring',),
'bilgodtgjøringen': ('bilgodtgjøring',),
'bilgodtgjøringene': ('bilgodtgjøring',),
'bilgodtgjøringer': ('bilgodtgjøring',),
'bilgummi': ('bilgummi',),
'bilgummien': ('bilgummi',),
'bilgummiene': ('bilgummi',),
'bilgummier': ('bilgummi',),
'bilhold': ('bilhold',),
'bilholda': ('bilhold',),
'bilholdene': ('bilhold',),
'bilholdet': ('bilhold',),
'bilhorn': ('bilhorn',),
'bilhorna': ('bilhorn',),
'bilhornene': ('bilhorn',),
'bilhornet': ('bilhorn',),
'bilingvalisme': ('bilingvalisme',),
'bilingvalismen': ('bilingvalisme',),
'bilingvalismene': ('bilingvalisme',),
'bilingvalismer': ('bilingvalisme',),
'bilingvalitet': ('bilingvalitet',),
'bilingvaliteten': ('bilingvalitet',),
'bilingvalitetene': ('bilingvalitet',),
'bilingvaliteter': ('bilingvalitet',),
'bilingvisme': ('bilingvisme',),
'bilingvismen': ('bilingvisme',),
'bilingvismene': ('bilingvisme',),
'bilingvismer': ('bilingvisme',),
'bilingvitet': ('bilingvitet',),
'bilingviteten': ('bilingvitet',),
'bilingvitetene': ('bilingvitet',),
'bilingviteter': ('bilingvitet',),
'bilisme': ('bilisme',),
'bilismen': ('bilisme',),
'bilismene': ('bilisme',),
'bilismer': ('bilisme',),
'bilist': ('bilist',),
'bilisten': ('bilist',),
'bilistene': ('bilist',),
'bilister': ('bilist',),
'biljard': ('biljard',),
'biljarden': ('biljard',),
'biljardene': ('biljard',),
'biljarder': ('biljard',),
'biljardbord': ('biljardbord',),
'biljardborda': ('biljardbord',),
'biljardbordene': ('biljardbord',),
'biljardborder': ('biljardbord',),
'biljardbordet': ('biljardbord',),
'bilkart': ('bilkart',),
'bilkarta': ('bilkart',),
'bilkartene': ('bilkart',),
'bilkarter': ('bilkart',),
'bilkartet': ('bilkart',),
'bilkirkegård': ('bilkirkegård',),
'bilkirkegården': ('bilkirkegård',),
'bilkirkegårdene': ('bilkirkegård',),
'bilkirkegårder': ('bilkirkegård',),
'bilkjennemerka': ('bilkjennemerke',),
'bilkjennemerke': ('bilkjennemerke',),
'bilkjennemerkene': ('bilkjennemerke',),
'bilkjennemerker': ('bilkjennemerke',),
'bilkjennemerket': ('bilkjennemerke',),
'bilkolonne': ('bilkolonne',),
'bilkolonnen': ('bilkolonne',),
'bilkolonnene': ('bilkolonne',),
'bilkolonner': ('bilkolonne',),
'bilkonsern': ('bilkonsern',),
'bilkonserna': ('bilkonsern',),
'bilkonsernene': ('bilkonsern',),
'bilkonserner': ('bilkonsern',),
'bilkonsernet': ('bilkonsern',),
'bilkontroll': ('bilkontroll',),
'bilkontrollen': ('bilkontroll',),
'bilkontrollene': ('bilkontroll',),
'bilkontroller': ('bilkontroll',),
'bilkø': ('bilkø',),
'bilkøen': ('bilkø',),
'bilkøene': ('bilkø',),
'bilkøer': ('bilkø',),
'billass': ('billass',),
'billassa': ('billass',),
'billassene': ('billass',),
'billasset': ('billass',),
'bille': ('bille',),
'billen': ('bille',),
'billene': ('bille',),
'biller': ('bille',),
'billedarkiv': ('billedarkiv',),
'billedarkiva': ('billedarkiv',),
'billedarkivene': ('billedarkiv',),
'billedarkiver': ('billedarkiv',),
'billedarkivet': ('billedarkiv',),
'billedband': ('billedband',),
'billedbanda': ('billedband',),
'billedbandene': ('billedband',),
'billedbandet': ('billedband',),
'billedbibel': ('billedbibel',),
'billedbibelen': ('billedbibel',),
'billedbiblene': ('billedbibel',),
'billedbibler': ('billedbibel',),
'billedbånd': ('billedbånd',),
'billedbånda': ('billedbånd',),
'billedbåndene': ('billedbånd',),
'billedbåndet': ('billedbånd',),
'billedgalleri': ('billedgalleri',),
'billedgalleria': ('billedgalleri',),
'billedgalleriene': ('billedgalleri',),
'billedgallerier': ('billedgalleri',),
'billedgalleriet': ('billedgalleri',),
'billedgåta': ('billedgåte',),
'billedgåte': ('billedgåte',),
'billedgåten': ('billedgåte',),
'billedgåtene': ('billedgåte',),
'billedgåter': ('billedgåte',),
'billedhogger': ('billedhogger',),
'billedhoggere': ('billedhogger',),
'billedhoggeren': ('billedhogger',),
'billedhoggerer': ('billedhogger',),
'billedhoggerne': ('billedhogger',),
'billedhoggerkunst': ('billedhoggerkunst',),
'billedhoggerkunsten': ('billedhoggerkunst',),
'billedhoggerkunstene': ('billedhoggerkunst',),
'billedhoggerkunster': ('billedhoggerkunst',),
'billedhugger': ('billedhugger',),
'billedhuggere': ('billedhugger',),
'billedhuggeren': ('billedhugger',),
'billedhuggerer': ('billedhugger',),
'billedhuggerne': ('billedhugger',),
'billedhuggerkunst': ('billedhuggerkunst',),
'billedhuggerkunsten': ('billedhuggerkunst',),
'billedhuggerkunstene': ('billedhuggerkunst',),
'billedhuggerkunster': ('billedhuggerkunst',),
'billedkunst': ('billedkunst',),
'billedkunsten': ('billedkunst',),
'billedkunstene': ('billedkunst',),
'billedkunster': ('billedkunst',),
'billedkunstner': ('billedkunstner',),
'billedkunstnere': ('billedkunstner',),
'billedkunstneren': ('billedkunstner',),
'billedkunstnerer': ('billedkunstner',),
'billedkunstnerne': ('billedkunstner',),
'billedreportasje': ('billedreportasje',),
'billedreportasjen': ('billedreportasje',),
'billedreportasjene': ('billedreportasje',),
'billedreportasjer': ('billedreportasje',),
'billedrør': ('billedrør',),
'billedrøra': ('billedrør',),
'billedrørene': ('billedrør',),
'billedrøret': ('billedrør',),
'billedsamband': ('billedsamband',),
'billedsambanda': ('billedsamband',),
'billedsambandene': ('billedsamband',),
'billedsambandet': ('billedsamband',),
'billedskarphet': ('billedskarphet',),
'billedskarpheta': ('billedskarphet',),
'billedskarpheten': ('billedskarphet',),
'billedskarphetene': ('billedskarphet',),
'billedskarpheter': ('billedskarphet',),
'billedskjærer': ('billedskjærer',),
'billedskjærere': ('billedskjærer',),
'billedskjæreren': ('billedskjærer',),
'billedskjærerer': ('billedskjærer',),
'billedskjærerne': ('billedskjærer',),
'billedskjæring': ('billedskjæring',),
'billedskjæringa': ('billedskjæring',),
'billedskjæringen': ('billedskjæring',),
'billedskjæringene': ('billedskjæring',),
'billedskjæringer': ('billedskjæring',),
'billedskrift': ('billedskrift',),
'billedskrifta': ('billedskrift',),
'billedskriften': ('billedskrift',),
'billedskriftene': ('billedskrift',),
'billedskrifter': ('billedskrift',),
'billedspråk': ('billedspråk',),
'billedspråka': ('billedspråk',),
'billedspråkene': ('billedspråk',),
'billedspråket': ('billedspråk',),
'billedstorm': ('billedstorm',),
'billedstormen': ('billedstorm',),
'billedstormene': ('billedstorm',),
'billedstormer': ('billedstorm',),
'billedstormer': ('billedstormer',),
'billedstormere': ('billedstormer',),
'billedstormeren': ('billedstormer',),
'billedstormerer': ('billedstormer',),
'billedstormerne': ('billedstormer',),
'billedtekst': ('billedtekst',),
'billedteksta': ('billedtekst',),
'billedteksten': ('billedtekst',),
'billedtekstene': ('billedtekst',),
'billedtekster': ('billedtekst',),
'billedtelegrafi': ('billedtelegrafi',),
'billedtelegrafien': ('billedtelegrafi',),
'billedtelegrafiene': ('billedtelegrafi',),
'billedtelegrafier': ('billedtelegrafi',),
'billedvev': ('billedvev',),
'billedveven': ('billedvev',),
'billedvevene': ('billedvev',),
'billedvever': ('billedvev',),
'billedveving': ('billedveving',),
'billedvevinga': ('billedveving',),
'billedvevingen': ('billedveving',),
'billedvevingene': ('billedveving',),
'billedvevinger': ('billedveving',),
'billedvevning': ('billedvevning',),
'billedvevninga': ('billedvevning',),
'billedvevningen': ('billedvevning',),
'billedvevningene': ('billedvevning',),
'billedvevninger': ('billedvevning',),
'billett': ('billett',),
'billetten': ('billett',),
'billettene': ('billett',),
'billetter': ('billett',),
'billetthefta': ('billetthefte',),
'billetthefte': ('billetthefte',),
'billettheftene': ('billetthefte',),
'billetthefter': ('billetthefte',),
'billettheftet': ('billetthefte',),
'billettkontor': ('billettkontor',),
'billettkontora': ('billettkontor',),
'billettkontorene': ('billettkontor',),
'billettkontorer': ('billettkontor',),
'billettkontoret': ('billettkontor',),
'billettkontroll': ('billettkontroll',),
'billettkontrollen': ('billettkontroll',),
'billettkontrollene': ('billettkontroll',),
'billettkontroller': ('billettkontroll',),
'billettluka': ('billettluke',),
'billettluke': ('billettluke',),
'billettluken': ('billettluke',),
'billettlukene': ('billettluke',),
'billettluker': ('billettluke',),
'billettpris': ('billettpris',),
'billettprisen': ('billettpris',),
'billettprisene': ('billettpris',),
'billettpriser': ('billettpris',),
'billettør': ('billettør',),
'billettøren': ('billettør',),
'billettørene': ('billettør',),
'billettører': ('billettør',),
'billigbillett': ('billigbillett',),
'billigbilletten': ('billigbillett',),
'billigbillettene': ('billigbillett',),
'billigbilletter': ('billigbillett',),
'billighet': ('billighet',),
'billigheta': ('billighet',),
'billigheten': ('billighet',),
'billighetene': ('billighet',),
'billigheter': ('billighet',),
'billighetserstatning': ('billighetserstatning',),
'billighetserstatninga': ('billighetserstatning',),
'billighetserstatningen': ('billighetserstatning',),
'billighetserstatningene': ('billighetserstatning',),
'billighetserstatninger': ('billighetserstatning',),
'billigsalg': ('billigsalg',),
'billigsalga': ('billigsalg',),
'billigsalgene': ('billigsalg',),
'billigsalget': ('billigsalg',),
'billigutgava': ('billigutgave',),
'billigutgave': ('billigutgave',),
'billigutgaven': ('billigutgave',),
'billigutgavene': ('billigutgave',),
'billigutgaver': ('billigutgave',),
'billion': ('billion',),
'billionen': ('billion',),
'billionene': ('billion',),
'billioner': ('billion',),
'billiondel': ('billiondel',),
'billiondelen': ('billiondel',),
'billiondelene': ('billiondel',),
'billiondeler': ('billiondel',),
'billøp': ('billøp',),
'billøpa': ('billøp',),
'billøpene': ('billøp',),
'billøpet': ('billøp',),
'bilmekaniker': ('bilmekaniker',),
'bilmekanikere': ('bilmekaniker',),
'bilmekanikeren': ('bilmekaniker',),
'bilmekanikerer': ('bilmekaniker',),
'bilmekanikerne': ('bilmekaniker',),
'bilmerka': ('bilmerke',),
'bilmerke': ('bilmerke',),
'bilmerkene': ('bilmerke',),
'bilmerker': ('bilmerke',),
'bilmerket': ('bilmerke',),
'bilnummer': ('bilnummer',),
'bilnummeret': ('bilnummer',),
'bilnumra': ('bilnummer',),
'bilnumre': ('bilnummer',),
'bilnumrene': ('bilnummer',),
'biloppretter': ('biloppretter',),
'bilopprettere': ('biloppretter',),
'biloppretteren': ('biloppretter',),
'biloppretterer': ('biloppretter',),
'biloppretterne': ('biloppretter',),
'bilpark': ('bilpark',),
'bilparken': ('bilpark',),
'bilparkene': ('bilpark',),
'bilparker': ('bilpark',),
'bilradio': ('bilradio',),
'bilradioen': ('bilradio',),
'bilradioene': ('bilradio',),
'bilradioer': ('bilradio',),
'bilreparatør': ('bilreparatør',),
'bilreparatøren': ('bilreparatør',),
'bilreparatørene': ('bilreparatør',),
'bilreparatører': ('bilreparatør',),
'biltilsyn': ('biltilsyn',),
'biltilsyna': ('biltilsyn',),
'biltilsynene': ('biltilsyn',),
'biltilsynet': ('biltilsyn',),
'biltog': ('biltog',),
'biltoga': ('biltog',),
'biltogene': ('biltog',),
'biltoget': ('biltog',),
'biltrafikk': ('biltrafikk',),
'biltrafikken': ('biltrafikk',),
'biltrafikkene': ('biltrafikk',),
'biltrafikker': ('biltrafikk',),
'bimetall': ('bimetall',),
'bimetalla': ('bimetall',),
'bimetallene': ('bimetall',),
'bimetaller': ('bimetall',),
'bimetallet': ('bimetall',),
'bimetallisme': ('bimetallisme',),
'bimetallismen': ('bimetallisme',),
'bimetallismene': ('bimetallisme',),
'bimetallismer': ('bimetallisme',),
'bind': ('bind',),
'binda': ('bind',),
'bindene': ('bind',),
'bindet': ('bind',),
'binde-s': ('binde-s',),
'binde-s-en': ('binde-s',),
'binde-s-ene': ('binde-s',),
'binde-s-er': ('binde-s',),
'bindeledd': ('bindeledd',),
'bindeledda': ('bindeledd',),
'bindeleddene': ('bindeledd',),
'bindeleddet': ('bindeledd',),
'bindemiddel': ('bindemiddel',),
'bindemiddelet': ('bindemiddel',),
'bindemidla': ('bindemiddel',),
'bindemidlene': ('bindemiddel',),
'bindemidler': ('bindemiddel',),
'bindemidlet': ('bindemiddel',),
'bindeord': ('bindeord',),
'bindeorda': ('bindeord',),
'bindeordene': ('bindeord',),
'bindeordet': ('bindeord',),
'binder': ('binder',),
'bindere': ('binder',),
'binderen': ('binder',),
'binderer': ('binder',),
'binderne': ('binder',),
'binderi': ('binderi',),
'binderia': ('binderi',),
'binderiene': ('binderi',),
'binderier': ('binderi',),
'binderiet': ('binderi',),
'binders': ('binders',),
'bindersen': ('binders',),
'bindersene': ('binders',),
'binderser': ('binders',),
'bindestrek': ('bindestrek',),
'bindestreken': ('bindestrek',),
'bindestrekene': ('bindestrek',),
'bindestreker': ('bindestrek',),
'bindevev': ('bindevev',),
'bindeveva': ('bindevev',),
'bindevevene': ('bindevev',),
'bindevevet': ('bindevev',),
'bindevokal': ('bindevokal',),
'bindevokalen': ('bindevokal',),
'bindevokalene': ('bindevokal',),
'bindevokaler': ('bindevokal',),
'binding': ('binding',),
'bindinga': ('binding',),
'bindingen': ('binding',),
'bindingene': ('binding',),
'bindinger': ('binding',),
'bindingsverk': ('bindingsverk',),
'bindingsverka': ('bindingsverk',),
'bindingsverkene': ('bindingsverk',),
'bindingsverker': ('bindingsverk',),
'bindingsverket': ('bindingsverk',),
'bindingsverkshus': ('bindingsverkshus',),
'bindingsverkshusa': ('bindingsverkshus',),
'bindingsverkshusene': ('bindingsverkshus',),
'bindingsverkshuset': ('bindingsverkshus',),
'bindsel': ('bindsel',),
'bindselet': ('bindsel',),
'bindsla': ('bindsel',),
'bindslene': ('bindsel',),
'bindsler': ('bindsel',),
'bindslet': ('bindsel',),
'bing': ('bing',),
'bingen': ('bing',),
'bingene': ('bing',),
'binger': ('bing',),
'binge': ('binge',),
'bingen': ('binge',),
'bingene': ('binge',),
'binger': ('binge',),
'bingefjøs': ('bingefjøs',),
'bingefjøsa': ('bingefjøs',),
'bingefjøsen': ('bingefjøs',),
'bingefjøsene': ('bingefjøs',),
'bingefjøset': ('bingefjøs',),
'bingfjøs': ('bingfjøs',),
'bingfjøsa': ('bingfjøs',),
'bingfjøsen': ('bingfjøs',),
'bingfjøsene': ('bingfjøs',),
'bingfjøset': ('bingfjøs',),
'bingo': ('bingo',),
'bingoen': ('bingo',),
'bingoene': ('bingo',),
'bingoer': ('bingo',),
'bingolokala': ('bingolokale',),
'bingolokale': ('bingolokale',),
'bingolokalene': ('bingolokale',),
'bingolokaler': ('bingolokale',),
'bingolokalet': ('bingolokale',),
'binna': ('binne',),
'binne': ('binne',),
'binnen': ('binne',),
'binnene': ('binne',),
'binner': ('binne',),
'binnsåle': ('binnsåle',),
'binnsålen': ('binnsåle',),
'binnsålene': ('binnsåle',),
'binnsåler': ('binnsåle',),
'binokkel': ('binokkel',),
'binokkelen': ('binokkel',),
'binoklene': ('binokkel',),
'binokler': ('binokkel',),
'binom': ('binom',),
'binoma': ('binom',),
'binomene': ('binom',),
'binomer': ('binom',),
'binomet': ('binom',),
'binomialformel': ('binomialformel',),
'binomialformelen': ('binomialformel',),
'binomialformlene': ('binomialformel',),
'binomialformler': ('binomialformel',),
'binyra': ('binyre',),
'binyre': ('binyre',),
'binyren': ('binyre',),
'binyrene': ('binyre',),
'binyrer': ('binyre',),
'binyret': ('binyre',),
'binæring': ('binæring',),
'binæringa': ('binæring',),
'binæringen': ('binæring',),
'binæringene': ('binæring',),
'binæringer': ('binæring',),
'biocid': ('biocid',),
'biocida': ('biocid',),
'biocidene': ('biocid',),
'biocider': ('biocid',),
'biocidet': ('biocid',),
'biodynamikk': ('biodynamikk',),
'biodynamikken': ('biodynamikk',),
'biodynamikkene': ('biodynamikk',),
'biodynamikker': ('biodynamikk',),
'biofysikk': ('biofysikk',),
'biofysikken': ('biofysikk',),
'biofysikkene': ('biofysikk',),
'biofysikker': ('biofysikk',),
'biograf': ('biograf',),
'biografen': ('biograf',),
'biografene': ('biograf',),
'biografer': ('biograf',),
'biografi': ('biografi',),
'biografien': ('biografi',),
'biografiene': ('biografi',),
'biografier': ('biografi',),
'biokjemi': ('biokjemi',),
'biokjemien': ('biokjemi',),
'biokjemiene': ('biokjemi',),
'biokjemier': ('biokjemi',),
'biokjemiker': ('biokjemiker',),
'biokjemikere': ('biokjemiker',),
'biokjemikeren': ('biokjemiker',),
'biokjemikerer': ('biokjemiker',),
'biokjemikerne': ('biokjemiker',),
'biolitt': ('biolitt',),
'biolitten': ('biolitt',),
'biolittene': ('biolitt',),
'biolitter': ('biolitt',),
'biolog': ('biolog',),
'biologen': ('biolog',),
'biologene': ('biolog',),
'biologer': ('biolog',),
'biologi': ('biologi',),
'biologien': ('biologi',),
'biologiene': ('biologi',),
'biologier': ('biologi',),
'biomasse': ('biomasse',),
'biomassen': ('biomasse',),
'biomassene': ('biomasse',),
'biomasser': ('biomasse',),
'biopsi': ('biopsi',),
'biopsien': ('biopsi',),
'biopsiene': ('biopsi',),
'biopsier': ('biopsi',),
'biorytme': ('biorytme',),
'biorytmen': ('biorytme',),
'biorytmene': ('biorytme',),
'biorytmer': ('biorytme',),
'biosfære': ('biosfære',),
'biosfæren': ('biosfære',),
'biosfærene': ('biosfære',),
'biosfærer': ('biosfære',),
'bioteknikk': ('bioteknikk',),
'bioteknikken': ('bioteknikk',),
'bioteknikkene': ('bioteknikk',),
'bioteknikker': ('bioteknikk',),
'bioteknologi': ('bioteknologi',),
'bioteknologien': ('bioteknologi',),
'bioteknologiene': ('bioteknologi',),
'bioteknologier': ('bioteknologi',),
'biotop': ('biotop',),
'biotopen': ('biotop',),
'biotopene': ('biotop',),
'biotoper': ('biotop',),
'biotyp': ('biotyp',),
'biotypen': ('biotyp',),
'biotypene': ('biotyp',),
'biotyper': ('biotyp',),
'biperson': ('biperson',),
'bipersonen': ('biperson',),
'bipersonene': ('biperson',),
'bipersoner': ('biperson',),
'biprodukt': ('biprodukt',),
'biprodukta': ('biprodukt',),
'biproduktene': ('biprodukt',),
'biprodukter': ('biprodukt',),
'biproduktet': ('biprodukt',),
'birgittiner': ('birgittiner',),
'birgittinere': ('birgittiner',),
'birgittineren': ('birgittiner',),
'birgittinerer': ('birgittiner',),
'birgittinerne': ('birgittiner',),
'birgittinerkloster': ('birgittinerkloster',),
'birgittinerklosteret': ('birgittinerkloster',),
'birgittinerklostra': ('birgittinerkloster',),
'birgittinerklostre': ('birgittinerkloster',),
'birgittinerklostrene': ('birgittinerkloster',),
'birgittinerklostret': ('birgittinerkloster',),
'birgittinermunk': ('birgittinermunk',),
'birgittinermunken': ('birgittinermunk',),
'birgittinermunkene': ('birgittinermunk',),
'birgittinermunker': ('birgittinermunk',),
'birgittinernonna': ('birgittinernonne',),
'birgittinernonne': ('birgittinernonne',),
'birgittinernonnen': ('birgittinernonne',),
'birgittinernonnene': ('birgittinernonne',),
'birgittinernonner': ('birgittinernonne',),
'birgittinerorden': ('birgittinerorden',),
'birgittinerordenen': ('birgittinerorden',),
'birgittinerordenene': ('birgittinerorden',),
'birgittinerordener': ('birgittinerorden',),
'birkebeiner': ('birkebeiner',),
'birkebeinere': ('birkebeiner',),
'birkebeineren': ('birkebeiner',),
'birkebeinerer': ('birkebeiner',),
'birkebeinerne': ('birkebeiner',),
'birolla': ('birolle',),
'birolle': ('birolle',),
'birollen': ('birolle',),
'birollene': ('birolle',),
'biroller': ('birolle',),
'birøkt': ('birøkt',),
'birøkta': ('birøkt',),
'birøkten': ('birøkt',),
'birøktene': ('birøkt',),
'birøkter': ('birøkt',),
'birøkter': ('birøkter',),
'birøktere': ('birøkter',),
'birøkteren': ('birøkter',),
'birøkterer': ('birøkter',),
'birøkterne': ('birøkter',),
'bisak': ('bisak',),
'bisaka': ('bisak',),
'bisaken': ('bisak',),
'bisakene': ('bisak',),
'bisaker': ('bisak',),
'bisam': ('bisam',),
'bisamen': ('bisam',),
'bisamene': ('bisam',),
'bisamer': ('bisam',),
'bisamfunn': ('bisamfunn',),
'bisamfunna': ('bisamfunn',),
'bisamfunnene': ('bisamfunn',),
'bisamfunnet': ('bisamfunn',),
'bisamkåpa': ('bisamkåpe',),
'bisamkåpe': ('bisamkåpe',),
'bisamkåpen': ('bisamkåpe',),
'bisamkåpene': ('bisamkåpe',),
'bisamkåper': ('bisamkåpe',),
'bisamrotta': ('bisamrotte',),
'bisamrotte': ('bisamrotte',),
'bisamrotten': ('bisamrotte',),
'bisamrottene': ('bisamrotte',),
'bisamrotter': ('bisamrotte',),
'bisamskinn': ('bisamskinn',),
'bisamskinna': ('bisamskinn',),
'bisamskinnene': ('bisamskinn',),
'bisamskinnet': ('bisamskinn',),
'bisarreri': ('bisarreri',),
'bisarreria': ('bisarreri',),
'bisarreriene': ('bisarreri',),
'bisarrerier': ('bisarreri',),
'bisarreriet': ('bisarreri',),
'biscene': ('biscene',),
'biscenen': ('biscene',),
'biscenene': ('biscene',),
'biscener': ('biscene',),
'bise': ('bise',),
'bisen': ('bise',),
'bisene': ('bise',),
'biser': ('bise',),
'biseksualitet': ('biseksualitet',),
'biseksualiteten': ('biseksualitet',),
'biseksualitetene': ('biseksualitet',),
'biseksualiteter': ('biseksualitet',),
'bisetning': ('bisetning',),
'bisetninga': ('bisetning',),
'bisetningen': ('bisetning',),
'bisetningene': ('bisetning',),
'bisetninger': ('bisetning',),
'bisettelse': ('bisettelse',),
'bisettelsen': ('bisettelse',),
'bisettelsene': ('bisettelse',),
'bisettelser': ('bisettelse',),
'bisitter': ('bisitter',),
'bisittere': ('bisitter',),
'bisitteren': ('bisitter',),
'bisitterer': ('bisitter',),
'bisitterne': ('bisitter',),
'bisk': ('bisk',),
'bisken': ('bisk',),
'biskene': ('bisk',),
'bisker': ('bisk',),
'biskop': ('biskop',),
'biskopen': ('biskop',),
'biskopene': ('biskop',),
'biskoper': ('biskop',),
'biskuit': ('biskuit',),
'biskuiten': ('biskuit',),
'biskuitene': ('biskuit',),
'biskuiter': ('biskuit',),
'bislag': ('bislag',),
'bislaga': ('bislag',),
'bislagene': ('bislag',),
'bislaget': ('bislag',),
'bismak': ('bismak',),
'bismaken': ('bismak',),
'bismakene': ('bismak',),
'bismaker': ('bismak',),
'bismer': ('bismer',),
'bismere': ('bismer',),
'bismeren': ('bismer',),
'bismerer': ('bismer',),
'bismerne': ('bismer',),
'bismerkrok': ('bismerkrok',),
'bismerkroken': ('bismerkrok',),
'bismerkrokene': ('bismerkrok',),
'bismerkroker': ('bismerkrok',),
'bismerlodd': ('bismerlodd',),
'bismerlodda': ('bismerlodd',),
'bismerloddene': ('bismerlodd',),
'bismerlodder': ('bismerlodd',),
'bismerloddet': ('bismerlodd',),
'bismerpund': ('bismerpund',),
'bismerpunda': ('bismerpund',),
'bismerpundene': ('bismerpund',),
'bismerpundet': ('bismerpund',),
'bismerstang': ('bismerstang',),
'bismerstanga': ('bismerstang',),
'bismerstangen': ('bismerstang',),
'bismerstengene': ('bismerstang',),
'bismerstenger': ('bismerstang',),
'bismervekt': ('bismervekt',),
'bismervekta': ('bismervekt',),
'bismervekten': ('bismervekt',),
'bismervektene': ('bismervekt',),
'bismervekter': ('bismervekt',),
'bisol': ('bisol',),
'bisola': ('bisol',),
'bisolen': ('bisol',),
'bisolene': ('bisol',),
'bisoler': ('bisol',),
'bison': ('bison',),
'bisonen': ('bison',),
'bisonene': ('bison',),
'bisoner': ('bison',),
'bisonokse': ('bisonokse',),
'bisonoksen': ('bisonokse',),
'bisonoksene': ('bisonokse',),
'bisonokser': ('bisonokse',),
'bispedømma': ('bispedømme',),
'bispedømme': ('bispedømme',),
'bispedømmene': ('bispedømme',),
'bispedømmer': ('bispedømme',),
'bispedømmet': ('bispedømme',),
'bispedømmeråd': ('bispedømmeråd',),
'bispedømmeråda': ('bispedømmeråd',),
'bispedømmerådene': ('bispedømmeråd',),
'bispedømmerådet': ('bispedømmeråd',),
'bispeembeta': ('bispeembete',),
'bispeembete': ('bispeembete',),
'bispeembetene': ('bispeembete',),
'bispeembeter': ('bispeembete',),
'bispeembetet': ('bispeembete',),
'bispegard': ('bispegard',),
'bispegarden': ('bispegard',),
'bispegardene': ('bispegard',),
'bispegarder': ('bispegard',),
'bispegård': ('bispegård',),
'bispegården': ('bispegård',),
'bispegårdene': ('bispegård',),
'bispegårder': ('bispegård',),
'bispehua': ('bispehue',),
'bispehue': ('bispehue',),
'bispehuen': ('bispehue',),
'bispehuene': ('bispehue',),
'bispehuer': ('bispehue',),
'bispehuva': ('bispehuve',),
'bispehuve': ('bispehuve',),
'bispehuven': ('bispehuve',),
'bispehuvene': ('bispehuve',),
'bispehuver': ('bispehuve',),
'bispelua': ('bispelue',),
'bispelue': ('bispelue',),
'bispeluen': ('bispelue',),
'bispeluene': ('bispelue',),
'bispeluer': ('bispelue',),
'bispelua': ('bispelue',),
'bispelue': ('bispelue',),
'bispeluen': ('bispelue',),
'bispeluene': ('bispelue',),
'bispeluer': ('bispelue',),
'bispeluva': ('bispeluve',),
'bispeluve': ('bispeluve',),
'bispeluven': ('bispeluve',),
'bispeluvene': ('bispeluve',),
'bispeluver': ('bispeluve',),
'bispeluva': ('bispeluve',),
'bispeluve': ('bispeluve',),
'bispeluven': ('bispeluve',),
'bispeluvene': ('bispeluve',),
'bispeluver': ('bispeluve',),
'bispeordinasjon': ('bispeordinasjon',),
'bispeordinasjonen': ('bispeordinasjon',),
'bispeordinasjonene': ('bispeordinasjon',),
'bispeordinasjoner': ('bispeordinasjon',),
'bispering': ('bispering',),
'bisperingen': ('bispering',),
'bisperingene': ('bispering',),
'bisperinger': ('bispering',),
'bispeseta': ('bispesete',),
'bispesete': ('bispesete',),
'bispesetene': ('bispesete',),
'bispeseter': ('bispesete',),
'bispesetet': ('bispesete',),
'bispestol': ('bispestol',),
'bispestolen': ('bispestol',),
'bispestolene': ('bispestol',),
'bispestoler': ('bispestol',),
'bispevisitas': ('bispevisitas',),
'bispevisitasen': ('bispevisitas',),
'bispevisitasene': ('bispevisitas',),
'bispevisitaser': ('bispevisitas',),
'bissevov': ('bissevov',),
'bissevoven': ('bissevov',),
'bissevovene': ('bissevov',),
'bissevover': ('bissevov',),
'bistand': ('bistand',),
'bistanden': ('bistand',),
'bistandene': ('bistand',),
'bistander': ('bistand',),
'bistandsminister': ('bistandsminister',),
'bistandsministere': ('bistandsminister',),
'bistandsministeren': ('bistandsminister',),
'bistandsministerer': ('bistandsminister',),
'bistandsministerne': ('bistandsminister',),
'bistandsministre': ('bistandsminister',),
'bistandsministrene': ('bistandsminister',),
'bistandsministrer': ('bistandsminister',),
'bistandsplikt': ('bistandsplikt',),
'bistandsplikta': ('bistandsplikt',),
'bistandsplikten': ('bistandsplikt',),
'bistandspliktene': ('bistandsplikt',),
'bistandsplikter': ('bistandsplikt',),
'bistikk': ('bistikk',),
'bistikka': ('bistikk',),
'bistikkene': ('bistikk',),
'bistikket': ('bistikk',),
'bistilling': ('bistilling',),
'bistillinga': ('bistilling',),
'bistillingen': ('bistilling',),
'bistillingene': ('bistilling',),
'bistillinger': ('bistilling',),
'bistro': ('bistro',),
'bistroen': ('bistro',),
'bistroene': ('bistro',),
'bistroer': ('bistro',),
'bisverm': ('bisverm',),
'bisvermen': ('bisverm',),
'bisvermene': ('bisverm',),
'bisvermer': ('bisverm',),
'bit': ('bit',),
'biten': ('bit',),
'bitene': ('bit',),
'biter': ('bit',),
'bits': ('bit',),
'bit': ('bit',),
'biten': ('bit',),
'bitene': ('bit',),
'biter': ('bit',),
'bite': ('bite',),
'biten': ('bite',),
'bitene': ('bite',),
'biter': ('bite',),
'bitemunn': ('bitemunn',),
'bitemunnen': ('bitemunn',),
'bitemunnene': ('bitemunn',),
'bitemunner': ('bitemunn',),
'bitestikkel': ('bitestikkel',),
'bitestikkelen': ('bitestikkel',),
'bitestiklene': ('bitestikkel',),
'bitestikler': ('bitestikkel',),
'biteti': ('biteti',),
'bitetia': ('biteti',),
'bitetiene': ('biteti',),
'bitetiet': ('biteti',),
'biting': ('biting',),
'bitinga': ('biting',),
'bitingen': ('biting',),
'bitingene': ('biting',),
'bitjern': ('bitjern',),
'bitjerna': ('bitjern',),
'bitjernene': ('bitjern',),
'bitjernet': ('bitjern',),
'bitrykk': ('bitrykk',),
'bitrykka': ('bitrykk',),
'bitrykkene': ('bitrykk',),
'bitrykket': ('bitrykk',),
'bitt': ('bitt',),
'bitta': ('bitt',),
'bittene': ('bitt',),
'bittet': ('bitt',),
'bittekonvall': ('bittekonvall',),
'bittekonvallen': ('bittekonvall',),
'bittekonvallene': ('bittekonvall',),
'bittekonvaller': ('bittekonvall',),
'bitter': ('bitter',),
'bittere': ('bitter',),
'bitteren': ('bitter',),
'bitterer': ('bitter',),
'bitterne': ('bitter',),
'bitterhet': ('bitterhet',),
'bitterheta': ('bitterhet',),
'bitterheten': ('bitterhet',),
'bitterhetene': ('bitterhet',),
'bitterheter': ('bitterhet',),
'bitterstoff': ('bitterstoff',),
'bitterstoffa': ('bitterstoff',),
'bitterstoffene': ('bitterstoff',),
'bitterstoffer': ('bitterstoff',),
'bitterstoffet': ('bitterstoff',),
'bittervin': ('bittervin',),
'bittervinen': ('bittervin',),
'bittervinene': ('bittervin',),
'bitterviner': ('bittervin',),
'bitumen': ('bitumen',),
'bitumena': ('bitumen',),
'bitumenene': ('bitumen',),
'bitumenet': ('bitumen',),
'bivirkning': ('bivirkning',),
'bivirkninga': ('bivirkning',),
'bivirkningen': ('bivirkning',),
'bivirkningene': ('bivirkning',),
'bivirkninger': ('bivirkning',),
'bivoks': ('bivoks',),
'bivoksa': ('bivoks',),
'bivoksen': ('bivoks',),
'bivoksene': ('bivoks',),
'bivokser': ('bivoks',),
'bivokset': ('bivoks',),
'bivuakk': ('bivuakk',),
'bivuakken': ('bivuakk',),
'bivuakkene': ('bivuakk',),
'bivuakker': ('bivuakk',),
'bjeff': ('bjeff',),
'bjeffa': ('bjeff',),
'bjeffene': ('bjeff',),
'bjeffet': ('bjeff',),
'bjekso': ('bjekso',),
'bjeksoen': ('bjekso',),
'bjeksoene': ('bjekso',),
'bjeksoer': ('bjekso',),
'bjelke': ('bjelke',),
'bjelken': ('bjelke',),
'bjelkene': ('bjelke',),
'bjelker': ('bjelke',),
'bjelkeloft': ('bjelkeloft',),
'bjelkelofta': ('bjelkeloft',),
'bjelkeloftene': ('bjelkeloft',),
'bjelkeloftet': ('bjelkeloft',),
'bjelketak': ('bjelketak',),
'bjelketaka': ('bjelketak',),
'bjelketakene': ('bjelketak',),
'bjelketaket': ('bjelketak',),
'bjella': ('bjelle',),
'bjelle': ('bjelle',),
'bjellen': ('bjelle',),
'bjellene': ('bjelle',),
'bjeller': ('bjelle',),
'bjella': ('bjelle',),
'bjelle': ('bjelle',),
'bjellen': ('bjelle',),
'bjellene': ('bjelle',),
'bjeller': ('bjelle',),
'bjelleblom': ('bjelleblom',),
'bjelleblommen': ('bjelleblom',),
'bjelleblommene': ('bjelleblom',),
'bjelleblommer': ('bjelleblom',),
'bjelleblom': ('bjelleblom',),
'bjelleblommen': ('bjelleblom',),
'bjelleblommene': ('bjelleblom',),
'bjelleblommer': ('bjelleblom',),
'bjelleklang': ('bjelleklang',),
'bjelleklangen': ('bjelleklang',),
'bjelleklangene': ('bjelleklang',),
'bjelleklanger': ('bjelleklang',),
'bjelleklang': ('bjelleklang',),
'bjelleklangen': ('bjelleklang',),
'bjelleklangene': ('bjelleklang',),
'bjelleklanger': ('bjelleklang',),
'bjelleklave': ('bjelleklave',),
'bjelleklaven': ('bjelleklave',),
'bjelleklavene': ('bjelleklave',),
'bjelleklaver': ('bjelleklave',),
'bjelleklave': ('bjelleklave',),
'bjelleklaven': ('bjelleklave',),
'bjelleklavene': ('bjelleklave',),
'bjelleklaver': ('bjelleklave',),
'bjelleku': ('bjelleku',),
'bjellekua': ('bjelleku',),
'bjellekuen': ('bjelleku',),
'bjellekuene': ('bjelleku',),
'bjellekuer': ('bjelleku',),
'bjellekyr': ('bjelleku',),
'bjellekyrne': ('bjelleku',),
'bjelleku': ('bjelleku',),
'bjellekua': ('bjelleku',),
'bjellekuen': ('bjelleku',),
'bjellekuene': ('bjelleku',),
'bjellekuer': ('bjelleku',),
'bjellekyr': ('bjelleku',),
'bjellekyrne': ('bjelleku',),
'bjellesau': ('bjellesau',),
'bjellesauen': ('bjellesau',),
'bjellesauene': ('bjellesau',),
'bjellesauer': ('bjellesau',),
'bjellesau': ('bjellesau',),
'bjellesauen': ('bjellesau',),
'bjellesauene': ('bjellesau',),
'bjellesauer': ('bjellesau',),
'bjerk': ('bjerk',),
'bjerka': ('bjerk',),
'bjerken': ('bjerk',),
'bjerkene': ('bjerk',),
'bjerker': ('bjerk',),
'bjerkebelta': ('bjerkebelte',),
'bjerkebelte': ('bjerkebelte',),
'bjerkebeltene': ('bjerkebelte',),
'bjerkebelter': ('bjerkebelte',),
'bjerkebeltet': ('bjerkebelte',),
'bjerkefamilie': ('bjerkefamilie',),
'bjerkefamilien': ('bjerkefamilie',),
'bjerkefamiliene': ('bjerkefamilie',),
'bjerkefamilier': ('bjerkefamilie',),
'bjerkefink': ('bjerkefink',),
'bjerkefinken': ('bjerkefink',),
'bjerkefinkene': ('bjerkefink',),
'bjerkefinker': ('bjerkefink',),
'bjerkeli': ('bjerkeli',),
'bjerkelia': ('bjerkeli',),
'bjerkelien': ('bjerkeli',),
'bjerkeliene': ('bjerkeli',),
'bjerkelier': ('bjerkeli',),
'bjerkeris': ('bjerkeris',),
'bjerkerisa': ('bjerkeris',),
'bjerkerisene': ('bjerkeris',),
'bjerkeriset': ('bjerkeris',),
'bjerkestamme': ('bjerkestamme',),
'bjerkestammen': ('bjerkestamme',),
'bjerkestammene': ('bjerkestamme',),
'bjerkestammer': ('bjerkestamme',),
'bjerkeved': ('bjerkeved',),
'bjerkeveden': ('bjerkeved',),
'bjerkevedene': ('bjerkeved',),
'bjerkeveder': ('bjerkeved',),
'bjølla': ('bjølle',),
'bjølle': ('bjølle',),
'bjøllen': ('bjølle',),
'bjøllene': ('bjølle',),
'bjøller': ('bjølle',),
'bjølla': ('bjølle',),
'bjølle': ('bjølle',),
'bjøllen': ('bjølle',),
'bjøllene': ('bjølle',),
'bjøller': ('bjølle',),
'bjølleblom': ('bjølleblom',),
'bjølleblommen': ('bjølleblom',),
'bjølleblommene': ('bjølleblom',),
'bjølleblommer': ('bjølleblom',),
'bjølleblom': ('bjølleblom',),
'bjølleblommen': ('bjølleblom',),
'bjølleblommene': ('bjølleblom',),
'bjølleblommer': ('bjølleblom',),
'bjølleklang': ('bjølleklang',),
'bjølleklangen': ('bjølleklang',),
'bjølleklangene': ('bjølleklang',),
'bjølleklanger': ('bjølleklang',),
'bjølleklang': ('bjølleklang',),
'bjølleklangen': ('bjølleklang',),
'bjølleklangene': ('bjølleklang',),
'bjølleklanger': ('bjølleklang',),
'bjølleklave': ('bjølleklave',),
'bjølleklaven': ('bjølleklave',),
'bjølleklavene': ('bjølleklave',),
'bjølleklaver': ('bjølleklave',),
'bjølleklave': ('bjølleklave',),
'bjølleklaven': ('bjølleklave',),
'bjølleklavene': ('bjølleklave',),
'bjølleklaver': ('bjølleklave',),
'bjølleku': ('bjølleku',),
'bjøllekua': ('bjølleku',),
'bjøllekuene': ('bjølleku',),
'bjøllekuer': ('bjølleku',),
'bjøllekyr': ('bjølleku',),
'bjøllekyrne': ('bjølleku',),
'bjølleku': ('bjølleku',),
'bjøllekua': ('bjølleku',),
'bjøllekuene': ('bjølleku',),
'bjøllekuer': ('bjølleku',),
'bjøllekyr': ('bjølleku',),
'bjøllekyrne': ('bjølleku',),
'bjøllesau': ('bjøllesau',),
'bjøllesauen': ('bjøllesau',),
'bjøllesauene': ('bjøllesau',),
'bjøllesauer': ('bjøllesau',),
'bjøllesau': ('bjøllesau',),
'bjøllesauen': ('bjøllesau',),
'bjøllesauene': ('bjøllesau',),
'bjøllesauer': ('bjøllesau',),
'bjørk': ('bjørk',),
'bjørka': ('bjørk',),
'bjørken': ('bjørk',),
'bjørkene': ('bjørk',),
'bjørker': ('bjørk',),
'bjørkebelta': ('bjørkebelte',),
'bjørkebelte': ('bjørkebelte',),
'bjørkebeltene': ('bjørkebelte',),
'bjørkebelter': ('bjørkebelte',),
'bjørkebeltet': ('bjørkebelte',),
'bjørkefamilie': ('bjørkefamilie',),
'bjørkefamilien': ('bjørkefamilie',),
'bjørkefamiliene': ('bjørkefamilie',),
'bjørkefamilier': ('bjørkefamilie',),
'bjørkefink': ('bjørkefink',),
'bjørkefinken': ('bjørkefink',),
'bjørkefinkene': ('bjørkefink',),
'bjørkefinker': ('bjørkefink',),
'bjørkeli': ('bjørkeli',),
'bjørkelia': ('bjørkeli',),
'bjørkelien': ('bjørkeli',),
'bjørkeliene': ('bjørkeli',),
'bjørkelier': ('bjørkeli',),
'bjørkeris': ('bjørkeris',),
'bjørkerisa': ('bjørkeris',),
'bjørkerisene': ('bjørkeris',),
'bjørkeriset': ('bjørkeris',),
'bjørkestamme': ('bjørkestamme',),
'bjørkestammen': ('bjørkestamme',),
'bjørkestammene': ('bjørkestamme',),
'bjørkestammer': ('bjørkestamme',),
'bjørkeved': ('bjørkeved',),
'bjørkeveden': ('bjørkeved',),
'bjørkevedene': ('bjørkeved',),
'bjørkeveder': ('bjørkeved',),
'bjørn': ('bjørn',),
'bjørnen': ('bjørn',),
'bjørnene': ('bjørn',),
'bjørner': ('bjørn',),
'bjørnebinna': ('bjørnebinne',),
'bjørnebinne': ('bjørnebinne',),
'bjørnebinnen': ('bjørnebinne',),
'bjørnebinnene': ('bjørnebinne',),
'bjørnebinner': ('bjørnebinne',),
'bjørnebær': ('bjørnebær',),
'bjørnebæra': ('bjørnebær',),
'bjørnebærene': ('bjørnebær',),
'bjørnebæret': ('bjørnebær',),
'bjørnegrav': ('bjørnegrav',),
'bjørnegrava': ('bjørnegrav',),
'bjørnegraven': ('bjørnegrav',),
'bjørnegravene': ('bjørnegrav',),
'bjørnegraver': ('bjørnegrav',),
'bjørnehi': ('bjørnehi',),
'bjørnehia': ('bjørnehi',),
'bjørnehiene': ('bjørnehi',),
'bjørnehiet': ('bjørnehi',),
'bjørnekam': ('bjørnekam',),
'bjørnekammen': ('bjørnekam',),
'bjørnekammene': ('bjørnekam',),
'bjørnekammer': ('bjørnekam',),
'bjørnekjeks': ('bjørnekjeks',),
'bjørnekjeksen': ('bjørnekjeks',),
'bjørnekjeksene': ('bjørnekjeks',),
'bjørnekjekser': ('bjørnekjeks',),
'bjørneklo': ('bjørneklo',),
'bjørnekloa': ('bjørneklo',),
'bjørnekloen': ('bjørneklo',),
'bjørneklør': ('bjørneklo',),
'bjørneklørne': ('bjørneklo',),
'bjørnemose': ('bjørnemose',),
'bjørnemosen': ('bjørnemose',),
'bjørnemosene': ('bjørnemose',),
'bjørnemoser': ('bjørnemose',),
'bjørneskinn': ('bjørneskinn',),
'bjørneskinna': ('bjørneskinn',),
'bjørneskinnene': ('bjørneskinn',),
'bjørneskinnet': ('bjørneskinn',),
'bjørneskinnslua': ('bjørneskinnslue',),
'bjørneskinnslue': ('bjørneskinnslue',),
'bjørneskinnsluen': ('bjørneskinnslue',),
'bjørneskinnsluene': ('bjørneskinnslue',),
'bjørneskinnsluer': ('bjørneskinnslue',),
'bjørneskinnsluva': ('bjørneskinnsluve',),
'bjørneskinnsluve': ('bjørneskinnsluve',),
'bjørneskinnsluven': ('bjørneskinnsluve',),
'bjørneskinnsluvene': ('bjørneskinnsluve',),
'bjørneskinnsluver': ('bjørneskinnsluve',),
'bjørnestamme': ('bjørnestamme',),
'bjørnestammen': ('bjørnestamme',),
'bjørnestammene': ('bjørnestamme',),
'bjørnestammer': ('bjørnestamme',),
'bjørnetjeneste': ('bjørnetjeneste',),
'bjørnetjenesten': ('bjørnetjeneste',),
'bjørnetjenestene': ('bjørnetjeneste',),
'bjørnetjenester': ('bjørnetjeneste',),
'bjørnunge': ('bjørnunge',),
'bjørnungen': ('bjørnunge',),
'bjørnungene': ('bjørnunge',),
'bjørnunger': ('bjørnunge',),
'bla-bla': ('bla-bla',),
'bla-blaa': ('bla-bla',),
'bla-blaene': ('bla-bla',),
'bla-blaet': ('bla-bla',),
'blackout': ('blackout',),
'blackouten': ('blackout',),
'blackoutene': ('blackout',),
'blackouter': ('blackout',),
'blad': ('blad',),
'blada': ('blad',),
'bladene': ('blad',),
'blader': ('blad',),
'bladet': ('blad',),
'bladan': ('bladan',),
'bladana': ('bladan',),
'bladanene': ('bladan',),
'bladanet': ('bladan',),
'bladbille': ('bladbille',),
'bladbillen': ('bladbille',),
'bladbillene': ('bladbille',),
'bladbiller': ('bladbille',),
'bladekspedisjon': ('bladekspedisjon',),
'bladekspedisjonen': ('bladekspedisjon',),
'bladekspedisjonene': ('bladekspedisjon',),
'bladekspedisjoner': ('bladekspedisjon',),
'bladfot': ('bladfot',),
'bladfoten': ('bladfot',),
'bladføttene': ('bladfot',),
'bladføtter': ('bladfot',),
'bladgrønt': ('bladgrønt',),
'bladgull': ('bladgull',),
'bladgulla': ('bladgull',),
'bladgullene': ('bladgull',),
'bladgullet': ('bladgull',),
'bladkjeller': ('bladkjeller',),
'bladkjellere': ('bladkjeller',),
'bladkjelleren': ('bladkjeller',),
'bladkjellerer': ('bladkjeller',),
'bladkjellerne': ('bladkjeller',),
'bladkjøtt': ('bladkjøtt',),
'bladkjøtta': ('bladkjøtt',),
'bladkjøttene': ('bladkjøtt',),
'bladkjøttet': ('bladkjøtt',),
'bladlus': ('bladlus',),
'bladlusa': ('bladlus',),
'bladlusen': ('bladlus',),
'bladlusene': ('bladlus',),
'bladmage': ('bladmage',),
'bladmagen': ('bladmage',),
'bladmagene': ('bladmage',),
'bladmager': ('bladmage',),
'bladmave': ('bladmave',),
'bladmaven': ('bladmave',),
'bladmavene': ('bladmave',),
'bladmaver': ('bladmave',),
'bladmetall': ('bladmetall',),
'bladmetalla': ('bladmetall',),
'bladmetallene': ('bladmetall',),
'bladmetaller': ('bladmetall',),
'bladmetallet': ('bladmetall',),
'bladnerve': ('bladnerve',),
'bladnerven': ('bladnerve',),
'bladnervene': ('bladnerve',),
'bladnerver': ('bladnerve',),
'bladsalat': ('bladsalat',),
'bladsalaten': ('bladsalat',),
'bladsalatene': ('bladsalat',),
'bladsalater': ('bladsalat',),
'bladskjede': ('bladskjede',),
'bladskjeden': ('bladskjede',),
'bladskjedene': ('bladskjede',),
'bladskjeder': ('bladskjede',),
'bladslir': ('bladslir',),
'bladslira': ('bladslir',),
'bladsliren': ('bladslir',),
'bladslirene': ('bladslir',),
'bladslirer': ('bladslir',),
'bladslira': ('bladslire',),
'bladslire': ('bladslire',),
'bladsliren': ('bladslire',),
'bladslirene': ('bladslire',),
'bladslirer': ('bladslire',),
'bladstilk': ('bladstilk',),
'bladstilken': ('bladstilk',),
'bladstilkene': ('bladstilk',),
'bladstilker': ('bladstilk',),
'bladsølv': ('bladsølv',),
'bladsølva': ('bladsølv',),
'bladsølvene': ('bladsølv',),
'bladsølvet': ('bladsølv',),
'bladtobakk': ('bladtobakk',),
'bladtobakken': ('bladtobakk',),
'bladtobakkene': ('bladtobakk',),
'bladtobakker': ('bladtobakk',),
'bladvott': ('bladvott',),
'bladvotten': ('bladvott',),
'bladvottene': ('bladvott',),
'bladvotter': ('bladvott',),
'blaff': ('blaff',),
'blaffen': ('blaff',),
'blaffene': ('blaff',),
'blaffer': ('blaff',),
'blaff': ('blaff',),
'blaffa': ('blaff',),
'blaffene': ('blaff',),
'blaffet': ('blaff',),
'blakkert': ('blakkert',),
'blakkerten': ('blakkert',),
'blakkertene': ('blakkert',),
'blakkerter': ('blakkert',),
'blamasje': ('blamasje',),
'blamasjen': ('blamasje',),
'blamasjene': ('blamasje',),
'blamasjer': ('blamasje',),
'blanda': ('blande',),
'blande': ('blande',),
'blanden': ('blande',),
'blandene': ('blande',),
'blander': ('blande',),
'blandeapparat': ('blandeapparat',),
'blandeapparata': ('blandeapparat',),
'blandeapparatene': ('blandeapparat',),
'blandeapparater': ('blandeapparat',),
'blandeapparatet': ('blandeapparat',),
'blandebatteri': ('blandebatteri',),
'blandebatteria': ('blandebatteri',),
'blandebatteriene': ('blandebatteri',),
'blandebatterier': ('blandebatteri',),
'blandebatteriet': ('blandebatteri',),
'blandemaskin': ('blandemaskin',),
'blandemaskina': ('blandemaskin',),
'blandemaskinen': ('blandemaskin',),
'blandemaskinene': ('blandemaskin',),
'blandemaskiner': ('blandemaskin',),
'blander': ('blander',),
'blandere': ('blander',),
'blanderen': ('blander',),
'blanderer': ('blander',),
'blanderne': ('blander',),
'blandevann': ('blandevann',),
'blandevanna': ('blandevann',),
'blandevannene': ('blandevann',),
'blandevannet': ('blandevann',),
'blandevatn': ('blandevatn',),
'blandevatna': ('blandevatn',),
'blandevatnene': ('blandevatn',),
'blandevatnet': ('blandevatn',),
'blandfrø': ('blandfrø',),
'blandfrøa': ('blandfrø',),
'blandfrøene': ('blandfrø',),
'blandfrøet': ('blandfrø',),
'blanding': ('blanding',),
'blandinga': ('blanding',),
'blandingen': ('blanding',),
'blandingene': ('blanding',),
'blandinger': ('blanding',),
'blandingsdrikk': ('blandingsdrikk',),
'blandingsdrikken': ('blandingsdrikk',),
'blandingsdrikkene': ('blandingsdrikk',),
'blandingsdrikker': ('blandingsdrikk',),
'blandingsfarge': ('blandingsfarge',),
'blandingsfargen': ('blandingsfarge',),
'blandingsfargene': ('blandingsfarge',),
'blandingsfarger': ('blandingsfarge',),
'blandingsfolk': ('blandingsfolk',),
'blandingsfolka': ('blandingsfolk',),
'blandingsfolkene': ('blandingsfolk',),
'blandingsfolket': ('blandingsfolk',),
'blandingsforhold': ('blandingsforhold',),
'blandingsforholda': ('blandingsforhold',),
'blandingsforholdene': ('blandingsforhold',),
'blandingsforholdet': ('blandingsforhold',),
'blandingsføra': ('blandingsføre',),
'blandingsføre': ('blandingsføre',),
'blandingsførene': ('blandingsføre',),
'blandingsfører': ('blandingsføre',),
'blandingsføret': ('blandingsføre',),
'blandingsrase': ('blandingsrase',),
'blandingsrasen': ('blandingsrase',),
'blandingsrasene': ('blandingsrase',),
'blandingsraser': ('blandingsrase',),
'blandingsskog': ('blandingsskog',),
'blandingsskogen': ('blandingsskog',),
'blandingsskogene': ('blandingsskog',),
'blandingsskoger': ('blandingsskog',),
'blandingsspråk': ('blandingsspråk',),
'blandingsspråka': ('blandingsspråk',),
'blandingsspråkene': ('blandingsspråk',),
'blandingsspråket': ('blandingsspråk',),
'blandingsøkonomi': ('blandingsøkonomi',),
'blandingsøkonomien': ('blandingsøkonomi',),
'blandingsøkonomiene': ('blandingsøkonomi',),
'blandingsøkonomier': ('blandingsøkonomi',),
'blandkorn': ('blandkorn',),
'blandkorna': ('blandkorn',),
'blandkornene': ('blandkorn',),
'blandkornet': ('blandkorn',),
'blankett': ('blankett',),
'blanketten': ('blankett',),
'blankettene': ('blankett',),
'blanketter': ('blankett',),
'blankis': ('blankis',),
'blankisen': ('blankis',),
'blankisene': ('blankis',),
'blankiser': ('blankis',),
'blanklaks': ('blanklaks',),
'blanklaksen': ('blanklaks',),
'blanklaksene': ('blanklaks',),
'blanklakser': ('blanklaks',),
'blankoaksept': ('blankoaksept',),
'blankoaksepten': ('blankoaksept',),
'blankoakseptene': ('blankoaksept',),
'blankoaksepter': ('blankoaksept',),
'blankofullmakt': ('blankofullmakt',),
'blankofullmakta': ('blankofullmakt',),
'blankofullmakten': ('blankofullmakt',),
'blankofullmaktene': ('blankofullmakt',),
'blankofullmakter': ('blankofullmakt',),
'blankokreditt': ('blankokreditt',),
'blankokreditten': ('blankokreditt',),
'blankokredittene': ('blankokreditt',),
'blankokreditter': ('blankokreditt',),
'blankolån': ('blankolån',),
'blankolåna': ('blankolån',),
'blankolånene': ('blankolån',),
'blankolånet': ('blankolån',),
'blankoveksel': ('blankoveksel',),
'blankovekselen': ('blankoveksel',),
'blankovekslene': ('blankoveksel',),
'blankoveksler': ('blankoveksel',),
'blankvers': ('blankvers',),
'blankversa': ('blankvers',),
'blankversene': ('blankvers',),
'blankverset': ('blankvers',),
'blankål': ('blankål',),
'blankålen': ('blankål',),
'blankålene': ('blankål',),
'blankåler': ('blankål',),
'blasfemi': ('blasfemi',),
'blasfemien': ('blasfemi',),
'blasfemiene': ('blasfemi',),
'blasfemier': ('blasfemi',),
'blason': ('blason',),
'blasonen': ('blason',),
'blasonene': ('blason',),
'blasoner': ('blason',),
'blastula': ('blastula',),
'blastulaen': ('blastula',),
'blastulaene': ('blastula',),
'blastulaer': ('blastula',),
'blastulastadia': ('blastulastadium',),
'blastulastadiene': ('blastulastadium',),
'blastulastadier': ('blastulastadium',),
'blastulastadiet': ('blastulastadium',),
'blastulastadium': ('blastulastadium',),
'blautdyr': ('blautdyr',),
'blautdyra': ('blautdyr',),
'blautdyrene': ('blautdyr',),
'blautdyret': ('blautdyr',),
'blautfisk': ('blautfisk',),
'blautfisken': ('blautfisk',),
'blautfiskene': ('blautfisk',),
'blautfisker': ('blautfisk',),
'blautkaka': ('blautkake',),
'blautkake': ('blautkake',),
'blautkaken': ('blautkake',),
'blautkakene': ('blautkake',),
'blautkaker': ('blautkake',),
'blautmyr': ('blautmyr',),
'blautmyra': ('blautmyr',),
'blautmyren': ('blautmyr',),
'blautmyrene': ('blautmyr',),
'blautmyrer': ('blautmyr',),
'blautråte': ('blautråte',),
'blautråten': ('blautråte',),
'blautråtene': ('blautråte',),
'blautråter': ('blautråte',),
'blautskilpadda': ('blautskilpadde',),
'blautskilpadde': ('blautskilpadde',),
'blautskilpadden': ('blautskilpadde',),
'blautskilpaddene': ('blautskilpadde',),
'blautskilpadder': ('blautskilpadde',),
'blei': ('blei',),
'bleien': ('blei',),
'bleiene': ('blei',),
'bleier': ('blei',),
'blei': ('blei',),
'bleien': ('blei',),
'bleiene': ('blei',),
'bleier': ('blei',),
'bleia': ('bleie',),
'bleie': ('bleie',),
'bleien': ('bleie',),
'bleiene': ('bleie',),
'bleier': ('bleie',),
'bleiebarn': ('bleiebarn',),
'bleiebarna': ('bleiebarn',),
'bleiebarnene': ('bleiebarn',),
'bleiebarnet': ('bleiebarn',),
'bleievask': ('bleievask',),
'bleievasken': ('bleievask',),
'bleievaskene': ('bleievask',),
'bleievasker': ('bleievask',),
'bleig': ('bleig',),
'bleigen': ('bleig',),
'bleigene': ('bleig',),
'bleiger': ('bleig',),
'bleik': ('bleik',),
'bleika': ('bleik',),
'bleiken': ('bleik',),
'bleikene': ('bleik',),
'bleiker': ('bleik',),
'bleikansikt': ('bleikansikt',),
'bleikansikta': ('bleikansikt',),
'bleikansiktene': ('bleikansikt',),
'bleikansikter': ('bleikansikt',),
'bleikansiktet': ('bleikansikt',),
'bleika': ('bleike',),
'bleike': ('bleike',),
'bleiken': ('bleike',),
'bleikene': ('bleike',),
'bleiker': ('bleike',),
'bleikemiddel': ('bleikemiddel',),
'bleikemiddelet': ('bleikemiddel',),
'bleikemidla': ('bleikemiddel',),
'bleikemidlene': ('bleikemiddel',),
'bleikemidler': ('bleikemiddel',),
'bleikemidlet': ('bleikemiddel',),
'bleikevoll': ('bleikevoll',),
'bleikevollen': ('bleikevoll',),
'bleikevollene': ('bleikevoll',),
'bleikevoller': ('bleikevoll',),
'bleikfis': ('bleikfis',),
'bleikfisen': ('bleikfis',),
'bleikfisene': ('bleikfis',),
'bleikfiser': ('bleikfis',),
'bleikfjes': ('bleikfjes',),
'bleikfjesa': ('bleikfjes',),
'bleikfjesene': ('bleikfjes',),
'bleikfjeset': ('bleikfjes',),
'bleikjord': ('bleikjord',),
'bleikjorda': ('bleikjord',),
'bleikjorden': ('bleikjord',),
'bleikjordene': ('bleikjord',),
'bleikjorder': ('bleikjord',),
'bleiknebb': ('bleiknebb',),
'bleiknebba': ('bleiknebb',),
'bleiknebben': ('bleiknebb',),
'bleiknebbene': ('bleiknebb',),
'bleiknebbet': ('bleiknebb',),
'blekansikt': ('blekansikt',),
'blekansikta': ('blekansikt',),
'blekansiktene': ('blekansikt',),
'blekansikter': ('blekansikt',),
'blekansiktet': ('blekansikt',),
'blekemiddel': ('blekemiddel',),
'blekemiddelet': ('blekemiddel',),
'blekemidla': ('blekemiddel',),
'blekemidlene': ('blekemiddel',),
'blekemidler': ('blekemiddel',),
'blekemidlet': ('blekemiddel',),
'blekevoll': ('blekevoll',),
'blekevollen': ('blekevoll',),
'blekevollene': ('blekevoll',),
'blekevoller': ('blekevoll',),
'blekk': ('blekk',),
'blekka': ('blekk',),
'blekkene': ('blekk',),
'blekket': ('blekk',),
'blekk': ('blekk',),
'blekka': ('blekk',),
'blekkene': ('blekk',),
'blekket': ('blekk',),
'blekk': ('blekk',),
'blekka': ('blekk',),
'blekkene': ('blekk',),
'blekket': ('blekk',),
'blekk-kjertel': ('blekk-kjertel',),
'blekk-kjertelen': ('blekk-kjertel',),
'blekk-kjertlene': ('blekk-kjertel',),
'blekk-kjertler': ('blekk-kjertel',),
'blekk-klatt': ('blekk-klatt',),
'blekk-klatten': ('blekk-klatt',),
'blekk-klattene': ('blekk-klatt',),
'blekk-klatter': ('blekk-klatt',),
'blekk-kopp': ('blekk-kopp',),
'blekk-koppen': ('blekk-kopp',),
'blekk-koppene': ('blekk-kopp',),
'blekk-kopper': ('blekk-kopp',),
'blekk-kopp': ('blekk-kopp',),
'blekk-koppen': ('blekk-kopp',),
'blekk-koppene': ('blekk-kopp',),
'blekk-kopper': ('blekk-kopp',),
'blekkboks': ('blekkboks',),
'blekkboksen': ('blekkboks',),
'blekkboksene': ('blekkboks',),
'blekkbokser': ('blekkboks',),
'blekkdåse': ('blekkdåse',),
'blekkdåsen': ('blekkdåse',),
'blekkdåsene': ('blekkdåse',),
'blekkdåser': ('blekkdåse',),
'blekkdåse': ('blekkdåse',),
'blekkdåsen': ('blekkdåse',),
'blekkdåsene': ('blekkdåse',),
'blekkdåser': ('blekkdåse',),
'blekka': ('blekke',),
'blekke': ('blekke',),
'blekken': ('blekke',),
'blekkene': ('blekke',),
'blekker': ('blekke',),
'blekkflekk': ('blekkflekk',),
'blekkflekken': ('blekkflekk',),
'blekkflekkene': ('blekkflekk',),
'blekkflekker': ('blekkflekk',),
'blekkhus': ('blekkhus',),
'blekkhusa': ('blekkhus',),
'blekkhusene': ('blekkhus',),
'blekkhuset': ('blekkhus',),
'blekkjertel': ('blekkjertel',),
'blekkjertelen': ('blekkjertel',),
'blekkjertlene': ('blekkjertel',),
'blekkjertler': ('blekkjertel',),
'blekklatt': ('blekklatt',),
'blekklatten': ('blekklatt',),
'blekklattene': ('blekklatt',),
'blekklatter': ('blekklatt',),
'blekkopp': ('blekkopp',),
'blekkoppen': ('blekkopp',),
'blekkoppene': ('blekkopp',),
'blekkopper': ('blekkopp',),
'blekkopp': ('blekkopp',),
'blekkoppen': ('blekkopp',),
'blekkoppene': ('blekkopp',),
'blekkopper': ('blekkopp',),
'blekkplata': ('blekkplate',),
'blekkplate': ('blekkplate',),
'blekkplaten': ('blekkplate',),
'blekkplatene': ('blekkplate',),
'blekkplater': ('blekkplate',),
'blekkplata': ('blekkplate',),
'blekkplate': ('blekkplate',),
'blekkplaten': ('blekkplate',),
'blekkplatene': ('blekkplate',),
'blekkplater': ('blekkplate',),
'blekkslager': ('blekkslager',),
'blekkslagere': ('blekkslager',),
'blekkslageren': ('blekkslager',),
'blekkslagerer': ('blekkslager',),
'blekkslagerne': ('blekkslager',),
'blekkslager': ('blekkslager',),
'blekkslagere': ('blekkslager',),
'blekkslageren': ('blekkslager',),
'blekkslagerer': ('blekkslager',),
'blekkslagerne': ('blekkslager',),
'blekkslagerverksted': ('blekkslagerverksted',),
'blekkslagerverkstedene': ('blekkslagerverksted',),
'blekkslagerverksteder': ('blekkslagerverksted',),
'blekkslagerverkstedet': ('blekkslagerverksted',),
'blekkslagerverksted': ('blekkslagerverksted',),
'blekkslagerverkstedene': ('blekkslagerverksted',),
'blekkslagerverksteder': ('blekkslagerverksted',),
'blekkslagerverkstedet': ('blekkslagerverksted',),
'blekkspann': ('blekkspann',),
'blekkspanna': ('blekkspann',),
'blekkspannene': ('blekkspann',),
'blekkspannet': ('blekkspann',),
'blekkspann': ('blekkspann',),
'blekkspanna': ('blekkspann',),
'blekkspannene': ('blekkspann',),
'blekkspannet': ('blekkspann',),
'blekksprut': ('blekksprut',),
'blekkspruten': ('blekksprut',),
'blekksprutene': ('blekksprut',),
'blekkspruter': ('blekksprut',),
'blekkvara': ('blekkvare',),
'blekkvare': ('blekkvare',),
'blekkvaren': ('blekkvare',),
'blekkvarene': ('blekkvare',),
'blekkvarer': ('blekkvare',),
'blekkvara': ('blekkvare',),
'blekkvare': ('blekkvare',),
'blekkvaren': ('blekkvare',),
'blekkvarene': ('blekkvare',),
'blekkvarer': ('blekkvare',),
'blekkviskelær': ('blekkviskelær',),
'blekkviskelæra': ('blekkviskelær',),
'blekkviskelærene': ('blekkviskelær',),
'blekkviskelæret': ('blekkviskelær',),
'bleknebb': ('bleknebb',),
'bleknebba': ('bleknebb',),
'bleknebben': ('bleknebb',),
'bleknebbene': ('bleknebb',),
'bleknebbet': ('bleknebb',),
'blemma': ('blemme',),
'blemme': ('blemme',),
'blemmen': ('blemme',),
'blemmene': ('blemme',),
'blemmer': ('blemme',),
'blemmestål': ('blemmestål',),
'blemmeståla': ('blemmestål',),
'blemmestålene': ('blemmestål',),
'blemmestålet': ('blemmestål',),
'blende': ('blende',),
'blenden': ('blende',),
'blendene': ('blende',),
'blender': ('blende',),
'blender': ('blender',),
'blendere': ('blender',),
'blenderen': ('blender',),
'blenderer': ('blender',),
'blenderne': ('blender',),
'blendering': ('blendering',),
'blenderinga': ('blendering',),
'blenderingen': ('blendering',),
'blenderingene': ('blendering',),
'blenderinger': ('blendering',),
'blenderinnstilling': ('blenderinnstilling',),
'blenderinnstillinga': ('blenderinnstilling',),
'blenderinnstillingen': ('blenderinnstilling',),
'blenderinnstillingene': ('blenderinnstilling',),
'blenderinnstillinger': ('blenderinnstilling',),
'blenderåpning': ('blenderåpning',),
'blenderåpninga': ('blenderåpning',),
'blenderåpningen': ('blenderåpning',),
'blenderåpningene': ('blenderåpning',),
'blenderåpninger': ('blenderåpning',),
'blending': ('blending',),
'blendinga': ('blending',),
'blendingen': ('blending',),
'blendingene': ('blending',),
'blendinger': ('blending',),
'blendingsgardin': ('blendingsgardin',),
'blendingsgardina': ('blendingsgardin',),
'blendingsgardinen': ('blendingsgardin',),
'blendingsgardinene': ('blendingsgardin',),
'blendingsgardiner': ('blendingsgardin',),
'blendingsgardinet': ('blendingsgardin',),
'blendverk': ('blendverk',),
'blendverka': ('blendverk',),
'blendverkene': ('blendverk',),
'blendverket': ('blendverk',),
'bles': ('bles',),
'blesa': ('bles',),
'blesene': ('bles',),
'bleset': ('bles',),
'blesand': ('blesand',),
'blesanda': ('blesand',),
'blesanden': ('blesand',),
'blesendene': ('blesand',),
'blesender': ('blesand',),
'blest': ('blest',),
'blesten': ('blest',),
'blestene': ('blest',),
'blester': ('blest',),
'blestsjef': ('blestsjef',),
'blestsjefen': ('blestsjef',),
'blestsjefene': ('blestsjef',),
'blestsjefer': ('blestsjef',),
'blikk-kopp': ('blikk-kopp',),
'blikk-koppen': ('blikk-kopp',),
'blikk-koppene': ('blikk-kopp',),
'blikk-kopper': ('blikk-kopp',),
'blikk-kopp': ('blikk-kopp',),
'blikk-koppen': ('blikk-kopp',),
'blikk-koppene': ('blikk-kopp',),
'blikk-kopper': ('blikk-kopp',),
'blikkboks': ('blikkboks',),
'blikkboksen': ('blikkboks',),
'blikkboksene': ('blikkboks',),
'blikkbokser': ('blikkboks',),
'blikkdåsa': ('blikkdåse',),
'blikkdåse': ('blikkdåse',),
'blikkdåsen': ('blikkdåse',),
'blikkdåsene': ('blikkdåse',),
'blikkdåser': ('blikkdåse',),
'blikkdåsa': ('blikkdåse',),
'blikkdåse': ('blikkdåse',),
'blikkdåsen': ('blikkdåse',),
'blikkdåsene': ('blikkdåse',),
'blikkdåser': ('blikkdåse',),
'blikkenslager': ('blikkenslager',),
'blikkenslagere': ('blikkenslager',),
'blikkenslageren': ('blikkenslager',),
'blikkenslagerer': ('blikkenslager',),
'blikkenslagerne': ('blikkenslager',),
'blikkenslager': ('blikkenslager',),
'blikkenslagere': ('blikkenslager',),
'blikkenslageren': ('blikkenslager',),
'blikkenslagerer': ('blikkenslager',),
'blikkenslagerne': ('blikkenslager',),
'blikkenslagerverksted': ('blikkenslagerverksted',),
'blikkenslagerverkstedene': ('blikkenslagerverksted',),
'blikkenslagerverksteder': ('blikkenslagerverksted',),
'blikkenslagerverkstedet': ('blikkenslagerverksted',),
'blikkenslagerverksted': ('blikkenslagerverksted',),
'blikkenslagerverkstedene': ('blikkenslagerverksted',),
'blikkenslagerverksteder': ('blikkenslagerverksted',),
'blikkenslagerverkstedet': ('blikkenslagerverksted',),
'blikkfang': ('blikkfang',),
'blikkfanga': ('blikkfang',),
'blikkfangene': ('blikkfang',),
'blikkfanget': ('blikkfang',),
'blikkopp': ('blikkopp',),
'blikkoppen': ('blikkopp',),
'blikkoppene': ('blikkopp',),
'blikkopper': ('blikkopp',),
'blikkopp': ('blikkopp',),
'blikkoppen': ('blikkopp',),
'blikkoppene': ('blikkopp',),
'blikkopper': ('blikkopp',),
'blikkplata': ('blikkplate',),
'blikkplate': ('blikkplate',),
'blikkplaten': ('blikkplate',),
'blikkplatene': ('blikkplate',),
'blikkplater': ('blikkplate',),
'blikkplata': ('blikkplate',),
'blikkplate': ('blikkplate',),
'blikkplaten': ('blikkplate',),
'blikkplatene': ('blikkplate',),
'blikkplater': ('blikkplate',),
'blikkslager': ('blikkslager',),
'blikkslagere': ('blikkslager',),
'blikkslageren': ('blikkslager',),
'blikkslagerer': ('blikkslager',),
'blikkslagerne': ('blikkslager',),
'blikkslager': ('blikkslager',),
'blikkslagere': ('blikkslager',),
'blikkslageren': ('blikkslager',),
'blikkslagerer': ('blikkslager',),
'blikkslagerne': ('blikkslager',),
'blikkslagerverksted': ('blikkslagerverksted',),
'blikkslagerverkstedene': ('blikkslagerverksted',),
'blikkslagerverksteder': ('blikkslagerverksted',),
'blikkslagerverkstedet': ('blikkslagerverksted',),
'blikkslagerverksted': ('blikkslagerverksted',),
'blikkslagerverkstedene': ('blikkslagerverksted',),
'blikkslagerverksteder': ('blikkslagerverksted',),
'blikkslagerverkstedet': ('blikkslagerverksted',),
'blikkspann': ('blikkspann',),
'blikkspanna': ('blikkspann',),
'blikkspannene': ('blikkspann',),
'blikkspannet': ('blikkspann',),
'blikkspann': ('blikkspann',),
'blikkspanna': ('blikkspann',),
'blikkspannene': ('blikkspann',),
'blikkspannet': ('blikkspann',),
'blikkvara': ('blikkvare',),
'blikkvare': ('blikkvare',),
'blikkvaren': ('blikkvare',),
'blikkvarene': ('blikkvare',),
'blikkvarer': ('blikkvare',),
'blikkvara': ('blikkvare',),
'blikkvare': ('blikkvare',),
'blikkvaren': ('blikkvare',),
'blikkvarene': ('blikkvare',),
'blikkvarer': ('blikkvare',),
'blinda': ('blinde',),
'blinde': ('blinde',),
'blinden': ('blinde',),
'blindene': ('blinde',),
'blinder': ('blinde',),
'blindealfabet': ('blindealfabet',),
'blindealfabeta': ('blindealfabet',),
'blindealfabetene': ('blindealfabet',),
'blindealfabeter': ('blindealfabet',),
'blindealfabetet': ('blindealfabet',),
'blindebukk': ('blindebukk',),
'blindebukken': ('blindebukk',),
'blindebukkene': ('blindebukk',),
'blindebukker': ('blindebukk',),
'blindeforbund': ('blindeforbund',),
'blindeforbunda': ('blindeforbund',),
'blindeforbundene': ('blindeforbund',),
'blindeforbundet': ('blindeforbund',),
'blindeførerhund': ('blindeførerhund',),
'blindeførerhunden': ('blindeførerhund',),
'blindeførerhundene': ('blindeførerhund',),
'blindeførerhunder': ('blindeførerhund',),
'blindemann': ('blindemann',),
'blindemannen': ('blindemann',),
'blindemenn': ('blindemann',),
'blindemennene': ('blindemann',),
'blindesak': ('blindesak',),
'blindesaka': ('blindesak',),
'blindesaken': ('blindesak',),
'blindesakene': ('blindesak',),
'blindesaker': ('blindesak',),
'blindeskole': ('blindeskole',),
'blindeskolen': ('blindeskole',),
'blindeskolene': ('blindeskole',),
'blindeskoler': ('blindeskole',),
'blindeskrift': ('blindeskrift',),
'blindeskrifta': ('blindeskrift',),
'blindeskriften': ('blindeskrift',),
'blindeskriftene': ('blindeskrift',),
'blindeskrifter': ('blindeskrift',),
'blindflyging': ('blindflyging',),
'blindflyginga': ('blindflyging',),
'blindflygingen': ('blindflyging',),
'blindflygingene': ('blindflyging',),
'blindflyginger': ('blindflyging',),
'blindflying': ('blindflying',),
'blindflyinga': ('blindflying',),
'blindflyingen': ('blindflying',),
'blindflyingene': ('blindflying',),
'blindflyinger': ('blindflying',),
'blindgata': ('blindgate',),
'blindgate': ('blindgate',),
'blindgaten': ('blindgate',),
'blindgatene': ('blindgate',),
'blindgater': ('blindgate',),
'blindgjenger': ('blindgjenger',),
'blindgjengere': ('blindgjenger',),
'blindgjengeren': ('blindgjenger',),
'blindgjengerer': ('blindgjenger',),
'blindgjengerne': ('blindgjenger',),
'blindhet': ('blindhet',),
'blindheta': ('blindhet',),
'blindheten': ('blindhet',),
'blindhetene': ('blindhet',),
'blindheter': ('blindhet',),
'blinding': ('blinding',),
'blindingen': ('blinding',),
'blindingene': ('blinding',),
'blindinger': ('blinding',),
'blinding': ('blinding',),
'blindingen': ('blinding',),
'blindingene': ('blinding',),
'blindinger': ('blinding',),
'blindklegg': ('blindklegg',),
'blindkleggen': ('blindklegg',),
'blindkleggene': ('blindklegg',),
'blindklegger': ('blindklegg',),
'blindlanding': ('blindlanding',),
'blindlandinga': ('blindlanding',),
'blindlandingen': ('blindlanding',),
'blindlandingene': ('blindlanding',),
'blindlandinger': ('blindlanding',),
'blindnagle': ('blindnagle',),
'blindnaglen': ('blindnagle',),
'blindnaglene': ('blindnagle',),
'blindnagler': ('blindnagle',),
'blindpassasjer': ('blindpassasjer',),
'blindpassasjeren': ('blindpassasjer',),
'blindpassasjerene': ('blindpassasjer',),
'blindpassasjerer': ('blindpassasjer',),
'blindramma': ('blindramme',),
'blindramme': ('blindramme',),
'blindrammen': ('blindramme',),
'blindrammene': ('blindramme',),
'blindrammer': ('blindramme',),
'blindskjær': ('blindskjær',),
'blindskjæra': ('blindskjær',),
'blindskjærene': ('blindskjær',),
'blindskjæret': ('blindskjær',),
'blindspor': ('blindspor',),
'blindspora': ('blindspor',),
'blindsporene': ('blindspor',),
'blindsporet': ('blindspor',),
'blindtarm': ('blindtarm',),
'blindtarmen': ('blindtarm',),
'blindtarmene': ('blindtarm',),
'blindtarmer': ('blindtarm',),
'blindtarmsbetennelse': ('blindtarmsbetennelse',),
'blindtarmsbetennelsen': ('blindtarmsbetennelse',),
'blindtarmsbetennelsene': ('blindtarmsbetennelse',),
'blindtarmsbetennelser': ('blindtarmsbetennelse',),
'blindtarmsvedheng': ('blindtarmsvedheng',),
'blindtarmsvedhenga': ('blindtarmsvedheng',),
'blindtarmsvedhengene': ('blindtarmsvedheng',),
'blindtarmsvedhenget': ('blindtarmsvedheng',),
'blindveg': ('blindveg',),
'blindvegen': ('blindveg',),
'blindvegene': ('blindveg',),
'blindveger': ('blindveg',),
'blindvei': ('blindvei',),
'blindveien': ('blindvei',),
'blindveiene': ('blindvei',),
'blindveier': ('blindvei',),
'blings': ('blings',),
'blingsen': ('blings',),
'blingsene': ('blings',),
'blingser': ('blings',),
'blink': ('blink',),
'blinken': ('blink',),
'blinkene': ('blink',),
'blinker': ('blink',),
'blink': ('blink',),
'blinka': ('blink',),
'blinkene': ('blink',),
'blinket': ('blink',),
'blinkemerka': ('blinkemerke',),
'blinkemerke': ('blinkemerke',),
'blinkemerkene': ('blinkemerke',),
'blinkemerker': ('blinkemerke',),
'blinkemerket': ('blinkemerke',),
'blinkeøks': ('blinkeøks',),
'blinkeøksa': ('blinkeøks',),
'blinkeøksen': ('blinkeøks',),
'blinkeøksene': ('blinkeøks',),
'blinkeøkser': ('blinkeøks',),
'blinkfyr': ('blinkfyr',),
'blinkfyra': ('blinkfyr',),
'blinkfyrene': ('blinkfyr',),
'blinkfyret': ('blinkfyr',),
'blinklanterna': ('blinklanterne',),
'blinklanterne': ('blinklanterne',),
'blinklanternen': ('blinklanterne',),
'blinklanternene': ('blinklanterne',),
'blinklanterner': ('blinklanterne',),
'blinklys': ('blinklys',),
'blinklysa': ('blinklys',),
'blinklysene': ('blinklys',),
'blinklyset': ('blinklys',),
'blinkmerka': ('blinkmerke',),
'blinkmerke': ('blinkmerke',),
'blinkmerkene': ('blinkmerke',),
'blinkmerker': ('blinkmerke',),
'blinkmerket': ('blinkmerke',),
'blinkskott': ('blinkskott',),
'blinkskotta': ('blinkskott',),
'blinkskottene': ('blinkskott',),
'blinkskottet': ('blinkskott',),
'blinkskudd': ('blinkskudd',),
'blinkskudda': ('blinkskudd',),
'blinkskuddene': ('blinkskudd',),
'blinkskuddet': ('blinkskudd',),
'blinkøks': ('blinkøks',),
'blinkøksa': ('blinkøks',),
'blinkøksen': ('blinkøks',),
'blinkøksene': ('blinkøks',),
'blinkøkser': ('blinkøks',),
'blits': ('blits',),
'blitsen': ('blits',),
'blitsene': ('blits',),
'blitser': ('blits',),
'blitskrig': ('blitskrig',),
'blitskrigen': ('blitskrig',),
'blitskrigene': ('blitskrig',),
'blitskriger': ('blitskrig',),
'blitslampa': ('blitslampe',),
'blitslampe': ('blitslampe',),
'blitslampen': ('blitslampe',),
'blitslampene': ('blitslampe',),
'blitslamper': ('blitslampe',),
'blitslys': ('blitslys',),
'blitslysa': ('blitslys',),
'blitslysene': ('blitslys',),
'blitslyset': ('blitslys',),
'blod': ('blod',),
'bloda': ('blod',),
'blodene': ('blod',),
'blodet': ('blod',),
'blodansamling': ('blodansamling',),
'blodansamlinga': ('blodansamling',),
'blodansamlingen': ('blodansamling',),
'blodansamlingene': ('blodansamling',),
'blodansamlinger': ('blodansamling',),
'blodappelsin': ('blodappelsin',),
'blodappelsinen': ('blodappelsin',),
'blodappelsinene': ('blodappelsin',),
'blodappelsiner': ('blodappelsin',),
'blodbad': ('blodbad',),
'blodbada': ('blodbad',),
'blodbadene': ('blodbad',),
'blodbadet': ('blodbad',),
'blodbank': ('blodbank',),
'blodbanken': ('blodbank',),
'blodbankene': ('blodbank',),
'blodbanker': ('blodbank',),
'blodblemma': ('blodblemme',),
'blodblemme': ('blodblemme',),
'blodblemmen': ('blodblemme',),
'blodblemmene': ('blodblemme',),
'blodblemmer': ('blodblemme',),
'blodbok': ('blodbok',),
'blodboka': ('blodbok',),
'blodboken': ('blodbok',),
'blodbokene': ('blodbok',),
'blodboker': ('blodbok',),
'blodbøk': ('blodbøk',),
'blodbøken': ('blodbøk',),
'blodbøkene': ('blodbøk',),
'blodbøker': ('blodbøk',),
'blodcella': ('blodcelle',),
'blodcelle': ('blodcelle',),
'blodcellen': ('blodcelle',),
'blodcellene': ('blodcelle',),
'blodceller': ('blodcelle',),
'bloddoping': ('bloddoping',),
'bloddopinga': ('bloddoping',),
'bloddopingen': ('bloddoping',),
'bloddopingene': ('bloddoping',),
'bloddopinger': ('bloddoping',),
'bloddråpe': ('bloddråpe',),
'bloddråpen': ('bloddråpe',),
'bloddråpene': ('bloddråpe',),
'bloddråper': ('bloddråpe',),
'blodforgiftning': ('blodforgiftning',),
'blodforgiftninga': ('blodforgiftning',),
'blodforgiftningen': ('blodforgiftning',),
'blodforgiftningene': ('blodforgiftning',),
'blodforgiftninger': ('blodforgiftning',),
'blodgiver': ('blodgiver',),
'blodgivere': ('blodgiver',),
'blodgiveren': ('blodgiver',),
'blodgiverer': ('blodgiver',),
'blodgiverne': ('blodgiver',),
'blodgruppa': ('blodgruppe',),
'blodgruppe': ('blodgruppe',),
'blodgruppen': ('blodgruppe',),
'blodgruppene': ('blodgruppe',),
'blodgrupper': ('blodgruppe',),
'blodhevn': ('blodhevn',),
'blodhevnen': ('blodhevn',),
'blodhevnene': ('blodhevn',),
'blodhevner': ('blodhevn',),
'blodhund': ('blodhund',),
'blodhunden': ('blodhund',),
'blodhundene': ('blodhund',),
'blodhunder': ('blodhund',),
'blodigla': ('blodigle',),
'blodigle': ('blodigle',),
'blodiglen': ('blodigle',),
'blodiglene': ('blodigle',),
'blodigler': ('blodigle',),
'blodikte': ('blodikte',),
'blodikten': ('blodikte',),
'blodiktene': ('blodikte',),
'blodikter': ('blodikte',),
'blodkar': ('blodkar',),
'blodkara': ('blodkar',),
'blodkarene': ('blodkar',),
'blodkaret': ('blodkar',),
'blodkreft': ('blodkreft',),
'blodkreften': ('blodkreft',),
'blodkreftene': ('blodkreft',),
'blodkrefter': ('blodkreft',),
'blodlegema': ('blodlegeme',),
'blodlegeme': ('blodlegeme',),
'blodlegemene': ('blodlegeme',),
'blodlegemer': ('blodlegeme',),
'blodlegemet': ('blodlegeme',),
'blodmangel': ('blodmangel',),
'blodmangelen': ('blodmangel',),
'blodmanglene': ('blodmangel',),
'blodmangler': ('blodmangel',),
'blodmat': ('blodmat',),
'blodmaten': ('blodmat',),
'blodmatene': ('blodmat',),
'blodmater': ('blodmat',),
'blodomløp': ('blodomløp',),
'blodomløpa': ('blodomløp',),
'blodomløpene': ('blodomløp',),
'blodomløpet': ('blodomløp',),
'blodoverføring': ('blodoverføring',),
'blodoverføringa': ('blodoverføring',),
'blodoverføringen': ('blodoverføring',),
'blodoverføringene': ('blodoverføring',),
'blodoverføringer': ('blodoverføring',),
'blodpengene': ('blodpenger',),
'blodpenger': ('blodpenger',),
'blodpiss': ('blodpiss',),
'blodpissa': ('blodpiss',),
'blodpissene': ('blodpiss',),
'blodpisset': ('blodpiss',),
'blodplasma': ('blodplasma',),
'blodplasmaa': ('blodplasma',),
'blodplasmaene': ('blodplasma',),
'blodplasmaet': ('blodplasma',),
'blodplata': ('blodplate',),
'blodplate': ('blodplate',),
'blodplaten': ('blodplate',),
'blodplatene': ('blodplate',),
'blodplater': ('blodplate',),
'blodpris': ('blodpris',),
'blodprisen': ('blodpris',),
'blodprisene': ('blodpris',),
'blodpriser': ('blodpris',),
'blodpropp': ('blodpropp',),
'blodproppen': ('blodpropp',),
'blodproppene': ('blodpropp',),
'blodpropper': ('blodpropp',),
'blodprosent': ('blodprosent',),
'blodprosenten': ('blodprosent',),
'blodprosentene': ('blodprosent',),
'blodprosenter': ('blodprosent',),
'blodprøva': ('blodprøve',),
'blodprøve': ('blodprøve',),
'blodprøven': ('blodprøve',),
'blodprøvene': ('blodprøve',),
'blodprøver': ('blodprøve',),
'blodpudding': ('blodpudding',),
'blodpuddingen': ('blodpudding',),
'blodpuddingene': ('blodpudding',),
'blodpuddinger': ('blodpudding',),
'blodpøl': ('blodpøl',),
'blodpølen': ('blodpøl',),
'blodpølene': ('blodpøl',),
'blodpøler': ('blodpøl',),
'blodsband': ('blodsband',),
'blodsbanda': ('blodsband',),
'blodsbandene': ('blodsband',),
'blodsbandet': ('blodsband',),
'blodsbånd': ('blodsbånd',),
'blodsbånda': ('blodsbånd',),
'blodsbåndene': ('blodsbånd',),
'blodsbåndet': ('blodsbånd',),
'blodsdråpe': ('blodsdråpe',),
'blodsdråpen': ('blodsdråpe',),
'blodsdråpene': ('blodsdråpe',),
'blodsdråper': ('blodsdråpe',),
'blodsenkning': ('blodsenkning',),
'blodsenkninga': ('blodsenkning',),
'blodsenkningen': ('blodsenkning',),
'blodsenkningene': ('blodsenkning',),
'blodsenkninger': ('blodsenkning',),
'blodsera': ('blodserum',),
'blodseraene': ('blodserum',),
'blodserum': ('blodserum',),
'blodseruma': ('blodserum',),
'blodserumene': ('blodserum',),
'blodserumer': ('blodserum',),
'blodserumet': ('blodserum',),
'blodskam': ('blodskam',),
'blodskamma': ('blodskam',),
'blodskammen': ('blodskam',),
'blodskammene': ('blodskam',),
'blodskammer': ('blodskam',),
'blodslit': ('blodslit',),
'blodslita': ('blodslit',),
'blodslitene': ('blodslit',),
'blodslitet': ('blodslit',),
'blodsmak': ('blodsmak',),
'blodsmaken': ('blodsmak',),
'blodsmakene': ('blodsmak',),
'blodsmaker': ('blodsmak',),
'blodsprut': ('blodsprut',),
'blodspruten': ('blodsprut',),
'blodsprutene': ('blodsprut',),
'blodspruter': ('blodsprut',),
'blodstyrtning': ('blodstyrtning',),
'blodstyrtninga': ('blodstyrtning',),
'blodstyrtningen': ('blodstyrtning',),
'blodstyrtningene': ('blodstyrtning',),
'blodstyrtninger': ('blodstyrtning',),
'blodsuger': ('blodsuger',),
'blodsugere': ('blodsuger',),
'blodsugeren': ('blodsuger',),
'blodsugerer': ('blodsuger',),
'blodsugerne': ('blodsuger',),
'blodsutgytelse': ('blodsutgytelse',),
'blodsutgytelsen': ('blodsutgytelse',),
'blodsutgytelsene': ('blodsutgytelse',),
'blodsutgytelser': ('blodsutgytelse',),
'blodtap': ('blodtap',),
'blodtapa': ('blodtap',),
'blodtapene': ('blodtap',),
'blodtapet': ('blodtap',),
'blodtilførsel': ('blodtilførsel',),
'blodtilførselen': ('blodtilførsel',),
'blodtilførslene': ('blodtilførsel',),
'blodtilførsler': ('blodtilførsel',),
'blodtransfusjon': ('blodtransfusjon',),
'blodtransfusjonen': ('blodtransfusjon',),
'blodtransfusjonene': ('blodtransfusjon',),
'blodtransfusjoner': ('blodtransfusjon',),
'blodtrykk': ('blodtrykk',),
'blodtrykka': ('blodtrykk',),
'blodtrykkene': ('blodtrykk',),
'blodtrykket': ('blodtrykk',),
'blodtype': ('blodtype',),
'blodtypen': ('blodtype',),
'blodtypene': ('blodtype',),
'blodtyper': ('blodtype',),
'bloduttredelse': ('bloduttredelse',),
'bloduttredelsen': ('bloduttredelse',),
'bloduttredelsene': ('bloduttredelse',),
'bloduttredelser': ('bloduttredelse',),
'blodvitna': ('blodvitne',),
'blodvitne': ('blodvitne',),
'blodvitnene': ('blodvitne',),
'blodvitner': ('blodvitne',),
'blodvitnet': ('blodvitne',),
'blodvæska': ('blodvæske',),
'blodvæske': ('blodvæske',),
'blodvæsken': ('blodvæske',),
'blodvæskene': ('blodvæske',),
'blodvæsker': ('blodvæske',),
'blodåra': ('blodåre',),
'blodåre': ('blodåre',),
'blodåren': ('blodåre',),
'blodårene': ('blodåre',),
'blodårer': ('blodåre',),
'blokade': ('blokade',),
'blokaden': ('blokade',),
'blokadene': ('blokade',),
'blokader': ('blokade',),
'blokadebryter': ('blokadebryter',),
'blokadebrytere': ('blokadebryter',),
'blokadebryteren': ('blokadebryter',),
'blokadebryterer': ('blokadebryter',),
'blokadebryterne': ('blokadebryter',),
'blokadeskip': ('blokadeskip',),
'blokadeskipa': ('blokadeskip',),
'blokadeskipene': ('blokadeskip',),
'blokadeskipet': ('blokadeskip',),
'blokk': ('blokk',),
'blokka': ('blokk',),
'blokken': ('blokk',),
'blokkene': ('blokk',),
'blokker': ('blokk',),
'blokkboer': ('blokkboer',),
'blokkboere': ('blokkboer',),
'blokkboeren': ('blokkboer',),
'blokkboerer': ('blokkboer',),
'blokkboerne': ('blokkboer',),
'blokkbokstav': ('blokkbokstav',),
'blokkbokstaven': ('blokkbokstav',),
'blokkbokstavene': ('blokkbokstav',),
'blokkbokstaver': ('blokkbokstav',),
'blokkbuer': ('blokkbuer',),
'blokkbuere': ('blokkbuer',),
'blokkbueren': ('blokkbuer',),
'blokkbuerer': ('blokkbuer',),
'blokkbuerne': ('blokkbuer',),
'blokkebær': ('blokkebær',),
'blokkebæra': ('blokkebær',),
'blokkebærene': ('blokkebær',),
'blokkebæret': ('blokkebær',),
'blokkebær': ('blokkebær',),
'blokkebæra': ('blokkebær',),
'blokkebærene': ('blokkebær',),
'blokkebæret': ('blokkebær',),
'blokkering': ('blokkering',),
'blokkeringa': ('blokkering',),
'blokkeringen': ('blokkering',),
'blokkeringene': ('blokkering',),
'blokkeringer': ('blokkering',),
'blokkfløyta': ('blokkfløyte',),
'blokkfløyte': ('blokkfløyte',),
'blokkfløyten': ('blokkfløyte',),
'blokkfløytene': ('blokkfløyte',),
'blokkfløyter': ('blokkfløyte',),
'blokkhus': ('blokkhus',),
'blokkhusa': ('blokkhus',),
'blokkhusene': ('blokkhus',),
'blokkhuset': ('blokkhus',),
'blokkleilighet': ('blokkleilighet',),
'blokkleiligheta': ('blokkleilighet',),
'blokkleiligheten': ('blokkleilighet',),
'blokkleilighetene': ('blokkleilighet',),
'blokkleiligheter': ('blokkleilighet',),
'blokkpost': ('blokkpost',),
'blokkposten': ('blokkpost',),
'blokkpostene': ('blokkpost',),
'blokkposter': ('blokkpost',),
'blokkskiva': ('blokkskive',),
'blokkskive': ('blokkskive',),
'blokkskiven': ('blokkskive',),
'blokkskivene': ('blokkskive',),
'blokkskiver': ('blokkskive',),
'blokkskrift': ('blokkskrift',),
'blokkskrifta': ('blokkskrift',),
'blokkskriften': ('blokkskrift',),
'blokkskriftene': ('blokkskrift',),
'blokkskrifter': ('blokkskrift',),
'blomkarse': ('blomkarse',),
'blomkarsen': ('blomkarse',),
'blomkarsene': ('blomkarse',),
'blomkarser': ('blomkarse',),
'blomkål': ('blomkål',),
'blomkålen': ('blomkål',),
'blomkålene': ('blomkål',),
'blomkåler': ('blomkål',),
'blomkålhoda': ('blomkålhode',),
'blomkålhode': ('blomkålhode',),
'blomkålhodene': ('blomkålhode',),
'blomkålhoder': ('blomkålhode',),
'blomkålhodet': ('blomkålhode',),
'blomkålsopp': ('blomkålsopp',),
'blomkålsoppen': ('blomkålsopp',),
'blomkålsoppene': ('blomkålsopp',),
'blomkålsopper': ('blomkålsopp',),
'blomkålsuppa': ('blomkålsuppe',),
'blomkålsuppe': ('blomkålsuppe',),
'blomkålsuppen': ('blomkålsuppe',),
'blomkålsuppene': ('blomkålsuppe',),
'blomkålsupper': ('blomkålsuppe',),
'blomkåløra': ('blomkåløre',),
'blomkåløre': ('blomkåløre',),
'blomkålørene': ('blomkåløre',),
'blomkålører': ('blomkåløre',),
'blomkåløret': ('blomkåløre',),
'blomst': ('blomst',),
'blomsten': ('blomst',),
'blomstene': ('blomst',),
'blomster': ('blomst',),
'blomster': ('blomster',),
'blomsteren': ('blomster',),
'blomstre': ('blomster',),
'blomstrene': ('blomster',),
'blomstrer': ('blomster',),
'blomsterbarn': ('blomsterbarn',),
'blomsterbarna': ('blomsterbarn',),
'blomsterbarnene': ('blomsterbarn',),
'blomsterbarnet': ('blomsterbarn',),
'blomsterbed': ('blomsterbed',),
'blomsterbeda': ('blomsterbed',),
'blomsterbedene': ('blomsterbed',),
'blomsterbedet': ('blomsterbed',),
'blomsterbinder': ('blomsterbinder',),
'blomsterbindere': ('blomsterbinder',),
'blomsterbinderen': ('blomsterbinder',),
'blomsterbinderer': ('blomsterbinder',),
'blomsterbinderne': ('blomsterbinder',),
'blomsterbotn': ('blomsterbotn',),
'blomsterbotnen': ('blomsterbotn',),
'blomsterbotnene': ('blomsterbotn',),
'blomsterbotner': ('blomsterbotn',),
'blomsterbukett': ('blomsterbukett',),
'blomsterbuketten': ('blomsterbukett',),
'blomsterbukettene': ('blomsterbukett',),
'blomsterbuketter': ('blomsterbukett',),
'blomsterbunn': ('blomsterbunn',),
'blomsterbunnen': ('blomsterbunn',),
'blomsterbunnene': ('blomsterbunn',),
'blomsterbunner': ('blomsterbunn',),
'blomsterdekorasjon': ('blomsterdekorasjon',),
'blomsterdekorasjonen': ('blomsterdekorasjon',),
'blomsterdekorasjonene': ('blomsterdekorasjon',),
'blomsterdekorasjoner': ('blomsterdekorasjon',),
'blomsterhandel': ('blomsterhandel',),
'blomsterhandelen': ('blomsterhandel',),
'blomsterhandlene': ('blomsterhandel',),
'blomsterhandler': ('blomsterhandel',),
'blomsterhilsen': ('blomsterhilsen',),
'blomsterhilsenen': ('blomsterhilsen',),
'blomsterhilsenene': ('blomsterhilsen',),
'blomsterhilsener': ('blomsterhilsen',),
'blomsterkassa': ('blomsterkasse',),
'blomsterkasse': ('blomsterkasse',),
'blomsterkassen': ('blomsterkasse',),
'blomsterkassene': ('blomsterkasse',),
'blomsterkasser': ('blomsterkasse',),
'blomsterkrans': ('blomsterkrans',),
'blomsterkransen': ('blomsterkrans',),
'blomsterkransene': ('blomsterkrans',),
'blomsterkranser': ('blomsterkrans',),
'blomsterløk': ('blomsterløk',),
'blomsterløken': ('blomsterløk',),
'blomsterløkene': ('blomsterløk',),
'blomsterløker': ('blomsterløk',),
'blomsterlauk': ('blomsterlauk',),
'blomsterlauken': ('blomsterlauk',),
'blomsterlaukene': ('blomsterlauk',),
'blomsterlauker': ('blomsterlauk',),
'blomsterpotta': ('blomsterpotte',),
'blomsterpotte': ('blomsterpotte',),
'blomsterpotten': ('blomsterpotte',),
'blomsterpottene': ('blomsterpotte',),
'blomsterpotter': ('blomsterpotte',),
'blomsterprakt': ('blomsterprakt',),
'blomsterprakta': ('blomsterprakt',),
'blomsterprakten': ('blomsterprakt',),
'blomsterpraktene': ('blomsterprakt',),
'blomsterprakter': ('blomsterprakt',),
'blomsterrabatt': ('blomsterrabatt',),
'blomsterrabatten': ('blomsterrabatt',),
'blomsterrabattene': ('blomsterrabatt',),
'blomsterrabatter': ('blomsterrabatt',),
'blomsterskjerm': ('blomsterskjerm',),
'blomsterskjermen': ('blomsterskjerm',),
'blomsterskjermene': ('blomsterskjerm',),
'blomsterskjermer': ('blomsterskjerm',),
'blomsterstand': ('blomsterstand',),
'blomsterstanden': ('blomsterstand',),
'blomsterstandene': ('blomsterstand',),
'blomsterstander': ('blomsterstand',),
'blomstertorg': ('blomstertorg',),
'blomstertorga': ('blomstertorg',),
'blomstertorgene': ('blomstertorg',),
'blomstertorget': ('blomstertorg',),
'blomstervase': ('blomstervase',),
'blomstervasen': ('blomstervase',),
'blomstervasene': ('blomstervase',),
'blomstervaser': ('blomstervase',),
'blomstring': ('blomstring',),
'blomstringa': ('blomstring',),
'blomstringen': ('blomstring',),
'blomstringene': ('blomstring',),
'blomstringer': ('blomstring',),
'blomstringstid': ('blomstringstid',),
'blomstringstida': ('blomstringstid',),
'blomstringstiden': ('blomstringstid',),
'blomstringstidene': ('blomstringstid',),
'blomstringstider': ('blomstringstid',),
'blonde': ('blonde',),
'blonden': ('blonde',),
'blondene': ('blonde',),
'blonder': ('blonde',),
'blondeblusa': ('blondebluse',),
'blondebluse': ('blondebluse',),
'blondeblusen': ('blondebluse',),
'blondeblusene': ('blondebluse',),
'blondebluser': ('blondebluse',),
'blondekant': ('blondekant',),
'blondekanten': ('blondekant',),
'blondekantene': ('blondekant',),
'blondekanter': ('blondekant',),
'blondeslør': ('blondeslør',),
'blondesløra': ('blondeslør',),
'blondeslørene': ('blondeslør',),
'blondesløret': ('blondeslør',),
'blondestoff': ('blondestoff',),
'blondestoffa': ('blondestoff',),
'blondestoffene': ('blondestoff',),
'blondestoffer': ('blondestoff',),
'blondestoffet': ('blondestoff',),
'blondina': ('blondine',),
'blondine': ('blondine',),
'blondinen': ('blondine',),
'blondinene': ('blondine',),
'blondiner': ('blondine',),
'blot': ('blot',),
'blota': ('blot',),
'blotene': ('blot',),
'blotet': ('blot',),
'blotter': ('blotter',),
'blottere': ('blotter',),
'blotteren': ('blotter',),
'blotterer': ('blotter',),
'blotterne': ('blotter',),
'blow-out': ('blow-out',),
'blow-outen': ('blow-out',),
'blow-outene': ('blow-out',),
'blow-outer': ('blow-out',),
'blueback': ('blueback',),
'bluebacken': ('blueback',),
'bluebackene': ('blueback',),
'bluebacker': ('blueback',),
'blueline': ('blueline',),
'blues': ('blues',),
'bluesen': ('blues',),
'bluesene': ('blues',),
'bluessanger': ('bluessanger',),
'bluessangere': ('bluessanger',),
'bluessangeren': ('bluessanger',),
'bluessangerer': ('bluessanger',),
'bluessangerne': ('bluessanger',),
'bluferdighet': ('bluferdighet',),
'bluferdigheta': ('bluferdighet',),
'bluferdigheten': ('bluferdighet',),
'bluferdighetene': ('bluferdighet',),
'bluferdigheter': ('bluferdighet',),
'blund': ('blund',),
'blunden': ('blund',),
'blundene': ('blund',),
'blunder': ('blund',),
'blunder': ('blunder',),
'blundere': ('blunder',),
'blunderen': ('blunder',),
'blunderer': ('blunder',),
'blunderne': ('blunder',),
'blunk': ('blunk',),
'blunka': ('blunk',),
'blunken': ('blunk',),
'blunkene': ('blunk',),
'blunket': ('blunk',),
'blusa': ('bluse',),
'bluse': ('bluse',),
'blusen': ('bluse',),
'blusene': ('bluse',),
'bluser': ('bluse',),
'bluseliv': ('bluseliv',),
'bluseliva': ('bluseliv',),
'bluselivene': ('bluseliv',),
'bluselivet': ('bluseliv',),
'bluss': ('bluss',),
'blussa': ('bluss',),
'blussene': ('bluss',),
'blusset': ('bluss',),
'bluslene': ('blussel',),
'blusler': ('blussel',),
'blussel': ('blussel',),
'blusselen': ('blussel',),
'bly': ('bly',),
'blya': ('bly',),
'blyene': ('bly',),
'blyet': ('bly',),
'blyakkumulator': ('blyakkumulator',),
'blyakkumulatoren': ('blyakkumulator',),
'blyakkumulatorene': ('blyakkumulator',),
'blyakkumulatorer': ('blyakkumulator',),
'blyant': ('blyant',),
'blyanten': ('blyant',),
'blyantene': ('blyant',),
'blyanter': ('blyant',),
'blyantskissa': ('blyantskisse',),
'blyantskisse': ('blyantskisse',),
'blyantskissen': ('blyantskisse',),
'blyantskissene': ('blyantskisse',),
'blyantskisser': ('blyantskisse',),
'blyantspisser': ('blyantspisser',),
'blyantspissere': ('blyantspisser',),
'blyantspisseren': ('blyantspisser',),
'blyantspisserer': ('blyantspisser',),
'blyantspisserne': ('blyantspisser',),
'blyantstegning': ('blyantstegning',),
'blyantstegninga': ('blyantstegning',),
'blyantstegningen': ('blyantstegning',),
'blyantstegningene': ('blyantstegning',),
'blyantstegninger': ('blyantstegning',),
'blyantstift': ('blyantstift',),
'blyantstiften': ('blyantstift',),
'blyantstiftene': ('blyantstift',),
'blyantstifter': ('blyantstift',),
'blyanttegning': ('blyanttegning',),
'blyanttegninga': ('blyanttegning',),
'blyanttegningen': ('blyanttegning',),
'blyanttegningene': ('blyanttegning',),
'blyanttegninger': ('blyanttegning',),
'blybensin': ('blybensin',),
'blybensinen': ('blybensin',),
'blybensinene': ('blybensin',),
'blybensiner': ('blybensin',),
'blyerts': ('blyerts',),
'blyertsen': ('blyerts',),
'blyertsene': ('blyerts',),
'blyertser': ('blyerts',),
'blyfarge': ('blyfarge',),
'blyfargen': ('blyfarge',),
'blyfargene': ('blyfarge',),
'blyfarger': ('blyfarge',),
'blyforbindelse': ('blyforbindelse',),
'blyforbindelsen': ('blyforbindelse',),
'blyforbindelsene': ('blyforbindelse',),
'blyforbindelser': ('blyforbindelse',),
'blyforgiftning': ('blyforgiftning',),
'blyforgiftninga': ('blyforgiftning',),
'blyforgiftningen': ('blyforgiftning',),
'blyforgiftningene': ('blyforgiftning',),
'blyforgiftninger': ('blyforgiftning',),
'blyforkle': ('blyforkle',),
'blyforkleet': ('blyforkle',),
'blyforklær': ('blyforkle',),
'blyforklærne': ('blyforkle',),
'blyglans': ('blyglans',),
'blyglansen': ('blyglans',),
'blyglansene': ('blyglans',),
'blyglanser': ('blyglans',),
'blygsel': ('blygsel',),
'blygselen': ('blygsel',),
'blygsla': ('blygsel',),
'blygslene': ('blygsel',),
'blygsler': ('blygsel',),
'blyhagl': ('blyhagl',),
'blyhagla': ('blyhagl',),
'blyhaglene': ('blyhagl',),
'blyhaglet': ('blyhagl',),
'blyinnfatning': ('blyinnfatning',),
'blyinnfatninga': ('blyinnfatning',),
'blyinnfatningen': ('blyinnfatning',),
'blyinnfatningene': ('blyinnfatning',),
'blyinnfatninger': ('blyinnfatning',),
'blymalm': ('blymalm',),
'blymalmen': ('blymalm',),
'blymalmene': ('blymalm',),
'blymalmer': ('blymalm',),
'blyoksid': ('blyoksid',),
'blyoksida': ('blyoksid',),
'blyoksidene': ('blyoksid',),
'blyoksider': ('blyoksid',),
'blyoksidet': ('blyoksid',),
'blyregn': ('blyregn',),
'blyregna': ('blyregn',),
'blyregnene': ('blyregn',),
'blyregnet': ('blyregn',),
'blysulfid': ('blysulfid',),
'blysulfida': ('blysulfid',),
'blysulfidene': ('blysulfid',),
'blysulfider': ('blysulfid',),
'blysulfidet': ('blysulfid',),
'blyvindu': ('blyvindu',),
'blyvindua': ('blyvindu',),
'blyvinduene': ('blyvindu',),
'blyvinduer': ('blyvindu',),
'blyvinduet': ('blyvindu',),
'blåbok': ('blåbok',),
'blåboka': ('blåbok',),
'blåboken': ('blåbok',),
'blåbøkene': ('blåbok',),
'blåbøker': ('blåbok',),
'blåbær': ('blåbær',),
'blåbæra': ('blåbær',),
'blåbærene': ('blåbær',),
'blåbæret': ('blåbær',),
'blåbærpai': ('blåbærpai',),
'blåbærpaien': ('blåbærpai',),
'blåbærpaiene': ('blåbærpai',),
'blåbærpaier': ('blåbærpai',),
'blåbærsaft': ('blåbærsaft',),
'blåbærsafta': ('blåbærsaft',),
'blåbærsaften': ('blåbærsaft',),
'blåbærsaftene': ('blåbærsaft',),
'blåbærsafter': ('blåbærsaft',),
'blåbærsuppa': ('blåbærsuppe',),
'blåbærsuppe': ('blåbærsuppe',),
'blåbærsuppen': ('blåbærsuppe',),
'blåbærsuppene': ('blåbærsuppe',),
'blåbærsupper': ('blåbærsuppe',),
'blåbærsyltetøy': ('blåbærsyltetøy',),
'blåbærsyltetøya': ('blåbærsyltetøy',),
'blåbærsyltetøyene': ('blåbærsyltetøy',),
'blåbærsyltetøyer': ('blåbærsyltetøy',),
'blåbærsyltetøyet': ('blåbærsyltetøy',),
'blådress': ('blådress',),
'blådressen': ('blådress',),
'blådressene': ('blådress',),
'blådresser': ('blådress',),
'blåhval': ('blåhval',),
'blåhvalen': ('blåhval',),
'blåhvalene': ('blåhval',),
'blåhvaler': ('blåhval',),
'blåklokka': ('blåklokke',),
'blåklokke': ('blåklokke',),
'blåklokken': ('blåklokke',),
'blåklokkene': ('blåklokke',),
'blåklokker': ('blåklokke',),
'blåknapp': ('blåknapp',),
'blåknappen': ('blåknapp',),
'blåknappene': ('blåknapp',),
'blåknapper': ('blåknapp',),
'blåknute': ('blåknute',),
'blåknuten': ('blåknute',),
'blåknutene': ('blåknute',),
'blåknuter': ('blåknute',),
'blåkoll': ('blåkoll',),
'blåkollen': ('blåkoll',),
'blåkollene': ('blåkoll',),
'blåkoller': ('blåkoll',),
'blåkval': ('blåkval',),
'blåkvalen': ('blåkval',),
'blåkvalene': ('blåkval',),
'blåkvaler': ('blåkval',),
'blåkveita': ('blåkveite',),
'blåkveite': ('blåkveite',),
'blåkveiten': ('blåkveite',),
'blåkveitene': ('blåkveite',),
'blåkveiter': ('blåkveite',),
'blåleir': ('blåleir',),
'blåleira': ('blåleir',),
'blåleirene': ('blåleir',),
'blåleiret': ('blåleir',),
'blåleira': ('blåleire',),
'blåleire': ('blåleire',),
'blåleiren': ('blåleire',),
'blåleirene': ('blåleire',),
'blåleirer': ('blåleire',),
'blålys': ('blålys',),
'blålysa': ('blålys',),
'blålysene': ('blålys',),
'blålyset': ('blålys',),
'blåmandag': ('blåmandag',),
'blåmandagen': ('blåmandag',),
'blåmandagene': ('blåmandag',),
'blåmandager': ('blåmandag',),
'blåmeis': ('blåmeis',),
'blåmeisa': ('blåmeis',),
'blåmeisen': ('blåmeis',),
'blåmeisene': ('blåmeis',),
'blåmeiser': ('blåmeis',),
'blåmyr': ('blåmyr',),
'blåmyra': ('blåmyr',),
'blåmyren': ('blåmyr',),
'blåmyrene': ('blåmyr',),
'blåmyrer': ('blåmyr',),
'blåne': ('blåne',),
'blånen': ('blåne',),
'blånene': ('blåne',),
'blåner': ('blåne',),
'blåpapir': ('blåpapir',),
'blåpapira': ('blåpapir',),
'blåpapirene': ('blåpapir',),
'blåpapirer': ('blåpapir',),
'blåpapiret': ('blåpapir',),
'blår': ('blår',),
'blåregn': ('blåregn',),
'blåregnen': ('blåregn',),
'blåregnene': ('blåregn',),
'blåregner': ('blåregn',),
'blårev': ('blårev',),
'blåreven': ('blårev',),
'blårevene': ('blårev',),
'blårever': ('blårev',),
'blåruss': ('blåruss',),
'blårussen': ('blåruss',),
'blårussene': ('blåruss',),
'blås': ('blås',),
'blåsen': ('blås',),
'blåsene': ('blås',),
'blåser': ('blås',),
'blåsa': ('blåse',),
'blåse': ('blåse',),
'blåsen': ('blåse',),
'blåsene': ('blåse',),
'blåser': ('blåse',),
'blåsebelg': ('blåsebelg',),
'blåsebelgen': ('blåsebelg',),
'blåsebelgene': ('blåsebelg',),
'blåsebelger': ('blåsebelg',),
'blåseinstrument': ('blåseinstrument',),
'blåseinstrumenta': ('blåseinstrument',),
'blåseinstrumentene': ('blåseinstrument',),
'blåseinstrumenter': ('blåseinstrument',),
'blåseinstrumentet': ('blåseinstrument',),
'blåser': ('blåser',),
'blåsere': ('blåser',),
'blåseren': ('blåser',),
'blåserer': ('blåser',),
'blåserne': ('blåser',),
'blåserør': ('blåserør',),
'blåserøra': ('blåserør',),
'blåserørene': ('blåserør',),
'blåserøret': ('blåserør',),
'blåskjell': ('blåskjell',),
'blåskjella': ('blåskjell',),
'blåskjellen': ('blåskjell',),
'blåskjellene': ('blåskjell',),
'blåskjellet': ('blåskjell',),
'blåst': ('blåst',),
'blåsten': ('blåst',),
'blåstene': ('blåst',),
'blåster': ('blåst',),
'blåstrupe': ('blåstrupe',),
'blåstrupen': ('blåstrupe',),
'blåstrupene': ('blåstrupe',),
'blåstruper': ('blåstrupe',),
'blåstrømpa': ('blåstrømpe',),
'blåstrømpe': ('blåstrømpe',),
'blåstrømpen': ('blåstrømpe',),
'blåstrømpene': ('blåstrømpe',),
'blåstrømper': ('blåstrømpe',),
'blåsymra': ('blåsymre',),
'blåsymre': ('blåsymre',),
'blåsymren': ('blåsymre',),
'blåsymrene': ('blåsymre',),
'blåsymrer': ('blåsymre',),
'blåsyra': ('blåsyre',),
'blåsyre': ('blåsyre',),
'blåsyren': ('blåsyre',),
'blåsyrene': ('blåsyre',),
'blåsyrer': ('blåsyre',),
'blått': ('blått',),
'blåtøy': ('blåtøy',),
'blåtøya': ('blåtøy',),
'blåtøyene': ('blåtøy',),
'blåtøyer': ('blåtøy',),
'blåtøyet': ('blåtøy',),
'blåtøyskjole': ('blåtøyskjole',),
'blåtøyskjolen': ('blåtøyskjole',),
'blåtøyskjolene': ('blåtøyskjole',),
'blåtøyskjoler': ('blåtøyskjole',),
'blåved': ('blåved',),
'blåveden': ('blåved',),
'blåvedene': ('blåved',),
'blåveder': ('blåved',),
'blåveis': ('blåveis',),
'blåveisen': ('blåveis',),
'blåveisene': ('blåveis',),
'blåveiser': ('blåveis',),
'blæra': ('blære',),
'blære': ('blære',),
'blæren': ('blære',),
'blærene': ('blære',),
'blærer': ('blære',),
'blæra': ('blære',),
'blære': ('blære',),
'blæren': ('blære',),
'blærene': ('blære',),
'blærer': ('blære',),
'blærebetennelse': ('blærebetennelse',),
'blærebetennelsen': ('blærebetennelse',),
'blærebetennelsene': ('blærebetennelse',),
'blærebetennelser': ('blærebetennelse',),
'blærehals': ('blærehals',),
'blærehalsen': ('blærehals',),
'blærehalsene': ('blærehals',),
'blærehalser': ('blærehals',),
'blærehalskjertel': ('blærehalskjertel',),
'blærehalskjertelen': ('blærehalskjertel',),
'blærehalskjertlene': ('blærehalskjertel',),
'blærehalskjertler': ('blærehalskjertel',),
'blærekatarr': ('blærekatarr',),
'blærekatarren': ('blærekatarr',),
'blærekatarrene': ('blærekatarr',),
'blærekatarrer': ('blærekatarr',),
'blæretang': ('blæretang',),
'blæretanga': ('blæretang',),
'blæretangen': ('blæretang',),
'blæretangene': ('blæretang',),
'blæretanger': ('blæretang',),
'blæretanget': ('blæretang',),
'bløder': ('bløder',),
'blødere': ('bløder',),
'bløderen': ('bløder',),
'bløderer': ('bløder',),
'bløderne': ('bløder',),
'bløderfamilie': ('bløderfamilie',),
'bløderfamilien': ('bløderfamilie',),
'bløderfamiliene': ('bløderfamilie',),
'bløderfamilier': ('bløderfamilie',),
'blødersjukdom': ('blødersjukdom',),
'blødersjukdommen': ('blødersjukdom',),
'blødersjukdommene': ('blødersjukdom',),
'blødersjukdommer': ('blødersjukdom',),
'blødersjuka': ('blødersjuke',),
'blødersjuke': ('blødersjuke',),
'blødersjuken': ('blødersjuke',),
'blødersjukene': ('blødersjuke',),
'blødersjuker': ('blødersjuke',),
'blødersykdom': ('blødersykdom',),
'blødersykdommen': ('blødersykdom',),
'blødersykdommene': ('blødersykdom',),
'blødersykdommer': ('blødersykdom',),
'blødersyka': ('blødersyke',),
'blødersyke': ('blødersyke',),
'blødersyken': ('blødersyke',),
'blødersykene': ('blødersyke',),
'blødersyker': ('blødersyke',),
'blødme': ('blødme',),
'blødmen': ('blødme',),
'blødmene': ('blødme',),
'blødmer': ('blødme',),
'blødning': ('blødning',),
'blødninga': ('blødning',),
'blødningen': ('blødning',),
'blødningene': ('blødning',),
'blødninger': ('blødning',),
'bløff': ('bløff',),
'bløffen': ('bløff',),
'bløffene': ('bløff',),
'bløffer': ('bløff',),
'bløffmaker': ('bløffmaker',),
'bløffmakere': ('bløffmaker',),
'bløffmakeren': ('bløffmaker',),
'bløffmakerer': ('bløffmaker',),
'bløffmakerne': ('bløffmaker',),
'bløt': ('bløt',),
'bløtdyr': ('bløtdyr',),
'bløtdyra': ('bløtdyr',),
'bløtdyrene': ('bløtdyr',),
'bløtdyret': ('bløtdyr',),
'bløtjern': ('bløtjern',),
'bløtjerna': ('bløtjern',),
'bløtjernene': ('bløtjern',),
'bløtjernet': ('bløtjern',),
'bløtkaka': ('bløtkake',),
'bløtkake': ('bløtkake',),
'bløtkaken': ('bløtkake',),
'bløtkakene': ('bløtkake',),
'bløtkaker': ('bløtkake',),
'bløtskilpadda': ('bløtskilpadde',),
'bløtskilpadde': ('bløtskilpadde',),
'bløtskilpadden': ('bløtskilpadde',),
'bløtskilpaddene': ('bløtskilpadde',),
'bløtskilpadder': ('bløtskilpadde',),
'bløtstål': ('bløtstål',),
'bløtståla': ('bløtstål',),
'bløtstålene': ('bløtstål',),
'bløtstålet': ('bløtstål',),
'bløyt': ('bløyt',),
'bløyta': ('bløyte',),
'bløyte': ('bløyte',),
'bløyten': ('bløyte',),
'bløytene': ('bløyte',),
'bløyter': ('bløyte',),
'bo': ('bo',),
'boa': ('bo',),
'boene': ('bo',),
'boet': ('bo',),
'bo': ('bo',),
'boa': ('boa',),
'boaen': ('boa',),
'boaene': ('boa',),
'boaer': ('boa',),
'boardingkort': ('boardingkort',),
'boardingkorta': ('boardingkort',),
'boardingkortene': ('boardingkort',),
'boardingkortet': ('boardingkort',),
'bobby': ('bobby',),
'bobbyen': ('bobby',),
'bobbyene': ('bobby',),
'bobbyer': ('bobby',),
'bobestyrer': ('bobestyrer',),
'bobestyrere': ('bobestyrer',),
'bobestyreren': ('bobestyrer',),
'bobestyrerer': ('bobestyrer',),
'bobestyrerne': ('bobestyrer',),
'bobla': ('boble',),
'boble': ('boble',),
'boblen': ('boble',),
'boblene': ('boble',),
'bobler': ('boble',),
'boblejakka': ('boblejakke',),
'boblejakke': ('boblejakke',),
'boblejakken': ('boblejakke',),
'boblejakkene': ('boblejakke',),
'boblejakker': ('boblejakke',),
'boblestoff': ('boblestoff',),
'boblestoffa': ('boblestoff',),
'boblestoffene': ('boblestoff',),
'boblestoffer': ('boblestoff',),
'boblestoffet': ('boblestoff',),
'bobsleigh': ('bobsleigh',),
'bobsleighen': ('bobsleigh',),
'bobsleighene': ('bobsleigh',),
'bobsleigher': ('bobsleigh',),
'bobsleighbane': ('bobsleighbane',),
'bobsleighbanen': ('bobsleighbane',),
'bobsleighbanene': ('bobsleighbane',),
'bobsleighbaner': ('bobsleighbane',),
'boccia': ('boccia',),
'bocciaen': ('boccia',),
'bocciaene': ('boccia',),
'bocciaer': ('boccia',),
'bod': ('bod',),
'boden': ('bod',),
'bodene': ('bod',),
'boder': ('bod',),
'bodega': ('bodega',),
'bodegaen': ('bodega',),
'bodegaene': ('bodega',),
'bodegaer': ('bodega',),
'bodybuilding': ('bodybuilding',),
'bodybuildinga': ('bodybuilding',),
'bodybuildingen': ('bodybuilding',),
'bodybuildingene': ('bodybuilding',),
'bodybuildinger': ('bodybuilding',),
'boer': ('boer',),
'boere': ('boer',),
'boeren': ('boer',),
'boerer': ('boer',),
'boerne': ('boer',),
'bofellesskap': ('bofellesskap',),
'bofellesskapa': ('bofellesskap',),
'bofellesskapene': ('bofellesskap',),
'bofellesskaper': ('bofellesskap',),
'bofellesskapet': ('bofellesskap',),
'boflata': ('boflate',),
'boflate': ('boflate',),
'boflaten': ('boflate',),
'boflatene': ('boflate',),
'boflater': ('boflate',),
'boform': ('boform',),
'boforma': ('boform',),
'boformen': ('boform',),
'boformene': ('boform',),
'boformer': ('boform',),
'bog': ('bog',),
'bogen': ('bog',),
'bogene': ('bog',),
'boger': ('bog',),
'boge': ('boge',),
'bogen': ('boge',),
'bogene': ('boge',),
'boger': ('boge',),
'bogebro': ('bogebro',),
'bogebroa': ('bogebro',),
'bogebroen': ('bogebro',),
'bogebroene': ('bogebro',),
'bogebroer': ('bogebro',),
'bogebru': ('bogebru',),
'bogebrua': ('bogebru',),
'bogebruen': ('bogebru',),
'bogebruene': ('bogebru',),
'bogebruer': ('bogebru',),
'bogegang': ('bogegang',),
'bogegangen': ('bogegang',),
'bogegangene': ('bogegang',),
'bogeganger': ('bogegang',),
'bogegrad': ('bogegrad',),
'bogegraden': ('bogegrad',),
'bogegradene': ('bogegrad',),
'bogegrader': ('bogegrad',),
'bogeminutt': ('bogeminutt',),
'bogeminutta': ('bogeminutt',),
'bogeminuttene': ('bogeminutt',),
'bogeminutter': ('bogeminutt',),
'bogeminuttet': ('bogeminutt',),
'bogeparentes': ('bogeparentes',),
'bogeparentesen': ('bogeparentes',),
'bogeparentesene': ('bogeparentes',),
'bogeparenteser': ('bogeparentes',),
'bogesag': ('bogesag',),
'bogesaga': ('bogesag',),
'bogesagen': ('bogesag',),
'bogesagene': ('bogesag',),
'bogesager': ('bogesag',),
'bogesekund': ('bogesekund',),
'bogesekunda': ('bogesekund',),
'bogesekundene': ('bogesekund',),
'bogesekunder': ('bogesekund',),
'bogesekundet': ('bogesekund',),
'bogestreng': ('bogestreng',),
'bogestrengen': ('bogestreng',),
'bogestrengene': ('bogestreng',),
'bogestrenger': ('bogestreng',),
'bogetak': ('bogetak',),
'bogetaka': ('bogetak',),
'bogetakene': ('bogetak',),
'bogetaket': ('bogetak',),
'bogevindu': ('bogevindu',),
'bogevindua': ('bogevindu',),
'bogevinduene': ('bogevindu',),
'bogevinduer': ('bogevindu',),
'bogevinduet': ('bogevindu',),
'boggi': ('boggi',),
'boggien': ('boggi',),
'boggiene': ('boggi',),
'boggier': ('boggi',),
'boggivogn': ('boggivogn',),
'boggivogna': ('boggivogn',),
'boggivognen': ('boggivogn',),
'boggivognene': ('boggivogn',),
'boggivogner': ('boggivogn',),
'bogtre': ('bogtre',),
'bogtrea': ('bogtre',),
'bogtreet': ('bogtre',),
'bogtrær': ('bogtre',),
'bogtrærne': ('bogtre',),
'bohava': ('bohave',),
'bohave': ('bohave',),
'bohavene': ('bohave',),
'bohaver': ('bohave',),
'bohavet': ('bohave',),
'bohem': ('bohem',),
'bohemen': ('bohem',),
'bohemene': ('bohem',),
'bohemer': ('bohem',),
'bohembevegelse': ('bohembevegelse',),
'bohembevegelsen': ('bohembevegelse',),
'bohembevegelsene': ('bohembevegelse',),
'bohembevegelser': ('bohembevegelse',),
'boi': ('boi',),
'boien': ('boi',),
'boiene': ('boi',),
'boier': ('boi',),
'boikott': ('boikott',),
'boikotten': ('boikott',),
'boikottene': ('boikott',),
'boikotter': ('boikott',),
'bojar': ('bojar',),
'bojaren': ('bojar',),
'bojarene': ('bojar',),
'bojarer': ('bojar',),
'bok': ('bok',),
'boka': ('bok',),
'boken': ('bok',),
'bokene': ('bok',),
'boker': ('bok',),
'bok': ('bok',),
'boka': ('bok',),
'boken': ('bok',),
'bøkene': ('bok',),
'bøker': ('bok',),
'bokanmeldelse': ('bokanmeldelse',),
'bokanmeldelsen': ('bokanmeldelse',),
'bokanmeldelsene': ('bokanmeldelse',),
'bokanmeldelser': ('bokanmeldelse',),
'bokanmelder': ('bokanmelder',),
'bokanmeldere': ('bokanmelder',),
'bokanmelderen': ('bokanmelder',),
'bokanmelderer': ('bokanmelder',),
'bokanmelderne': ('bokanmelder',),
'bokbind': ('bokbind',),
'bokbinda': ('bokbind',),
'bokbindene': ('bokbind',),
'bokbindet': ('bokbind',),
'bokbinder': ('bokbinder',),
'bokbindere': ('bokbinder',),
'bokbinderen': ('bokbinder',),
'bokbinderer': ('bokbinder',),
'bokbinderne': ('bokbinder',),
'bokbrenning': ('bokbrenning',),
'bokbrenninga': ('bokbrenning',),
'bokbrenningen': ('bokbrenning',),
'bokbrenningene': ('bokbrenning',),
'bokbrenninger': ('bokbrenning',),
'bokbuss': ('bokbuss',),
'bokbussen': ('bokbuss',),
'bokbussene': ('bokbuss',),
'bokbusser': ('bokbuss',),
'bokbåt': ('bokbåt',),
'bokbåten': ('bokbåt',),
'bokbåtene': ('bokbåt',),
'bokbåter': ('bokbåt',),
'bokettersyn': ('bokettersyn',),
'bokettersyna': ('bokettersyn',),
'bokettersynene': ('bokettersyn',),
'bokettersynet': ('bokettersyn',),
'bokfink': ('bokfink',),
'bokfinken': ('bokfink',),
'bokfinkene': ('bokfink',),
'bokfinker': ('bokfink',),
'bokflom': ('bokflom',),
'bokflommen': ('bokflom',),
'bokflommene': ('bokflom',),
'bokflommer': ('bokflom',),
'bokform': ('bokform',),
'bokforma': ('bokform',),
'bokformen': ('bokform',),
'bokformene': ('bokform',),
'bokformer': ('bokform',),
'bokføring': ('bokføring',),
'bokføringa': ('bokføring',),
'bokføringen': ('bokføring',),
'bokføringene': ('bokføring',),
'bokføringer': ('bokføring',),
'bokhandel': ('bokhandel',),
'bokhandelen': ('bokhandel',),
'bokhandlene': ('bokhandel',),
'bokhandler': ('bokhandel',),
'bokhandler': ('bokhandler',),
'bokhandlere': ('bokhandler',),
'bokhandleren': ('bokhandler',),
'bokhandlerer': ('bokhandler',),
'bokhandlerne': ('bokhandler',),
'bokholder': ('bokholder',),
'bokholdere': ('bokholder',),
'bokholderen': ('bokholder',),
'bokholderer': ('bokholder',),
'bokholderne': ('bokholder',),
'bokholderi': ('bokholderi',),
'bokholderia': ('bokholderi',),
'bokholderiene': ('bokholderi',),
'bokholderier': ('bokholderi',),
'bokholderiet': ('bokholderi',),
'bokhvete': ('bokhvete',),
'bokhveten': ('bokhvete',),
'bokhvetene': ('bokhvete',),
'bokhveter': ('bokhvete',),
'bokhvete': ('bokhvete',),
'bokhveten': ('bokhvete',),
'bokhvetene': ('bokhvete',),
'bokhveter': ('bokhvete',),
'bokhylla': ('bokhylle',),
'bokhylle': ('bokhylle',),
'bokhyllen': ('bokhylle',),
'bokhyllene': ('bokhylle',),
'bokhyller': ('bokhylle',),
'bokhøst': ('bokhøst',),
'bokhøsten': ('bokhøst',),
'bokhøstene': ('bokhøst',),
'bokhøster': ('bokhøst',),
'bokk': ('bokk',),
'bokken': ('bokk',),
'bokkene': ('bokk',),
'bokker': ('bokk',),
'bokklubb': ('bokklubb',),
'bokklubben': ('bokklubb',),
'bokklubbene': ('bokklubb',),
'bokklubber': ('bokklubb',),
'bokkunst': ('bokkunst',),
'bokkunsten': ('bokkunst',),
'bokkunstene': ('bokkunst',),
'bokkunster': ('bokkunst',),
'bokkveite': ('bokkveite',),
'bokkveiten': ('bokkveite',),
'bokkveitene': ('bokkveite',),
'bokkveiter': ('bokkveite',),
'bokkveite': ('bokkveite',),
'bokkveiten': ('bokkveite',),
'bokkveitene': ('bokkveite',),
'bokkveiter': ('bokkveite',),
'bokkøl': ('bokkøl',),
'bokkøla': ('bokkøl',),
'bokkølet': ('bokkøl',),
'boklade': ('boklade',),
'bokladen': ('boklade',),
'bokladene': ('boklade',),
'boklader': ('boklade',),
'bokladepris': ('bokladepris',),
'bokladeprisen': ('bokladepris',),
'bokladeprisene': ('bokladepris',),
'bokladepriser': ('bokladepris',),
'bokmelder': ('bokmelder',),
'bokmeldere': ('bokmelder',),
'bokmelderen': ('bokmelder',),
'bokmelderer': ('bokmelder',),
'bokmelderne': ('bokmelder',),
'bokmelding': ('bokmelding',),
'bokmeldinga': ('bokmelding',),
'bokmeldingen': ('bokmelding',),
'bokmeldingene': ('bokmelding',),
'bokmeldinger': ('bokmelding',),
'bokmerka': ('bokmerke',),
'bokmerke': ('bokmerke',),
'bokmerkene': ('bokmerke',),
'bokmerker': ('bokmerke',),
'bokmerket': ('bokmerke',),
'bokmål': ('bokmål',),
'bokmåla': ('bokmål',),
'bokmålene': ('bokmål',),
'bokmålet': ('bokmål',),
'bokmålstekst': ('bokmålstekst',),
'bokmålsteksta': ('bokmålstekst',),
'bokmålsteksten': ('bokmålstekst',),
'bokmålstekstene': ('bokmålstekst',),
'bokmålstekster': ('bokmålstekst',),
'bokmålsutgava': ('bokmålsutgave',),
'bokmålsutgave': ('bokmålsutgave',),
'bokmålsutgaven': ('bokmålsutgave',),
'bokmålsutgavene': ('bokmålsutgave',),
'bokmålsutgaver': ('bokmålsutgave',),
'boknefisk': ('boknefisk',),
'boknefisken': ('boknefisk',),
'boknefiskene': ('boknefisk',),
'boknefisker': ('boknefisk',),
'boknesild': ('boknesild',),
'boknesilda': ('boknesild',),
'boknesildene': ('boknesild',),
'boknesilder': ('boknesild',),
'bokollektiv': ('bokollektiv',),
'bokollektiva': ('bokollektiv',),
'bokollektivene': ('bokollektiv',),
'bokollektiver': ('bokollektiv',),
'bokollektivet': ('bokollektiv',),
'bokorm': ('bokorm',),
'bokormen': ('bokorm',),
'bokormene': ('bokorm',),
'bokormer': ('bokorm',),
'bokreditt': ('bokreditt',),
'bokreditten': ('bokreditt',),
'bokredittene': ('bokreditt',),
'bokreditter': ('bokreditt',),
'bokreol': ('bokreol',),
'bokreolen': ('bokreol',),
'bokreolene': ('bokreol',),
'bokreoler': ('bokreol',),
'boks': ('boks',),
'boksen': ('boks',),
'boksene': ('boks',),
'bokser': ('boks',),
'boks': ('boks',),
'boksen': ('boks',),
'boksene': ('boks',),
'bokser': ('boks',),
'boksamler': ('boksamler',),
'boksamlere': ('boksamler',),
'boksamleren': ('boksamler',),
'boksamlerer': ('boksamler',),
'boksamlerne': ('boksamler',),
'boksamling': ('boksamling',),
'boksamlinga': ('boksamling',),
'boksamlingen': ('boksamling',),
'boksamlingene': ('boksamling',),
'boksamlinger': ('boksamling',),
'boksehanske': ('boksehanske',),
'boksehansken': ('boksehanske',),
'boksehanskene': ('boksehanske',),
'boksehansker': ('boksehanske',),
'boksekamp': ('boksekamp',),
'boksekampen': ('boksekamp',),
'boksekampene': ('boksekamp',),
'boksekamper': ('boksekamp',),
'bokser': ('bokser',),
'boksere': ('bokser',),
'bokseren': ('bokser',),
'bokserer': ('bokser',),
'bokserne': ('bokser',),
'bokser': ('bokser',),
'boksere': ('bokser',),
'bokseren': ('bokser',),
'bokserer': ('bokser',),
'bokserne': ('bokser',),
'boksering': ('boksering',),
'bokseringen': ('boksering',),
'bokseringene': ('boksering',),
'bokseringer': ('boksering',),
'boksermotor': ('boksermotor',),
'boksermotoren': ('boksermotor',),
'boksermotorene': ('boksermotor',),
'boksermotorer': ('boksermotor',),
'bokskalv': ('bokskalv',),
'bokskalven': ('bokskalv',),
'bokskalvene': ('bokskalv',),
'bokskalver': ('bokskalv',),
'bokskalvsko': ('bokskalvsko',),
'bokskalvskoa': ('bokskalvsko',),
'bokskalvskoen': ('bokskalvsko',),
'bokskalvskoene': ('bokskalvsko',),
'bokskalvskor': ('bokskalvsko',),
'bokskalvskorne': ('bokskalvsko',),
'bokskred': ('bokskred',),
'bokskreda': ('bokskred',),
'bokskredene': ('bokskred',),
'bokskredet': ('bokskred',),
'bokspråk': ('bokspråk',),
'bokspråka': ('bokspråk',),
'bokspråkene': ('bokspråk',),
'bokspråket': ('bokspråk',),
'bokstav': ('bokstav',),
'bokstaven': ('bokstav',),
'bokstavene': ('bokstav',),
'bokstaver': ('bokstav',),
'bokstavord': ('bokstavord',),
'bokstavorda': ('bokstavord',),
'bokstavordene': ('bokstavord',),
'bokstavordet': ('bokstavord',),
'bokstavregning': ('bokstavregning',),
'bokstavregninga': ('bokstavregning',),
'bokstavregningen': ('bokstavregning',),
'bokstavregningene': ('bokstavregning',),
'bokstavregninger': ('bokstavregning',),
'bokstavrekning': ('bokstavrekning',),
'bokstavrekninga': ('bokstavrekning',),
'bokstavrekningen': ('bokstavrekning',),
'bokstavrekningene': ('bokstavrekning',),
'bokstavrekninger': ('bokstavrekning',),
'bokstavrim': ('bokstavrim',),
'bokstavrima': ('bokstavrim',),
'bokstavrimene': ('bokstavrim',),
'bokstavrimet': ('bokstavrim',),
'bokstavtrelldom': ('bokstavtrelldom',),
'bokstavtrelldommen': ('bokstavtrelldom',),
'bokstavtrelldommene': ('bokstavtrelldom',),
'bokstavtrelldommer': ('bokstavtrelldom',),
'boksåpner': ('boksåpner',),
'boksåpnere': ('boksåpner',),
'boksåpneren': ('boksåpner',),
'boksåpnerer': ('boksåpner',),
'boksåpnerne': ('boksåpner',),
'boksøl': ('boksøl',),
'boksøla': ('boksøl',),
'boksølet': ('boksøl',),
'boktitlene': ('boktittel',),
'boktitler': ('boktittel',),
'boktittel': ('boktittel',),
'boktittelen': ('boktittel',),
'boktrykk': ('boktrykk',),
'boktrykka': ('boktrykk',),
'boktrykkene': ('boktrykk',),
'boktrykket': ('boktrykk',),
'boktrykker': ('boktrykker',),
'boktrykkere': ('boktrykker',),
'boktrykkeren': ('boktrykker',),
'boktrykkerer': ('boktrykker',),
'boktrykkerne': ('boktrykker',),
'boktrykkeri': ('boktrykkeri',),
'boktrykkeria': ('boktrykkeri',),
'boktrykkeriene': ('boktrykkeri',),
'boktrykkerier': ('boktrykkeri',),
'boktrykkeriet': ('boktrykkeri',),
'boktrykkerkunst': ('boktrykkerkunst',),
'boktrykkerkunsten': ('boktrykkerkunst',),
'boktrykkerkunstene': ('boktrykkerkunst',),
'boktrykkerkunster': ('boktrykkerkunst',),
'bokverden': ('bokverden',),
'bokverdenen': ('bokverden',),
'bokverdenene': ('bokverden',),
'bokverdener': ('bokverden',),
'bol': ('bol',),
'bolen': ('bol',),
'bolene': ('bol',),
'boler': ('bol',),
'bol': ('bol',),
'bola': ('bol',),
'bolene': ('bol',),
'bolet': ('bol',),
'bolero': ('bolero',),
'boleroen': ('bolero',),
'boleroene': ('bolero',),
'boleroer': ('bolero',),
'bolig': ('bolig',),
'boligen': ('bolig',),
'boligene': ('bolig',),
'boliger': ('bolig',),
'boligblokk': ('boligblokk',),
'boligblokka': ('boligblokk',),
'boligblokken': ('boligblokk',),
'boligblokkene': ('boligblokk',),
'boligblokker': ('boligblokk',),
'boligbyggelag': ('boligbyggelag',),
'boligbyggelaga': ('boligbyggelag',),
'boligbyggelagene': ('boligbyggelag',),
'boligbyggelaget': ('boligbyggelag',),
'boligbygging': ('boligbygging',),
'boligbygginga': ('boligbygging',),
'boligbyggingen': ('boligbygging',),
'boligbyggingene': ('boligbygging',),
'boligbygginger': ('boligbygging',),
'boligdekk': ('boligdekk',),
'boligdekka': ('boligdekk',),
'boligdekkene': ('boligdekk',),
'boligdekket': ('boligdekk',),
'boligfelt': ('boligfelt',),
'boligfelta': ('boligfelt',),
'boligfeltene': ('boligfelt',),
'boligfelter': ('boligfelt',),
'boligfeltet': ('boligfelt',),
'boligfinansiering': ('boligfinansiering',),
'boligfinansieringa': ('boligfinansiering',),
'boligfinansieringen': ('boligfinansiering',),
'boligfinansieringene': ('boligfinansiering',),
'boligfinansieringer': ('boligfinansiering',),
'boligforhold': ('boligforhold',),
'boligforholda': ('boligforhold',),
'boligforholdene': ('boligforhold',),
'boligforholdet': ('boligforhold',),
'boligformidling': ('boligformidling',),
'boligformidlinga': ('boligformidling',),
'boligformidlingen': ('boligformidling',),
'boligformidlingene': ('boligformidling',),
'boligformidlinger': ('boligformidling',),
'bolighai': ('bolighai',),
'bolighaien': ('bolighai',),
'bolighaiene': ('bolighai',),
'bolighaier': ('bolighai',),
'boliglån': ('boliglån',),
'boliglåna': ('boliglån',),
'boliglånene': ('boliglån',),
'boliglånet': ('boliglån',),
'boligmarked': ('boligmarked',),
'boligmarkeda': ('boligmarked',),
'boligmarkedene': ('boligmarked',),
'boligmarkeder': ('boligmarked',),
'boligmarkedet': ('boligmarked',),
'boligmarknad': ('boligmarknad',),
'boligmarknaden': ('boligmarknad',),
'boligmarknadene': ('boligmarknad',),
'boligmarknader': ('boligmarknad',),
'boligmasse': ('boligmasse',),
'boligmassen': ('boligmasse',),
'boligmassene': ('boligmasse',),
'boligmasser': ('boligmasse',),
'boligmiljø': ('boligmiljø',),
'boligmiljøa': ('boligmiljø',),
'boligmiljøene': ('boligmiljø',),
'boligmiljøer': ('boligmiljø',),
'boligmiljøet': ('boligmiljø',),
'boligområda': ('boligområde',),
'boligområde': ('boligområde',),
'boligområdene': ('boligområde',),
'boligområder': ('boligområde',),
'boligområdet': ('boligområde',),
'boligplattform': ('boligplattform',),
'boligplattforma': ('boligplattform',),
'boligplattformen': ('boligplattform',),
'boligplattformene': ('boligplattform',),
'boligplattformer': ('boligplattform',),
'boligreising': ('boligreising',),
'boligreisinga': ('boligreising',),
'boligreisingen': ('boligreising',),
'boligreisingene': ('boligreising',),
'boligreisinger': ('boligreising',),
'boligstandard': ('boligstandard',),
'boligstandarden': ('boligstandard',),
'boligstandardene': ('boligstandard',),
'boligstandarder': ('boligstandard',),
'boligtelefon': ('boligtelefon',),
'boligtelefonen': ('boligtelefon',),
'boligtelefonene': ('boligtelefon',),
'boligtelefoner': ('boligtelefon',),
'boligtomt': ('boligtomt',),
'boligtomta': ('boligtomt',),
'boligtomten': ('boligtomt',),
'boligtomtene': ('boligtomt',),
'boligtomter': ('boligtomt',),
'bolivianer': ('bolivianer',),
'bolivianere': ('bolivianer',),
'bolivianeren': ('bolivianer',),
'bolivianerer': ('bolivianer',),
'bolivianerne': ('bolivianer',),
'bolk': ('bolk',),
'bolken': ('bolk',),
'bolkene': ('bolk',),
'bolker': ('bolk',),
'bolle': ('bolle',),
'bollen': ('bolle',),
'bollene': ('bolle',),
'boller': ('bolle',),
'bolle': ('bolle',),
'bollen': ('bolle',),
'bollene': ('bolle',),
'boller': ('bolle',),
'bolleansikt': ('bolleansikt',),
'bolleansikta': ('bolleansikt',),
'bolleansiktene': ('bolleansikt',),
'bolleansikter': ('bolleansikt',),
'bolleansiktet': ('bolleansikt',),
'bolledeig': ('bolledeig',),
'bolledeigen': ('bolledeig',),
'bolledeigene': ('bolledeig',),
'bolledeiger': ('bolledeig',),
'bollekinn': ('bollekinn',),
'bollekinna': ('bollekinn',),
'bollekinnene': ('bollekinn',),
'bollekinner': ('bollekinn',),
'bollekinnet': ('bollekinn',),
'bolsjevik': ('bolsjevik',),
'bolsjeviken': ('bolsjevik',),
'bolsjevikene': ('bolsjevik',),
'bolsjeviker': ('bolsjevik',),
'bolsok': ('bolsok',),
'bolsoken': ('bolsok',),
'bolsokene': ('bolsok',),
'bolsoker': ('bolsok',),
'bolt': ('bolt',),
'bolten': ('bolt',),
'boltene': ('bolt',),
'bolter': ('bolt',),
'bolverk': ('bolverk',),
'bolverka': ('bolverk',),
'bolverkene': ('bolverk',),
'bolverker': ('bolverk',),
'bolverket': ('bolverk',),
'bomaskin': ('bomaskin',),
'bomaskina': ('bomaskin',),
'bomaskinen': ('bomaskin',),
'bomaskinene': ('bomaskin',),
'bomaskiner': ('bomaskin',),
'bombardement': ('bombardement',),
'bombardementa': ('bombardement',),
'bombardementene': ('bombardement',),
'bombardementer': ('bombardement',),
'bombardementet': ('bombardement',),
'bombasin': ('bombasin',),
'bombasina': ('bombasin',),
'bombasinen': ('bombasin',),
'bombasinene': ('bombasin',),
'bombasiner': ('bombasin',),
'bombasinet': ('bombasin',),
'bombast': ('bombast',),
'bombasten': ('bombast',),
'bombastene': ('bombast',),
'bombaster': ('bombast',),
'bomba': ('bombe',),
'bombe': ('bombe',),
'bomben': ('bombe',),
'bombene': ('bombe',),
'bomber': ('bombe',),
'bombeangrep': ('bombeangrep',),
'bombeangrepa': ('bombeangrep',),
'bombeangrepene': ('bombeangrep',),
'bombeangrepet': ('bombeangrep',),
'bombeattentat': ('bombeattentat',),
'bombeattentata': ('bombeattentat',),
'bombeattentatene': ('bombeattentat',),
'bombeattentater': ('bombeattentat',),
'bombeattentatet': ('bombeattentat',),
'bombefly': ('bombefly',),
'bombeflya': ('bombefly',),
'bombeflyene': ('bombefly',),
'bombeflyet': ('bombefly',),
'bombekaster': ('bombekaster',),
'bombekastere': ('bombekaster',),
'bombekasteren': ('bombekaster',),
'bombekasterer': ('bombekaster',),
'bombekasterne': ('bombekaster',),
'bomber': ('bomber',),
'bombere': ('bomber',),
'bomberen': ('bomber',),
'bomberer': ('bomber',),
'bomberne': ('bomber',),
'bomberegn': ('bomberegn',),
'bomberegna': ('bomberegn',),
'bomberegnene': ('bomberegn',),
'bomberegnet': ('bomberegn',),
'bomberom': ('bomberom',),
'bomberomma': ('bomberom',),
'bomberommene': ('bomberom',),
'bomberommet': ('bomberom',),
'bomkast': ('bomkast',),
'bomkasta': ('bomkast',),
'bomkastene': ('bomkast',),
'bomkastet': ('bomkast',),
'bomma': ('bomme',),
'bomme': ('bomme',),
'bommen': ('bomme',),
'bommene': ('bomme',),
'bommer': ('bomme',),
'bommer': ('bommer',),
'bommere': ('bommer',),
'bommeren': ('bommer',),
'bommerer': ('bommer',),
'bommerne': ('bommer',),
'bommert': ('bommert',),
'bommerten': ('bommert',),
'bommertene': ('bommert',),
'bommerter': ('bommert',),
'bommesi': ('bommesi',),
'bommesien': ('bommesi',),
'bommesiene': ('bommesi',),
'bommesier': ('bommesi',),
'bomolja': ('bomolje',),
'bomolje': ('bomolje',),
'bomoljen': ('bomolje',),
'bomoljene': ('bomolje',),
'bomoljer': ('bomolje',),
'bompengene': ('bompenger',),
'bompenger': ('bompenger',),
'boms': ('boms',),
'bomsen': ('boms',),
'bomsene': ('boms',),
'bomser': ('boms',),
'bomskott': ('bomskott',),
'bomskotta': ('bomskott',),
'bomskottene': ('bomskott',),
'bomskottet': ('bomskott',),
'bomskudd': ('bomskudd',),
'bomskudda': ('bomskudd',),
'bomskuddene': ('bomskudd',),
'bomskuddet': ('bomskudd',),
'bomtur': ('bomtur',),
'bomturen': ('bomtur',),
'bomturene': ('bomtur',),
'bomturer': ('bomtur',),
'bomull': ('bomull',),
'bomulla': ('bomull',),
'bomullen': ('bomull',),
'bomullene': ('bomull',),
'bomuller': ('bomull',),
'bomullsgarn': ('bomullsgarn',),
'bomullsgarna': ('bomullsgarn',),
'bomullsgarnene': ('bomullsgarn',),
'bomullsgarnet': ('bomullsgarn',),
'bomullsgenser': ('bomullsgenser',),
'bomullsgensere': ('bomullsgenser',),
'bomullsgenseren': ('bomullsgenser',),
'bomullsgenserer': ('bomullsgenser',),
'bomullsgenserne': ('bomullsgenser',),
'bomullsplantasje': ('bomullsplantasje',),
'bomullsplantasjen': ('bomullsplantasje',),
'bomullsplantasjene': ('bomullsplantasje',),
'bomullsplantasjer': ('bomullsplantasje',),
'bomullsplanta': ('bomullsplante',),
'bomullsplante': ('bomullsplante',),
'bomullsplanten': ('bomullsplante',),
'bomullsplantene': ('bomullsplante',),
'bomullsplanter': ('bomullsplante',),
'bomullsstoff': ('bomullsstoff',),
'bomullsstoffa': ('bomullsstoff',),
'bomullsstoffene': ('bomullsstoff',),
'bomullsstoffer': ('bomullsstoff',),
'bomullsstoffet': ('bomullsstoff',),
'bomvakt': ('bomvakt',),
'bomvakta': ('bomvakt',),
'bomvakten': ('bomvakt',),
'bomvaktene': ('bomvakt',),
'bomvakter': ('bomvakt',),
'bomveg': ('bomveg',),
'bomvegen': ('bomveg',),
'bomvegene': ('bomveg',),
'bomveger': ('bomveg',),
'bomvei': ('bomvei',),
'bomveien': ('bomvei',),
'bomveiene': ('bomvei',),
'bomveier': ('bomvei',),
'bonde': ('bonde',),
'bonden': ('bonde',),
'bøndene': ('bonde',),
'bønder': ('bonde',),
'bondeanger': ('bondeanger',),
'bondeangere': ('bondeanger',),
'bondeangeren': ('bondeanger',),
'bondeangerer': ('bondeanger',),
'bondeangerne': ('bondeanger',),
'bondeangre': ('bondeanger',),
'bondeangrene': ('bondeanger',),
'bondeangrer': ('bondeanger',),
'bondefanger': ('bondefanger',),
'bondefangere': ('bondefanger',),
'bondefangeren': ('bondefanger',),
'bondefangerer': ('bondefanger',),
'bondefangerne': ('bondefanger',),
'bondefangeri': ('bondefangeri',),
'bondefangeria': ('bondefangeri',),
'bondefangeriene': ('bondefangeri',),
'bondefangerier': ('bondefangeri',),
'bondefangeriet': ('bondefangeri',),
'bondefortelling': ('bondefortelling',),
'bondefortellinga': ('bondefortelling',),
'bondefortellingen': ('bondefortelling',),
'bondefortellingene': ('bondefortelling',),
'bondefortellinger': ('bondefortelling',),
'bondegard': ('bondegard',),
'bondegarden': ('bondegard',),
'bondegardene': ('bondegard',),
'bondegarder': ('bondegard',),
'bondegardsferie': ('bondegardsferie',),
'bondegardsferien': ('bondegardsferie',),
'bondegardsferiene': ('bondegardsferie',),
'bondegardsferier': ('bondegardsferie',),
'bondegård': ('bondegård',),
'bondegården': ('bondegård',),
'bondegårdene': ('bondegård',),
'bondegårder': ('bondegård',),
'bondegårdsferie': ('bondegårdsferie',),
'bondegårdsferien': ('bondegårdsferie',),
'bondegårdsferiene': ('bondegårdsferie',),
'bondegårdsferier': ('bondegårdsferie',),
'bondekultur': ('bondekultur',),
'bondekulturen': ('bondekultur',),
'bondekulturene': ('bondekultur',),
'bondekulturer': ('bondekultur',),
'bondelag': ('bondelag',),
'bondelaga': ('bondelag',),
'bondelagene': ('bondelag',),
'bondelaget': ('bondelag',),
'bondepika': ('bondepike',),
'bondepike': ('bondepike',),
'bondepiken': ('bondepike',),
'bondepikene': ('bondepike',),
'bondepiker': ('bondepike',),
'bonderomantikk': ('bonderomantikk',),
'bonderomantikken': ('bonderomantikk',),
'bonderomantikkene': ('bonderomantikk',),
'bonderomantikker': ('bonderomantikk',),
'bondevett': ('bondevett',),
'bondevetta': ('bondevett',),
'bondevettene': ('bondevett',),
'bondevettet': ('bondevett',),
'bonevoks': ('bonevoks',),
'bonevoksa': ('bonevoks',),
'bonevoksen': ('bonevoks',),
'bonevoksene': ('bonevoks',),
'bonevokser': ('bonevoks',),
'bonevokset': ('bonevoks',),
'bong': ('bong',),
'bongen': ('bong',),
'bongene': ('bong',),
'bonger': ('bong',),
'bongbong': ('bongbong',),
'bongbongen': ('bongbong',),
'bongbongene': ('bongbong',),
'bongbonger': ('bongbong',),
'bongotromma': ('bongotromme',),
'bongotromme': ('bongotromme',),
'bongotrommen': ('bongotromme',),
'bongotrommene': ('bongotromme',),
'bongotrommer': ('bongotromme',),
'bonitet': ('bonitet',),
'boniteten': ('bonitet',),
'bonitetene': ('bonitet',),
'boniteter': ('bonitet',),
'bonjour': ('bonjour',),
'bonjouren': ('bonjour',),
'bonjourene': ('bonjour',),
'bonjourer': ('bonjour',),
'bonmot': ('bonmot',),
'bonmota': ('bonmot',),
'bonmotene': ('bonmot',),
'bonmoter': ('bonmot',),
'bonmotet': ('bonmot',),
'bonus': ('bonus',),
'bonusen': ('bonus',),
'bonusene': ('bonus',),
'bonuser': ('bonus',),
'boogie-woogie': ('boogie-woogie',),
'boogie-woogien': ('boogie-woogie',),
'boogie-woogiene': ('boogie-woogie',),
'boogie-woogier': ('boogie-woogie',),
'bookmaker': ('bookmaker',),
'bookmakere': ('bookmaker',),
'bookmakeren': ('bookmaker',),
'bookmakerer': ('bookmaker',),
'bookmakerne': ('bookmaker',),
'boom': ('boom',),
'boomen': ('boom',),
'boomene': ('boom',),
'boomer': ('boom',),
'booster': ('booster',),
'boostere': ('booster',),
'boosteren': ('booster',),
'boosterer': ('booster',),
'boosterne': ('booster',),
'bop': ('bop',),
'bopen': ('bop',),
'bopene': ('bop',),
'boper': ('bop',),
'bopel': ('bopel',),
'bopelen': ('bopel',),
'bopelene': ('bopel',),
'bopeler': ('bopel',),
'boplikt': ('boplikt',),
'boplikta': ('boplikt',),
'boplikten': ('boplikt',),
'bopliktene': ('boplikt',),
'boplikter': ('boplikt',),
'bor': ('bor',),
'bora': ('bor',),
'boren': ('bor',),
'borene': ('bor',),
'boret': ('bor',),
'boraks': ('boraks',),
'boraksen': ('boraks',),
'boraksene': ('boraks',),
'borakser': ('boraks',),
'borat': ('borat',),
'borata': ('borat',),
'boratene': ('borat',),
'borater': ('borat',),
'boratet': ('borat',),
'bord': ('bord',),
'borden': ('bord',),
'bordene': ('bord',),
'border': ('bord',),
'bord': ('bord',),
'borden': ('bord',),
'bordene': ('bord',),
'border': ('bord',),
'bord': ('bord',),
'borda': ('bord',),
'bordene': ('bord',),
'border': ('bord',),
'bordet': ('bord',),
'bordbein': ('bordbein',),
'bordbeina': ('bordbein',),
'bordbeinene': ('bordbein',),
'bordbeinet': ('bordbein',),
'bordben': ('bordben',),
'bordbena': ('bordben',),
'bordbenene': ('bordben',),
'bordbenet': ('bordben',),
'bordbønn': ('bordbønn',),
'bordbønna': ('bordbønn',),
'bordbønnen': ('bordbønn',),
'bordbønnene': ('bordbønn',),
'bordbønner': ('bordbønn',),
'borddama': ('borddame',),
'borddame': ('borddame',),
'borddamen': ('borddame',),
'borddamene': ('borddame',),
'borddamer': ('borddame',),
'borddans': ('borddans',),
'borddansen': ('borddans',),
'borddansene': ('borddans',),
'borddanser': ('borddans',),
'borda': ('borde',),
'borde': ('borde',),
'borden': ('borde',),
'bordene': ('borde',),
'border': ('borde',),
'borda': ('borde',),
'borde': ('borde',),
'borden': ('borde',),
'bordene': ('borde',),
'border': ('borde',),
'bordeaux': ('bordeaux',),
'bordeauxen': ('bordeaux',),
'bordeauxene': ('bordeaux',),
'bordeauxer': ('bordeaux',),
'bordeauxvin': ('bordeauxvin',),
'bordeauxvinen': ('bordeauxvin',),
'bordeauxvinene': ('bordeauxvin',),
'bordeauxviner': ('bordeauxvin',),
'bordell': ('bordell',),
'bordella': ('bordell',),
'bordellen': ('bordell',),
'bordellene': ('bordell',),
'bordeller': ('bordell',),
'bordellet': ('bordell',),
'bordellkvarter': ('bordellkvarter',),
'bordellkvartera': ('bordellkvarter',),
'bordellkvarterene': ('bordellkvarter',),
'bordellkvarterer': ('bordellkvarter',),
'bordellkvarteret': ('bordellkvarter',),
'bordkalender': ('bordkalender',),
'bordkalendere': ('bordkalender',),
'bordkalenderen': ('bordkalender',),
'bordkalenderer': ('bordkalender',),
'bordkalenderne': ('bordkalender',),
'bordkalendre': ('bordkalender',),
'bordkalendrene': ('bordkalender',),
'bordkalendrer': ('bordkalender',),
'bordkavaler': ('bordkavaler',),
'bordkavaleren': ('bordkavaler',),
'bordkavalerene': ('bordkavaler',),
'bordkavalerer': ('bordkavaler',),
'bordkledning': ('bordkledning',),
'bordkledninga': ('bordkledning',),
'bordkledningen': ('bordkledning',),
'bordkledningene': ('bordkledning',),
'bordkledninger': ('bordkledning',),
'bordkort': ('bordkort',),
'bordkorta': ('bordkort',),
'bordkortene': ('bordkort',),
'bordkortet': ('bordkort',),
'bordpakning': ('bordpakning',),
'bordpakninga': ('bordpakning',),
'bordpakningen': ('bordpakning',),
'bordpakningene': ('bordpakning',),
'bordpakninger': ('bordpakning',),
'bordsetning': ('bordsetning',),
'bordsetninga': ('bordsetning',),
'bordsetningen': ('bordsetning',),
'bordsetningene': ('bordsetning',),
'bordsetninger': ('bordsetning',),
'bordskikk': ('bordskikk',),
'bordskikken': ('bordskikk',),
'bordskikkene': ('bordskikk',),
'bordskikker': ('bordskikk',),
'bordtale': ('bordtale',),
'bordtalen': ('bordtale',),
'bordtalene': ('bordtale',),
'bordtaler': ('bordtale',),
'bordtennis': ('bordtennis',),
'bordtennisen': ('bordtennis',),
'bordtennisene': ('bordtennis',),
'bordtenniser': ('bordtennis',),
'bordvers': ('bordvers',),
'bordversa': ('bordvers',),
'bordversene': ('bordvers',),
'bordverset': ('bordvers',),
'borebille': ('borebille',),
'borebillen': ('borebille',),
'borebillene': ('borebille',),
'borebiller': ('borebille',),
'boredekk': ('boredekk',),
'boredekka': ('boredekk',),
'boredekkene': ('boredekk',),
'boredekket': ('boredekk',),
'borefartøy': ('borefartøy',),
'borefartøya': ('borefartøy',),
'borefartøyene': ('borefartøy',),
'borefartøyer': ('borefartøy',),
'borefartøyet': ('borefartøy',),
'borehol': ('borehol',),
'borehola': ('borehol',),
'boreholene': ('borehol',),
'boreholet': ('borehol',),
'borehull': ('borehull',),
'borehulla': ('borehull',),
'borehullene': ('borehull',),
'borehuller': ('borehull',),
'borehullet': ('borehull',),
'boremusling': ('boremusling',),
'boremuslingen': ('boremusling',),
'boremuslingene': ('boremusling',),
'boremuslinger': ('boremusling',),
'boreplass': ('boreplass',),
'boreplassen': ('boreplass',),
'boreplassene': ('boreplass',),
'boreplasser': ('boreplass',),
'boreplattform': ('boreplattform',),
'boreplattforma': ('boreplattform',),
'boreplattformen': ('boreplattform',),
'boreplattformene': ('boreplattform',),
'boreplattformer': ('boreplattform',),
'borerigg': ('borerigg',),
'boreriggen': ('borerigg',),
'boreriggene': ('borerigg',),
'borerigger': ('borerigg',),
'borerør': ('borerør',),
'borerøra': ('borerør',),
'borerørene': ('borerør',),
'borerøret': ('borerør',),
'boresikringsventil': ('boresikringsventil',),
'boresikringsventilen': ('boresikringsventil',),
'boresikringsventilene': ('boresikringsventil',),
'boresikringsventiler': ('boresikringsventil',),
'boreskip': ('boreskip',),
'boreskipa': ('boreskip',),
'boreskipene': ('boreskip',),
'boreskipet': ('boreskip',),
'boreslam': ('boreslam',),
'boreslamma': ('boreslam',),
'boreslammene': ('boreslam',),
'boreslammet': ('boreslam',),
'borestart': ('borestart',),
'borestarten': ('borestart',),
'borestartene': ('borestart',),
'borestarter': ('borestart',),
'borestreng': ('borestreng',),
'borestrengen': ('borestreng',),
'borestrengene': ('borestreng',),
'borestrenger': ('borestreng',),
'borettslag': ('borettslag',),
'borettslaga': ('borettslag',),
'borettslagene': ('borettslag',),
'borettslaget': ('borettslag',),
'boretårn': ('boretårn',),
'boretårna': ('boretårn',),
'boretårnene': ('boretårn',),
'boretårnet': ('boretårn',),
'borg': ('borg',),
'borga': ('borg',),
'borgen': ('borg',),
'borgene': ('borg',),
'borger': ('borg',),
'borg': ('borg',),
'borger': ('borger',),
'borgere': ('borger',),
'borgeren': ('borger',),
'borgerer': ('borger',),
'borgerne': ('borger',),
'borgerbrev': ('borgerbrev',),
'borgerbreva': ('borgerbrev',),
'borgerbrevene': ('borgerbrev',),
'borgerbrever': ('borgerbrev',),
'borgerbrevet': ('borgerbrev',),
'borgerdåd': ('borgerdåd',),
'borgerdåden': ('borgerdåd',),
'borgerdådene': ('borgerdåd',),
'borgerdåder': ('borgerdåd',),
'borgerdådsmedalje': ('borgerdådsmedalje',),
'borgerdådsmedaljen': ('borgerdådsmedalje',),
'borgerdådsmedaljene': ('borgerdådsmedalje',),
'borgerdådsmedaljer': ('borgerdådsmedalje',),
'borgerkrig': ('borgerkrig',),
'borgerkrigen': ('borgerkrig',),
'borgerkrigene': ('borgerkrig',),
'borgerkriger': ('borgerkrig',),
'borgerkrigstilstand': ('borgerkrigstilstand',),
'borgerkrigstilstanden': ('borgerkrigstilstand',),
'borgerkrigstilstandene': ('borgerkrigstilstand',),
'borgerkrigstilstander': ('borgerkrigstilstand',),
'borgermester': ('borgermester',),
'borgermestere': ('borgermester',),
'borgermesteren': ('borgermester',),
'borgermesterer': ('borgermester',),
'borgermesterne': ('borgermester',),
'borgermestre': ('borgermester',),
'borgermestrene': ('borgermester',),
'borgermestrer': ('borgermester',),
'borgerplikt': ('borgerplikt',),
'borgerplikta': ('borgerplikt',),
'borgerplikten': ('borgerplikt',),
'borgerpliktene': ('borgerplikt',),
'borgerplikter': ('borgerplikt',),
'borgerrett': ('borgerrett',),
'borgerretten': ('borgerrett',),
'borgerrettene': ('borgerrett',),
'borgerretter': ('borgerrett',),
'borgerrettsbevegelse': ('borgerrettsbevegelse',),
'borgerrettsbevegelsen': ('borgerrettsbevegelse',),
'borgerrettsbevegelsene': ('borgerrettsbevegelse',),
'borgerrettsbevegelser': ('borgerrettsbevegelse',),
'borgerskap': ('borgerskap',),
'borgerskapa': ('borgerskap',),
'borgerskapene': ('borgerskap',),
'borgerskapet': ('borgerskap',),
'borgertog': ('borgertog',),
'borgertoga': ('borgertog',),
'borgertogene': ('borgertog',),
'borgertoget': ('borgertog',),
'borgerånd': ('borgerånd',),
'borgerånden': ('borgerånd',),
'borgeråndene': ('borgerånd',),
'borgerånder': ('borgerånd',),
'borgfred': ('borgfred',),
'borgfreden': ('borgfred',),
'borgfredene': ('borgfred',),
'borgfreder': ('borgfred',),
'borgis': ('borgis',),
'borgisen': ('borgis',),
'borgisene': ('borgis',),
'borgiser': ('borgis',),
'borgruin': ('borgruin',),
'borgruinen': ('borgruin',),
'borgruinene': ('borgruin',),
'borgruiner': ('borgruin',),
'borgstova': ('borgstove',),
'borgstove': ('borgstove',),
'borgstoven': ('borgstove',),
'borgstovene': ('borgstove',),
'borgstover': ('borgstove',),
'borgstua': ('borgstue',),
'borgstue': ('borgstue',),
'borgstuen': ('borgstue',),
'borgstuene': ('borgstue',),
'borgstuer': ('borgstue',),
'boring': ('boring',),
'boringa': ('boring',),
'boringen': ('boring',),
'boringene': ('boring',),
'boringer': ('boring',),
'bork': ('bork',),
'borken': ('bork',),
'borkene': ('bork',),
'borker': ('bork',),
'borkrona': ('borkrone',),
'borkrone': ('borkrone',),
'borkronen': ('borkrone',),
'borkronene': ('borkrone',),
'borkroner': ('borkrone',),
'borre': ('borre',),
'borren': ('borre',),
'borrene': ('borre',),
'borrer': ('borre',),
'borra': ('borre',),
'borre': ('borre',),
'borren': ('borre',),
'borrene': ('borre',),
'borrer': ('borre',),
'borrelås': ('borrelås',),
'borrelåsa': ('borrelås',),
'borrelåsen': ('borrelås',),
'borrelåsene': ('borrelås',),
'borrelåser': ('borrelås',),
'borrelåset': ('borrelås',),
'borsj': ('borsj',),
'borsjen': ('borsj',),
'borsjene': ('borsj',),
'borsjer': ('borsj',),
'borsyra': ('borsyre',),
'borsyre': ('borsyre',),
'borsyren': ('borsyre',),
'borsyrene': ('borsyre',),
'borsyrer': ('borsyre',),
'bortebane': ('bortebane',),
'bortebanen': ('bortebane',),
'bortebanene': ('bortebane',),
'bortebaner': ('bortebane',),
'borteboer': ('borteboer',),
'borteboere': ('borteboer',),
'borteboeren': ('borteboer',),
'borteboerer': ('borteboer',),
'borteboerne': ('borteboer',),
'borteboerstipend': ('borteboerstipend',),
'borteboerstipenda': ('borteboerstipend',),
'borteboerstipendene': ('borteboerstipend',),
'borteboerstipender': ('borteboerstipend',),
'borteboerstipendet': ('borteboerstipend',),
'borteboerstipendia': ('borteboerstipendium',),
'borteboerstipendiene': ('borteboerstipendium',),
'borteboerstipendier': ('borteboerstipendium',),
'borteboerstipendiet': ('borteboerstipendium',),
'borteboerstipendium': ('borteboerstipendium',),
'bortebuer': ('bortebuer',),
'bortebuere': ('bortebuer',),
'bortebueren': ('bortebuer',),
'bortebuerer': ('bortebuer',),
'bortebuerne': ('bortebuer',),
'bortebuerstipend': ('bortebuerstipend',),
'bortebuerstipenda': ('bortebuerstipend',),
'bortebuerstipendene': ('bortebuerstipend',),
'bortebuerstipender': ('bortebuerstipend',),
'bortebuerstipendet': ('bortebuerstipend',),
'bortebuerstipendia': ('bortebuerstipendium',),
'bortebuerstipendiene': ('bortebuerstipendium',),
'bortebuerstipendier': ('bortebuerstipendium',),
'bortebuerstipendiet': ('bortebuerstipendium',),
'bortebuerstipendium': ('bortebuerstipendium',),
'bortekamp': ('bortekamp',),
'bortekampen': ('bortekamp',),
'bortekampene': ('bortekamp',),
'bortekamper': ('bortekamp',),
'bortfall': ('bortfall',),
'bortfalla': ('bortfall',),
'bortfallene': ('bortfall',),
'bortfallet': ('bortfall',),
'bortgang': ('bortgang',),
'bortgangen': ('bortgang',),
'bortgangene': ('bortgang',),
'bortganger': ('bortgang',),
'bortleia': ('bortleie',),
'bortleie': ('bortleie',),
'bortleien': ('bortleie',),
'bortleiene': ('bortleie',),
'bortleier': ('bortleie',),
'borvann': ('borvann',),
'borvanna': ('borvann',),
'borvannene': ('borvann',),
'borvannet': ('borvann',),
'borvaselin': ('borvaselin',),
'borvaselinen': ('borvaselin',),
'borvaselinene': ('borvaselin',),
'borvaseliner': ('borvaselin',),
'borvatn': ('borvatn',),
'borvatna': ('borvatn',),
'borvatnene': ('borvatn',),
'borvatnet': ('borvatn',),
'borvinda': ('borvinde',),
'borvinde': ('borvinde',),
'borvinden': ('borvinde',),
'borvindene': ('borvinde',),
'borvinder': ('borvinde',),
'bosetning': ('bosetning',),
'bosetninga': ('bosetning',),
'bosetningen': ('bosetning',),
'bosetningene': ('bosetning',),
'bosetninger': ('bosetning',),
'bosetningskart': ('bosetningskart',),
'bosetningskarta': ('bosetningskart',),
'bosetningskartene': ('bosetningskart',),
'bosetningskarter': ('bosetningskart',),
'bosetningskartet': ('bosetningskart',),
'bosetningsmønster': ('bosetningsmønster',),
'bosetningsmønsteret': ('bosetningsmønster',),
'bosetningsmønstra': ('bosetningsmønster',),
'bosetningsmønstre': ('bosetningsmønster',),
'bosetningsmønstrene': ('bosetningsmønster',),
'bosetningsmønstret': ('bosetningsmønster',),
'bosetting': ('bosetting',),
'bosettinga': ('bosetting',),
'bosettingen': ('bosetting',),
'bosettingene': ('bosetting',),
'bosettinger': ('bosetting',),
'bosettingskart': ('bosettingskart',),
'bosettingskarta': ('bosettingskart',),
'bosettingskartene': ('bosettingskart',),
'bosettingskarter': ('bosettingskart',),
'bosettingskartet': ('bosettingskart',),
'bosettingsmønster': ('bosettingsmønster',),
'bosettingsmønsteret': ('bosettingsmønster',),
'bosettingsmønstra': ('bosettingsmønster',),
'bosettingsmønstre': ('bosettingsmønster',),
'bosettingsmønstrene': ('bosettingsmønster',),
'bosettingsmønstret': ('bosettingsmønster',),
'boslodd': ('boslodd',),
'boslodden': ('boslodd',),
'bosloddene': ('boslodd',),
'boslodder': ('boslodd',),
'bosnier': ('bosnier',),
'bosniere': ('bosnier',),
'bosnieren': ('bosnier',),
'bosnierer': ('bosnier',),
'bosnierne': ('bosnier',),
'boss': ('boss',),
'bossen': ('boss',),
'bossene': ('boss',),
'bosser': ('boss',),
'boss': ('boss',),
'bossa': ('boss',),
'bossene': ('boss',),
'bosset': ('boss',),
'bossa nova': ('bossa nova',),
'bossa novaen': ('bossa nova',),
'bossa novaene': ('bossa nova',),
'bossa novaer': ('bossa nova',),
'bosted': ('bosted',),
'bostedene': ('bosted',),
'bosteder': ('bosted',),
'bostedet': ('bosted',),
'bostedsadressa': ('bostedsadresse',),
'bostedsadresse': ('bostedsadresse',),
'bostedsadressen': ('bostedsadresse',),
'bostedsadressene': ('bostedsadresse',),
'bostedsadresser': ('bostedsadresse',),
'bostedskommune': ('bostedskommune',),
'bostedskommunen': ('bostedskommune',),
'bostedskommunene': ('bostedskommune',),
'bostedskommuner': ('bostedskommune',),
'boston': ('boston',),
'bostonen': ('boston',),
'bostonene': ('boston',),
'bostoner': ('boston',),
'bostyra': ('bostyre',),
'bostyre': ('bostyre',),
'bostyrene': ('bostyre',),
'bostyrer': ('bostyre',),
'bostyret': ('bostyre',),
'bostyrer': ('bostyrer',),
'bostyrere': ('bostyrer',),
'bostyreren': ('bostyrer',),
'bostyrerer': ('bostyrer',),
'bostyrerne': ('bostyrer',),
'bostøtta': ('bostøtte',),
'bostøtte': ('bostøtte',),
'bostøtten': ('bostøtte',),
'bostøttene': ('bostøtte',),
'bostøtter': ('bostøtte',),
'bot': ('bot',),
'bota': ('bot',),
'boten': ('bot',),
'bøtene': ('bot',),
'bøter': ('bot',),
'botaniker': ('botaniker',),
'botanikere': ('botaniker',),
'botanikeren': ('botaniker',),
'botanikerer': ('botaniker',),
'botanikerne': ('botaniker',),
'botanikk': ('botanikk',),
'botanikken': ('botanikk',),
'botanikkene': ('botanikk',),
'botanikker': ('botanikk',),
'botemiddel': ('botemiddel',),
'botemiddelet': ('botemiddel',),
'botemidla': ('botemiddel',),
'botemidlene': ('botemiddel',),
'botemidler': ('botemiddel',),
'botemidlet': ('botemiddel',),
'botevon': ('botevon',),
'botevona': ('botevon',),
'botevonen': ('botevon',),
'botevonene': ('botevon',),
'botevoner': ('botevon',),
'botfor': ('botfor',),
'botforen': ('botfor',),
'botforene': ('botfor',),
'botforer': ('botfor',),
'botid': ('botid',),
'botida': ('botid',),
'botiden': ('botid',),
'botidene': ('botid',),
'botider': ('botid',),
'botn': ('botn',),
'botnen': ('botn',),
'botnene': ('botn',),
'botner': ('botn',),
'botn': ('botn',),
'botnen': ('botn',),
'botnene': ('botn',),
'botner': ('botn',),
'botnband': ('botnband',),
'botnbanda': ('botnband',),
'botnbandene': ('botnband',),
'botnbandet': ('botnband',),
'botnbord': ('botnbord',),
'botnborda': ('botnbord',),
'botnbordene': ('botnbord',),
'botnborder': ('botnbord',),
'botnbordet': ('botnbord',),
'botnbånd': ('botnbånd',),
'botnbånda': ('botnbånd',),
'botnbåndene': ('botnbånd',),
'botnbåndet': ('botnbånd',),
'botnfall': ('botnfall',),
'botnfalla': ('botnfall',),
'botnfallene': ('botnfall',),
'botnfallet': ('botnfall',),
'botnfisk': ('botnfisk',),
'botnfisken': ('botnfisk',),
'botnfiskene': ('botnfisk',),
'botnfisker': ('botnfisk',),
'botnflata': ('botnflate',),
'botnflate': ('botnflate',),
'botnflaten': ('botnflate',),
'botnflatene': ('botnflate',),
'botnflater': ('botnflate',),
'botnlag': ('botnlag',),
'botnlaga': ('botnlag',),
'botnlagene': ('botnlag',),
'botnlaget': ('botnlag',),
'botnløshet': ('botnløshet',),
'botnløsheta': ('botnløshet',),
'botnløsheten': ('botnløshet',),
'botnløshetene': ('botnløshet',),
'botnløsheter': ('botnløshet',),
'botnløysa': ('botnløyse',),
'botnløyse': ('botnløyse',),
'botnløysen': ('botnløyse',),
'botnløysene': ('botnløyse',),
'botnløyser': ('botnløyse',),
'botnmorene': ('botnmorene',),
'botnmorenen': ('botnmorene',),
'botnmorenene': ('botnmorene',),
'botnmorener': ('botnmorene',),
'botnnivå': ('botnnivå',),
'botnnivåa': ('botnnivå',),
'botnnivåene': ('botnnivå',),
'botnnivåer': ('botnnivå',),
'botnnivået': ('botnnivå',),
'botnpanna': ('botnpanne',),
'botnpanne': ('botnpanne',),
'botnpannen': ('botnpanne',),
'botnpannene': ('botnpanne',),
'botnpanner': ('botnpanne',),
'botnrekord': ('botnrekord',),
'botnrekorden': ('botnrekord',),
'botnrekordene': ('botnrekord',),
'botnrekorder': ('botnrekord',),
'botnstoff': ('botnstoff',),
'botnstoffa': ('botnstoff',),
'botnstoffene': ('botnstoff',),
'botnstoffer': ('botnstoff',),
'botnstoffet': ('botnstoff',),
'botnstrid': ('botnstrid',),
'botnstriden': ('botnstrid',),
'botnstridene': ('botnstrid',),
'botnstrider': ('botnstrid',),
'botolvsmess': ('botolvsmess',),
'botolvsmess': ('botolvsmess',),
'botolvsmesse': ('botolvsmesse',),
'botsbenk': ('botsbenk',),
'botsbenken': ('botsbenk',),
'botsbenkene': ('botsbenk',),
'botsbenker': ('botsbenk',),
'botsdag': ('botsdag',),
'botsdagen': ('botsdag',),
'botsdagene': ('botsdag',),
'botsdager': ('botsdag',),
'botsfengsel': ('botsfengsel',),
'botsfengselet': ('botsfengsel',),
'botsfengsla': ('botsfengsel',),
'botsfengslene': ('botsfengsel',),
'botsfengsler': ('botsfengsel',),
'botsfengslet': ('botsfengsel',),
'botsgang': ('botsgang',),
'botsgangen': ('botsgang',),
'botsgangene': ('botsgang',),
'botsganger': ('botsgang',),
'botssakrament': ('botssakrament',),
'botssakramenta': ('botssakrament',),
'botssakramentene': ('botssakrament',),
'botssakramenter': ('botssakrament',),
'botssakramentet': ('botssakrament',),
'botssalme': ('botssalme',),
'botssalmen': ('botssalme',),
'botssalmene': ('botssalme',),
'botssalmer': ('botssalme',),
'botswaner': ('botswaner',),
'botswanere': ('botswaner',),
'botswaneren': ('botswaner',),
'botswanerer': ('botswaner',),
'botswanerne': ('botswaner',),
'botsøvelse': ('botsøvelse',),
'botsøvelsen': ('botsøvelse',),
'botsøvelsene': ('botsøvelse',),
'botsøvelser': ('botsøvelse',),
'botsøving': ('botsøving',),
'botsøvinga': ('botsøving',),
'botsøvingen': ('botsøving',),
'botsøvingene': ('botsøving',),
'botsøvinger': ('botsøving',),
'bott': ('bott',),
'bottlenose': ('bottlenose',),
'bottlenosen': ('bottlenose',),
'bottlenosene': ('bottlenose',),
'bottlenoser': ('bottlenose',),
'botulisme': ('botulisme',),
'botulismen': ('botulisme',),
'botulismene': ('botulisme',),
'botulismer': ('botulisme',),
'bouclea': ('bouclé',),
'boucleen': ('bouclé',),
'boucleene': ('bouclé',),
'boucleer': ('bouclé',),
'boucleet': ('bouclé',),
'bouclé': ('bouclé',),
'boucléen': ('bouclé',),
'boucléene': ('bouclé',),
'boucléer': ('bouclé',),
'bouclégarn': ('bouclégarn',),
'bouclégarna': ('bouclégarn',),
'bouclégarnene': ('bouclégarn',),
'bouclégarnet': ('bouclégarn',),
'boucléteppa': ('boucléteppe',),
'boucléteppe': ('boucléteppe',),
'boucléteppene': ('boucléteppe',),
'bouclétepper': ('boucléteppe',),
'boucléteppet': ('boucléteppe',),
'bouillabaisse': ('bouillabaisse',),
'bouillabaissen': ('bouillabaisse',),
'bouillabaissene': ('bouillabaisse',),
'bouillabaisser': ('bouillabaisse',),
'bouquet': ('bouquet',),
'bouqueten': ('bouquet',),
'bouquetene': ('bouquet',),
'bouqueter': ('bouquet',),
'bourgeois': ('bourgeois',),
'bourgeoisen': ('bourgeois',),
'bourgeoisene': ('bourgeois',),
'bourgeoiser': ('bourgeois',),
'bourgeoisi': ('bourgeoisi',),
'bourgeoisia': ('bourgeoisi',),
'bourgeoisiene': ('bourgeoisi',),
'bourgeoisier': ('bourgeoisi',),
'bourgeoisiet': ('bourgeoisi',),
'bouzouki': ('bouzouki',),
'bouzoukien': ('bouzouki',),
'bouzoukiene': ('bouzouki',),
'bouzoukier': ('bouzouki',),
'bovenbramsegl': ('bovenbramsegl',),
'bovenbramsegla': ('bovenbramsegl',),
'bovenbramseglene': ('bovenbramsegl',),
'bovenbramseglet': ('bovenbramsegl',),
'bovenbramseil': ('bovenbramseil',),
'bovenbramseila': ('bovenbramseil',),
'bovenbramseilene': ('bovenbramseil',),
'bovenbramseilet': ('bovenbramseil',),
'bovenvekt': ('bovenvekt',),
'bovenvekta': ('bovenvekt',),
'bovenvekten': ('bovenvekt',),
'bovenvektene': ('bovenvekt',),
'bovenvekter': ('bovenvekt',),
'bow': ('bow',),
'bowen': ('bow',),
'bowene': ('bow',),
'bower': ('bow',),
'bowl': ('bowl',),
'bowlen': ('bowl',),
'bowlene': ('bowl',),
'bowler': ('bowl',),
'bowle': ('bowle',),
'bowlen': ('bowle',),
'bowlene': ('bowle',),
'bowler': ('bowle',),
'bowler': ('bowler',),
'bowlere': ('bowler',),
'bowleren': ('bowler',),
'bowlerer': ('bowler',),
'bowlerne': ('bowler',),
'bowler': ('bowler',),
'bowlere': ('bowler',),
'bowleren': ('bowler',),
'bowlerer': ('bowler',),
'bowlerne': ('bowler',),
'bowlerhatt': ('bowlerhatt',),
'bowlerhatten': ('bowlerhatt',),
'bowlerhattene': ('bowlerhatt',),
'bowlerhatter': ('bowlerhatt',),
'bowling': ('bowling',),
'bowlinga': ('bowling',),
'bowlingen': ('bowling',),
'bowlingene': ('bowling',),
'bowlinger': ('bowling',),
'bowlingbane': ('bowlingbane',),
'bowlingbanen': ('bowlingbane',),
'bowlingbanene': ('bowlingbane',),
'bowlingbaner': ('bowlingbane',),
'bowlinghall': ('bowlinghall',),
'bowlinghallen': ('bowlinghall',),
'bowlinghallene': ('bowlinghall',),
'bowlinghaller': ('bowlinghall',),
'bowlingkula': ('bowlingkule',),
'bowlingkule': ('bowlingkule',),
'bowlingkulen': ('bowlingkule',),
'bowlingkulene': ('bowlingkule',),
'bowlingkuler': ('bowlingkule',),
'bowlingspeller': ('bowlingspeller',),
'bowlingspellere': ('bowlingspeller',),
'bowlingspelleren': ('bowlingspeller',),
'bowlingspellerer': ('bowlingspeller',),
'bowlingspellerne': ('bowlingspeller',),
'bowlingspiller': ('bowlingspiller',),
'bowlingspillere': ('bowlingspiller',),
'bowlingspilleren': ('bowlingspiller',),
'bowlingspillerer': ('bowlingspiller',),
'bowlingspillerne': ('bowlingspiller',),
'boy': ('boy',),
'boyen': ('boy',),
'boyene': ('boy',),
'boyer': ('boy',),
'boysenbær': ('boysenbær',),
'boysenbæra': ('boysenbær',),
'boysenbærene': ('boysenbær',),
'boysenbæret': ('boysenbær',),
'boysenbær': ('boysenbær',),
'boysenbæra': ('boysenbær',),
'boysenbærene': ('boysenbær',),
'boysenbæret': ('boysenbær',),
'brachiopod': ('brachiopod',),
'brachiopoden': ('brachiopod',),
'brachiopodene': ('brachiopod',),
'brachiopoder': ('brachiopod',),
'bragd': ('bragd',),
'bragda': ('bragd',),
'bragden': ('bragd',),
'bragdene': ('bragd',),
'bragder': ('bragd',),
'brageløfta': ('brageløfte',),
'brageløfte': ('brageløfte',),
'brageløftene': ('brageløfte',),
'brageløfter': ('brageløfte',),
'brageløftet': ('brageløfte',),
'brageløfta': ('brageløfte',),
'brageløfte': ('brageløfte',),
'brageløftene': ('brageløfte',),
'brageløfter': ('brageløfte',),
'brageløftet': ('brageløfte',),
'braille': ('braille',),
'braillen': ('braille',),
'braillene': ('braille',),
'brailler': ('braille',),
'brailleskrift': ('brailleskrift',),
'brailleskrifta': ('brailleskrift',),
'brailleskriften': ('brailleskrift',),
'brailleskriftene': ('brailleskrift',),
'brailleskrifter': ('brailleskrift',),
'brak': ('brak',),
'braka': ('brak',),
'brakene': ('brak',),
'braket': ('brak',),
'brakett': ('brakett',),
'braketten': ('brakett',),
'brakettene': ('brakett',),
'braketter': ('brakett',),
'brakk': ('brakk',),
'brakken': ('brakk',),
'brakkene': ('brakk',),
'brakker': ('brakk',),
'brakka': ('brakke',),
'brakke': ('brakke',),
'brakken': ('brakke',),
'brakkene': ('brakke',),
'brakker': ('brakke',),
'brakkebaron': ('brakkebaron',),
'brakkebaronen': ('brakkebaron',),
'brakkebaronene': ('brakkebaron',),
'brakkebaroner': ('brakkebaron',),
'brakkeboer': ('brakkeboer',),
'brakkeboere': ('brakkeboer',),
'brakkeboeren': ('brakkeboer',),
'brakkeboerer': ('brakkeboer',),
'brakkeboerne': ('brakkeboer',),
'brakkebuer': ('brakkebuer',),
'brakkebuere': ('brakkebuer',),
'brakkebueren': ('brakkebuer',),
'brakkebuerer': ('brakkebuer',),
'brakkebuerne': ('brakkebuer',),
'brakkeby': ('brakkeby',),
'brakkebyen': ('brakkeby',),
'brakkebyene': ('brakkeby',),
'brakkebyer': ('brakkeby',),
'brakkesjef': ('brakkesjef',),
'brakkesjefen': ('brakkesjef',),
'brakkesjefene': ('brakkesjef',),
'brakkesjefer': ('brakkesjef',),
'brakkjord': ('brakkjord',),
'brakkjorda': ('brakkjord',),
'brakkjorden': ('brakkjord',),
'brakkjordene': ('brakkjord',),
'brakkjorder': ('brakkjord',),
'brakkland': ('brakkland',),
'brakklanda': ('brakkland',),
'brakklandene': ('brakkland',),
'brakklandet': ('brakkland',),
'brakkmark': ('brakkmark',),
'brakkmarka': ('brakkmark',),
'brakkmarken': ('brakkmark',),
'brakkmarkene': ('brakkmark',),
'brakkmarker': ('brakkmark',),
'brakknesa': ('brakknese',),
'brakknese': ('brakknese',),
'brakknesen': ('brakknese',),
'brakknesene': ('brakknese',),
'brakkneser': ('brakknese',),
'brakkvann': ('brakkvann',),
'brakkvanna': ('brakkvann',),
'brakkvannene': ('brakkvann',),
'brakkvannet': ('brakkvann',),
'brakkvatn': ('brakkvatn',),
'brakkvatna': ('brakkvatn',),
'brakkvatnene': ('brakkvatn',),
'brakkvatnet': ('brakkvatn',),
'braknederlag': ('braknederlag',),
'braknederlaga': ('braknederlag',),
'braknederlagene': ('braknederlag',),
'braknederlaget': ('braknederlag',),
'brakseier': ('brakseier',),
'brakseiere': ('brakseier',),
'brakseieren': ('brakseier',),
'brakseierne': ('brakseier',),
'brakseire': ('brakseier',),
'brakseirene': ('brakseier',),
'brakseirer': ('brakseier',),
'braktap': ('braktap',),
'braktapa': ('braktap',),
'braktapene': ('braktap',),
'braktapet': ('braktap',),
'brakteat': ('brakteat',),
'brakteaten': ('brakteat',),
'brakteatene': ('brakteat',),
'brakteater': ('brakteat',),
'bram': ('bram',),
'bramaisme': ('bramaisme',),
'bramaismen': ('bramaisme',),
'bramaismene': ('bramaisme',),
'bramaismer': ('bramaisme',),
'braman': ('braman',),
'bramanen': ('braman',),
'bramanene': ('braman',),
'bramaner': ('braman',),
'bramanisme': ('bramanisme',),
'bramanismen': ('bramanisme',),
'bramanismene': ('bramanisme',),
'bramanismer': ('bramanisme',),
'bramin': ('bramin',),
'braminen': ('bramin',),
'braminene': ('bramin',),
'braminer': ('bramin',),
'bramsegl': ('bramsegl',),
'bramsegla': ('bramsegl',),
'bramseglene': ('bramsegl',),
'bramseglet': ('bramsegl',),
'bramseil': ('bramseil',),
'bramseila': ('bramseil',),
'bramseilene': ('bramseil',),
'bramseilet': ('bramseil',),
'bramstang': ('bramstang',),
'bramstanga': ('bramstang',),
'bramstangen': ('bramstang',),
'bramstengene': ('bramstang',),
'bramstenger': ('bramstang',),
'brand': ('brand',),
'branden': ('brand',),
'brandene': ('brand',),
'brander': ('brand',),
'brand': ('brand',),
'branden': ('brand',),
'brandene': ('brand',),
'brander': ('brand',),
'brande': ('brande',),
'branden': ('brande',),
'brandene': ('brande',),
'brander': ('brande',),
'brander': ('brander',),
'brandere': ('brander',),
'branderen': ('brander',),
'branderer': ('brander',),
'branderne': ('brander',),
'brandy': ('brandy',),
'brandyen': ('brandy',),
'brandyene': ('brandy',),
'brandyer': ('brandy',),
'brann': ('brann',),
'brannen': ('brann',),
'brannene': ('brann',),
'branner': ('brann',),
'brannalarm': ('brannalarm',),
'brannalarmen': ('brannalarm',),
'brannalarmene': ('brannalarm',),
'brannalarmer': ('brannalarm',),
'brannbil': ('brannbil',),
'brannbilen': ('brannbil',),
'brannbilene': ('brannbil',),
'brannbiler': ('brannbil',),
'brannbomba': ('brannbombe',),
'brannbombe': ('brannbombe',),
'brannbomben': ('brannbombe',),
'brannbombene': ('brannbombe',),
'brannbomber': ('brannbombe',),
'branndør': ('branndør',),
'branndøra': ('branndør',),
'branndøren': ('branndør',),
'branndørene': ('branndør',),
'branndører': ('branndør',),
'brannfakkel': ('brannfakkel',),
'brannfakkelen': ('brannfakkel',),
'brannfaklene': ('brannfakkel',),
'brannfakler': ('brannfakkel',),
'brannforsikring': ('brannforsikring',),
'brannforsikringa': ('brannforsikring',),
'brannforsikringen': ('brannforsikring',),
'brannforsikringene': ('brannforsikring',),
'brannforsikringer': ('brannforsikring',),
'branngata': ('branngate',),
'branngate': ('branngate',),
'branngaten': ('branngate',),
'branngatene': ('branngate',),
'branngater': ('branngate',),
'branngavl': ('branngavl',),
'branngavlen': ('branngavl',),
'branngavlene': ('branngavl',),
'branngavler': ('branngavl',),
'branngranat': ('branngranat',),
'branngranaten': ('branngranat',),
'branngranatene': ('branngranat',),
'branngranater': ('branngranat',),
'branninstruks': ('branninstruks',),
'branninstruksen': ('branninstruks',),
'branninstruksene': ('branninstruks',),
'branninstrukser': ('branninstruks',),
'brannkassa': ('brannkasse',),
'brannkasse': ('brannkasse',),
'brannkassen': ('brannkasse',),
'brannkassene': ('brannkasse',),
'brannkasser': ('brannkasse',),
'brannkorps': ('brannkorps',),
'brannkorpsa': ('brannkorps',),
'brannkorpsene': ('brannkorps',),
'brannkorpset': ('brannkorps',),
'brannlilja': ('brannlilje',),
'brannlilje': ('brannlilje',),
'brannliljen': ('brannlilje',),
'brannliljene': ('brannlilje',),
'brannliljer': ('brannlilje',),
'brannmann': ('brannmann',),
'brannmannen': ('brannmann',),
'brannmenn': ('brannmann',),
'brannmennene': ('brannmann',),
'brannmannskap': ('brannmannskap',),
'brannmannskapa': ('brannmannskap',),
'brannmannskapene': ('brannmannskap',),
'brannmannskaper': ('brannmannskap',),
'brannmannskapet': ('brannmannskap',),
'brannmannsløft': ('brannmannsløft',),
'brannmannsløfta': ('brannmannsløft',),
'brannmannsløftene': ('brannmannsløft',),
'brannmannsløftet': ('brannmannsløft',),
'brannmester': ('brannmester',),
'brannmestere': ('brannmester',),
'brannmesteren': ('brannmester',),
'brannmesterer': ('brannmester',),
'brannmesterne': ('brannmester',),
'brannmestre': ('brannmester',),
'brannmestrene': ('brannmester',),
'brannmestrer': ('brannmester',),
'brannmur': ('brannmur',),
'brannmuren': ('brannmur',),
'brannmurene': ('brannmur',),
'brannmurer': ('brannmur',),
'brannrør': ('brannrør',),
'brannrøra': ('brannrør',),
'brannrørene': ('brannrør',),
'brannrøret': ('brannrør',),
'brannsalva': ('brannsalve',),
'brannsalve': ('brannsalve',),
'brannsalven': ('brannsalve',),
'brannsalvene': ('brannsalve',),
'brannsalver': ('brannsalve',),
'brannsikring': ('brannsikring',),
'brannsikringa': ('brannsikring',),
'brannsikringen': ('brannsikring',),
'brannsikringene': ('brannsikring',),
'brannsikringer': ('brannsikring',),
'brannsirena': ('brannsirene',),
'brannsirene': ('brannsirene',),
'brannsirenen': ('brannsirene',),
'brannsirenene': ('brannsirene',),
'brannsirener': ('brannsirene',),
'brannskade': ('brannskade',),
'brannskaden': ('brannskade',),
'brannskadene': ('brannskade',),
'brannskader': ('brannskade',),
'brannskadetakst': ('brannskadetakst',),
'brannskadetaksten': ('brannskadetakst',),
'brannskadetakstene': ('brannskadetakst',),
'brannskadetakster': ('brannskadetakst',),
'brannslange': ('brannslange',),
'brannslangen': ('brannslange',),
'brannslangene': ('brannslange',),
'brannslanger': ('brannslange',),
'brannslokking': ('brannslokking',),
'brannslokkinga': ('brannslokking',),
'brannslokkingen': ('brannslokking',),
'brannslokkingene': ('brannslokking',),
'brannslokkinger': ('brannslokking',),
'brannslokkingsapparat': ('brannslokkingsapparat',),
'brannslokkingsapparata': ('brannslokkingsapparat',),
'brannslokkingsapparatene': ('brannslokkingsapparat',),
'brannslokkingsapparater': ('brannslokkingsapparat',),
'brannslokkingsapparatet': ('brannslokkingsapparat',),
'brannslokning': ('brannslokning',),
'brannslokninga': ('brannslokning',),
'brannslokningen': ('brannslokning',),
'brannslokningene': ('brannslokning',),
'brannslokninger': ('brannslokning',),
'brannslokningsapparat': ('brannslokningsapparat',),
'brannslokningsapparata': ('brannslokningsapparat',),
'brannslokningsapparatene': ('brannslokningsapparat',),
'brannslokningsapparater': ('brannslokningsapparat',),
'brannslokningsapparatet': ('brannslokningsapparat',),
'brannslukking': ('brannslukking',),
'brannslukkinga': ('brannslukking',),
'brannslukkingen': ('brannslukking',),
'brannslukkingene': ('brannslukking',),
'brannslukkinger': ('brannslukking',),
'brannslukkingsapparat': ('brannslukkingsapparat',),
'brannslukkingsapparata': ('brannslukkingsapparat',),
'brannslukkingsapparatene': ('brannslukkingsapparat',),
'brannslukkingsapparater': ('brannslukkingsapparat',),
'brannslukkingsapparatet': ('brannslukkingsapparat',),
'brannslukning': ('brannslukning',),
'brannslukninga': ('brannslukning',),
'brannslukningen': ('brannslukning',),
'brannslukningene': ('brannslukning',),
'brannslukninger': ('brannslukning',),
'brannslukningsapparat': ('brannslukningsapparat',),
'brannslukningsapparata': ('brannslukningsapparat',),
'brannslukningsapparatene': ('brannslukningsapparat',),
'brannslukningsapparater': ('brannslukningsapparat',),
'brannslukningsapparatet': ('brannslukningsapparat',),
'brannsperra': ('brannsperre',),
'brannsperre': ('brannsperre',),
'brannsperren': ('brannsperre',),
'brannsperrene': ('brannsperre',),
'brannsperrer': ('brannsperre',),
'brannsprøyta': ('brannsprøyte',),
'brannsprøyte': ('brannsprøyte',),
'brannsprøyten': ('brannsprøyte',),
'brannsprøytene': ('brannsprøyte',),
'brannsprøyter': ('brannsprøyte',),
'brannstasjon': ('brannstasjon',),
'brannstasjonen': ('brannstasjon',),
'brannstasjonene': ('brannstasjon',),
'brannstasjoner': ('brannstasjon',),
'brannsted': ('brannsted',),
'brannstedene': ('brannsted',),
'brannsteder': ('brannsted',),
'brannstedet': ('brannsted',),
'brannstifter': ('brannstifter',),
'brannstiftere': ('brannstifter',),
'brannstifteren': ('brannstifter',),
'brannstifterer': ('brannstifter',),
'brannstifterne': ('brannstifter',),
'brannstige': ('brannstige',),
'brannstigen': ('brannstige',),
'brannstigene': ('brannstige',),
'brannstiger': ('brannstige',),
'brannsår': ('brannsår',),
'brannsåra': ('brannsår',),
'brannsårene': ('brannsår',),
'brannsåret': ('brannsår',),
'branntakst': ('branntakst',),
'branntaksten': ('branntakst',),
'branntakstene': ('branntakst',),
'branntakster': ('branntakst',),
'branntau': ('branntau',),
'branntaua': ('branntau',),
'branntauene': ('branntau',),
'branntauer': ('branntau',),
'branntauet': ('branntau',),
'branntomt': ('branntomt',),
'branntomta': ('branntomt',),
'branntomten': ('branntomt',),
'branntomtene': ('branntomt',),
'branntomter': ('branntomt',),
'brannutrykning': ('brannutrykning',),
'brannutrykninga': ('brannutrykning',),
'brannutrykningen': ('brannutrykning',),
'brannutrykningene': ('brannutrykning',),
'brannutrykninger': ('brannutrykning',),
'brannvegg': ('brannvegg',),
'brannveggen': ('brannvegg',),
'brannveggene': ('brannvegg',),
'brannvegger': ('brannvegg',),
'brannvern': ('brannvern',),
'brannverna': ('brannvern',),
'brannvernene': ('brannvern',),
'brannvernet': ('brannvern',),
'brannvernforskrift': ('brannvernforskrift',),
'brannvernforskrifta': ('brannvernforskrift',),
'brannvernforskriften': ('brannvernforskrift',),
'brannvernforskriftene': ('brannvernforskrift',),
'brannvernforskrifter': ('brannvernforskrift',),
'brannvesen': ('brannvesen',),
'brannvesena': ('brannvesen',),
'brannvesenene': ('brannvesen',),
'brannvesener': ('brannvesen',),
'brannvesenet': ('brannvesen',),
'brannårsak': ('brannårsak',),
'brannårsaka': ('brannårsak',),
'brannårsaken': ('brannårsak',),
'brannårsakene': ('brannårsak',),
'brannårsaker': ('brannårsak',),
'bransje': ('bransje',),
'bransjen': ('bransje',),
'bransjene': ('bransje',),
'bransjer': ('bransje',),
'bransjeavtale': ('bransjeavtale',),
'bransjeavtalen': ('bransjeavtale',),
'bransjeavtalene': ('bransjeavtale',),
'bransjeavtaler': ('bransjeavtale',),
'bransjeforretning': ('bransjeforretning',),
'bransjeforretninga': ('bransjeforretning',),
'bransjeforretningen': ('bransjeforretning',),
'bransjeforretningene': ('bransjeforretning',),
'bransjeforretninger': ('bransjeforretning',),
'bransjekunnskap': ('bransjekunnskap',),
'bransjekunnskapen': ('bransjekunnskap',),
'bransjekunnskapene': ('bransjekunnskap',),
'bransjekunnskaper': ('bransjekunnskap',),
'bransjeråd': ('bransjeråd',),
'bransjeråda': ('bransjeråd',),
'bransjerådene': ('bransjeråd',),
'bransjerådet': ('bransjeråd',),
'bras': ('bras',),
'brasen': ('bras',),
'brasene': ('bras',),
'braser': ('bras',),
'bras': ('bras',),
'brasa': ('bras',),
'brasene': ('bras',),
'braset': ('bras',),
'brasilianer': ('brasilianer',),
'brasilianere': ('brasilianer',),
'brasilianeren': ('brasilianer',),
'brasilianerer': ('brasilianer',),
'brasilianerne': ('brasilianer',),
'brask': ('brask',),
'brasma': ('brasme',),
'brasme': ('brasme',),
'brasmen': ('brasme',),
'brasmene': ('brasme',),
'brasmer': ('brasme',),
'brass': ('brass',),
'brassen': ('brass',),
'brassene': ('brass',),
'brasser': ('brass',),
'brassband': ('brassband',),
'brassbanda': ('brassband',),
'brassbandene': ('brassband',),
'brassbandet': ('brassband',),
'brassespark': ('brassespark',),
'brassesparka': ('brassespark',),
'brassesparkene': ('brassespark',),
'brassesparket': ('brassespark',),
'brast': ('brast',),
'bratning': ('bratning',),
'bratninga': ('bratning',),
'bratningen': ('bratning',),
'bratningene': ('bratning',),
'bratninger': ('bratning',),
'bratsj': ('bratsj',),
'bratsjen': ('bratsj',),
'bratsjene': ('bratsj',),
'bratsjer': ('bratsj',),
'bratsjist': ('bratsjist',),
'bratsjisten': ('bratsjist',),
'bratsjistene': ('bratsjist',),
'bratsjister': ('bratsjist',),
'bratta': ('bratte',),
'bratte': ('bratte',),
'bratten': ('bratte',),
'brattene': ('bratte',),
'bratter': ('bratte',),
'brattheng': ('brattheng',),
'bratthenga': ('brattheng',),
'bratthengene': ('brattheng',),
'bratthenget': ('brattheng',),
'brattstup': ('brattstup',),
'brattstupa': ('brattstup',),
'brattstupene': ('brattstup',),
'brattstupet': ('brattstup',),
'brauter': ('brauter',),
'brautere': ('brauter',),
'brauteren': ('brauter',),
'brauterer': ('brauter',),
'brauterne': ('brauter',),
'bravade': ('bravade',),
'bravaden': ('bravade',),
'bravadene': ('bravade',),
'bravader': ('bravade',),
'bravo': ('bravo',),
'bravoa': ('bravo',),
'bravoene': ('bravo',),
'bravoer': ('bravo',),
'bravoet': ('bravo',),
'bravorop': ('bravorop',),
'bravoropa': ('bravorop',),
'bravoropene': ('bravorop',),
'bravoropet': ('bravorop',),
'bravur': ('bravur',),
'bravuren': ('bravur',),
'bravurene': ('bravur',),
'bravurer': ('bravur',),
'bravurnummer': ('bravurnummer',),
'bravurnummeret': ('bravurnummer',),
'bravurnumra': ('bravurnummer',),
'bravurnumre': ('bravurnummer',),
'bravurnumrene': ('bravurnummer',),
'bre': ('bre',),
'breen': ('bre',),
'breene': ('bre',),
'breer': ('bre',),
'bredd': ('bredd',),
'bredda': ('bredd',),
'bredden': ('bredd',),
'breddene': ('bredd',),
'bredder': ('bredd',),
'bredde': ('bredde',),
'bredden': ('bredde',),
'breddene': ('bredde',),
'bredder': ('bredde',),
'bredde': ('bredde',),
'bredden': ('bredde',),
'breddene': ('bredde',),
'bredder': ('bredde',),
'bredde': ('bredde',),
'bredden': ('bredde',),
'breddene': ('bredde',),
'bredder': ('bredde',),
'breddegrad': ('breddegrad',),
'breddegraden': ('breddegrad',),
'breddegradene': ('breddegrad',),
'breddegrader': ('breddegrad',),
'breddegrad': ('breddegrad',),
'breddegraden': ('breddegrad',),
'breddegradene': ('breddegrad',),
'breddegrader': ('breddegrad',),
'breddeminutt': ('breddeminutt',),
'breddeminutta': ('breddeminutt',),
'breddeminuttene': ('breddeminutt',),
'breddeminutter': ('breddeminutt',),
'breddeminuttet': ('breddeminutt',),
'breddeminutt': ('breddeminutt',),
'breddeminutta': ('breddeminutt',),
'breddeminuttene': ('breddeminutt',),
'breddeminutter': ('breddeminutt',),
'breddeminuttet': ('breddeminutt',),
'breddesekund': ('breddesekund',),
'breddesekunda': ('breddesekund',),
'breddesekundene': ('breddesekund',),
'breddesekunder': ('breddesekund',),
'breddesekundet': ('breddesekund',),
'breddesekund': ('breddesekund',),
'breddesekunda': ('breddesekund',),
'breddesekundene': ('breddesekund',),
'breddesekunder': ('breddesekund',),
'breddesekundet': ('breddesekund',),
'breddesirkel': ('breddesirkel',),
'breddesirkelen': ('breddesirkel',),
'breddesirklene': ('breddesirkel',),
'breddesirkler': ('breddesirkel',),
'breddesirkel': ('breddesirkel',),
'breddesirkelen': ('breddesirkel',),
'breddesirklene': ('breddesirkel',),
'breddesirkler': ('breddesirkel',),
'bredfilm': ('bredfilm',),
'bredfilmen': ('bredfilm',),
'bredfilmene': ('bredfilm',),
'bredfilmer': ('bredfilm',),
'bredsida': ('bredside',),
'bredside': ('bredside',),
'bredsiden': ('bredside',),
'bredsidene': ('bredside',),
'bredsider': ('bredside',),
'bregna': ('bregne',),
'bregne': ('bregne',),
'bregnen': ('bregne',),
'bregnene': ('bregne',),
'bregner': ('bregne',),
'bregnekratt': ('bregnekratt',),
'bregnekratta': ('bregnekratt',),
'bregnekrattene': ('bregnekratt',),
'bregnekrattet': ('bregnekratt',),
'breibygd': ('breibygd',),
'breibygda': ('breibygd',),
'breibygden': ('breibygd',),
'breibygdene': ('breibygd',),
'breibygder': ('breibygd',),
'breidd': ('breidd',),
'breidda': ('breidd',),
'breidden': ('breidd',),
'breiddene': ('breidd',),
'breidder': ('breidd',),
'breidd': ('breidd',),
'breidda': ('breidd',),
'breidden': ('breidd',),
'breiddene': ('breidd',),
'breidder': ('breidd',),
'breiddegrad': ('breiddegrad',),
'breiddegraden': ('breiddegrad',),
'breiddegradene': ('breiddegrad',),
'breiddegrader': ('breiddegrad',),
'breiddegrad': ('breiddegrad',),
'breiddegraden': ('breiddegrad',),
'breiddegradene': ('breiddegrad',),
'breiddegrader': ('breiddegrad',),
'breiddeminutt': ('breiddeminutt',),
'breiddeminutta': ('breiddeminutt',),
'breiddeminuttene': ('breiddeminutt',),
'breiddeminutter': ('breiddeminutt',),
'breiddeminuttet': ('breiddeminutt',),
'breiddeminutt': ('breiddeminutt',),
'breiddeminutta': ('breiddeminutt',),
'breiddeminuttene': ('breiddeminutt',),
'breiddeminutter': ('breiddeminutt',),
'breiddeminuttet': ('breiddeminutt',),
'breiddesekund': ('breiddesekund',),
'breiddesekunda': ('breiddesekund',),
'breiddesekundene': ('breiddesekund',),
'breiddesekunder': ('breiddesekund',),
'breiddesekundet': ('breiddesekund',),
'breiddesekund': ('breiddesekund',),
'breiddesekunda': ('breiddesekund',),
'breiddesekundene': ('breiddesekund',),
'breiddesekunder': ('breiddesekund',),
'breiddesekundet': ('breiddesekund',),
'breiddesirkel': ('breiddesirkel',),
'breiddesirkelen': ('breiddesirkel',),
'breiddesirklene': ('breiddesirkel',),
'breiddesirkler': ('breiddesirkel',),
'breiddesirkel': ('breiddesirkel',),
'breiddesirkelen': ('breiddesirkel',),
'breiddesirklene': ('breiddesirkel',),
'breiddesirkler': ('breiddesirkel',),
'breieriva': ('breierive',),
'breierive': ('breierive',),
'breieriven': ('breierive',),
'breierivene': ('breierive',),
'breieriver': ('breierive',),
'breievoll': ('breievoll',),
'breievollen': ('breievoll',),
'breievollene': ('breievoll',),
'breievoller': ('breievoll',),
'breifilm': ('breifilm',),
'breifilmen': ('breifilm',),
'breifilmene': ('breifilm',),
'breifilmer': ('breifilm',),
'breiflabb': ('breiflabb',),
'breiflabben': ('breiflabb',),
'breiflabbene': ('breiflabb',),
'breiflabber': ('breiflabb',),
'breifokk': ('breifokk',),
'breifokka': ('breifokk',),
'breifokken': ('breifokk',),
'breifokkene': ('breifokk',),
'breifokker': ('breifokk',),
'breis': ('breis',),
'breisen': ('breis',),
'breisene': ('breis',),
'breiser': ('breis',),
'breisida': ('breiside',),
'breiside': ('breiside',),
'breisiden': ('breiside',),
'breisidene': ('breiside',),
'breisider': ('breiside',),
'breislede': ('breislede',),
'breisleden': ('breislede',),
'breisledene': ('breislede',),
'breisleder': ('breislede',),
'breitschwans': ('breitschwans',),
'breitschwansen': ('breitschwans',),
'breitschwansene': ('breitschwans',),
'breitschwanser': ('breitschwans',),
'brejord': ('brejord',),
'brejorda': ('brejord',),
'brejorden': ('brejord',),
'brejordene': ('brejord',),
'brejorder': ('brejord',),
'brek': ('brek',),
'breka': ('brek',),
'brekene': ('brek',),
'breket': ('brek',),
'brekalv': ('brekalv',),
'brekalven': ('brekalv',),
'brekalvene': ('brekalv',),
'brekalver': ('brekalv',),
'brekk': ('brekk',),
'brekka': ('brekk',),
'brekkene': ('brekk',),
'brekket': ('brekk',),
'brekk': ('brekk',),
'brekka': ('brekk',),
'brekkene': ('brekk',),
'brekket': ('brekk',),
'brekkasje': ('brekkasje',),
'brekkasjen': ('brekkasje',),
'brekkasjene': ('brekkasje',),
'brekkasjer': ('brekkasje',),
'brekkbønna': ('brekkbønne',),
'brekkbønne': ('brekkbønne',),
'brekkbønnen': ('brekkbønne',),
'brekkbønnene': ('brekkbønne',),
'brekkbønner': ('brekkbønne',),
'brekka': ('brekke',),
'brekke': ('brekke',),
'brekken': ('brekke',),
'brekkene': ('brekke',),
'brekker': ('brekke',),
'brekkfarge': ('brekkfarge',),
'brekkfargen': ('brekkfarge',),
'brekkfargene': ('brekkfarge',),
'brekkfarger': ('brekkfarge',),
'brekkjern': ('brekkjern',),
'brekkjerna': ('brekkjern',),
'brekkjernene': ('brekkjern',),
'brekkjernet': ('brekkjern',),
'brekkmiddel': ('brekkmiddel',),
'brekkmiddelet': ('brekkmiddel',),
'brekkmidla': ('brekkmiddel',),
'brekkmidlene': ('brekkmiddel',),
'brekkmidler': ('brekkmiddel',),
'brekkmidlet': ('brekkmiddel',),
'brekkstang': ('brekkstang',),
'brekkstanga': ('brekkstang',),
'brekkstangen': ('brekkstang',),
'brekkstengene': ('brekkstang',),
'brekkstenger': ('brekkstang',),
'brekkvogn': ('brekkvogn',),
'brekkvogna': ('brekkvogn',),
'brekkvognen': ('brekkvogn',),
'brekkvognene': ('brekkvogn',),
'brekkvogner': ('brekkvogn',),
'brekning': ('brekning',),
'brekninga': ('brekning',),
'brekningen': ('brekning',),
'brekningene': ('brekning',),
'brekninger': ('brekning',),
'brekningsfornemmelse': ('brekningsfornemmelse',),
'brekningsfornemmelsen': ('brekningsfornemmelse',),
'brekningsfornemmelsene': ('brekningsfornemmelse',),
'brekningsfornemmelser': ('brekningsfornemmelse',),
'brem': ('brem',),
'bremmen': ('brem',),
'bremmene': ('brem',),
'bremmer': ('brem',),
'brems': ('brems',),
'bremsen': ('brems',),
'bremsene': ('brems',),
'bremser': ('brems',),
'brems': ('brems',),
'bremsen': ('brems',),
'bremsene': ('brems',),
'bremser': ('brems',),
'brems': ('brems',),
'bremsen': ('brems',),
'bremsene': ('brems',),
'bremser': ('brems',),
'bremsa': ('bremse',),
'bremse': ('bremse',),
'bremsen': ('bremse',),
'bremsene': ('bremse',),
'bremser': ('bremse',),
'bremseband': ('bremseband',),
'bremsebanda': ('bremseband',),
'bremsebandene': ('bremseband',),
'bremsebandet': ('bremseband',),
'bremsebånd': ('bremsebånd',),
'bremsebånda': ('bremsebånd',),
'bremsebåndene': ('bremsebånd',),
'bremsebåndet': ('bremsebånd',),
'bremseeffekt': ('bremseeffekt',),
'bremseeffekten': ('bremseeffekt',),
'bremseeffektene': ('bremseeffekt',),
'bremseeffekter': ('bremseeffekt',),
'bremseflata': ('bremseflate',),
'bremseflate': ('bremseflate',),
'bremseflaten': ('bremseflate',),
'bremseflatene': ('bremseflate',),
'bremseflater': ('bremseflate',),
'bremsehestekraft': ('bremsehestekraft',),
'bremsehestekrafta': ('bremsehestekraft',),
'bremsehestekraften': ('bremsehestekraft',),
'bremsehestekreftene': ('bremsehestekraft',),
'bremsehestekrefter': ('bremsehestekraft',),
'bremselengd': ('bremselengd',),
'bremselengda': ('bremselengd',),
'bremselengden': ('bremselengd',),
'bremselengdene': ('bremselengd',),
'bremselengder': ('bremselengd',),
'bremselengda': ('bremselengde',),
'bremselengde': ('bremselengde',),
'bremselengden': ('bremselengde',),
'bremselengdene': ('bremselengde',),
'bremselengder': ('bremselengde',),
'bremselys': ('bremselys',),
'bremselysa': ('bremselys',),
'bremselysene': ('bremselys',),
'bremselyset': ('bremselys',),
'bremsevogn': ('bremsevogn',),
'bremsevogna': ('bremsevogn',),
'bremsevognen': ('bremsevogn',),
'bremsevognene': ('bremsevogn',),
'bremsevogner': ('bremsevogn',),
'bremsevæska': ('bremsevæske',),
'bremsevæske': ('bremsevæske',),
'bremsevæsken': ('bremsevæske',),
'bremsevæskene': ('bremsevæske',),
'bremsevæsker': ('bremsevæske',),
'brenn-nesla': ('brenn-nesle',),
'brenn-nesle': ('brenn-nesle',),
'brenn-neslen': ('brenn-nesle',),
'brenn-neslene': ('brenn-nesle',),
'brenn-nesler': ('brenn-nesle',),
'brenneglas': ('brenneglas',),
'brenneglasa': ('brenneglas',),
'brenneglasene': ('brenneglas',),
'brenneglaset': ('brenneglas',),
'brenneglass': ('brenneglass',),
'brenneglassa': ('brenneglass',),
'brenneglassene': ('brenneglass',),
'brenneglasset': ('brenneglass',),
'brennemerka': ('brennemerke',),
'brennemerke': ('brennemerke',),
'brennemerkene': ('brennemerke',),
'brennemerker': ('brennemerke',),
'brennemerket': ('brennemerke',),
'brennenesla': ('brennenesle',),
'brennenesle': ('brennenesle',),
'brenneneslen': ('brennenesle',),
'brenneneslene': ('brennenesle',),
'brennenesler': ('brennenesle',),
'brenner': ('brenner',),
'brennere': ('brenner',),
'brenneren': ('brenner',),
'brennerer': ('brenner',),
'brennerne': ('brenner',),
'brenneri': ('brenneri',),
'brenneria': ('brenneri',),
'brenneriene': ('brenneri',),
'brennerier': ('brenneri',),
'brenneriet': ('brenneri',),
'brennesla': ('brennesle',),
'brennesle': ('brennesle',),
'brenneslen': ('brennesle',),
'brenneslene': ('brennesle',),
'brennesler': ('brennesle',),
'brennevin': ('brennevin',),
'brennevinene': ('brennevin',),
'brenneviner': ('brennevin',),
'brennevinet': ('brennevin',),
'brennevinsdjevel': ('brennevinsdjevel',),
'brennevinsdjevelen': ('brennevinsdjevel',),
'brennevinsdjevlene': ('brennevinsdjevel',),
'brennevinsdjevler': ('brennevinsdjevel',),
'brennevinsgauk': ('brennevinsgauk',),
'brennevinsgauken': ('brennevinsgauk',),
'brennevinsgaukene': ('brennevinsgauk',),
'brennevinsgauker': ('brennevinsgauk',),
'brennglas': ('brennglas',),
'brennglasa': ('brennglas',),
'brennglasene': ('brennglas',),
'brennglaset': ('brennglas',),
'brennglass': ('brennglass',),
'brennglassa': ('brennglass',),
'brennglassene': ('brennglass',),
'brennglasset': ('brennglass',),
'brennhast': ('brennhast',),
'brennhasten': ('brennhast',),
'brennhastene': ('brennhast',),
'brennhaster': ('brennhast',),
'brennhete': ('brennhete',),
'brennheten': ('brennhete',),
'brennhetene': ('brennhete',),
'brennheter': ('brennhete',),
'brennhår': ('brennhår',),
'brennhåra': ('brennhår',),
'brennhårene': ('brennhår',),
'brennhåret': ('brennhår',),
'brenning': ('brenning',),
'brenninga': ('brenning',),
'brenningen': ('brenning',),
'brenningene': ('brenning',),
'brenninger': ('brenning',),
'brenning': ('brenning',),
'brenninga': ('brenning',),
'brenningen': ('brenning',),
'brenningene': ('brenning',),
'brenninger': ('brenning',),
'brennkoppene': ('brennkopper',),
'brennkopper': ('brennkopper',),
'brennkulda': ('brennkulde',),
'brennkulde': ('brennkulde',),
'brennkulden': ('brennkulde',),
'brennkuldene': ('brennkulde',),
'brennkulder': ('brennkulde',),
'brennmanet': ('brennmanet',),
'brennmaneta': ('brennmanet',),
'brennmaneten': ('brennmanet',),
'brennmanetene': ('brennmanet',),
'brennmaneter': ('brennmanet',),
'brennoffer': ('brennoffer',),
'brennofferet': ('brennoffer',),
'brennofra': ('brennoffer',),
'brennofre': ('brennoffer',),
'brennofrene': ('brennoffer',),
'brennpunkt': ('brennpunkt',),
'brennpunkta': ('brennpunkt',),
'brennpunktene': ('brennpunkt',),
'brennpunkter': ('brennpunkt',),
'brennpunktet': ('brennpunkt',),
'brennstoff': ('brennstoff',),
'brennstoffa': ('brennstoff',),
'brennstoffene': ('brennstoff',),
'brennstoffer': ('brennstoff',),
'brennstoffet': ('brennstoff',),
'brennvidda': ('brennvidde',),
'brennvidde': ('brennvidde',),
'brennvidden': ('brennvidde',),
'brennviddene': ('brennvidde',),
'brennvidder': ('brennvidde',),
'brensel': ('brensel',),
'brenselet': ('brensel',),
'brensla': ('brensel',),
'brenslene': ('brensel',),
'brensler': ('brensel',),
'brenslet': ('brensel',),
'brenselcella': ('brenselcelle',),
'brenselcelle': ('brenselcelle',),
'brenselcellen': ('brenselcelle',),
'brenselcellene': ('brenselcelle',),
'brenselceller': ('brenselcelle',),
'brenselforbruk': ('brenselforbruk',),
'brenselforbruka': ('brenselforbruk',),
'brenselforbrukene': ('brenselforbruk',),
'brenselforbruket': ('brenselforbruk',),
'brenselforsyning': ('brenselforsyning',),
'brenselforsyninga': ('brenselforsyning',),
'brenselforsyningen': ('brenselforsyning',),
'brenselforsyningene': ('brenselforsyning',),
'brenselforsyninger': ('brenselforsyning',),
'brenselscella': ('brenselscelle',),
'brenselscelle': ('brenselscelle',),
'brenselscellen': ('brenselscelle',),
'brenselscellene': ('brenselscelle',),
'brenselsceller': ('brenselscelle',),
'bresje': ('bresje',),
'bresjen': ('bresje',),
'bresjene': ('bresje',),
'bresjer': ('bresje',),
'bresprekk': ('bresprekk',),
'bresprekken': ('bresprekk',),
'bresprekkene': ('bresprekk',),
'bresprekker': ('bresprekk',),
'brest': ('brest',),
'bresten': ('brest',),
'brestene': ('brest',),
'brester': ('brest',),
'brest': ('brest',),
'bresten': ('brest',),
'brestene': ('brest',),
'brester': ('brest',),
'bretagner': ('bretagner',),
'bretagnere': ('bretagner',),
'bretagneren': ('bretagner',),
'bretagnerer': ('bretagner',),
'bretagnerne': ('bretagner',),
'bretoner': ('bretoner',),
'bretonere': ('bretoner',),
'bretoneren': ('bretoner',),
'bretonerer': ('bretoner',),
'bretonerne': ('bretoner',),
'bretonner': ('bretonner',),
'bretonnere': ('bretonner',),
'bretonneren': ('bretonner',),
'bretonnerer': ('bretonner',),
'bretonnerne': ('bretonner',),
'bretonsk': ('bretonsk',),
'bretonsken': ('bretonsk',),
'bretonskene': ('bretonsk',),
'bretonsker': ('bretonsk',),
'brett': ('brett',),
'bretten': ('brett',),
'brettene': ('brett',),
'bretter': ('brett',),
'brett': ('brett',),
'bretta': ('brett',),
'brettene': ('brett',),
'bretter': ('brett',),
'brettet': ('brett',),
'brettemerka': ('brettemerke',),
'brettemerke': ('brettemerke',),
'brettemerkene': ('brettemerke',),
'brettemerker': ('brettemerke',),
'brettemerket': ('brettemerke',),
'brettemess': ('brettemess',),
'brettemesse': ('brettemesse',),
'brettmess': ('brettmess',),
'brettmesse': ('brettmesse',),
'brettsegler': ('brettsegler',),
'brettseglere': ('brettsegler',),
'brettsegleren': ('brettsegler',),
'brettseglerer': ('brettsegler',),
'brettseglerne': ('brettsegler',),
'brettsegling': ('brettsegling',),
'brettseglinga': ('brettsegling',),
'brettseglingen': ('brettsegling',),
'brettseglingene': ('brettsegling',),
'brettseglinger': ('brettsegling',),
'brettseiler': ('brettseiler',),
'brettseilere': ('brettseiler',),
'brettseileren': ('brettseiler',),
'brettseilerer': ('brettseiler',),
'brettseilerne': ('brettseiler',),
'brettseiling': ('brettseiling',),
'brettseilinga': ('brettseiling',),
'brettseilingen': ('brettseiling',),
'brettseilingene': ('brettseiling',),
'brettseilinger': ('brettseiling',),
'brettspell': ('brettspell',),
'brettspella': ('brettspell',),
'brettspellene': ('brettspell',),
'brettspellet': ('brettspell',),
'brettspill': ('brettspill',),
'brettspilla': ('brettspill',),
'brettspillene': ('brettspill',),
'brettspillet': ('brettspill',),
'brev': ('brev',),
'breva': ('brev',),
'brevene': ('brev',),
'brever': ('brev',),
'brevet': ('brev',),
'brevadel': ('brevadel',),
'brevadelen': ('brevadel',),
'brevadelene': ('brevadel',),
'brevadeler': ('brevadel',),
'brevandrer': ('brevandrer',),
'brevandrere': ('brevandrer',),
'brevandreren': ('brevandrer',),
'brevandrerer': ('brevandrer',),
'brevandrerne': ('brevandrer',),
'brevann': ('brevann',),
'brevanna': ('brevann',),
'brevannene': ('brevann',),
'brevannet': ('brevann',),
'brevatn': ('brevatn',),
'brevatna': ('brevatn',),
'brevatnene': ('brevatn',),
'brevatnet': ('brevatn',),
'brevbomba': ('brevbombe',),
'brevbombe': ('brevbombe',),
'brevbomben': ('brevbombe',),
'brevbombene': ('brevbombe',),
'brevbomber': ('brevbombe',),
'brevbrott': ('brevbrott',),
'brevbrotta': ('brevbrott',),
'brevbrottene': ('brevbrott',),
'brevbrottet': ('brevbrott',),
'brevbrudd': ('brevbrudd',),
'brevbrudda': ('brevbrudd',),
'brevbruddene': ('brevbrudd',),
'brevbruddet': ('brevbrudd',),
'brevdua': ('brevdue',),
'brevdue': ('brevdue',),
'brevduen': ('brevdue',),
'brevduene': ('brevdue',),
'brevduer': ('brevdue',),
'brevforbud': ('brevforbud',),
'brevforbuda': ('brevforbud',),
'brevforbudene': ('brevforbud',),
'brevforbudet': ('brevforbud',),
'brevhoda': ('brevhode',),
'brevhode': ('brevhode',),
'brevhodene': ('brevhode',),
'brevhoder': ('brevhode',),
'brevhodet': ('brevhode',),
'breviar': ('breviar',),
'breviara': ('breviar',),
'breviarene': ('breviar',),
'breviarer': ('breviar',),
'breviaret': ('breviar',),
'breviaria': ('breviarium',),
'breviariene': ('breviarium',),
'breviarier': ('breviarium',),
'breviariet': ('breviarium',),
'breviarium': ('breviarium',),
'brevkassa': ('brevkasse',),
'brevkasse': ('brevkasse',),
'brevkassen': ('brevkasse',),
'brevkassene': ('brevkasse',),
'brevkasser': ('brevkasse',),
'brevkort': ('brevkort',),
'brevkorta': ('brevkort',),
'brevkortene': ('brevkort',),
'brevkortet': ('brevkort',),
'brevkurs': ('brevkurs',),
'brevkursa': ('brevkurs',),
'brevkursene': ('brevkurs',),
'brevkurser': ('brevkurs',),
'brevkurset': ('brevkurs',),
'brevkursene': ('brevkursus',),
'brevkurser': ('brevkursus',),
'brevkursus': ('brevkursus',),
'brevkursuset': ('brevkursus',),
'brevporto': ('brevporto',),
'brevportoen': ('brevporto',),
'brevportoene': ('brevporto',),
'brevportoer': ('brevporto',),
'brevsending': ('brevsending',),
'brevsendinga': ('brevsending',),
'brevsendingen': ('brevsending',),
'brevsendingene': ('brevsending',),
'brevsendinger': ('brevsending',),
'brevskole': ('brevskole',),
'brevskolen': ('brevskole',),
'brevskolene': ('brevskole',),
'brevskoler': ('brevskole',),
'brevskriver': ('brevskriver',),
'brevskrivere': ('brevskriver',),
'brevskriveren': ('brevskriver',),
'brevskriverer': ('brevskriver',),
'brevskriverne': ('brevskriver',),
'brevundervisning': ('brevundervisning',),
'brevundervisninga': ('brevundervisning',),
'brevundervisningen': ('brevundervisning',),
'brevundervisningene': ('brevundervisning',),
'brevundervisninger': ('brevundervisning',),
'brevvekt': ('brevvekt',),
'brevvekta': ('brevvekt',),
'brevvekten': ('brevvekt',),
'brevvektene': ('brevvekt',),
'brevvekter': ('brevvekt',),
'brevvenn': ('brevvenn',),
'brevvennen': ('brevvenn',),
'brevvennene': ('brevvenn',),
'brevvenner': ('brevvenn',),
'bridge': ('bridge',),
'bridgen': ('bridge',),
'bridgene': ('bridge',),
'bridger': ('bridge',),
'brie': ('brie',),
'brien': ('brie',),
'briene': ('brie',),
'brier': ('brie',),
'brifing': ('brifing',),
'brifinga': ('brifing',),
'brifingen': ('brifing',),
'brifingene': ('brifing',),
'brifinger': ('brifing',),
'brigade': ('brigade',),
'brigaden': ('brigade',),
'brigadene': ('brigade',),
'brigader': ('brigade',),
'brigadegeneral': ('brigadegeneral',),
'brigadegeneralen': ('brigadegeneral',),
'brigadegeneralene': ('brigadegeneral',),
'brigadegeneraler': ('brigadegeneral',),
'brigadekommandør': ('brigadekommandør',),
'brigadekommandøren': ('brigadekommandør',),
'brigadekommandørene': ('brigadekommandør',),
'brigadekommandører': ('brigadekommandør',),
'brigadeoffiser': ('brigadeoffiser',),
'brigadeoffiseren': ('brigadeoffiser',),
'brigadeoffiserene': ('brigadeoffiser',),
'brigadeoffiserer': ('brigadeoffiser',),
'brigader': ('brigader',),
'brigaderen': ('brigader',),
'brigaderene': ('brigader',),
'brigaderer': ('brigader',),
'brikett': ('brikett',),
'briketten': ('brikett',),
'brikettene': ('brikett',),
'briketter': ('brikett',),
'brikka': ('brikke',),
'brikke': ('brikke',),
'brikken': ('brikke',),
'brikkene': ('brikke',),
'brikker': ('brikke',),
'brikkespell': ('brikkespell',),
'brikkespella': ('brikkespell',),
'brikkespellene': ('brikkespell',),
'brikkespellet': ('brikkespell',),
'brikkespill': ('brikkespill',),
'brikkespilla': ('brikkespill',),
'brikkespillene': ('brikkespill',),
'brikkespillet': ('brikkespill',),
'brikkevev': ('brikkevev',),
'brikkeveven': ('brikkevev',),
'brikkevevene': ('brikkevev',),
'brikkevever': ('brikkevev',),
'briks': ('briks',),
'briksen': ('briks',),
'briksene': ('briks',),
'brikser': ('briks',),
'briljans': ('briljans',),
'briljansen': ('briljans',),
'briljansene': ('briljans',),
'briljanser': ('briljans',),
'briljant': ('briljant',),
'briljanten': ('briljant',),
'briljantene': ('briljant',),
'briljanter': ('briljant',),
'briljantin': ('briljantin',),
'briljantinen': ('briljantin',),
'briljantinene': ('briljantin',),
'briljantiner': ('briljantin',),
'briljantine': ('briljantine',),
'briljantinen': ('briljantine',),
'briljantinene': ('briljantine',),
'briljantiner': ('briljantine',),
'briljantsmykka': ('briljantsmykke',),
'briljantsmykke': ('briljantsmykke',),
'briljantsmykkene': ('briljantsmykke',),
'briljantsmykker': ('briljantsmykke',),
'briljantsmykket': ('briljantsmykke',),
'brilla': ('brille',),
'brille': ('brille',),
'brillen': ('brille',),
'brillene': ('brille',),
'briller': ('brille',),
'brillefutteral': ('brillefutteral',),
'brillefutterala': ('brillefutteral',),
'brillefutteralene': ('brillefutteral',),
'brillefutteraler': ('brillefutteral',),
'brillefutteralet': ('brillefutteral',),
'brilleglas': ('brilleglas',),
'brilleglasa': ('brilleglas',),
'brilleglasene': ('brilleglas',),
'brilleglaset': ('brilleglas',),
'brilleglass': ('brilleglass',),
'brilleglassa': ('brilleglass',),
'brilleglassene': ('brilleglass',),
'brilleglasset': ('brilleglass',),
'brilleinnfatning': ('brilleinnfatning',),
'brilleinnfatninga': ('brilleinnfatning',),
'brilleinnfatningen': ('brilleinnfatning',),
'brilleinnfatningene': ('brilleinnfatning',),
'brilleinnfatninger': ('brilleinnfatning',),
'brilleslange': ('brilleslange',),
'brilleslangen': ('brilleslange',),
'brilleslangene': ('brilleslange',),
'brilleslanger': ('brilleslange',),
'brim': ('brim',),
'brima': ('brim',),
'brimene': ('brim',),
'brimet': ('brim',),
'brimsjø': ('brimsjø',),
'brimsjøen': ('brimsjø',),
'brimsjøene': ('brimsjø',),
'brimsjøer': ('brimsjø',),
'bringe': ('bringe',),
'bringen': ('bringe',),
'bringene': ('bringe',),
'bringer': ('bringe',),
'bringa': ('bringe',),
'bringe': ('bringe',),
'bringen': ('bringe',),
'bringene': ('bringe',),
'bringer': ('bringe',),
'bringebær': ('bringebær',),
'bringebæra': ('bringebær',),
'bringebærene': ('bringebær',),
'bringebæret': ('bringebær',),
'bringebær': ('bringebær',),
'bringebæra': ('bringebær',),
'bringebærene': ('bringebær',),
'bringebæret': ('bringebær',),
'bringebærbille': ('bringebærbille',),
'bringebærbillen': ('bringebærbille',),
'bringebærbillene': ('bringebærbille',),
'bringebærbiller': ('bringebærbille',),
'bringebærbusk': ('bringebærbusk',),
'bringebærbusken': ('bringebærbusk',),
'bringebærbuskene': ('bringebærbusk',),
'bringebærbusker': ('bringebærbusk',),
'bringebærmakk': ('bringebærmakk',),
'bringebærmakken': ('bringebærmakk',),
'bringebærmakkene': ('bringebærmakk',),
'bringebærmakker': ('bringebærmakk',),
'bringebærmark': ('bringebærmark',),
'bringebærmarken': ('bringebærmark',),
'bringebærmarkene': ('bringebærmark',),
'bringebærmarker': ('bringebærmark',),
'bringebærsaft': ('bringebærsaft',),
'bringebærsafta': ('bringebærsaft',),
'bringebærsaften': ('bringebærsaft',),
'bringebærsaftene': ('bringebærsaft',),
'bringebærsafter': ('bringebærsaft',),
'bringebærsyltetøy': ('bringebærsyltetøy',),
'bringebærsyltetøya': ('bringebærsyltetøy',),
'bringebærsyltetøyene': ('bringebærsyltetøy',),
'bringebærsyltetøyet': ('bringebærsyltetøy',),
'brink': ('brink',),
'brinken': ('brink',),
'brinkene': ('brink',),
'brinker': ('brink',),
'bris': ('bris',),
'brisen': ('bris',),
'brisene': ('bris',),
'briser': ('bris',),
'brisantammunisjon': ('brisantammunisjon',),
'brisantammunisjonen': ('brisantammunisjon',),
'brisantammunisjonene': ('brisantammunisjon',),
'brisantammunisjoner': ('brisantammunisjon',),
'brisk': ('brisk',),
'brisken': ('brisk',),
'briskene': ('brisk',),
'brisker': ('brisk',),
'brisk': ('brisk',),
'brisken': ('brisk',),
'briskene': ('brisk',),
'brisker': ('brisk',),
'briskelåg': ('briskelåg',),
'briskelågen': ('briskelåg',),
'briskelågene': ('briskelåg',),
'briskelåger': ('briskelåg',),
'briskelåg': ('briskelåg',),
'briskelågen': ('briskelåg',),
'briskelågene': ('briskelåg',),
'briskelåger': ('briskelåg',),
'brisling': ('brisling',),
'brislingen': ('brisling',),
'brislingene': ('brisling',),
'brislinger': ('brisling',),
'brislingfiska': ('brislingfiske',),
'brislingfiske': ('brislingfiske',),
'brislingfiskene': ('brislingfiske',),
'brislingfisker': ('brislingfiske',),
'brislingfisket': ('brislingfiske',),
'brislingsteng': ('brislingsteng',),
'brislingstenga': ('brislingsteng',),
'brislingstengene': ('brislingsteng',),
'brislingstenget': ('brislingsteng',),
'brislene': ('brissel',),
'brisler': ('brissel',),
'brissel': ('brissel',),
'brisselen': ('brissel',),
'brist': ('brist',),
'bristen': ('brist',),
'bristene': ('brist',),
'brister': ('brist',),
'brist': ('brist',),
'bristen': ('brist',),
'bristene': ('brist',),
'brister': ('brist',),
'bristepunkt': ('bristepunkt',),
'bristepunkta': ('bristepunkt',),
'bristepunktene': ('bristepunkt',),
'bristepunktet': ('bristepunkt',),
'brite': ('brite',),
'briten': ('brite',),
'britene': ('brite',),
'briter': ('brite',),
'britisk-engelsk': ('britisk-engelsk',),
'britisk-engelsken': ('britisk-engelsk',),
'britisk-engelskene': ('britisk-engelsk',),
'britisk-engelsker': ('britisk-engelsk',),
'britisk-engelsk': ('britisk-engelsk',),
'britisk-engelsken': ('britisk-engelsk',),
'britisk-engelskene': ('britisk-engelsk',),
'britisk-engelsker': ('britisk-engelsk',),
'bro': ('bro',),
'broa': ('bro',),
'broen': ('bro',),
'broene': ('bro',),
'broer': ('bro',),
'bro-bro-brille': ('bro-bro-brille',),
'brobygger': ('brobygger',),
'brobyggere': ('brobygger',),
'brobyggeren': ('brobygger',),
'brobyggerer': ('brobygger',),
'brobyggerne': ('brobygger',),
'brodd': ('brodd',),
'brodden': ('brodd',),
'broddene': ('brodd',),
'brodder': ('brodd',),
'broder': ('broder',),
'broderen': ('broder',),
'brødre': ('broder',),
'brødrene': ('broder',),
'broderfolk': ('broderfolk',),
'broderfolka': ('broderfolk',),
'broderfolkene': ('broderfolk',),
'broderfolket': ('broderfolk',),
'brodergarn': ('brodergarn',),
'brodergarna': ('brodergarn',),
'brodergarnene': ('brodergarn',),
'brodergarnet': ('brodergarn',),
'broderhand': ('broderhand',),
'broderhanda': ('broderhand',),
'broderhanden': ('broderhand',),
'broderhendene': ('broderhand',),
'broderhender': ('broderhand',),
'broderhendene': ('broderhånd',),
'broderhender': ('broderhånd',),
'broderhånd': ('broderhånd',),
'broderhånda': ('broderhånd',),
'broderhånden': ('broderhånd',),
'broderi': ('broderi',),
'broderia': ('broderi',),
'broderiene': ('broderi',),
'broderier': ('broderi',),
'broderiet': ('broderi',),
'broderiforretning': ('broderiforretning',),
'broderiforretninga': ('broderiforretning',),
'broderiforretningen': ('broderiforretning',),
'broderiforretningene': ('broderiforretning',),
'broderiforretninger': ('broderiforretning',),
'broderkjærlighet': ('broderkjærlighet',),
'broderkjærligheta': ('broderkjærlighet',),
'broderkjærligheten': ('broderkjærlighet',),
'broderkjærlighetene': ('broderkjærlighet',),
'broderkjærligheter': ('broderkjærlighet',),
'broderland': ('broderland',),
'broderlanda': ('broderland',),
'broderlandene': ('broderland',),
'broderlandet': ('broderland',),
'brodermord': ('brodermord',),
'brodermorda': ('brodermord',),
'brodermordene': ('brodermord',),
'brodermordet': ('brodermord',),
'broderring': ('broderring',),
'broderringen': ('broderring',),
'broderringene': ('broderring',),
'broderringer': ('broderring',),
'brodersaks': ('brodersaks',),
'brodersaksa': ('brodersaks',),
'brodersaksen': ('brodersaks',),
'brodersaksene': ('brodersaks',),
'brodersakser': ('brodersaks',),
'brodersamfunn': ('brodersamfunn',),
'brodersamfunna': ('brodersamfunn',),
'brodersamfunnene': ('brodersamfunn',),
'brodersamfunnet': ('brodersamfunn',),
'broderånd': ('broderånd',),
'broderånden': ('broderånd',),
'broderåndene': ('broderånd',),
'broderånder': ('broderånd',),
'brohoda': ('brohode',),
'brohode': ('brohode',),
'brohodene': ('brohode',),
'brohoder': ('brohode',),
'brohodet': ('brohode',),
'broiler': ('broiler',),
'broilere': ('broiler',),
'broileren': ('broiler',),
'broilerer': ('broiler',),
'broilerne': ('broiler',),
'broilerproduksjon': ('broilerproduksjon',),
'broilerproduksjonen': ('broilerproduksjon',),
'broilerproduksjonene': ('broilerproduksjon',),
'broilerproduksjoner': ('broilerproduksjon',),
'brok': ('brok',),
'broka': ('brok',),
'broken': ('brok',),
'brøkene': ('brok',),
'brøker': ('brok',),
'brok': ('brok',),
'broka': ('brok',),
'broken': ('brok',),
'brøkene': ('brok',),
'brøker': ('brok',),
'brokade': ('brokade',),
'brokaden': ('brokade',),
'brokadene': ('brokade',),
'brokader': ('brokade',),
'brokadestoff': ('brokadestoff',),
'brokadestoffa': ('brokadestoff',),
'brokadestoffene': ('brokadestoff',),
'brokadestoffer': ('brokadestoff',),
'brokadestoffet': ('brokadestoff',),
'brokar': ('brokar',),
'brokara': ('brokar',),
'brokarene': ('brokar',),
'brokaret': ('brokar',),
'brokk': ('brokk',),
'brokka': ('brokk',),
'brokken': ('brokk',),
'brokkene': ('brokk',),
'brokker': ('brokk',),
'brokket': ('brokk',),
'brokkbind': ('brokkbind',),
'brokkbinda': ('brokkbind',),
'brokkbindene': ('brokkbind',),
'brokkbindet': ('brokkbind',),
'brokke': ('brokke',),
'brokken': ('brokke',),
'brokkene': ('brokke',),
'brokker': ('brokke',),
'brokkoli': ('brokkoli',),
'brokkolien': ('brokkoli',),
'brokkoliene': ('brokkoli',),
'brokkolier': ('brokkoli',),
'brokkurt': ('brokkurt',),
'brokkurta': ('brokkurt',),
'brokkurten': ('brokkurt',),
'brokkurtene': ('brokkurt',),
'brokkurter': ('brokkurt',),
'brolegger': ('brolegger',),
'broleggere': ('brolegger',),
'broleggeren': ('brolegger',),
'broleggerer': ('brolegger',),
'broleggerne': ('brolegger',),
'brolegging': ('brolegging',),
'brolegginga': ('brolegging',),
'broleggingen': ('brolegging',),
'broleggingene': ('brolegging',),
'brolegginger': ('brolegging',),
'brolegning': ('brolegning',),
'brolegninga': ('brolegning',),
'brolegningen': ('brolegning',),
'brolegningene': ('brolegning',),
'brolegninger': ('brolegning',),
'brom': ('brom',),
'bromma': ('brom',),
'brommene': ('brom',),
'brommet': ('brom',),
'brom': ('brom',),
'bromma': ('brom',),
'brommene': ('brom',),
'brommet': ('brom',),
'bromid': ('bromid',),
'bromida': ('bromid',),
'bromidene': ('bromid',),
'bromider': ('bromid',),
'bromidet': ('bromid',),
'bromidpapir': ('bromidpapir',),
'bromidpapira': ('bromidpapir',),
'bromidpapirene': ('bromidpapir',),
'bromidpapirer': ('bromidpapir',),
'bromidpapiret': ('bromidpapir',),
'bromisme': ('bromisme',),
'bromismen': ('bromisme',),
'bromismene': ('bromisme',),
'bromismer': ('bromisme',),
'bronkie': ('bronkie',),
'bronkien': ('bronkie',),
'bronkiene': ('bronkie',),
'bronkier': ('bronkie',),
'bronkiegrein': ('bronkiegrein',),
'bronkiegreina': ('bronkiegrein',),
'bronkiegreinen': ('bronkiegrein',),
'bronkiegreinene': ('bronkiegrein',),
'bronkiegreiner': ('bronkiegrein',),
'bronkiegren': ('bronkiegren',),
'bronkiegrena': ('bronkiegren',),
'bronkiegrenen': ('bronkiegren',),
'bronkiegrenene': ('bronkiegren',),
'bronkiegrener': ('bronkiegren',),
'bronkitt': ('bronkitt',),
'bronkitten': ('bronkitt',),
'bronkittene': ('bronkitt',),
'bronkitter': ('bronkitt',),
'bronkitthoste': ('bronkitthoste',),
'bronkitthosten': ('bronkitthoste',),
'bronkitthostene': ('bronkitthoste',),
'bronkitthoster': ('bronkitthoste',),
'bronse': ('bronse',),
'bronsen': ('bronse',),
'bronsene': ('bronse',),
'bronser': ('bronse',),
'bronsealder': ('bronsealder',),
'bronsealdere': ('bronsealder',),
'bronsealderen': ('bronsealder',),
'bronsealderer': ('bronsealder',),
'bronsealderne': ('bronsealder',),
'bronsealdre': ('bronsealder',),
'bronsealdrene': ('bronsealder',),
'bronsealdrer': ('bronsealder',),
'bronsefarge': ('bronsefarge',),
'bronsefargen': ('bronsefarge',),
'bronsefargene': ('bronsefarge',),
'bronsefarger': ('bronsefarge',),
'bronsemedalje': ('bronsemedalje',),
'bronsemedaljen': ('bronsemedalje',),
'bronsemedaljene': ('bronsemedalje',),
'bronsemedaljer': ('bronsemedalje',),
'bronsemedaljevinner': ('bronsemedaljevinner',),
'bronsemedaljevinnere': ('bronsemedaljevinner',),
'bronsemedaljevinneren': ('bronsemedaljevinner',),
'bronsemedaljevinnerer': ('bronsemedaljevinner',),
'bronsemedaljevinnerne': ('bronsemedaljevinner',),
'bropilar': ('bropilar',),
'bropilaren': ('bropilar',),
'bropilarene': ('bropilar',),
'bropilarer': ('bropilar',),
'bror': ('bror',),
'broren': ('bror',),
'brødre': ('bror',),
'brødrene': ('bror',),
'brordatter': ('brordatter',),
'brordattera': ('brordatter',),
'brordatteren': ('brordatter',),
'brordøtre': ('brordatter',),
'brordøtrene': ('brordatter',),
'brordøtrer': ('brordatter',),
'brorkona': ('brorkone',),
'brorkone': ('brorkone',),
'brorkonen': ('brorkone',),
'brorkonene': ('brorkone',),
'brorkoner': ('brorkone',),
'brorpart': ('brorpart',),
'brorparten': ('brorpart',),
'brorpartene': ('brorpart',),
'brorparter': ('brorpart',),
'brorskap': ('brorskap',),
'brorskapa': ('brorskap',),
'brorskapen': ('brorskap',),
'brorskapene': ('brorskap',),
'brorskaper': ('brorskap',),
'brorskapet': ('brorskap',),
'brorsønn': ('brorsønn',),
'brorsønnen': ('brorsønn',),
'brorsønnene': ('brorsønn',),
'brorsønner': ('brorsønn',),
'brosja': ('brosje',),
'brosje': ('brosje',),
'brosjen': ('brosje',),
'brosjene': ('brosje',),
'brosjer': ('brosje',),
'brosjyre': ('brosjyre',),
'brosjyren': ('brosjyre',),
'brosjyrene': ('brosjyre',),
'brosjyrer': ('brosjyre',),
'brosma': ('brosme',),
'brosme': ('brosme',),
'brosmen': ('brosme',),
'brosmene': ('brosme',),
'brosmer': ('brosme',),
'brospenn': ('brospenn',),
'brospenna': ('brospenn',),
'brospennene': ('brospenn',),
'brospennet': ('brospenn',),
'brostein': ('brostein',),
'brosteinen': ('brostein',),
'brosteinene': ('brostein',),
'brosteiner': ('brostein',),
'brotsj': ('brotsj',),
'brotsjen': ('brotsj',),
'brotsjene': ('brotsj',),
'brotsjer': ('brotsj',),
'brott': ('brott',),
'brotta': ('brott',),
'brottene': ('brott',),
'brottet': ('brott',),
'brott': ('brott',),
'brotta': ('brott',),
'brottene': ('brott',),
'brottet': ('brott',),
'brottbelastning': ('brottbelastning',),
'brottbelastninga': ('brottbelastning',),
'brottbelastningen': ('brottbelastning',),
'brottbelastningene': ('brottbelastning',),
'brottbelastninger': ('brottbelastning',),
'brottfasthet': ('brottfasthet',),
'brottfastheta': ('brottfasthet',),
'brottfastheten': ('brottfasthet',),
'brottfasthetene': ('brottfasthet',),
'brottfastheter': ('brottfasthet',),
'brottflata': ('brottflate',),
'brottflate': ('brottflate',),
'brottflaten': ('brottflate',),
'brottflatene': ('brottflate',),
'brottflater': ('brottflate',),
'brotthella': ('brotthelle',),
'brotthelle': ('brotthelle',),
'brotthellen': ('brotthelle',),
'brotthellene': ('brotthelle',),
'brottheller': ('brotthelle',),
'brottsjø': ('brottsjø',),
'brottsjøen': ('brottsjø',),
'brottsjøene': ('brottsjø',),
'brottsjøer': ('brottsjø',),
'brottsmann': ('brottsmann',),
'brottsmannen': ('brottsmann',),
'brottsmenn': ('brottsmann',),
'brottsmennene': ('brottsmann',),
'brottstein': ('brottstein',),
'brottsteinen': ('brottstein',),
'brottsteinene': ('brottstein',),
'brottsteiner': ('brottstein',),
'brottstykka': ('brottstykke',),
'brottstykke': ('brottstykke',),
'brottstykkene': ('brottstykke',),
'brottstykker': ('brottstykke',),
'brottstykket': ('brottstykke',),
'brottstyrke': ('brottstyrke',),
'brottstyrken': ('brottstyrke',),
'brottstyrkene': ('brottstyrke',),
'brottstyrker': ('brottstyrke',),
'brottsverk': ('brottsverk',),
'brottsverka': ('brottsverk',),
'brottsverkene': ('brottsverk',),
'brottsverker': ('brottsverk',),
'brottsverket': ('brottsverk',),
'bru': ('bru',),
'brua': ('bru',),
'bruen': ('bru',),
'bruene': ('bru',),
'bruer': ('bru',),
'brubygger': ('brubygger',),
'brubyggere': ('brubygger',),
'brubyggeren': ('brubygger',),
'brubyggerer': ('brubygger',),
'brubyggerne': ('brubygger',),
'brud': ('brud',),
'bruda': ('brud',),
'bruden': ('brud',),
'brudene': ('brud',),
'bruder': ('brud',),
'brud': ('brud',),
'bruda': ('brud',),
'bruden': ('brud',),
'brudene': ('brud',),
'bruder': ('brud',),
'brudd': ('brudd',),
'brudda': ('brudd',),
'bruddene': ('brudd',),
'bruddet': ('brudd',),
'bruddbelastning': ('bruddbelastning',),
'bruddbelastninga': ('bruddbelastning',),
'bruddbelastningen': ('bruddbelastning',),
'bruddbelastningene': ('bruddbelastning',),
'bruddbelastninger': ('bruddbelastning',),
'bruddfasthet': ('bruddfasthet',),
'bruddfastheta': ('bruddfasthet',),
'bruddfastheten': ('bruddfasthet',),
'bruddfasthetene': ('bruddfasthet',),
'bruddfastheter': ('bruddfasthet',),
'bruddflata': ('bruddflate',),
'bruddflate': ('bruddflate',),
'bruddflaten': ('bruddflate',),
'bruddflatene': ('bruddflate',),
'bruddflater': ('bruddflate',),
'bruddhella': ('bruddhelle',),
'bruddhelle': ('bruddhelle',),
'bruddhellen': ('bruddhelle',),
'bruddhellene': ('bruddhelle',),
'bruddheller': ('bruddhelle',),
'bruddstein': ('bruddstein',),
'bruddsteinen': ('bruddstein',),
'bruddsteinene': ('bruddstein',),
'bruddsteiner': ('bruddstein',),
'bruddstykka': ('bruddstykke',),
'bruddstykke': ('bruddstykke',),
'bruddstykkene': ('bruddstykke',),
'bruddstykker': ('bruddstykke',),
'bruddstykket': ('bruddstykke',),
'bruddstyrke': ('bruddstyrke',),
'bruddstyrken': ('bruddstyrke',),
'bruddstyrkene': ('bruddstyrke',),
'bruddstyrker': ('bruddstyrke',),
'brudebukett': ('brudebukett',),
'brudebuketten': ('brudebukett',),
'brudebukettene': ('brudebukett',),
'brudebuketter': ('brudebukett',),
'brudebukett': ('brudebukett',),
'brudebuketten': ('brudebukett',),
'brudebukettene': ('brudebukett',),
'brudebuketter': ('brudebukett',),
'brudedans': ('brudedans',),
'brudedansen': ('brudedans',),
'brudedansene': ('brudedans',),
'brudedanser': ('brudedans',),
'brudedans': ('brudedans',),
'brudedansen': ('brudedans',),
'brudedansene': ('brudedans',),
'brudedanser': ('brudedans',),
'brudeferd': ('brudeferd',),
'brudeferda': ('brudeferd',),
'brudeferden': ('brudeferd',),
'brudeferdene': ('brudeferd',),
'brudeferder': ('brudeferd',),
'brudeferd': ('brudeferd',),
'brudeferda': ('brudeferd',),
'brudeferden': ('brudeferd',),
'brudeferdene': ('brudeferd',),
'brudeferder': ('brudeferd',),
'brudefølga': ('brudefølge',),
'brudefølge': ('brudefølge',),
'brudefølgene': ('brudefølge',),
'brudefølger': ('brudefølge',),
'brudefølget': ('brudefølge',),
'brudefølga': ('brudefølge',),
'brudefølge': ('brudefølge',),
'brudefølgene': ('brudefølge',),
'brudefølger': ('brudefølge',),
'brudefølget': ('brudefølge',),
'brudefølgja': ('brudefølgje',),
'brudefølgje': ('brudefølgje',),
'brudefølgjene': ('brudefølgje',),
'brudefølgjer': ('brudefølgje',),
'brudefølgjet': ('brudefølgje',),
'brudefølgja': ('brudefølgje',),
'brudefølgje': ('brudefølgje',),
'brudefølgjene': ('brudefølgje',),
'brudefølgjer': ('brudefølgje',),
'brudefølgjet': ('brudefølgje',),
'brudelys': ('brudelys',),
'brudelysa': ('brudelys',),
'brudelysen': ('brudelys',),
'brudelysene': ('brudelys',),
'brudelyser': ('brudelys',),
'brudelyset': ('brudelys',),
'brudelys': ('brudelys',),
'brudelysa': ('brudelys',),
'brudelysen': ('brudelys',),
'brudelysene': ('brudelys',),
'brudelyser': ('brudelys',),
'brudelyset': ('brudelys',),
'brudemarsj': ('brudemarsj',),
'brudemarsjen': ('brudemarsj',),
'brudemarsjene': ('brudemarsj',),
'brudemarsjer': ('brudemarsj',),
'brudemarsj': ('brudemarsj',),
'brudemarsjen': ('brudemarsj',),
'brudemarsjene': ('brudemarsj',),
'brudemarsjer': ('brudemarsj',),
'brudepar': ('brudepar',),
'brudepara': ('brudepar',),
'brudeparene': ('brudepar',),
'brudeparet': ('brudepar',),
'brudepar': ('brudepar',),
'brudepara': ('brudepar',),
'brudeparene': ('brudepar',),
'brudeparet': ('brudepar',),
'brudeseng': ('brudeseng',),
'brudesenga': ('brudeseng',),
'brudesengen': ('brudeseng',),
'brudesengene': ('brudeseng',),
'brudesenger': ('brudeseng',),
'brudeseng': ('brudeseng',),
'brudesenga': ('brudeseng',),
'brudesengen': ('brudeseng',),
'brudesengene': ('brudeseng',),
'brudesenger': ('brudeseng',),
'brudeslør': ('brudeslør',),
'brudesløra': ('brudeslør',),
'brudeslørene': ('brudeslør',),
'brudesløret': ('brudeslør',),
'brudeslør': ('brudeslør',),
'brudesløra': ('brudeslør',),
'brudeslørene': ('brudeslør',),
'brudesløret': ('brudeslør',),
'brudeslør': ('brudeslør',),
'brudesløra': ('brudeslør',),
'brudeslørene': ('brudeslør',),
'brudesløret': ('brudeslør',),
'brudeslør': ('brudeslør',),
'brudesløra': ('brudeslør',),
'brudeslørene': ('brudeslør',),
'brudesløret': ('brudeslør',),
'brudespore': ('brudespore',),
'brudesporen': ('brudespore',),
'brudesporene': ('brudespore',),
'brudesporer': ('brudespore',),
'brudespore': ('brudespore',),
'brudesporen': ('brudespore',),
'brudesporene': ('brudespore',),
'brudesporer': ('brudespore',),
'brudevielse': ('brudevielse',),
'brudevielsen': ('brudevielse',),
'brudevielsene': ('brudevielse',),
'brudevielser': ('brudevielse',),
'brudevielse': ('brudevielse',),
'brudevielsen': ('brudevielse',),
'brudevielsene': ('brudevielse',),
'brudevielser': ('brudevielse',),
'brudevigsel': ('brudevigsel',),
'brudevigselen': ('brudevigsel',),
'brudevigslene': ('brudevigsel',),
'brudevigsler': ('brudevigsel',),
'brudevigsel': ('brudevigsel',),
'brudevigselen': ('brudevigsel',),
'brudevigslene': ('brudevigsel',),
'brudevigsler': ('brudevigsel',),
'brudgom': ('brudgom',),
'brudgommen': ('brudgom',),
'brudgommene': ('brudgom',),
'brudgommer': ('brudgom',),
'brudgomstale': ('brudgomstale',),
'brudgomstalen': ('brudgomstale',),
'brudgomstalene': ('brudgomstale',),
'brudgomstaler': ('brudgomstale',),
'brudulje': ('brudulje',),
'bruduljen': ('brudulje',),
'bruduljene': ('brudulje',),
'bruduljer': ('brudulje',),
'brugda': ('brugde',),
'brugde': ('brugde',),
'brugden': ('brugde',),
'brugdene': ('brugde',),
'brugder': ('brugde',),
'bruhoda': ('bruhode',),
'bruhode': ('bruhode',),
'bruhodene': ('bruhode',),
'bruhoder': ('bruhode',),
'bruhodet': ('bruhode',),
'bruk': ('bruk',),
'bruka': ('bruk',),
'brukene': ('bruk',),
'bruket': ('bruk',),
'bruk': ('bruk',),
'bruka': ('bruk',),
'bruken': ('bruk',),
'brukene': ('bruk',),
'bruker': ('bruk',),
'bruket': ('bruk',),
'brukar': ('brukar',),
'brukara': ('brukar',),
'brukarene': ('brukar',),
'brukaret': ('brukar',),
'brukelighet': ('brukelighet',),
'brukeligheta': ('brukelighet',),
'brukeligheten': ('brukelighet',),
'brukelighetene': ('brukelighet',),
'brukeligheter': ('brukelighet',),
'bruker': ('bruker',),
'brukere': ('bruker',),
'brukeren': ('bruker',),
'brukerer': ('bruker',),
'brukerne': ('bruker',),
'bruksanvisning': ('bruksanvisning',),
'bruksanvisninga': ('bruksanvisning',),
'bruksanvisningen': ('bruksanvisning',),
'bruksanvisningene': ('bruksanvisning',),
'bruksanvisninger': ('bruksanvisning',),
'bruksegenskap': ('bruksegenskap',),
'bruksegenskapen': ('bruksegenskap',),
'bruksegenskapene': ('bruksegenskap',),
'bruksegenskaper': ('bruksegenskap',),
'brukseier': ('brukseier',),
'brukseiere': ('brukseier',),
'brukseieren': ('brukseier',),
'brukseierer': ('brukseier',),
'brukseierne': ('brukseier',),
'bruksendring': ('bruksendring',),
'bruksendringa': ('bruksendring',),
'bruksendringen': ('bruksendring',),
'bruksendringene': ('bruksendring',),
'bruksendringer': ('bruksendring',),
'bruksgjenstand': ('bruksgjenstand',),
'bruksgjenstanden': ('bruksgjenstand',),
'bruksgjenstandene': ('bruksgjenstand',),
'bruksgjenstander': ('bruksgjenstand',),
'brukshaver': ('brukshaver',),
'brukshavere': ('brukshaver',),
'brukshaveren': ('brukshaver',),
'brukshaverer': ('brukshaver',),
'brukshaverne': ('brukshaver',),
'brukskultur': ('brukskultur',),
'brukskulturen': ('brukskultur',),
'brukskulturene': ('brukskultur',),
'brukskulturer': ('brukskultur',),
'brukskunst': ('brukskunst',),
'brukskunsten': ('brukskunst',),
'brukskunstene': ('brukskunst',),
'brukskunster': ('brukskunst',),
'brukskunstner': ('brukskunstner',),
'brukskunstnere': ('brukskunstner',),
'brukskunstneren': ('brukskunstner',),
'brukskunstnerer': ('brukskunstner',),
'brukskunstnerne': ('brukskunstner',),
'bruksmåte': ('bruksmåte',),
'bruksmåten': ('bruksmåte',),
'bruksmåtene': ('bruksmåte',),
'bruksmåter': ('bruksmåte',),
'bruksnummer': ('bruksnummer',),
'bruksnummeret': ('bruksnummer',),
'bruksnumra': ('bruksnummer',),
'bruksnumre': ('bruksnummer',),
'bruksnumrene': ('bruksnummer',),
'bruksområda': ('bruksområde',),
'bruksområde': ('bruksområde',),
'bruksområdene': ('bruksområde',),
'bruksområder': ('bruksområde',),
'bruksområdet': ('bruksområde',),
'bruksplen': ('bruksplen',),
'bruksplenen': ('bruksplen',),
'bruksplenene': ('bruksplen',),
'bruksplener': ('bruksplen',),
'bruksplikt': ('bruksplikt',),
'bruksplikta': ('bruksplikt',),
'bruksplikten': ('bruksplikt',),
'brukspliktene': ('bruksplikt',),
'bruksplikter': ('bruksplikt',),
'bruksrett': ('bruksrett',),
'bruksretten': ('bruksrett',),
'bruksrettene': ('bruksrett',),
'bruksretter': ('bruksrett',),
'bruksskog': ('bruksskog',),
'bruksskogen': ('bruksskog',),
'bruksskogene': ('bruksskog',),
'bruksskoger': ('bruksskog',),
'brukstid': ('brukstid',),
'brukstida': ('brukstid',),
'brukstiden': ('brukstid',),
'brukstidene': ('brukstid',),
'brukstider': ('brukstid',),
'brukstjuveri': ('brukstjuveri',),
'brukstjuveria': ('brukstjuveri',),
'brukstjuveriene': ('brukstjuveri',),
'brukstjuverier': ('brukstjuveri',),
'brukstjuveriet': ('brukstjuveri',),
'brukstyveri': ('brukstyveri',),
'brukstyveria': ('brukstyveri',),
'brukstyveriene': ('brukstyveri',),
'brukstyverier': ('brukstyveri',),
'brukstyveriet': ('brukstyveri',),
'bruksverdi': ('bruksverdi',),
'bruksverdien': ('bruksverdi',),
'bruksverdiene': ('bruksverdi',),
'bruksverdier': ('bruksverdi',),
'bruktbil': ('bruktbil',),
'bruktbilen': ('bruktbil',),
'bruktbilene': ('bruktbil',),
'bruktbiler': ('bruktbil',),
'bruktbilforhandler': ('bruktbilforhandler',),
'bruktbilforhandlere': ('bruktbilforhandler',),
'bruktbilforhandleren': ('bruktbilforhandler',),
'bruktbilforhandlerer': ('bruktbilforhandler',),
'bruktbilforhandlerne': ('bruktbilforhandler',),
'bruktbilmarked': ('bruktbilmarked',),
'bruktbilmarkeda': ('bruktbilmarked',),
'bruktbilmarkedene': ('bruktbilmarked',),
'bruktbilmarkeder': ('bruktbilmarked',),
'bruktbilmarkedet': ('bruktbilmarked',),
'bruktbilmarknad': ('bruktbilmarknad',),
'bruktbilmarknaden': ('bruktbilmarknad',),
'bruktbilmarknadene': ('bruktbilmarknad',),
'bruktbilmarknader': ('bruktbilmarknad',),
'brulegger': ('brulegger',),
'bruleggere': ('brulegger',),
'bruleggeren': ('brulegger',),
'bruleggerer': ('brulegger',),
'bruleggerne': ('brulegger',),
'brulegging': ('brulegging',),
'brulegginga': ('brulegging',),
'bruleggingen': ('brulegging',),
'bruleggingene': ('brulegging',),
'brulegginger': ('brulegging',),
'brulegning': ('brulegning',),
'brulegninga': ('brulegning',),
'brulegningen': ('brulegning',),
'brulegningene': ('brulegning',),
'brulegninger': ('brulegning',),
'brum': ('brum',),
'brumma': ('brum',),
'brummene': ('brum',),
'brummet': ('brum',),
'brumlebasse': ('brumlebasse',),
'brumlebassen': ('brumlebasse',),
'brumlebassene': ('brumlebasse',),
'brumlebasser': ('brumlebasse',),
'brunalge': ('brunalge',),
'brunalgen': ('brunalge',),
'brunalgene': ('brunalge',),
'brunalger': ('brunalge',),
'brunbjørn': ('brunbjørn',),
'brunbjørnen': ('brunbjørn',),
'brunbjørnene': ('brunbjørn',),
'brunbjørner': ('brunbjørn',),
'bruneier': ('bruneier',),
'bruneiere': ('bruneier',),
'bruneieren': ('bruneier',),
'bruneierer': ('bruneier',),
'bruneierne': ('bruneier',),
'brunetta': ('brunette',),
'brunette': ('brunette',),
'brunetten': ('brunette',),
'brunettene': ('brunette',),
'brunetter': ('brunette',),
'brunfe': ('brunfe',),
'brunfea': ('brunfe',),
'brunfeene': ('brunfe',),
'brunfeet': ('brunfe',),
'brunjernstein': ('brunjernstein',),
'brunjernsteinen': ('brunjernstein',),
'brunjernsteinene': ('brunjernstein',),
'brunjernsteiner': ('brunjernstein',),
'brunkol': ('brunkol',),
'brunkola': ('brunkol',),
'brunkolene': ('brunkol',),
'brunkolet': ('brunkol',),
'brunkol': ('brunkol',),
'brunkola': ('brunkol',),
'brunkolet': ('brunkol',),
'brunkoltjæra': ('brunkoltjære',),
'brunkoltjære': ('brunkoltjære',),
'brunkoltjæren': ('brunkoltjære',),
'brunkoltjærene': ('brunkoltjære',),
'brunkoltjærer': ('brunkoltjære',),
'brunkull': ('brunkull',),
'brunkulla': ('brunkull',),
'brunkullene': ('brunkull',),
'brunkullet': ('brunkull',),
'brunkulltjæra': ('brunkulltjære',),
'brunkulltjære': ('brunkulltjære',),
'brunkulltjæren': ('brunkulltjære',),
'brunkulltjærene': ('brunkulltjære',),
'brunkulltjærer': ('brunkulltjære',),
'brunnakke': ('brunnakke',),
'brunnakken': ('brunnakke',),
'brunnakkene': ('brunnakke',),
'brunnakker': ('brunnakke',),
'brunost': ('brunost',),
'brunosten': ('brunost',),
'brunostene': ('brunost',),
'brunoster': ('brunost',),
'brunrot': ('brunrot',),
'brunrota': ('brunrot',),
'brunroten': ('brunrot',),
'brunrøttene': ('brunrot',),
'brunrøtter': ('brunrot',),
'brunsj': ('brunsj',),
'brunsjen': ('brunsj',),
'brunsjene': ('brunsj',),
'brunsjer': ('brunsj',),
'brunskjorta': ('brunskjorte',),
'brunskjorte': ('brunskjorte',),
'brunskjorten': ('brunskjorte',),
'brunskjortene': ('brunskjorte',),
'brunskjorter': ('brunskjorte',),
'brunst': ('brunst',),
'brunsten': ('brunst',),
'brunstene': ('brunst',),
'brunster': ('brunst',),
'brunstein': ('brunstein',),
'brunsteinen': ('brunstein',),
'brunsteinene': ('brunstein',),
'brunsteiner': ('brunstein',),
'brunsttid': ('brunsttid',),
'brunsttida': ('brunsttid',),
'brunsttiden': ('brunsttid',),
'brunsttidene': ('brunsttid',),
'brunsttider': ('brunsttid',),
'brunsukker': ('brunsukker',),
'brunsukkera': ('brunsukker',),
'brunsukkere': ('brunsukker',),
'brunsukkerene': ('brunsukker',),
'brunsukkeret': ('brunsukker',),
'brunsukkerne': ('brunsukker',),
'brunt': ('brunt',),
'brunvara': ('brunvare',),
'brunvare': ('brunvare',),
'brunvaren': ('brunvare',),
'brunvarene': ('brunvare',),
'brunvarer': ('brunvare',),
'brupilar': ('brupilar',),
'brupilaren': ('brupilar',),
'brupilarene': ('brupilar',),
'brupilarer': ('brupilar',),
'brur': ('brur',),
'brura': ('brur',),
'bruren': ('brur',),
'brurene': ('brur',),
'brurer': ('brur',),
'brur': ('brur',),
'brura': ('brur',),
'brurene': ('brur',),
'brurer': ('brur',),
'brurbukett': ('brurbukett',),
'brurbuketten': ('brurbukett',),
'brurbukettene': ('brurbukett',),
'brurbuketter': ('brurbukett',),
'brurbukett': ('brurbukett',),
'brurbuketten': ('brurbukett',),
'brurbukettene': ('brurbukett',),
'brurbuketter': ('brurbukett',),
'brurdans': ('brurdans',),
'brurdansen': ('brurdans',),
'brurdansene': ('brurdans',),
'brurdanser': ('brurdans',),
'brurdans': ('brurdans',),
'brurdansen': ('brurdans',),
'brurdansene': ('brurdans',),
'brurdanser': ('brurdans',),
'brurebukett': ('brurebukett',),
'brurebuketten': ('brurebukett',),
'brurebukettene': ('brurebukett',),
'brurebuketter': ('brurebukett',),
'brurebukett': ('brurebukett',),
'brurebuketten': ('brurebukett',),
'brurebukettene': ('brurebukett',),
'brurebuketter': ('brurebukett',),
'bruredans': ('bruredans',),
'bruredansen': ('bruredans',),
'bruredansene': ('bruredans',),
'bruredanser': ('bruredans',),
'bruredans': ('bruredans',),
'bruredansen': ('bruredans',),
'bruredansene': ('bruredans',),
'bruredanser': ('bruredans',),
'brureferd': ('brureferd',),
'brureferda': ('brureferd',),
'brureferden': ('brureferd',),
'brureferdene': ('brureferd',),
'brureferder': ('brureferd',),
'brureferd': ('brureferd',),
'brureferda': ('brureferd',),
'brureferden': ('brureferd',),
'brureferdene': ('brureferd',),
'brureferder': ('brureferd',),
'brurefølga': ('brurefølge',),
'brurefølge': ('brurefølge',),
'brurefølgene': ('brurefølge',),
'brurefølger': ('brurefølge',),
'brurefølget': ('brurefølge',),
'brurefølga': ('brurefølge',),
'brurefølge': ('brurefølge',),
'brurefølgene': ('brurefølge',),
'brurefølger': ('brurefølge',),
'brurefølget': ('brurefølge',),
'brurefølgja': ('brurefølgje',),
'brurefølgje': ('brurefølgje',),
'brurefølgjene': ('brurefølgje',),
'brurefølgjer': ('brurefølgje',),
'brurefølgjet': ('brurefølgje',),
'brurefølgja': ('brurefølgje',),
'brurefølgje': ('brurefølgje',),
'brurefølgjene': ('brurefølgje',),
'brurefølgjer': ('brurefølgje',),
'brurefølgjet': ('brurefølgje',),
'brurelys': ('brurelys',),
'brurelysa': ('brurelys',),
'brurelysen': ('brurelys',),
'brurelysene': ('brurelys',),
'brurelyser': ('brurelys',),
'brurelyset': ('brurelys',),
'brurelys': ('brurelys',),
'brurelysa': ('brurelys',),
'brurelysen': ('brurelys',),
'brurelysene': ('brurelys',),
'brurelyser': ('brurelys',),
'brurelyset': ('brurelys',),
'bruremarsj': ('bruremarsj',),
'bruremarsjen': ('bruremarsj',),
'bruremarsjene': ('bruremarsj',),
'bruremarsjer': ('bruremarsj',),
'bruremarsj': ('bruremarsj',),
'bruremarsjen': ('bruremarsj',),
'bruremarsjene': ('bruremarsj',),
'bruremarsjer': ('bruremarsj',),
'brurepar': ('brurepar',),
'brurepara': ('brurepar',),
'brureparene': ('brurepar',),
'brureparet': ('brurepar',),
'brurepar': ('brurepar',),
'brurepara': ('brurepar',),
'brureparene': ('brurepar',),
'brureparet': ('brurepar',),
'brureseng': ('brureseng',),
'bruresenga': ('brureseng',),
'bruresengen': ('brureseng',),
'bruresengene': ('brureseng',),
'bruresenger': ('brureseng',),
'brureseng': ('brureseng',),
'bruresenga': ('brureseng',),
'bruresengen': ('brureseng',),
'bruresengene': ('brureseng',),
'bruresenger': ('brureseng',),
'brureslør': ('brureslør',),
'bruresløra': ('brureslør',),
'brureslørene': ('brureslør',),
'bruresløret': ('brureslør',),
'brureslør': ('brureslør',),
'bruresløra': ('brureslør',),
'brureslørene': ('brureslør',),
'bruresløret': ('brureslør',),
'brureslør': ('brureslør',),
'bruresløra': ('brureslør',),
'brureslørene': ('brureslør',),
'bruresløret': ('brureslør',),
'brureslør': ('brureslør',),
'bruresløra': ('brureslør',),
'brureslørene': ('brureslør',),
'bruresløret': ('brureslør',),
'brurespore': ('brurespore',),
'bruresporen': ('brurespore',),
'bruresporene': ('brurespore',),
'bruresporer': ('brurespore',),
'brurespore': ('brurespore',),
'bruresporen': ('brurespore',),
'bruresporene': ('brurespore',),
'bruresporer': ('brurespore',),
'brurevielse': ('brurevielse',),
'brurevielsen': ('brurevielse',),
'brurevielsene': ('brurevielse',),
'brurevielser': ('brurevielse',),
'brurevielse': ('brurevielse',),
'brurevielsen': ('brurevielse',),
'brurevielsene': ('brurevielse',),
'brurevielser': ('brurevielse',),
'brurevigsel': ('brurevigsel',),
'brurevigselen': ('brurevigsel',),
'brurevigslene': ('brurevigsel',),
'brurevigsler': ('brurevigsel',),
'brurevigsel': ('brurevigsel',),
'brurevigselen': ('brurevigsel',),
'brurevigslene': ('brurevigsel',),
'brurevigsler': ('brurevigsel',),
'brurferd': ('brurferd',),
'brurferda': ('brurferd',),
'brurferden': ('brurferd',),
'brurferdene': ('brurferd',),
'brurferder': ('brurferd',),
'brurferd': ('brurferd',),
'brurferda': ('brurferd',),
'brurferden': ('brurferd',),
'brurferdene': ('brurferd',),
'brurferder': ('brurferd',),
'brurfølga': ('brurfølge',),
'brurfølge': ('brurfølge',),
'brurfølgene': ('brurfølge',),
'brurfølger': ('brurfølge',),
'brurfølget': ('brurfølge',),
'brurfølga': ('brurfølge',),
'brurfølge': ('brurfølge',),
'brurfølgene': ('brurfølge',),
'brurfølger': ('brurfølge',),
'brurfølget': ('brurfølge',),
'brurfølgja': ('brurfølgje',),
'brurfølgje': ('brurfølgje',),
'brurfølgjene': ('brurfølgje',),
'brurfølgjer': ('brurfølgje',),
'brurfølgjet': ('brurfølgje',),
'brurfølgja': ('brurfølgje',),
'brurfølgje': ('brurfølgje',),
'brurfølgjene': ('brurfølgje',),
'brurfølgjer': ('brurfølgje',),
'brurfølgjet': ('brurfølgje',),
'brurlys': ('brurlys',),
'brurlysa': ('brurlys',),
'brurlysen': ('brurlys',),
'brurlysene': ('brurlys',),
'brurlyser': ('brurlys',),
'brurlyset': ('brurlys',),
'brurlys': ('brurlys',),
'brurlysa': ('brurlys',),
'brurlysen': ('brurlys',),
'brurlysene': ('brurlys',),
'brurlyser': ('brurlys',),
'brurlyset': ('brurlys',),
'brurmarsj': ('brurmarsj',),
'brurmarsjen': ('brurmarsj',),
'brurmarsjene': ('brurmarsj',),
'brurmarsjer': ('brurmarsj',),
'brurmarsj': ('brurmarsj',),
'brurmarsjen': ('brurmarsj',),
'brurmarsjene': ('brurmarsj',),
'brurmarsjer': ('brurmarsj',),
'brurpar': ('brurpar',),
'brurpara': ('brurpar',),
'brurparene': ('brurpar',),
'brurparet': ('brurpar',),
'brurpar': ('brurpar',),
'brurpara': ('brurpar',),
'brurparene': ('brurpar',),
'brurparet': ('brurpar',),
'brurseng': ('brurseng',),
'brursenga': ('brurseng',),
'brursengen': ('brurseng',),
'brursengene': ('brurseng',),
'brursenger': ('brurseng',),
'brurseng': ('brurseng',),
'brursenga': ('brurseng',),
'brursengen': ('brurseng',),
'brursengene': ('brurseng',),
'brursenger': ('brurseng',),
'brurslør': ('brurslør',),
'brursløra': ('brurslør',),
'brurslørene': ('brurslør',),
'brursløret': ('brurslør',),
'brurslør': ('brurslør',),
'brursløra': ('brurslør',),
'brurslørene': ('brurslør',),
'brursløret': ('brurslør',),
'brurslør': ('brurslør',),
'brursløra': ('brurslør',),
'brurslørene': ('brurslør',),
'brursløret': ('brurslør',),
'brurslør': ('brurslør',),
'brursløra': ('brurslør',),
'brurslørene': ('brurslør',),
'brursløret': ('brurslør',),
'brurspore': ('brurspore',),
'brursporen': ('brurspore',),
'brursporene': ('brurspore',),
'brursporer': ('brurspore',),
'brurspore': ('brurspore',),
'brursporen': ('brurspore',),
'brursporene': ('brurspore',),
'brursporer': ('brurspore',),
'brurvielse': ('brurvielse',),
'brurvielsen': ('brurvielse',),
'brurvielsene': ('brurvielse',),
'brurvielser': ('brurvielse',),
'brurvielse': ('brurvielse',),
'brurvielsen': ('brurvielse',),
'brurvielsene': ('brurvielse',),
'brurvielser': ('brurvielse',),
'brurvigsel': ('brurvigsel',),
'brurvigselen': ('brurvigsel',),
'brurvigslene': ('brurvigsel',),
'brurvigsler': ('brurvigsel',),
'brurvigsel': ('brurvigsel',),
'brurvigselen': ('brurvigsel',),
'brurvigslene': ('brurvigsel',),
'brurvigsler': ('brurvigsel',),
'brus': ('brus',),
'brusen': ('brus',),
'brusene': ('brus',),
'brus': ('brus',),
'brusa': ('brus',),
'brusene': ('brus',),
'bruset': ('brus',),
'brushane': ('brushane',),
'brushanen': ('brushane',),
'brushanene': ('brushane',),
'brushaner': ('brushane',),
'brushoda': ('brushode',),
'brushode': ('brushode',),
'brushodene': ('brushode',),
'brushoder': ('brushode',),
'brushodet': ('brushode',),
'brusk': ('brusk',),
'brusken': ('brusk',),
'bruskene': ('brusk',),
'brusker': ('brusk',),
'bruskfisk': ('bruskfisk',),
'bruskfisken': ('bruskfisk',),
'bruskfiskene': ('bruskfisk',),
'bruskfisker': ('bruskfisk',),
'bruskplata': ('bruskplate',),
'bruskplate': ('bruskplate',),
'bruskplaten': ('bruskplate',),
'bruskplatene': ('bruskplate',),
'bruskplater': ('bruskplate',),
'bruskskiva': ('bruskskive',),
'bruskskive': ('bruskskive',),
'bruskskiven': ('bruskskive',),
'bruskskivene': ('bruskskive',),
'bruskskiver': ('bruskskive',),
'bruskskjelett': ('bruskskjelett',),
'bruskskjeletta': ('bruskskjelett',),
'bruskskjelettene': ('bruskskjelett',),
'bruskskjeletter': ('bruskskjelett',),
'bruskskjelettet': ('bruskskjelett',),
'bruskvev': ('bruskvev',),
'bruskveva': ('bruskvev',),
'bruskvevene': ('bruskvev',),
'bruskvevet': ('bruskvev',),
'bruspenn': ('bruspenn',),
'bruspenna': ('bruspenn',),
'bruspennene': ('bruspenn',),
'bruspennet': ('bruspenn',),
'bruspulver': ('bruspulver',),
'bruspulvera': ('bruspulver',),
'bruspulvere': ('bruspulver',),
'bruspulveret': ('bruspulver',),
'bruspulverne': ('bruspulver',),
'brusselknipling': ('brusselknipling',),
'brusselkniplingen': ('brusselknipling',),
'brusselkniplingene': ('brusselknipling',),
'brusselkniplinger': ('brusselknipling',),
'brusselknipling': ('brusselknipling',),
'brusselkniplingen': ('brusselknipling',),
'brusselkniplingene': ('brusselknipling',),
'brusselkniplinger': ('brusselknipling',),
'brusselteppa': ('brusselteppe',),
'brusselteppe': ('brusselteppe',),
'brusselteppene': ('brusselteppe',),
'brusseltepper': ('brusselteppe',),
'brusselteppet': ('brusselteppe',),
'brusselteppa': ('brusselteppe',),
'brusselteppe': ('brusselteppe',),
'brusselteppene': ('brusselteppe',),
'brusseltepper': ('brusselteppe',),
'brusselteppet': ('brusselteppe',),
'brustein': ('brustein',),
'brusteinen': ('brustein',),
'brusteinene': ('brustein',),
'brusteiner': ('brustein',),
'brutalitet': ('brutalitet',),
'brutaliteten': ('brutalitet',),
'brutalitetene': ('brutalitet',),
'brutaliteter': ('brutalitet',),
'brutto': ('brutto',),
'bruttoen': ('brutto',),
'bruttoene': ('brutto',),
'bruttoer': ('brutto',),
'bruttoavling': ('bruttoavling',),
'bruttoavlinga': ('bruttoavling',),
'bruttoavlingen': ('bruttoavling',),
'bruttoavlingene': ('bruttoavling',),
'bruttoavlinger': ('bruttoavling',),
'bruttobeløp': ('bruttobeløp',),
'bruttobeløpa': ('bruttobeløp',),
'bruttobeløpene': ('bruttobeløp',),
'bruttobeløpet': ('bruttobeløp',),
'bruttobudsjett': ('bruttobudsjett',),
'bruttobudsjetta': ('bruttobudsjett',),
'bruttobudsjettene': ('bruttobudsjett',),
'bruttobudsjetter': ('bruttobudsjett',),
'bruttobudsjettet': ('bruttobudsjett',),
'bruttoformue': ('bruttoformue',),
'bruttoformuen': ('bruttoformue',),
'bruttoformuene': ('bruttoformue',),
'bruttoformuer': ('bruttoformue',),
'bruttofortjenesta': ('bruttofortjeneste',),
'bruttofortjeneste': ('bruttofortjeneste',),
'bruttofortjenesten': ('bruttofortjeneste',),
'bruttofortjenestene': ('bruttofortjeneste',),
'bruttofortjenester': ('bruttofortjeneste',),
'bruttoinntekt': ('bruttoinntekt',),
'bruttoinntekta': ('bruttoinntekt',),
'bruttoinntekten': ('bruttoinntekt',),
'bruttoinntektene': ('bruttoinntekt',),
'bruttoinntekter': ('bruttoinntekt',),
'bruttonasjonalprodukt': ('bruttonasjonalprodukt',),
'bruttonasjonalprodukta': ('bruttonasjonalprodukt',),
'bruttonasjonalproduktene': ('bruttonasjonalprodukt',),
'bruttonasjonalprodukter': ('bruttonasjonalprodukt',),
'bruttonasjonalproduktet': ('bruttonasjonalprodukt',),
'bruttoregistertonn': ('bruttoregistertonn',),
'bruttoregistertonna': ('bruttoregistertonn',),
'bruttoregistertonnene': ('bruttoregistertonn',),
'bruttoregistertonnet': ('bruttoregistertonn',),
'bruttotonnasje': ('bruttotonnasje',),
'bruttotonnasjen': ('bruttotonnasje',),
'bruttotonnasjene': ('bruttotonnasje',),
'bruttotonnasjer': ('bruttotonnasje',),
'bruttovekt': ('bruttovekt',),
'bruttovekta': ('bruttovekt',),
'bruttovekten': ('bruttovekt',),
'bruttovektene': ('bruttovekt',),
'bruttovekter': ('bruttovekt',),
'bry': ('bry',),
'brya': ('bry',),
'bryene': ('bry',),
'bryet': ('bry',),
'bryderi': ('bryderi',),
'bryderia': ('bryderi',),
'bryderiene': ('bryderi',),
'bryderier': ('bryderi',),
'bryderiet': ('bryderi',),
'brygg': ('brygg',),
'brygga': ('brygg',),
'bryggene': ('brygg',),
'brygget': ('brygg',),
'brygga': ('brygge',),
'brygge': ('brygge',),
'bryggen': ('brygge',),
'bryggene': ('brygge',),
'brygger': ('brygge',),
'bryggearbeider': ('bryggearbeider',),
'bryggearbeidere': ('bryggearbeider',),
'bryggearbeideren': ('bryggearbeider',),
'bryggearbeiderer': ('bryggearbeider',),
'bryggearbeiderne': ('bryggearbeider',),
'bryggeavgift': ('bryggeavgift',),
'bryggeavgifta': ('bryggeavgift',),
'bryggeavgiften': ('bryggeavgift',),
'bryggeavgiftene': ('bryggeavgift',),
'bryggeavgifter': ('bryggeavgift',),
'bryggedans': ('bryggedans',),
'bryggedansen': ('bryggedans',),
'bryggedansene': ('bryggedans',),
'bryggedanser': ('bryggedans',),
'bryggekjel': ('bryggekjel',),
'bryggekjelen': ('bryggekjel',),
'bryggekjelene': ('bryggekjel',),
'bryggekjeler': ('bryggekjel',),
'bryggekjele': ('bryggekjele',),
'bryggekjelen': ('bryggekjele',),
'bryggekjelene': ('bryggekjele',),
'bryggekjeler': ('bryggekjele',),
'bryggepanna': ('bryggepanne',),
'bryggepanne': ('bryggepanne',),
'bryggepannen': ('bryggepanne',),
'bryggepannene': ('bryggepanne',),
'bryggepanner': ('bryggepanne',),
'brygger': ('brygger',),
'bryggere': ('brygger',),
'bryggeren': ('brygger',),
'bryggerer': ('brygger',),
'bryggerne': ('brygger',),
'bryggerhest': ('bryggerhest',),
'bryggerhesten': ('bryggerhest',),
'bryggerhestene': ('bryggerhest',),
'bryggerhester': ('bryggerhest',),
'bryggerhus': ('bryggerhus',),
'bryggerhusa': ('bryggerhus',),
'bryggerhusene': ('bryggerhus',),
'bryggerhuset': ('bryggerhus',),
'bryggeri': ('bryggeri',),
'bryggeria': ('bryggeri',),
'bryggeriene': ('bryggeri',),
'bryggerier': ('bryggeri',),
'bryggeriet': ('bryggeri',),
'bryggerihest': ('bryggerihest',),
'bryggerihesten': ('bryggerihest',),
'bryggerihestene': ('bryggerihest',),
'bryggerihester': ('bryggerihest',),
'bryggesjauer': ('bryggesjauer',),
'bryggesjauere': ('bryggesjauer',),
'bryggesjaueren': ('bryggesjauer',),
'bryggesjauerer': ('bryggesjauer',),
'bryggesjauerne': ('bryggesjauer',),
'bryllup': ('bryllup',),
'bryllupa': ('bryllup',),
'bryllupene': ('bryllup',),
'brylluper': ('bryllup',),
'bryllupet': ('bryllup',),
'bryllupsdag': ('bryllupsdag',),
'bryllupsdagen': ('bryllupsdag',),
'bryllupsdagene': ('bryllupsdag',),
'bryllupsdager': ('bryllupsdag',),
'bryllupsgava': ('bryllupsgave',),
'bryllupsgave': ('bryllupsgave',),
'bryllupsgaven': ('bryllupsgave',),
'bryllupsgavene': ('bryllupsgave',),
'bryllupsgaver': ('bryllupsgave',),
'bryllupsklokka': ('bryllupsklokke',),
'bryllupsklokke': ('bryllupsklokke',),
'bryllupsklokken': ('bryllupsklokke',),
'bryllupsklokkene': ('bryllupsklokke',),
'bryllupsklokker': ('bryllupsklokke',),
'bryllupsmarsj': ('bryllupsmarsj',),
'bryllupsmarsjen': ('bryllupsmarsj',),
'bryllupsmarsjene': ('bryllupsmarsj',),
'bryllupsmarsjer': ('bryllupsmarsj',),
'bryllupsnatt': ('bryllupsnatt',),
'bryllupsnatta': ('bryllupsnatt',),
'bryllupsnatten': ('bryllupsnatt',),
'bryllupsnettene': ('bryllupsnatt',),
'bryllupsnetter': ('bryllupsnatt',),
'bryllupsreisa': ('bryllupsreise',),
'bryllupsreise': ('bryllupsreise',),
'bryllupsreisen': ('bryllupsreise',),
'bryllupsreisene': ('bryllupsreise',),
'bryllupsreiser': ('bryllupsreise',),
'bryn': ('bryn',),
'bryna': ('bryn',),
'brynene': ('bryn',),
'brynet': ('bryn',),
'brynde': ('brynde',),
'brynden': ('brynde',),
'bryndene': ('brynde',),
'brynder': ('brynde',),
'bryna': ('bryne',),
'bryne': ('bryne',),
'brynene': ('bryne',),
'bryner': ('bryne',),
'brynet': ('bryne',),
'brynja': ('brynje',),
'brynje': ('brynje',),
'brynjen': ('brynje',),
'brynjene': ('brynje',),
'brynjer': ('brynje',),
'bryolog': ('bryolog',),
'bryologen': ('bryolog',),
'bryologene': ('bryolog',),
'bryologer': ('bryolog',),
'bryologi': ('bryologi',),
'bryologien': ('bryologi',),
'bryologiene': ('bryologi',),
'bryologier': ('bryologi',),
'brysselerknipling': ('brysselerknipling',),
'brysselerkniplingen': ('brysselerknipling',),
'brysselerkniplingene': ('brysselerknipling',),
'brysselerkniplinger': ('brysselerknipling',),
'brysselerknipling': ('brysselerknipling',),
'brysselerkniplingen': ('brysselerknipling',),
'brysselerkniplingene': ('brysselerknipling',),
'brysselerkniplinger': ('brysselerknipling',),
'brysselerteppa': ('brysselerteppe',),
'brysselerteppe': ('brysselerteppe',),
'brysselerteppene': ('brysselerteppe',),
'brysselertepper': ('brysselerteppe',),
'brysselerteppet': ('brysselerteppe',),
'brysselerteppa': ('brysselerteppe',),
'brysselerteppe': ('brysselerteppe',),
'brysselerteppene': ('brysselerteppe',),
'brysselertepper': ('brysselerteppe',),
'brysselerteppet': ('brysselerteppe',),
'bryst': ('bryst',),
'brysta': ('bryst',),
'brystene': ('bryst',),
'bryster': ('bryst',),
'brystet': ('bryst',),
'brystbarn': ('brystbarn',),
'brystbarna': ('brystbarn',),
'brystbarnene': ('brystbarn',),
'brystbarnet': ('brystbarn',),
'brystbilda': ('brystbilde',),
'brystbilde': ('brystbilde',),
'brystbildene': ('brystbilde',),
'brystbilder': ('brystbilde',),
'brystbildet': ('brystbilde',),
'brysthinna': ('brysthinne',),
'brysthinne': ('brysthinne',),
'brysthinnen': ('brysthinne',),
'brysthinnene': ('brysthinne',),
'brysthinner': ('brysthinne',),
'brysthinnebetennelse': ('brysthinnebetennelse',),
'brysthinnebetennelsen': ('brysthinnebetennelse',),
'brysthinnebetennelsene': ('brysthinnebetennelse',),
'brysthinnebetennelser': ('brysthinnebetennelse',),
'brystholder': ('brystholder',),
'brystholdere': ('brystholder',),
'brystholderen': ('brystholder',),
'brystholderer': ('brystholder',),
'brystholderne': ('brystholder',),
'brysthola': ('brysthole',),
'brysthole': ('brysthole',),
'brystholen': ('brysthole',),
'brystholene': ('brysthole',),
'brystholer': ('brysthole',),
'brysthula': ('brysthule',),
'brysthule': ('brysthule',),
'brysthulen': ('brysthule',),
'brysthulene': ('brysthule',),
'brysthuler': ('brysthule',),
'brysthøgd': ('brysthøgd',),
'brysthøgda': ('brysthøgd',),
'brysthøgdene': ('brysthøgd',),
'brysthøgder': ('brysthøgd',),
'brysthøyde': ('brysthøyde',),
'brysthøyden': ('brysthøyde',),
'brysthøydene': ('brysthøyde',),
'brysthøyder': ('brysthøyde',),
'brystkassa': ('brystkasse',),
'brystkasse': ('brystkasse',),
'brystkassen': ('brystkasse',),
'brystkassene': ('brystkasse',),
'brystkasser': ('brystkasse',),
'brystkreft': ('brystkreft',),
'brystkreften': ('brystkreft',),
'brystkreftene': ('brystkreft',),
'brystkrefter': ('brystkreft',),
'brystlomma': ('brystlomme',),
'brystlomme': ('brystlomme',),
'brystlommen': ('brystlomme',),
'brystlommene': ('brystlomme',),
'brystlommer': ('brystlomme',),
'brystmål': ('brystmål',),
'brystmåla': ('brystmål',),
'brystmålene': ('brystmål',),
'brystmålet': ('brystmål',),
'brystning': ('brystning',),
'brystninga': ('brystning',),
'brystningen': ('brystning',),
'brystningene': ('brystning',),
'brystninger': ('brystning',),
'brystnål': ('brystnål',),
'brystnåla': ('brystnål',),
'brystnålen': ('brystnål',),
'brystnålene': ('brystnål',),
'brystnåler': ('brystnål',),
'brystsvømming': ('brystsvømming',),
'brystsvømminga': ('brystsvømming',),
'brystsvømmingen': ('brystsvømming',),
'brystsvømmingene': ('brystsvømming',),
'brystsvømminger': ('brystsvømming',),
'brysttone': ('brysttone',),
'brysttonen': ('brysttone',),
'brysttonene': ('brysttone',),
'brysttoner': ('brysttone',),
'brystvern': ('brystvern',),
'brystverna': ('brystvern',),
'brystvernene': ('brystvern',),
'brystvernet': ('brystvern',),
'brystvirvel': ('brystvirvel',),
'brystvirvelen': ('brystvirvel',),
'brystvirvlene': ('brystvirvel',),
'brystvirvler': ('brystvirvel',),
'brystvorta': ('brystvorte',),
'brystvorte': ('brystvorte',),
'brystvorten': ('brystvorte',),
'brystvortene': ('brystvorte',),
'brystvorter': ('brystvorte',),
'brytbønna': ('brytbønne',),
'brytbønne': ('brytbønne',),
'brytbønnen': ('brytbønne',),
'brytbønnene': ('brytbønne',),
'brytbønner': ('brytbønne',),
'brytekamp': ('brytekamp',),
'brytekampen': ('brytekamp',),
'brytekampene': ('brytekamp',),
'brytekamper': ('brytekamp',),
'bryter': ('bryter',),
'brytere': ('bryter',),
'bryteren': ('bryter',),
'bryterer': ('bryter',),
'bryterne': ('bryter',),
'bryterpanel': ('bryterpanel',),
'bryterpanela': ('bryterpanel',),
'bryterpanelene': ('bryterpanel',),
'bryterpaneler': ('bryterpanel',),
'bryterpanelet': ('bryterpanel',),
'bryterskap': ('bryterskap',),
'bryterskapa': ('bryterskap',),
'bryterskapene': ('bryterskap',),
'bryterskapet': ('bryterskap',),
'brytertak': ('brytertak',),
'brytertaka': ('brytertak',),
'brytertakene': ('brytertak',),
'brytertaket': ('brytertak',),
'bryting': ('bryting',),
'brytinga': ('bryting',),
'brytingen': ('bryting',),
'brytingene': ('bryting',),
'brytinger': ('bryting',),
'brytingstid': ('brytingstid',),
'brytingstida': ('brytingstid',),
'brytingstiden': ('brytingstid',),
'brytingstidene': ('brytingstid',),
'brytingstider': ('brytingstid',),
'brytingsår': ('brytingsår',),
'brytingsåra': ('brytingsår',),
'brytingsårene': ('brytingsår',),
'brytingsåret': ('brytingsår',),
'brytning': ('brytning',),
'brytninga': ('brytning',),
'brytningen': ('brytning',),
'brytningene': ('brytning',),
'brytninger': ('brytning',),
'brytningstid': ('brytningstid',),
'brytningstida': ('brytningstid',),
'brytningstiden': ('brytningstid',),
'brytningstidene': ('brytningstid',),
'brytningstider': ('brytningstid',),
'brytningsår': ('brytningsår',),
'brytningsåra': ('brytningsår',),
'brytningsårene': ('brytningsår',),
'brytningsåret': ('brytningsår',),
'brådjup': ('brådjup',),
'brådjupa': ('brådjup',),
'brådjupene': ('brådjup',),
'brådjupet': ('brådjup',),
'brådyp': ('brådyp',),
'brådypa': ('brådyp',),
'brådypene': ('brådyp',),
'brådypet': ('brådyp',),
'bråhast': ('bråhast',),
'bråhasten': ('bråhast',),
'bråhastene': ('bråhast',),
'bråhaster': ('bråhast',),
'bråk': ('bråk',),
'bråka': ('bråk',),
'bråkene': ('bråk',),
'bråket': ('bråk',),
'bråk': ('bråk',),
'bråka': ('bråk',),
'bråken': ('bråk',),
'brækene': ('bråk',),
'bræker': ('bråk',),
'bråkast': ('bråkast',),
'bråkasta': ('bråkast',),
'bråkastene': ('bråkast',),
'bråkastet': ('bråkast',),
'bråkebøtta': ('bråkebøtte',),
'bråkebøtte': ('bråkebøtte',),
'bråkebøtten': ('bråkebøtte',),
'bråkebøttene': ('bråkebøtte',),
'bråkebøtter': ('bråkebøtte',),
'bråkmaker': ('bråkmaker',),
'bråkmakere': ('bråkmaker',),
'bråkmakeren': ('bråkmaker',),
'bråkmakerer': ('bråkmaker',),
'bråkmakerne': ('bråkmaker',),
'bråkulda': ('bråkulde',),
'bråkulde': ('bråkulde',),
'bråkulden': ('bråkulde',),
'bråkuldene': ('bråkulde',),
'bråkulder': ('bråkulde',),
'bråsinna': ('bråsinne',),
'bråsinne': ('bråsinne',),
'bråsinnene': ('bråsinne',),
'bråsinner': ('bråsinne',),
'bråsinnet': ('bråsinne',),
'bråte': ('bråte',),
'bråten': ('bråte',),
'bråtene': ('bråte',),
'bråter': ('bråte',),
'bråtebrann': ('bråtebrann',),
'bråtebrannen': ('bråtebrann',),
'bråtebrannene': ('bråtebrann',),
'bråtebranner': ('bråtebrann',),
'bråtebrenning': ('bråtebrenning',),
'bråtebrenninga': ('bråtebrenning',),
'bråtebrenningen': ('bråtebrenning',),
'bråtebrenningene': ('bråtebrenning',),
'bråtebrenninger': ('bråtebrenning',),
'bråterøyk': ('bråterøyk',),
'bråterøyken': ('bråterøyk',),
'bråterøykene': ('bråterøyk',),
'bråterøyker': ('bråterøyk',),
'brød': ('brød',),
'brøda': ('brød',),
'brødene': ('brød',),
'brødet': ('brød',),
'brødbaking': ('brødbaking',),
'brødbakinga': ('brødbaking',),
'brødbakingen': ('brødbaking',),
'brødbakingene': ('brødbaking',),
'brødbakinger': ('brødbaking',),
'brødbakning': ('brødbakning',),
'brødbakninga': ('brødbakning',),
'brødbakningen': ('brødbakning',),
'brødbakningene': ('brødbakning',),
'brødbakninger': ('brødbakning',),
'brødbille': ('brødbille',),
'brødbillen': ('brødbille',),
'brødbillene': ('brødbille',),
'brødbiller': ('brødbille',),
'brødbit': ('brødbit',),
'brødbiten': ('brødbit',),
'brødbitene': ('brødbit',),
'brødbiter': ('brødbit',),
'brødblings': ('brødblings',),
'brødblingsen': ('brødblings',),
'brødblingsene': ('brødblings',),
'brødblingser': ('brødblings',),
'brøddeig': ('brøddeig',),
'brøddeigen': ('brøddeig',),
'brøddeigene': ('brøddeig',),
'brøddeiger': ('brøddeig',),
'brøde': ('brøde',),
'brøden': ('brøde',),
'brødene': ('brøde',),
'brøder': ('brøde',),
'brødfrukt': ('brødfrukt',),
'brødfrukta': ('brødfrukt',),
'brødfrukten': ('brødfrukt',),
'brødfruktene': ('brødfrukt',),
'brødfrukter': ('brødfrukt',),
'brødfrukttre': ('brødfrukttre',),
'brødfrukttrea': ('brødfrukttre',),
'brødfrukttreet': ('brødfrukttre',),
'brødfrukttrær': ('brødfrukttre',),
'brødfrukttrærne': ('brødfrukttre',),
'brødnid': ('brødnid',),
'brødnida': ('brødnid',),
'brødnidene': ('brødnid',),
'brødnidet': ('brødnid',),
'brødremenighet': ('brødremenighet',),
'brødremenigheta': ('brødremenighet',),
'brødremenigheten': ('brødremenighet',),
'brødremenighetene': ('brødremenighet',),
'brødremenigheter': ('brødremenighet',),
'brødrister': ('brødrister',),
'brødristere': ('brødrister',),
'brødristeren': ('brødrister',),
'brødristerer': ('brødrister',),
'brødristerne': ('brødrister',),
'brødskrift': ('brødskrift',),
'brødskrifta': ('brødskrift',),
'brødskriften': ('brødskrift',),
'brødskriftene': ('brødskrift',),
'brødskrifter': ('brødskrift',),
'brøk': ('brøk',),
'brøken': ('brøk',),
'brøkene': ('brøk',),
'brøker': ('brøk',),
'brøkdel': ('brøkdel',),
'brøkdelen': ('brøkdel',),
'brøkdelene': ('brøkdel',),
'brøkdeler': ('brøkdel',),
'brøkregning': ('brøkregning',),
'brøkregninga': ('brøkregning',),
'brøkregningen': ('brøkregning',),
'brøkregningene': ('brøkregning',),
'brøkregninger': ('brøkregning',),
'brøkrekning': ('brøkrekning',),
'brøkrekninga': ('brøkrekning',),
'brøkrekningen': ('brøkrekning',),
'brøkrekningene': ('brøkrekning',),
'brøkrekninger': ('brøkrekning',),
'brøkstrek': ('brøkstrek',),
'brøkstreken': ('brøkstrek',),
'brøkstrekene': ('brøkstrek',),
'brøkstreker': ('brøkstrek',),
'brøl': ('brøl',),
'brøla': ('brøl',),
'brølene': ('brøl',),
'brølet': ('brøl',),
'brølapa': ('brølape',),
'brølape': ('brølape',),
'brølapen': ('brølape',),
'brølapene': ('brølape',),
'brølaper': ('brølape',),
'brøleapa': ('brøleape',),
'brøleape': ('brøleape',),
'brøleapen': ('brøleape',),
'brøleapene': ('brøleape',),
'brøleaper': ('brøleape',),
'brøler': ('brøler',),
'brølere': ('brøler',),
'brøleren': ('brøler',),
'brølerer': ('brøler',),
'brølerne': ('brøler',),
'brønn': ('brønn',),
'brønnen': ('brønn',),
'brønnene': ('brønn',),
'brønner': ('brønn',),
'brønnbor': ('brønnbor',),
'brønnbora': ('brønnbor',),
'brønnboren': ('brønnbor',),
'brønnborene': ('brønnbor',),
'brønnboret': ('brønnbor',),
'brønnboring': ('brønnboring',),
'brønnboringa': ('brønnboring',),
'brønnboringen': ('brønnboring',),
'brønnboringene': ('brønnboring',),
'brønnboringer': ('brønnboring',),
'brønnbåt': ('brønnbåt',),
'brønnbåten': ('brønnbåt',),
'brønnbåtene': ('brønnbåt',),
'brønnbåter': ('brønnbåt',),
'brønnhoda': ('brønnhode',),
'brønnhode': ('brønnhode',),
'brønnhodene': ('brønnhode',),
'brønnhoder': ('brønnhode',),
'brønnhodet': ('brønnhode',),
'brønnhus': ('brønnhus',),
'brønnhusa': ('brønnhus',),
'brønnhusene': ('brønnhus',),
'brønnhuset': ('brønnhus',),
'brønnkapasitet': ('brønnkapasitet',),
'brønnkapasiteten': ('brønnkapasitet',),
'brønnkapasitetene': ('brønnkapasitet',),
'brønnkapasiteter': ('brønnkapasitet',),
'brønnpisser': ('brønnpisser',),
'brønnpissere': ('brønnpisser',),
'brønnpisseren': ('brønnpisser',),
'brønnpisserer': ('brønnpisser',),
'brønnpisserne': ('brønnpisser',),
'brøst': ('brøst',),
'brøsta': ('brøst',),
'brøsten': ('brøst',),
'brøstene': ('brøst',),
'brøstet': ('brøst',),
'brøyt': ('brøyt',),
'brøyten': ('brøyt',),
'brøytene': ('brøyt',),
'brøyter': ('brøyt',),
'brøytebil': ('brøytebil',),
'brøytebilen': ('brøytebil',),
'brøytebilene': ('brøytebil',),
'brøytebiler': ('brøytebil',),
'brøytekant': ('brøytekant',),
'brøytekanten': ('brøytekant',),
'brøytekantene': ('brøytekant',),
'brøytekanter': ('brøytekant',),
'bu': ('bu',),
'bua': ('bu',),
'buene': ('bu',),
'buet': ('bu',),
'bu': ('bu',),
'bua': ('bu',),
'buen': ('bu',),
'buene': ('bu',),
'buer': ('bu',),
'bu': ('bu',),
'bua': ('bu',),
'buen': ('bu',),
'buene': ('bu',),
'buer': ('bu',),
'bubestyrer': ('bubestyrer',),
'bubestyrere': ('bubestyrer',),
'bubestyreren': ('bubestyrer',),
'bubestyrerer': ('bubestyrer',),
'bubestyrerne': ('bubestyrer',),
'bud': ('bud',),
'buda': ('bud',),
'budene': ('bud',),
'budet': ('bud',),
'budbringer': ('budbringer',),
'budbringere': ('budbringer',),
'budbringeren': ('budbringer',),
'budbringerer': ('budbringer',),
'budbringerne': ('budbringer',),
'budbærer': ('budbærer',),
'budbærere': ('budbærer',),
'budbæreren': ('budbærer',),
'budbærerer': ('budbærer',),
'budbærerne': ('budbærer',),
'buddha': ('buddha',),
'buddhaen': ('buddha',),
'buddhaene': ('buddha',),
'buddhaer': ('buddha',),
'buddhafigur': ('buddhafigur',),
'buddhafiguren': ('buddhafigur',),
'buddhafigurene': ('buddhafigur',),
'buddhafigurer': ('buddhafigur',),
'buddhatempel': ('buddhatempel',),
'buddhatempelet': ('buddhatempel',),
'buddhatempla': ('buddhatempel',),
'buddhatemplene': ('buddhatempel',),
'buddhatempler': ('buddhatempel',),
'buddhatemplet': ('buddhatempel',),
'buddhisme': ('buddhisme',),
'buddhismen': ('buddhisme',),
'buddhismene': ('buddhisme',),
'buddhismer': ('buddhisme',),
'buddhist': ('buddhist',),
'buddhisten': ('buddhist',),
'buddhistene': ('buddhist',),
'buddhister': ('buddhist',),
'buddhistmunk': ('buddhistmunk',),
'buddhistmunken': ('buddhistmunk',),
'buddhistmunkene': ('buddhistmunk',),
'buddhistmunker': ('buddhistmunk',),
'budeia': ('budeie',),
'budeie': ('budeie',),
'budeien': ('budeie',),
'budeiene': ('budeie',),
'budeier': ('budeie',),
'budoar': ('budoar',),
'budoara': ('budoar',),
'budoarene': ('budoar',),
'budoarer': ('budoar',),
'budoaret': ('budoar',),
'budrått': ('budrått',),
'budråtten': ('budrått',),
'budråttene': ('budrått',),
'budråtter': ('budrått',),
'budsjett': ('budsjett',),
'budsjetta': ('budsjett',),
'budsjettene': ('budsjett',),
'budsjetter': ('budsjett',),
'budsjettet': ('budsjett',),
'budsjett-termin': ('budsjett-termin',),
'budsjett-terminen': ('budsjett-termin',),
'budsjett-terminene': ('budsjett-termin',),
'budsjett-terminer': ('budsjett-termin',),
'budsjettbehandling': ('budsjettbehandling',),
'budsjettbehandlinga': ('budsjettbehandling',),
'budsjettbehandlingen': ('budsjettbehandling',),
'budsjettbehandlingene': ('budsjettbehandling',),
'budsjettbehandlinger': ('budsjettbehandling',),
'budsjettermin': ('budsjettermin',),
'budsjetterminen': ('budsjettermin',),
'budsjetterminene': ('budsjettermin',),
'budsjetterminer': ('budsjettermin',),
'budsjettforslag': ('budsjettforslag',),
'budsjettforslaga': ('budsjettforslag',),
'budsjettforslagene': ('budsjettforslag',),
'budsjettforslaget': ('budsjettforslag',),
'budskap': ('budskap',),
'budskapa': ('budskap',),
'budskapene': ('budskap',),
'budskaper': ('budskap',),
'budskapet': ('budskap',),
'budskapsdag': ('budskapsdag',),
'budskapsdagen': ('budskapsdag',),
'budskapsdagene': ('budskapsdag',),
'budskapsdager': ('budskapsdag',),
'budstikka': ('budstikke',),
'budstikke': ('budstikke',),
'budstikken': ('budstikke',),
'budstikkene': ('budstikke',),
'budstikker': ('budstikke',),
'bue': ('bue',),
'buen': ('bue',),
'buene': ('bue',),
'buer': ('bue',),
'buebro': ('buebro',),
'buebroa': ('buebro',),
'buebroen': ('buebro',),
'buebroene': ('buebro',),
'buebroer': ('buebro',),
'buebru': ('buebru',),
'buebrua': ('buebru',),
'buebruen': ('buebru',),
'buebruene': ('buebru',),
'buebruer': ('buebru',),
'buegang': ('buegang',),
'buegangen': ('buegang',),
'buegangene': ('buegang',),
'bueganger': ('buegang',),
'buegrad': ('buegrad',),
'buegraden': ('buegrad',),
'buegradene': ('buegrad',),
'buegrader': ('buegrad',),
'buekorps': ('buekorps',),
'buekorpsa': ('buekorps',),
'buekorpsene': ('buekorps',),
'buekorpset': ('buekorps',),
'bueminutt': ('bueminutt',),
'bueminutta': ('bueminutt',),
'bueminuttene': ('bueminutt',),
'bueminutter': ('bueminutt',),
'bueminuttet': ('bueminutt',),
'bueparentes': ('bueparentes',),
'bueparentesen': ('bueparentes',),
'bueparentesene': ('bueparentes',),
'bueparenteser': ('bueparentes',),
'buesag': ('buesag',),
'buesaga': ('buesag',),
'buesagen': ('buesag',),
'buesagene': ('buesag',),
'buesager': ('buesag',),
'buesekund': ('buesekund',),
'buesekunda': ('buesekund',),
'buesekundene': ('buesekund',),
'buesekunder': ('buesekund',),
'buesekundet': ('buesekund',),
'buestreng': ('buestreng',),
'buestrengen': ('buestreng',),
'buestrengene': ('buestreng',),
'buestrenger': ('buestreng',),
'buetak': ('buetak',),
'buetaka': ('buetak',),
'buetakene': ('buetak',),
'buetaket': ('buetak',),
'buevindu': ('buevindu',),
'buevindua': ('buevindu',),
'buevinduene': ('buevindu',),
'buevinduer': ('buevindu',),
'buevinduet': ('buevindu',),
'bufar': ('bufar',),
'bufaren': ('bufar',),
'bufarene': ('bufar',),
'bufarer': ('bufar',),
'bufardag': ('bufardag',),
'bufardagen': ('bufardag',),
'bufardagene': ('bufardag',),
'bufardager': ('bufardag',),
'bufe': ('bufe',),
'bufea': ('bufe',),
'bufeene': ('bufe',),
'bufeet': ('bufe',),
'bufellesskap': ('bufellesskap',),
'bufellesskapa': ('bufellesskap',),
'bufellesskapene': ('bufellesskap',),
'bufellesskaper': ('bufellesskap',),
'bufellesskapet': ('bufellesskap',),
'buffeen': ('buffé',),
'buffeene': ('buffé',),
'buffeer': ('buffé',),
'buffé': ('buffé',),
'bufféen': ('buffé',),
'bufféene': ('buffé',),
'bufféer': ('buffé',),
'buffer': ('buffer',),
'buffere': ('buffer',),
'bufferen': ('buffer',),
'bufferer': ('buffer',),
'bufferne': ('buffer',),
'buffersona': ('buffersone',),
'buffersone': ('buffersone',),
'buffersonen': ('buffersone',),
'buffersonene': ('buffersone',),
'buffersoner': ('buffersone',),
'bufferstat': ('bufferstat',),
'bufferstaten': ('bufferstat',),
'bufferstatene': ('bufferstat',),
'bufferstater': ('bufferstat',),
'buffo': ('buffo',),
'buffoen': ('buffo',),
'buffoene': ('buffo',),
'buffoer': ('buffo',),
'buffoopera': ('buffoopera',),
'buffooperaen': ('buffoopera',),
'buffooperaene': ('buffoopera',),
'buffooperaer': ('buffoopera',),
'buflata': ('buflate',),
'buflate': ('buflate',),
'buflaten': ('buflate',),
'buflatene': ('buflate',),
'buflater': ('buflate',),
'buform': ('buform',),
'buforma': ('buform',),
'buformen': ('buform',),
'buformene': ('buform',),
'buformer': ('buform',),
'buhund': ('buhund',),
'buhunden': ('buhund',),
'buhundene': ('buhund',),
'buhunder': ('buhund',),
'buk': ('buk',),
'buken': ('buk',),
'bukene': ('buk',),
'buker': ('buk',),
'bukeen': ('buké',),
'bukeene': ('buké',),
'bukeer': ('buké',),
'buké': ('buké',),
'bukéen': ('buké',),
'bukéene': ('buké',),
'bukéer': ('buké',),
'bukett': ('bukett',),
'buketten': ('bukett',),
'bukettene': ('bukett',),
'buketter': ('bukett',),
'bukgjord': ('bukgjord',),
'bukgjorda': ('bukgjord',),
'bukgjorden': ('bukgjord',),
'bukgjordene': ('bukgjord',),
'bukgjorder': ('bukgjord',),
'bukhinna': ('bukhinne',),
'bukhinne': ('bukhinne',),
'bukhinnen': ('bukhinne',),
'bukhinnene': ('bukhinne',),
'bukhinner': ('bukhinne',),
'bukhinnebetennelse': ('bukhinnebetennelse',),
'bukhinnebetennelsen': ('bukhinnebetennelse',),
'bukhinnebetennelsene': ('bukhinnebetennelse',),
'bukhinnebetennelser': ('bukhinnebetennelse',),
'bukhola': ('bukhole',),
'bukhole': ('bukhole',),
'bukholen': ('bukhole',),
'bukholene': ('bukhole',),
'bukholer': ('bukhole',),
'bukhula': ('bukhule',),
'bukhule': ('bukhule',),
'bukhulen': ('bukhule',),
'bukhulene': ('bukhule',),
'bukhuler': ('bukhule',),
'bukk': ('bukk',),
'bukken': ('bukk',),
'bukkene': ('bukk',),
'bukker': ('bukk',),
'bukk': ('bukk',),
'bukka': ('bukk',),
'bukkene': ('bukk',),
'bukket': ('bukk',),
'bukkebein': ('bukkebein',),
'bukkebeina': ('bukkebein',),
'bukkebeinene': ('bukkebein',),
'bukkebeinet': ('bukkebein',),
'bukkeben': ('bukkeben',),
'bukkebena': ('bukkeben',),
'bukkebenene': ('bukkeben',),
'bukkebenet': ('bukkeben',),
'bukkeblad': ('bukkeblad',),
'bukkeblada': ('bukkeblad',),
'bukkebladene': ('bukkeblad',),
'bukkeblader': ('bukkeblad',),
'bukkebladet': ('bukkeblad',),
'bukkehorn': ('bukkehorn',),
'bukkehorna': ('bukkehorn',),
'bukkehornene': ('bukkehorn',),
'bukkehornet': ('bukkehorn',),
'bukkel': ('bukkel',),
'bukkelen': ('bukkel',),
'buklene': ('bukkel',),
'bukler': ('bukkel',),
'bukkeskjegg': ('bukkeskjegg',),
'bukkeskjegga': ('bukkeskjegg',),
'bukkeskjeggene': ('bukkeskjegg',),
'bukkeskjegget': ('bukkeskjegg',),
'buklist': ('buklist',),
'buklista': ('buklist',),
'buklisten': ('buklist',),
'buklistene': ('buklist',),
'buklister': ('buklist',),
'bukollektiv': ('bukollektiv',),
'bukollektiva': ('bukollektiv',),
'bukollektivene': ('bukollektiv',),
'bukollektiver': ('bukollektiv',),
'bukollektivet': ('bukollektiv',),
'bukreditt': ('bukreditt',),
'bukreditten': ('bukreditt',),
'bukredittene': ('bukreditt',),
'bukreditter': ('bukreditt',),
'buksbom': ('buksbom',),
'buksbommen': ('buksbom',),
'buksbommene': ('buksbom',),
'buksbommer': ('buksbom',),
'buksbomhekk': ('buksbomhekk',),
'buksbomhekken': ('buksbomhekk',),
'buksbomhekkene': ('buksbomhekk',),
'buksbomhekker': ('buksbomhekk',),
'buksa': ('bukse',),
'bukse': ('bukse',),
'buksen': ('bukse',),
'buksene': ('bukse',),
'bukser': ('bukse',),
'buksebak': ('buksebak',),
'buksebaken': ('buksebak',),
'buksebakene': ('buksebak',),
'buksebaker': ('buksebak',),
'buksebein': ('buksebein',),
'buksebeina': ('buksebein',),
'buksebeinene': ('buksebein',),
'buksebeinet': ('buksebein',),
'bukseben': ('bukseben',),
'buksebena': ('bukseben',),
'buksebenene': ('bukseben',),
'buksebenet': ('bukseben',),
'buksedrakt': ('buksedrakt',),
'buksedrakta': ('buksedrakt',),
'buksedrakten': ('buksedrakt',),
'buksedraktene': ('buksedrakt',),
'buksedrakter': ('buksedrakt',),
'buksedress': ('buksedress',),
'buksedressen': ('buksedress',),
'buksedressene': ('buksedress',),
'buksedresser': ('buksedress',),
'bukselomma': ('bukselomme',),
'bukselomme': ('bukselomme',),
'bukselommen': ('bukselomme',),
'bukselommene': ('bukselomme',),
'bukselommer': ('bukselomme',),
'bukserbåt': ('bukserbåt',),
'bukserbåten': ('bukserbåt',),
'bukserbåtene': ('bukserbåt',),
'bukserbåter': ('bukserbåt',),
'buksesele': ('buksesele',),
'bukseselen': ('buksesele',),
'bukseselene': ('buksesele',),
'bukseseler': ('buksesele',),
'bukseskjørt': ('bukseskjørt',),
'bukseskjørta': ('bukseskjørt',),
'bukseskjørtene': ('bukseskjørt',),
'bukseskjørter': ('bukseskjørt',),
'bukseskjørtet': ('bukseskjørt',),
'buksesmekk': ('buksesmekk',),
'buksesmekken': ('buksesmekk',),
'buksesmekkene': ('buksesmekk',),
'buksesmekker': ('buksesmekk',),
'bukspytt': ('bukspytt',),
'bukspytta': ('bukspytt',),
'bukspyttene': ('bukspytt',),
'bukspyttet': ('bukspytt',),
'bukspyttkjertel': ('bukspyttkjertel',),
'bukspyttkjertelen': ('bukspyttkjertel',),
'bukspyttkjertlene': ('bukspyttkjertel',),
'bukspyttkjertler': ('bukspyttkjertel',),
'bukt': ('bukt',),
'bukta': ('bukt',),
'bukten': ('bukt',),
'buktene': ('bukt',),
'bukter': ('bukt',),
'buktaler': ('buktaler',),
'buktalere': ('buktaler',),
'buktaleren': ('buktaler',),
'buktalerer': ('buktaler',),
'buktalerne': ('buktaler',),
'buktning': ('buktning',),
'buktninga': ('buktning',),
'buktningen': ('buktning',),
'buktningene': ('buktning',),
'buktninger': ('buktning',),
'bukvirvel': ('bukvirvel',),
'bukvirvelen': ('bukvirvel',),
'bukvirvlene': ('bukvirvel',),
'bukvirvler': ('bukvirvel',),
'bulb': ('bulb',),
'bulben': ('bulb',),
'bulbene': ('bulb',),
'bulber': ('bulb',),
'bulder': ('bulder',),
'bulderet': ('bulder',),
'buldra': ('bulder',),
'buldre': ('bulder',),
'buldrene': ('bulder',),
'buldrer': ('bulder',),
'buldret': ('bulder',),
'buldrebasse': ('buldrebasse',),
'buldrebassen': ('buldrebasse',),
'buldrebassene': ('buldrebasse',),
'buldrebasser': ('buldrebasse',),
'bule': ('bule',),
'bulen': ('bule',),
'bulene': ('bule',),
'buler': ('bule',),
'bula': ('bule',),
'bule': ('bule',),
'bulen': ('bule',),
'bulene': ('bule',),
'buler': ('bule',),
'bulevard': ('bulevard',),
'bulevarden': ('bulevard',),
'bulevardene': ('bulevard',),
'bulevarder': ('bulevard',),
'bulevardavis': ('bulevardavis',),
'bulevardavisa': ('bulevardavis',),
'bulevardavisen': ('bulevardavis',),
'bulevardavisene': ('bulevardavis',),
'bulevardaviser': ('bulevardavis',),
'bulgarer': ('bulgarer',),
'bulgarere': ('bulgarer',),
'bulgareren': ('bulgarer',),
'bulgarerer': ('bulgarer',),
'bulgarerne': ('bulgarer',),
'bulgarsk': ('bulgarsk',),
'bulgarsken': ('bulgarsk',),
'bulgarskene': ('bulgarsk',),
'bulgarsker': ('bulgarsk',),
'bulimi': ('bulimi',),
'bulimien': ('bulimi',),
'bulimiene': ('bulimi',),
'bulimier': ('bulimi',),
'bulimiker': ('bulimiker',),
'bulimikere': ('bulimiker',),
'bulimikeren': ('bulimiker',),
'bulimikerer': ('bulimiker',),
'bulimikerne': ('bulimiker',),
'buljong': ('buljong',),
'buljongen': ('buljong',),
'buljongene': ('buljong',),
'buljonger': ('buljong',),
'buljongpar': ('buljongpar',),
'buljongpara': ('buljongpar',),
'buljongparene': ('buljongpar',),
'buljongparet': ('buljongpar',),
'buljongterning': ('buljongterning',),
'buljongterningen': ('buljongterning',),
'buljongterningene': ('buljongterning',),
'buljongterninger': ('buljongterning',),
'bulkbil': ('bulkbil',),
'bulkbilen': ('bulkbil',),
'bulkbilene': ('bulkbil',),
'bulkbiler': ('bulkbil',),
'bulkcarrier': ('bulkcarrier',),
'bulkcarriere': ('bulkcarrier',),
'bulkcarrieren': ('bulkcarrier',),
'bulkcarrierer': ('bulkcarrier',),
'bulkcarrierne': ('bulkcarrier',),
'bulklast': ('bulklast',),
'bulklasta': ('bulklast',),
'bulklasten': ('bulklast',),
'bulklastene': ('bulklast',),
'bulklaster': ('bulklast',),
'bulkskip': ('bulkskip',),
'bulkskipa': ('bulkskip',),
'bulkskipene': ('bulkskip',),
'bulkskipet': ('bulkskip',),
'bulldogg': ('bulldogg',),
'bulldoggen': ('bulldogg',),
'bulldoggene': ('bulldogg',),
'bulldogger': ('bulldogg',),
'bulldoggansikt': ('bulldoggansikt',),
'bulldoggansikta': ('bulldoggansikt',),
'bulldoggansiktene': ('bulldoggansikt',),
'bulldoggansikter': ('bulldoggansikt',),
'bulldoggansiktet': ('bulldoggansikt',),
'bulldoser': ('bulldoser',),
'bulldosere': ('bulldoser',),
'bulldoseren': ('bulldoser',),
'bulldoserer': ('bulldoser',),
'bulldoserne': ('bulldoser',),
'bulle': ('bulle',),
'bullen': ('bulle',),
'bullene': ('bulle',),
'buller': ('bulle',),
'bulletin': ('bulletin',),
'bulletinen': ('bulletin',),
'bulletinene': ('bulletin',),
'bulletiner': ('bulletin',),
'bulmeurt': ('bulmeurt',),
'bulmeurta': ('bulmeurt',),
'bulmeurten': ('bulmeurt',),
'bulmeurtene': ('bulmeurt',),
'bulmeurter': ('bulmeurt',),
'bulter': ('bulter',),
'bumaskin': ('bumaskin',),
'bumaskina': ('bumaskin',),
'bumaskinen': ('bumaskin',),
'bumaskinene': ('bumaskin',),
'bumaskiner': ('bumaskin',),
'bumerang': ('bumerang',),
'bumerangen': ('bumerang',),
'bumerangene': ('bumerang',),
'bumeranger': ('bumerang',),
'bumerka': ('bumerke',),
'bumerke': ('bumerke',),
'bumerkene': ('bumerke',),
'bumerker': ('bumerke',),
'bumerket': ('bumerke',),
'bumsa': ('bumse',),
'bumse': ('bumse',),
'bumsen': ('bumse',),
'bumsene': ('bumse',),
'bumser': ('bumse',),
'bunad': ('bunad',),
'bunaden': ('bunad',),
'bunadene': ('bunad',),
'bunader': ('bunad',),
'bunadskjorta': ('bunadskjorte',),
'bunadskjorte': ('bunadskjorte',),
'bunadskjorten': ('bunadskjorte',),
'bunadskjortene': ('bunadskjorte',),
'bunadskjorter': ('bunadskjorte',),
'bunadsko': ('bunadsko',),
'bunadskoen': ('bunadsko',),
'bunadskoene': ('bunadsko',),
'bunadskor': ('bunadsko',),
'bunadskorne': ('bunadsko',),
'bunadsskjorta': ('bunadsskjorte',),
'bunadsskjorte': ('bunadsskjorte',),
'bunadsskjorten': ('bunadsskjorte',),
'bunadsskjortene': ('bunadsskjorte',),
'bunadsskjorter': ('bunadsskjorte',),
'bunadssko': ('bunadssko',),
'bunadsskoa': ('bunadssko',),
'bunadsskoen': ('bunadssko',),
'bunadsskoene': ('bunadssko',),
'bunadsskor': ('bunadssko',),
'bunadsskorne': ('bunadssko',),
'bunadssølv': ('bunadssølv',),
'bunadssølva': ('bunadssølv',),
'bunadssølvene': ('bunadssølv',),
'bunadssølvet': ('bunadssølv',),
'bunadsølv': ('bunadsølv',),
'bunadsølva': ('bunadsølv',),
'bunadsølvene': ('bunadsølv',),
'bunadsølvet': ('bunadsølv',),
'bunding': ('bunding',),
'bundingen': ('bunding',),
'bundingene': ('bunding',),
'bundinger': ('bunding',),
'bundsforvant': ('bundsforvant',),
'bundsforvante': ('bundsforvant',),
'bundsforvanten': ('bundsforvant',),
'bundsforvantene': ('bundsforvant',),
'bungalow': ('bungalow',),
'bungalowen': ('bungalow',),
'bungalowene': ('bungalow',),
'bungalower': ('bungalow',),
'bunke': ('bunke',),
'bunken': ('bunke',),
'bunkene': ('bunke',),
'bunker': ('bunke',),
'bunke': ('bunke',),
'bunken': ('bunke',),
'bunkene': ('bunke',),
'bunker': ('bunke',),
'bunke': ('bunke',),
'bunken': ('bunke',),
'bunkene': ('bunke',),
'bunker': ('bunke',),
'bunker': ('bunker',),
'bunkere': ('bunker',),
'bunkeren': ('bunker',),
'bunkerer': ('bunker',),
'bunkerne': ('bunker',),
'bunkers': ('bunkers',),
'bunkersen': ('bunkers',),
'bunkersene': ('bunkers',),
'bunn': ('bunn',),
'bunnen': ('bunn',),
'bunnene': ('bunn',),
'bunner': ('bunn',),
'bunn-nivå': ('bunn-nivå',),
'bunn-nivåa': ('bunn-nivå',),
'bunn-nivåene': ('bunn-nivå',),
'bunn-nivåer': ('bunn-nivå',),
'bunn-nivået': ('bunn-nivå',),
'bunnband': ('bunnband',),
'bunnbanda': ('bunnband',),
'bunnbandene': ('bunnband',),
'bunnbandet': ('bunnband',),
'bunnbord': ('bunnbord',),
'bunnborda': ('bunnbord',),
'bunnbordene': ('bunnbord',),
'bunnborder': ('bunnbord',),
'bunnbordet': ('bunnbord',),
'bunnbånd': ('bunnbånd',),
'bunnbånda': ('bunnbånd',),
'bunnbåndene': ('bunnbånd',),
'bunnbåndet': ('bunnbånd',),
'bunnfall': ('bunnfall',),
'bunnfalla': ('bunnfall',),
'bunnfallene': ('bunnfall',),
'bunnfallet': ('bunnfall',),
'bunnfisk': ('bunnfisk',),
'bunnfisken': ('bunnfisk',),
'bunnfiskene': ('bunnfisk',),
'bunnfisker': ('bunnfisk',),
'bunnflata': ('bunnflate',),
'bunnflate': ('bunnflate',),
'bunnflaten': ('bunnflate',),
'bunnflatene': ('bunnflate',),
'bunnflater': ('bunnflate',),
'bunnivå': ('bunnivå',),
'bunnivåa': ('bunnivå',),
'bunnivåene': ('bunnivå',),
'bunnivåer': ('bunnivå',),
'bunnivået': ('bunnivå',),
'bunnlag': ('bunnlag',),
'bunnlaga': ('bunnlag',),
'bunnlagene': ('bunnlag',),
'bunnlaget': ('bunnlag',),
'bunnløshet': ('bunnløshet',),
'bunnløsheta': ('bunnløshet',),
'bunnløsheten': ('bunnløshet',),
'bunnløshetene': ('bunnløshet',),
'bunnløsheter': ('bunnløshet',),
'bunnløysa': ('bunnløyse',),
'bunnløyse': ('bunnløyse',),
'bunnløysen': ('bunnløyse',),
'bunnløysene': ('bunnløyse',),
'bunnløyser': ('bunnløyse',),
'bunnmorene': ('bunnmorene',),
'bunnmorenen': ('bunnmorene',),
'bunnmorenene': ('bunnmorene',),
'bunnmorener': ('bunnmorene',),
'bunnpanna': ('bunnpanne',),
'bunnpanne': ('bunnpanne',),
'bunnpannen': ('bunnpanne',),
'bunnpannene': ('bunnpanne',),
'bunnpanner': ('bunnpanne',),
'bunnrekord': ('bunnrekord',),
'bunnrekorden': ('bunnrekord',),
'bunnrekordene': ('bunnrekord',),
'bunnrekorder': ('bunnrekord',),
'bunnstoff': ('bunnstoff',),
'bunnstoffa': ('bunnstoff',),
'bunnstoffene': ('bunnstoff',),
'bunnstoffer': ('bunnstoff',),
'bunnstoffet': ('bunnstoff',),
'bunnstrid': ('bunnstrid',),
'bunnstriden': ('bunnstrid',),
'bunnstridene': ('bunnstrid',),
'bunnstrider': ('bunnstrid',),
'bunsenbrenner': ('bunsenbrenner',),
'bunsenbrennere': ('bunsenbrenner',),
'bunsenbrenneren': ('bunsenbrenner',),
'bunsenbrennerer': ('bunsenbrenner',),
'bunsenbrennerne': ('bunsenbrenner',),
'bunt': ('bunt',),
'bunten': ('bunt',),
'buntene': ('bunt',),
'bunter': ('bunt',),
'buntmaker': ('buntmaker',),
'buntmakere': ('buntmaker',),
'buntmakeren': ('buntmaker',),
'buntmakerer': ('buntmaker',),
'buntmakerne': ('buntmaker',),
'buorm': ('buorm',),
'buormen': ('buorm',),
'buormene': ('buorm',),
'buormer': ('buorm',),
'buplikt': ('buplikt',),
'buplikta': ('buplikt',),
'buplikten': ('buplikt',),
'bupliktene': ('buplikt',),
'buplikter': ('buplikt',),
'bur': ('bur',),
'bura': ('bur',),
'burene': ('bur',),
'buret': ('bur',),
'bureiser': ('bureiser',),
'bureisere': ('bureiser',),
'bureiseren': ('bureiser',),
'bureiserer': ('bureiser',),
'bureiserne': ('bureiser',),
'bureising': ('bureising',),
'bureisinga': ('bureising',),
'bureisingen': ('bureising',),
'bureisingene': ('bureising',),
'bureisinger': ('bureising',),
'burettslag': ('burettslag',),
'burettslaga': ('burettslag',),
'burettslagene': ('burettslag',),
'burettslaget': ('burettslag',),
'burfugl': ('burfugl',),
'burfuglen': ('burfugl',),
'burfuglene': ('burfugl',),
'burfugler': ('burfugl',),
'burger': ('burger',),
'burgere': ('burger',),
'burgeren': ('burger',),
'burgerer': ('burger',),
'burgerne': ('burger',),
'burgunder': ('burgunder',),
'burgundere': ('burgunder',),
'burgunderen': ('burgunder',),
'burgunderer': ('burgunder',),
'burgunderne': ('burgunder',),
'burgundervin': ('burgundervin',),
'burgundervinen': ('burgundervin',),
'burgundervinene': ('burgundervin',),
'burgunderviner': ('burgundervin',),
'burhøna': ('burhøne',),
'burhøne': ('burhøne',),
'burhønen': ('burhøne',),
'burhønene': ('burhøne',),
'burhøner': ('burhøne',),
'burjat': ('burjat',),
'burjaten': ('burjat',),
'burjatene': ('burjat',),
'burjater': ('burjat',),
'burkiner': ('burkiner',),
'burkinere': ('burkiner',),
'burkineren': ('burkiner',),
'burkinerer': ('burkiner',),
'burkinerne': ('burkiner',),
'burkne': ('burkne',),
'burknen': ('burkne',),
'burknene': ('burkne',),
'burkner': ('burkne',),
'burloft': ('burloft',),
'burlofta': ('burloft',),
'burloftene': ('burloft',),
'burloftet': ('burloft',),
'burmaner': ('burmaner',),
'burmanere': ('burmaner',),
'burmaneren': ('burmaner',),
'burmanerer': ('burmaner',),
'burmanerne': ('burmaner',),
'burnus': ('burnus',),
'burnusen': ('burnus',),
'burnusene': ('burnus',),
'burnuser': ('burnus',),
'burot': ('burot',),
'burota': ('burot',),
'buroten': ('burot',),
'burotene': ('burot',),
'bursdag': ('bursdag',),
'bursdagen': ('bursdag',),
'bursdagene': ('bursdag',),
'bursdager': ('bursdag',),
'bursjoa': ('bursjoa',),
'bursjoaen': ('bursjoa',),
'bursjoaene': ('bursjoa',),
'bursjoaer': ('bursjoa',),
'bursjoasi': ('bursjoasi',),
'bursjoasia': ('bursjoasi',),
'bursjoasiene': ('bursjoasi',),
'bursjoasier': ('bursjoasi',),
'bursjoasiet': ('bursjoasi',),
'burundier': ('burundier',),
'burundiere': ('burundier',),
'burundieren': ('burundier',),
'burundierer': ('burundier',),
'burundierne': ('burundier',),
'bus': ('bus',),
'busen': ('bus',),
'busene': ('bus',),
'buser': ('bus',),
'buse': ('buse',),
'busen': ('buse',),
'busene': ('buse',),
'buser': ('buse',),
'busemann': ('busemann',),
'busemannen': ('busemann',),
'busemenn': ('busemann',),
'busemennene': ('busemann',),
'busetning': ('busetning',),
'busetninga': ('busetning',),
'busetningen': ('busetning',),
'busetningene': ('busetning',),
'busetninger': ('busetning',),
'busetningskart': ('busetningskart',),
'busetningskarta': ('busetningskart',),
'busetningskartene': ('busetningskart',),
'busetningskarter': ('busetningskart',),
'busetningskartet': ('busetningskart',),
'busetningsmønster': ('busetningsmønster',),
'busetningsmønsteret': ('busetningsmønster',),
'busetningsmønstra': ('busetningsmønster',),
'busetningsmønstre': ('busetningsmønster',),
'busetningsmønstrene': ('busetningsmønster',),
'busetningsmønstret': ('busetningsmønster',),
'busettingskart': ('busettingskart',),
'busettingskarta': ('busettingskart',),
'busettingskartene': ('busettingskart',),
'busettingskarter': ('busettingskart',),
'busettingskartet': ('busettingskart',),
'busettingsmønster': ('busettingsmønster',),
'busettingsmønsteret': ('busettingsmønster',),
'busettingsmønstra': ('busettingsmønster',),
'busettingsmønstre': ('busettingsmønster',),
'busettingsmønstrene': ('busettingsmønster',),
'busettingsmønstret': ('busettingsmønster',),
'bush': ('bush',),
'bushen': ('bush',),
'bushene': ('bush',),
'busher': ('bush',),
'bushel': ('bushel',),
'bushelen': ('bushel',),
'bushelene': ('bushel',),
'bushels': ('bushel',),
'business': ('business',),
'businessen': ('business',),
'businessene': ('business',),
'businesser': ('business',),
'busk': ('busk',),
'busken': ('busk',),
'buskene': ('busk',),
'busker': ('busk',),
'buskagitasjon': ('buskagitasjon',),
'buskagitasjonen': ('buskagitasjon',),
'buskagitasjonene': ('buskagitasjon',),
'buskagitasjoner': ('buskagitasjon',),
'buskap': ('buskap',),
'buskapen': ('buskap',),
'buskapene': ('buskap',),
'buskaper': ('buskap',),
'buskas': ('buskas',),
'buskasa': ('buskas',),
'buskasene': ('buskas',),
'buskaser': ('buskas',),
'buskaset': ('buskas',),
'buska': ('buske',),
'buske': ('buske',),
'busken': ('buske',),
'buskene': ('buske',),
'busker': ('buske',),
'buskfuru': ('buskfuru',),
'buskfurua': ('buskfuru',),
'buskfuruen': ('buskfuru',),
'buskfuruene': ('buskfuru',),
'buskfuruer': ('buskfuru',),
'buskis': ('buskis',),
'buskisen': ('buskis',),
'buskisene': ('buskis',),
'buskiser': ('buskis',),
'buskmann': ('buskmann',),
'buskmannen': ('buskmann',),
'buskmenn': ('buskmann',),
'buskmennene': ('buskmann',),
'busknellik': ('busknellik',),
'busknelliken': ('busknellik',),
'busknellikene': ('busknellik',),
'busknelliker': ('busknellik',),
'buskskvett': ('buskskvett',),
'buskskvetten': ('buskskvett',),
'buskskvettene': ('buskskvett',),
'buskskvetter': ('buskskvett',),
'buskvekst': ('buskvekst',),
'buskveksten': ('buskvekst',),
'buskvekstene': ('buskvekst',),
'buskvekster': ('buskvekst',),
'buss': ('buss',),
'bussen': ('buss',),
'bussene': ('buss',),
'busser': ('buss',),
'buss': ('buss',),
'bussen': ('buss',),
'bussene': ('buss',),
'busser': ('buss',),
'buss-sjåfør': ('buss-sjåfør',),
'buss-sjåføren': ('buss-sjåfør',),
'buss-sjåførene': ('buss-sjåfør',),
'buss-sjåfører': ('buss-sjåfør',),
'buss-stopp': ('buss-stopp',),
'buss-stoppa': ('buss-stopp',),
'buss-stoppen': ('buss-stopp',),
'buss-stoppene': ('buss-stopp',),
'buss-stoppet': ('buss-stopp',),
'busse': ('busse',),
'bussen': ('busse',),
'bussene': ('busse',),
'busser': ('busse',),
'bussa': ('busse',),
'busse': ('busse',),
'bussen': ('busse',),
'bussene': ('busse',),
'busser': ('busse',),
'busserull': ('busserull',),
'busserullen': ('busserull',),
'busserullene': ('busserull',),
'busseruller': ('busserull',),
'bussfelt': ('bussfelt',),
'bussfelta': ('bussfelt',),
'bussfeltene': ('bussfelt',),
'bussfelter': ('bussfelt',),
'bussfeltet': ('bussfelt',),
'bussfil': ('bussfil',),
'bussfilen': ('bussfil',),
'bussfilene': ('bussfil',),
'bussfiler': ('bussfil',),
'bussforbindelse': ('bussforbindelse',),
'bussforbindelsen': ('bussforbindelse',),
'bussforbindelsene': ('bussforbindelse',),
'bussforbindelser': ('bussforbindelse',),
'bussholdeplass': ('bussholdeplass',),
'bussholdeplassen': ('bussholdeplass',),
'bussholdeplassene': ('bussholdeplass',),
'bussholdeplasser': ('bussholdeplass',),
'bussjåfør': ('bussjåfør',),
'bussjåføren': ('bussjåfør',),
'bussjåførene': ('bussjåfør',),
'bussjåfører': ('bussjåfør',),
'bussruta': ('bussrute',),
'bussrute': ('bussrute',),
'bussruten': ('bussrute',),
'bussrutene': ('bussrute',),
'bussruter': ('bussrute',),
'bussterminal': ('bussterminal',),
'bussterminalen': ('bussterminal',),
'bussterminalene': ('bussterminal',),
'bussterminaler': ('bussterminal',),
'busstopp': ('busstopp',),
'busstoppa': ('busstopp',),
'busstoppen': ('busstopp',),
'busstoppene': ('busstopp',),
'busstoppet': ('busstopp',),
'bust': ('bust',),
'busta': ('bust',),
'busten': ('bust',),
'bustene': ('bust',),
'buster': ('bust',),
'bustad': ('bustad',),
'bustaden': ('bustad',),
'bustadene': ('bustad',),
'bustader': ('bustad',),
'bustadbank': ('bustadbank',),
'bustadbanken': ('bustadbank',),
'bustadbankene': ('bustadbank',),
'bustadbanker': ('bustadbank',),
'bustadlån': ('bustadlån',),
'bustadlåna': ('bustadlån',),
'bustadlånene': ('bustadlån',),
'bustadlånet': ('bustadlån',),
'bustnellik': ('bustnellik',),
'bustnelliken': ('bustnellik',),
'bustnellikene': ('bustnellik',),
'bustnelliker': ('bustnellik',),
'bustyra': ('bustyre',),
'bustyre': ('bustyre',),
'bustyrene': ('bustyre',),
'bustyrer': ('bustyre',),
'bustyret': ('bustyre',),
'bustyrer': ('bustyrer',),
'bustyrere': ('bustyrer',),
'bustyreren': ('bustyrer',),
'bustyrerer': ('bustyrer',),
'bustyrerne': ('bustyrer',),
'bustøtta': ('bustøtte',),
'bustøtte': ('bustøtte',),
'bustøtten': ('bustøtte',),
'bustøttene': ('bustøtte',),
'bustøtter': ('bustøtte',),
'butan': ('butan',),
'butana': ('butan',),
'butanen': ('butan',),
'butanene': ('butan',),
'butaner': ('butan',),
'butanet': ('butan',),
'butid': ('butid',),
'butida': ('butid',),
'butiden': ('butid',),
'butidene': ('butid',),
'butider': ('butid',),
'butikk': ('butikk',),
'butikken': ('butikk',),
'butikkene': ('butikk',),
'butikker': ('butikk',),
'butikk-kjede': ('butikk-kjede',),
'butikk-kjeden': ('butikk-kjede',),
'butikk-kjedene': ('butikk-kjede',),
'butikk-kjeder': ('butikk-kjede',),
'butikkdød': ('butikkdød',),
'butikkdøden': ('butikkdød',),
'butikkdødene': ('butikkdød',),
'butikkdøder': ('butikkdød',),
'butikkfagskole': ('butikkfagskole',),
'butikkfagskolen': ('butikkfagskole',),
'butikkfagskolene': ('butikkfagskole',),
'butikkfagskoler': ('butikkfagskole',),
'butikkfunksjonær': ('butikkfunksjonær',),
'butikkfunksjonæren': ('butikkfunksjonær',),
'butikkfunksjonærene': ('butikkfunksjonær',),
'butikkfunksjonærer': ('butikkfunksjonær',),
'butikkjede': ('butikkjede',),
'butikkjeden': ('butikkjede',),
'butikkjedene': ('butikkjede',),
'butikkjeder': ('butikkjede',),
'butikksenter': ('butikksenter',),
'butikksenteret': ('butikksenter',),
'butikksentra': ('butikksenter',),
'butikksentre': ('butikksenter',),
'butikksentrene': ('butikksenter',),
'butikksentret': ('butikksenter',),
'butikktjuv': ('butikktjuv',),
'butikktjuven': ('butikktjuv',),
'butikktjuvene': ('butikktjuv',),
'butikktjuver': ('butikktjuv',),
'butikktjuveri': ('butikktjuveri',),
'butikktjuveria': ('butikktjuveri',),
'butikktjuveriene': ('butikktjuveri',),
'butikktjuverier': ('butikktjuveri',),
'butikktjuveriet': ('butikktjuveri',),
'butikktyv': ('butikktyv',),
'butikktyven': ('butikktyv',),
'butikktyvene': ('butikktyv',),
'butikktyver': ('butikktyv',),
'butikktyveri': ('butikktyveri',),
'butikktyveria': ('butikktyveri',),
'butikktyveriene': ('butikktyveri',),
'butikktyverier': ('butikktyveri',),
'butikktyveriet': ('butikktyveri',),
'butikkvindu': ('butikkvindu',),
'butikkvindua': ('butikkvindu',),
'butikkvinduene': ('butikkvindu',),
'butikkvinduer': ('butikkvindu',),
'butikkvinduet': ('butikkvindu',),
'butt': ('butt',),
'butten': ('butt',),
'buttene': ('butt',),
'butter': ('butt',),
'butt': ('butt',),
'butten': ('butt',),
'buttene': ('butt',),
'butter': ('butt',),
'butterdeig': ('butterdeig',),
'butterdeigen': ('butterdeig',),
'butterdeigene': ('butterdeig',),
'butterdeiger': ('butterdeig',),
'butterfly': ('butterfly',),
'butterflyen': ('butterfly',),
'butterflyene': ('butterfly',),
'butterflyer': ('butterfly',),
'buttskjøt': ('buttskjøt',),
'buttskjøten': ('buttskjøt',),
'buttskjøtene': ('buttskjøt',),
'buttskjøter': ('buttskjøt',),
'buttsveis': ('buttsveis',),
'buttsveisen': ('buttsveis',),
'buttsveisene': ('buttsveis',),
'buttsveiser': ('buttsveis',),
'by': ('by',),
'byen': ('by',),
'byene': ('by',),
'byer': ('by',),
'byantikvar': ('byantikvar',),
'byantikvaren': ('byantikvar',),
'byantikvarene': ('byantikvar',),
'byantikvarer': ('byantikvar',),
'bybefolkning': ('bybefolkning',),
'bybefolkninga': ('bybefolkning',),
'bybefolkningen': ('bybefolkning',),
'bybefolkningene': ('bybefolkning',),
'bybefolkninger': ('bybefolkning',),
'bybilda': ('bybilde',),
'bybilde': ('bybilde',),
'bybildene': ('bybilde',),
'bybilder': ('bybilde',),
'bybildet': ('bybilde',),
'bybud': ('bybud',),
'bybuda': ('bybud',),
'bybudene': ('bybud',),
'bybudet': ('bybud',),
'bydeform': ('bydeform',),
'bydeforma': ('bydeform',),
'bydeformen': ('bydeform',),
'bydeformene': ('bydeform',),
'bydeformer': ('bydeform',),
'bydel': ('bydel',),
'bydelen': ('bydel',),
'bydelene': ('bydel',),
'bydeler': ('bydel',),
'bydelsutvalg': ('bydelsutvalg',),
'bydelsutvalga': ('bydelsutvalg',),
'bydelsutvalgene': ('bydelsutvalg',),
'bydelsutvalget': ('bydelsutvalg',),
'bya': ('bye',),
'bye': ('bye',),
'byen': ('bye',),
'byene': ('bye',),
'byer': ('bye',),
'bya': ('bye',),
'bye': ('bye',),
'byen': ('bye',),
'byene': ('bye',),
'byer': ('bye',),
'byfogd': ('byfogd',),
'byfogden': ('byfogd',),
'byfogdene': ('byfogd',),
'byfogder': ('byfogd',),
'byfolk': ('byfolk',),
'byfolka': ('byfolk',),
'byfolkene': ('byfolk',),
'byfolket': ('byfolk',),
'byfornyelse': ('byfornyelse',),
'byfornyelsen': ('byfornyelse',),
'byfornyelsene': ('byfornyelse',),
'byfornyelser': ('byfornyelse',),
'byfornying': ('byfornying',),
'byfornyinga': ('byfornying',),
'byfornyingen': ('byfornying',),
'byfornyingene': ('byfornying',),
'byfornyinger': ('byfornying',),
'bygd': ('bygd',),
'bygda': ('bygd',),
'bygden': ('bygd',),
'bygdene': ('bygd',),
'bygder': ('bygd',),
'bygdeallmenning': ('bygdeallmenning',),
'bygdeallmenningen': ('bygdeallmenning',),
'bygdeallmenningene': ('bygdeallmenning',),
'bygdeallmenninger': ('bygdeallmenning',),
'bygdeborg': ('bygdeborg',),
'bygdeborga': ('bygdeborg',),
'bygdeborgen': ('bygdeborg',),
'bygdeborgene': ('bygdeborg',),
'bygdeborger': ('bygdeborg',),
'bygdeby': ('bygdeby',),
'bygdebyen': ('bygdeby',),
'bygdebyene': ('bygdeby',),
'bygdebyer': ('bygdeby',),
'bygdedans': ('bygdedans',),
'bygdedansen': ('bygdedans',),
'bygdedansene': ('bygdedans',),
'bygdedanser': ('bygdedans',),
'bygdefolk': ('bygdefolk',),
'bygdefolka': ('bygdefolk',),
'bygdefolkene': ('bygdefolk',),
'bygdefolket': ('bygdefolk',),
'bygdegeni': ('bygdegeni',),
'bygdegenia': ('bygdegeni',),
'bygdegeniene': ('bygdegeni',),
'bygdegenier': ('bygdegeni',),
'bygdegeniet': ('bygdegeni',),
'bygdekultur': ('bygdekultur',),
'bygdekulturen': ('bygdekultur',),
'bygdekulturene': ('bygdekultur',),
'bygdekulturer': ('bygdekultur',),
'bygdelag': ('bygdelag',),
'bygdelaga': ('bygdelag',),
'bygdelagene': ('bygdelag',),
'bygdelaget': ('bygdelag',),
'bygdemål': ('bygdemål',),
'bygdemåla': ('bygdemål',),
'bygdemålene': ('bygdemål',),
'bygdemålet': ('bygdemål',),
'bygdemålsdikter': ('bygdemålsdikter',),
'bygdemålsdiktere': ('bygdemålsdikter',),
'bygdemålsdikteren': ('bygdemålsdikter',),
'bygdemålsdikterer': ('bygdemålsdikter',),
'bygdemålsdikterne': ('bygdemålsdikter',),
'bygdemålslitteratur': ('bygdemålslitteratur',),
'bygdemålslitteraturen': ('bygdemålslitteratur',),
'bygdemålslitteraturene': ('bygdemålslitteratur',),
'bygdemålslitteraturer': ('bygdemålslitteratur',),
'bygdemålsvisa': ('bygdemålsvise',),
'bygdemålsvise': ('bygdemålsvise',),
'bygdemålsvisen': ('bygdemålsvise',),
'bygdemålsvisene': ('bygdemålsvise',),
'bygdemålsviser': ('bygdemålsvise',),
'bygdetun': ('bygdetun',),
'bygdetuna': ('bygdetun',),
'bygdetunene': ('bygdetun',),
'bygdetunet': ('bygdetun',),
'bygdeveg': ('bygdeveg',),
'bygdevegen': ('bygdeveg',),
'bygdevegene': ('bygdeveg',),
'bygdeveger': ('bygdeveg',),
'bygdevei': ('bygdevei',),
'bygdeveien': ('bygdevei',),
'bygdeveiene': ('bygdevei',),
'bygdeveier': ('bygdevei',),
'byga': ('byge',),
'byge': ('byge',),
'bygen': ('byge',),
'bygene': ('byge',),
'byger': ('byge',),
'byga': ('byge',),
'byge': ('byge',),
'bygen': ('byge',),
'bygene': ('byge',),
'byger': ('byge',),
'bygerilja': ('bygerilja',),
'bygeriljaen': ('bygerilja',),
'bygeriljaene': ('bygerilja',),
'bygeriljaer': ('bygerilja',),
'bygg': ('bygg',),
'bygga': ('bygg',),
'byggene': ('bygg',),
'bygget': ('bygg',),
'bygg': ('bygg',),
'bygga': ('bygg',),
'byggen': ('bygg',),
'byggene': ('bygg',),
'bygger': ('bygg',),
'bygget': ('bygg',),
'bygg-gryn': ('bygg-gryn',),
'bygg-gryna': ('bygg-gryn',),
'bygg-grynene': ('bygg-gryn',),
'bygg-grynet': ('bygg-gryn',),
'byggearbeid': ('byggearbeid',),
'byggearbeida': ('byggearbeid',),
'byggearbeidene': ('byggearbeid',),
'byggearbeider': ('byggearbeid',),
'byggearbeidet': ('byggearbeid',),
'byggeelement': ('byggeelement',),
'byggeelementa': ('byggeelement',),
'byggeelementene': ('byggeelement',),
'byggeelementer': ('byggeelement',),
'byggeelementet': ('byggeelement',),
'byggefelt': ('byggefelt',),
'byggefelta': ('byggefelt',),
'byggefeltene': ('byggefelt',),
'byggefelter': ('byggefelt',),
'byggefeltet': ('byggefelt',),
'byggeforbud': ('byggeforbud',),
'byggeforbuda': ('byggeforbud',),
'byggeforbudene': ('byggeforbud',),
'byggeforbudet': ('byggeforbud',),
'byggeforetak': ('byggeforetak',),
'byggeforetaka': ('byggeforetak',),
'byggeforetakene': ('byggeforetak',),
'byggeforetaket': ('byggeforetak',),
'byggeforskrift': ('byggeforskrift',),
'byggeforskrifta': ('byggeforskrift',),
'byggeforskriften': ('byggeforskrift',),
'byggeforskriftene': ('byggeforskrift',),
'byggeforskrifter': ('byggeforskrift',),
'byggegrensa': ('byggegrense',),
'byggegrense': ('byggegrense',),
'byggegrensen': ('byggegrense',),
'byggegrensene': ('byggegrense',),
'byggegrenser': ('byggegrense',),
'byggekloss': ('byggekloss',),
'byggeklossen': ('byggekloss',),
'byggeklossene': ('byggekloss',),
'byggeklosser': ('byggekloss',),
'byggeklossprinsipp': ('byggeklossprinsipp',),
'byggeklossprinsippa': ('byggeklossprinsipp',),
'byggeklossprinsippene': ('byggeklossprinsipp',),
'byggeklossprinsipper': ('byggeklossprinsipp',),
'byggeklossprinsippet': ('byggeklossprinsipp',),
'byggekunst': ('byggekunst',),
'byggekunsten': ('byggekunst',),
'byggekunstene': ('byggekunst',),
'byggekunster': ('byggekunst',),
'byggeleder': ('byggeleder',),
'byggeledere': ('byggeleder',),
'byggelederen': ('byggeleder',),
'byggelederer': ('byggeleder',),
'byggelederne': ('byggeleder',),
'byggelån': ('byggelån',),
'byggelåna': ('byggelån',),
'byggelånene': ('byggelån',),
'byggelånet': ('byggelån',),
'byggeløyva': ('byggeløyve',),
'byggeløyve': ('byggeløyve',),
'byggeløyvene': ('byggeløyve',),
'byggeløyver': ('byggeløyve',),
'byggeløyvet': ('byggeløyve',),
'byggemelding': ('byggemelding',),
'byggemeldinga': ('byggemelding',),
'byggemeldingen': ('byggemelding',),
'byggemeldingene': ('byggemelding',),
'byggemeldinger': ('byggemelding',),
'byggemåte': ('byggemåte',),
'byggemåten': ('byggemåte',),
'byggemåtene': ('byggemåte',),
'byggemåter': ('byggemåte',),
'byggenemnd': ('byggenemnd',),
'byggenemnda': ('byggenemnd',),
'byggenemnden': ('byggenemnd',),
'byggenemndene': ('byggenemnd',),
'byggenemnder': ('byggenemnd',),
'byggenummer': ('byggenummer',),
'byggenummeret': ('byggenummer',),
'byggenumra': ('byggenummer',),
'byggenumre': ('byggenummer',),
'byggenumrene': ('byggenummer',),
'bygger': ('bygger',),
'byggere': ('bygger',),
'byggeren': ('bygger',),
'byggerer': ('bygger',),
'byggerne': ('bygger',),
'byggesamtykka': ('byggesamtykke',),
'byggesamtykke': ('byggesamtykke',),
'byggesamtykkene': ('byggesamtykke',),
'byggesamtykker': ('byggesamtykke',),
'byggesamtykket': ('byggesamtykke',),
'byggesett': ('byggesett',),
'byggesetta': ('byggesett',),
'byggesettene': ('byggesett',),
'byggesettet': ('byggesett',),
'byggeskikk': ('byggeskikk',),
'byggeskikken': ('byggeskikk',),
'byggeskikkene': ('byggeskikk',),
'byggeskikker': ('byggeskikk',),
'byggesona': ('byggesone',),
'byggesone': ('byggesone',),
'byggesonen': ('byggesone',),
'byggesonene': ('byggesone',),
'byggesoner': ('byggesone',),
'byggestein': ('byggestein',),
'byggesteinen': ('byggestein',),
'byggesteinene': ('byggestein',),
'byggesteiner': ('byggestein',),
'byggetid': ('byggetid',),
'byggetida': ('byggetid',),
'byggetiden': ('byggetid',),
'byggetidene': ('byggetid',),
'byggetider': ('byggetid',),
'byggetillatelse': ('byggetillatelse',),
'byggetillatelsen': ('byggetillatelse',),
'byggetillatelsene': ('byggetillatelse',),
'byggetillatelser': ('byggetillatelse',),
'byggetomt': ('byggetomt',),
'byggetomta': ('byggetomt',),
'byggetomten': ('byggetomt',),
'byggetomtene': ('byggetomt',),
'byggetomter': ('byggetomt',),
'byggetrinn': ('byggetrinn',),
'byggetrinna': ('byggetrinn',),
'byggetrinnene': ('byggetrinn',),
'byggetrinnet': ('byggetrinn',),
'byggevara': ('byggevare',),
'byggevare': ('byggevare',),
'byggevaren': ('byggevare',),
'byggevarene': ('byggevare',),
'byggevarer': ('byggevare',),
'byggevirksomhet': ('byggevirksomhet',),
'byggevirksomheta': ('byggevirksomhet',),
'byggevirksomheten': ('byggevirksomhet',),
'byggevirksomhetene': ('byggevirksomhet',),
'byggevirksomheter': ('byggevirksomhet',),
'byggherre': ('byggherre',),
'byggherren': ('byggherre',),
'byggherrene': ('byggherre',),
'byggherrer': ('byggherre',),
'bygging': ('bygging',),
'bygginga': ('bygging',),
'byggingen': ('bygging',),
'byggingene': ('bygging',),
'bygginger': ('bygging',),
'byggkorn': ('byggkorn',),
'byggkorna': ('byggkorn',),
'byggkornene': ('byggkorn',),
'byggkornet': ('byggkorn',),
'byggmel': ('byggmel',),
'byggmela': ('byggmel',),
'byggmelene': ('byggmel',),
'byggmelet': ('byggmel',),
'byggmester': ('byggmester',),
'byggmestere': ('byggmester',),
'byggmesteren': ('byggmester',),
'byggmesterer': ('byggmester',),
'byggmesterne': ('byggmester',),
'byggmestre': ('byggmester',),
'byggmestrene': ('byggmester',),
'byggmestrer': ('byggmester',),
'byggmjøl': ('byggmjøl',),
'byggmjøla': ('byggmjøl',),
'byggmjølene': ('byggmjøl',),
'byggmjølet': ('byggmjøl',),
'byggryn': ('byggryn',),
'byggryna': ('byggryn',),
'byggrynene': ('byggryn',),
'byggrynet': ('byggryn',),
'byggsuppa': ('byggsuppe',),
'byggsuppe': ('byggsuppe',),
'byggsuppen': ('byggsuppe',),
'byggsuppene': ('byggsuppe',),
'byggsupper': ('byggsuppe',),
'byggverk': ('byggverk',),
'byggverka': ('byggverk',),
'byggverkene': ('byggverk',),
'byggverker': ('byggverk',),
'byggverket': ('byggverk',),
'bygning': ('bygning',),
'bygninga': ('bygning',),
'bygningen': ('bygning',),
'bygningene': ('bygning',),
'bygninger': ('bygning',),
'bygningsarbeider': ('bygningsarbeider',),
'bygningsarbeidere': ('bygningsarbeider',),
'bygningsarbeideren': ('bygningsarbeider',),
'bygningsarbeiderer': ('bygningsarbeider',),
'bygningsarbeiderne': ('bygningsarbeider',),
'bygningsartikkel': ('bygningsartikkel',),
'bygningsartikkelen': ('bygningsartikkel',),
'bygningsartiklene': ('bygningsartikkel',),
'bygningsartikler': ('bygningsartikkel',),
'bygningsattest': ('bygningsattest',),
'bygningsattesten': ('bygningsattest',),
'bygningsattestene': ('bygningsattest',),
'bygningsattester': ('bygningsattest',),
'bygningsdel': ('bygningsdel',),
'bygningsdelen': ('bygningsdel',),
'bygningsdelene': ('bygningsdel',),
'bygningsdeler': ('bygningsdel',),
'bygningsindustri': ('bygningsindustri',),
'bygningsindustrien': ('bygningsindustri',),
'bygningsindustriene': ('bygningsindustri',),
'bygningsindustrier': ('bygningsindustri',),
'bygningskontroll': ('bygningskontroll',),
'bygningskontrollen': ('bygningskontroll',),
'bygningskontrollene': ('bygningskontroll',),
'bygningskontroller': ('bygningskontroll',),
'bygningslov': ('bygningslov',),
'bygningsloven': ('bygningslov',),
'bygningslovene': ('bygningslov',),
'bygningslover': ('bygningslov',),
'bygningsnemnd': ('bygningsnemnd',),
'bygningsnemnda': ('bygningsnemnd',),
'bygningsnemnden': ('bygningsnemnd',),
'bygningsnemndene': ('bygningsnemnd',),
'bygningsnemnder': ('bygningsnemnd',),
'bygningspapp': ('bygningspapp',),
'bygningspappen': ('bygningspapp',),
'bygningspappene': ('bygningspapp',),
'bygningspapper': ('bygningspapp',),
'bygningsråd': ('bygningsråd',),
'bygningsråda': ('bygningsråd',),
'bygningsrådene': ('bygningsråd',),
'bygningsrådet': ('bygningsråd',),
'bygningssjef': ('bygningssjef',),
'bygningssjefen': ('bygningssjef',),
'bygningssjefene': ('bygningssjef',),
'bygningssjefer': ('bygningssjef',),
'bygningssnekker': ('bygningssnekker',),
'bygningssnekkere': ('bygningssnekker',),
'bygningssnekkeren': ('bygningssnekker',),
'bygningssnekkerer': ('bygningssnekker',),
'bygningssnekkerne': ('bygningssnekker',),
'bygningsvedtekt': ('bygningsvedtekt',),
'bygningsvedtekta': ('bygningsvedtekt',),
'bygningsvedtekten': ('bygningsvedtekt',),
'bygningsvedtektene': ('bygningsvedtekt',),
'bygningsvedtekter': ('bygningsvedtekt',),
'bygsel': ('bygsel',),
'bygselen': ('bygsel',),
'bygsla': ('bygsel',),
'bygslene': ('bygsel',),
'bygsler': ('bygsel',),
'bygselbrev': ('bygselbrev',),
'bygselbreva': ('bygselbrev',),
'bygselbrevene': ('bygselbrev',),
'bygselbrever': ('bygselbrev',),
'bygselbrevet': ('bygselbrev',),
'bygselrett': ('bygselrett',),
'bygselretten': ('bygselrett',),
'bygselrettene': ('bygselrett',),
'bygselretter': ('bygselrett',),
'bygård': ('bygård',),
'bygården': ('bygård',),
'bygårdene': ('bygård',),
'bygårder': ('bygård',),
'bykjerne': ('bykjerne',),
'bykjernen': ('bykjerne',),
'bykjernene': ('bykjerne',),
'bykjerner': ('bykjerne',),
'bykommune': ('bykommune',),
'bykommunen': ('bykommune',),
'bykommunene': ('bykommune',),
'bykommuner': ('bykommune',),
'byks': ('byks',),
'byksa': ('byks',),
'byksene': ('byks',),
'bykset': ('byks',),
'bykultur': ('bykultur',),
'bykulturen': ('bykultur',),
'bykulturene': ('bykultur',),
'bykulturer': ('bykultur',),
'byliv': ('byliv',),
'byliva': ('byliv',),
'bylivene': ('byliv',),
'bylivet': ('byliv',),
'byll': ('byll',),
'byllen': ('byll',),
'byllene': ('byll',),
'byller': ('byll',),
'byllepest': ('byllepest',),
'byllepesta': ('byllepest',),
'byllepesten': ('byllepest',),
'byllepestene': ('byllepest',),
'byllepester': ('byllepest',),
'bylt': ('bylt',),
'bylten': ('bylt',),
'byltene': ('bylt',),
'bylter': ('bylt',),
'bymenneska': ('bymenneske',),
'bymenneske': ('bymenneske',),
'bymenneskene': ('bymenneske',),
'bymennesker': ('bymenneske',),
'bymennesket': ('bymenneske',),
'bymiljø': ('bymiljø',),
'bymiljøa': ('bymiljø',),
'bymiljøene': ('bymiljø',),
'bymiljøer': ('bymiljø',),
'bymiljøet': ('bymiljø',),
'bymur': ('bymur',),
'bymuren': ('bymur',),
'bymurene': ('bymur',),
'bymurer': ('bymur',),
'bymål': ('bymål',),
'bymåla': ('bymål',),
'bymålene': ('bymål',),
'bymålet': ('bymål',),
'byoriginal': ('byoriginal',),
'byoriginalen': ('byoriginal',),
'byoriginalene': ('byoriginal',),
'byoriginaler': ('byoriginal',),
'byplan': ('byplan',),
'byplanen': ('byplan',),
'byplanene': ('byplan',),
'byplaner': ('byplan',),
'byplanlegging': ('byplanlegging',),
'byplanlegginga': ('byplanlegging',),
'byplanleggingen': ('byplanlegging',),
'byplanleggingene': ('byplanlegging',),
'byplanlegginger': ('byplanlegging',),
'byplanråd': ('byplanråd',),
'byplanråda': ('byplanråd',),
'byplanrådene': ('byplanråd',),
'byplanrådet': ('byplanråd',),
'byport': ('byport',),
'byporten': ('byport',),
'byportene': ('byport',),
'byporter': ('byport',),
'byrd': ('byrd',),
'byrden': ('byrd',),
'byrdene': ('byrd',),
'byrder': ('byrd',),
'byrde': ('byrde',),
'byrden': ('byrde',),
'byrdene': ('byrde',),
'byrder': ('byrde',),
'byrett': ('byrett',),
'byretten': ('byrett',),
'byrettene': ('byrett',),
'byretter': ('byrett',),
'byrette': ('byrette',),
'byretten': ('byrette',),
'byrettene': ('byrette',),
'byretter': ('byrette',),
'byrettsdom': ('byrettsdom',),
'byrettsdommen': ('byrettsdom',),
'byrettsdommene': ('byrettsdom',),
'byrettsdommer': ('byrettsdom',),
'byrettsdommer': ('byrettsdommer',),
'byrettsdommere': ('byrettsdommer',),
'byrettsdommeren': ('byrettsdommer',),
'byrettsdommerer': ('byrettsdommer',),
'byrettsdommerne': ('byrettsdommer',),
'byrettsjustitiarien': ('byrettsjustitiarius',),
'byrettsjustitiariene': ('byrettsjustitiarius',),
'byrettsjustitiarier': ('byrettsjustitiarius',),
'byrettsjustitiarius': ('byrettsjustitiarius',),
'byrå': ('byrå',),
'byråa': ('byrå',),
'byråene': ('byrå',),
'byråer': ('byrå',),
'byrået': ('byrå',),
'byråd': ('byråd',),
'byråden': ('byråd',),
'byrådene': ('byråd',),
'byråder': ('byråd',),
'byråd': ('byråd',),
'byråda': ('byråd',),
'byrådene': ('byråd',),
'byrådet': ('byråd',),
'byrådsleder': ('byrådsleder',),
'byrådsledere': ('byrådsleder',),
'byrådslederen': ('byrådsleder',),
'byrådslederer': ('byrådsleder',),
'byrådslederne': ('byrådsleder',),
'byråkrat': ('byråkrat',),
'byråkraten': ('byråkrat',),
'byråkratene': ('byråkrat',),
'byråkrater': ('byråkrat',),
'byråkrati': ('byråkrati',),
'byråkratia': ('byråkrati',),
'byråkratiene': ('byråkrati',),
'byråkratier': ('byråkrati',),
'byråkratiet': ('byråkrati',),
'byråsjef': ('byråsjef',),
'byråsjefen': ('byråsjef',),
'byråsjefene': ('byråsjef',),
'byråsjefer': ('byråsjef',),
'byråsjefsstilling': ('byråsjefsstilling',),
'byråsjefsstillinga': ('byråsjefsstilling',),
'byråsjefsstillingen': ('byråsjefsstilling',),
'byråsjefsstillingene': ('byråsjefsstilling',),
'byråsjefsstillinger': ('byråsjefsstilling',),
'byråsjefstilling': ('byråsjefstilling',),
'byråsjefstillinga': ('byråsjefstilling',),
'byråsjefstillingen': ('byråsjefstilling',),
'byråsjefstillingene': ('byråsjefstilling',),
'byråsjefstillinger': ('byråsjefstilling',),
'bysantiner': ('bysantiner',),
'bysantinere': ('bysantiner',),
'bysantineren': ('bysantiner',),
'bysantinerer': ('bysantiner',),
'bysantinerne': ('bysantiner',),
'bysbarn': ('bysbarn',),
'bysbarna': ('bysbarn',),
'bysbarnene': ('bysbarn',),
'bysbarnet': ('bysbarn',),
'byskriver': ('byskriver',),
'byskrivere': ('byskriver',),
'byskriveren': ('byskriver',),
'byskriverer': ('byskriver',),
'byskriverne': ('byskriver',),
'byssa': ('bysse',),
'bysse': ('bysse',),
'byssen': ('bysse',),
'byssene': ('bysse',),
'bysser': ('bysse',),
'byssegutt': ('byssegutt',),
'byssegutten': ('byssegutt',),
'bysseguttene': ('byssegutt',),
'byssegutter': ('byssegutt',),
'byssejenta': ('byssejente',),
'byssejente': ('byssejente',),
'byssejenten': ('byssejente',),
'byssejentene': ('byssejente',),
'byssejenter': ('byssejente',),
'byssetjeneste': ('byssetjeneste',),
'byssetjenesten': ('byssetjeneste',),
'byssetjenestene': ('byssetjeneste',),
'byssetjenester': ('byssetjeneste',),
'bysta': ('byste',),
'byste': ('byste',),
'bysten': ('byste',),
'bystene': ('byste',),
'byster': ('byste',),
'bysteholder': ('bysteholder',),
'bysteholdere': ('bysteholder',),
'bysteholderen': ('bysteholder',),
'bysteholderer': ('bysteholder',),
'bysteholderne': ('bysteholder',),
'bystyra': ('bystyre',),
'bystyre': ('bystyre',),
'bystyrene': ('bystyre',),
'bystyrer': ('bystyre',),
'bystyret': ('bystyre',),
'bystyremedlem': ('bystyremedlem',),
'bystyremedlemma': ('bystyremedlem',),
'bystyremedlemmene': ('bystyremedlem',),
'bystyremedlemmer': ('bystyremedlem',),
'bystyremedlemmet': ('bystyremedlem',),
'bystyrevalg': ('bystyrevalg',),
'bystyrevalga': ('bystyrevalg',),
'bystyrevalgene': ('bystyrevalg',),
'bystyrevalget': ('bystyrevalg',),
'bystyrevedtak': ('bystyrevedtak',),
'bystyrevedtaka': ('bystyrevedtak',),
'bystyrevedtakene': ('bystyrevedtak',),
'bystyrevedtaket': ('bystyrevedtak',),
'byte': ('byte',),
'byten': ('byte',),
'bytene': ('byte',),
'bytta': ('bytte',),
'bytte': ('bytte',),
'byttene': ('bytte',),
'bytter': ('bytte',),
'byttet': ('bytte',),
'byttearbeid': ('byttearbeid',),
'byttearbeida': ('byttearbeid',),
'byttearbeidene': ('byttearbeid',),
'byttearbeider': ('byttearbeid',),
'byttearbeidet': ('byttearbeid',),
'byttegjenstand': ('byttegjenstand',),
'byttegjenstanden': ('byttegjenstand',),
'byttegjenstandene': ('byttegjenstand',),
'byttegjenstander': ('byttegjenstand',),
'byttehandel': ('byttehandel',),
'byttehandelen': ('byttehandel',),
'byttehandlene': ('byttehandel',),
'byttehandler': ('byttehandel',),
'byttehusholdning': ('byttehusholdning',),
'byttehusholdninga': ('byttehusholdning',),
'byttehusholdningen': ('byttehusholdning',),
'byttehusholdningene': ('byttehusholdning',),
'byttehusholdninger': ('byttehusholdning',),
'byttemiddel': ('byttemiddel',),
'byttemiddelet': ('byttemiddel',),
'byttemidla': ('byttemiddel',),
'byttemidlene': ('byttemiddel',),
'byttemidler': ('byttemiddel',),
'byttemidlet': ('byttemiddel',),
'bytting': ('bytting',),
'byttingen': ('bytting',),
'byttingene': ('bytting',),
'byttinger': ('bytting',),
'byvekt': ('byvekt',),
'byvekta': ('byvekt',),
'byvekten': ('byvekt',),
'byvektene': ('byvekt',),
'byvekter': ('byvekt',),
'byvåpen': ('byvåpen',),
'byvåpenet': ('byvåpen',),
'byvåpna': ('byvåpen',),
'byvåpnene': ('byvåpen',),
'båe': ('båe',),
'båen': ('båe',),
'båene': ('båe',),
'båer': ('båe',),
'båk': ('båk',),
'båken': ('båk',),
'båkene': ('båk',),
'båker': ('båk',),
'båke': ('båke',),
'båken': ('båke',),
'båkene': ('båke',),
'båker': ('båke',),
'bål': ('bål',),
'båla': ('bål',),
'bålene': ('bål',),
'bålet': ('bål',),
'båle': ('båle',),
'bålen': ('båle',),
'bålene': ('båle',),
'båler': ('båle',),
'bålferd': ('bålferd',),
'bålferda': ('bålferd',),
'bålferden': ('bålferd',),
'bålferdene': ('bålferd',),
'bålferder': ('bålferd',),
'bånd': ('bånd',),
'bånda': ('bånd',),
'båndene': ('bånd',),
'båndet': ('bånd',),
'båndby': ('båndby',),
'båndbyen': ('båndby',),
'båndbyene': ('båndby',),
'båndbyer': ('båndby',),
'båndjern': ('båndjern',),
'båndjerna': ('båndjern',),
'båndjernene': ('båndjern',),
'båndjernet': ('båndjern',),
'båndkniv': ('båndkniv',),
'båndkniven': ('båndkniv',),
'båndknivene': ('båndkniv',),
'båndkniver': ('båndkniv',),
'båndopptaker': ('båndopptaker',),
'båndopptakere': ('båndopptaker',),
'båndopptakeren': ('båndopptaker',),
'båndopptakerer': ('båndopptaker',),
'båndopptakerne': ('båndopptaker',),
'båndsalat': ('båndsalat',),
'båndsalaten': ('båndsalat',),
'båndsalatene': ('båndsalat',),
'båndsalater': ('båndsalat',),
'båndspeller': ('båndspeller',),
'båndspellere': ('båndspeller',),
'båndspelleren': ('båndspeller',),
'båndspellerer': ('båndspeller',),
'båndspellerne': ('båndspeller',),
'båndspiller': ('båndspiller',),
'båndspillere': ('båndspiller',),
'båndspilleren': ('båndspiller',),
'båndspillerer': ('båndspiller',),
'båndspillerne': ('båndspiller',),
'båndstål': ('båndstål',),
'båndståla': ('båndstål',),
'båndstålene': ('båndstål',),
'båndstålet': ('båndstål',),
'båndtvang': ('båndtvang',),
'båndtvangen': ('båndtvang',),
'båndtvangene': ('båndtvang',),
'båndtvanger': ('båndtvang',),
'bånsull': ('bånsull',),
'bånsullen': ('bånsull',),
'bånsullene': ('bånsull',),
'bånsuller': ('bånsull',),
'bår': ('bår',),
'båra': ('bår',),
'båren': ('bår',),
'bårene': ('bår',),
'bårer': ('bår',),
'båra': ('båre',),
'båre': ('båre',),
'båren': ('båre',),
'bårene': ('båre',),
'bårer': ('båre',),
'båra': ('båre',),
'båre': ('båre',),
'båren': ('båre',),
'bårene': ('båre',),
'bårer': ('båre',),
'bårerom': ('bårerom',),
'båreromma': ('bårerom',),
'bårerommene': ('bårerom',),
'bårerommet': ('bårerom',),
'bås': ('bås',),
'båsen': ('bås',),
'båsene': ('bås',),
'båser': ('bås',),
'båsfjøs': ('båsfjøs',),
'båsfjøsa': ('båsfjøs',),
'båsfjøsen': ('båsfjøs',),
'båsfjøsene': ('båsfjøs',),
'båsfjøset': ('båsfjøs',),
'båt': ('båt',),
'båten': ('båt',),
'båtene': ('båt',),
'båter': ('båt',),
'båtbygger': ('båtbygger',),
'båtbyggere': ('båtbygger',),
'båtbyggeren': ('båtbygger',),
'båtbyggerer': ('båtbygger',),
'båtbyggerne': ('båtbygger',),
'båtbyggeri': ('båtbyggeri',),
'båtbyggeria': ('båtbyggeri',),
'båtbyggeriene': ('båtbyggeri',),
'båtbyggerier': ('båtbyggeri',),
'båtbyggeriet': ('båtbyggeri',),
'båtdekk': ('båtdekk',),
'båtdekka': ('båtdekk',),
'båtdekkene': ('båtdekk',),
'båtdekket': ('båtdekk',),
'båtfører': ('båtfører',),
'båtførere': ('båtfører',),
'båtføreren': ('båtfører',),
'båtførerer': ('båtfører',),
'båtførerne': ('båtfører',),
'båtførerbevis': ('båtførerbevis',),
'båtførerbevisa': ('båtførerbevis',),
'båtførerbevisene': ('båtførerbevis',),
'båtførerbeviser': ('båtførerbevis',),
'båtførerbeviset': ('båtførerbevis',),
'båthua': ('båthue',),
'båthue': ('båthue',),
'båthuen': ('båthue',),
'båthuene': ('båthue',),
'båthuer': ('båthue',),
'båthuva': ('båthuve',),
'båthuve': ('båthuve',),
'båthuven': ('båthuve',),
'båthuvene': ('båthuve',),
'båthuver': ('båthuve',),
'båthvelv': ('båthvelv',),
'båthvelva': ('båthvelv',),
'båthvelvene': ('båthvelv',),
'båthvelvet': ('båthvelv',),
'båtkvelv': ('båtkvelv',),
'båtkvelva': ('båtkvelv',),
'båtkvelven': ('båtkvelv',),
'båtkvelvene': ('båtkvelv',),
'båtkvelver': ('båtkvelv',),
'båtkvelvet': ('båtkvelv',),
'båtlengd': ('båtlengd',),
'båtlengda': ('båtlengd',),
'båtlengden': ('båtlengd',),
'båtlengdene': ('båtlengd',),
'båtlengder': ('båtlengd',),
'båtlengda': ('båtlengde',),
'båtlengde': ('båtlengde',),
'båtlengden': ('båtlengde',),
'båtlengdene': ('båtlengde',),
'båtlengder': ('båtlengde',),
'båtlua': ('båtlue',),
'båtlue': ('båtlue',),
'båtluen': ('båtlue',),
'båtluene': ('båtlue',),
'båtluer': ('båtlue',),
'båtluva': ('båtluve',),
'båtluve': ('båtluve',),
'båtluven': ('båtluve',),
'båtluvene': ('båtluve',),
'båtluver': ('båtluve',),
'båtmannskap': ('båtmannskap',),
'båtmannskapa': ('båtmannskap',),
'båtmannskapene': ('båtmannskap',),
'båtmannskaper': ('båtmannskap',),
'båtmannskapet': ('båtmannskap',),
'båtmotor': ('båtmotor',),
'båtmotoren': ('båtmotor',),
'båtmotorene': ('båtmotor',),
'båtmotorer': ('båtmotor',),
'båtnaust': ('båtnaust',),
'båtnausta': ('båtnaust',),
'båtnaustene': ('båtnaust',),
'båtnaustet': ('båtnaust',),
'båtrip': ('båtrip',),
'båtripa': ('båtrip',),
'båtripen': ('båtrip',),
'båtripene': ('båtrip',),
'båtriper': ('båtrip',),
'båtripa': ('båtripe',),
'båtripe': ('båtripe',),
'båtripen': ('båtripe',),
'båtripene': ('båtripe',),
'båtriper': ('båtripe',),
'båtruta': ('båtrute',),
'båtrute': ('båtrute',),
'båtruten': ('båtrute',),
'båtrutene': ('båtrute',),
'båtruter': ('båtrute',),
'båtshake': ('båtshake',),
'båtshaken': ('båtshake',),
'båtshakene': ('båtshake',),
'båtshaker': ('båtshake',),
'båtsmann': ('båtsmann',),
'båtsmannen': ('båtsmann',),
'båtsmenn': ('båtsmann',),
'båtsmennene': ('båtsmann',),
'båtsmannsknop': ('båtsmannsknop',),
'båtsmannsknopen': ('båtsmannsknop',),
'båtsmannsknopene': ('båtsmannsknop',),
'båtsmannsknoper': ('båtsmannsknop',),
'båtsmannsstol': ('båtsmannsstol',),
'båtsmannsstolen': ('båtsmannsstol',),
'båtsmannsstolene': ('båtsmannsstol',),
'båtsmannsstoler': ('båtsmannsstol',),
'båtstø': ('båtstø',),
'båtstøa': ('båtstø',),
'båtstøen': ('båtstø',),
'båtstøene': ('båtstø',),
'båtstøer': ('båtstø',),
'båttur': ('båttur',),
'båtturen': ('båttur',),
'båtturene': ('båttur',),
'båtturer': ('båttur',),
'båtvett': ('båtvett',),
'båtvetta': ('båtvett',),
'båtvettene': ('båtvett',),
'båtvettet': ('båtvett',),
'bæ': ('bæ',),
'bæa': ('bæ',),
'bæene': ('bæ',),
'bæet': ('bæ',),
'bær': ('bær',),
'bæra': ('bær',),
'bærene': ('bær',),
'bæret': ('bær',),
'bærbusk': ('bærbusk',),
'bærbusken': ('bærbusk',),
'bærbuskene': ('bærbusk',),
'bærbusker': ('bærbusk',),
'bærdyrking': ('bærdyrking',),
'bærdyrkinga': ('bærdyrking',),
'bærdyrkingen': ('bærdyrking',),
'bærdyrkingene': ('bærdyrking',),
'bærdyrkinger': ('bærdyrking',),
'bærebjelke': ('bærebjelke',),
'bærebjelken': ('bærebjelke',),
'bærebjelkene': ('bærebjelke',),
'bærebjelker': ('bærebjelke',),
'bærebølga': ('bærebølge',),
'bærebølge': ('bærebølge',),
'bærebølgen': ('bærebølge',),
'bærebølgene': ('bærebølge',),
'bærebølger': ('bærebølge',),
'bærebølgja': ('bærebølgje',),
'bærebølgje': ('bærebølgje',),
'bærebølgjen': ('bærebølgje',),
'bærebølgjene': ('bærebølgje',),
'bærebølgjer': ('bærebølgje',),
'bæreevna': ('bæreevne',),
'bæreevne': ('bæreevne',),
'bæreevnen': ('bæreevne',),
'bæreevnene': ('bæreevne',),
'bæreevner': ('bæreevne',),
'bæreplanbåt': ('bæreplanbåt',),
'bæreplanbåten': ('bæreplanbåt',),
'bæreplanbåtene': ('bæreplanbåt',),
'bæreplanbåter': ('bæreplanbåt',),
'bærepose': ('bærepose',),
'bæreposen': ('bærepose',),
'bæreposene': ('bærepose',),
'bæreposer': ('bærepose',),
'bærer': ('bærer',),
'bærere': ('bærer',),
'bæreren': ('bærer',),
'bærerer': ('bærer',),
'bærerne': ('bærer',),
'bærerakett': ('bærerakett',),
'bæreraketten': ('bærerakett',),
'bærerakettene': ('bærerakett',),
'bæreraketter': ('bærerakett',),
'bærestol': ('bærestol',),
'bærestolen': ('bærestol',),
'bærestolene': ('bærestol',),
'bærestoler': ('bærestol',),
'bærestykka': ('bærestykke',),
'bærestykke': ('bærestykke',),
'bærestykkene': ('bærestykke',),
'bærestykker': ('bærestykke',),
'bærestykket': ('bærestykke',),
'bærevegg': ('bærevegg',),
'bæreveggen': ('bærevegg',),
'bæreveggene': ('bærevegg',),
'bærevegger': ('bærevegg',),
'bærhøst': ('bærhøst',),
'bærhøsten': ('bærhøst',),
'bærhøstene': ('bærhøst',),
'bærhøster': ('bærhøst',),
'bærlyng': ('bærlyng',),
'bærlynga': ('bærlyng',),
'bærlyngen': ('bærlyng',),
'bærlyngene': ('bærlyng',),
'bærlynger': ('bærlyng',),
'bærlynget': ('bærlyng',),
'bærplukker': ('bærplukker',),
'bærplukkere': ('bærplukker',),
'bærplukkeren': ('bærplukker',),
'bærplukkerer': ('bærplukker',),
'bærplukkerne': ('bærplukker',),
'bærtua': ('bærtue',),
'bærtue': ('bærtue',),
'bærtuen': ('bærtue',),
'bærtuene': ('bærtue',),
'bærtuer': ('bærtue',),
'bærtur': ('bærtur',),
'bærturen': ('bærtur',),
'bærturene': ('bærtur',),
'bærturer': ('bærtur',),
'bærtuva': ('bærtuve',),
'bærtuve': ('bærtuve',),
'bærtuven': ('bærtuve',),
'bærtuvene': ('bærtuve',),
'bærtuver': ('bærtuve',),
'bæsj': ('bæsj',),
'bæsjen': ('bæsj',),
'bæsjene': ('bæsj',),
'bæsjer': ('bæsj',),
'bø': ('bø',),
'bøen': ('bø',),
'bøene': ('bø',),
'bøer': ('bø',),
'bø': ('bø',),
'bøa': ('bø',),
'bøene': ('bø',),
'bøet': ('bø',),
'bøddel': ('bøddel',),
'bøddelen': ('bøddel',),
'bødlene': ('bøddel',),
'bødler': ('bøddel',),
'bøddelgjerning': ('bøddelgjerning',),
'bøddelgjerninga': ('bøddelgjerning',),
'bøddelgjerningen': ('bøddelgjerning',),
'bøddelgjerningene': ('bøddelgjerning',),
'bøddelgjerninger': ('bøddelgjerning',),
'bøddeløks': ('bøddeløks',),
'bøddeløksa': ('bøddeløks',),
'bøddeløksen': ('bøddeløks',),
'bøddeløksene': ('bøddeløks',),
'bøddeløkser': ('bøddeløks',),
'bøffel': ('bøffel',),
'bøffelen': ('bøffel',),
'bøflene': ('bøffel',),
'bøfler': ('bøffel',),
'bøffelgras': ('bøffelgras',),
'bøffelgrasa': ('bøffelgras',),
'bøffelgrasene': ('bøffelgras',),
'bøffelgraset': ('bøffelgras',),
'bøffelgress': ('bøffelgress',),
'bøffelgressa': ('bøffelgress',),
'bøffelgressene': ('bøffelgress',),
'bøffelgresset': ('bøffelgress',),
'bøffelku': ('bøffelku',),
'bøffelkua': ('bøffelku',),
'bøffelkuen': ('bøffelku',),
'bøffelkuene': ('bøffelku',),
'bøffelkuer': ('bøffelku',),
'bøffelkyr': ('bøffelku',),
'bøffelkyrne': ('bøffelku',),
'bøffellær': ('bøffellær',),
'bøffellæra': ('bøffellær',),
'bøffellærene': ('bøffellær',),
'bøffellæret': ('bøffellær',),
'bøffelokse': ('bøffelokse',),
'bøffeloksen': ('bøffelokse',),
'bøffeloksene': ('bøffelokse',),
'bøffelokser': ('bøffelokse',),
'bøhmer': ('bøhmer',),
'bøhmere': ('bøhmer',),
'bøhmeren': ('bøhmer',),
'bøhmerer': ('bøhmer',),
'bøhmerne': ('bøhmer',),
'bøk': ('bøk',),
'bøken': ('bøk',),
'bøkene': ('bøk',),
'bøker': ('bøk',),
'bøkelauv': ('bøkelauv',),
'bøkelauva': ('bøkelauv',),
'bøkelauvene': ('bøkelauv',),
'bøkelauvet': ('bøkelauv',),
'bøkeløv': ('bøkeløv',),
'bøkeløva': ('bøkeløv',),
'bøkeløvene': ('bøkeløv',),
'bøkeløvet': ('bøkeløv',),
'bøkenøtt': ('bøkenøtt',),
'bøkenøtta': ('bøkenøtt',),
'bøkenøtten': ('bøkenøtt',),
'bøkenøttene': ('bøkenøtt',),
'bøkenøtter': ('bøkenøtt',),
'bøkeskog': ('bøkeskog',),
'bøkeskogen': ('bøkeskog',),
'bøkeskogene': ('bøkeskog',),
'bøkeskoger': ('bøkeskog',),
'bøkker': ('bøkker',),
'bøkkere': ('bøkker',),
'bøkkeren': ('bøkker',),
'bøkkerer': ('bøkker',),
'bøkkerne': ('bøkker',),
'bøkkerhandverk': ('bøkkerhandverk',),
'bøkkerhandverka': ('bøkkerhandverk',),
'bøkkerhandverkene': ('bøkkerhandverk',),
'bøkkerhandverket': ('bøkkerhandverk',),
'bøkkerhåndverk': ('bøkkerhåndverk',),
'bøkkerhåndverka': ('bøkkerhåndverk',),
'bøkkerhåndverkene': ('bøkkerhåndverk',),
'bøkkerhåndverket': ('bøkkerhåndverk',),
'bøkling': ('bøkling',),
'bøklingen': ('bøkling',),
'bøklingene': ('bøkling',),
'bøklinger': ('bøkling',),
'bøla': ('bøle',),
'bøle': ('bøle',),
'bølene': ('bøle',),
'bøler': ('bøle',),
'bølet': ('bøle',),
'bøla': ('bøle',),
'bøle': ('bøle',),
'bølen': ('bøle',),
'bølene': ('bøle',),
'bøler': ('bøle',),
'bølga': ('bølge',),
'bølge': ('bølge',),
'bølgen': ('bølge',),
'bølgene': ('bølge',),
'bølger': ('bølge',),
'bølgebevegelse': ('bølgebevegelse',),
'bølgebevegelsen': ('bølgebevegelse',),
'bølgebevegelsene': ('bølgebevegelse',),
'bølgebevegelser': ('bølgebevegelse',),
'bølgeblekk': ('bølgeblekk',),
'bølgeblekka': ('bølgeblekk',),
'bølgeblekkene': ('bølgeblekk',),
'bølgeblekket': ('bølgeblekk',),
'bølgeblekkplata': ('bølgeblekkplate',),
'bølgeblekkplate': ('bølgeblekkplate',),
'bølgeblekkplaten': ('bølgeblekkplate',),
'bølgeblekkplatene': ('bølgeblekkplate',),
'bølgeblekkplater': ('bølgeblekkplate',),
'bølgeblikk': ('bølgeblikk',),
'bølgeblikka': ('bølgeblikk',),
'bølgeblikkene': ('bølgeblikk',),
'bølgeblikket': ('bølgeblikk',),
'bølgeblikkplata': ('bølgeblikkplate',),
'bølgeblikkplate': ('bølgeblikkplate',),
'bølgeblikkplaten': ('bølgeblikkplate',),
'bølgeblikkplatene': ('bølgeblikkplate',),
'bølgeblikkplater': ('bølgeblikkplate',),
'bølgebryter': ('bølgebryter',),
'bølgebrytere': ('bølgebryter',),
'bølgebryteren': ('bølgebryter',),
'bølgebryterer': ('bølgebryter',),
'bølgebryterne': ('bølgebryter',),
'bølgedal': ('bølgedal',),
'bølgedalen': ('bølgedal',),
'bølgedalene': ('bølgedal',),
'bølgedaler': ('bølgedal',),
'bølgedemper': ('bølgedemper',),
'bølgedempere': ('bølgedemper',),
'bølgedemperen': ('bølgedemper',),
'bølgedemperer': ('bølgedemper',),
'bølgedemperne': ('bølgedemper',),
'bølgeenergi': ('bølgeenergi',),
'bølgeenergien': ('bølgeenergi',),
'bølgeenergiene': ('bølgeenergi',),
'bølgeenergier': ('bølgeenergi',),
'bølgefront': ('bølgefront',),
'bølgefronten': ('bølgefront',),
'bølgefrontene': ('bølgefront',),
'bølgefronter': ('bølgefront',),
'bølgegang': ('bølgegang',),
'bølgegangen': ('bølgegang',),
'bølgegangene': ('bølgegang',),
'bølgeganger': ('bølgegang',),
'bølgekam': ('bølgekam',),
'bølgekammen': ('bølgekam',),
'bølgekammene': ('bølgekam',),
'bølgekammer': ('bølgekam',),
'bølgekraftverk': ('bølgekraftverk',),
'bølgekraftverka': ('bølgekraftverk',),
'bølgekraftverkene': ('bølgekraftverk',),
'bølgekraftverker': ('bølgekraftverk',),
'bølgekraftverket': ('bølgekraftverk',),
'bølgelengda': ('bølgelengde',),
'bølgelengde': ('bølgelengde',),
'bølgelengden': ('bølgelengde',),
'bølgelengdene': ('bølgelengde',),
'bølgelengder': ('bølgelengde',),
'bølgelæra': ('bølgelære',),
'bølgelære': ('bølgelære',),
'bølgelæren': ('bølgelære',),
'bølgelærene': ('bølgelære',),
'bølgelærer': ('bølgelære',),
'bølgepapp': ('bølgepapp',),
'bølgepappen': ('bølgepapp',),
'bølgepappene': ('bølgepapp',),
'bølgepapper': ('bølgepapp',),
'bølgeplata': ('bølgeplate',),
'bølgeplate': ('bølgeplate',),
'bølgeplaten': ('bølgeplate',),
'bølgeplatene': ('bølgeplate',),
'bølgeplater': ('bølgeplate',),
'bølgerygg': ('bølgerygg',),
'bølgeryggen': ('bølgerygg',),
'bølgeryggene': ('bølgerygg',),
'bølgerygger': ('bølgerygg',),
'bølgetopp': ('bølgetopp',),
'bølgetoppen': ('bølgetopp',),
'bølgetoppene': ('bølgetopp',),
'bølgetopper': ('bølgetopp',),
'bølging': ('bølging',),
'bølginga': ('bølging',),
'bølgingen': ('bølging',),
'bølgingene': ('bølging',),
'bølginger': ('bølging',),
'bølgja': ('bølgje',),
'bølgje': ('bølgje',),
'bølgjen': ('bølgje',),
'bølgjene': ('bølgje',),
'bølgjer': ('bølgje',),
'bølgjebevegelse': ('bølgjebevegelse',),
'bølgjebevegelsen': ('bølgjebevegelse',),
'bølgjebevegelsene': ('bølgjebevegelse',),
'bølgjebevegelser': ('bølgjebevegelse',),
'bølgjeblekk': ('bølgjeblekk',),
'bølgjeblekka': ('bølgjeblekk',),
'bølgjeblekkene': ('bølgjeblekk',),
'bølgjeblekket': ('bølgjeblekk',),
'bølgjeblekkplata': ('bølgjeblekkplate',),
'bølgjeblekkplate': ('bølgjeblekkplate',),
'bølgjeblekkplaten': ('bølgjeblekkplate',),
'bølgjeblekkplatene': ('bølgjeblekkplate',),
'bølgjeblekkplater': ('bølgjeblekkplate',),
'bølgjeblikk': ('bølgjeblikk',),
'bølgjeblikka': ('bølgjeblikk',),
'bølgjeblikkene': ('bølgjeblikk',),
'bølgjeblikket': ('bølgjeblikk',),
'bølgjeblikkplata': ('bølgjeblikkplate',),
'bølgjeblikkplate': ('bølgjeblikkplate',),
'bølgjeblikkplaten': ('bølgjeblikkplate',),
'bølgjeblikkplatene': ('bølgjeblikkplate',),
'bølgjeblikkplater': ('bølgjeblikkplate',),
'bølgjebryter': ('bølgjebryter',),
'bølgjebrytere': ('bølgjebryter',),
'bølgjebryteren': ('bølgjebryter',),
'bølgjebryterer': ('bølgjebryter',),
'bølgjebryterne': ('bølgjebryter',),
'bølgjedal': ('bølgjedal',),
'bølgjedalen': ('bølgjedal',),
'bølgjedalene': ('bølgjedal',),
'bølgjedaler': ('bølgjedal',),
'bølgjedemper': ('bølgjedemper',),
'bølgjedempere': ('bølgjedemper',),
'bølgjedemperen': ('bølgjedemper',),
'bølgjedemperer': ('bølgjedemper',),
'bølgjedemperne': ('bølgjedemper',),
'bølgjeenergi': ('bølgjeenergi',),
'bølgjeenergien': ('bølgjeenergi',),
'bølgjeenergiene': ('bølgjeenergi',),
'bølgjeenergier': ('bølgjeenergi',),
'bølgjefront': ('bølgjefront',),
'bølgjefronten': ('bølgjefront',),
'bølgjefrontene': ('bølgjefront',),
'bølgjefronter': ('bølgjefront',),
'bølgjegang': ('bølgjegang',),
'bølgjegangen': ('bølgjegang',),
'bølgjegangene': ('bølgjegang',),
'bølgjeganger': ('bølgjegang',),
'bølgjekam': ('bølgjekam',),
'bølgjekammen': ('bølgjekam',),
'bølgjekammene': ('bølgjekam',),
'bølgjekammer': ('bølgjekam',),
'bølgjekraftverk': ('bølgjekraftverk',),
'bølgjekraftverka': ('bølgjekraftverk',),
'bølgjekraftverkene': ('bølgjekraftverk',),
'bølgjekraftverker': ('bølgjekraftverk',),
'bølgjekraftverket': ('bølgjekraftverk',),
'bølgjelengda': ('bølgjelengde',),
'bølgjelengde': ('bølgjelengde',),
'bølgjelengden': ('bølgjelengde',),
'bølgjelengdene': ('bølgjelengde',),
'bølgjelengder': ('bølgjelengde',),
'bølgjelæra': ('bølgjelære',),
'bølgjelære': ('bølgjelære',),
'bølgjelæren': ('bølgjelære',),
'bølgjelærene': ('bølgjelære',),
'bølgjelærer': ('bølgjelære',),
'bølgjepapp': ('bølgjepapp',),
'bølgjepappen': ('bølgjepapp',),
'bølgjepappene': ('bølgjepapp',),
'bølgjepapper': ('bølgjepapp',),
'bølgjeplata': ('bølgjeplate',),
'bølgjeplate': ('bølgjeplate',),
'bølgjeplaten': ('bølgjeplate',),
'bølgjeplatene': ('bølgjeplate',),
'bølgjeplater': ('bølgjeplate',),
'bølgjerygg': ('bølgjerygg',),
'bølgjeryggen': ('bølgjerygg',),
'bølgjeryggene': ('bølgjerygg',),
'bølgjerygger': ('bølgjerygg',),
'bølgjetopp': ('bølgjetopp',),
'bølgjetoppen': ('bølgjetopp',),
'bølgjetoppene': ('bølgjetopp',),
'bølgjetopper': ('bølgjetopp',),
'bøling': ('bøling',),
'bølingen': ('bøling',),
'bølingene': ('bøling',),
'bølinger': ('bøling',),
'bølla': ('bølle',),
'bølle': ('bølle',),
'bøllen': ('bølle',),
'bøllene': ('bølle',),
'bøller': ('bølle',),
'bøllefrø': ('bøllefrø',),
'bøllefrøa': ('bøllefrø',),
'bøllefrøene': ('bøllefrø',),
'bøllefrøet': ('bøllefrø',),
'bønn': ('bønn',),
'bønna': ('bønn',),
'bønnen': ('bønn',),
'bønnene': ('bønn',),
'bønner': ('bønn',),
'bønna': ('bønne',),
'bønne': ('bønne',),
'bønnen': ('bønne',),
'bønnene': ('bønne',),
'bønner': ('bønne',),
'bønnebok': ('bønnebok',),
'bønneboka': ('bønnebok',),
'bønneboken': ('bønnebok',),
'bønnebøkene': ('bønnebok',),
'bønnebøker': ('bønnebok',),
'bønneformular': ('bønneformular',),
'bønneformulara': ('bønneformular',),
'bønneformularen': ('bønneformular',),
'bønneformularene': ('bønneformular',),
'bønneformularer': ('bønneformular',),
'bønneformularet': ('bønneformular',),
'bønnematta': ('bønnematte',),
'bønnematte': ('bønnematte',),
'bønnematten': ('bønnematte',),
'bønnemattene': ('bønnematte',),
'bønnematter': ('bønnematte',),
'bønnemøta': ('bønnemøte',),
'bønnemøte': ('bønnemøte',),
'bønnemøtene': ('bønnemøte',),
'bønnemøter': ('bønnemøte',),
'bønnemøtet': ('bønnemøte',),
'bønnesamling': ('bønnesamling',),
'bønnesamlinga': ('bønnesamling',),
'bønnesamlingen': ('bønnesamling',),
'bønnesamlingene': ('bønnesamling',),
'bønnesamlinger': ('bønnesamling',),
'bønnestengel': ('bønnestengel',),
'bønnestengelen': ('bønnestengel',),
'bønnestenglene': ('bønnestengel',),
'bønnestengler': ('bønnestengel',),
'bønnesuppa': ('bønnesuppe',),
'bønnesuppe': ('bønnesuppe',),
'bønnesuppen': ('bønnesuppe',),
'bønnesuppene': ('bønnesuppe',),
'bønnesupper': ('bønnesuppe',),
'bønnevikka': ('bønnevikke',),
'bønnevikke': ('bønnevikke',),
'bønnevikken': ('bønnevikke',),
'bønnevikkene': ('bønnevikke',),
'bønnevikker': ('bønnevikke',),
'bønnskrift': ('bønnskrift',),
'bønnskrifta': ('bønnskrift',),
'bønnskriftene': ('bønnskrift',),
'bønnskrifter': ('bønnskrift',),
'bønnskriftet': ('bønnskrift',),
'bør': ('bør',),
'børa': ('bør',),
'børen': ('bør',),
'børene': ('bør',),
'bører': ('bør',),
'børa': ('børe',),
'børe': ('børe',),
'børen': ('børe',),
'børene': ('børe',),
'bører': ('børe',),
'børnskap': ('børnskap',),
'børnskapen': ('børnskap',),
'børnskapene': ('børnskap',),
'børnskaper': ('børnskap',),
'børs': ('børs',),
'børsen': ('børs',),
'børsene': ('børs',),
'børser': ('børs',),
'børsa': ('børse',),
'børse': ('børse',),
'børsen': ('børse',),
'børsene': ('børse',),
'børser': ('børse',),
'børsemaker': ('børsemaker',),
'børsemakere': ('børsemaker',),
'børsemakeren': ('børsemaker',),
'børsemakerer': ('børsemaker',),
'børsemakerne': ('børsemaker',),
'børsemunning': ('børsemunning',),
'børsemunninga': ('børsemunning',),
'børsemunningen': ('børsemunning',),
'børsemunningene': ('børsemunning',),
'børsemunninger': ('børsemunning',),
'børshai': ('børshai',),
'børshaien': ('børshai',),
'børshaiene': ('børshai',),
'børshaier': ('børshai',),
'børskommisær': ('børskommisær',),
'børskommisæren': ('børskommisær',),
'børskommisærene': ('børskommisær',),
'børskommisærer': ('børskommisær',),
'børskrakk': ('børskrakk',),
'børskrakka': ('børskrakk',),
'børskrakkene': ('børskrakk',),
'børskrakket': ('børskrakk',),
'børsmegler': ('børsmegler',),
'børsmeglere': ('børsmegler',),
'børsmegleren': ('børsmegler',),
'børsmeglerer': ('børsmegler',),
'børsmeglerne': ('børsmegler',),
'børsmekler': ('børsmekler',),
'børsmeklere': ('børsmekler',),
'børsmekleren': ('børsmekler',),
'børsmeklerer': ('børsmekler',),
'børsmeklerne': ('børsmekler',),
'børsnotering': ('børsnotering',),
'børsnoteringa': ('børsnotering',),
'børsnoteringen': ('børsnotering',),
'børsnoteringene': ('børsnotering',),
'børsnoteringer': ('børsnotering',),
'børspapir': ('børspapir',),
'børspapira': ('børspapir',),
'børspapirene': ('børspapir',),
'børspapirer': ('børspapir',),
'børspapiret': ('børspapir',),
'børsspekulasjon': ('børsspekulasjon',),
'børsspekulasjonen': ('børsspekulasjon',),
'børsspekulasjonene': ('børsspekulasjon',),
'børsspekulasjoner': ('børsspekulasjon',),
'børst': ('børst',),
'børsten': ('børst',),
'børstene': ('børst',),
'børster': ('børst',),
'børste': ('børste',),
'børsten': ('børste',),
'børstene': ('børste',),
'børster': ('børste',),
'børstebinder': ('børstebinder',),
'børstebindere': ('børstebinder',),
'børstebinderen': ('børstebinder',),
'børstebinderer': ('børstebinder',),
'børstebinderne': ('børstebinder',),
'børstemakk': ('børstemakk',),
'børstemakken': ('børstemakk',),
'børstemakkene': ('børstemakk',),
'børstemakker': ('børstemakk',),
'børstemark': ('børstemark',),
'børstemarken': ('børstemark',),
'børstemarkene': ('børstemark',),
'børstemarker': ('børstemark',),
'børsteorm': ('børsteorm',),
'børsteormen': ('børsteorm',),
'børsteormene': ('børsteorm',),
'børsteormer': ('børsteorm',),
'bøss': ('bøss',),
'bøssa': ('bøss',),
'bøssene': ('bøss',),
'bøsset': ('bøss',),
'bøssa': ('bøsse',),
'bøsse': ('bøsse',),
'bøssen': ('bøsse',),
'bøssene': ('bøsse',),
'bøsser': ('bøsse',),
'bøssing': ('bøssing',),
'bøssingen': ('bøssing',),
'bøssingene': ('bøssing',),
'bøssinger': ('bøssing',),
'bøteri': ('bøteri',),
'bøteria': ('bøteri',),
'bøteriene': ('bøteri',),
'bøterier': ('bøteri',),
'bøteriet': ('bøteri',),
'bøtingsvon': ('bøtingsvon',),
'bøtingsvona': ('bøtingsvon',),
'bøtingsvonen': ('bøtingsvon',),
'bøtingsvonene': ('bøtingsvon',),
'bøtingsvoner': ('bøtingsvon',),
'bøtta': ('bøtte',),
'bøtte': ('bøtte',),
'bøtten': ('bøtte',),
'bøttene': ('bøtte',),
'bøtter': ('bøtte',),
'bøtteballett': ('bøtteballett',),
'bøtteballetten': ('bøtteballett',),
'bøtteballettene': ('bøtteballett',),
'bøtteballetter': ('bøtteballett',),
'bøttekott': ('bøttekott',),
'bøttekotta': ('bøttekott',),
'bøttekottene': ('bøttekott',),
'bøttekottet': ('bøttekott',),
'bøttepapir': ('bøttepapir',),
'bøttepapira': ('bøttepapir',),
'bøttepapirene': ('bøttepapir',),
'bøttepapirer': ('bøttepapir',),
'bøttepapiret': ('bøttepapir',),
'bøy': ('bøy',),
'bøyen': ('bøy',),
'bøyene': ('bøy',),
'bøyer': ('bøy',),
'bøya': ('bøye',),
'bøye': ('bøye',),
'bøyen': ('bøye',),
'bøyene': ('bøye',),
'bøyer': ('bøye',),
'bøya': ('bøye',),
'bøye': ('bøye',),
'bøyen': ('bøye',),
'bøyene': ('bøye',),
'bøyer': ('bøye',),
'bøya': ('bøye',),
'bøye': ('bøye',),
'bøyen': ('bøye',),
'bøyene': ('bøye',),
'bøyer': ('bøye',),
'bøyemuskel': ('bøyemuskel',),
'bøyemuskelen': ('bøyemuskel',),
'bøyemusklene': ('bøyemuskel',),
'bøyemuskler': ('bøyemuskel',),
'bøyeprøva': ('bøyeprøve',),
'bøyeprøve': ('bøyeprøve',),
'bøyeprøven': ('bøyeprøve',),
'bøyeprøvene': ('bøyeprøve',),
'bøyeprøver': ('bøyeprøve',),
'bøyg': ('bøyg',),
'bøygen': ('bøyg',),
'bøygene': ('bøyg',),
'bøyger': ('bøyg',),
'bøying': ('bøying',),
'bøyinga': ('bøying',),
'bøyingen': ('bøying',),
'bøyingene': ('bøying',),
'bøyinger': ('bøying',),
'bøyingsendelse': ('bøyingsendelse',),
'bøyingsendelsen': ('bøyingsendelse',),
'bøyingsendelsene': ('bøyingsendelse',),
'bøyingsendelser': ('bøyingsendelse',),
'bøyingsending': ('bøyingsending',),
'bøyingsendinga': ('bøyingsending',),
'bøyingsendingen': ('bøyingsending',),
'bøyingsendingene': ('bøyingsending',),
'bøyingsendinger': ('bøyingsending',),
'bøyingsform': ('bøyingsform',),
'bøyingsforma': ('bøyingsform',),
'bøyingsformen': ('bøyingsform',),
'bøyingsformene': ('bøyingsform',),
'bøyingsformer': ('bøyingsform',),
'bøyingsmønster': ('bøyingsmønster',),
'bøyingsmønsteret': ('bøyingsmønster',),
'bøyingsmønstra': ('bøyingsmønster',),
'bøyingsmønstre': ('bøyingsmønster',),
'bøyingsmønstrene': ('bøyingsmønster',),
'bøyingsmønstret': ('bøyingsmønster',),
'bøyingsspråk': ('bøyingsspråk',),
'bøyingsspråka': ('bøyingsspråk',),
'bøyingsspråkene': ('bøyingsspråk',),
'bøyingsspråket': ('bøyingsspråk',),
'bøyingsverk': ('bøyingsverk',),
'bøyingsverka': ('bøyingsverk',),
'bøyingsverkene': ('bøyingsverk',),
'bøyingsverker': ('bøyingsverk',),
'bøyingsverket': ('bøyingsverk',),
'bøyle': ('bøyle',),
'bøylen': ('bøyle',),
'bøylene': ('bøyle',),
'bøyler': ('bøyle',),
'bøylehest': ('bøylehest',),
'bøylehesten': ('bøylehest',),
'bøylehestene': ('bøylehest',),
'bøylehester': ('bøylehest',),
'bøyning': ('bøyning',),
'bøyninga': ('bøyning',),
'bøyningen': ('bøyning',),
'bøyningene': ('bøyning',),
'bøyninger': ('bøyning',),
'bøyningsendelse': ('bøyningsendelse',),
'bøyningsendelsen': ('bøyningsendelse',),
'bøyningsendelsene': ('bøyningsendelse',),
'bøyningsendelser': ('bøyningsendelse',),
'bøyningsending': ('bøyningsending',),
'bøyningsendinga': ('bøyningsending',),
'bøyningsendingen': ('bøyningsending',),
'bøyningsendingene': ('bøyningsending',),
'bøyningsendinger': ('bøyningsending',),
'bøyningsform': ('bøyningsform',),
'bøyningsforma': ('bøyningsform',),
'bøyningsformen': ('bøyningsform',),
'bøyningsformene': ('bøyningsform',),
'bøyningsformer': ('bøyningsform',),
'bøyningsmønster': ('bøyningsmønster',),
'bøyningsmønsteret': ('bøyningsmønster',),
'bøyningsmønstra': ('bøyningsmønster',),
'bøyningsmønstre': ('bøyningsmønster',),
'bøyningsmønstrene': ('bøyningsmønster',),
'bøyningsmønstret': ('bøyningsmønster',),
'bøyningsspråk': ('bøyningsspråk',),
'bøyningsspråka': ('bøyningsspråk',),
'bøyningsspråkene': ('bøyningsspråk',),
'bøyningsspråket': ('bøyningsspråk',),
'bøyningsverk': ('bøyningsverk',),
'bøyningsverka': ('bøyningsverk',),
'bøyningsverkene': ('bøyningsverk',),
'bøyningsverker': ('bøyningsverk',),
'bøyningsverket': ('bøyningsverk',),
'c': ('c',),
'c\'en': ('c',),
'c-en': ('c',),
'c-ene': ('c',),
'c-er': ('c',),
'cédille': ('cédille',),
'cédillen': ('cédille',),
'cédillene': ('cédille',),
'cédiller': ('cédille',),
'c-moll': ('c-moll',),
'c-mollen': ('c-moll',),
'c-mollene': ('c-moll',),
'c-moller': ('c-moll',),
'c-nøkkel': ('c-nøkkel',),
'c-nøkkelen': ('c-nøkkel',),
'c-nøklene': ('c-nøkkel',),
'c-nøkler': ('c-nøkkel',),
'cabincruiser': ('cabincruiser',),
'cabincruisere': ('cabincruiser',),
'cabincruiseren': ('cabincruiser',),
'cabincruiserer': ('cabincruiser',),
'cabincruiserne': ('cabincruiser',),
'cabincruiser': ('cabincruiser',),
'cabincruisere': ('cabincruiser',),
'cabincruiseren': ('cabincruiser',),
'cabincruiserer': ('cabincruiser',),
'cabincruiserne': ('cabincruiser',),
'caddie': ('caddie',),
'caddien': ('caddie',),
'caddiene': ('caddie',),
'caddier': ('caddie',),
'californier': ('californier',),
'californiere': ('californier',),
'californieren': ('californier',),
'californierer': ('californier',),
'californierne': ('californier',),
'californium': ('californium',),
'californiuma': ('californium',),
'californiumene': ('californium',),
'californiumet': ('californium',),
'calling': ('calling',),
'callingen': ('calling',),
'callingene': ('calling',),
'callinger': ('calling',),
'calvados': ('calvados',),
'calvadosen': ('calvados',),
'calvadosene': ('calvados',),
'calvadoser': ('calvados',),
'calypso': ('calypso',),
'calypsoen': ('calypso',),
'calypsoene': ('calypso',),
'calypsoer': ('calypso',),
'calypsoorkester': ('calypsoorkester',),
'calypsoorkesteret': ('calypsoorkester',),
'calypsoorkestra': ('calypsoorkester',),
'calypsoorkestre': ('calypsoorkester',),
'calypsoorkestrene': ('calypsoorkester',),
'calypsoorkestret': ('calypsoorkester',),
'calypsotakt': ('calypsotakt',),
'calypsotakta': ('calypsotakt',),
'calypsotakten': ('calypsotakt',),
'calypsotaktene': ('calypsotakt',),
'calypsotakter': ('calypsotakt',),
'cambric': ('cambric',),
'cambricen': ('cambric',),
'cambricene': ('cambric',),
'cambricer': ('cambric',),
'camembert': ('camembert',),
'camemberten': ('camembert',),
'camembertene': ('camembert',),
'camemberter': ('camembert',),
'camorra': ('camorra',),
'camorraen': ('camorra',),
'camorraene': ('camorra',),
'camorraer': ('camorra',),
'camp': ('camp',),
'campen': ('camp',),
'campene': ('camp',),
'camper': ('camp',),
'camper': ('camper',),
'campere': ('camper',),
'camperen': ('camper',),
'camperer': ('camper',),
'camperne': ('camper',),
'camping': ('camping',),
'campingen': ('camping',),
'campingene': ('camping',),
'campinger': ('camping',),
'campinghytta': ('campinghytte',),
'campinghytte': ('campinghytte',),
'campinghytten': ('campinghytte',),
'campinghyttene': ('campinghytte',),
'campinghytter': ('campinghytte',),
'campingplass': ('campingplass',),
'campingplassen': ('campingplass',),
'campingplassene': ('campingplass',),
'campingplasser': ('campingplass',),
'campingutstyr': ('campingutstyr',),
'campingutstyra': ('campingutstyr',),
'campingutstyrene': ('campingutstyr',),
'campingutstyret': ('campingutstyr',),
'campingvogn': ('campingvogn',),
'campingvogna': ('campingvogn',),
'campingvognen': ('campingvogn',),
'campingvognene': ('campingvogn',),
'campingvogner': ('campingvogn',),
'campus': ('campus',),
'campusen': ('campus',),
'campusene': ('campus',),
'campuser': ('campus',),
'canadier': ('canadier',),
'canadiere': ('canadier',),
'canadieren': ('canadier',),
'canadierer': ('canadier',),
'canadierne': ('canadier',),
'canasta': ('canasta',),
'canastaen': ('canasta',),
'canastaene': ('canasta',),
'canastaer': ('canasta',),
'cancan': ('cancan',),
'cancanen': ('cancan',),
'cancanene': ('cancan',),
'cancaner': ('cancan',),
'cancer': ('cancer',),
'canceren': ('cancer',),
'cancerene': ('cancer',),
'cancerer': ('cancer',),
'cand.mag.-eksamen': ('cand.mag.-eksamen',),
'cand.mag.-eksamenen': ('cand.mag.-eksamen',),
'cand.mag.-eksamenene': ('cand.mag.-eksamen',),
'cand.mag.-eksamener': ('cand.mag.-eksamen',),
'candela': ('candela',),
'candelaen': ('candela',),
'candelaene': ('candela',),
'cannabis': ('cannabis',),
'cannabisen': ('cannabis',),
'cannabisene': ('cannabis',),
'cannabiser': ('cannabis',),
'cannabisplanta': ('cannabisplante',),
'cannabisplante': ('cannabisplante',),
'cannabisplanten': ('cannabisplante',),
'cannabisplantene': ('cannabisplante',),
'cannabisplanter': ('cannabisplante',),
'cannabisstoff': ('cannabisstoff',),
'cannabisstoffa': ('cannabisstoff',),
'cannabisstoffene': ('cannabisstoff',),
'cannabisstoffer': ('cannabisstoff',),
'cannabisstoffet': ('cannabisstoff',),
'canvass': ('canvass',),
'canvassen': ('canvass',),
'canvassene': ('canvass',),
'canvasser': ('canvass',),
'canvassing': ('canvassing',),
'canvassinga': ('canvassing',),
'canvassingen': ('canvassing',),
'canvassingene': ('canvassing',),
'canvassinger': ('canvassing',),
'canyon': ('canyon',),
'canyonen': ('canyon',),
'canyonene': ('canyon',),
'canyoner': ('canyon',),
'cape': ('cape',),
'capen': ('cape',),
'capene': ('cape',),
'caper': ('cape',),
'cappuccino': ('cappuccino',),
'cappuccinoen': ('cappuccino',),
'cappuccinoene': ('cappuccino',),
'cappuccinoer': ('cappuccino',),
'capriccio': ('capriccio',),
'capriccioen': ('capriccio',),
'capriccioene': ('capriccio',),
'capriccioer': ('capriccio',),
'caravan': ('caravan',),
'caravanen': ('caravan',),
'caravanene': ('caravan',),
'caravaner': ('caravan',),
'cardigan': ('cardigan',),
'cardiganen': ('cardigan',),
'cardiganene': ('cardigan',),
'cardiganer': ('cardigan',),
'cargo': ('cargo',),
'cargoen': ('cargo',),
'cargoene': ('cargo',),
'cargoer': ('cargo',),
'cargoliner': ('cargoliner',),
'cargolinere': ('cargoliner',),
'cargolineren': ('cargoliner',),
'cargolinerer': ('cargoliner',),
'cargolinerne': ('cargoliner',),
'carnet': ('carnet',),
'carneta': ('carnet',),
'carneten': ('carnet',),
'carnetene': ('carnet',),
'carneter': ('carnet',),
'carnetet': ('carnet',),
'carport': ('carport',),
'carporten': ('carport',),
'carportene': ('carport',),
'carporter': ('carport',),
'carrier': ('carrier',),
'carriere': ('carrier',),
'carrieren': ('carrier',),
'carrierer': ('carrier',),
'carrierne': ('carrier',),
'carte blanche': ('carte blanche',),
'casanova': ('casanova',),
'casanovaen': ('casanova',),
'casanovaene': ('casanova',),
'casanovaer': ('casanova',),
'case': ('case',),
'casen': ('case',),
'casene': ('case',),
'caser': ('case',),
'case study': ('case study',),
'cash and carry': ('cash and carry',),
'casting': ('casting',),
'castingen': ('casting',),
'castingene': ('casting',),
'castinger': ('casting',),
'catering': ('catering',),
'cateringen': ('catering',),
'cateringene': ('catering',),
'cateringer': ('catering',),
'caterpillar': ('caterpillar',),
'caterpillaren': ('caterpillar',),
'caterpillarene': ('caterpillar',),
'caterpillarer': ('caterpillar',),
'catgut': ('catgut',),
'catguten': ('catgut',),
'catgutene': ('catgut',),
'catguter': ('catgut',),
'celebritet': ('celebritet',),
'celebriteten': ('celebritet',),
'celebritetene': ('celebritet',),
'celebriteter': ('celebritet',),
'celesta': ('celesta',),
'celestaen': ('celesta',),
'celestaene': ('celesta',),
'celestaer': ('celesta',),
'cella': ('celle',),
'celle': ('celle',),
'cellen': ('celle',),
'cellene': ('celle',),
'celler': ('celle',),
'cellebiologi': ('cellebiologi',),
'cellebiologien': ('cellebiologi',),
'cellebiologiene': ('cellebiologi',),
'cellebiologier': ('cellebiologi',),
'cellebro': ('cellebro',),
'cellebroa': ('cellebro',),
'cellebroen': ('cellebro',),
'cellebroene': ('cellebro',),
'cellebroer': ('cellebro',),
'cellebru': ('cellebru',),
'cellebrua': ('cellebru',),
'cellebruen': ('cellebru',),
'cellebruene': ('cellebru',),
'cellebruer': ('cellebru',),
'celledeling': ('celledeling',),
'celledelinga': ('celledeling',),
'celledelingen': ('celledeling',),
'celledelingene': ('celledeling',),
'celledelinger': ('celledeling',),
'cellegift': ('cellegift',),
'cellegifta': ('cellegift',),
'cellegiften': ('cellegift',),
'cellegiftene': ('cellegift',),
'cellegifter': ('cellegift',),
'cellekjerne': ('cellekjerne',),
'cellekjernen': ('cellekjerne',),
'cellekjernene': ('cellekjerne',),
'cellekjerner': ('cellekjerne',),
'cellekultur': ('cellekultur',),
'cellekulturen': ('cellekultur',),
'cellekulturene': ('cellekultur',),
'cellekulturer': ('cellekultur',),
'cellelæra': ('cellelære',),
'cellelære': ('cellelære',),
'cellelæren': ('cellelære',),
'cellelærene': ('cellelære',),
'cellelærer': ('cellelære',),
'cellemembran': ('cellemembran',),
'cellemembranen': ('cellemembran',),
'cellemembranene': ('cellemembran',),
'cellemembraner': ('cellemembran',),
'cellestoff': ('cellestoff',),
'cellestoffa': ('cellestoff',),
'cellestoffene': ('cellestoff',),
'cellestoffer': ('cellestoff',),
'cellestoffet': ('cellestoff',),
'cellevev': ('cellevev',),
'celleveva': ('cellevev',),
'cellevevene': ('cellevev',),
'cellevevet': ('cellevev',),
'cellist': ('cellist',),
'cellisten': ('cellist',),
'cellistene': ('cellist',),
'cellister': ('cellist',),
'cello': ('cello',),
'celloen': ('cello',),
'celloene': ('cello',),
'celloer': ('cello',),
'cellofan': ('cellofan',),
'cellofanen': ('cellofan',),
'cellofanene': ('cellofan',),
'cellofaner': ('cellofan',),
'cellularpatologi': ('cellularpatologi',),
'cellularpatologien': ('cellularpatologi',),
'cellularpatologiene': ('cellularpatologi',),
'cellularpatologier': ('cellularpatologi',),
'cellull': ('cellull',),
'cellulla': ('cellull',),
'cellullen': ('cellull',),
'cellullene': ('cellull',),
'celluller': ('cellull',),
'celluloid': ('celluloid',),
'celluloiden': ('celluloid',),
'celluloidene': ('celluloid',),
'celluloider': ('celluloid',),
'cellulose': ('cellulose',),
'cellulosen': ('cellulose',),
'cellulosene': ('cellulose',),
'celluloser': ('cellulose',),
'cellulosefabrikk': ('cellulosefabrikk',),
'cellulosefabrikken': ('cellulosefabrikk',),
'cellulosefabrikkene': ('cellulosefabrikk',),
'cellulosefabrikker': ('cellulosefabrikk',),
'cellulosefilm': ('cellulosefilm',),
'cellulosefilmen': ('cellulosefilm',),
'cellulosefilmene': ('cellulosefilm',),
'cellulosefilmer': ('cellulosefilm',),
'celluloselakk': ('celluloselakk',),
'celluloselakken': ('celluloselakk',),
'celluloselakkene': ('celluloselakk',),
'celluloselakker': ('celluloselakk',),
'celluloselim': ('celluloselim',),
'celluloselima': ('celluloselim',),
'celluloselimene': ('celluloselim',),
'celluloselimet': ('celluloselim',),
'cellulosemasse': ('cellulosemasse',),
'cellulosemassen': ('cellulosemasse',),
'cellulosemassene': ('cellulosemasse',),
'cellulosemasser': ('cellulosemasse',),
'cellulosenitrat': ('cellulosenitrat',),
'cellulosenitrata': ('cellulosenitrat',),
'cellulosenitratene': ('cellulosenitrat',),
'cellulosenitrater': ('cellulosenitrat',),
'cellulosenitratet': ('cellulosenitrat',),
'cellulosepapp': ('cellulosepapp',),
'cellulosepappen': ('cellulosepapp',),
'cellulosepappene': ('cellulosepapp',),
'cellulosepapper': ('cellulosepapp',),
'cellulosevatt': ('cellulosevatt',),
'cellulosevatta': ('cellulosevatt',),
'cellulosevatten': ('cellulosevatt',),
'cellulosevattene': ('cellulosevatt',),
'cellulosevatter': ('cellulosevatt',),
'cellulosevattet': ('cellulosevatt',),
'celsius': ('celsius',),
'celsiusgrad': ('celsiusgrad',),
'celsiusgraden': ('celsiusgrad',),
'celsiusgradene': ('celsiusgrad',),
'celsiusgrader': ('celsiusgrad',),
'celsiusskala': ('celsiusskala',),
'celsiusskalaen': ('celsiusskala',),
'celsiusskalaene': ('celsiusskala',),
'celsiusskalaer': ('celsiusskala',),
'celsiustermometer': ('celsiustermometer',),
'celsiustermometeret': ('celsiustermometer',),
'celsiustermometra': ('celsiustermometer',),
'celsiustermometre': ('celsiustermometer',),
'celsiustermometrene': ('celsiustermometer',),
'celsiustermometret': ('celsiustermometer',),
'cembalist': ('cembalist',),
'cembalisten': ('cembalist',),
'cembalistene': ('cembalist',),
'cembalister': ('cembalist',),
'cembalo': ('cembalo',),
'cembaloen': ('cembalo',),
'cembaloene': ('cembalo',),
'cembaloer': ('cembalo',),
'cent': ('cent',),
'centen': ('cent',),
'centene': ('cent',),
'centavo': ('centavo',),
'centavoen': ('centavo',),
'centavoene': ('centavo',),
'centavos': ('centavo',),
'centesimi': ('centesimo',),
'centesimiene': ('centesimo',),
'centesimo': ('centesimo',),
'centesimoen': ('centesimo',),
'centigram': ('centigram',),
'centigramma': ('centigram',),
'centigrammene': ('centigram',),
'centigrammet': ('centigram',),
'centime': ('centime',),
'centimen': ('centime',),
'centimene': ('centime',),
'centimes': ('centime',),
'centimeter': ('centimeter',),
'centimeteren': ('centimeter',),
'centimeterne': ('centimeter',),
'centimo': ('centimo',),
'centimoen': ('centimo',),
'centimoene': ('centimo',),
'centimos': ('centimo',),
'cereal': ('cereal',),
'cereala': ('cereal',),
'cerealene': ('cereal',),
'cerealer': ('cereal',),
'cerealet': ('cereal',),
'cerebral parese': ('cerebral parese',),
'cerebral paresen': ('cerebral parese',),
'cerebral paresene': ('cerebral parese',),
'cerebral pareser': ('cerebral parese',),
'cerebral parese-pasient': ('cerebral parese-pasient',),
'cerebral parese-pasienten': ('cerebral parese-pasient',),
'cerebral parese-pasientene': ('cerebral parese-pasient',),
'cerebral parese-pasienter': ('cerebral parese-pasient',),
'cerebralparetiker': ('cerebralparetiker',),
'cerebralparetikere': ('cerebralparetiker',),
'cerebralparetikeren': ('cerebralparetiker',),
'cerebralparetikerer': ('cerebralparetiker',),
'cerebralparetikerne': ('cerebralparetiker',),
'cerise': ('cerise',),
'cerisen': ('cerise',),
'cerisene': ('cerise',),
'ceriser': ('cerise',),
'cerium': ('cerium',),
'ceriuma': ('cerium',),
'ceriumene': ('cerium',),
'ceriumet': ('cerium',),
'certeparti': ('certeparti',),
'certepartia': ('certeparti',),
'certepartiene': ('certeparti',),
'certepartier': ('certeparti',),
'certepartiet': ('certeparti',),
'cesium': ('cesium',),
'cesiuma': ('cesium',),
'cesiumene': ('cesium',),
'cesiumet': ('cesium',),
'cess': ('cess',),
'cessen': ('cess',),
'cessene': ('cess',),
'cesser': ('cess',),
'cesur': ('cesur',),
'cesuren': ('cesur',),
'cesurene': ('cesur',),
'cesurer': ('cesur',),
'ceyloner': ('ceyloner',),
'ceylonere': ('ceyloner',),
'ceyloneren': ('ceyloner',),
'ceylonerer': ('ceyloner',),
'ceylonerne': ('ceyloner',),
'cha-cha-cha': ('cha-cha-cha',),
'cha-cha-chaen': ('cha-cha-cha',),
'cha-cha-chaene': ('cha-cha-cha',),
'cha-cha-chaer': ('cha-cha-cha',),
'chablis': ('chablis',),
'chablisen': ('chablis',),
'chablisene': ('chablis',),
'chabliser': ('chablis',),
'chaconne': ('chaconne',),
'chaconnen': ('chaconne',),
'chaconnene': ('chaconne',),
'chaconner': ('chaconne',),
'chamotte': ('chamotte',),
'chamotten': ('chamotte',),
'chamottene': ('chamotte',),
'chamotter': ('chamotte',),
'chamottestein': ('chamottestein',),
'chamottesteinen': ('chamottestein',),
'chamottesteinene': ('chamottestein',),
'chamottesteiner': ('chamottestein',),
'champagne': ('champagne',),
'champagnen': ('champagne',),
'champagnene': ('champagne',),
'champagner': ('champagne',),
'champagneglas': ('champagneglas',),
'champagneglasa': ('champagneglas',),
'champagneglasene': ('champagneglas',),
'champagneglaset': ('champagneglas',),
'champagneglass': ('champagneglass',),
'champagneglassa': ('champagneglass',),
'champagneglassene': ('champagneglass',),
'champagneglasset': ('champagneglass',),
'champion': ('champion',),
'championen': ('champion',),
'championene': ('champion',),
'championer': ('champion',),
'championat': ('championat',),
'championata': ('championat',),
'championatene': ('championat',),
'championatet': ('championat',),
'chargé d\'affaires': ('chargé d\'affaires',),
'chargé d\'affairesen': ('chargé d\'affaires',),
'chargés d\'affaires': ('chargé d\'affaires',),
'charleston': ('charleston',),
'charlestonen': ('charleston',),
'charlestonene': ('charleston',),
'charlestoner': ('charleston',),
'charmeuse': ('charmeuse',),
'charmeusen': ('charmeuse',),
'charmeusene': ('charmeuse',),
'charmeuser': ('charmeuse',),
'charter': ('charter',),
'charteret': ('charter',),
'chartra': ('charter',),
'chartre': ('charter',),
'chartrene': ('charter',),
'chartret': ('charter',),
'charterfly': ('charterfly',),
'charterflya': ('charterfly',),
'charterflyene': ('charterfly',),
'charterflyet': ('charterfly',),
'charterreisa': ('charterreise',),
'charterreise': ('charterreise',),
'charterreisen': ('charterreise',),
'charterreisene': ('charterreise',),
'charterreiser': ('charterreise',),
'chartertur': ('chartertur',),
'charterturen': ('chartertur',),
'charterturene': ('chartertur',),
'charterturer': ('chartertur',),
'chartreuse': ('chartreuse',),
'chartreusen': ('chartreuse',),
'chartreusene': ('chartreuse',),
'chartreuser': ('chartreuse',),
'chassis': ('chassis',),
'chassisa': ('chassis',),
'chassisene': ('chassis',),
'chassiser': ('chassis',),
'chassiset': ('chassis',),
'chassisnummer': ('chassisnummer',),
'chassisnummeret': ('chassisnummer',),
'chassisnumra': ('chassisnummer',),
'chassisnumre': ('chassisnummer',),
'chassisnumrene': ('chassisnummer',),
'chateau': ('chateau',),
'chateaua': ('chateau',),
'chateauene': ('chateau',),
'chateauer': ('chateau',),
'chateauet': ('chateau',),
'chateaubriand': ('chateaubriand',),
'chateaubrianden': ('chateaubriand',),
'chateaubriandene': ('chateaubriand',),
'chateaubriander': ('chateaubriand',),
'chateauvin': ('chateauvin',),
'chateauvinen': ('chateauvin',),
'chateauvinene': ('chateauvin',),
'chateauviner': ('chateauvin',),
'chausseen': ('chaussé',),
'chausseene': ('chaussé',),
'chausseer': ('chaussé',),
'chaussé': ('chaussé',),
'chausséen': ('chaussé',),
'chausséene': ('chaussé',),
'chausséer': ('chaussé',),
'cheddar': ('cheddar',),
'cheddaren': ('cheddar',),
'cheddarene': ('cheddar',),
'cheddarer': ('cheddar',),
'cheddarost': ('cheddarost',),
'cheddarosten': ('cheddarost',),
'cheddarostene': ('cheddarost',),
'cheddaroster': ('cheddarost',),
'chemise': ('chemise',),
'chemisen': ('chemise',),
'chemisene': ('chemise',),
'chemiser': ('chemise',),
'chenille': ('chenille',),
'chenillen': ('chenille',),
'chenillene': ('chenille',),
'cheniller': ('chenille',),
'chenillefrynsa': ('chenillefrynse',),
'chenillefrynse': ('chenillefrynse',),
'chenillefrynsen': ('chenillefrynse',),
'chenillefrynsene': ('chenillefrynse',),
'chenillefrynser': ('chenillefrynse',),
'chenillegarn': ('chenillegarn',),
'chenillegarna': ('chenillegarn',),
'chenillegarnene': ('chenillegarn',),
'chenillegarnet': ('chenillegarn',),
'chenillegenser': ('chenillegenser',),
'chenillegensere': ('chenillegenser',),
'chenillegenseren': ('chenillegenser',),
'chenillegenserer': ('chenillegenser',),
'chenillegenserne': ('chenillegenser',),
'chianti': ('chianti',),
'chiantien': ('chianti',),
'chiantiene': ('chianti',),
'chiantier': ('chianti',),
'chief': ('chief',),
'chiefen': ('chief',),
'chiefene': ('chief',),
'chiefer': ('chief',),
'chiffer': ('chiffer',),
'chifferet': ('chiffer',),
'chifra': ('chiffer',),
'chifre': ('chiffer',),
'chifrene': ('chiffer',),
'chifferskrift': ('chifferskrift',),
'chifferskrifta': ('chifferskrift',),
'chifferskriften': ('chifferskrift',),
'chifferskriftene': ('chifferskrift',),
'chifferskrifter': ('chifferskrift',),
'chiffersystem': ('chiffersystem',),
'chiffersystema': ('chiffersystem',),
'chiffersystemene': ('chiffersystem',),
'chiffersystemer': ('chiffersystem',),
'chiffersystemet': ('chiffersystem',),
'chiffertekst': ('chiffertekst',),
'chifferteksta': ('chiffertekst',),
'chifferteksten': ('chiffertekst',),
'chiffertekstene': ('chiffertekst',),
'chiffertekster': ('chiffertekst',),
'chiffertelegram': ('chiffertelegram',),
'chiffertelegramma': ('chiffertelegram',),
'chiffertelegrammene': ('chiffertelegram',),
'chiffertelegrammer': ('chiffertelegram',),
'chiffertelegrammet': ('chiffertelegram',),
'chiffon': ('chiffon',),
'chiffonen': ('chiffon',),
'chiffonene': ('chiffon',),
'chiffoner': ('chiffon',),
'chiffonskjerf': ('chiffonskjerf',),
'chiffonskjerfa': ('chiffonskjerf',),
'chiffonskjerfene': ('chiffonskjerf',),
'chiffonskjerfet': ('chiffonskjerf',),
'chihuahua': ('chihuahua',),
'chihuahuaen': ('chihuahua',),
'chihuahuaene': ('chihuahua',),
'chihuahuaer': ('chihuahua',),
'chilener': ('chilener',),
'chilenere': ('chilener',),
'chileneren': ('chilener',),
'chilenerer': ('chilener',),
'chilenerne': ('chilener',),
'chilesalpeter': ('chilesalpeter',),
'chilesalpetere': ('chilesalpeter',),
'chilesalpeteren': ('chilesalpeter',),
'chilesalpeterer': ('chilesalpeter',),
'chilesalpeterne': ('chilesalpeter',),
'chilesalpetre': ('chilesalpeter',),
'chilesalpetrene': ('chilesalpeter',),
'chilesalpetrer': ('chilesalpeter',),
'chilipepper': ('chilipepper',),
'chilipeppere': ('chilipepper',),
'chilipepperen': ('chilipepper',),
'chilipepperer': ('chilipepper',),
'chilipepperne': ('chilipepper',),
'chilipeprene': ('chilipepper',),
'chilipeprer': ('chilipepper',),
'chinchilla': ('chinchilla',),
'chinchillaen': ('chinchilla',),
'chinchillaene': ('chinchilla',),
'chinchillaer': ('chinchilla',),
'chinchillakanin': ('chinchillakanin',),
'chinchillakaninen': ('chinchillakanin',),
'chinchillakaninene': ('chinchillakanin',),
'chinchillakaniner': ('chinchillakanin',),
'chippendale': ('chippendale',),
'chips': ('chips',),
'chipsen': ('chips',),
'chipsene': ('chips',),
'choke': ('choke',),
'choken': ('choke',),
'chokene': ('choke',),
'choker': ('choke',),
'chomageforsikring': ('chomageforsikring',),
'chomageforsikringa': ('chomageforsikring',),
'chomageforsikringen': ('chomageforsikring',),
'chomageforsikringene': ('chomageforsikring',),
'chomageforsikringer': ('chomageforsikring',),
'chow-chow': ('chow-chow',),
'chow-chowen': ('chow-chow',),
'chow-chowene': ('chow-chow',),
'chow-chower': ('chow-chow',),
'chuck': ('chuck',),
'chucken': ('chuck',),
'chuckene': ('chuck',),
'chucker': ('chuck',),
'chutney': ('chutney',),
'chutneyen': ('chutney',),
'chutneyene': ('chutney',),
'chutneyer': ('chutney',),
'cicero': ('cicero',),
'ciceroen': ('cicero',),
'ciceroene': ('cicero',),
'cicerone': ('cicerone',),
'ciceronen': ('cicerone',),
'ciceronene': ('cicerone',),
'ciceroner': ('cicerone',),
'cinemascopa': ('cinemascope',),
'cinemascope': ('cinemascope',),
'cinemascopene': ('cinemascope',),
'cinemascoper': ('cinemascope',),
'cinemascopet': ('cinemascope',),
'cinematek': ('cinematek',),
'cinemateka': ('cinematek',),
'cinematekene': ('cinematek',),
'cinemateker': ('cinematek',),
'cinemateket': ('cinematek',),
'cirkapris': ('cirkapris',),
'cirkaprisen': ('cirkapris',),
'cirkaprisene': ('cirkapris',),
'cirkapriser': ('cirkapris',),
'cirkatal': ('cirkatal',),
'cirkatala': ('cirkatal',),
'cirkatalene': ('cirkatal',),
'cirkatalet': ('cirkatal',),
'cirkatall': ('cirkatall',),
'cirkatalla': ('cirkatall',),
'cirkatallene': ('cirkatall',),
'cirkatallet': ('cirkatall',),
'cirkumfleks': ('cirkumfleks',),
'cirkumfleksen': ('cirkumfleks',),
'cirkumfleksene': ('cirkumfleks',),
'cirkumflekser': ('cirkumfleks',),
'cirrussky': ('cirrussky',),
'cirrusskya': ('cirrussky',),
'cirrusskyen': ('cirrussky',),
'cirrusskyene': ('cirrussky',),
'cirrusskyer': ('cirrussky',),
'ciss': ('ciss',),
'cissen': ('ciss',),
'cissene': ('ciss',),
'cisser': ('ciss',),
'ciss-moll': ('ciss-moll',),
'ciss-mollen': ('ciss-moll',),
'ciss-mollene': ('ciss-moll',),
'ciss-moller': ('ciss-moll',),
'cistercienser': ('cistercienser',),
'cisterciensere': ('cistercienser',),
'cistercienseren': ('cistercienser',),
'cistercienserer': ('cistercienser',),
'cistercienserne': ('cistercienser',),
'cisterciensermunk': ('cisterciensermunk',),
'cisterciensermunken': ('cisterciensermunk',),
'cisterciensermunkene': ('cisterciensermunk',),
'cisterciensermunker': ('cisterciensermunk',),
'cisterciensernonna': ('cisterciensernonne',),
'cisterciensernonne': ('cisterciensernonne',),
'cisterciensernonnen': ('cisterciensernonne',),
'cisterciensernonnene': ('cisterciensernonne',),
'cisterciensernonner': ('cisterciensernonne',),
'cistercienserorden': ('cistercienserorden',),
'cistercienserordenen': ('cistercienserorden',),
'cistercienserordenene': ('cistercienserorden',),
'cistercienserordener': ('cistercienserorden',),
'cisterna': ('cisterne',),
'cisterne': ('cisterne',),
'cisternen': ('cisterne',),
'cisternene': ('cisterne',),
'cisterner': ('cisterne',),
'citadell': ('citadell',),
'citadella': ('citadell',),
'citadellene': ('citadell',),
'citadeller': ('citadell',),
'citadellet': ('citadell',),
'citer': ('citer',),
'citere': ('citer',),
'citeren': ('citer',),
'citerer': ('citer',),
'citerne': ('citer',),
'city': ('city',),
'cityen': ('city',),
'cityene': ('city',),
'cityer': ('city',),
'clairobscur': ('clairobscur',),
'clairobscura': ('clairobscur',),
'clairobscurene': ('clairobscur',),
'clairobscuret': ('clairobscur',),
'clairvoyance': ('clairvoyance',),
'clairvoyancen': ('clairvoyance',),
'clairvoyancene': ('clairvoyance',),
'clairvoyancer': ('clairvoyance',),
'clearing': ('clearing',),
'clearingen': ('clearing',),
'clearingene': ('clearing',),
'clearinger': ('clearing',),
'clearingkonti': ('clearingkonto',),
'clearingkontiene': ('clearingkonto',),
'clearingkonto': ('clearingkonto',),
'clearingkontoen': ('clearingkonto',),
'clearingkontoene': ('clearingkonto',),
'clearingkontoer': ('clearingkonto',),
'clinch': ('clinch',),
'clinchen': ('clinch',),
'clinchene': ('clinch',),
'clincher': ('clinch',),
'close race': ('close race',),
'clou': ('clou',),
'cloua': ('clou',),
'clouen': ('clou',),
'clouene': ('clou',),
'clouet': ('clou',),
'clutch': ('clutch',),
'clutchen': ('clutch',),
'clutchene': ('clutch',),
'clutcher': ('clutch',),
'clutchpedal': ('clutchpedal',),
'clutchpedalen': ('clutchpedal',),
'clutchpedalene': ('clutchpedal',),
'clutchpedaler': ('clutchpedal',),
'cocker spaniel': ('cocker spaniel',),
'cocker spanielen': ('cocker spaniel',),
'cocker spanielene': ('cocker spaniel',),
'cocker spanieler': ('cocker spaniel',),
'cockney': ('cockney',),
'cockneyen': ('cockney',),
'cockneyene': ('cockney',),
'cockneyer': ('cockney',),
'cockpit': ('cockpit',),
'cockpiten': ('cockpit',),
'cockpitene': ('cockpit',),
'cockpiter': ('cockpit',),
'cocktail': ('cocktail',),
'cocktailen': ('cocktail',),
'cocktailene': ('cocktail',),
'cocktailer': ('cocktail',),
'cocktailbær': ('cocktailbær',),
'cocktailbæra': ('cocktailbær',),
'cocktailbærene': ('cocktailbær',),
'cocktailbæret': ('cocktailbær',),
'cocktailkjole': ('cocktailkjole',),
'cocktailkjolen': ('cocktailkjole',),
'cocktailkjolene': ('cocktailkjole',),
'cocktailkjoler': ('cocktailkjole',),
'cocktailselskap': ('cocktailselskap',),
'cocktailselskapa': ('cocktailselskap',),
'cocktailselskapene': ('cocktailselskap',),
'cocktailselskaper': ('cocktailselskap',),
'cocktailselskapet': ('cocktailselskap',),
'coil': ('coil',),
'coilen': ('coil',),
'coilene': ('coil',),
'coiler': ('coil',),
'coitus interruptus': ('coitus interruptus',),
'collage': ('collage',),
'collagen': ('collage',),
'collagene': ('collage',),
'collager': ('collage',),
'collega': ('college',),
'college': ('college',),
'collegene': ('college',),
'colleger': ('college',),
'colleget': ('college',),
'collegegenser': ('collegegenser',),
'collegegensere': ('collegegenser',),
'collegegenseren': ('collegegenser',),
'collegegenserer': ('collegegenser',),
'collegegenserne': ('collegegenser',),
'collie': ('collie',),
'collien': ('collie',),
'colliene': ('collie',),
'collier': ('collie',),
'collier': ('collier',),
'colliera': ('collier',),
'collierene': ('collier',),
'collierer': ('collier',),
'collieret': ('collier',),
'colombianer': ('colombianer',),
'colombianere': ('colombianer',),
'colombianeren': ('colombianer',),
'colombianerer': ('colombianer',),
'colombianerne': ('colombianer',),
'coloradobille': ('coloradobille',),
'coloradobillen': ('coloradobille',),
'coloradobillene': ('coloradobille',),
'coloradobiller': ('coloradobille',),
'coltpistol': ('coltpistol',),
'coltpistolen': ('coltpistol',),
'coltpistolene': ('coltpistol',),
'coltpistoler': ('coltpistol',),
'columbi egg': ('columbi egg',),
'columbi egga': ('columbi egg',),
'columbi eggene': ('columbi egg',),
'columbi egget': ('columbi egg',),
'comeback': ('comeback',),
'comebacka': ('comeback',),
'comebacken': ('comeback',),
'comebackene': ('comeback',),
'comebacket': ('comeback',),
'commando': ('commando',),
'commandoen': ('commando',),
'commandoene': ('commando',),
'commandoer': ('commando',),
'commandoløp': ('commandoløp',),
'commandoløpa': ('commandoløp',),
'commandoløpene': ('commandoløp',),
'commandoløpet': ('commandoløp',),
'commandoraid': ('commandoraid',),
'commandoraida': ('commandoraid',),
'commandoraidene': ('commandoraid',),
'commandoraidet': ('commandoraid',),
'commandosoldat': ('commandosoldat',),
'commandosoldaten': ('commandosoldat',),
'commandosoldatene': ('commandosoldat',),
'commandosoldater': ('commandosoldat',),
'commandotropp': ('commandotropp',),
'commandotroppen': ('commandotropp',),
'commandotroppene': ('commandotropp',),
'commandotropper': ('commandotropp',),
'commedia dell\'arte': ('commedia dell\'arte',),
'computertomografi': ('computertomografi',),
'computertomografien': ('computertomografi',),
'computertomografiene': ('computertomografi',),
'computertomografier': ('computertomografi',),
'conga': ('conga',),
'congaen': ('conga',),
'congaene': ('conga',),
'congaer': ('conga',),
'congatromma': ('congatromme',),
'congatromme': ('congatromme',),
'congatrommen': ('congatromme',),
'congatrommene': ('congatromme',),
'congatrommer': ('congatromme',),
'consommeen': ('consommé',),
'consommeene': ('consommé',),
'consommeer': ('consommé',),
'consommé': ('consommé',),
'consomméen': ('consommé',),
'consomméene': ('consommé',),
'consomméer': ('consommé',),
'container': ('container',),
'containere': ('container',),
'containeren': ('container',),
'containerer': ('container',),
'containerne': ('container',),
'containerhamn': ('containerhamn',),
'containerhamna': ('containerhamn',),
'containerhamnen': ('containerhamn',),
'containerhamnene': ('containerhamn',),
'containerhamner': ('containerhamn',),
'containerhavn': ('containerhavn',),
'containerhavna': ('containerhavn',),
'containerhavnen': ('containerhavn',),
'containerhavnene': ('containerhavn',),
'containerhavner': ('containerhavn',),
'containerskip': ('containerskip',),
'containerskipa': ('containerskip',),
'containerskipene': ('containerskip',),
'containerskipet': ('containerskip',),
'copyright': ('copyright',),
'copyrighten': ('copyright',),
'copyrightene': ('copyright',),
'copyrighter': ('copyright',),
'copyrightmerka': ('copyrightmerke',),
'copyrightmerke': ('copyrightmerke',),
'copyrightmerkene': ('copyrightmerke',),
'copyrightmerker': ('copyrightmerke',),
'copyrightmerket': ('copyrightmerke',),
'copyrightsida': ('copyrightside',),
'copyrightside': ('copyrightside',),
'copyrightsiden': ('copyrightside',),
'copyrightsidene': ('copyrightside',),
'copyrightsider': ('copyrightside',),
'corner': ('corner',),
'cornere': ('corner',),
'corneren': ('corner',),
'cornerer': ('corner',),
'cornerne': ('corner',),
'cornflakes': ('cornflakes',),
'cornflakesen': ('cornflakes',),
'cornflakesene': ('cornflakes',),
'cornflakeser': ('cornflakes',),
'corps de ballet': ('corps de ballet',),
'corps diplomatique': ('corps diplomatique',),
'corsicaner': ('corsicaner',),
'corsicanere': ('corsicaner',),
'corsicaneren': ('corsicaner',),
'corsicanerer': ('corsicaner',),
'corsicanerne': ('corsicaner',),
'cosinus': ('cosinus',),
'cosinusen': ('cosinus',),
'cosinusene': ('cosinus',),
'cosinuser': ('cosinus',),
'costaricaner': ('costaricaner',),
'costaricanere': ('costaricaner',),
'costaricaneren': ('costaricaner',),
'costaricanerer': ('costaricaner',),
'costaricanerne': ('costaricaner',),
'cotangens': ('cotangens',),
'cotangensen': ('cotangens',),
'cotangensene': ('cotangens',),
'cotangenser': ('cotangens',),
'cottage cheese': ('cottage cheese',),
'cottage cheese-en': ('cottage cheese',),
'cottage cheese-ene': ('cottage cheese',),
'cottage cheese-er': ('cottage cheese',),
'coulomb': ('coulomb',),
'coulomben': ('coulomb',),
'coulombene': ('coulomb',),
'coulombmeter': ('coulombmeter',),
'coulombmeteret': ('coulombmeter',),
'coulombmetra': ('coulombmeter',),
'coulombmetre': ('coulombmeter',),
'coulombmetrene': ('coulombmeter',),
'coulombmetret': ('coulombmeter',),
'coulometer': ('coulometer',),
'coulometeret': ('coulometer',),
'coulometra': ('coulometer',),
'coulometre': ('coulometer',),
'coulometrene': ('coulometer',),
'coulometret': ('coulometer',),
'country and western': ('country and western',),
'countrymusikk': ('countrymusikk',),
'countrymusikken': ('countrymusikk',),
'countrymusikkene': ('countrymusikk',),
'countrymusikker': ('countrymusikk',),
'couronne': ('couronne',),
'couronnen': ('couronne',),
'couronnene': ('couronne',),
'couronner': ('couronne',),
'couscous': ('couscous',),
'couscousen': ('couscous',),
'couscousene': ('couscous',),
'couscouser': ('couscous',),
'cover': ('cover',),
'covera': ('cover',),
'coveret': ('cover',),
'coverne': ('cover',),
'cover charge': ('cover charge',),
'cover chargen': ('cover charge',),
'cover chargene': ('cover charge',),
'cover charger': ('cover charge',),
'coverversjon': ('coverversjon',),
'coverversjonen': ('coverversjon',),
'coverversjonene': ('coverversjon',),
'coverversjoner': ('coverversjon',),
'cowboy': ('cowboy',),
'cowboyen': ('cowboy',),
'cowboyene': ('cowboy',),
'cowboyer': ('cowboy',),
'cowboyfilm': ('cowboyfilm',),
'cowboyfilmen': ('cowboyfilm',),
'cowboyfilmene': ('cowboyfilm',),
'cowboyfilmer': ('cowboyfilm',),
'cowboyhatt': ('cowboyhatt',),
'cowboyhatten': ('cowboyhatt',),
'cowboyhattene': ('cowboyhatt',),
'cowboyhatter': ('cowboyhatt',),
'cox': ('cox',),
'coxen': ('cox',),
'coxene': ('cox',),
'coxer': ('cox',),
'coyote': ('coyote',),
'coyoten': ('coyote',),
'coyotene': ('coyote',),
'coyoter': ('coyote',),
'crêpe': ('crêpe',),
'crêpen': ('crêpe',),
'crêpene': ('crêpe',),
'crêper': ('crêpe',),
'crêpe de chine': ('crêpe de chine',),
'crêpe georgette': ('crêpe georgette',),
'crêpe georgetten': ('crêpe georgette',),
'crêpe georgettene': ('crêpe georgette',),
'crêpe georgetter': ('crêpe georgette',),
'crazyfilm': ('crazyfilm',),
'crazyfilmen': ('crazyfilm',),
'crazyfilmene': ('crazyfilm',),
'crazyfilmer': ('crazyfilm',),
'crazyhumor': ('crazyhumor',),
'crazyhumoren': ('crazyhumor',),
'crazyhumorene': ('crazyhumor',),
'crazyhumorer': ('crazyhumor',),
'crazykomedie': ('crazykomedie',),
'crazykomedien': ('crazykomedie',),
'crazykomediene': ('crazykomedie',),
'crazykomedier': ('crazykomedie',),
'credo': ('credo',),
'credoa': ('credo',),
'credoene': ('credo',),
'credoet': ('credo',),
'crescendo': ('crescendo',),
'crescendoa': ('crescendo',),
'crescendoen': ('crescendo',),
'crescendoene': ('crescendo',),
'crescendoer': ('crescendo',),
'crescendoet': ('crescendo',),
'cricket': ('cricket',),
'cricketen': ('cricket',),
'cricketene': ('cricket',),
'cricketer': ('cricket',),
'crimplena': ('crimplene',),
'crimplene': ('crimplene',),
'crimplenene': ('crimplene',),
'crimplener': ('crimplene',),
'crimplenet': ('crimplene',),
'cross': ('cross',),
'crossa': ('cross',),
'crossene': ('cross',),
'crosser': ('cross',),
'crosset': ('cross',),
'crossball': ('crossball',),
'crossballen': ('crossball',),
'crossballene': ('crossball',),
'crossballer': ('crossball',),
'croupier': ('croupier',),
'croupieren': ('croupier',),
'croupierene': ('croupier',),
'croupierer': ('croupier',),
'cruisa': ('cruise',),
'cruise': ('cruise',),
'cruisene': ('cruise',),
'cruiset': ('cruise',),
'cruisefart': ('cruisefart',),
'cruisefarten': ('cruisefart',),
'cruisefartene': ('cruisefart',),
'cruisefarter': ('cruisefart',),
'cruiser': ('cruiser',),
'cruisere': ('cruiser',),
'cruiseren': ('cruiser',),
'cruiserer': ('cruiser',),
'cruiserne': ('cruiser',),
'cruiservekt': ('cruiservekt',),
'cruiservekta': ('cruiservekt',),
'cruiservekten': ('cruiservekt',),
'cruiservektene': ('cruiservekt',),
'cruiservekter': ('cruiservekt',),
'cruiseskip': ('cruiseskip',),
'cruiseskipa': ('cruiseskip',),
'cruiseskipene': ('cruiseskip',),
'cruiseskipet': ('cruiseskip',),
'cruzeiro': ('cruzeiro',),
'cruzeiroen': ('cruzeiro',),
'cruzeiroene': ('cruzeiro',),
'cruzeiros': ('cruzeiro',),
'csardas': ('csardas',),
'csardasen': ('csardas',),
'csardasene': ('csardas',),
'csardaser': ('csardas',),
'cubaner': ('cubaner',),
'cubanere': ('cubaner',),
'cubaneren': ('cubaner',),
'cubanerer': ('cubaner',),
'cubanerne': ('cubaner',),
'cup': ('cup',),
'cupen': ('cup',),
'cupene': ('cup',),
'cuper': ('cup',),
'cupfinale': ('cupfinale',),
'cupfinalen': ('cupfinale',),
'cupfinalene': ('cupfinale',),
'cupfinaler': ('cupfinale',),
'cupkamp': ('cupkamp',),
'cupkampen': ('cupkamp',),
'cupkampene': ('cupkamp',),
'cupkamper': ('cupkamp',),
'cupmester': ('cupmester',),
'cupmestere': ('cupmester',),
'cupmesteren': ('cupmester',),
'cupmesterer': ('cupmester',),
'cupmesterne': ('cupmester',),
'cupmestre': ('cupmester',),
'cupmestrene': ('cupmester',),
'cupmestrer': ('cupmester',),
'cupmesterskap': ('cupmesterskap',),
'cupmesterskapa': ('cupmesterskap',),
'cupmesterskapene': ('cupmesterskap',),
'cupmesterskaper': ('cupmesterskap',),
'cupmesterskapet': ('cupmesterskap',),
'curaçao': ('curaçao',),
'curaçaoen': ('curaçao',),
'curaçaoene': ('curaçao',),
'curaçaoer': ('curaçao',),
'curare': ('curare',),
'curaren': ('curare',),
'curarene': ('curare',),
'curarer': ('curare',),
'curie': ('curie',),
'curieen': ('curie',),
'curieene': ('curie',),
'curium': ('curium',),
'curiuma': ('curium',),
'curiumene': ('curium',),
'curiumet': ('curium',),
'curler': ('curler',),
'curlere': ('curler',),
'curleren': ('curler',),
'curlerer': ('curler',),
'curlerne': ('curler',),
'curling': ('curling',),
'curlingen': ('curling',),
'curlingene': ('curling',),
'curlinger': ('curling',),
'cyan': ('cyan',),
'cyana': ('cyan',),
'cyanene': ('cyan',),
'cyanet': ('cyan',),
'cyanamid': ('cyanamid',),
'cyanamida': ('cyanamid',),
'cyanamidene': ('cyanamid',),
'cyanamider': ('cyanamid',),
'cyanamidet': ('cyanamid',),
'cyanid': ('cyanid',),
'cyanida': ('cyanid',),
'cyanidene': ('cyanid',),
'cyanider': ('cyanid',),
'cyanidet': ('cyanid',),
'cyanin': ('cyanin',),
'cyanina': ('cyanin',),
'cyaninene': ('cyanin',),
'cyaniner': ('cyanin',),
'cyaninet': ('cyanin',),
'cyanose': ('cyanose',),
'cyanosen': ('cyanose',),
'cyanosene': ('cyanose',),
'cyanoser': ('cyanose',),
'cyclostyle': ('cyclostyle',),
'cyclostylen': ('cyclostyle',),
'cyclostylene': ('cyclostyle',),
'cyclostyler': ('cyclostyle',),
'cykel': ('cykel',),
'cykelen': ('cykel',),
'cyklene': ('cykel',),
'cykler': ('cykel',),
'cyklamat': ('cyklamat',),
'cyklamata': ('cyklamat',),
'cyklamatene': ('cyklamat',),
'cyklamatet': ('cyklamat',),
'cymbal': ('cymbal',),
'cymbalen': ('cymbal',),
'cymbalene': ('cymbal',),
'cymbaler': ('cymbal',),
'cymbel': ('cymbel',),
'cymbelen': ('cymbel',),
'cymblene': ('cymbel',),
'cymbler': ('cymbel',),
'cyste': ('cyste',),
'cysten': ('cyste',),
'cystene': ('cyste',),
'cyster': ('cyste',),
'cytolog': ('cytolog',),
'cytologen': ('cytolog',),
'cytologene': ('cytolog',),
'cytologer': ('cytolog',),
'cytologi': ('cytologi',),
'cytologien': ('cytologi',),
'cytologiene': ('cytologi',),
'cytologier': ('cytologi',),
'cytoplasma': ('cytoplasma',),
'cytoplasmaene': ('cytoplasma',),
'cytoplasmaer': ('cytoplasma',),
'cytoplasmaet': ('cytoplasma',),
'cæsarisme': ('cæsarisme',),
'cæsarismen': ('cæsarisme',),
'cæsarismene': ('cæsarisme',),
'cæsarismer': ('cæsarisme',),
'cøliaker': ('cøliaker',),
'cøliakere': ('cøliaker',),
'cøliakeren': ('cøliaker',),
'cøliakerer': ('cøliaker',),
'cøliakerne': ('cøliaker',),
'cøliaki': ('cøliaki',),
'cøliakien': ('cøliaki',),
'cøliakiene': ('cøliaki',),
'cøliakier': ('cøliaki',),
'd': ('d',),
'd\'en': ('d',),
'd-en': ('d',),
'd-ene': ('d',),
'd-er': ('d',),
'déjà vu': ('déjà vu',),
'démarche': ('démarche',),
'démarchen': ('démarche',),
'démarchene': ('démarche',),
'démarcher': ('démarche',),
'düsseldorferskole': ('düsseldorferskole',),
'düsseldorferskolen': ('düsseldorferskole',),
'düsseldorferskolene': ('düsseldorferskole',),
'düsseldorferskoler': ('düsseldorferskole',),
'düsseldorfskole': ('düsseldorfskole',),
'düsseldorfskolen': ('düsseldorfskole',),
'düsseldorfskolene': ('düsseldorfskole',),
'düsseldorfskoler': ('düsseldorfskole',),
'd-moll': ('d-moll',),
'd-mollen': ('d-moll',),
'd-mollene': ('d-moll',),
'd-moller': ('d-moll',),
'dachs': ('dachs',),
'dachsen': ('dachs',),
'dachsene': ('dachs',),
'dachser': ('dachs',),
'dachshund': ('dachshund',),
'dachshunden': ('dachshund',),
'dachshundene': ('dachshund',),
'dachshunder': ('dachshund',),
'dadaisme': ('dadaisme',),
'dadaismen': ('dadaisme',),
'dadaismene': ('dadaisme',),
'dadaismer': ('dadaisme',),
'dadaist': ('dadaist',),
'dadaisten': ('dadaist',),
'dadaistene': ('dadaist',),
'dadaister': ('dadaist',),
'dadda': ('dadda',),
'daddaen': ('dadda',),
'daddaene': ('dadda',),
'daddaer': ('dadda',),
'daddelpalme': ('daddelpalme',),
'daddelpalmen': ('daddelpalme',),
'daddelpalmene': ('daddelpalme',),
'daddelpalmer': ('daddelpalme',),
'dag': ('dag',),
'dagen': ('dag',),
'dagene': ('dag',),
'dager': ('dag',),
'dagarbeid': ('dagarbeid',),
'dagarbeida': ('dagarbeid',),
'dagarbeidene': ('dagarbeid',),
'dagarbeider': ('dagarbeid',),
'dagarbeidet': ('dagarbeid',),
'dagbarn': ('dagbarn',),
'dagbarna': ('dagbarn',),
'dagbarnene': ('dagbarn',),
'dagbarnet': ('dagbarn',),
'dagbergart': ('dagbergart',),
'dagbergarta': ('dagbergart',),
'dagbergarten': ('dagbergart',),
'dagbergartene': ('dagbergart',),
'dagbergarter': ('dagbergart',),
'dagblad': ('dagblad',),
'dagblada': ('dagblad',),
'dagbladene': ('dagblad',),
'dagblader': ('dagblad',),
'dagbladet': ('dagblad',),
'dagbok': ('dagbok',),
'dagboka': ('dagbok',),
'dagboken': ('dagbok',),
'dagbøkene': ('dagbok',),
'dagbøker': ('dagbok',),
'dagboksforfatter': ('dagboksforfatter',),
'dagboksforfattere': ('dagboksforfatter',),
'dagboksforfatteren': ('dagboksforfatter',),
'dagboksforfatterer': ('dagboksforfatter',),
'dagboksforfatterne': ('dagboksforfatter',),
'dagboksopptegnelse': ('dagboksopptegnelse',),
'dagboksopptegnelsen': ('dagboksopptegnelse',),
'dagboksopptegnelsene': ('dagboksopptegnelse',),
'dagboksopptegnelser': ('dagboksopptegnelse',),
'dagbrott': ('dagbrott',),
'dagbrotta': ('dagbrott',),
'dagbrottene': ('dagbrott',),
'dagbrottet': ('dagbrott',),
'dagbrottsdrift': ('dagbrottsdrift',),
'dagbrottsdrifta': ('dagbrottsdrift',),
'dagbrottsdriften': ('dagbrottsdrift',),
'dagbrottsdriftene': ('dagbrottsdrift',),
'dagbrottsdrifter': ('dagbrottsdrift',),
'dagbrudd': ('dagbrudd',),
'dagbrudda': ('dagbrudd',),
'dagbruddene': ('dagbrudd',),
'dagbruddet': ('dagbrudd',),
'dagbruddsdrift': ('dagbruddsdrift',),
'dagbruddsdrifta': ('dagbruddsdrift',),
'dagbruddsdriften': ('dagbruddsdrift',),
'dagbruddsdriftene': ('dagbruddsdrift',),
'dagbruddsdrifter': ('dagbruddsdrift',),
'dagdriver': ('dagdriver',),
'dagdrivere': ('dagdriver',),
'dagdriveren': ('dagdriver',),
'dagdriverer': ('dagdriver',),
'dagdriverne': ('dagdriver',),
'dagdriverliv': ('dagdriverliv',),
'dagdriverliva': ('dagdriverliv',),
'dagdriverlivene': ('dagdriverliv',),
'dagdriverlivet': ('dagdriverliv',),
'dagdrøm': ('dagdrøm',),
'dagdrømmen': ('dagdrøm',),
'dagdrømmene': ('dagdrøm',),
'dagdrømmer': ('dagdrøm',),
'daggry': ('daggry',),
'daggrya': ('daggry',),
'daggryene': ('daggry',),
'daggryet': ('daggry',),
'dagheim': ('dagheim',),
'dagheimen': ('dagheim',),
'dagheimene': ('dagheim',),
'dagheimer': ('dagheim',),
'dagheimplass': ('dagheimplass',),
'dagheimplassen': ('dagheimplass',),
'dagheimplassene': ('dagheimplass',),
'dagheimplasser': ('dagheimplass',),
'dagheimsplass': ('dagheimsplass',),
'dagheimsplassen': ('dagheimsplass',),
'dagheimsplassene': ('dagheimsplass',),
'dagheimsplasser': ('dagheimsplass',),
'daghjelp': ('daghjelp',),
'daghjelpa': ('daghjelp',),
'daghjelpen': ('daghjelp',),
'daghjelpene': ('daghjelp',),
'daghjelper': ('daghjelp',),
'daghjem': ('daghjem',),
'daghjemma': ('daghjem',),
'daghjemmene': ('daghjem',),
'daghjemmet': ('daghjem',),
'daghjemplass': ('daghjemplass',),
'daghjemplassen': ('daghjemplass',),
'daghjemplassene': ('daghjemplass',),
'daghjemplasser': ('daghjemplass',),
'daghjemsplass': ('daghjemsplass',),
'daghjemsplassen': ('daghjemsplass',),
'daghjemsplassene': ('daghjemsplass',),
'daghjemsplasser': ('daghjemsplass',),
'dagleier': ('dagleier',),
'dagleiere': ('dagleier',),
'dagleieren': ('dagleier',),
'dagleierer': ('dagleier',),
'dagleierne': ('dagleier',),
'dagligliv': ('dagligliv',),
'dagligliva': ('dagligliv',),
'dagliglivene': ('dagligliv',),
'dagliglivet': ('dagligliv',),
'dagligstova': ('dagligstove',),
'dagligstove': ('dagligstove',),
'dagligstoven': ('dagligstove',),
'dagligstovene': ('dagligstove',),
'dagligstover': ('dagligstove',),
'dagligstua': ('dagligstue',),
'dagligstue': ('dagligstue',),
'dagligstuen': ('dagligstue',),
'dagligstuene': ('dagligstue',),
'dagligstuer': ('dagligstue',),
'dagligtale': ('dagligtale',),
'dagligtalen': ('dagligtale',),
'dagligtalene': ('dagligtale',),
'dagligtaler': ('dagligtale',),
'dagligvara': ('dagligvare',),
'dagligvare': ('dagligvare',),
'dagligvaren': ('dagligvare',),
'dagligvarene': ('dagligvare',),
'dagligvarer': ('dagligvare',),
'dagligvareforretning': ('dagligvareforretning',),
'dagligvareforretninga': ('dagligvareforretning',),
'dagligvareforretningen': ('dagligvareforretning',),
'dagligvareforretningene': ('dagligvareforretning',),
'dagligvareforretninger': ('dagligvareforretning',),
'dagligvarehandel': ('dagligvarehandel',),
'dagligvarehandelen': ('dagligvarehandel',),
'dagligvarehandlene': ('dagligvarehandel',),
'dagligvarehandler': ('dagligvarehandel',),
'daglønn': ('daglønn',),
'daglønna': ('daglønn',),
'daglønnen': ('daglønn',),
'daglønnene': ('daglønn',),
'daglønner': ('daglønn',),
'daglønner': ('daglønner',),
'daglønnere': ('daglønner',),
'daglønneren': ('daglønner',),
'daglønnerer': ('daglønner',),
'daglønnerne': ('daglønner',),
'dagmamma': ('dagmamma',),
'dagmammaen': ('dagmamma',),
'dagmammaene': ('dagmamma',),
'dagmammaer': ('dagmamma',),
'dagmann': ('dagmann',),
'dagmannen': ('dagmann',),
'dagmenn': ('dagmann',),
'dagmennene': ('dagmann',),
'dagning': ('dagning',),
'dagninga': ('dagning',),
'dagningen': ('dagning',),
'dagningene': ('dagning',),
'dagninger': ('dagning',),
'dago': ('dago',),
'dagoen': ('dago',),
'dagoene': ('dago',),
'dagoer': ('dago',),
'dagpappa': ('dagpappa',),
'dagpappaen': ('dagpappa',),
'dagpappaene': ('dagpappa',),
'dagpappaer': ('dagpappa',),
'dagpendler': ('dagpendler',),
'dagpendlere': ('dagpendler',),
'dagpendleren': ('dagpendler',),
'dagpendlerer': ('dagpendler',),
'dagpendlerne': ('dagpendler',),
'dagpengene': ('dagpenger',),
'dagpenger': ('dagpenger',),
'dagsarbeid': ('dagsarbeid',),
'dagsarbeida': ('dagsarbeid',),
'dagsarbeidene': ('dagsarbeid',),
'dagsarbeider': ('dagsarbeid',),
'dagsarbeidet': ('dagsarbeid',),
'dagsavis': ('dagsavis',),
'dagsavisa': ('dagsavis',),
'dagsavisen': ('dagsavis',),
'dagsavisene': ('dagsavis',),
'dagsaviser': ('dagsavis',),
'dagsbefaling': ('dagsbefaling',),
'dagsbefalinga': ('dagsbefaling',),
'dagsbefalingen': ('dagsbefaling',),
'dagsbefalingene': ('dagsbefaling',),
'dagsbefalinger': ('dagsbefaling',),
'dagsenter': ('dagsenter',),
'dagsenteret': ('dagsenter',),
'dagsentra': ('dagsenter',),
'dagsentre': ('dagsenter',),
'dagsentrene': ('dagsenter',),
'dagsentret': ('dagsenter',),
'dagsform': ('dagsform',),
'dagsforma': ('dagsform',),
'dagsformen': ('dagsform',),
'dagsformene': ('dagsform',),
'dagsformer': ('dagsform',),
'dagsida': ('dagside',),
'dagside': ('dagside',),
'dagsiden': ('dagside',),
'dagsidene': ('dagside',),
'dagsider': ('dagside',),
'dagsjukehus': ('dagsjukehus',),
'dagsjukehusa': ('dagsjukehus',),
'dagsjukehusene': ('dagsjukehus',),
'dagsjukehuset': ('dagsjukehus',),
'dagskift': ('dagskift',),
'dagskifta': ('dagskift',),
'dagskiftene': ('dagskift',),
'dagskiftet': ('dagskift',),
'dagslys': ('dagslys',),
'dagslysa': ('dagslys',),
'dagslysene': ('dagslys',),
'dagslyset': ('dagslys',),
'dagslysskjerm': ('dagslysskjerm',),
'dagslysskjermen': ('dagslysskjerm',),
'dagslysskjermene': ('dagslysskjerm',),
'dagslysskjermer': ('dagslysskjerm',),
'dagsmarsj': ('dagsmarsj',),
'dagsmarsjen': ('dagsmarsj',),
'dagsmarsjene': ('dagsmarsj',),
'dagsmarsjer': ('dagsmarsj',),
'dagsnytt': ('dagsnytt',),
'dagsnyttsending': ('dagsnyttsending',),
'dagsnyttsendinga': ('dagsnyttsending',),
'dagsnyttsendingen': ('dagsnyttsending',),
'dagsnyttsendingene': ('dagsnyttsending',),
'dagsnyttsendinger': ('dagsnyttsending',),
'dagsommerfugl': ('dagsommerfugl',),
'dagsommerfuglen': ('dagsommerfugl',),
'dagsommerfuglene': ('dagsommerfugl',),
'dagsommerfugler': ('dagsommerfugl',),
'dagsorden': ('dagsorden',),
'dagsordenen': ('dagsorden',),
'dagsordenene': ('dagsorden',),
'dagsordener': ('dagsorden',),
'dagsordre': ('dagsordre',),
'dagsordren': ('dagsordre',),
'dagsordrene': ('dagsordre',),
'dagsordrer': ('dagsordre',),
'dagspressa': ('dagspresse',),
'dagspresse': ('dagspresse',),
'dagspressen': ('dagspresse',),
'dagspressene': ('dagspresse',),
'dagspresser': ('dagspresse',),
'dagsreisa': ('dagsreise',),
'dagsreise': ('dagsreise',),
'dagsreisen': ('dagsreise',),
'dagsreisene': ('dagsreise',),
'dagsreiser': ('dagsreise',),
'dagsrevy': ('dagsrevy',),
'dagsrevyen': ('dagsrevy',),
'dagsrevyene': ('dagsrevy',),
'dagsrevyer': ('dagsrevy',),
'dagstur': ('dagstur',),
'dagsturen': ('dagstur',),
'dagsturene': ('dagstur',),
'dagsturer': ('dagstur',),
'dagsverk': ('dagsverk',),
'dagsverka': ('dagsverk',),
'dagsverkene': ('dagsverk',),
'dagsverker': ('dagsverk',),
'dagsverket': ('dagsverk',),
'dagsvermer': ('dagsvermer',),
'dagsvermere': ('dagsvermer',),
'dagsvermeren': ('dagsvermer',),
'dagsvermerer': ('dagsvermer',),
'dagsvermerne': ('dagsvermer',),
'dagsykehus': ('dagsykehus',),
'dagsykehusa': ('dagsykehus',),
'dagsykehusene': ('dagsykehus',),
'dagsykehuset': ('dagsykehus',),
'dagtid': ('dagtid',),
'dagtida': ('dagtid',),
'dagtiden': ('dagtid',),
'dagtidene': ('dagtid',),
'dagtider': ('dagtid',),
'dagtog': ('dagtog',),
'dagtoga': ('dagtog',),
'dagtogene': ('dagtog',),
'dagtoget': ('dagtog',),
'daguerreotypi': ('daguerreotypi',),
'daguerreotypien': ('daguerreotypi',),
'daguerreotypiene': ('daguerreotypi',),
'daguerreotypier': ('daguerreotypi',),
'daguerreotypi': ('daguerreotypi',),
'daguerreotypia': ('daguerreotypi',),
'daguerreotypiene': ('daguerreotypi',),
'daguerreotypier': ('daguerreotypi',),
'daguerreotypiet': ('daguerreotypi',),
'dagvakt': ('dagvakt',),
'dagvakta': ('dagvakt',),
'dagvakten': ('dagvakt',),
'dagvaktene': ('dagvakt',),
'dagvakter': ('dagvakt',),
'dagveksel': ('dagveksel',),
'dagvekselen': ('dagveksel',),
'dagvekslene': ('dagveksel',),
'dagveksler': ('dagveksel',),
'dahlie': ('dahlie',),
'dahlien': ('dahlie',),
'dahliene': ('dahlie',),
'dahlier': ('dahlie',),
'dakapo': ('dakapo',),
'dakapoen': ('dakapo',),
'dakapoene': ('dakapo',),
'dakapoer': ('dakapo',),
'dakapo': ('dakapo',),
'dakapoa': ('dakapo',),
'dakapoene': ('dakapo',),
'dakapoer': ('dakapo',),
'dakapoet': ('dakapo',),
'dakaponummer': ('dakaponummer',),
'dakaponummeret': ('dakaponummer',),
'dakaponumra': ('dakaponummer',),
'dakaponumre': ('dakaponummer',),
'dakaponumrene': ('dakaponummer',),
'daktyl': ('daktyl',),
'daktylen': ('daktyl',),
'daktylene': ('daktyl',),
'daktyler': ('daktyl',),
'daktylene': ('daktylos',),
'daktyler': ('daktylos',),
'daktylos': ('daktylos',),
'daktylosen': ('daktylos',),
'dal': ('dal',),
'dalen': ('dal',),
'dalene': ('dal',),
'daler': ('dal',),
'dalai-lama': ('dalai-lama',),
'dalai-lamaen': ('dalai-lama',),
'dalai-lamaene': ('dalai-lama',),
'dalai-lamaer': ('dalai-lama',),
'dalasau': ('dalasau',),
'dalasauen': ('dalasau',),
'dalasauene': ('dalasau',),
'dalasauer': ('dalasau',),
'dalbotn': ('dalbotn',),
'dalbotnen': ('dalbotn',),
'dalbotnene': ('dalbotn',),
'dalbotner': ('dalbotn',),
'dalbotn': ('dalbotn',),
'dalbotnen': ('dalbotn',),
'dalbotnene': ('dalbotn',),
'dalbotner': ('dalbotn',),
'dalbu': ('dalbu',),
'dalbuen': ('dalbu',),
'dalbuene': ('dalbu',),
'dalbuer': ('dalbu',),
'dalbunn': ('dalbunn',),
'dalbunnen': ('dalbunn',),
'dalbunnene': ('dalbunn',),
'dalbunner': ('dalbunn',),
'daler': ('daler',),
'dalere': ('daler',),
'daleren': ('daler',),
'dalerer': ('daler',),
'dalerne': ('daler',),
'dalføra': ('dalføre',),
'dalføre': ('dalføre',),
'dalførene': ('dalføre',),
'dalfører': ('dalføre',),
'dalføret': ('dalføre',),
'dalgryta': ('dalgryte',),
'dalgryte': ('dalgryte',),
'dalgryten': ('dalgryte',),
'dalgrytene': ('dalgryte',),
'dalgryter': ('dalgryte',),
'dall': ('dall',),
'dallen': ('dall',),
'dallene': ('dall',),
'daller': ('dall',),
'dalmatier': ('dalmatier',),
'dalmatiere': ('dalmatier',),
'dalmatieren': ('dalmatier',),
'dalmatierer': ('dalmatier',),
'dalmatierne': ('dalmatier',),
'dalmatiner': ('dalmatiner',),
'dalmatinere': ('dalmatiner',),
'dalmatineren': ('dalmatiner',),
'dalmatinerer': ('dalmatiner',),
'dalmatinerne': ('dalmatiner',),
'dalsenkning': ('dalsenkning',),
'dalsenkninga': ('dalsenkning',),
'dalsenkningen': ('dalsenkning',),
'dalsenkningene': ('dalsenkning',),
'dalsenkninger': ('dalsenkning',),
'dalsida': ('dalside',),
'dalside': ('dalside',),
'dalsiden': ('dalside',),
'dalsidene': ('dalside',),
'dalsider': ('dalside',),
'dalstrøk': ('dalstrøk',),
'dalstrøka': ('dalstrøk',),
'dalstrøkene': ('dalstrøk',),
'dalstrøket': ('dalstrøk',),
'dalsøkk': ('dalsøkk',),
'dalsøkka': ('dalsøkk',),
'dalsøkkene': ('dalsøkk',),
'dalsøkket': ('dalsøkk',),
'dalt': ('dalt',),
'dalten': ('dalt',),
'daltene': ('dalt',),
'dalter': ('dalt',),
'dam': ('dam',),
'dammen': ('dam',),
'dammene': ('dam',),
'dammer': ('dam',),
'dam': ('dam',),
'dammen': ('dam',),
'dammene': ('dam',),
'dammer': ('dam',),
'damanlegg': ('damanlegg',),
'damanlegga': ('damanlegg',),
'damanleggene': ('damanlegg',),
'damanlegget': ('damanlegg',),
'damascenerstål': ('damascenerstål',),
'damascenerståla': ('damascenerstål',),
'damascenerstålene': ('damascenerstål',),
'damascenerstålet': ('damascenerstål',),
'damascenersverd': ('damascenersverd',),
'damascenersverda': ('damascenersverd',),
'damascenersverdene': ('damascenersverd',),
'damascenersverdet': ('damascenersverd',),
'damask': ('damask',),
'damasken': ('damask',),
'damaskene': ('damask',),
'damasker': ('damask',),
'damaskduk': ('damaskduk',),
'damaskduken': ('damaskduk',),
'damaskdukene': ('damaskduk',),
'damaskduker': ('damaskduk',),
'dambrett': ('dambrett',),
'dambretta': ('dambrett',),
'dambrettene': ('dambrett',),
'dambretter': ('dambrett',),
'dambrettet': ('dambrett',),
'dambrikka': ('dambrikke',),
'dambrikke': ('dambrikke',),
'dambrikken': ('dambrikke',),
'dambrikkene': ('dambrikke',),
'dambrikker': ('dambrikke',),
'dama': ('dame',),
'dame': ('dame',),
'damen': ('dame',),
'damene': ('dame',),
'damer': ('dame',),
'damebekjentskap': ('damebekjentskap',),
'damebekjentskapa': ('damebekjentskap',),
'damebekjentskapene': ('damebekjentskap',),
'damebekjentskaper': ('damebekjentskap',),
'damebekjentskapet': ('damebekjentskap',),
'damebind': ('damebind',),
'damebinda': ('damebind',),
'damebindene': ('damebind',),
'damebindet': ('damebind',),
'damefotball': ('damefotball',),
'damefotballen': ('damefotball',),
'damefotballene': ('damefotball',),
'damefotballer': ('damefotball',),
'damefrisør': ('damefrisør',),
'damefrisøren': ('damefrisør',),
'damefrisørene': ('damefrisør',),
'damefrisører': ('damefrisør',),
'damejeanne': ('damejeanne',),
'damejeannen': ('damejeanne',),
'damejeannene': ('damejeanne',),
'damejeanner': ('damejeanne',),
'damekor': ('damekor',),
'damekora': ('damekor',),
'damekorene': ('damekor',),
'damekoret': ('damekor',),
'damelag': ('damelag',),
'damelaga': ('damelag',),
'damelagene': ('damelag',),
'damelaget': ('damelag',),
'damemenneska': ('damemenneske',),
'damemenneske': ('damemenneske',),
'damemenneskene': ('damemenneske',),
'damemennesker': ('damemenneske',),
'damemennesket': ('damemenneske',),
'damesykkel': ('damesykkel',),
'damesykkelen': ('damesykkel',),
'damesyklene': ('damesykkel',),
'damesykler': ('damesykkel',),
'dametekka': ('dametekke',),
'dametekke': ('dametekke',),
'dametekkene': ('dametekke',),
'dametekker': ('dametekke',),
'dametekket': ('dametekke',),
'dametoalett': ('dametoalett',),
'dametoaletta': ('dametoalett',),
'dametoalettene': ('dametoalett',),
'dametoaletter': ('dametoalett',),
'dametoalettet': ('dametoalett',),
'dameur': ('dameur',),
'dameura': ('dameur',),
'dameurene': ('dameur',),
'dameuret': ('dameur',),
'damfisk': ('damfisk',),
'damfisken': ('damfisk',),
'damfiskene': ('damfisk',),
'damfisker': ('damfisk',),
'damkrona': ('damkrone',),
'damkrone': ('damkrone',),
'damkronen': ('damkrone',),
'damkronene': ('damkrone',),
'damkroner': ('damkrone',),
'damkultur': ('damkultur',),
'damkulturen': ('damkultur',),
'damkulturene': ('damkultur',),
'damkulturer': ('damkultur',),
'damluka': ('damluke',),
'damluke': ('damluke',),
'damluken': ('damluke',),
'damlukene': ('damluke',),
'damluker': ('damluke',),
'dammusling': ('dammusling',),
'dammuslingen': ('dammusling',),
'dammuslingene': ('dammusling',),
'dammuslinger': ('dammusling',),
'damoklessverd': ('damoklessverd',),
'damoklessverda': ('damoklessverd',),
'damoklessverdene': ('damoklessverd',),
'damoklessverdet': ('damoklessverd',),
'damp': ('damp',),
'dampen': ('damp',),
'dampene': ('damp',),
'damper': ('damp',),
'dampbad': ('dampbad',),
'dampbada': ('dampbad',),
'dampbadene': ('dampbad',),
'dampbadet': ('dampbad',),
'dampbåt': ('dampbåt',),
'dampbåten': ('dampbåt',),
'dampbåtene': ('dampbåt',),
'dampbåter': ('dampbåt',),
'damper': ('damper',),
'dampere': ('damper',),
'damperen': ('damper',),
'damperer': ('damper',),
'damperne': ('damper',),
'dampfart': ('dampfart',),
'dampfarten': ('dampfart',),
'dampfartene': ('dampfart',),
'dampfarter': ('dampfart',),
'dampkjel': ('dampkjel',),
'dampkjelen': ('dampkjel',),
'dampkjelene': ('dampkjel',),
'dampkjeler': ('dampkjel',),
'dampkjele': ('dampkjele',),
'dampkjelen': ('dampkjele',),
'dampkjelene': ('dampkjele',),
'dampkjeler': ('dampkjele',),
'dampkjøkken': ('dampkjøkken',),
'dampkjøkkena': ('dampkjøkken',),
'dampkjøkkenene': ('dampkjøkken',),
'dampkjøkkener': ('dampkjøkken',),
'dampkjøkkenet': ('dampkjøkken',),
'damplokomotiv': ('damplokomotiv',),
'damplokomotiva': ('damplokomotiv',),
'damplokomotivene': ('damplokomotiv',),
'damplokomotiver': ('damplokomotiv',),
'damplokomotivet': ('damplokomotiv',),
'dampmaskin': ('dampmaskin',),
'dampmaskina': ('dampmaskin',),
'dampmaskinen': ('dampmaskin',),
'dampmaskinene': ('dampmaskin',),
'dampmaskiner': ('dampmaskin',),
'dampmotor': ('dampmotor',),
'dampmotoren': ('dampmotor',),
'dampmotorene': ('dampmotor',),
'dampmotorer': ('dampmotor',),
'dampradio': ('dampradio',),
'dampradioen': ('dampradio',),
'dampradioene': ('dampradio',),
'dampradioer': ('dampradio',),
'dampskip': ('dampskip',),
'dampskipa': ('dampskip',),
'dampskipene': ('dampskip',),
'dampskipet': ('dampskip',),
'dampskipsselskap': ('dampskipsselskap',),
'dampskipsselskapa': ('dampskipsselskap',),
'dampskipsselskapene': ('dampskipsselskap',),
'dampskipsselskaper': ('dampskipsselskap',),
'dampskipsselskapet': ('dampskipsselskap',),
'dampturbin': ('dampturbin',),
'dampturbinen': ('dampturbin',),
'dampturbinene': ('dampturbin',),
'dampturbiner': ('dampturbin',),
'dampvegvals': ('dampvegvals',),
'dampvegvalsen': ('dampvegvals',),
'dampvegvalsene': ('dampvegvals',),
'dampvegvalser': ('dampvegvals',),
'dampveivals': ('dampveivals',),
'dampveivalsen': ('dampveivals',),
'dampveivalsene': ('dampveivals',),
'dampveivalser': ('dampveivals',),
'damrokka': ('damrokke',),
'damrokke': ('damrokke',),
'damrokken': ('damrokke',),
'damrokkene': ('damrokke',),
'damrokker': ('damrokke',),
'damsnegl': ('damsnegl',),
'damsneglen': ('damsnegl',),
'damsneglene': ('damsnegl',),
'damsnegler': ('damsnegl',),
'damsnile': ('damsnile',),
'damsnilen': ('damsnile',),
'damsnilene': ('damsnile',),
'damsniler': ('damsnile',),
'damvokter': ('damvokter',),
'damvoktere': ('damvokter',),
'damvokteren': ('damvokter',),
'damvokterer': ('damvokter',),
'damvokterne': ('damvokter',),
'dandy': ('dandy',),
'dandyen': ('dandy',),
'dandyene': ('dandy',),
'dandyer': ('dandy',),
'dane': ('dane',),
'danen': ('dane',),
'danene': ('dane',),
'daner': ('dane',),
'danevelda': ('danevelde',),
'danevelde': ('danevelde',),
'daneveldene': ('danevelde',),
'danevelder': ('danevelde',),
'daneveldet': ('danevelde',),
'dangel': ('dangel',),
'dangelet': ('dangel',),
'dangla': ('dangel',),
'danglene': ('dangel',),
'dangler': ('dangel',),
'danglet': ('dangel',),
'danisme': ('danisme',),
'danismen': ('danisme',),
'danismene': ('danisme',),
'danismer': ('danisme',),
'dank': ('dank',),
'dannebrog': ('dannebrog',),
'dannebrogsorden': ('dannebrogsorden',),
'dannebrogsordenen': ('dannebrogsorden',),
'dannebrogsordenene': ('dannebrogsorden',),
'dannebrogsordener': ('dannebrogsorden',),
'dannelse': ('dannelse',),
'dannelsen': ('dannelse',),
'dannelsene': ('dannelse',),
'dannelser': ('dannelse',),
'dannelse': ('dannelse',),
'dannelsen': ('dannelse',),
'dannelsene': ('dannelse',),
'dannelser': ('dannelse',),
'dannelsesideal': ('dannelsesideal',),
'dannelsesideala': ('dannelsesideal',),
'dannelsesidealene': ('dannelsesideal',),
'dannelsesidealer': ('dannelsesideal',),
'dannelsesidealet': ('dannelsesideal',),
'dannelsesnivå': ('dannelsesnivå',),
'dannelsesnivåa': ('dannelsesnivå',),
'dannelsesnivåene': ('dannelsesnivå',),
'dannelsesnivåer': ('dannelsesnivå',),
'dannelsesnivået': ('dannelsesnivå',),
'dannelsesprosess': ('dannelsesprosess',),
'dannelsesprosessen': ('dannelsesprosess',),
'dannelsesprosessene': ('dannelsesprosess',),
'dannelsesprosesser': ('dannelsesprosess',),
'danning': ('danning',),
'danninga': ('danning',),
'danningen': ('danning',),
'danningene': ('danning',),
'danninger': ('danning',),
'danningsprosess': ('danningsprosess',),
'danningsprosessen': ('danningsprosess',),
'danningsprosessene': ('danningsprosess',),
'danningsprosesser': ('danningsprosess',),
'danoman': ('danoman',),
'danomanen': ('danoman',),
'danomanene': ('danoman',),
'danomaner': ('danoman',),
'danomani': ('danomani',),
'danomanien': ('danomani',),
'danomaniene': ('danomani',),
'danomanier': ('danomani',),
'dans': ('dans',),
'dansen': ('dans',),
'dansene': ('dans',),
'danser': ('dans',),
'dansarring': ('dansarring',),
'dansarringen': ('dansarring',),
'dansarringene': ('dansarring',),
'dansarringer': ('dansarring',),
'dansarslått': ('dansarslått',),
'dansarslåtten': ('dansarslått',),
'dansarslåttene': ('dansarslått',),
'dansarslåtter': ('dansarslått',),
'dansarvoll': ('dansarvoll',),
'dansarvollen': ('dansarvoll',),
'dansarvollene': ('dansarvoll',),
'dansarvoller': ('dansarvoll',),
'dansegolv': ('dansegolv',),
'dansegolva': ('dansegolv',),
'dansegolvene': ('dansegolv',),
'dansegolvet': ('dansegolv',),
'dansegulv': ('dansegulv',),
'dansegulva': ('dansegulv',),
'dansegulvene': ('dansegulv',),
'dansegulvet': ('dansegulv',),
'danselokala': ('danselokale',),
'danselokale': ('danselokale',),
'danselokalene': ('danselokale',),
'danselokaler': ('danselokale',),
'danselokalet': ('danselokale',),
'dansemoro': ('dansemoro',),
'dansemoroa': ('dansemoro',),
'dansemoroen': ('dansemoro',),
'dansemoroene': ('dansemoro',),
'dansemoroer': ('dansemoro',),
'dansemusikk': ('dansemusikk',),
'dansemusikken': ('dansemusikk',),
'dansemusikkene': ('dansemusikk',),
'dansemusikker': ('dansemusikk',),
'danser': ('danser',),
'dansere': ('danser',),
'danseren': ('danser',),
'danserer': ('danser',),
'danserne': ('danser',),
'danserestaurant': ('danserestaurant',),
'danserestauranten': ('danserestaurant',),
'danserestaurantene': ('danserestaurant',),
'danserestauranter': ('danserestaurant',),
'danseskole': ('danseskole',),
'danseskolen': ('danseskole',),
'danseskolene': ('danseskole',),
'danseskoler': ('danseskole',),
'dansetrinn': ('dansetrinn',),
'dansetrinna': ('dansetrinn',),
'dansetrinnene': ('dansetrinn',),
'dansetrinnet': ('dansetrinn',),
'dansevisa': ('dansevise',),
'dansevise': ('dansevise',),
'dansevisen': ('dansevise',),
'dansevisene': ('dansevise',),
'danseviser': ('dansevise',),
'dansk': ('dansk',),
'dansken': ('dansk',),
'danskene': ('dansk',),
'dansker': ('dansk',),
'dansk-norsk': ('dansk-norsk',),
'dansk-norsken': ('dansk-norsk',),
'dansk-norskene': ('dansk-norsk',),
'dansk-norsker': ('dansk-norsk',),
'danske': ('danske',),
'dansken': ('danske',),
'danskene': ('danske',),
'dansker': ('danske',),
'dansketid': ('dansketid',),
'dansketida': ('dansketid',),
'dansketiden': ('dansketid',),
'dansketidene': ('dansketid',),
'dansketider': ('dansketid',),
'dari': ('dari',),
'darien': ('dari',),
'dariene': ('dari',),
'darier': ('dari',),
'dark horse': ('dark horse',),
'darts': ('darts',),
'darwinisme': ('darwinisme',),
'darwinismen': ('darwinisme',),
'darwinismene': ('darwinisme',),
'darwinismer': ('darwinisme',),
'darwinist': ('darwinist',),
'darwinisten': ('darwinist',),
'darwinistene': ('darwinist',),
'darwinister': ('darwinist',),
'dash': ('dash',),
'dashen': ('dash',),
'dashene': ('dash',),
'dasher': ('dash',),
'dashbord': ('dashbord',),
'dashborda': ('dashbord',),
'dashbordene': ('dashbord',),
'dashborder': ('dashbord',),
'dashbordet': ('dashbord',),
'dask': ('dask',),
'daska': ('dask',),
'dasken': ('dask',),
'daskene': ('dask',),
'dasker': ('dask',),
'dasket': ('dask',),
'dass': ('dass',),
'dassa': ('dass',),
'dassen': ('dass',),
'dassene': ('dass',),
'dasser': ('dass',),
'dasset': ('dass',),
'data': ('data',),
'dataen': ('data',),
'dataene': ('data',),
'dataet': ('data',),
'dataanlegg': ('dataanlegg',),
'dataanlegga': ('dataanlegg',),
'dataanleggene': ('dataanlegg',),
'dataanlegget': ('dataanlegg',),
'databank': ('databank',),
'databanken': ('databank',),
'databankene': ('databank',),
'databanker': ('databank',),
'database': ('database',),
'databasen': ('database',),
'databasene': ('database',),
'databaser': ('database',),
'databehandling': ('databehandling',),
'databehandlinga': ('databehandling',),
'databehandlingen': ('databehandling',),
'databehandlingene': ('databehandling',),
'databehandlinger': ('databehandling',),
'databehandlingssystem': ('databehandlingssystem',),
'databehandlingssystema': ('databehandlingssystem',),
'databehandlingssystemene': ('databehandlingssystem',),
'databehandlingssystemer': ('databehandlingssystem',),
'databehandlingssystemet': ('databehandlingssystem',),
'databrikka': ('databrikke',),
'databrikke': ('databrikke',),
'databrikken': ('databrikke',),
'databrikkene': ('databrikke',),
'databrikker': ('databrikke',),
'datafrik': ('datafrik',),
'datafriken': ('datafrik',),
'datafrikene': ('datafrik',),
'datafriker': ('datafrik',),
'datagrafikk': ('datagrafikk',),
'datagrafikken': ('datagrafikk',),
'datagrafikkene': ('datagrafikk',),
'datagrafikker': ('datagrafikk',),
'datakraft': ('datakraft',),
'datakrafta': ('datakraft',),
'datakraften': ('datakraft',),
'datakreftene': ('datakraft',),
'datakrefter': ('datakraft',),
'datakriminalitet': ('datakriminalitet',),
'datakriminaliteten': ('datakriminalitet',),
'datakriminalitetene': ('datakriminalitet',),
'datakriminaliteter': ('datakriminalitet',),
'datalefsa': ('datalefse',),
'datalefse': ('datalefse',),
'datalefsen': ('datalefse',),
'datalefsene': ('datalefse',),
'datalefser': ('datalefse',),
'datalogi': ('datalogi',),
'datalogien': ('datalogi',),
'datalogiene': ('datalogi',),
'datalogier': ('datalogi',),
'datalov': ('datalov',),
'dataloven': ('datalov',),
'datalovene': ('datalov',),
'datalover': ('datalov',),
'datamaskin': ('datamaskin',),
'datamaskina': ('datamaskin',),
'datamaskinen': ('datamaskin',),
'datamaskinene': ('datamaskin',),
'datamaskiner': ('datamaskin',),
'datamaskinnett': ('datamaskinnett',),
'datamaskinnetta': ('datamaskinnett',),
'datamaskinnettene': ('datamaskinnett',),
'datamaskinnettet': ('datamaskinnett',),
'datamaskinspråk': ('datamaskinspråk',),
'datamaskinspråka': ('datamaskinspråk',),
'datamaskinspråkene': ('datamaskinspråk',),
'datamaskinspråket': ('datamaskinspråk',),
'datamatikk': ('datamatikk',),
'datamatikken': ('datamatikk',),
'datamatikkene': ('datamatikk',),
'datamatikker': ('datamatikk',),
'datanett': ('datanett',),
'datanetta': ('datanett',),
'datanettene': ('datanett',),
'datanettet': ('datanett',),
'dataoverføring': ('dataoverføring',),
'dataoverføringa': ('dataoverføring',),
'dataoverføringen': ('dataoverføring',),
'dataoverføringene': ('dataoverføring',),
'dataoverføringer': ('dataoverføring',),
'dataprogram': ('dataprogram',),
'dataprogramma': ('dataprogram',),
'dataprogrammene': ('dataprogram',),
'dataprogrammer': ('dataprogram',),
'dataprogrammet': ('dataprogram',),
'datasett': ('datasett',),
'datasetta': ('datasett',),
'datasettene': ('datasett',),
'datasettet': ('datasett',),
'datasikring': ('datasikring',),
'datasikringa': ('datasikring',),
'datasikringen': ('datasikring',),
'datasikringene': ('datasikring',),
'datasikringer': ('datasikring',),
'dataskjerm': ('dataskjerm',),
'dataskjermen': ('dataskjerm',),
'dataskjermene': ('dataskjerm',),
'dataskjermer': ('dataskjerm',),
'datasnok': ('datasnok',),
'datasnoken': ('datasnok',),
'datasnokene': ('datasnok',),
'datasnoker': ('datasnok',),
'datasnoker': ('datasnoker',),
'datasnokere': ('datasnoker',),
'datasnokeren': ('datasnoker',),
'datasnokerer': ('datasnoker',),
'datasnokerne': ('datasnoker',),
'datasnoking': ('datasnoking',),
'datasnokinga': ('datasnoking',),
'datasnokingen': ('datasnoking',),
'datasnokingene': ('datasnoking',),
'datasnokinger': ('datasnoking',),
'dataspråk': ('dataspråk',),
'dataspråka': ('dataspråk',),
'dataspråkene': ('dataspråk',),
'dataspråket': ('dataspråk',),
'datateknikk': ('datateknikk',),
'datateknikken': ('datateknikk',),
'datateknikkene': ('datateknikk',),
'datateknikker': ('datateknikk',),
'datateknologi': ('datateknologi',),
'datateknologien': ('datateknologi',),
'datateknologiene': ('datateknologi',),
'datateknologier': ('datateknologi',),
'dataterminal': ('dataterminal',),
'dataterminalen': ('dataterminal',),
'dataterminalene': ('dataterminal',),
'dataterminaler': ('dataterminal',),
'datatilsyn': ('datatilsyn',),
'datatilsyna': ('datatilsyn',),
'datatilsynene': ('datatilsyn',),
'datatilsynet': ('datatilsyn',),
'datatomografi': ('datatomografi',),
'datatomografien': ('datatomografi',),
'datatomografiene': ('datatomografi',),
'datatomografier': ('datatomografi',),
'datavern': ('datavern',),
'dataverna': ('datavern',),
'datavernene': ('datavern',),
'datavernet': ('datavern',),
'datavirus': ('datavirus',),
'datavirusa': ('datavirus',),
'datavirusene': ('datavirus',),
'dataviruset': ('datavirus',),
'datel': ('datel',),
'dateltjeneste': ('dateltjeneste',),
'dateltjenesten': ('dateltjeneste',),
'dateltjenestene': ('dateltjeneste',),
'dateltjenester': ('dateltjeneste',),
'datering': ('datering',),
'dateringa': ('datering',),
'dateringen': ('datering',),
'dateringene': ('datering',),
'dateringer': ('datering',),
'datid': ('datid',),
'datida': ('datid',),
'datiden': ('datid',),
'datidene': ('datid',),
'datider': ('datid',),
'dativ': ('dativ',),
'dativen': ('dativ',),
'dativene': ('dativ',),
'dativer': ('dativ',),
'dativform': ('dativform',),
'dativforma': ('dativform',),
'dativformen': ('dativform',),
'dativformene': ('dativform',),
'dativformer': ('dativform',),
'dato': ('dato',),
'datoen': ('dato',),
'datoene': ('dato',),
'datoer': ('dato',),
'datolinja': ('datolinje',),
'datolinje': ('datolinje',),
'datolinjen': ('datolinje',),
'datolinjene': ('datolinje',),
'datolinjer': ('datolinje',),
'datomerka': ('datomerke',),
'datomerke': ('datomerke',),
'datomerkene': ('datomerke',),
'datomerker': ('datomerke',),
'datomerket': ('datomerke',),
'datomerking': ('datomerking',),
'datomerkinga': ('datomerking',),
'datomerkingen': ('datomerking',),
'datomerkingene': ('datomerking',),
'datomerkinger': ('datomerking',),
'datoparkering': ('datoparkering',),
'datoparkeringa': ('datoparkering',),
'datoparkeringen': ('datoparkering',),
'datoparkeringene': ('datoparkering',),
'datoparkeringer': ('datoparkering',),
'dator': ('dator',),
'datoren': ('dator',),
'datorene': ('dator',),
'datorer': ('dator',),
'datostempel': ('datostempel',),
'datostempelet': ('datostempel',),
'datostempla': ('datostempel',),
'datostemplene': ('datostempel',),
'datostempler': ('datostempel',),
'datostemplet': ('datostempel',),
'datour': ('datour',),
'datoura': ('datour',),
'datourene': ('datour',),
'datouret': ('datour',),
'datoveksel': ('datoveksel',),
'datovekselen': ('datoveksel',),
'datovekslene': ('datoveksel',),
'datoveksler': ('datoveksel',),
'datter': ('datter',),
'dattera': ('datter',),
'datteren': ('datter',),
'døtre': ('datter',),
'døtrene': ('datter',),
'døtrer': ('datter',),
'datterbedrift': ('datterbedrift',),
'datterbedriften': ('datterbedrift',),
'datterbedriftene': ('datterbedrift',),
'datterbedrifter': ('datterbedrift',),
'datterdatter': ('datterdatter',),
'datterdattera': ('datterdatter',),
'datterdatteren': ('datterdatter',),
'datterdøtre': ('datterdatter',),
'datterdøtrene': ('datterdatter',),
'datterdøtrer': ('datterdatter',),
'datterselskap': ('datterselskap',),
'datterselskapa': ('datterselskap',),
'datterselskapene': ('datterselskap',),
'datterselskaper': ('datterselskap',),
'datterselskapet': ('datterselskap',),
'datterspråk': ('datterspråk',),
'datterspråka': ('datterspråk',),
'datterspråkene': ('datterspråk',),
'datterspråket': ('datterspråk',),
'dattersønn': ('dattersønn',),
'dattersønnen': ('dattersønn',),
'dattersønnene': ('dattersønn',),
'dattersønner': ('dattersønn',),
'data': ('datum',),
'dataene': ('datum',),
'datum': ('datum',),
'datumen': ('datum',),
'datumet': ('datum',),
'daudball': ('daudball',),
'daudballen': ('daudball',),
'daudballene': ('daudball',),
'daudballer': ('daudball',),
'daudballsituasjon': ('daudballsituasjon',),
'daudballsituasjonen': ('daudballsituasjon',),
'daudballsituasjonene': ('daudballsituasjon',),
'daudballsituasjoner': ('daudballsituasjon',),
'daudgang': ('daudgang',),
'daudgangen': ('daudgang',),
'daudgangene': ('daudgang',),
'daudganger': ('daudgang',),
'dauding': ('dauding',),
'daudingen': ('dauding',),
'daudingene': ('dauding',),
'daudinger': ('dauding',),
'daudinghoda': ('daudinghode',),
'daudinghode': ('daudinghode',),
'daudinghodene': ('daudinghode',),
'daudinghoder': ('daudinghode',),
'daudinghodet': ('daudinghode',),
'daudlinja': ('daudlinje',),
'daudlinje': ('daudlinje',),
'daudlinjen': ('daudlinje',),
'daudlinjene': ('daudlinje',),
'daudlinjer': ('daudlinje',),
'daudmannsknapp': ('daudmannsknapp',),
'daudmannsknappen': ('daudmannsknapp',),
'daudmannsknappene': ('daudmannsknapp',),
'daudmannsknapper': ('daudmannsknapp',),
'daudperiode': ('daudperiode',),
'daudperioden': ('daudperiode',),
'daudperiodene': ('daudperiode',),
'daudperioder': ('daudperiode',),
'daudpunkt': ('daudpunkt',),
'daudpunkta': ('daudpunkt',),
'daudpunktene': ('daudpunkt',),
'daudpunkter': ('daudpunkt',),
'daudpunktet': ('daudpunkt',),
'daudsesong': ('daudsesong',),
'daudsesongen': ('daudsesong',),
'daudsesongene': ('daudsesong',),
'daudsesonger': ('daudsesong',),
'daudsona': ('daudsone',),
'daudsone': ('daudsone',),
'daudsonen': ('daudsone',),
'daudsonene': ('daudsone',),
'daudsoner': ('daudsone',),
'daudtid': ('daudtid',),
'daudtida': ('daudtid',),
'daudtiden': ('daudtid',),
'daudtidene': ('daudtid',),
'daudtider': ('daudtid',),
'daudvekt': ('daudvekt',),
'daudvekta': ('daudvekt',),
'daudvekten': ('daudvekt',),
'daudvektene': ('daudvekt',),
'daudvekter': ('daudvekt',),
'daudvektlast': ('daudvektlast',),
'daudvektlasta': ('daudvektlast',),
'daudvektlasten': ('daudvektlast',),
'daudvektlastene': ('daudvektlast',),
'daudvektlaster': ('daudvektlast',),
'daudvekttonn': ('daudvekttonn',),
'daudvekttonna': ('daudvekttonn',),
'daudvekttonnene': ('daudvekttonn',),
'daudvekttonnet': ('daudvekttonn',),
'daugras': ('daugras',),
'daugrasa': ('daugras',),
'daugrasene': ('daugras',),
'daugraset': ('daugras',),
'daugress': ('daugress',),
'daugressa': ('daugress',),
'daugressene': ('daugress',),
'daugresset': ('daugress',),
'daujord': ('daujord',),
'daujorda': ('daujord',),
'daujorden': ('daujord',),
'daujordene': ('daujord',),
'daujorder': ('daujord',),
'daukjøtt': ('daukjøtt',),
'daukjøtta': ('daukjøtt',),
'daukjøttene': ('daukjøtt',),
'daukjøttet': ('daukjøtt',),
'daunesla': ('daunesle',),
'daunesle': ('daunesle',),
'dauneslen': ('daunesle',),
'dauneslene': ('daunesle',),
'daunesler': ('daunesle',),
'dauphin': ('dauphin',),
'dauphinen': ('dauphin',),
'dauphinene': ('dauphin',),
'dauphiner': ('dauphin',),
'dausekk': ('dausekk',),
'dausekken': ('dausekk',),
'dausekkene': ('dausekk',),
'dausekker': ('dausekk',),
'dauvnesla': ('dauvnesle',),
'dauvnesle': ('dauvnesle',),
'dauvneslen': ('dauvnesle',),
'dauvneslene': ('dauvnesle',),
'dauvnesler': ('dauvnesle',),
'davidsstjerna': ('davidsstjerne',),
'davidsstjerne': ('davidsstjerne',),
'davidsstjernen': ('davidsstjerne',),
'davidsstjernene': ('davidsstjerne',),
'davidsstjerner': ('davidsstjerne',),
'davit': ('davit',),
'daviten': ('davit',),
'davitene': ('davit',),
'daviter': ('davit',),
'de luxe': ('de luxe',),
'de luxe-modell': ('de luxe-modell',),
'de luxe-modellen': ('de luxe-modell',),
'de luxe-modellene': ('de luxe-modell',),
'de luxe-modeller': ('de luxe-modell',),
'de luxe-utgava': ('de luxe-utgave',),
'de luxe-utgave': ('de luxe-utgave',),
'de luxe-utgaven': ('de luxe-utgave',),
'de luxe-utgavene': ('de luxe-utgave',),
'de luxe-utgaver': ('de luxe-utgave',),
'deadline': ('deadline',),
'deadlinen': ('deadline',),
'deadlinene': ('deadline',),
'deadliner': ('deadline',),
'debatt': ('debatt',),
'debatten': ('debatt',),
'debattene': ('debatt',),
'debatter': ('debatt',),
'debatt-teknikk': ('debatt-teknikk',),
'debatt-teknikken': ('debatt-teknikk',),
'debatt-teknikkene': ('debatt-teknikk',),
'debatt-teknikker': ('debatt-teknikk',),
'debattant': ('debattant',),
'debattanten': ('debattant',),
'debattantene': ('debattant',),
'debattanter': ('debattant',),
'debatteknikk': ('debatteknikk',),
'debatteknikken': ('debatteknikk',),
'debatteknikkene': ('debatteknikk',),
'debatteknikker': ('debatteknikk',),
'debattnivå': ('debattnivå',),
'debattnivåa': ('debattnivå',),
'debattnivåene': ('debattnivå',),
'debattnivåer': ('debattnivå',),
'debattnivået': ('debattnivå',),
'debet': ('debet',),
'debeten': ('debet',),
'debetene': ('debet',),
'debeter': ('debet',),
'debetsida': ('debetside',),
'debetside': ('debetside',),
'debetsiden': ('debetside',),
'debetsidene': ('debetside',),
'debetsider': ('debetside',),
'debilitet': ('debilitet',),
'debiliteten': ('debilitet',),
'debilitetene': ('debilitet',),
'debiliteter': ('debilitet',),
'debitor': ('debitor',),
'debitoren': ('debitor',),
'debitorene': ('debitor',),
'debitorer': ('debitor',),
'debitorland': ('debitorland',),
'debitorlanda': ('debitorland',),
'debitorlandene': ('debitorland',),
'debitorlandet': ('debitorland',),
'debitorpost': ('debitorpost',),
'debitorposten': ('debitorpost',),
'debitorpostene': ('debitorpost',),
'debitorposter': ('debitorpost',),
'debut': ('debut',),
'debuten': ('debut',),
'debutene': ('debut',),
'debuter': ('debut',),
'debutant': ('debutant',),
'debutanten': ('debutant',),
'debutantene': ('debutant',),
'debutanter': ('debutant',),
'debutarbeid': ('debutarbeid',),
'debutarbeida': ('debutarbeid',),
'debutarbeidene': ('debutarbeid',),
'debutarbeider': ('debutarbeid',),
'debutarbeidet': ('debutarbeid',),
'debutkonsert': ('debutkonsert',),
'debutkonserten': ('debutkonsert',),
'debutkonsertene': ('debutkonsert',),
'debutkonserter': ('debutkonsert',),
'debutrolla': ('debutrolle',),
'debutrolle': ('debutrolle',),
'debutrollen': ('debutrolle',),
'debutrollene': ('debutrolle',),
'debutroller': ('debutrolle',),
'debutroman': ('debutroman',),
'debutromanen': ('debutroman',),
'debutromanene': ('debutroman',),
'debutromaner': ('debutroman',),
'decca': ('decca',),
'deccakjede': ('deccakjede',),
'deccakjeden': ('deccakjede',),
'deccakjedene': ('deccakjede',),
'deccakjeder': ('deccakjede',),
'deccasystem': ('deccasystem',),
'deccasystema': ('deccasystem',),
'deccasystemene': ('deccasystem',),
'deccasystemer': ('deccasystem',),
'deccasystemet': ('deccasystem',),
'decennia': ('decennium',),
'decenniene': ('decennium',),
'decennier': ('decennium',),
'decenniet': ('decennium',),
'decennium': ('decennium',),
'decharge': ('decharge',),
'dechargen': ('decharge',),
'dechargene': ('decharge',),
'decharger': ('decharge',),
'decrescendo': ('decrescendo',),
'decrescendoa': ('decrescendo',),
'decrescendoen': ('decrescendo',),
'decrescendoene': ('decrescendo',),
'decrescendoer': ('decrescendo',),
'decrescendoet': ('decrescendo',),
'dedikasjon': ('dedikasjon',),
'dedikasjonen': ('dedikasjon',),
'dedikasjonene': ('dedikasjon',),
'dedikasjoner': ('dedikasjon',),
'deduksjon': ('deduksjon',),
'deduksjonen': ('deduksjon',),
'deduksjonene': ('deduksjon',),
'deduksjoner': ('deduksjon',),
'defaitisme': ('defaitisme',),
'defaitismen': ('defaitisme',),
'defaitismene': ('defaitisme',),
'defaitismer': ('defaitisme',),
'defaitist': ('defaitist',),
'defaitisten': ('defaitist',),
'defaitistene': ('defaitist',),
'defaitister': ('defaitist',),
'defekt': ('defekt',),
'defekten': ('defekt',),
'defektene': ('defekt',),
'defekter': ('defekt',),
'defensiv': ('defensiv',),
'defensiven': ('defensiv',),
'defensivene': ('defensiv',),
'defensiver': ('defensiv',),
'defensivallianse': ('defensivallianse',),
'defensivalliansen': ('defensivallianse',),
'defensivalliansene': ('defensivallianse',),
'defensivallianser': ('defensivallianse',),
'defensor': ('defensor',),
'defensoren': ('defensor',),
'defensorene': ('defensor',),
'defensorer': ('defensor',),
'defensorat': ('defensorat',),
'defensorata': ('defensorat',),
'defensoratene': ('defensorat',),
'defensorater': ('defensorat',),
'defensoratet': ('defensorat',),
'defibrillering': ('defibrillering',),
'defibrilleringa': ('defibrillering',),
'defibrilleringen': ('defibrillering',),
'defibrilleringene': ('defibrillering',),
'defibrilleringer': ('defibrillering',),
'deficit': ('deficit',),
'deficiten': ('deficit',),
'deficitene': ('deficit',),
'deficiter': ('deficit',),
'defilea': ('defilé',),
'defileene': ('defilé',),
'defileer': ('defilé',),
'defileet': ('defilé',),
'defilé': ('defilé',),
'defiléa': ('defilé',),
'defiléene': ('defilé',),
'defiléer': ('defilé',),
'defiléet': ('defilé',),
'definisjon': ('definisjon',),
'definisjonen': ('definisjon',),
'definisjonene': ('definisjon',),
'definisjoner': ('definisjon',),
'definisjonsspørsmål': ('definisjonsspørsmål',),
'definisjonsspørsmåla': ('definisjonsspørsmål',),
'definisjonsspørsmålene': ('definisjonsspørsmål',),
'definisjonsspørsmålet': ('definisjonsspørsmål',),
'deflasjon': ('deflasjon',),
'deflasjonen': ('deflasjon',),
'deflasjonene': ('deflasjon',),
'deflasjoner': ('deflasjon',),
'deflasjonsperiode': ('deflasjonsperiode',),
'deflasjonsperioden': ('deflasjonsperiode',),
'deflasjonsperiodene': ('deflasjonsperiode',),
'deflasjonsperioder': ('deflasjonsperiode',),
'deflasjonspolitikk': ('deflasjonspolitikk',),
'deflasjonspolitikken': ('deflasjonspolitikk',),
'deflasjonspolitikkene': ('deflasjonspolitikk',),
'deflasjonspolitikker': ('deflasjonspolitikk',),
'deflektor': ('deflektor',),
'deflektoren': ('deflektor',),
'deflektorene': ('deflektor',),
'deflektorer': ('deflektor',),
'deformasjon': ('deformasjon',),
'deformasjonen': ('deformasjon',),
'deformasjonene': ('deformasjon',),
'deformasjoner': ('deformasjon',),
'deformasjonsherding': ('deformasjonsherding',),
'deformasjonsherdinga': ('deformasjonsherding',),
'deformasjonsherdingen': ('deformasjonsherding',),
'deformasjonsherdingene': ('deformasjonsherding',),
'deformasjonsherdinger': ('deformasjonsherding',),
'deformering': ('deformering',),
'deformeringa': ('deformering',),
'deformeringen': ('deformering',),
'deformeringene': ('deformering',),
'deformeringer': ('deformering',),
'deformitet': ('deformitet',),
'deformiteten': ('deformitet',),
'deformitetene': ('deformitet',),
'deformiteter': ('deformitet',),
'defroster': ('defroster',),
'defrostere': ('defroster',),
'defrosteren': ('defroster',),
'defrosterer': ('defroster',),
'defrosterne': ('defroster',),
'defrosteranlegg': ('defrosteranlegg',),
'defrosteranlegga': ('defrosteranlegg',),
'defrosteranleggene': ('defrosteranlegg',),
'defrosteranlegget': ('defrosteranlegg',),
'defrostervæska': ('defrostervæske',),
'defrostervæske': ('defrostervæske',),
'defrostervæsken': ('defrostervæske',),
'defrostervæskene': ('defrostervæske',),
'defrostervæsker': ('defrostervæske',),
'degenerasjon': ('degenerasjon',),
'degenerasjonen': ('degenerasjon',),
'degenerasjonene': ('degenerasjon',),
'degenerasjoner': ('degenerasjon',),
'degenerasjonstegn': ('degenerasjonstegn',),
'degenerasjonstegna': ('degenerasjonstegn',),
'degenerasjonstegnene': ('degenerasjonstegn',),
'degenerasjonstegnet': ('degenerasjonstegn',),
'degn': ('degn',),
'degnen': ('degn',),
'degnene': ('degn',),
'degner': ('degn',),
'dego': ('dego',),
'degoen': ('dego',),
'degoene': ('dego',),
'degoer': ('dego',),
'degradasjon': ('degradasjon',),
'degradasjonen': ('degradasjon',),
'degradasjonene': ('degradasjon',),
'degradasjoner': ('degradasjon',),
'degresjon': ('degresjon',),
'degresjonen': ('degresjon',),
'degresjonene': ('degresjon',),
'degresjoner': ('degresjon',),
'deig': ('deig',),
'deigen': ('deig',),
'deigene': ('deig',),
'deiger': ('deig',),
'deigtrau': ('deigtrau',),
'deigtraua': ('deigtrau',),
'deigtrauene': ('deigtrau',),
'deigtrauet': ('deigtrau',),
'deild': ('deild',),
'deilda': ('deild',),
'deilden': ('deild',),
'deildene': ('deild',),
'deilder': ('deild',),
'deildegast': ('deildegast',),
'deildegasten': ('deildegast',),
'deildegastene': ('deildegast',),
'deildegaster': ('deildegast',),
'deildestein': ('deildestein',),
'deildesteinen': ('deildestein',),
'deildesteinene': ('deildestein',),
'deildesteiner': ('deildestein',),
'deildetjuv': ('deildetjuv',),
'deildetjuven': ('deildetjuv',),
'deildetjuvene': ('deildetjuv',),
'deildetjuver': ('deildetjuv',),
'deildetyv': ('deildetyv',),
'deildetyven': ('deildetyv',),
'deildetyvene': ('deildetyv',),
'deildetyver': ('deildetyv',),
'deis': ('deis',),
'deisen': ('deis',),
'deisene': ('deis',),
'deiser': ('deis',),
'deisme': ('deisme',),
'deismen': ('deisme',),
'deismene': ('deisme',),
'deismer': ('deisme',),
'deist': ('deist',),
'deisten': ('deist',),
'deistene': ('deist',),
'deister': ('deist',),
'dejeuner': ('dejeuner',),
'dejeuneren': ('dejeuner',),
'dejeunerene': ('dejeuner',),
'dejeunerer': ('dejeuner',),
'dekadanse': ('dekadanse',),
'dekadansen': ('dekadanse',),
'dekadansene': ('dekadanse',),
'dekadanser': ('dekadanse',),
'dekadanselitteratur': ('dekadanselitteratur',),
'dekadanselitteraturen': ('dekadanselitteratur',),
'dekadanselitteraturene': ('dekadanselitteratur',),
'dekadanselitteraturer': ('dekadanselitteratur',),
'dekade': ('dekade',),
'dekaden': ('dekade',),
'dekadene': ('dekade',),
'dekader': ('dekade',),
'dekadent': ('dekadent',),
'dekadenten': ('dekadent',),
'dekadentene': ('dekadent',),
'dekadenter': ('dekadent',),
'dekagram': ('dekagram',),
'dekagramma': ('dekagram',),
'dekagrammene': ('dekagram',),
'dekagrammet': ('dekagram',),
'dekaliter': ('dekaliter',),
'dekaliteren': ('dekaliter',),
'dekaliterne': ('dekaliter',),
'dekalog': ('dekalog',),
'dekalogen': ('dekalog',),
'dekalogene': ('dekalog',),
'dekaloger': ('dekalog',),
'dekameter': ('dekameter',),
'dekameteren': ('dekameter',),
'dekameterne': ('dekameter',),
'dekan': ('dekan',),
'dekanen': ('dekan',),
'dekanene': ('dekan',),
'dekaner': ('dekan',),
'dekanat': ('dekanat',),
'dekanata': ('dekanat',),
'dekanatene': ('dekanat',),
'dekanater': ('dekanat',),
'dekanatet': ('dekanat',),
'dekanen': ('dekanus',),
'dekanene': ('dekanus',),
'dekaner': ('dekanus',),
'dekanus': ('dekanus',),
'dekapod': ('dekapod',),
'dekapoden': ('dekapod',),
'dekapodene': ('dekapod',),
'dekapoder': ('dekapod',),
'dekar': ('dekar',),
'dekara': ('dekar',),
'dekarene': ('dekar',),
'dekaret': ('dekar',),
'dekk': ('dekk',),
'dekka': ('dekk',),
'dekkene': ('dekk',),
'dekket': ('dekk',),
'dekkadressa': ('dekkadresse',),
'dekkadresse': ('dekkadresse',),
'dekkadressen': ('dekkadresse',),
'dekkadressene': ('dekkadresse',),
'dekkadresser': ('dekkadresse',),
'dekkblad': ('dekkblad',),
'dekkblada': ('dekkblad',),
'dekkbladene': ('dekkblad',),
'dekkblader': ('dekkblad',),
'dekkbladet': ('dekkblad',),
'dekka': ('dekke',),
'dekke': ('dekke',),
'dekkene': ('dekke',),
'dekker': ('dekke',),
'dekket': ('dekke',),
'dekken': ('dekken',),
'dekkena': ('dekken',),
'dekkenene': ('dekken',),
'dekkener': ('dekken',),
'dekkenet': ('dekken',),
'dekketallerken': ('dekketallerken',),
'dekketallerkenen': ('dekketallerken',),
'dekketallerkenene': ('dekketallerken',),
'dekketallerkener': ('dekketallerken',),
'dekketøy': ('dekketøy',),
'dekketøya': ('dekketøy',),
'dekketøyene': ('dekketøy',),
'dekketøyer': ('dekketøy',),
'dekketøyet': ('dekketøy',),
'dekkevna': ('dekkevne',),
'dekkevne': ('dekkevne',),
'dekkevnen': ('dekkevne',),
'dekkevnene': ('dekkevne',),
'dekkevner': ('dekkevne',),
'dekkfarge': ('dekkfarge',),
'dekkfargen': ('dekkfarge',),
'dekkfargene': ('dekkfarge',),
'dekkfarger': ('dekkfarge',),
'dekkfjær': ('dekkfjær',),
'dekkfjæra': ('dekkfjær',),
'dekkfjæren': ('dekkfjær',),
'dekkfjærene': ('dekkfjær',),
'dekkfjærer': ('dekkfjær',),
'dekkfjør': ('dekkfjør',),
'dekkfjøra': ('dekkfjør',),
'dekkfjøren': ('dekkfjør',),
'dekkfjørene': ('dekkfjør',),
'dekkfjører': ('dekkfjør',),
'dekkfrøing': ('dekkfrøing',),
'dekkfrøingen': ('dekkfrøing',),
'dekkfrøingene': ('dekkfrøing',),
'dekkfrøinger': ('dekkfrøing',),
'dekknavn': ('dekknavn',),
'dekknavna': ('dekknavn',),
'dekknavnene': ('dekknavn',),
'dekknavnet': ('dekknavn',),
'dekkorganisasjon': ('dekkorganisasjon',),
'dekkorganisasjonen': ('dekkorganisasjon',),
'dekkorganisasjonene': ('dekkorganisasjon',),
'dekkorganisasjoner': ('dekkorganisasjon',),
'dekksfartøy': ('dekksfartøy',),
'dekksfartøya': ('dekksfartøy',),
'dekksfartøyene': ('dekksfartøy',),
'dekksfartøyer': ('dekksfartøy',),
'dekksfartøyet': ('dekksfartøy',),
'dekksgutt': ('dekksgutt',),
'dekksgutten': ('dekksgutt',),
'dekksguttene': ('dekksgutt',),
'dekksgutter': ('dekksgutt',),
'dekksjenta': ('dekksjente',),
'dekksjente': ('dekksjente',),
'dekksjenten': ('dekksjente',),
'dekksjentene': ('dekksjente',),
'dekksjenter': ('dekksjente',),
'dekkslast': ('dekkslast',),
'dekkslasta': ('dekkslast',),
'dekkslasten': ('dekkslast',),
'dekkslastene': ('dekkslast',),
'dekkslaster': ('dekkslast',),
'dekksmannskap': ('dekksmannskap',),
'dekksmannskapa': ('dekksmannskap',),
'dekksmannskapene': ('dekksmannskap',),
'dekksmannskaper': ('dekksmannskap',),
'dekksmannskapet': ('dekksmannskap',),
'dekksoffiser': ('dekksoffiser',),
'dekksoffiseren': ('dekksoffiser',),
'dekksoffiserene': ('dekksoffiser',),
'dekksoffiserer': ('dekksoffiser',),
'dekkspassasjer': ('dekkspassasjer',),
'dekkspassasjeren': ('dekkspassasjer',),
'dekkspassasjerene': ('dekkspassasjer',),
'dekkspassasjerer': ('dekkspassasjer',),
'dekksplass': ('dekksplass',),
'dekksplassen': ('dekksplass',),
'dekksplassene': ('dekksplass',),
'dekksplasser': ('dekksplass',),
'dekkstilling': ('dekkstilling',),
'dekkstillinga': ('dekkstilling',),
'dekkstillingen': ('dekkstilling',),
'dekkstillingene': ('dekkstilling',),
'dekkstillinger': ('dekkstilling',),
'dekkstjeneste': ('dekkstjeneste',),
'dekkstjenesten': ('dekkstjeneste',),
'dekkstjenestene': ('dekkstjeneste',),
'dekkstjenester': ('dekkstjeneste',),
'dekkvev': ('dekkvev',),
'dekkveva': ('dekkvev',),
'dekkvevene': ('dekkvev',),
'dekkvevet': ('dekkvev',),
'deklamasjon': ('deklamasjon',),
'deklamasjonen': ('deklamasjon',),
'deklamasjonene': ('deklamasjon',),
'deklamasjoner': ('deklamasjon',),
'deklarasjon': ('deklarasjon',),
'deklarasjonen': ('deklarasjon',),
'deklarasjonene': ('deklarasjon',),
'deklarasjoner': ('deklarasjon',),
'deklinasjon': ('deklinasjon',),
'deklinasjonen': ('deklinasjon',),
'deklinasjonene': ('deklinasjon',),
'deklinasjoner': ('deklinasjon',),
'dekning': ('dekning',),
'dekninga': ('dekning',),
'dekningen': ('dekning',),
'dekningene': ('dekning',),
'dekninger': ('dekning',),
'dekningsbidrag': ('dekningsbidrag',),
'dekningsbidraga': ('dekningsbidrag',),
'dekningsbidragene': ('dekningsbidrag',),
'dekningsbidraget': ('dekningsbidrag',),
'dekningskjøp': ('dekningskjøp',),
'dekningskjøpa': ('dekningskjøp',),
'dekningskjøpene': ('dekningskjøp',),
'dekningskjøpet': ('dekningskjøp',),
'dekningstilskott': ('dekningstilskott',),
'dekningstilskotta': ('dekningstilskott',),
'dekningstilskottene': ('dekningstilskott',),
'dekningstilskottet': ('dekningstilskott',),
'dekningstilskudd': ('dekningstilskudd',),
'dekningstilskudda': ('dekningstilskudd',),
'dekningstilskuddene': ('dekningstilskudd',),
'dekningstilskuddet': ('dekningstilskudd',),
'dekoder': ('dekoder',),
'dekodere': ('dekoder',),
'dekoderen': ('dekoder',),
'dekoderer': ('dekoder',),
'dekoderne': ('dekoder',),
'dekokt': ('dekokt',),
'dekokta': ('dekokt',),
'dekoktene': ('dekokt',),
'dekokter': ('dekokt',),
'dekoktet': ('dekokt',),
'dekomposisjon': ('dekomposisjon',),
'dekomposisjonen': ('dekomposisjon',),
'dekomposisjonene': ('dekomposisjon',),
'dekomposisjoner': ('dekomposisjon',),
'dekor': ('dekor',),
'dekoren': ('dekor',),
'dekorene': ('dekor',),
'dekorer': ('dekor',),
'dekorasjon': ('dekorasjon',),
'dekorasjonen': ('dekorasjon',),
'dekorasjonene': ('dekorasjon',),
'dekorasjoner': ('dekorasjon',),
'dekoratør': ('dekoratør',),
'dekoratøren': ('dekoratør',),
'dekoratørene': ('dekoratør',),
'dekoratører': ('dekoratør',),
'dekort': ('dekort',),
'dekorten': ('dekort',),
'dekortene': ('dekort',),
'dekorter': ('dekort',),
'dekret': ('dekret',),
'dekreta': ('dekret',),
'dekretene': ('dekret',),
'dekreter': ('dekret',),
'dekretet': ('dekret',),
'deksel': ('deksel',),
'dekselet': ('deksel',),
'deksla': ('deksel',),
'dekslene': ('deksel',),
'deksler': ('deksel',),
'dekslet': ('deksel',),
'dekstrin': ('dekstrin',),
'dekstrina': ('dekstrin',),
'dekstrinene': ('dekstrin',),
'dekstrinet': ('dekstrin',),
'dekupør': ('dekupør',),
'dekupøren': ('dekupør',),
'dekupørene': ('dekupør',),
'dekupører': ('dekupør',),
'dekupørarbeid': ('dekupørarbeid',),
'dekupørarbeida': ('dekupørarbeid',),
'dekupørarbeidene': ('dekupørarbeid',),
'dekupørarbeider': ('dekupørarbeid',),
'dekupørarbeidet': ('dekupørarbeid',),
'del': ('del',),
'delen': ('del',),
'delene': ('del',),
'deler': ('del',),
'delaktighet': ('delaktighet',),
'delaktigheta': ('delaktighet',),
'delaktigheten': ('delaktighet',),
'delaktighetene': ('delaktighet',),
'delaktigheter': ('delaktighet',),
'dela': ('dele',),
'dele': ('dele',),
'delene': ('dele',),
'deler': ('dele',),
'delet': ('dele',),
'deleatur': ('deleatur',),
'deleaturen': ('deleatur',),
'deleaturene': ('deleatur',),
'deleaturer': ('deleatur',),
'deleaturtegn': ('deleaturtegn',),
'deleaturtegna': ('deleaturtegn',),
'deleaturtegnene': ('deleaturtegn',),
'deleaturtegnet': ('deleaturtegn',),
'deleforbud': ('deleforbud',),
'deleforbuda': ('deleforbud',),
'deleforbudene': ('deleforbud',),
'deleforbudet': ('deleforbud',),
'delegasjon': ('delegasjon',),
'delegasjonen': ('delegasjon',),
'delegasjonene': ('delegasjon',),
'delegasjoner': ('delegasjon',),
'delegat': ('delegat',),
'delegaten': ('delegat',),
'delegatene': ('delegat',),
'delegater': ('delegat',),
'delegering': ('delegering',),
'delegeringa': ('delegering',),
'delegeringen': ('delegering',),
'delegeringene': ('delegering',),
'delegeringer': ('delegering',),
'deleier': ('deleier',),
'deleiere': ('deleier',),
'deleieren': ('deleier',),
'deleierer': ('deleier',),
'deleierne': ('deleier',),
'deleksamen': ('deleksamen',),
'deleksamenen': ('deleksamen',),
'deleksamenene': ('deleksamen',),
'deleksamener': ('deleksamen',),
'delelager': ('delelager',),
'delelageret': ('delelager',),
'delelagra': ('delelager',),
'delelagre': ('delelager',),
'delelagrene': ('delelager',),
'delelagerekspeditør': ('delelagerekspeditør',),
'delelagerekspeditøren': ('delelagerekspeditør',),
'delelagerekspeditørene': ('delelagerekspeditør',),
'delelagerekspeditører': ('delelagerekspeditør',),
'delelinja': ('delelinje',),
'delelinje': ('delelinje',),
'delelinjen': ('delelinje',),
'delelinjene': ('delelinje',),
'delelinjer': ('delelinje',),
'delfin': ('delfin',),
'delfinen': ('delfin',),
'delfinene': ('delfin',),
'delfiner': ('delfin',),
'delikatesse': ('delikatesse',),
'delikatessen': ('delikatesse',),
'delikatessene': ('delikatesse',),
'delikatesser': ('delikatesse',),
'delikatesseforretning': ('delikatesseforretning',),
'delikatesseforretninga': ('delikatesseforretning',),
'delikatesseforretningen': ('delikatesseforretning',),
'delikatesseforretningene': ('delikatesseforretning',),
'delikatesseforretninger': ('delikatesseforretning',),
'delikt': ('delikt',),
'delikta': ('delikt',),
'deliktene': ('delikt',),
'delikter': ('delikt',),
'deliktet': ('delikt',),
'deling': ('deling',),
'delinga': ('deling',),
'delingen': ('deling',),
'delingene': ('deling',),
'delinger': ('deling',),
'delingsartikkel': ('delingsartikkel',),
'delingsartikkelen': ('delingsartikkel',),
'delingsartiklene': ('delingsartikkel',),
'delingsartikler': ('delingsartikkel',),
'delingslinja': ('delingslinje',),
'delingslinje': ('delingslinje',),
'delingslinjen': ('delingslinje',),
'delingslinjene': ('delingslinje',),
'delingslinjer': ('delingslinje',),
'delingspunkt': ('delingspunkt',),
'delingspunkta': ('delingspunkt',),
'delingspunktene': ('delingspunkt',),
'delingspunkter': ('delingspunkt',),
'delingspunktet': ('delingspunkt',),
'delingstal': ('delingstal',),
'delingstala': ('delingstal',),
'delingstalene': ('delingstal',),
'delingstalet': ('delingstal',),
'delingstall': ('delingstall',),
'delingstalla': ('delingstall',),
'delingstallene': ('delingstall',),
'delingstallet': ('delingstall',),
'delingstegn': ('delingstegn',),
'delingstegna': ('delingstegn',),
'delingstegnene': ('delingstegn',),
'delingstegnet': ('delingstegn',),
'delinkvent': ('delinkvent',),
'delinkventen': ('delinkvent',),
'delinkventene': ('delinkvent',),
'delinkventer': ('delinkvent',),
'delirant': ('delirant',),
'deliranten': ('delirant',),
'delirantene': ('delirant',),
'deliranter': ('delirant',),
'deliria': ('delirium',),
'deliriene': ('delirium',),
'delirier': ('delirium',),
'deliriet': ('delirium',),
'delirium': ('delirium',),
'delirium tremens': ('delirium tremens',),
'delkrederekonti': ('delkrederekonto',),
'delkrederekontiene': ('delkrederekonto',),
'delkrederekonto': ('delkrederekonto',),
'delkrederekontoen': ('delkrederekonto',),
'delkrederekontoene': ('delkrederekonto',),
'delkrederekontoer': ('delkrederekonto',),
'delkultur': ('delkultur',),
'delkulturen': ('delkultur',),
'delkulturene': ('delkultur',),
'delkulturer': ('delkultur',),
'delløsning': ('delløsning',),
'delløsninga': ('delløsning',),
'delløsningen': ('delløsning',),
'delløsningene': ('delløsning',),
'delløsninger': ('delløsning',),
'delløysing': ('delløysing',),
'delløysinga': ('delløysing',),
'delløysingen': ('delløysing',),
'delløysingene': ('delløysing',),
'delløysinger': ('delløysing',),
'delmengde': ('delmengde',),
'delmengden': ('delmengde',),
'delmengdene': ('delmengde',),
'delmengder': ('delmengde',),
'delstat': ('delstat',),
'delstaten': ('delstat',),
'delstatene': ('delstat',),
'delstater': ('delstat',),
'delstatsforsamling': ('delstatsforsamling',),
'delstatsforsamlinga': ('delstatsforsamling',),
'delstatsforsamlingen': ('delstatsforsamling',),
'delstatsforsamlingene': ('delstatsforsamling',),
'delstatsforsamlinger': ('delstatsforsamling',),
'delstatsregjering': ('delstatsregjering',),
'delstatsregjeringa': ('delstatsregjering',),
'delstatsregjeringen': ('delstatsregjering',),
'delstatsregjeringene': ('delstatsregjering',),
'delstatsregjeringer': ('delstatsregjering',),
'delta': ('delta',),
'deltaen': ('delta',),
'deltaene': ('delta',),
'deltaer': ('delta',),
'delta': ('delta',),
'deltaene': ('delta',),
'deltaer': ('delta',),
'deltaet': ('delta',),
'deltadannelse': ('deltadannelse',),
'deltadannelsen': ('deltadannelse',),
'deltadannelsene': ('deltadannelse',),
'deltadannelser': ('deltadannelse',),
'deltadanning': ('deltadanning',),
'deltadanninga': ('deltadanning',),
'deltadanningen': ('deltadanning',),
'deltadanningene': ('deltadanning',),
'deltadanninger': ('deltadanning',),
'deltaing': ('deltaing',),
'deltainga': ('deltaing',),
'deltaingen': ('deltaing',),
'deltaingene': ('deltaing',),
'deltainger': ('deltaing',),
'deltakelse': ('deltakelse',),
'deltakelsen': ('deltakelse',),
'deltakelsene': ('deltakelse',),
'deltakelser': ('deltakelse',),
'deltaker': ('deltaker',),
'deltakere': ('deltaker',),
'deltakeren': ('deltaker',),
'deltakerer': ('deltaker',),
'deltakerne': ('deltaker',),
'deltaking': ('deltaking',),
'deltakinga': ('deltaking',),
'deltakingen': ('deltaking',),
'deltakingene': ('deltaking',),
'deltakinger': ('deltaking',),
'deltakobling': ('deltakobling',),
'deltakoblinga': ('deltakobling',),
'deltakoblingen': ('deltakobling',),
'deltakoblingene': ('deltakobling',),
'deltakoblinger': ('deltakobling',),
'deltakopling': ('deltakopling',),
'deltakoplinga': ('deltakopling',),
'deltakoplingen': ('deltakopling',),
'deltakoplingene': ('deltakopling',),
'deltakoplinger': ('deltakopling',),
'deltamuskel': ('deltamuskel',),
'deltamuskelen': ('deltamuskel',),
'deltamusklene': ('deltamuskel',),
'deltamuskler': ('deltamuskel',),
'deltastråling': ('deltastråling',),
'deltastrålinga': ('deltastråling',),
'deltastrålingen': ('deltastråling',),
'deltastrålingene': ('deltastråling',),
'deltastrålinger': ('deltastråling',),
'deltaveng': ('deltaveng',),
'deltavengen': ('deltaveng',),
'deltavengene': ('deltaveng',),
'deltavenger': ('deltaveng',),
'deltaving': ('deltaving',),
'deltavingen': ('deltaving',),
'deltavingene': ('deltaving',),
'deltavinger': ('deltaving',),
'deltavinge': ('deltavinge',),
'deltavingen': ('deltavinge',),
'deltavingene': ('deltavinge',),
'deltavinger': ('deltavinge',),
'deltid': ('deltid',),
'deltida': ('deltid',),
'deltiden': ('deltid',),
'deltidene': ('deltid',),
'deltider': ('deltid',),
'deltidsarbeid': ('deltidsarbeid',),
'deltidsarbeida': ('deltidsarbeid',),
'deltidsarbeidene': ('deltidsarbeid',),
'deltidsarbeider': ('deltidsarbeid',),
'deltidsarbeidet': ('deltidsarbeid',),
'deltidsarbeider': ('deltidsarbeider',),
'deltidsarbeidere': ('deltidsarbeider',),
'deltidsarbeideren': ('deltidsarbeider',),
'deltidsarbeiderer': ('deltidsarbeider',),
'deltidsarbeiderne': ('deltidsarbeider',),
'deltidsjobb': ('deltidsjobb',),
'deltidsjobben': ('deltidsjobb',),
'deltidsjobbene': ('deltidsjobb',),
'deltidsjobber': ('deltidsjobb',),
'deltidsstilling': ('deltidsstilling',),
'deltidsstillinga': ('deltidsstilling',),
'deltidsstillingen': ('deltidsstilling',),
'deltidsstillingene': ('deltidsstilling',),
'deltidsstillinger': ('deltidsstilling',),
'demagog': ('demagog',),
'demagogen': ('demagog',),
'demagogene': ('demagog',),
'demagoger': ('demagog',),
'demagogi': ('demagogi',),
'demagogien': ('demagogi',),
'demagogiene': ('demagogi',),
'demagogier': ('demagogi',),
'demarkasjonslinja': ('demarkasjonslinje',),
'demarkasjonslinje': ('demarkasjonslinje',),
'demarkasjonslinjen': ('demarkasjonslinje',),
'demarkasjonslinjene': ('demarkasjonslinje',),
'demarkasjonslinjer': ('demarkasjonslinje',),
'demens': ('demens',),
'demensen': ('demens',),
'demensene': ('demens',),
'demenser': ('demens',),
'dementi': ('dementi',),
'dementia': ('dementi',),
'dementiene': ('dementi',),
'dementier': ('dementi',),
'dementiet': ('dementi',),
'dementia': ('dementia',),
'demimonde': ('demimonde',),
'demimonden': ('demimonde',),
'demimondene': ('demimonde',),
'demimonder': ('demimonde',),
'demisjon': ('demisjon',),
'demisjonen': ('demisjon',),
'demisjonene': ('demisjon',),
'demisjoner': ('demisjon',),
'demisjonssøknad': ('demisjonssøknad',),
'demisjonssøknaden': ('demisjonssøknad',),
'demisjonssøknadene': ('demisjonssøknad',),
'demisjonssøknader': ('demisjonssøknad',),
'demning': ('demning',),
'demninga': ('demning',),
'demningen': ('demning',),
'demningene': ('demning',),
'demninger': ('demning',),
'demo': ('demo',),
'demoen': ('demo',),
'demoene': ('demo',),
'demoer': ('demo',),
'demografi': ('demografi',),
'demografien': ('demografi',),
'demografiene': ('demografi',),
'demografier': ('demografi',),
'demokrat': ('demokrat',),
'demokraten': ('demokrat',),
'demokratene': ('demokrat',),
'demokrater': ('demokrat',),
'demokrati': ('demokrati',),
'demokratia': ('demokrati',),
'demokratiene': ('demokrati',),
'demokratier': ('demokrati',),
'demokratiet': ('demokrati',),
'demokratiseringsprosess': ('demokratiseringsprosess',),
'demokratiseringsprosessen': ('demokratiseringsprosess',),
'demokratiseringsprosessene': ('demokratiseringsprosess',),
'demokratiseringsprosesser': ('demokratiseringsprosess',),
'demon': ('demon',),
'demonen': ('demon',),
'demonene': ('demon',),
'demoner': ('demon',),
'demonstrant': ('demonstrant',),
'demonstranten': ('demonstrant',),
'demonstrantene': ('demonstrant',),
'demonstranter': ('demonstrant',),
'demonstrasjon': ('demonstrasjon',),
'demonstrasjonen': ('demonstrasjon',),
'demonstrasjonene': ('demonstrasjon',),
'demonstrasjoner': ('demonstrasjon',),
'demonstrasjonsbil': ('demonstrasjonsbil',),
'demonstrasjonsbilen': ('demonstrasjonsbil',),
'demonstrasjonsbilene': ('demonstrasjonsbil',),
'demonstrasjonsbiler': ('demonstrasjonsbil',),
'demonstrasjonsfelt': ('demonstrasjonsfelt',),
'demonstrasjonsfelta': ('demonstrasjonsfelt',),
'demonstrasjonsfeltene': ('demonstrasjonsfelt',),
'demonstrasjonsfelter': ('demonstrasjonsfelt',),
'demonstrasjonsfeltet': ('demonstrasjonsfelt',),
'demonstrasjonsmøta': ('demonstrasjonsmøte',),
'demonstrasjonsmøte': ('demonstrasjonsmøte',),
'demonstrasjonsmøtene': ('demonstrasjonsmøte',),
'demonstrasjonsmøter': ('demonstrasjonsmøte',),
'demonstrasjonsmøtet': ('demonstrasjonsmøte',),
'demonstrasjonstog': ('demonstrasjonstog',),
'demonstrasjonstoga': ('demonstrasjonstog',),
'demonstrasjonstogene': ('demonstrasjonstog',),
'demonstrasjonstoget': ('demonstrasjonstog',),
'demonutdrivelse': ('demonutdrivelse',),
'demonutdrivelsen': ('demonutdrivelse',),
'demonutdrivelsene': ('demonutdrivelse',),
'demonutdrivelser': ('demonutdrivelse',),
'demonutdriving': ('demonutdriving',),
'demonutdrivinga': ('demonutdriving',),
'demonutdrivingen': ('demonutdriving',),
'demonutdrivingene': ('demonutdriving',),
'demonutdrivinger': ('demonutdriving',),
'demoralisasjon': ('demoralisasjon',),
'demoralisasjonen': ('demoralisasjon',),
'demoralisasjonene': ('demoralisasjon',),
'demoralisasjoner': ('demoralisasjon',),
'demper': ('demper',),
'dempere': ('demper',),
'demperen': ('demper',),
'demperer': ('demper',),
'demperne': ('demper',),
'demping': ('demping',),
'dempinga': ('demping',),
'dempingen': ('demping',),
'dempingene': ('demping',),
'dempinger': ('demping',),
'dempingsfaktor': ('dempingsfaktor',),
'dempingsfaktoren': ('dempingsfaktor',),
'dempingsfaktorene': ('dempingsfaktor',),
'dempingsfaktorer': ('dempingsfaktor',),
'dempingskraft': ('dempingskraft',),
'dempingskrafta': ('dempingskraft',),
'dempingskraften': ('dempingskraft',),
'dempingskreftene': ('dempingskraft',),
'dempingskrefter': ('dempingskraft',),
'dempning': ('dempning',),
'dempninga': ('dempning',),
'dempningen': ('dempning',),
'dempningene': ('dempning',),
'dempninger': ('dempning',),
'dempningsfaktor': ('dempningsfaktor',),
'dempningsfaktoren': ('dempningsfaktor',),
'dempningsfaktorene': ('dempningsfaktor',),
'dempningsfaktorer': ('dempningsfaktor',),
'dempningskraft': ('dempningskraft',),
'dempningskrafta': ('dempningskraft',),
'dempningskraften': ('dempningskraft',),
'dempningskreftene': ('dempningskraft',),
'dempningskrefter': ('dempningskraft',),
'demring': ('demring',),
'demringa': ('demring',),
'demringen': ('demring',),
'demringene': ('demring',),
'demringer': ('demring',),
'demringstid': ('demringstid',),
'demringstida': ('demringstid',),
'demringstiden': ('demringstid',),
'demringstidene': ('demringstid',),
'demringstider': ('demringstid',),
'demringstilstand': ('demringstilstand',),
'demringstilstanden': ('demringstilstand',),
'demringstilstandene': ('demringstilstand',),
'demringstilstander': ('demringstilstand',),
'denar': ('denar',),
'denaren': ('denar',),
'denarene': ('denar',),
'denarer': ('denar',),
'denier': ('denier',),
'denieren': ('denier',),
'denierene': ('denier',),
'denim': ('denim',),
'denimen': ('denim',),
'denimene': ('denim',),
'denimer': ('denim',),
'denitrifikasjon': ('denitrifikasjon',),
'denitrifikasjonen': ('denitrifikasjon',),
'denitrifikasjonene': ('denitrifikasjon',),
'denitrifikasjoner': ('denitrifikasjon',),
'denominativ': ('denominativ',),
'denominativa': ('denominativ',),
'denominativene': ('denominativ',),
'denominativer': ('denominativ',),
'denominativet': ('denominativ',),
'denotasjon': ('denotasjon',),
'denotasjonen': ('denotasjon',),
'denotasjonene': ('denotasjon',),
'denotasjoner': ('denotasjon',),
'densitet': ('densitet',),
'densiteten': ('densitet',),
'densitetene': ('densitet',),
'densiteter': ('densitet',),
'dental': ('dental',),
'dentalen': ('dental',),
'dentalene': ('dental',),
'dentaler': ('dental',),
'denudasjon': ('denudasjon',),
'denudasjonen': ('denudasjon',),
'denudasjonene': ('denudasjon',),
'denudasjoner': ('denudasjon',),
'deodorant': ('deodorant',),
'deodoranten': ('deodorant',),
'deodorantene': ('deodorant',),
'deodoranter': ('deodorant',),
'deoksyribonukleinsyra': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyre': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyren': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyrene': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyrer': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyra': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyre': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyren': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyrene': ('deoksyribonukleinsyre',),
'deoksyribonukleinsyrer': ('deoksyribonukleinsyre',),
'departement': ('departement',),
'departementa': ('departement',),
'departementene': ('departement',),
'departementer': ('departement',),
'departementet': ('departement',),
'departementsråd': ('departementsråd',),
'departementsråden': ('departementsråd',),
'departementsrådene': ('departementsråd',),
'departementsråder': ('departementsråd',),
'departementssjef': ('departementssjef',),
'departementssjefen': ('departementssjef',),
'departementssjefene': ('departementssjef',),
'departementssjefer': ('departementssjef',),
'depesje': ('depesje',),
'depesjen': ('depesje',),
'depesjene': ('depesje',),
'depesjer': ('depesje',),
'deplasement': ('deplasement',),
'deplasementa': ('deplasement',),
'deplasementene': ('deplasement',),
'deplasementer': ('deplasement',),
'deplasementet': ('deplasement',),
'deponi': ('deponi',),
'deponia': ('deponi',),
'deponiene': ('deponi',),
'deponier': ('deponi',),
'deponiet': ('deponi',),
'deportasjon': ('deportasjon',),
'deportasjonen': ('deportasjon',),
'deportasjonene': ('deportasjon',),
'deportasjoner': ('deportasjon',),
'depositobevis': ('depositobevis',),
'depositobevisa': ('depositobevis',),
'depositobevisene': ('depositobevis',),
'depositobeviser': ('depositobevis',),
'depositobeviset': ('depositobevis',),
'deposita': ('depositum',),
'depositaene': ('depositum',),
'depositum': ('depositum',),
'deposituma': ('depositum',),
'depositumene': ('depositum',),
'depositumer': ('depositum',),
'depositumet': ('depositum',),
'depot': ('depot',),
'depota': ('depot',),
'depotene': ('depot',),
'depoter': ('depot',),
'depotet': ('depot',),
'depotavdeling': ('depotavdeling',),
'depotavdelinga': ('depotavdeling',),
'depotavdelingen': ('depotavdeling',),
'depotavdelingene': ('depotavdeling',),
'depotavdelinger': ('depotavdeling',),
'depravasjon': ('depravasjon',),
'depravasjonen': ('depravasjon',),
'depravasjonene': ('depravasjon',),
'depravasjoner': ('depravasjon',),
'depresjon': ('depresjon',),
'depresjonen': ('depresjon',),
'depresjonene': ('depresjon',),
'depresjoner': ('depresjon',),
'depresjonsperiode': ('depresjonsperiode',),
'depresjonsperioden': ('depresjonsperiode',),
'depresjonsperiodene': ('depresjonsperiode',),
'depresjonsperioder': ('depresjonsperiode',),
'dept': ('dept',),
'depta': ('dept',),
'deptene': ('dept',),
'depter': ('dept',),
'deptet': ('dept',),
'deputasjon': ('deputasjon',),
'deputasjonen': ('deputasjon',),
'deputasjonene': ('deputasjon',),
'deputasjoner': ('deputasjon',),
'deputertkammer': ('deputertkammer',),
'deputertkammeret': ('deputertkammer',),
'deputertkamra': ('deputertkammer',),
'deputertkamre': ('deputertkammer',),
'deputertkamrene': ('deputertkammer',),
'derby': ('derby',),
'derbya': ('derby',),
'derbyene': ('derby',),
'derbyer': ('derby',),
'derbyet': ('derby',),
'dereliksjon': ('dereliksjon',),
'dereliksjonen': ('dereliksjon',),
'dereliksjonene': ('dereliksjon',),
'dereliksjoner': ('dereliksjon',),
'derelikt': ('derelikt',),
'derelikta': ('derelikt',),
'dereliktene': ('derelikt',),
'derelikter': ('derelikt',),
'dereliktet': ('derelikt',),
'derivasjon': ('derivasjon',),
'derivasjonen': ('derivasjon',),
'derivasjonene': ('derivasjon',),
'derivasjoner': ('derivasjon',),
'derivat': ('derivat',),
'derivata': ('derivat',),
'derivatene': ('derivat',),
'derivater': ('derivat',),
'derivatet': ('derivat',),
'dermatologi': ('dermatologi',),
'dermatologien': ('dermatologi',),
'dermatologiene': ('dermatologi',),
'dermatologier': ('dermatologi',),
'derrik': ('derrik',),
'derriken': ('derrik',),
'derrikene': ('derrik',),
'derriker': ('derrik',),
'derrikkran': ('derrikkran',),
'derrikkrana': ('derrikkran',),
'derrikkranen': ('derrikkran',),
'derrikkranene': ('derrikkran',),
'derrikkraner': ('derrikkran',),
'dervisj': ('dervisj',),
'dervisjen': ('dervisj',),
'dervisjene': ('dervisj',),
'dervisjer': ('dervisj',),
'descendens': ('descendens',),
'descendensen': ('descendens',),
'descendensene': ('descendens',),
'descendenser': ('descendens',),
'descendensteori': ('descendensteori',),
'descendensteorien': ('descendensteori',),
'descendensteoriene': ('descendensteori',),
'descendensteorier': ('descendensteori',),
'descendent': ('descendent',),
'descendenten': ('descendent',),
'descendentene': ('descendent',),
'descendenter': ('descendent',),
'desember': ('desember',),
'desersjon': ('desersjon',),
'desersjonen': ('desersjon',),
'desersjonene': ('desersjon',),
'desersjoner': ('desersjon',),
'desertasjon': ('desertasjon',),
'desertasjonen': ('desertasjon',),
'desertasjonene': ('desertasjon',),
'desertasjoner': ('desertasjon',),
'desertering': ('desertering',),
'deserteringa': ('desertering',),
'deserteringen': ('desertering',),
'deserteringene': ('desertering',),
'deserteringer': ('desertering',),
'desertør': ('desertør',),
'desertøren': ('desertør',),
'desertørene': ('desertør',),
'desertører': ('desertør',),
'desibel': ('desibel',),
'desibelen': ('desibel',),
'desibelene': ('desibel',),
'design': ('design',),
'designa': ('design',),
'designen': ('design',),
'designene': ('design',),
'designer': ('design',),
'designet': ('design',),
'designer': ('designer',),
'designere': ('designer',),
'designeren': ('designer',),
'designerer': ('designer',),
'designerne': ('designer',),
'desigram': ('desigram',),
'desigramma': ('desigram',),
'desigrammene': ('desigram',),
'desigrammet': ('desigram',),
'desim': ('desim',),
'desimen': ('desim',),
'desimene': ('desim',),
'desimer': ('desim',),
'desimal': ('desimal',),
'desimalen': ('desimal',),
'desimalene': ('desimal',),
'desimaler': ('desimal',),
'desimalbrøk': ('desimalbrøk',),
'desimalbrøken': ('desimalbrøk',),
'desimalbrøkene': ('desimalbrøk',),
'desimalbrøker': ('desimalbrøk',),
'desimalkomma': ('desimalkomma',),
'desimalkommaene': ('desimalkomma',),
'desimalkommaer': ('desimalkomma',),
'desimalkommaet': ('desimalkomma',),
'desimalregning': ('desimalregning',),
'desimalregninga': ('desimalregning',),
'desimalregningen': ('desimalregning',),
'desimalregningene': ('desimalregning',),
'desimalregninger': ('desimalregning',),
'desimalrekning': ('desimalrekning',),
'desimalrekninga': ('desimalrekning',),
'desimalrekningen': ('desimalrekning',),
'desimalrekningene': ('desimalrekning',),
'desimalrekninger': ('desimalrekning',),
'desimalsystem': ('desimalsystem',),
'desimalsystema': ('desimalsystem',),
'desimalsystemene': ('desimalsystem',),
'desimalsystemer': ('desimalsystem',),
'desimalsystemet': ('desimalsystem',),
'desimaltal': ('desimaltal',),
'desimaltala': ('desimaltal',),
'desimaltalene': ('desimaltal',),
'desimaltalet': ('desimaltal',),
'desimaltall': ('desimaltall',),
'desimaltalla': ('desimaltall',),
'desimaltallene': ('desimaltall',),
'desimaltallet': ('desimaltall',),
'desimalvekt': ('desimalvekt',),
'desimalvekta': ('desimalvekt',),
'desimalvekten': ('desimalvekt',),
'desimalvektene': ('desimalvekt',),
'desimalvekter': ('desimalvekt',),
'desime': ('desime',),
'desimen': ('desime',),
'desimene': ('desime',),
'desimer': ('desime',),
'desinfeksjon': ('desinfeksjon',),
'desinfeksjonen': ('desinfeksjon',),
'desinfeksjonene': ('desinfeksjon',),
'desinfeksjoner': ('desinfeksjon',),
'desinfeksjonsmiddel': ('desinfeksjonsmiddel',),
'desinfeksjonsmiddelet': ('desinfeksjonsmiddel',),
'desinfeksjonsmidla': ('desinfeksjonsmiddel',),
'desinfeksjonsmidlene': ('desinfeksjonsmiddel',),
'desinfeksjonsmidler': ('desinfeksjonsmiddel',),
'desinfeksjonsmidlet': ('desinfeksjonsmiddel',),
'desinformasjon': ('desinformasjon',),
'desinformasjonen': ('desinformasjon',),
'desinformasjonene': ('desinformasjon',),
'desinformasjoner': ('desinformasjon',),
'desintegrasjon': ('desintegrasjon',),
'desintegrasjonen': ('desintegrasjon',),
'desintegrasjonene': ('desintegrasjon',),
'desintegrasjoner': ('desintegrasjon',),
'desintegrator': ('desintegrator',),
'desintegratoren': ('desintegrator',),
'desintegratorene': ('desintegrator',),
'desintegratorer': ('desintegrator',),
'desisjon': ('desisjon',),
'desisjonen': ('desisjon',),
'desisjonene': ('desisjon',),
'desisjoner': ('desisjon',),
'desisor': ('desisor',),
'desisoren': ('desisor',),
'desisorene': ('desisor',),
'desisorer': ('desisor',),
'desk': ('desk',),
'desken': ('desk',),
'deskene': ('desk',),
'desker': ('desk',),
'desksjef': ('desksjef',),
'desksjefen': ('desksjef',),
'desksjefene': ('desksjef',),
'desksjefer': ('desksjef',),
'desmer': ('desmer',),
'desmere': ('desmer',),
'desmeren': ('desmer',),
'desmerer': ('desmer',),
'desmerne': ('desmer',),
'desmerdyr': ('desmerdyr',),
'desmerdyra': ('desmerdyr',),
'desmerdyrene': ('desmerdyr',),
'desmerdyret': ('desmerdyr',),
'desoksyribonukleinsyra': ('desoksyribonukleinsyre',),
'desoksyribonukleinsyre': ('desoksyribonukleinsyre',),
'desoksyribonukleinsyren': ('desoksyribonukleinsyre',),
'desoksyribonukleinsyrene': ('desoksyribonukleinsyre',),
'desoksyribonukleinsyrer': ('desoksyribonukleinsyre',),
'desperado': ('desperado',),
'desperadoen': ('desperado',),
'desperadoene': ('desperado',),
'desperadoer': ('desperado',),
'desperasjon': ('desperasjon',),
'desperasjonen': ('desperasjon',),
'desperasjonene': ('desperasjon',),
'desperasjoner': ('desperasjon',),
'despot': ('despot',),
'despoten': ('despot',),
'despotene': ('despot',),
'despoter': ('despot',),
'despoti': ('despoti',),
'despotia': ('despoti',),
'despotiene': ('despoti',),
'despotier': ('despoti',),
'despotiet': ('despoti',),
'despotisme': ('despotisme',),
'despotismen': ('despotisme',),
'despotismene': ('despotisme',),
'despotismer': ('despotisme',),
'dess': ('dess',),
'dessen': ('dess',),
'dessene': ('dess',),
'desser': ('dess',),
'dess-moll': ('dess-moll',),
'dess-mollen': ('dess-moll',),
'dess-mollene': ('dess-moll',),
'dess-moller': ('dess-moll',),
'dessert': ('dessert',),
'desserten': ('dessert',),
'dessertene': ('dessert',),
'desserter': ('dessert',),
'dessertgaffel': ('dessertgaffel',),
'dessertgaffelen': ('dessertgaffel',),
'dessertgafflene': ('dessertgaffel',),
'dessertgaffler': ('dessertgaffel',),
'dessertgenerasjon': ('dessertgenerasjon',),
'dessertgenerasjonen': ('dessertgenerasjon',),
'dessertgenerasjonene': ('dessertgenerasjon',),
'dessertgenerasjoner': ('dessertgenerasjon',),
'dessertglas': ('dessertglas',),
'dessertglasa': ('dessertglas',),
'dessertglasene': ('dessertglas',),
'dessertglaset': ('dessertglas',),
'dessertglass': ('dessertglass',),
'dessertglassa': ('dessertglass',),
'dessertglassene': ('dessertglass',),
'dessertglasset': ('dessertglass',),
'dessertskei': ('dessertskei',),
'dessertskeia': ('dessertskei',),
'dessertskeien': ('dessertskei',),
'dessertskeiene': ('dessertskei',),
'dessertskeier': ('dessertskei',),
'dessertskje': ('dessertskje',),
'dessertskjea': ('dessertskje',),
'dessertskjeen': ('dessertskje',),
'dessertskjeene': ('dessertskje',),
'dessertskjeer': ('dessertskje',),
'desserttallerken': ('desserttallerken',),
'desserttallerkenen': ('desserttallerken',),
'desserttallerkenene': ('desserttallerken',),
'desserttallerkener': ('desserttallerken',),
'dessertvin': ('dessertvin',),
'dessertvinen': ('dessertvin',),
'dessertvinene': ('dessertvin',),
'dessertviner': ('dessertvin',),
'destillasjon': ('destillasjon',),
'destillasjonen': ('destillasjon',),
'destillasjonene': ('destillasjon',),
'destillasjoner': ('destillasjon',),
'destillasjonsapparat': ('destillasjonsapparat',),
'destillasjonsapparata': ('destillasjonsapparat',),
'destillasjonsapparatene': ('destillasjonsapparat',),
'destillasjonsapparater': ('destillasjonsapparat',),
'destillasjonsapparatet': ('destillasjonsapparat',),
'destillasjonsrest': ('destillasjonsrest',),
'destillasjonsresten': ('destillasjonsrest',),
'destillasjonsrestene': ('destillasjonsrest',),
'destillasjonsrester': ('destillasjonsrest',),
'destillat': ('destillat',),
'destillata': ('destillat',),
'destillatene': ('destillat',),
'destillater': ('destillat',),
'destillatet': ('destillat',),
'destillatør': ('destillatør',),
'destillatøren': ('destillatør',),
'destillatørene': ('destillatør',),
'destillatører': ('destillatør',),
'destinasjon': ('destinasjon',),
'destinasjonen': ('destinasjon',),
'destinasjonene': ('destinasjon',),
'destinasjoner': ('destinasjon',),
'destroyer': ('destroyer',),
'destroyere': ('destroyer',),
'destroyeren': ('destroyer',),
'destroyerer': ('destroyer',),
'destroyerne': ('destroyer',),
'destruksjon': ('destruksjon',),
'destruksjonen': ('destruksjon',),
'destruksjonene': ('destruksjon',),
'destruksjoner': ('destruksjon',),
'destruksjonsanlegg': ('destruksjonsanlegg',),
'destruksjonsanlegga': ('destruksjonsanlegg',),
'destruksjonsanleggene': ('destruksjonsanlegg',),
'destruksjonsanlegget': ('destruksjonsanlegg',),
'destruksjonsverk': ('destruksjonsverk',),
'destruksjonsverka': ('destruksjonsverk',),
'destruksjonsverkene': ('destruksjonsverk',),
'destruksjonsverker': ('destruksjonsverk',),
'destruksjonsverket': ('destruksjonsverk',),
'destruktivitet': ('destruktivitet',),
'destruktiviteten': ('destruktivitet',),
'destruktivitetene': ('destruktivitet',),
'destruktiviteter': ('destruktivitet',),
'detail': ('detail',),
'detalj': ('detalj',),
'detaljen': ('detalj',),
'detaljene': ('detalj',),
'detaljer': ('detalj',),
'detaljanalysa': ('detaljanalyse',),
'detaljanalyse': ('detaljanalyse',),
'detaljanalysen': ('detaljanalyse',),
'detaljanalysene': ('detaljanalyse',),
'detaljanalyser': ('detaljanalyse',),
'detaljhandel': ('detaljhandel',),
'detaljhandelen': ('detaljhandel',),
'detaljhandlene': ('detaljhandel',),
'detaljhandler': ('detaljhandel',),
'detaljist': ('detaljist',),
'detaljisten': ('detaljist',),
'detaljistene': ('detaljist',),
'detaljister': ('detaljist',),
'detaljkunnskap': ('detaljkunnskap',),
'detaljkunnskapen': ('detaljkunnskap',),
'detaljkunnskapene': ('detaljkunnskap',),
'detaljkunnskaper': ('detaljkunnskap',),
'detaljplanlegging': ('detaljplanlegging',),
'detaljplanlegginga': ('detaljplanlegging',),
'detaljplanleggingen': ('detaljplanlegging',),
'detaljplanleggingene': ('detaljplanlegging',),
'detaljplanlegginger': ('detaljplanlegging',),
'detaljpris': ('detaljpris',),
'detaljprisen': ('detaljpris',),
'detaljprisene': ('detaljpris',),
'detaljpriser': ('detaljpris',),
'detasjement': ('detasjement',),
'detasjementa': ('detasjement',),
'detasjementene': ('detasjement',),
'detasjementer': ('detasjement',),
'detasjementet': ('detasjement',),
'detektiv': ('detektiv',),
'detektiven': ('detektiv',),
'detektivene': ('detektiv',),
'detektiver': ('detektiv',),
'detektivroman': ('detektivroman',),
'detektivromanen': ('detektivroman',),
'detektivromanene': ('detektivroman',),
'detektivromaner': ('detektivroman',),
'detektor': ('detektor',),
'detektoren': ('detektor',),
'detektorene': ('detektor',),
'detektorer': ('detektor',),
'determinant': ('determinant',),
'determinanten': ('determinant',),
'determinantene': ('determinant',),
'determinanter': ('determinant',),
'determinativ': ('determinativ',),
'determinativa': ('determinativ',),
'determinativene': ('determinativ',),
'determinativer': ('determinativ',),
'determinativet': ('determinativ',),
'determinisme': ('determinisme',),
'determinismen': ('determinisme',),
'determinismene': ('determinisme',),
'determinismer': ('determinisme',),
'determinist': ('determinist',),
'deterministen': ('determinist',),
'deterministene': ('determinist',),
'determinister': ('determinist',),
'detonasjon': ('detonasjon',),
'detonasjonen': ('detonasjon',),
'detonasjonene': ('detonasjon',),
'detonasjoner': ('detonasjon',),
'detonator': ('detonator',),
'detonatoren': ('detonator',),
'detonatorene': ('detonator',),
'detonatorer': ('detonator',),
'deus ex machina': ('deus ex machina',),
'deuterium': ('deuterium',),
'deuteriuma': ('deuterium',),
'deuteriumene': ('deuterium',),
'deuteriumet': ('deuterium',),
'deuteriumoksid': ('deuteriumoksid',),
'deuteriumoksida': ('deuteriumoksid',),
'deuteriumoksidene': ('deuteriumoksid',),
'deuteriumoksider': ('deuteriumoksid',),
'deuteriumoksidet': ('deuteriumoksid',),
'deuteron': ('deuteron',),
'deuterona': ('deuteron',),
'deuteronen': ('deuteron',),
'deuteronene': ('deuteron',),
'deuteroner': ('deuteron',),
'deuteronet': ('deuteron',),
'deviasjon': ('deviasjon',),
'deviasjonen': ('deviasjon',),
'deviasjonene': ('deviasjon',),
'deviasjoner': ('deviasjon',),
'devise': ('devise',),
'devisen': ('devise',),
'devisene': ('devise',),
'deviser': ('devise',),
'devon': ('devon',),
'devonformasjon': ('devonformasjon',),
'devonformasjonen': ('devonformasjon',),
'devonformasjonene': ('devonformasjon',),
'devonformasjoner': ('devonformasjon',),
'devonperiode': ('devonperiode',),
'devonperioden': ('devonperiode',),
'devonperiodene': ('devonperiode',),
'devonperioder': ('devonperiode',),
'devonsystem': ('devonsystem',),
'devonsystema': ('devonsystem',),
'devonsystemene': ('devonsystem',),
'devonsystemer': ('devonsystem',),
'devonsystemet': ('devonsystem',),
'diabetes': ('diabetes',),
'diabetesen': ('diabetes',),
'diabetesene': ('diabetes',),
'diabeteser': ('diabetes',),
'diabetiker': ('diabetiker',),
'diabetikere': ('diabetiker',),
'diabetikeren': ('diabetiker',),
'diabetikerer': ('diabetiker',),
'diabetikerne': ('diabetiker',),
'diadem': ('diadem',),
'diadema': ('diadem',),
'diademene': ('diadem',),
'diademer': ('diadem',),
'diademet': ('diadem',),
'diafon': ('diafon',),
'diafonen': ('diafon',),
'diafonene': ('diafon',),
'diafoner': ('diafon',),
'diafoni': ('diafoni',),
'diafonien': ('diafoni',),
'diafoniene': ('diafoni',),
'diafonier': ('diafoni',),
'diafragma': ('diafragma',),
'diafragmaene': ('diafragma',),
'diafragmaer': ('diafragma',),
'diafragmaet': ('diafragma',),
'diagnose': ('diagnose',),
'diagnosen': ('diagnose',),
'diagnosene': ('diagnose',),
'diagnoser': ('diagnose',),
'diagnostiker': ('diagnostiker',),
'diagnostikere': ('diagnostiker',),
'diagnostikeren': ('diagnostiker',),
'diagnostikerer': ('diagnostiker',),
'diagnostikerne': ('diagnostiker',),
'diagnostikk': ('diagnostikk',),
'diagnostikken': ('diagnostikk',),
'diagnostikkene': ('diagnostikk',),
'diagnostikker': ('diagnostikk',),
'diagonal': ('diagonal',),
'diagonalen': ('diagonal',),
'diagonalene': ('diagonal',),
'diagonaler': ('diagonal',),
'diagonaldekk': ('diagonaldekk',),
'diagonaldekka': ('diagonaldekk',),
'diagonaldekkene': ('diagonaldekk',),
'diagonaldekket': ('diagonaldekk',),
'diagonalgang': ('diagonalgang',),
'diagonalgangen': ('diagonalgang',),
'diagonalgangene': ('diagonalgang',),
'diagonalganger': ('diagonalgang',),
'diagram': ('diagram',),
'diagramma': ('diagram',),
'diagrammene': ('diagram',),
'diagrammer': ('diagram',),
'diagrammet': ('diagram',),
'diakon': ('diakon',),
'diakonen': ('diakon',),
'diakonene': ('diakon',),
'diakoner': ('diakon',),
'diakonheim': ('diakonheim',),
'diakonheimen': ('diakonheim',),
'diakonheimene': ('diakonheim',),
'diakonheimer': ('diakonheim',),
'diakonhjem': ('diakonhjem',),
'diakonhjemma': ('diakonhjem',),
'diakonhjemmene': ('diakonhjem',),
'diakonhjemmet': ('diakonhjem',),
'diakoni': ('diakoni',),
'diakonien': ('diakoni',),
'diakoniene': ('diakoni',),
'diakonier': ('diakoni',),
'diakonissa': ('diakonisse',),
'diakonisse': ('diakonisse',),
'diakonissen': ('diakonisse',),
'diakonissene': ('diakonisse',),
'diakonisser': ('diakonisse',),
'diakonissehus': ('diakonissehus',),
'diakonissehusa': ('diakonissehus',),
'diakonissehusene': ('diakonissehus',),
'diakonissehuset': ('diakonissehus',),
'diakroni': ('diakroni',),
'diakronien': ('diakroni',),
'diakroniene': ('diakroni',),
'diakronier': ('diakroni',),
'dialekt': ('dialekt',),
'dialekten': ('dialekt',),
'dialektene': ('dialekt',),
'dialekter': ('dialekt',),
'dialektatlas': ('dialektatlas',),
'dialektatlasa': ('dialektatlas',),
'dialektatlasene': ('dialektatlas',),
'dialektatlaser': ('dialektatlas',),
'dialektatlaset': ('dialektatlas',),
'dialektgrensa': ('dialektgrense',),
'dialektgrense': ('dialektgrense',),
'dialektgrensen': ('dialektgrense',),
'dialektgrensene': ('dialektgrense',),
'dialektgrenser': ('dialektgrense',),
'dialektiker': ('dialektiker',),
'dialektikere': ('dialektiker',),
'dialektikeren': ('dialektiker',),
'dialektikerer': ('dialektiker',),
'dialektikerne': ('dialektiker',),
'dialektikk': ('dialektikk',),
'dialektikken': ('dialektikk',),
'dialektikkene': ('dialektikk',),
'dialektikker': ('dialektikk',),
'dialektisering': ('dialektisering',),
'dialektiseringa': ('dialektisering',),
'dialektiseringen': ('dialektisering',),
'dialektiseringene': ('dialektisering',),
'dialektiseringer': ('dialektisering',),
'dialektkart': ('dialektkart',),
'dialektkarta': ('dialektkart',),
'dialektkartene': ('dialektkart',),
'dialektkarter': ('dialektkart',),
'dialektkartet': ('dialektkart',),
'dialektolog': ('dialektolog',),
'dialektologen': ('dialektolog',),
'dialektologene': ('dialektolog',),
'dialektologer': ('dialektolog',),
'dialektologi': ('dialektologi',),
'dialektologien': ('dialektologi',),
'dialektologiene': ('dialektologi',),
'dialektologier': ('dialektologi',),
'dialektstudia': ('dialektstudium',),
'dialektstudiene': ('dialektstudium',),
'dialektstudier': ('dialektstudium',),
'dialektstudiet': ('dialektstudium',),
'dialektstudium': ('dialektstudium',),
'dialog': ('dialog',),
'dialogen': ('dialog',),
'dialogene': ('dialog',),
'dialoger': ('dialog',),
'dialyse': ('dialyse',),
'dialysen': ('dialyse',),
'dialysene': ('dialyse',),
'dialyser': ('dialyse',),
'diamant': ('diamant',),
'diamanten': ('diamant',),
'diamantene': ('diamant',),
'diamanter': ('diamant',),
'diamantboring': ('diamantboring',),
'diamantboringa': ('diamantboring',),
'diamantboringen': ('diamantboring',),
'diamantboringene': ('diamantboring',),
'diamantboringer': ('diamantboring',),
'diamantbryllup': ('diamantbryllup',),
'diamantbryllupa': ('diamantbryllup',),
'diamantbryllupene': ('diamantbryllup',),
'diamantbrylluper': ('diamantbryllup',),
'diamantbryllupet': ('diamantbryllup',),
'diamantnål': ('diamantnål',),
'diamantnåla': ('diamantnål',),
'diamantnålen': ('diamantnål',),
'diamantnålene': ('diamantnål',),
'diamantnåler': ('diamantnål',),
'diamantplata': ('diamantplate',),
'diamantplate': ('diamantplate',),
'diamantplaten': ('diamantplate',),
'diamantplatene': ('diamantplate',),
'diamantplater': ('diamantplate',),
'diamantring': ('diamantring',),
'diamantringen': ('diamantring',),
'diamantringene': ('diamantring',),
'diamantringer': ('diamantring',),
'diameter': ('diameter',),
'diametere': ('diameter',),
'diameteren': ('diameter',),
'diameterer': ('diameter',),
'diameterne': ('diameter',),
'diametre': ('diameter',),
'diametrene': ('diameter',),
'diametrer': ('diameter',),
'dianetikk': ('dianetikk',),
'dianetikken': ('dianetikk',),
'dianetikkene': ('dianetikk',),
'dianetikker': ('dianetikk',),
'diapositiv': ('diapositiv',),
'diapositiva': ('diapositiv',),
'diapositivene': ('diapositiv',),
'diapositiver': ('diapositiv',),
'diapositivet': ('diapositiv',),
'diareen': ('diaré',),
'diareene': ('diaré',),
'diareer': ('diaré',),
'diaré': ('diaré',),
'diaréen': ('diaré',),
'diaréene': ('diaré',),
'diaréer': ('diaré',),
'diaria': ('diarium',),
'diariene': ('diarium',),
'diarier': ('diarium',),
'diariet': ('diarium',),
'diarium': ('diarium',),
'dias': ('dias',),
'diasa': ('dias',),
'diasene': ('dias',),
'diaset': ('dias',),
'diaskop': ('diaskop',),
'diaskopa': ('diaskop',),
'diaskopene': ('diaskop',),
'diaskoper': ('diaskop',),
'diaskopet': ('diaskop',),
'diaspora': ('diaspora',),
'diasporaen': ('diaspora',),
'diasporaene': ('diaspora',),
'diasporaer': ('diaspora',),
'diastase': ('diastase',),
'diastasen': ('diastase',),
'diastasene': ('diastase',),
'diastaser': ('diastase',),
'diatermi': ('diatermi',),
'diatermien': ('diatermi',),
'diatermiene': ('diatermi',),
'diatermier': ('diatermi',),
'diatese': ('diatese',),
'diatesen': ('diatese',),
'diatesene': ('diatese',),
'diateser': ('diatese',),
'diatomeen': ('diatomé',),
'diatomeene': ('diatomé',),
'diatomeer': ('diatomé',),
'diatomé': ('diatomé',),
'diatoméen': ('diatomé',),
'diatoméene': ('diatomé',),
'diatoméer': ('diatomé',),
'diatonikk': ('diatonikk',),
'diatonikken': ('diatonikk',),
'diatonikkene': ('diatonikk',),
'diatonikker': ('diatonikk',),
'didaktikk': ('didaktikk',),
'didaktikken': ('didaktikk',),
'didaktikkene': ('didaktikk',),
'didaktikker': ('didaktikk',),
'didym': ('didym',),
'didyma': ('didym',),
'didymene': ('didym',),
'didymet': ('didym',),
'die': ('die',),
'diebarn': ('diebarn',),
'diebarna': ('diebarn',),
'diebarnene': ('diebarn',),
'diebarnet': ('diebarn',),
'diegiing': ('diegiing',),
'diegiinga': ('diegiing',),
'diegiingen': ('diegiing',),
'diegiingene': ('diegiing',),
'diegiinger': ('diegiing',),
'diegiving': ('diegiving',),
'diegivinga': ('diegiving',),
'diegivingen': ('diegiving',),
'diegivingene': ('diegiving',),
'diegivinger': ('diegiving',),
'diegivning': ('diegivning',),
'diegivninga': ('diegivning',),
'diegivningen': ('diegivning',),
'diegivningene': ('diegivning',),
'diegivninger': ('diegivning',),
'diemal': ('diemal',),
'diemala': ('diemal',),
'diemalene': ('diemal',),
'diemalet': ('diemal',),
'diesel': ('diesel',),
'dieselen': ('diesel',),
'dieslene': ('diesel',),
'diesler': ('diesel',),
'dieseldrift': ('dieseldrift',),
'dieseldrifta': ('dieseldrift',),
'dieseldriften': ('dieseldrift',),
'dieseldriftene': ('dieseldrift',),
'dieseldrifter': ('dieseldrift',),
'dieselmotor': ('dieselmotor',),
'dieselmotoren': ('dieselmotor',),
'dieselmotorene': ('dieselmotor',),
'dieselmotorer': ('dieselmotor',),
'dieselolja': ('dieselolje',),
'dieselolje': ('dieselolje',),
'dieseloljen': ('dieselolje',),
'dieseloljene': ('dieselolje',),
'dieseloljer': ('dieselolje',),
'diettpengene': ('diettpenger',),
'diettpenger': ('diettpenger',),
'dietylbarbitursyra': ('dietylbarbitursyre',),
'dietylbarbitursyre': ('dietylbarbitursyre',),
'dietylbarbitursyren': ('dietylbarbitursyre',),
'dietylbarbitursyrene': ('dietylbarbitursyre',),
'dietylbarbitursyrer': ('dietylbarbitursyre',),
'dietyleter': ('dietyleter',),
'dietyletere': ('dietyleter',),
'dietyleteren': ('dietyleter',),
'dietyleterer': ('dietyleter',),
'dietyleterne': ('dietyleter',),
'differanse': ('differanse',),
'differansen': ('differanse',),
'differansene': ('differanse',),
'differanser': ('differanse',),
'differens': ('differens',),
'differensen': ('differens',),
'differensene': ('differens',),
'differenser': ('differens',),
'differensial': ('differensial',),
'differensialen': ('differensial',),
'differensialene': ('differensial',),
'differensialer': ('differensial',),
'differensial': ('differensial',),
'differensiala': ('differensial',),
'differensialene': ('differensial',),
'differensialer': ('differensial',),
'differensialet': ('differensial',),
'differensialbrems': ('differensialbrems',),
'differensialbremsen': ('differensialbrems',),
'differensialbremsene': ('differensialbrems',),
'differensialbremser': ('differensialbrems',),
'differensialbremsa': ('differensialbremse',),
'differensialbremse': ('differensialbremse',),
'differensialbremsen': ('differensialbremse',),
'differensialbremsene': ('differensialbremse',),
'differensialbremser': ('differensialbremse',),
'differensialkobling': ('differensialkobling',),
'differensialkoblinga': ('differensialkobling',),
'differensialkoblingen': ('differensialkobling',),
'differensialkoblingene': ('differensialkobling',),
'differensialkoblinger': ('differensialkobling',),
'differensialkopling': ('differensialkopling',),
'differensialkoplinga': ('differensialkopling',),
'differensialkoplingen': ('differensialkopling',),
'differensialkoplingene': ('differensialkopling',),
'differensialkoplinger': ('differensialkopling',),
'differensialligning': ('differensialligning',),
'differensialligninga': ('differensialligning',),
'differensialligningen': ('differensialligning',),
'differensialligningene': ('differensialligning',),
'differensialligninger': ('differensialligning',),
'differensiallikning': ('differensiallikning',),
'differensiallikninga': ('differensiallikning',),
'differensiallikningen': ('differensiallikning',),
'differensiallikningene': ('differensiallikning',),
'differensiallikninger': ('differensiallikning',),
'differensialregning': ('differensialregning',),
'differensialregninga': ('differensialregning',),
'differensialregningen': ('differensialregning',),
'differensialregningene': ('differensialregning',),
'differensialregninger': ('differensialregning',),
'differensialrekning': ('differensialrekning',),
'differensialrekninga': ('differensialrekning',),
'differensialrekningen': ('differensialrekning',),
'differensialrekningene': ('differensialrekning',),
'differensialrekninger': ('differensialrekning',),
'differensialsperra': ('differensialsperre',),
'differensialsperre': ('differensialsperre',),
'differensialsperren': ('differensialsperre',),
'differensialsperrene': ('differensialsperre',),
'differensialsperrer': ('differensialsperre',),
'differensiasjon': ('differensiasjon',),
'differensiasjonen': ('differensiasjon',),
'differensiasjonene': ('differensiasjon',),
'differensiasjoner': ('differensiasjon',),
'differensiering': ('differensiering',),
'differensieringa': ('differensiering',),
'differensieringen': ('differensiering',),
'differensieringene': ('differensiering',),
'differensieringer': ('differensiering',),
'diffraksjon': ('diffraksjon',),
'diffraksjonen': ('diffraksjon',),
'diffraksjonene': ('diffraksjon',),
'diffraksjoner': ('diffraksjon',),
'diffusjon': ('diffusjon',),
'diffusjonen': ('diffusjon',),
'diffusjonene': ('diffusjon',),
'diffusjoner': ('diffusjon',),
'diffusjonsteori': ('diffusjonsteori',),
'diffusjonsteorien': ('diffusjonsteori',),
'diffusjonsteoriene': ('diffusjonsteori',),
'diffusjonsteorier': ('diffusjonsteori',),
'difteri': ('difteri',),
'difterien': ('difteri',),
'difteriene': ('difteri',),
'difterier': ('difteri',),
'difteribasill': ('difteribasill',),
'difteribasillen': ('difteribasill',),
'difteribasillene': ('difteribasill',),
'difteribasiller': ('difteribasill',),
'difterisera': ('difteriserum',),
'difteriseraene': ('difteriserum',),
'difteriserum': ('difteriserum',),
'difteriseruma': ('difteriserum',),
'difteriserumene': ('difteriserum',),
'difteriserumer': ('difteriserum',),
'difteriserumet': ('difteriserum',),
'difteritt': ('difteritt',),
'difteritten': ('difteritt',),
'difterittene': ('difteritt',),
'difteritter': ('difteritt',),
'difterittbasill': ('difterittbasill',),
'difterittbasillen': ('difterittbasill',),
'difterittbasillene': ('difterittbasill',),
'difterittbasiller': ('difterittbasill',),
'difterittsera': ('difterittserum',),
'difterittseraene': ('difterittserum',),
'difterittserum': ('difterittserum',),
'difterittseruma': ('difterittserum',),
'difterittserumene': ('difterittserum',),
'difterittserumer': ('difterittserum',),
'difterittserumet': ('difterittserum',),
'diftong': ('diftong',),
'diftongen': ('diftong',),
'diftongene': ('diftong',),
'diftonger': ('diftong',),
'diftongering': ('diftongering',),
'diftongeringa': ('diftongering',),
'diftongeringen': ('diftongering',),
'diftongeringene': ('diftongering',),
'diftongeringer': ('diftongering',),
'digel': ('digel',),
'digelen': ('digel',),
'diglene': ('digel',),
'digler': ('digel',),
'digelomn': ('digelomn',),
'digelomnen': ('digelomn',),
'digelomnene': ('digelomn',),
'digelomner': ('digelomn',),
'digelovn': ('digelovn',),
'digelovnen': ('digelovn',),
'digelovnene': ('digelovn',),
'digelovner': ('digelovn',),
'digelstål': ('digelstål',),
'digelståla': ('digelstål',),
'digelstålene': ('digelstål',),
'digelstålet': ('digelstål',),
'digitalmaskin': ('digitalmaskin',),
'digitalmaskina': ('digitalmaskin',),
'digitalmaskinen': ('digitalmaskin',),
'digitalmaskinene': ('digitalmaskin',),
'digitalmaskiner': ('digitalmaskin',),
'digitalur': ('digitalur',),
'digitalura': ('digitalur',),
'digitalurene': ('digitalur',),
'digitaluret': ('digitalur',),
'diglossi': ('diglossi',),
'diglossien': ('diglossi',),
'diglossiene': ('diglossi',),
'diglossier': ('diglossi',),
'dignitar': ('dignitar',),
'dignitaren': ('dignitar',),
'dignitarene': ('dignitar',),
'dignitarer': ('dignitar',),
'dignitet': ('dignitet',),
'digniteten': ('dignitet',),
'dignitetene': ('dignitet',),
'digniteter': ('dignitet',),
'dignitær': ('dignitær',),
'dignitæren': ('dignitær',),
'dignitærene': ('dignitær',),
'dignitærer': ('dignitær',),
'digresjon': ('digresjon',),
'digresjonen': ('digresjon',),
'digresjonene': ('digresjon',),
'digresjoner': ('digresjon',),
'dika': ('dike',),
'dike': ('dike',),
'dikene': ('dike',),
'diker': ('dike',),
'diket': ('dike',),
'dikemyr': ('dikemyr',),
'dikemyra': ('dikemyr',),
'dikemyren': ('dikemyr',),
'dikemyrene': ('dikemyr',),
'dikemyrer': ('dikemyr',),
'dikkedarene': ('dikkedarer',),
'dikkedarer': ('dikkedarer',),
'diklordifenyltrikloretan': ('diklordifenyltrikloretan',),
'diklordifenyltrikloretanen': ('diklordifenyltrikloretan',),
'diklordifenyltrikloretanene': ('diklordifenyltrikloretan',),
'diklordifenyltrikloretaner': ('diklordifenyltrikloretan',),
'dikotomi': ('dikotomi',),
'dikotomien': ('dikotomi',),
'dikotomiene': ('dikotomi',),
'dikotomier': ('dikotomi',),
'diksjon': ('diksjon',),
'diksjonen': ('diksjon',),
'diksjonene': ('diksjon',),
'diksjoner': ('diksjon',),
'dikt': ('dikt',),
'dikta': ('dikt',),
'diktene': ('dikt',),
'diktet': ('dikt',),
'diktafon': ('diktafon',),
'diktafonen': ('diktafon',),
'diktafonene': ('diktafon',),
'diktafoner': ('diktafon',),
'diktat': ('diktat',),
'diktaten': ('diktat',),
'diktatene': ('diktat',),
'diktater': ('diktat',),
'diktat': ('diktat',),
'diktata': ('diktat',),
'diktatene': ('diktat',),
'diktater': ('diktat',),
'diktatet': ('diktat',),
'diktator': ('diktator',),
'diktatoren': ('diktator',),
'diktatorene': ('diktator',),
'diktatorer': ('diktator',),
'diktatur': ('diktatur',),
'diktatura': ('diktatur',),
'diktaturene': ('diktatur',),
'diktaturer': ('diktatur',),
'diktaturet': ('diktatur',),
'diktaturstat': ('diktaturstat',),
'diktaturstaten': ('diktaturstat',),
'diktaturstatene': ('diktaturstat',),
'diktaturstater': ('diktaturstat',),
'diktekunst': ('diktekunst',),
'diktekunsten': ('diktekunst',),
'diktekunstene': ('diktekunst',),
'diktekunster': ('diktekunst',),
'dikter': ('dikter',),
'diktere': ('dikter',),
'dikteren': ('dikter',),
'dikterer': ('dikter',),
'dikterne': ('dikter',),
'dikterevna': ('dikterevne',),
'dikterevne': ('dikterevne',),
'dikterevnen': ('dikterevne',),
'dikterevnene': ('dikterevne',),
'dikterevner': ('dikterevne',),
'diktergasje': ('diktergasje',),
'diktergasjen': ('diktergasje',),
'diktergasjene': ('diktergasje',),
'diktergasjer': ('diktergasje',),
'dikteringsmaskin': ('dikteringsmaskin',),
'dikteringsmaskina': ('dikteringsmaskin',),
'dikteringsmaskinen': ('dikteringsmaskin',),
'dikteringsmaskinene': ('dikteringsmaskin',),
'dikteringsmaskiner': ('dikteringsmaskin',),
'dikterlønn': ('dikterlønn',),
'dikterlønna': ('dikterlønn',),
'dikterlønnen': ('dikterlønn',),
'dikterlønnene': ('dikterlønn',),
'dikterlønner': ('dikterlønn',),
'diktermaskin': ('diktermaskin',),
'diktermaskina': ('diktermaskin',),
'diktermaskinen': ('diktermaskin',),
'diktermaskinene': ('diktermaskin',),
'diktermaskiner': ('diktermaskin',),
'dikternatur': ('dikternatur',),
'dikternaturen': ('dikternatur',),
'dikternaturene': ('dikternatur',),
'dikternaturer': ('dikternatur',),
'dikteråra': ('dikteråre',),
'dikteråre': ('dikteråre',),
'dikteråren': ('dikteråre',),
'dikterårene': ('dikteråre',),
'dikterårer': ('dikteråre',),
'diktning': ('diktning',),
'diktninga': ('diktning',),
'diktningen': ('diktning',),
'diktningene': ('diktning',),
'diktninger': ('diktning',),
'diktsamling': ('diktsamling',),
'diktsamlinga': ('diktsamling',),
'diktsamlingen': ('diktsamling',),
'diktsamlingene': ('diktsamling',),
'diktsamlinger': ('diktsamling',),
'diktsyklus': ('diktsyklus',),
'diktsyklusen': ('diktsyklus',),
'diktsyklusene': ('diktsyklus',),
'diktsykluser': ('diktsyklus',),
'diktverk': ('diktverk',),
'diktverka': ('diktverk',),
'diktverkene': ('diktverk',),
'diktverker': ('diktverk',),
'diktverket': ('diktverk',),
'dilemma': ('dilemma',),
'dilemmaene': ('dilemma',),
'dilemmaer': ('dilemma',),
'dilemmaet': ('dilemma',),
'dilettant': ('dilettant',),
'dilettanten': ('dilettant',),
'dilettantene': ('dilettant',),
'dilettanter': ('dilettant',),
'dilettanteri': ('dilettanteri',),
'dilettanteria': ('dilettanteri',),
'dilettanteriene': ('dilettanteri',),
'dilettanterier': ('dilettanteri',),
'dilettanteriet': ('dilettanteri',),
'dilettantisme': ('dilettantisme',),
'dilettantismen': ('dilettantisme',),
'dilettantismene': ('dilettantisme',),
'dilettantismer': ('dilettantisme',),
'diligence': ('diligence',),
'diligencen': ('diligence',),
'diligencene': ('diligence',),
'diligencer': ('diligence',),
'dill': ('dill',),
'dillen': ('dill',),
'dillene': ('dill',),
'diller': ('dill',),
'dill': ('dill',),
'dilla': ('dill',),
'dillene': ('dill',),
'dillet': ('dill',),
'dilldall': ('dilldall',),
'dilldalla': ('dilldall',),
'dilldallene': ('dilldall',),
'dilldallet': ('dilldall',),
'dilla': ('dille',),
'dille': ('dille',),
'dillen': ('dille',),
'dillene': ('dille',),
'diller': ('dille',),
'dilt': ('dilt',),
'dilta': ('dilt',),
'dilten': ('dilt',),
'diltene': ('dilt',),
'dilter': ('dilt',),
'diltet': ('dilt',),
'diluvia': ('diluvium',),
'diluviene': ('diluvium',),
'diluvier': ('diluvium',),
'diluviet': ('diluvium',),
'diluvium': ('diluvium',),
'dim': ('dim',),
'dimmen': ('dim',),
'dimmene': ('dim',),
'dimmer': ('dim',),
'dime': ('dime',),
'dimen': ('dime',),
'dimene': ('dime',),
'dimes': ('dime',),
'dimensjon': ('dimensjon',),
'dimensjonen': ('dimensjon',),
'dimensjonene': ('dimensjon',),
'dimensjoner': ('dimensjon',),
'diminuendo': ('diminuendo',),
'diminuendoa': ('diminuendo',),
'diminuendoene': ('diminuendo',),
'diminuendoer': ('diminuendo',),
'diminuendoet': ('diminuendo',),
'diminutiv': ('diminutiv',),
'diminutiva': ('diminutiv',),
'diminutiven': ('diminutiv',),
'diminutivene': ('diminutiv',),
'diminutiver': ('diminutiv',),
'diminutivet': ('diminutiv',),
'diminutivendelse': ('diminutivendelse',),
'diminutivendelsen': ('diminutivendelse',),
'diminutivendelsene': ('diminutivendelse',),
'diminutivendelser': ('diminutivendelse',),
'diminutivending': ('diminutivending',),
'diminutivendinga': ('diminutivending',),
'diminutivendingen': ('diminutivending',),
'diminutivendingene': ('diminutivending',),
'diminutivendinger': ('diminutivending',),
'diminutivform': ('diminutivform',),
'diminutivforma': ('diminutivform',),
'diminutivformen': ('diminutivform',),
'diminutivformene': ('diminutivform',),
'diminutivformer': ('diminutivform',),
'dimisjon': ('dimisjon',),
'dimisjonen': ('dimisjon',),
'dimisjonene': ('dimisjon',),
'dimisjoner': ('dimisjon',),
'dimisspreken': ('dimisspreken',),
'dimissprekenen': ('dimisspreken',),
'dimissprekenene': ('dimisspreken',),
'dimissprekener': ('dimisspreken',),
'dimma': ('dimme',),
'dimme': ('dimme',),
'dimmen': ('dimme',),
'dimmene': ('dimme',),
'dimmer': ('dimme',),
'dimmefest': ('dimmefest',),
'dimmefesten': ('dimmefest',),
'dimmefestene': ('dimmefest',),
'dimmefester': ('dimmefest',),
'dimorfi': ('dimorfi',),
'dimorfien': ('dimorfi',),
'dimorfiene': ('dimorfi',),
'dimorfier': ('dimorfi',),
'dimorfisme': ('dimorfisme',),
'dimorfismen': ('dimorfisme',),
'dimorfismene': ('dimorfisme',),
'dimorfismer': ('dimorfisme',),
'dinar': ('dinar',),
'dinaren': ('dinar',),
'dinarene': ('dinar',),
'dinarer': ('dinar',),
'diner': ('diner',),
'dineren': ('diner',),
'dinerene': ('diner',),
'dinerer': ('diner',),
'dingel': ('dingel',),
'dingelet': ('dingel',),
'dingla': ('dingel',),
'dinglene': ('dingel',),
'dingler': ('dingel',),
'dinglet': ('dingel',),
'dingeldangel': ('dingeldangel',),
'dingeldangelet': ('dingeldangel',),
'dingeldangla': ('dingeldangel',),
'dingeldanglene': ('dingeldangel',),
'dingeldangler': ('dingeldangel',),
'dingeldanglet': ('dingeldangel',),
'dingo': ('dingo',),
'dingoen': ('dingo',),
'dingoene': ('dingo',),
'dingoer': ('dingo',),
'dings': ('dings',),
'dingsen': ('dings',),
'dingsene': ('dings',),
'dingser': ('dings',),
'dinosaur': ('dinosaur',),
'dinosauren': ('dinosaur',),
'dinosaurene': ('dinosaur',),
'dinosaurer': ('dinosaur',),
'dinosaurene': ('dinosaurus',),
'dinosaurer': ('dinosaurus',),
'dinosauriene': ('dinosaurus',),
'dinosaurier': ('dinosaurus',),
'dinosaurus': ('dinosaurus',),
'dinosaurusen': ('dinosaurus',),
'diode': ('diode',),
'dioden': ('diode',),
'diodene': ('diode',),
'dioder': ('diode',),
'dioksid': ('dioksid',),
'dioksida': ('dioksid',),
'dioksidene': ('dioksid',),
'dioksider': ('dioksid',),
'dioksidet': ('dioksid',),
'dioksin': ('dioksin',),
'dioksina': ('dioksin',),
'dioksinene': ('dioksin',),
'dioksiner': ('dioksin',),
'dioksinet': ('dioksin',),
'diopter': ('diopter',),
'diopteret': ('diopter',),
'dioptra': ('diopter',),
'dioptre': ('diopter',),
'dioptrene': ('diopter',),
'dioptret': ('diopter',),
'dioptersikta': ('dioptersikte',),
'dioptersikte': ('dioptersikte',),
'dioptersiktene': ('dioptersikte',),
'dioptersikter': ('dioptersikte',),
'dioptersiktet': ('dioptersikte',),
'dioptri': ('dioptri',),
'dioptrien': ('dioptri',),
'dioptriene': ('dioptri',),
'dioptrier': ('dioptri',),
'dioptrikk': ('dioptrikk',),
'dioptrikken': ('dioptrikk',),
'dioptrikkene': ('dioptrikk',),
'dioptrikker': ('dioptrikk',),
'diplokokk': ('diplokokk',),
'diplokokken': ('diplokokk',),
'diplokokkene': ('diplokokk',),
'diplokokker': ('diplokokk',),
'diplom': ('diplom',),
'diploma': ('diplom',),
'diplomene': ('diplom',),
'diplomer': ('diplom',),
'diplomet': ('diplom',),
'diplomat': ('diplomat',),
'diplomaten': ('diplomat',),
'diplomatene': ('diplomat',),
'diplomater': ('diplomat',),
'diplomataria': ('diplomatarium',),
'diplomatariene': ('diplomatarium',),
'diplomatarier': ('diplomatarium',),
'diplomatariet': ('diplomatarium',),
'diplomatarium': ('diplomatarium',),
'diplomatfrakk': ('diplomatfrakk',),
'diplomatfrakken': ('diplomatfrakk',),
'diplomatfrakkene': ('diplomatfrakk',),
'diplomatfrakker': ('diplomatfrakk',),
'diplomati': ('diplomati',),
'diplomatia': ('diplomati',),
'diplomatiene': ('diplomati',),
'diplomatiet': ('diplomati',),
'diplomatikk': ('diplomatikk',),
'diplomatikken': ('diplomatikk',),
'diplomatikkene': ('diplomatikk',),
'diplomatikker': ('diplomatikk',),
'diplomatkorps': ('diplomatkorps',),
'diplomatkorpsa': ('diplomatkorps',),
'diplomatkorpsene': ('diplomatkorps',),
'diplomatkorpset': ('diplomatkorps',),
'diplomatlosje': ('diplomatlosje',),
'diplomatlosjen': ('diplomatlosje',),
'diplomatlosjene': ('diplomatlosje',),
'diplomatlosjer': ('diplomatlosje',),
'diplomatpass': ('diplomatpass',),
'diplomatpassa': ('diplomatpass',),
'diplomatpassene': ('diplomatpass',),
'diplomatpasset': ('diplomatpass',),
'diplomeksamen': ('diplomeksamen',),
'diplomeksamenen': ('diplomeksamen',),
'diplomeksamenene': ('diplomeksamen',),
'diplomeksamener': ('diplomeksamen',),
'diplomingeniør': ('diplomingeniør',),
'diplomingeniøren': ('diplomingeniør',),
'diplomingeniørene': ('diplomingeniør',),
'diplomingeniører': ('diplomingeniør',),
'diplomøkonom': ('diplomøkonom',),
'diplomøkonomen': ('diplomøkonom',),
'diplomøkonomene': ('diplomøkonom',),
'diplomøkonomer': ('diplomøkonom',),
'diplopi': ('diplopi',),
'diplopien': ('diplopi',),
'diplopiene': ('diplopi',),
'diplopier': ('diplopi',),
'dipol': ('dipol',),
'dipolen': ('dipol',),
'dipolene': ('dipol',),
'dipoler': ('dipol',),
'dipolantenna': ('dipolantenne',),
'dipolantenne': ('dipolantenne',),
'dipolantennen': ('dipolantenne',),
'dipolantennene': ('dipolantenne',),
'dipolantenner': ('dipolantenne',),
'dipolmolekyl': ('dipolmolekyl',),
'dipolmolekyla': ('dipolmolekyl',),
'dipolmolekylene': ('dipolmolekyl',),
'dipolmolekyler': ('dipolmolekyl',),
'dipolmolekylet': ('dipolmolekyl',),
'dipp': ('dipp',),
'dippen': ('dipp',),
'dippene': ('dipp',),
'dipper': ('dipp',),
'direksjon': ('direksjon',),
'direksjonen': ('direksjon',),
'direksjonene': ('direksjon',),
'direksjoner': ('direksjon',),
'direksjonssekretær': ('direksjonssekretær',),
'direksjonssekretæren': ('direksjonssekretær',),
'direksjonssekretærene': ('direksjonssekretær',),
'direksjonssekretærer': ('direksjonssekretær',),
'direkten': ('direkten',),
'direktesalg': ('direktesalg',),
'direktesalga': ('direktesalg',),
'direktesalgene': ('direktesalg',),
'direktesalget': ('direktesalg',),
'direktesending': ('direktesending',),
'direktesendinga': ('direktesending',),
'direktesendingen': ('direktesending',),
'direktesendingene': ('direktesending',),
'direktesendinger': ('direktesending',),
'direktiv': ('direktiv',),
'direktiva': ('direktiv',),
'direktivene': ('direktiv',),
'direktiver': ('direktiv',),
'direktivet': ('direktiv',),
'direktorat': ('direktorat',),
'direktorata': ('direktorat',),
'direktoratene': ('direktorat',),
'direktorater': ('direktorat',),
'direktoratet': ('direktorat',),
'direktør': ('direktør',),
'direktøren': ('direktør',),
'direktørene': ('direktør',),
'direktører': ('direktør',),
'dirham': ('dirham',),
'dirhamen': ('dirham',),
'dirhamene': ('dirham',),
'dirigent': ('dirigent',),
'dirigenten': ('dirigent',),
'dirigentene': ('dirigent',),
'dirigenter': ('dirigent',),
'dirigentklubba': ('dirigentklubbe',),
'dirigentklubbe': ('dirigentklubbe',),
'dirigentklubben': ('dirigentklubbe',),
'dirigentklubbene': ('dirigentklubbe',),
'dirigentklubber': ('dirigentklubbe',),
'dirigentstokk': ('dirigentstokk',),
'dirigentstokken': ('dirigentstokk',),
'dirigentstokkene': ('dirigentstokk',),
'dirigentstokker': ('dirigentstokk',),
'dirigentverv': ('dirigentverv',),
'dirigentverva': ('dirigentverv',),
'dirigentvervene': ('dirigentverv',),
'dirigentvervet': ('dirigentverv',),
'dirk': ('dirk',),
'dirken': ('dirk',),
'dirkene': ('dirk',),
'dirker': ('dirk',),
'dirr': ('dirr',),
'dirra': ('dirr',),
'dirren': ('dirr',),
'dirrene': ('dirr',),
'dirrer': ('dirr',),
'dirret': ('dirr',),
'dirring': ('dirring',),
'dirringa': ('dirring',),
'dirringen': ('dirring',),
'dirringene': ('dirring',),
'dirringer': ('dirring',),
'dis': ('dis',),
'disen': ('dis',),
'disene': ('dis',),
'diser': ('dis',),
'dis': ('dis',),
'disa': ('dis',),
'disen': ('dis',),
'disene': ('dis',),
'diser': ('dis',),
'disagio': ('disagio',),
'disagioen': ('disagio',),
'disagioene': ('disagio',),
'disagioer': ('disagio',),
'disc-jockey': ('disc-jockey',),
'disc-jockeyen': ('disc-jockey',),
'disc-jockeyene': ('disc-jockey',),
'disc-jockeyer': ('disc-jockey',),
'disc-jockey': ('disc-jockey',),
'disc-jockeyen': ('disc-jockey',),
'disc-jockeyene': ('disc-jockey',),
'disc-jockeyer': ('disc-jockey',),
'disfavør': ('disfavør',),
'disfavøren': ('disfavør',),
'disfavørene': ('disfavør',),
'disfavører': ('disfavør',),
'disharmoni': ('disharmoni',),
'disharmonien': ('disharmoni',),
'disharmoniene': ('disharmoni',),
'disharmonier': ('disharmoni',),
'disiplin': ('disiplin',),
'disiplinen': ('disiplin',),
'disiplinene': ('disiplin',),
'disipliner': ('disiplin',),
'disiplinærreglement': ('disiplinærreglement',),
'disiplinærreglementa': ('disiplinærreglement',),
'disiplinærreglementene': ('disiplinærreglement',),
'disiplinærreglementer': ('disiplinærreglement',),
'disiplinærreglementet': ('disiplinærreglement',),
'disiplinærstraff': ('disiplinærstraff',),
'disiplinærstraffen': ('disiplinærstraff',),
'disiplinærstraffene': ('disiplinærstraff',),
'disiplinærstraffer': ('disiplinærstraff',),
'disiplene': ('disippel',),
'disipler': ('disippel',),
'disippel': ('disippel',),
'disippelen': ('disippel',),
'disjunksjon': ('disjunksjon',),
'disjunksjonen': ('disjunksjon',),
'disjunksjonene': ('disjunksjon',),
'disjunksjoner': ('disjunksjon',),
'disk': ('disk',),
'disken': ('disk',),
'diskene': ('disk',),
'disker': ('disk',),
'disk': ('disk',),
'disken': ('disk',),
'diskene': ('disk',),
'disker': ('disk',),
'diskant': ('diskant',),
'diskanten': ('diskant',),
'diskantene': ('diskant',),
'diskanter': ('diskant',),
'diskantnøkkel': ('diskantnøkkel',),
'diskantnøkkelen': ('diskantnøkkel',),
'diskantnøklene': ('diskantnøkkel',),
'diskantnøkler': ('diskantnøkkel',),
'diskedama': ('diskedame',),
'diskedame': ('diskedame',),
'diskedamen': ('diskedame',),
'diskedamene': ('diskedame',),
'diskedamer': ('diskedame',),
'diskenspringer': ('diskenspringer',),
'diskenspringere': ('diskenspringer',),
'diskenspringeren': ('diskenspringer',),
'diskenspringerer': ('diskenspringer',),
'diskenspringerne': ('diskenspringer',),
'diskett': ('diskett',),
'disketten': ('diskett',),
'diskettene': ('diskett',),
'disketter': ('diskett',),
'diskjockey': ('diskjockey',),
'diskjockeyen': ('diskjockey',),
'diskjockeyene': ('diskjockey',),
'diskjockeyer': ('diskjockey',),
'diskjockey': ('diskjockey',),
'diskjockeyen': ('diskjockey',),
'diskjockeyene': ('diskjockey',),
'diskjockeyer': ('diskjockey',),
'disko': ('disko',),
'diskoen': ('disko',),
'diskoene': ('disko',),
'diskoer': ('disko',),
'diskomusikk': ('diskomusikk',),
'diskomusikken': ('diskomusikk',),
'diskomusikkene': ('diskomusikk',),
'diskomusikker': ('diskomusikk',),
'diskonteringsdag': ('diskonteringsdag',),
'diskonteringsdagen': ('diskonteringsdag',),
'diskonteringsdagene': ('diskonteringsdag',),
'diskonteringsdager': ('diskonteringsdag',),
'diskontinuitet': ('diskontinuitet',),
'diskontinuiteten': ('diskontinuitet',),
'diskontinuitetene': ('diskontinuitet',),
'diskontinuiteter': ('diskontinuitet',),
'diskonto': ('diskonto',),
'diskontoen': ('diskonto',),
'diskontoene': ('diskonto',),
'diskontoer': ('diskonto',),
'diskontopolitikk': ('diskontopolitikk',),
'diskontopolitikken': ('diskontopolitikk',),
'diskontopolitikkene': ('diskontopolitikk',),
'diskontopolitikker': ('diskontopolitikk',),
'diskontosats': ('diskontosats',),
'diskontosatsen': ('diskontosats',),
'diskontosatsene': ('diskontosats',),
'diskontosatser': ('diskontosats',),
'diskontør': ('diskontør',),
'diskontøren': ('diskontør',),
'diskontørene': ('diskontør',),
'diskontører': ('diskontør',),
'diskos': ('diskos',),
'diskosen': ('diskos',),
'diskosene': ('diskos',),
'diskoser': ('diskos',),
'diskoskast': ('diskoskast',),
'diskoskasta': ('diskoskast',),
'diskoskastene': ('diskoskast',),
'diskoskastet': ('diskoskast',),
'diskotek': ('diskotek',),
'diskoteka': ('diskotek',),
'diskotekene': ('diskotek',),
'diskoteker': ('diskotek',),
'diskoteket': ('diskotek',),
'diskreditt': ('diskreditt',),
'diskreditten': ('diskreditt',),
'diskredittene': ('diskreditt',),
'diskreditter': ('diskreditt',),
'diskrepans': ('diskrepans',),
'diskrepansen': ('diskrepans',),
'diskrepansene': ('diskrepans',),
'diskrepanser': ('diskrepans',),
'diskresjon': ('diskresjon',),
'diskresjonen': ('diskresjon',),
'diskresjonene': ('diskresjon',),
'diskresjoner': ('diskresjon',),
'diskresjonsbrott': ('diskresjonsbrott',),
'diskresjonsbrotta': ('diskresjonsbrott',),
'diskresjonsbrottene': ('diskresjonsbrott',),
'diskresjonsbrottet': ('diskresjonsbrott',),
'diskresjonsbrudd': ('diskresjonsbrudd',),
'diskresjonsbrudda': ('diskresjonsbrudd',),
'diskresjonsbruddene': ('diskresjonsbrudd',),
'diskresjonsbruddet': ('diskresjonsbrudd',),
'diskriminering': ('diskriminering',),
'diskrimineringa': ('diskriminering',),
'diskrimineringen': ('diskriminering',),
'diskrimineringene': ('diskriminering',),
'diskrimineringer': ('diskriminering',),
'diskurs': ('diskurs',),
'diskursen': ('diskurs',),
'diskursene': ('diskurs',),
'diskurser': ('diskurs',),
'diskursanalysa': ('diskursanalyse',),
'diskursanalyse': ('diskursanalyse',),
'diskursanalysen': ('diskursanalyse',),
'diskursanalysene': ('diskursanalyse',),
'diskursanalyser': ('diskursanalyse',),
'diskusjon': ('diskusjon',),
'diskusjonen': ('diskusjon',),
'diskusjonene': ('diskusjon',),
'diskusjoner': ('diskusjon',),
'diskusjonsgruppa': ('diskusjonsgruppe',),
'diskusjonsgruppe': ('diskusjonsgruppe',),
'diskusjonsgruppen': ('diskusjonsgruppe',),
'diskusjonsgruppene': ('diskusjonsgruppe',),
'diskusjonsgrupper': ('diskusjonsgruppe',),
'diskusjonsinnlegg': ('diskusjonsinnlegg',),
'diskusjonsinnlegga': ('diskusjonsinnlegg',),
'diskusjonsinnleggene': ('diskusjonsinnlegg',),
'diskusjonsinnlegget': ('diskusjonsinnlegg',),
'diskusjonstema': ('diskusjonstema',),
'diskusjonstemaene': ('diskusjonstema',),
'diskusjonstemaer': ('diskusjonstema',),
'diskusjonstemaet': ('diskusjonstema',),
'diskvalifikasjon': ('diskvalifikasjon',),
'diskvalifikasjonen': ('diskvalifikasjon',),
'diskvalifikasjonene': ('diskvalifikasjon',),
'diskvalifikasjoner': ('diskvalifikasjon',),
'diskvalifisering': ('diskvalifisering',),
'diskvalifiseringa': ('diskvalifisering',),
'diskvalifiseringen': ('diskvalifisering',),
'diskvalifiseringene': ('diskvalifisering',),
'diskvalifiseringer': ('diskvalifisering',),
'dispasje': ('dispasje',),
'dispasjen': ('dispasje',),
'dispasjene': ('dispasje',),
'dispasjer': ('dispasje',),
'dispasjør': ('dispasjør',),
'dispasjøren': ('dispasjør',),
'dispasjørene': ('dispasjør',),
'dispasjører': ('dispasjør',),
'dispasjøreksamen': ('dispasjøreksamen',),
'dispasjøreksamenen': ('dispasjøreksamen',),
'dispasjøreksamenene': ('dispasjøreksamen',),
'dispasjøreksamener': ('dispasjøreksamen',),
'dispensasjon': ('dispensasjon',),
'dispensasjonen': ('dispensasjon',),
'dispensasjonene': ('dispensasjon',),
'dispensasjoner': ('dispensasjon',),
'dispenser': ('dispenser',),
'dispensere': ('dispenser',),
'dispenseren': ('dispenser',),
'dispenserer': ('dispenser',),
'dispenserne': ('dispenser',),
'displaced person': ('displaced person',),
'displaced persons': ('displaced person',),
'display': ('display',),
'displaya': ('display',),
'displayene': ('display',),
'displayer': ('display',),
'displayet': ('display',),
'disponent': ('disponent',),
'disponenten': ('disponent',),
'disponentene': ('disponent',),
'disponenter': ('disponent',),
'disposisjon': ('disposisjon',),
'disposisjonen': ('disposisjon',),
'disposisjonene': ('disposisjon',),
'disposisjoner': ('disposisjon',),
'disposisjonsfond': ('disposisjonsfond',),
'disposisjonsfonda': ('disposisjonsfond',),
'disposisjonsfondene': ('disposisjonsfond',),
'disposisjonsfondet': ('disposisjonsfond',),
'disposisjonsplan': ('disposisjonsplan',),
'disposisjonsplanen': ('disposisjonsplan',),
'disposisjonsplanene': ('disposisjonsplan',),
'disposisjonsplaner': ('disposisjonsplan',),
'disposisjonsrett': ('disposisjonsrett',),
'disposisjonsretten': ('disposisjonsrett',),
'disposisjonsrettene': ('disposisjonsrett',),
'disposisjonsretter': ('disposisjonsrett',),
'disputas': ('disputas',),
'disputasen': ('disputas',),
'disputasene': ('disputas',),
'disputaser': ('disputas',),
'disputt': ('disputt',),
'disputten': ('disputt',),
'disputtene': ('disputt',),
'disputter': ('disputt',),
'diss-moll': ('diss-moll',),
'diss-mollen': ('diss-moll',),
'diss-mollene': ('diss-moll',),
'diss-moller': ('diss-moll',),
'dissa': ('disse',),
'disse': ('disse',),
'dissen': ('disse',),
'dissene': ('disse',),
'disser': ('disse',),
'dissekerkniv': ('dissekerkniv',),
'dissekerkniven': ('dissekerkniv',),
'dissekerknivene': ('dissekerkniv',),
'dissekerkniver': ('dissekerkniv',),
'disseksjon': ('disseksjon',),
'disseksjonen': ('disseksjon',),
'disseksjonene': ('disseksjon',),
'disseksjoner': ('disseksjon',),
'disseksjonskniv': ('disseksjonskniv',),
'disseksjonskniven': ('disseksjonskniv',),
'disseksjonsknivene': ('disseksjonskniv',),
'disseksjonskniver': ('disseksjonskniv',),
'dissens': ('dissens',),
'dissensen': ('dissens',),
'dissensene': ('dissens',),
'dissenser': ('dissens',),
'dissenter': ('dissenter',),
'dissentere': ('dissenter',),
'dissenteren': ('dissenter',),
'dissenterer': ('dissenter',),
'dissenterne': ('dissenter',),
'dissenterkirka': ('dissenterkirke',),
'dissenterkirke': ('dissenterkirke',),
'dissenterkirken': ('dissenterkirke',),
'dissenterkirkene': ('dissenterkirke',),
'dissenterkirker': ('dissenterkirke',),
'dissenterkjerka': ('dissenterkjerke',),
'dissenterkjerke': ('dissenterkjerke',),
'dissenterkjerken': ('dissenterkjerke',),
'dissenterkjerkene': ('dissenterkjerke',),
'dissenterkjerker': ('dissenterkjerke',),
'dissentermenighet': ('dissentermenighet',),
'dissentermenigheta': ('dissentermenighet',),
'dissentermenigheten': ('dissentermenighet',),
'dissentermenighetene': ('dissentermenighet',),
'dissentermenigheter': ('dissentermenighet',),
'dissentersamfunn': ('dissentersamfunn',),
'dissentersamfunna': ('dissentersamfunn',),
'dissentersamfunnene': ('dissentersamfunn',),
'dissentersamfunnet': ('dissentersamfunn',),
'dissident': ('dissident',),
'dissidenten': ('dissident',),
'dissidentene': ('dissident',),
'dissidenter': ('dissident',),
'dissimilasjon': ('dissimilasjon',),
'dissimilasjonen': ('dissimilasjon',),
'dissimilasjonene': ('dissimilasjon',),
'dissimilasjoner': ('dissimilasjon',),
'dissonans': ('dissonans',),
'dissonansen': ('dissonans',),
'dissonansene': ('dissonans',),
'dissonanser': ('dissonans',),
'dissosiasjon': ('dissosiasjon',),
'dissosiasjonen': ('dissosiasjon',),
'dissosiasjonene': ('dissosiasjon',),
'dissosiasjoner': ('dissosiasjon',),
'distanse': ('distanse',),
'distansen': ('distanse',),
'distansene': ('distanse',),
'distanser': ('distanse',),
'distanseløper': ('distanseløper',),
'distanseløpere': ('distanseløper',),
'distanseløperen': ('distanseløper',),
'distanseløperer': ('distanseløper',),
'distanseløperne': ('distanseløper',),
'distansemerka': ('distansemerke',),
'distansemerke': ('distansemerke',),
'distansemerkene': ('distansemerke',),
'distansemerker': ('distansemerke',),
'distansemerket': ('distansemerke',),
'distanseseier': ('distanseseier',),
'distanseseiere': ('distanseseier',),
'distanseseieren': ('distanseseier',),
'distanseseierne': ('distanseseier',),
'distanseseire': ('distanseseier',),
'distanseseirene': ('distanseseier',),
'distanseseirer': ('distanseseier',),
'distinksjon': ('distinksjon',),
'distinksjonen': ('distinksjon',),
'distinksjonene': ('distinksjon',),
'distinksjoner': ('distinksjon',),
'distraksjon': ('distraksjon',),
'distraksjonen': ('distraksjon',),
'distraksjonene': ('distraksjon',),
'distraksjoner': ('distraksjon',),
'distribusjon': ('distribusjon',),
'distribusjonen': ('distribusjon',),
'distribusjonene': ('distribusjon',),
'distribusjoner': ('distribusjon',),
'distribusjonsapparat': ('distribusjonsapparat',),
'distribusjonsapparata': ('distribusjonsapparat',),
'distribusjonsapparatene': ('distribusjonsapparat',),
'distribusjonsapparater': ('distribusjonsapparat',),
'distribusjonsapparatet': ('distribusjonsapparat',),
'distribusjonskjede': ('distribusjonskjede',),
'distribusjonskjeden': ('distribusjonskjede',),
'distribusjonskjedene': ('distribusjonskjede',),
'distribusjonskjeder': ('distribusjonskjede',),
'distribusjonsledd': ('distribusjonsledd',),
'distribusjonsledda': ('distribusjonsledd',),
'distribusjonsleddene': ('distribusjonsledd',),
'distribusjonsleddet': ('distribusjonsledd',),
'distribusjonsnett': ('distribusjonsnett',),
'distribusjonsnetta': ('distribusjonsnett',),
'distribusjonsnettene': ('distribusjonsnett',),
'distribusjonsnettet': ('distribusjonsnett',),
'distributør': ('distributør',),
'distributøren': ('distributør',),
'distributørene': ('distributør',),
'distributører': ('distributør',),
'distrikt': ('distrikt',),
'distrikta': ('distrikt',),
'distriktene': ('distrikt',),
'distrikter': ('distrikt',),
'distriktet': ('distrikt',),
'distriktshelsetjeneste': ('distriktshelsetjeneste',),
'distriktshelsetjenesten': ('distriktshelsetjeneste',),
'distriktshelsetjenestene': ('distriktshelsetjeneste',),
'distriktshelsetjenester': ('distriktshelsetjeneste',),
'distriktshøgskole': ('distriktshøgskole',),
'distriktshøgskolen': ('distriktshøgskole',),
'distriktshøgskolene': ('distriktshøgskole',),
'distriktshøgskoler': ('distriktshøgskole',),
'distriktshøyskole': ('distriktshøyskole',),
'distriktshøyskolen': ('distriktshøyskole',),
'distriktshøyskolene': ('distriktshøyskole',),
'distriktshøyskoler': ('distriktshøyskole',),
'distriktskommando': ('distriktskommando',),
'distriktskommandoen': ('distriktskommando',),
'distriktskommandoene': ('distriktskommando',),
'distriktskommandoer': ('distriktskommando',),
'distriktslege': ('distriktslege',),
'distriktslegen': ('distriktslege',),
'distriktslegene': ('distriktslege',),
'distriktsleger': ('distriktslege',),
'distriktspolitikk': ('distriktspolitikk',),
'distriktspolitikken': ('distriktspolitikk',),
'distriktspolitikkene': ('distriktspolitikk',),
'distriktspolitikker': ('distriktspolitikk',),
'distriktsprogram': ('distriktsprogram',),
'distriktsprogramma': ('distriktsprogram',),
'distriktsprogrammene': ('distriktsprogram',),
'distriktsprogrammer': ('distriktsprogram',),
'distriktsprogrammet': ('distriktsprogram',),
'distriktssjef': ('distriktssjef',),
'distriktssjefen': ('distriktssjef',),
'distriktssjefene': ('distriktssjef',),
'distriktssjefer': ('distriktssjef',),
'distriktstannlege': ('distriktstannlege',),
'distriktstannlegen': ('distriktstannlege',),
'distriktstannlegene': ('distriktstannlege',),
'distriktstannleger': ('distriktstannlege',),
'distriktsutbygging': ('distriktsutbygging',),
'distriktsutbygginga': ('distriktsutbygging',),
'distriktsutbyggingen': ('distriktsutbygging',),
'distriktsutbyggingene': ('distriktsutbygging',),
'distriktsutbygginger': ('distriktsutbygging',),
'distriktsveterinær': ('distriktsveterinær',),
'distriktsveterinæren': ('distriktsveterinær',),
'distriktsveterinærene': ('distriktsveterinær',),
'distriktsveterinærer': ('distriktsveterinær',),
'dittografi': ('dittografi',),
'dittografien': ('dittografi',),
'dittografiene': ('dittografi',),
'dittografier': ('dittografi',),
'dityrambe': ('dityrambe',),
'dityramben': ('dityrambe',),
'dityrambene': ('dityrambe',),
'dityramber': ('dityrambe',),
'diva': ('diva',),
'divaen': ('diva',),
'divaene': ('diva',),
'divaer': ('diva',),
'divan': ('divan',),
'divanen': ('divan',),
'divanene': ('divan',),
'divaner': ('divan',),
'divanputa': ('divanpute',),
'divanpute': ('divanpute',),
'divanputen': ('divanpute',),
'divanputene': ('divanpute',),
'divanputer': ('divanpute',),
'divanteppa': ('divanteppe',),
'divanteppe': ('divanteppe',),
'divanteppene': ('divanteppe',),
'divantepper': ('divanteppe',),
'divanteppet': ('divanteppe',),
'divergens': ('divergens',),
'divergensen': ('divergens',),
'divergensene': ('divergens',),
'divergenser': ('divergens',),
'diversekonti': ('diversekonto',),
'diversekontiene': ('diversekonto',),
'diversekonto': ('diversekonto',),
'diversekontoen': ('diversekonto',),
'diversekontoene': ('diversekonto',),
'diversekontoer': ('diversekonto',),
'diversjon': ('diversjon',),
'diversjonen': ('diversjon',),
'diversjonene': ('diversjon',),
'diversjoner': ('diversjon',),
'divertimenti': ('divertimento',),
'divertimentiene': ('divertimento',),
'divertimento': ('divertimento',),
'divertimentoa': ('divertimento',),
'divertimentoene': ('divertimento',),
'divertimentoer': ('divertimento',),
'divertimentoet': ('divertimento',),
'divertissement': ('divertissement',),
'divertissementa': ('divertissement',),
'divertissementene': ('divertissement',),
'divertissementer': ('divertissement',),
'divertissementet': ('divertissement',),
'dividend': ('dividend',),
'dividenden': ('dividend',),
'dividendene': ('dividend',),
'dividender': ('dividend',),
'dividende': ('dividende',),
'dividenden': ('dividende',),
'dividendene': ('dividende',),
'dividender': ('dividende',),
'divisjon': ('divisjon',),
'divisjonen': ('divisjon',),
'divisjonene': ('divisjon',),
'divisjoner': ('divisjon',),
'divisjonsmusikk': ('divisjonsmusikk',),
'divisjonsmusikken': ('divisjonsmusikk',),
'divisjonsmusikkene': ('divisjonsmusikk',),
'divisjonsmusikker': ('divisjonsmusikk',),
'divisjonssjef': ('divisjonssjef',),
'divisjonssjefen': ('divisjonssjef',),
'divisjonssjefene': ('divisjonssjef',),
'divisjonssjefer': ('divisjonssjef',),
'divisjonstegn': ('divisjonstegn',),
'divisjonstegna': ('divisjonstegn',),
'divisjonstegnene': ('divisjonstegn',),
'divisjonstegnet': ('divisjonstegn',),
'divisor': ('divisor',),
'divisoren': ('divisor',),
'divisorene': ('divisor',),
'divisorer': ('divisor',),
'dixielandstil': ('dixielandstil',),
'dixielandstilen': ('dixielandstil',),
'dixielandstilene': ('dixielandstil',),
'dixielandstiler': ('dixielandstil',),
'djekel': ('djekel',),
'djekelen': ('djekel',),
'djeklene': ('djekel',),
'djekler': ('djekel',),
'djervhet': ('djervhet',),
'djervheta': ('djervhet',),
'djervheten': ('djervhet',),
'djervhetene': ('djervhet',),
'djervheter': ('djervhet',),
'djervskap': ('djervskap',),
'djervskapen': ('djervskap',),
'djervskapene': ('djervskap',),
'djervskaper': ('djervskap',),
'djevel': ('djevel',),
'djevelen': ('djevel',),
'djevlene': ('djevel',),
'djevler': ('djevel',),
'djevelskap': ('djevelskap',),
'djevelskapa': ('djevelskap',),
'djevelskapen': ('djevelskap',),
'djevelskapene': ('djevelskap',),
'djevelskaper': ('djevelskap',),
'djevelskapet': ('djevelskap',),
'djevlebesvergelse': ('djevlebesvergelse',),
'djevlebesvergelsen': ('djevlebesvergelse',),
'djevlebesvergelsene': ('djevlebesvergelse',),
'djevlebesvergelser': ('djevlebesvergelse',),
'djevlebesverger': ('djevlebesverger',),
'djevlebesvergere': ('djevlebesverger',),
'djevlebesvergeren': ('djevlebesverger',),
'djevlebesvergerer': ('djevlebesverger',),
'djevlebesvergerne': ('djevlebesverger',),
'djevlefrykt': ('djevlefrykt',),
'djevlefrykten': ('djevlefrykt',),
'djevlefryktene': ('djevlefrykt',),
'djevlefrykter': ('djevlefrykt',),
'djevlemaner': ('djevlemaner',),
'djevlemanere': ('djevlemaner',),
'djevlemaneren': ('djevlemaner',),
'djevlemanerer': ('djevlemaner',),
'djevlemanerne': ('djevlemaner',),
'djevleutdriver': ('djevleutdriver',),
'djevleutdrivere': ('djevleutdriver',),
'djevleutdriveren': ('djevleutdriver',),
'djevleutdriverer': ('djevleutdriver',),
'djevleutdriverne': ('djevleutdriver',),
'djiboutier': ('djiboutier',),
'djiboutiere': ('djiboutier',),
'djiboutieren': ('djiboutier',),
'djiboutierer': ('djiboutier',),
'djiboutierne': ('djiboutier',),
'djunke': ('djunke',),
'djunken': ('djunke',),
'djunkene': ('djunke',),
'djunker': ('djunke',),
'djup': ('djup',),
'djupa': ('djup',),
'djupene': ('djup',),
'djupet': ('djup',),
'djupbergart': ('djupbergart',),
'djupbergarta': ('djupbergart',),
'djupbergarten': ('djupbergart',),
'djupbergartene': ('djupbergart',),
'djupbergarter': ('djupbergart',),
'djupboring': ('djupboring',),
'djupboringa': ('djupboring',),
'djupboringen': ('djupboring',),
'djupboringene': ('djupboring',),
'djupboringer': ('djupboring',),
'djupdykking': ('djupdykking',),
'djupdykkinga': ('djupdykking',),
'djupdykkingen': ('djupdykking',),
'djupdykkingene': ('djupdykking',),
'djupdykkinger': ('djupdykking',),
'djupfisk': ('djupfisk',),
'djupfisken': ('djupfisk',),
'djupfiskene': ('djupfisk',),
'djupfisker': ('djupfisk',),
'djupfryser': ('djupfryser',),
'djupfrysere': ('djupfryser',),
'djupfryseren': ('djupfryser',),
'djupfryserer': ('djupfryser',),
'djupfryserne': ('djupfryser',),
'djupgang': ('djupgang',),
'djupgangen': ('djupgang',),
'djupgangene': ('djupgang',),
'djupganger': ('djupgang',),
'djupgående': ('djupgående',),
'djupn': ('djupn',),
'djupna': ('djupn',),
'djupnen': ('djupn',),
'djupnene': ('djupn',),
'djupner': ('djupn',),
'djupsagn': ('djupsagn',),
'djupsagna': ('djupsagn',),
'djupsagnen': ('djupsagn',),
'djupsagnene': ('djupsagn',),
'djupsagner': ('djupsagn',),
'djupsnø': ('djupsnø',),
'djupsnøen': ('djupsnø',),
'djupsnøene': ('djupsnø',),
'djupsnøer': ('djupsnø',),
'djupstruktur': ('djupstruktur',),
'djupstrukturen': ('djupstruktur',),
'djupstrukturene': ('djupstruktur',),
'djupstrukturer': ('djupstruktur',),
'djuptallerken': ('djuptallerken',),
'djuptallerkenen': ('djuptallerken',),
'djuptallerkenene': ('djuptallerken',),
'djuptallerkener': ('djuptallerken',),
'djuptrykk': ('djuptrykk',),
'djuptrykka': ('djuptrykk',),
'djuptrykkene': ('djuptrykk',),
'djuptrykket': ('djuptrykk',),
'djupvannsfisk': ('djupvannsfisk',),
'djupvannsfisken': ('djupvannsfisk',),
'djupvannsfiskene': ('djupvannsfisk',),
'djupvannsfisker': ('djupvannsfisk',),
'djupvassfisk': ('djupvassfisk',),
'djupvassfisken': ('djupvassfisk',),
'djupvassfiskene': ('djupvassfisk',),
'djupvassfisker': ('djupvassfisk',),
'djupål': ('djupål',),
'djupålen': ('djupål',),
'djupålene': ('djupål',),
'djupåler': ('djupål',),
'do': ('do',),
'doen': ('do',),
'doene': ('do',),
'doer': ('do',),
'do': ('do',),
'doa': ('do',),
'doen': ('do',),
'doene': ('do',),
'doer': ('do',),
'doet': ('do',),
'dobba': ('dobbe',),
'dobbe': ('dobbe',),
'dobben': ('dobbe',),
'dobbene': ('dobbe',),
'dobber': ('dobbe',),
'dobba': ('dobbe',),
'dobbe': ('dobbe',),
'dobben': ('dobbe',),
'dobbene': ('dobbe',),
'dobber': ('dobbe',),
'dobbelt-v': ('dobbelt-v',),
'dobbelt-v-en': ('dobbelt-v',),
'dobbelt-v-ene': ('dobbelt-v',),
'dobbelt-v-er': ('dobbelt-v',),
'dobbeltagent': ('dobbeltagent',),
'dobbeltagenten': ('dobbeltagent',),
'dobbeltagentene': ('dobbeltagent',),
'dobbeltagenter': ('dobbeltagent',),
'dobbeltbekkasin': ('dobbeltbekkasin',),
'dobbeltbekkasinen': ('dobbeltbekkasin',),
'dobbeltbekkasinene': ('dobbeltbekkasin',),
'dobbeltbekkasiner': ('dobbeltbekkasin',),
'dobbeltbevissthet': ('dobbeltbevissthet',),
'dobbeltbevisstheta': ('dobbeltbevissthet',),
'dobbeltbevisstheten': ('dobbeltbevissthet',),
'dobbeltbevissthetene': ('dobbeltbevissthet',),
'dobbeltbevisstheter': ('dobbeltbevissthet',),
'dobbeltbinding': ('dobbeltbinding',),
'dobbeltbindinga': ('dobbeltbinding',),
'dobbeltbindingen': ('dobbeltbinding',),
'dobbeltbindingene': ('dobbeltbinding',),
'dobbeltbindinger': ('dobbeltbinding',),
'dobbeltdekker': ('dobbeltdekker',),
'dobbeltdekkere': ('dobbeltdekker',),
'dobbeltdekkeren': ('dobbeltdekker',),
'dobbeltdekkerer': ('dobbeltdekker',),
'dobbeltdekkerne': ('dobbeltdekker',),
'dobbeltdør': ('dobbeltdør',),
'dobbeltdøra': ('dobbeltdør',),
'dobbeltdøren': ('dobbeltdør',),
'dobbeltdørene': ('dobbeltdør',),
'dobbeltdører': ('dobbeltdør',),
'dobbelteksponering': ('dobbelteksponering',),
'dobbelteksponeringa': ('dobbelteksponering',),
'dobbelteksponeringen': ('dobbelteksponering',),
'dobbelteksponeringene': ('dobbelteksponering',),
'dobbelteksponeringer': ('dobbelteksponering',),
'dobbeltgjenger': ('dobbeltgjenger',),
'dobbeltgjengere': ('dobbeltgjenger',),
'dobbeltgjengeren': ('dobbeltgjenger',),
'dobbeltgjengerer': ('dobbeltgjenger',),
'dobbeltgjengerne': ('dobbeltgjenger',),
'dobbelthaka': ('dobbelthake',),
'dobbelthake': ('dobbelthake',),
'dobbelthaken': ('dobbelthake',),
'dobbelthakene': ('dobbelthake',),
'dobbelthaker': ('dobbelthake',),
'dobbeltkonsonant': ('dobbeltkonsonant',),
'dobbeltkonsonanten': ('dobbeltkonsonant',),
'dobbeltkonsonantene': ('dobbeltkonsonant',),
'dobbeltkonsonanter': ('dobbeltkonsonant',),
'dobbeltløper': ('dobbeltløper',),
'dobbeltløpere': ('dobbeltløper',),
'dobbeltløperen': ('dobbeltløper',),
'dobbeltløperer': ('dobbeltløper',),
'dobbeltløperne': ('dobbeltløper',),
'dobbeltmoral': ('dobbeltmoral',),
'dobbeltmoralen': ('dobbeltmoral',),
'dobbeltmoralene': ('dobbeltmoral',),
'dobbeltmoraler': ('dobbeltmoral',),
'dobbeltmyntfot': ('dobbeltmyntfot',),
'dobbeltmyntfoten': ('dobbeltmyntfot',),
'dobbeltmyntføttene': ('dobbeltmyntfot',),
'dobbeltmyntføtter': ('dobbeltmyntfot',),
'dobbeltnatur': ('dobbeltnatur',),
'dobbeltnaturen': ('dobbeltnatur',),
'dobbeltnaturene': ('dobbeltnatur',),
'dobbeltnaturer': ('dobbeltnatur',),
'dobbeltsculler': ('dobbeltsculler',),
'dobbeltscullere': ('dobbeltsculler',),
'dobbeltsculleren': ('dobbeltsculler',),
'dobbeltscullerer': ('dobbeltsculler',),
'dobbeltscullerne': ('dobbeltsculler',),
'dobbeltseier': ('dobbeltseier',),
'dobbeltseiere': ('dobbeltseier',),
'dobbeltseieren': ('dobbeltseier',),
'dobbeltseierne': ('dobbeltseier',),
'dobbeltseire': ('dobbeltseier',),
'dobbeltseirene': ('dobbeltseier',),
'dobbeltseirer': ('dobbeltseier',),
'dobbeltseng': ('dobbeltseng',),
'dobbeltsenga': ('dobbeltseng',),
'dobbeltsengen': ('dobbeltseng',),
'dobbeltsengene': ('dobbeltseng',),
'dobbeltsenger': ('dobbeltseng',),
'dobbeltspell': ('dobbeltspell',),
'dobbeltspella': ('dobbeltspell',),
'dobbeltspellene': ('dobbeltspell',),
'dobbeltspellet': ('dobbeltspell',),
'dobbeltspill': ('dobbeltspill',),
'dobbeltspilla': ('dobbeltspill',),
'dobbeltspillene': ('dobbeltspill',),
'dobbeltspillet': ('dobbeltspill',),
'dobbeltstemme': ('dobbeltstemme',),
'dobbeltstemmen': ('dobbeltstemme',),
'dobbeltstemmene': ('dobbeltstemme',),
'dobbeltstemmer': ('dobbeltstemme',),
'dobbeltsyn': ('dobbeltsyn',),
'dobbeltsyna': ('dobbeltsyn',),
'dobbeltsynene': ('dobbeltsyn',),
'dobbeltsyner': ('dobbeltsyn',),
'dobbeltsynet': ('dobbeltsyn',),
'dobbelttak': ('dobbelttak',),
'dobbelttaka': ('dobbelttak',),
'dobbelttakene': ('dobbelttak',),
'dobbelttaket': ('dobbelttak',),
'dobbelttilværelse': ('dobbelttilværelse',),
'dobbelttilværelsen': ('dobbelttilværelse',),
'dobbelttilværelsene': ('dobbelttilværelse',),
'dobbelttilværelser': ('dobbelttilværelse',),
'dobbelttime': ('dobbelttime',),
'dobbelttimen': ('dobbelttime',),
'dobbelttimene': ('dobbelttime',),
'dobbelttimer': ('dobbelttime',),
'dobbeltvindu': ('dobbeltvindu',),
'dobbeltvindua': ('dobbeltvindu',),
'dobbeltvinduene': ('dobbeltvindu',),
'dobbeltvinduer': ('dobbeltvindu',),
'dobbeltvinduet': ('dobbeltvindu',),
'dobbeltværelsa': ('dobbeltværelse',),
'dobbeltværelse': ('dobbeltværelse',),
'dobbeltværelsene': ('dobbeltværelse',),
'dobbeltværelser': ('dobbeltværelse',),
'dobbeltværelset': ('dobbeltværelse',),
'dobermann': ('dobermann',),
'dobermannen': ('dobermann',),
'dobermannene': ('dobermann',),
'dobermanner': ('dobermann',),
'dobermannpinsjer': ('dobermannpinsjer',),
'dobermannpinsjere': ('dobermannpinsjer',),
'dobermannpinsjeren': ('dobermannpinsjer',),
'dobermannpinsjerer': ('dobermannpinsjer',),
'dobermannpinsjerne': ('dobermannpinsjer',),
'doctor': ('doctor',),
'doctoren': ('doctor',),
'doctorene': ('doctor',),
'doctores': ('doctor',),
'doctor honoris causa': ('doctor honoris causa',),
'doge': ('doge',),
'dogen': ('doge',),
'dogene': ('doge',),
'doger': ('doge',),
'dogg': ('dogg',),
'doggen': ('dogg',),
'doggene': ('dogg',),
'dogger': ('dogg',),
'dogg': ('dogg',),
'dogga': ('dogg',),
'doggen': ('dogg',),
'doggene': ('dogg',),
'dogger': ('dogg',),
'doggdråpe': ('doggdråpe',),
'doggdråpen': ('doggdråpe',),
'doggdråpene': ('doggdråpe',),
'doggdråper': ('doggdråpe',),
'dogge': ('dogge',),
'doggen': ('dogge',),
'doggene': ('dogge',),
'dogger': ('dogge',),
'doggpil': ('doggpil',),
'doggpila': ('doggpil',),
'doggpilen': ('doggpil',),
'doggpilene': ('doggpil',),
'doggpiler': ('doggpil',),
'doggpunkt': ('doggpunkt',),
'doggpunkta': ('doggpunkt',),
'doggpunktene': ('doggpunkt',),
'doggpunkter': ('doggpunkt',),
'doggpunktet': ('doggpunkt',),
'doggskinn': ('doggskinn',),
'doggskinna': ('doggskinn',),
'doggskinnene': ('doggskinn',),
'doggskinnet': ('doggskinn',),
'dogmatiker': ('dogmatiker',),
'dogmatikere': ('dogmatiker',),
'dogmatikeren': ('dogmatiker',),
'dogmatikerer': ('dogmatiker',),
'dogmatikerne': ('dogmatiker',),
'dogmatikk': ('dogmatikk',),
'dogmatikken': ('dogmatikk',),
'dogmatikkene': ('dogmatikk',),
'dogmatikker': ('dogmatikk',),
'dogmatisme': ('dogmatisme',),
'dogmatismen': ('dogmatisme',),
'dogmatismene': ('dogmatisme',),
'dogmatismer': ('dogmatisme',),
'dogma': ('dogme',),
'dogme': ('dogme',),
'dogmene': ('dogme',),
'dogmer': ('dogme',),
'dogmet': ('dogme',),
'dokkanlegg': ('dokkanlegg',),
'dokkanlegga': ('dokkanlegg',),
'dokkanleggene': ('dokkanlegg',),
'dokkanlegget': ('dokkanlegg',),
'dokkarbeider': ('dokkarbeider',),
'dokkarbeidere': ('dokkarbeider',),
'dokkarbeideren': ('dokkarbeider',),
'dokkarbeiderer': ('dokkarbeider',),
'dokkarbeiderne': ('dokkarbeider',),
'dokka': ('dokke',),
'dokke': ('dokke',),
'dokken': ('dokke',),
'dokkene': ('dokke',),
'dokker': ('dokke',),
'dokkeansikt': ('dokkeansikt',),
'dokkeansikta': ('dokkeansikt',),
'dokkeansiktene': ('dokkeansikt',),
'dokkeansikter': ('dokkeansikt',),
'dokkeansiktet': ('dokkeansikt',),
'dokkeklær': ('dokkeklær',),
'dokkeklærne': ('dokkeklær',),
'dokkemann': ('dokkemann',),
'dokkemannen': ('dokkemann',),
'dokkemenn': ('dokkemann',),
'dokkemennene': ('dokkemann',),
'dokkestova': ('dokkestove',),
'dokkestove': ('dokkestove',),
'dokkestoven': ('dokkestove',),
'dokkestovene': ('dokkestove',),
'dokkestover': ('dokkestove',),
'dokkestua': ('dokkestue',),
'dokkestue': ('dokkestue',),
'dokkestuen': ('dokkestue',),
'dokkestuene': ('dokkestue',),
'dokkestuer': ('dokkestue',),
'dokketeater': ('dokketeater',),
'dokketeateret': ('dokketeater',),
'dokketeatra': ('dokketeater',),
'dokketeatre': ('dokketeater',),
'dokketeatrene': ('dokketeater',),
'dokketeatret': ('dokketeater',),
'dokkevogn': ('dokkevogn',),
'dokkevogna': ('dokkevogn',),
'dokkevognen': ('dokkevogn',),
'dokkevognene': ('dokkevogn',),
'dokkevogner': ('dokkevogn',),
'doksologi': ('doksologi',),
'doksologien': ('doksologi',),
'doksologiene': ('doksologi',),
'doksologier': ('doksologi',),
'dokter': ('dokter',),
'doktere': ('dokter',),
'dokteren': ('dokter',),
'dokterer': ('dokter',),
'dokterne': ('dokter',),
'doktor': ('doktor',),
'doktoren': ('doktor',),
'doktorene': ('doktor',),
'doktorer': ('doktor',),
'doktorand': ('doktorand',),
'doktoranden': ('doktorand',),
'doktorandene': ('doktorand',),
'doktorander': ('doktorand',),
'doktoravhandling': ('doktoravhandling',),
'doktoravhandlinga': ('doktoravhandling',),
'doktoravhandlingen': ('doktoravhandling',),
'doktoravhandlingene': ('doktoravhandling',),
'doktoravhandlinger': ('doktoravhandling',),
'doktordisputas': ('doktordisputas',),
'doktordisputasen': ('doktordisputas',),
'doktordisputasene': ('doktordisputas',),
'doktordisputaser': ('doktordisputas',),
'doktorgrad': ('doktorgrad',),
'doktorgraden': ('doktorgrad',),
'doktorgradene': ('doktorgrad',),
'doktorgrader': ('doktorgrad',),
'doktorgradsavhandling': ('doktorgradsavhandling',),
'doktorgradsavhandlinga': ('doktorgradsavhandling',),
'doktorgradsavhandlingen': ('doktorgradsavhandling',),
'doktorgradsavhandlingene': ('doktorgradsavhandling',),
'doktorgradsavhandlinger': ('doktorgradsavhandling',),
'doktorgradskandidat': ('doktorgradskandidat',),
'doktorgradskandidaten': ('doktorgradskandidat',),
'doktorgradskandidatene': ('doktorgradskandidat',),
'doktorgradskandidater': ('doktorgradskandidat',),
'doktorkandidat': ('doktorkandidat',),
'doktorkandidaten': ('doktorkandidat',),
'doktorkandidatene': ('doktorkandidat',),
'doktorkandidater': ('doktorkandidat',),
'doktormiddag': ('doktormiddag',),
'doktormiddagen': ('doktormiddag',),
'doktormiddagene': ('doktormiddag',),
'doktormiddager': ('doktormiddag',),
'doktorpromosjon': ('doktorpromosjon',),
'doktorpromosjonen': ('doktorpromosjon',),
'doktorpromosjonene': ('doktorpromosjon',),
'doktorpromosjoner': ('doktorpromosjon',),
'doktrina': ('doktrine',),
'doktrine': ('doktrine',),
'doktrinen': ('doktrine',),
'doktrinene': ('doktrine',),
'doktriner': ('doktrine',),
'dokument': ('dokument',),
'dokumenta': ('dokument',),
'dokumentene': ('dokument',),
'dokumenter': ('dokument',),
'dokumentet': ('dokument',),
'dokumentarfilm': ('dokumentarfilm',),
'dokumentarfilmen': ('dokumentarfilm',),
'dokumentarfilmene': ('dokumentarfilm',),
'dokumentarfilmer': ('dokumentarfilm',),
'dokumentarisme': ('dokumentarisme',),
'dokumentarismen': ('dokumentarisme',),
'dokumentarismene': ('dokumentarisme',),
'dokumentarismer': ('dokumentarisme',),
'dokumentarroman': ('dokumentarroman',),
'dokumentarromanen': ('dokumentarroman',),
'dokumentarromanene': ('dokumentarroman',),
'dokumentarromaner': ('dokumentarroman',),
'dokumentasjon': ('dokumentasjon',),
'dokumentasjonen': ('dokumentasjon',),
'dokumentasjonene': ('dokumentasjon',),
'dokumentasjoner': ('dokumentasjon',),
'dokumentavgift': ('dokumentavgift',),
'dokumentavgifta': ('dokumentavgift',),
'dokumentavgiften': ('dokumentavgift',),
'dokumentavgiftene': ('dokumentavgift',),
'dokumentavgifter': ('dokumentavgift',),
'dokumentfalsk': ('dokumentfalsk',),
'dokumentfalsken': ('dokumentfalsk',),
'dokumentfalskene': ('dokumentfalsk',),
'dokumentfalsker': ('dokumentfalsk',),
'dokumentmappa': ('dokumentmappe',),
'dokumentmappe': ('dokumentmappe',),
'dokumentmappen': ('dokumentmappe',),
'dokumentmappene': ('dokumentmappe',),
'dokumentmapper': ('dokumentmappe',),
'dolce far niente': ('dolce far niente',),
'doldis': ('doldis',),
'doldisen': ('doldis',),
'doldisene': ('doldis',),
'doldiser': ('doldis',),
'dolfin': ('dolfin',),
'dolfinen': ('dolfin',),
'dolfinene': ('dolfin',),
'dolfiner': ('dolfin',),
'dolk': ('dolk',),
'dolken': ('dolk',),
'dolkene': ('dolk',),
'dolker': ('dolk',),
'dolkestikk': ('dolkestikk',),
'dolkestikka': ('dolkestikk',),
'dolkestikkene': ('dolkestikk',),
'dolkestikket': ('dolkestikk',),
'dolkestøt': ('dolkestøt',),
'dolkestøta': ('dolkestøt',),
'dolkestøtene': ('dolkestøt',),
'dolkestøtet': ('dolkestøt',),
'dollar': ('dollar',),
'dollaren': ('dollar',),
'dollarene': ('dollar',),
'dollarglis': ('dollarglis',),
'dollarglisa': ('dollarglis',),
'dollarglisene': ('dollarglis',),
'dollargliset': ('dollarglis',),
'dollarturist': ('dollarturist',),
'dollarturisten': ('dollarturist',),
'dollarturistene': ('dollarturist',),
'dollarturister': ('dollarturist',),
'dollbord': ('dollbord',),
'dollborda': ('dollbord',),
'dollbordene': ('dollbord',),
'dollborder': ('dollbord',),
'dollbordet': ('dollbord',),
'dolomitt': ('dolomitt',),
'dolomitten': ('dolomitt',),
'dolomittene': ('dolomitt',),
'dolomitter': ('dolomitt',),
'dolp': ('dolp',),
'dolpa': ('dolp',),
'dolpen': ('dolp',),
'dolpene': ('dolp',),
'dolper': ('dolp',),
'dom': ('dom',),
'domen': ('dom',),
'domene': ('dom',),
'domer': ('dom',),
'dom': ('dom',),
'dommen': ('dom',),
'dommene': ('dom',),
'dommer': ('dom',),
'dombjella': ('dombjelle',),
'dombjelle': ('dombjelle',),
'dombjellen': ('dombjelle',),
'dombjellene': ('dombjelle',),
'dombjeller': ('dombjelle',),
'dombjølla': ('dombjølle',),
'dombjølle': ('dombjølle',),
'dombjøllen': ('dombjølle',),
'dombjøllene': ('dombjølle',),
'dombjøller': ('dombjølle',),
'domena': ('domene',),
'domene': ('domene',),
'domenen': ('domene',),
'domenene': ('domene',),
'domener': ('domene',),
'domenet': ('domene',),
'domherre': ('domherre',),
'domherren': ('domherre',),
'domherrene': ('domherre',),
'domherrer': ('domherre',),
'dominans': ('dominans',),
'dominansen': ('dominans',),
'dominansene': ('dominans',),
'dominanser': ('dominans',),
'dominant': ('dominant',),
'dominanten': ('dominant',),
'dominantene': ('dominant',),
'dominanter': ('dominant',),
'dominikaner': ('dominikaner',),
'dominikanere': ('dominikaner',),
'dominikaneren': ('dominikaner',),
'dominikanerer': ('dominikaner',),
'dominikanerne': ('dominikaner',),
'dominikaner': ('dominikaner',),
'dominikanere': ('dominikaner',),
'dominikaneren': ('dominikaner',),
'dominikanerer': ('dominikaner',),
'dominikanerne': ('dominikaner',),
'dominikanerkloster': ('dominikanerkloster',),
'dominikanerklosteret': ('dominikanerkloster',),
'dominikanerklostra': ('dominikanerkloster',),
'dominikanerklostre': ('dominikanerkloster',),
'dominikanerklostrene': ('dominikanerkloster',),
'dominikanerklostret': ('dominikanerkloster',),
'dominikanermunk': ('dominikanermunk',),
'dominikanermunken': ('dominikanermunk',),
'dominikanermunkene': ('dominikanermunk',),
'dominikanermunker': ('dominikanermunk',),
'dominikanerorden': ('dominikanerorden',),
'dominikanerordenen': ('dominikanerorden',),
'dominikanerordenene': ('dominikanerorden',),
'dominikanerordener': ('dominikanerorden',),
'dominiker': ('dominiker',),
'dominikere': ('dominiker',),
'dominikeren': ('dominiker',),
'dominikerer': ('dominiker',),
'dominikerne': ('dominiker',),
'dominion': ('dominion',),
'dominionen': ('dominion',),
'dominionene': ('dominion',),
'dominioner': ('dominion',),
'dominobrikka': ('dominobrikke',),
'dominobrikke': ('dominobrikke',),
'dominobrikken': ('dominobrikke',),
'dominobrikkene': ('dominobrikke',),
'dominobrikker': ('dominobrikke',),
'domisil': ('domisil',),
'domisila': ('domisil',),
'domisilene': ('domisil',),
'domisiler': ('domisil',),
'domisilet': ('domisil',),
'domisiliant': ('domisiliant',),
'domisilianten': ('domisiliant',),
'domisiliantene': ('domisiliant',),
'domisilianter': ('domisiliant',),
'domisiliat': ('domisiliat',),
'domisiliaten': ('domisiliat',),
'domisiliatene': ('domisiliat',),
'domisiliater': ('domisiliat',),
'domisilveksel': ('domisilveksel',),
'domisilvekselen': ('domisilveksel',),
'domisilvekslene': ('domisilveksel',),
'domisilveksler': ('domisilveksel',),
'domkapitla': ('domkapittel',),
'domkapitlene': ('domkapittel',),
'domkapitler': ('domkapittel',),
'domkapitlet': ('domkapittel',),
'domkapittel': ('domkapittel',),
'domkapittelet': ('domkapittel',),
'domkirka': ('domkirke',),
'domkirke': ('domkirke',),
'domkirken': ('domkirke',),
'domkirkene': ('domkirke',),
'domkirker': ('domkirke',),
'domkjerka': ('domkjerke',),
'domkjerke': ('domkjerke',),
'domkjerken': ('domkjerke',),
'domkjerkene': ('domkjerke',),
'domkjerker': ('domkjerke',),
'domkor': ('domkor',),
'domkora': ('domkor',),
'domkorene': ('domkor',),
'domkoret': ('domkor',),
'dommedag': ('dommedag',),
'dommedagen': ('dommedag',),
'dommedagene': ('dommedag',),
'dommedager': ('dommedag',),
'dommedagsbasun': ('dommedagsbasun',),
'dommedagsbasunen': ('dommedagsbasun',),
'dommedagsbasunene': ('dommedagsbasun',),
'dommedagsbasuner': ('dommedagsbasun',),
'dommedagspreken': ('dommedagspreken',),
'dommedagsprekenen': ('dommedagspreken',),
'dommedagsprekenene': ('dommedagspreken',),
'dommedagsprekener': ('dommedagspreken',),
'dommedagsprofet': ('dommedagsprofet',),
'dommedagsprofeten': ('dommedagsprofet',),
'dommedagsprofetene': ('dommedagsprofet',),
'dommedagsprofeter': ('dommedagsprofet',),
'dommer': ('dommer',),
'dommere': ('dommer',),
'dommeren': ('dommer',),
'dommerer': ('dommer',),
'dommerne': ('dommer',),
'dommered': ('dommered',),
'dommereden': ('dommered',),
'dommeredene': ('dommered',),
'dommereder': ('dommered',),
'dommerfløyta': ('dommerfløyte',),
'dommerfløyte': ('dommerfløyte',),
'dommerfløyten': ('dommerfløyte',),
'dommerfløytene': ('dommerfløyte',),
'dommerfløyter': ('dommerfløyte',),
'dommerfullmektig': ('dommerfullmektig',),
'dommerfullmektigen': ('dommerfullmektig',),
'dommerfullmektigene': ('dommerfullmektig',),
'dommerfullmektiger': ('dommerfullmektig',),
'dommertårn': ('dommertårn',),
'dommertårna': ('dommertårn',),
'dommertårnene': ('dommertårn',),
'dommertårnet': ('dommertårn',),
'domorganist': ('domorganist',),
'domorganisten': ('domorganist',),
'domorganistene': ('domorganist',),
'domorganister': ('domorganist',),
'dompap': ('dompap',),
'dompapen': ('dompap',),
'dompapene': ('dompap',),
'dompaper': ('dompap',),
'domprost': ('domprost',),
'domprosten': ('domprost',),
'domprostene': ('domprost',),
'domproster': ('domprost',),
'domra': ('domra',),
'domraen': ('domra',),
'domraene': ('domra',),
'domraer': ('domra',),
'domsavgjørelse': ('domsavgjørelse',),
'domsavgjørelsen': ('domsavgjørelse',),
'domsavgjørelsene': ('domsavgjørelse',),
'domsavgjørelser': ('domsavgjørelse',),
'domsavsigelse': ('domsavsigelse',),
'domsavsigelsen': ('domsavsigelse',),
'domsavsigelsene': ('domsavsigelse',),
'domsavsigelser': ('domsavsigelse',),
'domsgrunn': ('domsgrunn',),
'domsgrunnen': ('domsgrunn',),
'domsgrunnene': ('domsgrunn',),
'domsgrunner': ('domsgrunn',),
'domsmann': ('domsmann',),
'domsmannen': ('domsmann',),
'domsmenn': ('domsmann',),
'domsmennene': ('domsmann',),
'domsnemnd': ('domsnemnd',),
'domsnemnda': ('domsnemnd',),
'domsnemnden': ('domsnemnd',),
'domsnemndene': ('domsnemnd',),
'domsnemnder': ('domsnemnd',),
'domspremiss': ('domspremiss',),
'domspremissa': ('domspremiss',),
'domspremissen': ('domspremiss',),
'domspremissene': ('domspremiss',),
'domspremisser': ('domspremiss',),
'domspremisset': ('domspremiss',),
'domstol': ('domstol',),
'domstolen': ('domstol',),
'domstolene': ('domstol',),
'domstoler': ('domstol',),
'domstolsbehandling': ('domstolsbehandling',),
'domstolsbehandlinga': ('domstolsbehandling',),
'domstolsbehandlingen': ('domstolsbehandling',),
'domstolsbehandlingene': ('domstolsbehandling',),
'domstolsbehandlinger': ('domstolsbehandling',),
'don': ('don',),
'donen': ('don',),
'donene': ('don',),
'doner': ('don',),
'don': ('don',),
'dona': ('don',),
'donene': ('don',),
'donet': ('don',),
'don juan': ('don juan',),
'don juanen': ('don juan',),
'don juanene': ('don juan',),
'don juaner': ('don juan',),
'donasjon': ('donasjon',),
'donasjonen': ('donasjon',),
'donasjonene': ('donasjon',),
'donasjoner': ('donasjon',),
'donator': ('donator',),
'donatoren': ('donator',),
'donatorene': ('donator',),
'donatorer': ('donator',),
'dongeri': ('dongeri',),
'dongerien': ('dongeri',),
'dongeriene': ('dongeri',),
'dongerier': ('dongeri',),
'dongeribuksa': ('dongeribukse',),
'dongeribukse': ('dongeribukse',),
'dongeribuksen': ('dongeribukse',),
'dongeribuksene': ('dongeribukse',),
'dongeribukser': ('dongeribukse',),
'dongerijakka': ('dongerijakke',),
'dongerijakke': ('dongerijakke',),
'dongerijakken': ('dongerijakke',),
'dongerijakkene': ('dongerijakke',),
'dongerijakker': ('dongerijakke',),
'dongeriklær': ('dongeriklær',),
'dongeriklærne': ('dongeriklær',),
'doning': ('doning',),
'doninga': ('doning',),
'doningen': ('doning',),
'doningene': ('doning',),
'doninger': ('doning',),
'donjuan': ('donjuan',),
'donjuanen': ('donjuan',),
'donjuanene': ('donjuan',),
'donjuaner': ('donjuan',),
'donkey': ('donkey',),
'donkeyen': ('donkey',),
'donkeyene': ('donkey',),
'donkeyer': ('donkey',),
'donkeymann': ('donkeymann',),
'donkeymannen': ('donkeymann',),
'donkeymenn': ('donkeymann',),
'donkeymennene': ('donkeymann',),
'donkeymaskin': ('donkeymaskin',),
'donkeymaskina': ('donkeymaskin',),
'donkeymaskinen': ('donkeymaskin',),
'donkeymaskinene': ('donkeymaskin',),
'donkeymaskiner': ('donkeymaskin',),
'donkosakk': ('donkosakk',),
'donkosakken': ('donkosakk',),
'donkosakkene': ('donkosakk',),
'donkosakker': ('donkosakk',),
'donkraft': ('donkraft',),
'donkrafta': ('donkraft',),
'donkraften': ('donkraft',),
'donkraftene': ('donkraft',),
'donkrafter': ('donkraft',),
'donna': ('donna',),
'donnaen': ('donna',),
'donnaene': ('donna',),
'donnaer': ('donna',),
'donor': ('donor',),
'donoren': ('donor',),
'donorene': ('donor',),
'donorer': ('donor',),
'dont': ('dont',),
'donten': ('dont',),
'dontene': ('dont',),
'donter': ('dont',),
'dop': ('dop',),
'dopa': ('dop',),
'dopen': ('dop',),
'dopene': ('dop',),
'doper': ('dop',),
'dopet': ('dop',),
'doping': ('doping',),
'dopinga': ('doping',),
'dopingen': ('doping',),
'dopingene': ('doping',),
'dopinger': ('doping',),
'dopingkontroll': ('dopingkontroll',),
'dopingkontrollen': ('dopingkontroll',),
'dopingkontrollene': ('dopingkontroll',),
'dopingkontroller': ('dopingkontroll',),
'dopingmiddel': ('dopingmiddel',),
'dopingmiddelet': ('dopingmiddel',),
'dopingmidla': ('dopingmiddel',),
'dopingmidlene': ('dopingmiddel',),
'dopingmidler': ('dopingmiddel',),
'dopingmidlet': ('dopingmiddel',),
'dopp': ('dopp',),
'doppen': ('dopp',),
'doppene': ('dopp',),
'dopper': ('dopp',),
'doppe': ('doppe',),
'doppen': ('doppe',),
'doppene': ('doppe',),
'dopper': ('doppe',),
'dopplereffekt': ('dopplereffekt',),
'dopplereffekten': ('dopplereffekt',),
'dopplereffektene': ('dopplereffekt',),
'dopplereffekter': ('dopplereffekt',),
'doppsko': ('doppsko',),
'doppskoa': ('doppsko',),
'doppskoen': ('doppsko',),
'doppskoene': ('doppsko',),
'doppskor': ('doppsko',),
'doppskorne': ('doppsko',),
'dor': ('dor',),
'doren': ('dor',),
'dorene': ('dor',),
'dorer': ('dor',),
'dorer': ('dorer',),
'dorere': ('dorer',),
'doreren': ('dorer',),
'dorerer': ('dorer',),
'dorerne': ('dorer',),
'dorg': ('dorg',),
'dorga': ('dorg',),
'dorgen': ('dorg',),
'dorgene': ('dorg',),
'dorger': ('dorg',),
'dorgefiska': ('dorgefiske',),
'dorgefiske': ('dorgefiske',),
'dorgefiskene': ('dorgefiske',),
'dorgefisker': ('dorgefiske',),
'dorgefisket': ('dorgefiske',),
'dorgfiska': ('dorgfiske',),
'dorgfiske': ('dorgfiske',),
'dorgfiskene': ('dorgfiske',),
'dorgfisker': ('dorgfiske',),
'dorgfisket': ('dorgfiske',),
'dormitoria': ('dormitorium',),
'dormitoriene': ('dormitorium',),
'dormitorier': ('dormitorium',),
'dormitoriet': ('dormitorium',),
'dormitorium': ('dormitorium',),
'dorsal': ('dorsal',),
'dorsalen': ('dorsal',),
'dorsalene': ('dorsal',),
'dorsaler': ('dorsal',),
'dose': ('dose',),
'dosen': ('dose',),
'dosene': ('dose',),
'doser': ('dose',),
'dosent': ('dosent',),
'dosenten': ('dosent',),
'dosentene': ('dosent',),
'dosenter': ('dosent',),
'dosentur': ('dosentur',),
'dosentura': ('dosentur',),
'dosenturene': ('dosentur',),
'dosenturer': ('dosentur',),
'dosenturet': ('dosentur',),
'doser': ('doser',),
'dosere': ('doser',),
'doseren': ('doser',),
'doserer': ('doser',),
'doserne': ('doser',),
'dosering': ('dosering',),
'doseringa': ('dosering',),
'doseringen': ('dosering',),
'doseringene': ('dosering',),
'doseringer': ('dosering',),
'dosene': ('dosis',),
'doser': ('dosis',),
'dosis': ('dosis',),
'dosisen': ('dosis',),
'dosisene': ('dosis',),
'dosiser': ('dosis',),
'dossering': ('dossering',),
'dosseringa': ('dossering',),
'dosseringen': ('dossering',),
'dosseringene': ('dossering',),
'dosseringer': ('dossering',),
'dossier': ('dossier',),
'dossiera': ('dossier',),
'dossierene': ('dossier',),
'dossierer': ('dossier',),
'dossieret': ('dossier',),
'dotasjon': ('dotasjon',),
'dotasjonen': ('dotasjon',),
'dotasjonene': ('dotasjon',),
'dotasjoner': ('dotasjon',),
'dott': ('dott',),
'dotten': ('dott',),
'dottene': ('dott',),
'dotter': ('dott',),
'double': ('double',),
'doublen': ('double',),
'doublene': ('double',),
'doubler': ('double',),
'dovendyr': ('dovendyr',),
'dovendyra': ('dovendyr',),
'dovendyrene': ('dovendyr',),
'dovendyret': ('dovendyr',),
'dovenskap': ('dovenskap',),
'dovenskapen': ('dovenskap',),
'dovenskapene': ('dovenskap',),
'dovenskaper': ('dovenskap',),
'downlight': ('downlight',),
'downlighta': ('downlight',),
'downlightene': ('downlight',),
'downlightet': ('downlight',),
'downperiode': ('downperiode',),
'downperioden': ('downperiode',),
'downperiodene': ('downperiode',),
'downperioder': ('downperiode',),
'doyen': ('doyen',),
'doyenen': ('doyen',),
'doyenene': ('doyen',),
'doyener': ('doyen',),
'drabant': ('drabant',),
'drabanten': ('drabant',),
'drabantene': ('drabant',),
'drabanter': ('drabant',),
'drabantby': ('drabantby',),
'drabantbyen': ('drabantby',),
'drabantbyene': ('drabantby',),
'drabantbyer': ('drabantby',),
'draft': ('draft',),
'drafta': ('draft',),
'draftene': ('draft',),
'drafter': ('draft',),
'draftet': ('draft',),
'drag': ('drag',),
'draga': ('drag',),
'dragene': ('drag',),
'draget': ('drag',),
'drage': ('drage',),
'dragen': ('drage',),
'dragene': ('drage',),
'drager': ('drage',),
'drageblod': ('drageblod',),
'dragebloda': ('drageblod',),
'drageblodene': ('drageblod',),
'drageblodet': ('drageblod',),
'drageflyging': ('drageflyging',),
'drageflyginga': ('drageflyging',),
'drageflygingen': ('drageflyging',),
'drageflygingene': ('drageflyging',),
'drageflyginger': ('drageflyging',),
'drageflying': ('drageflying',),
'drageflyinga': ('drageflying',),
'drageflyingen': ('drageflying',),
'drageflyingene': ('drageflying',),
'drageflyinger': ('drageflying',),
'dragelilja': ('dragelilje',),
'dragelilje': ('dragelilje',),
'drageliljen': ('dragelilje',),
'drageliljene': ('dragelilje',),
'drageliljer': ('dragelilje',),
'dragelse': ('dragelse',),
'dragelsen': ('dragelse',),
'dragelsene': ('dragelse',),
'dragelser': ('dragelse',),
'drager': ('drager',),
'dragere': ('drager',),
'drageren': ('drager',),
'dragerer': ('drager',),
'dragerne': ('drager',),
'drageskip': ('drageskip',),
'drageskipa': ('drageskip',),
'drageskipene': ('drageskip',),
'drageskipet': ('drageskip',),
'dragestil': ('dragestil',),
'dragestilen': ('dragestil',),
'dragestilene': ('dragestil',),
'dragestiler': ('dragestil',),
'dragkamp': ('dragkamp',),
'dragkampen': ('dragkamp',),
'dragkampene': ('dragkamp',),
'dragkamper': ('dragkamp',),
'dragkista': ('dragkiste',),
'dragkiste': ('dragkiste',),
'dragkisten': ('dragkiste',),
'dragkistene': ('dragkiste',),
'dragkister': ('dragkiste',),
'dragkjerra': ('dragkjerre',),
'dragkjerre': ('dragkjerre',),
'dragkjerren': ('dragkjerre',),
'dragkjerrene': ('dragkjerre',),
'dragkjerrer': ('dragkjerre',),
'dragning': ('dragning',),
'dragninga': ('dragning',),
'dragningen': ('dragning',),
'dragningene': ('dragning',),
'dragninger': ('dragning',),
'dragnot': ('dragnot',),
'dragnota': ('dragnot',),
'dragnoten': ('dragnot',),
'dragnøtene': ('dragnot',),
'dragnøter': ('dragnot',),
'dragoman': ('dragoman',),
'dragomanen': ('dragoman',),
'dragomanene': ('dragoman',),
'dragomaner': ('dragoman',),
'dragon': ('dragon',),
'dragonen': ('dragon',),
'dragonene': ('dragon',),
'dragoner': ('dragon',),
'dragonløytnant': ('dragonløytnant',),
'dragonløytnanten': ('dragonløytnant',),
'dragonløytnantene': ('dragonløytnant',),
'dragonløytnanter': ('dragonløytnant',),
'dragonregiment': ('dragonregiment',),
'dragonregimenta': ('dragonregiment',),
'dragonregimentene': ('dragonregiment',),
'dragonregimenter': ('dragonregiment',),
'dragonregimentet': ('dragonregiment',),
'dragonuniform': ('dragonuniform',),
'dragonuniforma': ('dragonuniform',),
'dragonuniformen': ('dragonuniform',),
'dragonuniformene': ('dragonuniform',),
'dragonuniformer': ('dragonuniform',),
'dragracing': ('dragracing',),
'dragracingen': ('dragracing',),
'dragracingene': ('dragracing',),
'dragracinger': ('dragracing',),
'dragshow': ('dragshow',),
'dragshowa': ('dragshow',),
'dragshowene': ('dragshow',),
'dragshowet': ('dragshow',),
'dragslede': ('dragslede',),
'dragsleden': ('dragslede',),
'dragsledene': ('dragslede',),
'dragsleder': ('dragslede',),
'dragspell': ('dragspell',),
'dragspella': ('dragspell',),
'dragspellene': ('dragspell',),
'dragspellet': ('dragspell',),
'dragspill': ('dragspill',),
'dragspilla': ('dragspill',),
'dragspillene': ('dragspill',),
'dragspillet': ('dragspill',),
'dragster': ('dragster',),
'dragstere': ('dragster',),
'dragsteren': ('dragster',),
'dragsterer': ('dragster',),
'dragsterne': ('dragster',),
'dragsug': ('dragsug',),
'dragsuga': ('dragsug',),
'dragsugene': ('dragsug',),
'dragsuget': ('dragsug',),
'drahjelp': ('drahjelp',),
'drahjelpa': ('drahjelp',),
'drahjelpen': ('drahjelp',),
'drahjelpene': ('drahjelp',),
'drahjelper': ('drahjelp',),
'drake': ('drake',),
'draken': ('drake',),
'drakene': ('drake',),
'draker': ('drake',),
'drakeblod': ('drakeblod',),
'drakebloda': ('drakeblod',),
'drakeblodene': ('drakeblod',),
'drakeblodet': ('drakeblod',),
'drakeflyging': ('drakeflyging',),
'drakeflyginga': ('drakeflyging',),
'drakeflygingen': ('drakeflyging',),
'drakeflygingene': ('drakeflyging',),
'drakeflyginger': ('drakeflyging',),
'drakeflying': ('drakeflying',),
'drakeflyinga': ('drakeflying',),
'drakeflyingen': ('drakeflying',),
'drakeflyingene': ('drakeflying',),
'drakeflyinger': ('drakeflying',),
'drakelilja': ('drakelilje',),
'drakelilje': ('drakelilje',),
'drakeliljen': ('drakelilje',),
'drakeliljene': ('drakelilje',),
'drakeliljer': ('drakelilje',),
'drakeskip': ('drakeskip',),
'drakeskipa': ('drakeskip',),
'drakeskipene': ('drakeskip',),
'drakeskipet': ('drakeskip',),
'drakestil': ('drakestil',),
'drakestilen': ('drakestil',),
'drakestilene': ('drakestil',),
'drakestiler': ('drakestil',),
'drakme': ('drakme',),
'drakmen': ('drakme',),
'drakmene': ('drakme',),
'drakmer': ('drakme',),
'drakt': ('drakt',),
'drakta': ('drakt',),
'drakten': ('drakt',),
'draktene': ('drakt',),
'drakter': ('drakt',),
'draktjakka': ('draktjakke',),
'draktjakke': ('draktjakke',),
'draktjakken': ('draktjakke',),
'draktjakkene': ('draktjakke',),
'draktjakker': ('draktjakke',),
'draktpose': ('draktpose',),
'draktposen': ('draktpose',),
'draktposene': ('draktpose',),
'draktposer': ('draktpose',),
'draktskjørt': ('draktskjørt',),
'draktskjørta': ('draktskjørt',),
'draktskjørtene': ('draktskjørt',),
'draktskjørter': ('draktskjørt',),
'draktskjørtet': ('draktskjørt',),
'dralon': ('dralon',),
'dralonen': ('dralon',),
'dralonene': ('dralon',),
'draloner': ('dralon',),
'dram': ('dram',),
'drammen': ('dram',),
'drammene': ('dram',),
'drammer': ('dram',),
'drama': ('drama',),
'dramaene': ('drama',),
'dramaer': ('drama',),
'dramaet': ('drama',),
'dramatiker': ('dramatiker',),
'dramatikere': ('dramatiker',),
'dramatikeren': ('dramatiker',),
'dramatikerer': ('dramatiker',),
'dramatikerne': ('dramatiker',),
'dramatikk': ('dramatikk',),
'dramatikken': ('dramatikk',),
'dramatikkene': ('dramatikk',),
'dramatikker': ('dramatikk',),
'dramatisering': ('dramatisering',),
'dramatiseringa': ('dramatisering',),
'dramatiseringen': ('dramatisering',),
'dramatiseringene': ('dramatisering',),
'dramatiseringer': ('dramatisering',),
'dramaturg': ('dramaturg',),
'dramaturgen': ('dramaturg',),
'dramaturgene': ('dramaturg',),
'dramaturger': ('dramaturg',),
'dramaturgi': ('dramaturgi',),
'dramaturgien': ('dramaturgi',),
'dramaturgiene': ('dramaturgi',),
'dramaturgier': ('dramaturgi',),
'drammeglas': ('drammeglas',),
'drammeglasa': ('drammeglas',),
'drammeglasene': ('drammeglas',),
'drammeglaset': ('drammeglas',),
'drammeglass': ('drammeglass',),
'drammeglassa': ('drammeglass',),
'drammeglassene': ('drammeglass',),
'drammeglasset': ('drammeglass',),
'drammenser': ('drammenser',),
'drammensere': ('drammenser',),
'drammenseren': ('drammenser',),
'drammenserer': ('drammenser',),
'drammenserne': ('drammenser',),
'drank': ('drank',),
'dranken': ('drank',),
'drankene': ('drank',),
'dranker': ('drank',),
'dranker': ('dranker',),
'drankere': ('dranker',),
'drankeren': ('dranker',),
'drankerer': ('dranker',),
'drankerne': ('dranker',),
'drap': ('drap',),
'drapa': ('drap',),
'drapene': ('drap',),
'drapet': ('drap',),
'draperi': ('draperi',),
'draperia': ('draperi',),
'draperiene': ('draperi',),
'draperier': ('draperi',),
'draperiet': ('draperi',),
'drapsforsøk': ('drapsforsøk',),
'drapsforsøka': ('drapsforsøk',),
'drapsforsøkene': ('drapsforsøk',),
'drapsforsøket': ('drapsforsøk',),
'drapsmann': ('drapsmann',),
'drapsmannen': ('drapsmann',),
'drapsmenn': ('drapsmann',),
'drapsmennene': ('drapsmann',),
'drapssak': ('drapssak',),
'drapssaka': ('drapssak',),
'drapssaken': ('drapssak',),
'drapssakene': ('drapssak',),
'drapssaker': ('drapssak',),
'drapsvåpen': ('drapsvåpen',),
'drapsvåpenet': ('drapsvåpen',),
'drapsvåpna': ('drapsvåpen',),
'drapsvåpnene': ('drapsvåpen',),
'drasjeen': ('drasjé',),
'drasjeene': ('drasjé',),
'drasjeer': ('drasjé',),
'drasjé': ('drasjé',),
'drasjéen': ('drasjé',),
'drasjéene': ('drasjé',),
'drasjéer': ('drasjé',),
'draug': ('draug',),
'draugen': ('draug',),
'draugene': ('draug',),
'drauger': ('draug',),
'draugkyss': ('draugkyss',),
'draugkyssa': ('draugkyss',),
'draugkyssen': ('draugkyss',),
'draugkyssene': ('draugkyss',),
'draugkysset': ('draugkyss',),
'draugspy': ('draugspy',),
'draugspya': ('draugspy',),
'draugspyene': ('draugspy',),
'draugspyet': ('draugspy',),
'dravat': ('dravat',),
'dravaten': ('dravat',),
'dravatene': ('dravat',),
'dravater': ('dravat',),
'dravid': ('dravid',),
'draviden': ('dravid',),
'dravidene': ('dravid',),
'dravider': ('dravid',),
'dravle': ('dravle',),
'dravlen': ('dravle',),
'dravlene': ('dravle',),
'dravler': ('dravle',),
'drawback': ('drawback',),
'drawbacka': ('drawback',),
'drawbacken': ('drawback',),
'drawbackene': ('drawback',),
'drawbacket': ('drawback',),
'dregg': ('dregg',),
'dreggen': ('dregg',),
'dreggene': ('dregg',),
'dregger': ('dregg',),
'dreggekjetting': ('dreggekjetting',),
'dreggekjettingen': ('dreggekjetting',),
'dreggekjettingene': ('dreggekjetting',),
'dreggekjettinger': ('dreggekjetting',),
'dreggetau': ('dreggetau',),
'dreggetaua': ('dreggetau',),
'dreggetauene': ('dreggetau',),
'dreggetauet': ('dreggetau',),
'dreggkjetting': ('dreggkjetting',),
'dreggkjettingen': ('dreggkjetting',),
'dreggkjettingene': ('dreggkjetting',),
'dreggkjettinger': ('dreggkjetting',),
'dreggtau': ('dreggtau',),
'dreggtaua': ('dreggtau',),
'dreggtauene': ('dreggtau',),
'dreggtauer': ('dreggtau',),
'dreggtauet': ('dreggtau',),
'drei': ('drei',),
'dreien': ('drei',),
'dreiene': ('drei',),
'dreier': ('drei',),
'dreiearbeid': ('dreiearbeid',),
'dreiearbeida': ('dreiearbeid',),
'dreiearbeidene': ('dreiearbeid',),
'dreiearbeider': ('dreiearbeid',),
'dreiearbeidet': ('dreiearbeid',),
'dreiebenk': ('dreiebenk',),
'dreiebenken': ('dreiebenk',),
'dreiebenkene': ('dreiebenk',),
'dreiebenker': ('dreiebenk',),
'dreiebokforfatter': ('dreiebokforfatter',),
'dreiebokforfattere': ('dreiebokforfatter',),
'dreiebokforfatteren': ('dreiebokforfatter',),
'dreiebokforfatterer': ('dreiebokforfatter',),
'dreiebokforfatterne': ('dreiebokforfatter',),
'dreiefelt': ('dreiefelt',),
'dreiefelta': ('dreiefelt',),
'dreiefeltene': ('dreiefelt',),
'dreiefelter': ('dreiefelt',),
'dreiefeltet': ('dreiefelt',),
'dreiemoment': ('dreiemoment',),
'dreiemomenta': ('dreiemoment',),
'dreiemomentene': ('dreiemoment',),
'dreiemomenter': ('dreiemoment',),
'dreiemomentet': ('dreiemoment',),
'dreier': ('dreier',),
'dreiere': ('dreier',),
'dreieren': ('dreier',),
'dreierer': ('dreier',),
'dreierne': ('dreier',),
'dreiescene': ('dreiescene',),
'dreiescenen': ('dreiescene',),
'dreiescenene': ('dreiescene',),
'dreiescener': ('dreiescene',),
'dreieskiva': ('dreieskive',),
'dreieskive': ('dreieskive',),
'dreieskiven': ('dreieskive',),
'dreieskivene': ('dreieskive',),
'dreieskiver': ('dreieskive',),
'dreiestrøm': ('dreiestrøm',),
'dreiestrømmen': ('dreiestrøm',),
'dreiestrømmene': ('dreiestrøm',),
'dreiestrømmer': ('dreiestrøm',),
'dreiestål': ('dreiestål',),
'dreieståla': ('dreiestål',),
'dreiestålene': ('dreiestål',),
'dreiestålet': ('dreiestål',),
'dreietapp': ('dreietapp',),
'dreietappen': ('dreietapp',),
'dreietappene': ('dreietapp',),
'dreietapper': ('dreietapp',),
'dreiing': ('dreiing',),
'dreiinga': ('dreiing',),
'dreiingen': ('dreiing',),
'dreiingene': ('dreiing',),
'dreiinger': ('dreiing',),
'dreiingsakse': ('dreiingsakse',),
'dreiingsaksen': ('dreiingsakse',),
'dreiingsaksene': ('dreiingsakse',),
'dreiingsakser': ('dreiingsakse',),
'dreiingshastighet': ('dreiingshastighet',),
'dreiingshastigheta': ('dreiingshastighet',),
'dreiingshastigheten': ('dreiingshastighet',),
'dreiingshastighetene': ('dreiingshastighet',),
'dreiingshastigheter': ('dreiingshastighet',),
'dreil': ('dreil',),
'dreila': ('dreil',),
'dreilen': ('dreil',),
'dreilene': ('dreil',),
'dreiler': ('dreil',),
'dreilet': ('dreil',),
'dreining': ('dreining',),
'dreininga': ('dreining',),
'dreiningen': ('dreining',),
'dreiningene': ('dreining',),
'dreininger': ('dreining',),
'dreiningsakse': ('dreiningsakse',),
'dreiningsaksen': ('dreiningsakse',),
'dreiningsaksene': ('dreiningsakse',),
'dreiningsakser': ('dreiningsakse',),
'dreiningshastighet': ('dreiningshastighet',),
'dreiningshastigheta': ('dreiningshastighet',),
'dreiningshastigheten': ('dreiningshastighet',),
'dreiningshastighetene': ('dreiningshastighet',),
'dreiningshastigheter': ('dreiningshastighet',),
'dreis': ('dreis',),
'dreisen': ('dreis',),
'dreisene': ('dreis',),
'dreiser': ('dreis',),
'drektighet': ('drektighet',),
'drektigheta': ('drektighet',),
'drektigheten': ('drektighet',),
'drektighetene': ('drektighet',),
'drektigheter': ('drektighet',),
'drenering': ('drenering',),
'dreneringa': ('drenering',),
'dreneringen': ('drenering',),
'dreneringene': ('drenering',),
'dreneringer': ('drenering',),
'dreneringsrør': ('dreneringsrør',),
'dreneringsrøra': ('dreneringsrør',),
'dreneringsrørene': ('dreneringsrør',),
'dreneringsrøret': ('dreneringsrør',),
'dreneringsrør': ('dreneringsrør',),
'dreneringsrøra': ('dreneringsrør',),
'dreneringsrørene': ('dreneringsrør',),
'dreneringsrøret': ('dreneringsrør',),
'dreng': ('dreng',),
'drengen': ('dreng',),
'drengene': ('dreng',),
'drenger': ('dreng',),
'drengestova': ('drengestove',),
'drengestove': ('drengestove',),
'drengestoven': ('drengestove',),
'drengestovene': ('drengestove',),
'drengestover': ('drengestove',),
'drengestua': ('drengestue',),
'drengestue': ('drengestue',),
'drengestuen': ('drengestue',),
'drengestuene': ('drengestue',),
'drengestuer': ('drengestue',),
'drening': ('drening',),
'dreninga': ('drening',),
'dreningen': ('drening',),
'dreningene': ('drening',),
'dreninger': ('drening',),
'drensrør': ('drensrør',),
'drensrøra': ('drensrør',),
'drensrørene': ('drensrør',),
'drensrøret': ('drensrør',),
'drensrør': ('drensrør',),
'drensrøra': ('drensrør',),
'drensrørene': ('drensrør',),
'drensrøret': ('drensrør',),
'drep': ('drep',),
'drepen': ('drep',),
'drepene': ('drep',),
'dreper': ('drep',),
'dresin': ('dresin',),
'dresinen': ('dresin',),
'dresinene': ('dresin',),
'dresiner': ('dresin',),
'dress': ('dress',),
'dressen': ('dress',),
'dressene': ('dress',),
'dresser': ('dress',),
'dressbuksa': ('dressbukse',),
'dressbukse': ('dressbukse',),
'dressbuksen': ('dressbukse',),
'dressbuksene': ('dressbukse',),
'dressbukser': ('dressbukse',),
'dressing': ('dressing',),
'dressingen': ('dressing',),
'dressingene': ('dressing',),
'dressinger': ('dressing',),
'dressjakka': ('dressjakke',),
'dressjakke': ('dressjakke',),
'dressjakken': ('dressjakke',),
'dressjakkene': ('dressjakke',),
'dressjakker': ('dressjakke',),
'dressur': ('dressur',),
'dressuren': ('dressur',),
'dressurene': ('dressur',),
'dressurer': ('dressur',),
'dressurhalsband': ('dressurhalsband',),
'dressurhalsbanda': ('dressurhalsband',),
'dressurhalsbandene': ('dressurhalsband',),
'dressurhalsbandet': ('dressurhalsband',),
'dressurhalsbånd': ('dressurhalsbånd',),
'dressurhalsbånda': ('dressurhalsbånd',),
'dressurhalsbåndene': ('dressurhalsbånd',),
'dressurhalsbåndet': ('dressurhalsbånd',),
'dressurridning': ('dressurridning',),
'dressurridninga': ('dressurridning',),
'dressurridningen': ('dressurridning',),
'dressurridningene': ('dressurridning',),
'dressurridninger': ('dressurridning',),
'dressør': ('dressør',),
'dressøren': ('dressør',),
'dressørene': ('dressør',),
'dressører': ('dressør',),
'drett': ('drett',),
'dretta': ('drett',),
'dretten': ('drett',),
'drettene': ('drett',),
'dretter': ('drett',),
'drettet': ('drett',),
'drev': ('drev',),
'dreva': ('drev',),
'drevene': ('drev',),
'drevet': ('drev',),
'dribler': ('dribler',),
'driblere': ('dribler',),
'dribleren': ('dribler',),
'driblerer': ('dribler',),
'driblerne': ('dribler',),
'drift': ('drift',),
'drifta': ('drift',),
'driften': ('drift',),
'driftene': ('drift',),
'drifter': ('drift',),
'driftekar': ('driftekar',),
'driftekaren': ('driftekar',),
'driftekarene': ('driftekar',),
'driftekarer': ('driftekar',),
'driftsagronom': ('driftsagronom',),
'driftsagronomen': ('driftsagronom',),
'driftsagronomene': ('driftsagronom',),
'driftsagronomer': ('driftsagronom',),
'driftsbalanse': ('driftsbalanse',),
'driftsbalansen': ('driftsbalanse',),
'driftsbalansene': ('driftsbalanse',),
'driftsbalanser': ('driftsbalanse',),
'driftsbestyrer': ('driftsbestyrer',),
'driftsbestyrere': ('driftsbestyrer',),
'driftsbestyreren': ('driftsbestyrer',),
'driftsbestyrerer': ('driftsbestyrer',),
'driftsbestyrerne': ('driftsbestyrer',),
'driftsbygning': ('driftsbygning',),
'driftsbygninga': ('driftsbygning',),
'driftsbygningen': ('driftsbygning',),
'driftsbygningene': ('driftsbygning',),
'driftsbygninger': ('driftsbygning',),
'driftshemmelighet': ('driftshemmelighet',),
'driftshemmeligheta': ('driftshemmelighet',),
'driftshemmeligheten': ('driftshemmelighet',),
'driftshemmelighetene': ('driftshemmelighet',),
'driftshemmeligheter': ('driftshemmelighet',),
'driftsherre': ('driftsherre',),
'driftsherren': ('driftsherre',),
'driftsherrene': ('driftsherre',),
'driftsherrer': ('driftsherre',),
'driftsingeniør': ('driftsingeniør',),
'driftsingeniøren': ('driftsingeniør',),
'driftsingeniørene': ('driftsingeniør',),
'driftsingeniører': ('driftsingeniør',),
'driftsinnskrenkning': ('driftsinnskrenkning',),
'driftsinnskrenkninga': ('driftsinnskrenkning',),
'driftsinnskrenkningen': ('driftsinnskrenkning',),
'driftsinnskrenkningene': ('driftsinnskrenkning',),
'driftsinnskrenkninger': ('driftsinnskrenkning',),
'driftskapital': ('driftskapital',),
'driftskapitalen': ('driftskapital',),
'driftskapitalene': ('driftskapital',),
'driftskapitaler': ('driftskapital',),
'driftskostnad': ('driftskostnad',),
'driftskostnaden': ('driftskostnad',),
'driftskostnadene': ('driftskostnad',),
'driftskostnader': ('driftskostnad',),
'driftskreditt': ('driftskreditt',),
'driftskreditten': ('driftskreditt',),
'driftskredittene': ('driftskreditt',),
'driftskreditter': ('driftskreditt',),
'driftsliv': ('driftsliv',),
'driftsliva': ('driftsliv',),
'driftslivene': ('driftsliv',),
'driftslivet': ('driftsliv',),
'driftsmiddel': ('driftsmiddel',),
'driftsmiddelet': ('driftsmiddel',),
'driftsmidla': ('driftsmiddel',),
'driftsmidlene': ('driftsmiddel',),
'driftsmidler': ('driftsmiddel',),
'driftsmidlet': ('driftsmiddel',),
'driftsmåte': ('driftsmåte',),
'driftsmåten': ('driftsmåte',),
'driftsmåtene': ('driftsmåte',),
'driftsmåter': ('driftsmåte',),
'driftsoverskott': ('driftsoverskott',),
'driftsoverskotta': ('driftsoverskott',),
'driftsoverskottene': ('driftsoverskott',),
'driftsoverskottet': ('driftsoverskott',),
'driftsoverskudd': ('driftsoverskudd',),
'driftsoverskudda': ('driftsoverskudd',),
'driftsoverskuddene': ('driftsoverskudd',),
'driftsoverskuddet': ('driftsoverskudd',),
'driftsplan': ('driftsplan',),
'driftsplanen': ('driftsplan',),
'driftsplanene': ('driftsplan',),
'driftsplaner': ('driftsplan',),
'driftsplanlegging': ('driftsplanlegging',),
'driftsplanlegginga': ('driftsplanlegging',),
'driftsplanleggingen': ('driftsplanlegging',),
'driftsplanleggingene': ('driftsplanlegging',),
'driftsplanlegginger': ('driftsplanlegging',),
'driftsregnskap': ('driftsregnskap',),
'driftsregnskapa': ('driftsregnskap',),
'driftsregnskapene': ('driftsregnskap',),
'driftsregnskaper': ('driftsregnskap',),
'driftsregnskapet': ('driftsregnskap',),
'driftsrekneskap': ('driftsrekneskap',),
'driftsrekneskapen': ('driftsrekneskap',),
'driftsrekneskapene': ('driftsrekneskap',),
'driftsrekneskaper': ('driftsrekneskap',),
'driftsresultat': ('driftsresultat',),
'driftsresultata': ('driftsresultat',),
'driftsresultatene': ('driftsresultat',),
'driftsresultater': ('driftsresultat',),
'driftsresultatet': ('driftsresultat',),
'driftsstans': ('driftsstans',),
'driftsstansen': ('driftsstans',),
'driftsstansene': ('driftsstans',),
'driftsstanser': ('driftsstans',),
'driftstillegg': ('driftstillegg',),
'driftstillegga': ('driftstillegg',),
'driftstilleggene': ('driftstillegg',),
'driftstillegget': ('driftstillegg',),
'driftstilskott': ('driftstilskott',),
'driftstilskotta': ('driftstilskott',),
'driftstilskottene': ('driftstilskott',),
'driftstilskottet': ('driftstilskott',),
'driftstilskudd': ('driftstilskudd',),
'driftstilskudda': ('driftstilskudd',),
'driftstilskuddene': ('driftstilskudd',),
'driftstilskuddet': ('driftstilskudd',),
'driftsunderskott': ('driftsunderskott',),
'driftsunderskotta': ('driftsunderskott',),
'driftsunderskottene': ('driftsunderskott',),
'driftsunderskottet': ('driftsunderskott',),
'driftsunderskudd': ('driftsunderskudd',),
'driftsunderskudda': ('driftsunderskudd',),
'driftsunderskuddene': ('driftsunderskudd',),
'driftsunderskuddet': ('driftsunderskudd',),
'driftsår': ('driftsår',),
'driftsåra': ('driftsår',),
'driftsårene': ('driftsår',),
'driftsåret': ('driftsår',),
'driftsøkonomi': ('driftsøkonomi',),
'driftsøkonomien': ('driftsøkonomi',),
'driftsøkonomiene': ('driftsøkonomi',),
'driftsøkonomier': ('driftsøkonomi',),
'drikk': ('drikk',),
'drikken': ('drikk',),
'drikkene': ('drikk',),
'drikker': ('drikk',),
'drikke': ('drikke',),
'drikkebula': ('drikkebule',),
'drikkebule': ('drikkebule',),
'drikkebulen': ('drikkebule',),
'drikkebulene': ('drikkebule',),
'drikkebuler': ('drikkebule',),
'drikkefontene': ('drikkefontene',),
'drikkefontenen': ('drikkefontene',),
'drikkefontenene': ('drikkefontene',),
'drikkefontener': ('drikkefontene',),
'drikkegilda': ('drikkegilde',),
'drikkegilde': ('drikkegilde',),
'drikkegildene': ('drikkegilde',),
'drikkegilder': ('drikkegilde',),
'drikkegildet': ('drikkegilde',),
'drikkehorn': ('drikkehorn',),
'drikkehorna': ('drikkehorn',),
'drikkehornene': ('drikkehorn',),
'drikkehornet': ('drikkehorn',),
'drikkekar': ('drikkekar',),
'drikkekara': ('drikkekar',),
'drikkekarene': ('drikkekar',),
'drikkekaret': ('drikkekar',),
'drikkelag': ('drikkelag',),
'drikkelaga': ('drikkelag',),
'drikkelagene': ('drikkelag',),
'drikkelaget': ('drikkelag',),
'drikkepengene': ('drikkepenger',),
'drikkepenger': ('drikkepenger',),
'drikkepress': ('drikkepress',),
'drikkepressa': ('drikkepress',),
'drikkepressene': ('drikkepress',),
'drikkepresset': ('drikkepress',),
'drikkeskikk': ('drikkeskikk',),
'drikkeskikken': ('drikkeskikk',),
'drikkeskikkene': ('drikkeskikk',),
'drikkeskikker': ('drikkeskikk',),
'drikkevann': ('drikkevann',),
'drikkevanna': ('drikkevann',),
'drikkevannene': ('drikkevann',),
'drikkevannet': ('drikkevann',),
'drikkevara': ('drikkevare',),
'drikkevare': ('drikkevare',),
'drikkevaren': ('drikkevare',),
'drikkevarene': ('drikkevare',),
'drikkevarer': ('drikkevare',),
'drikkevatn': ('drikkevatn',),
'drikkevatna': ('drikkevatn',),
'drikkevatnene': ('drikkevatn',),
'drikkevatnet': ('drikkevatn',),
'drikkevisa': ('drikkevise',),
'drikkevise': ('drikkevise',),
'drikkevisen': ('drikkevise',),
'drikkevisene': ('drikkevise',),
'drikkeviser': ('drikkevise',),
'drikks': ('drikks',),
'drikksen': ('drikks',),
'drikksene': ('drikks',),
'drikkser': ('drikks',),
'driks': ('driks',),
'driksen': ('driks',),
'driksene': ('driks',),
'drikser': ('driks',),
'drillbor': ('drillbor',),
'drillbora': ('drillbor',),
'drillboren': ('drillbor',),
'drillborene': ('drillbor',),
'drillboret': ('drillbor',),
'drilljenta': ('drilljente',),
'drilljente': ('drilljente',),
'drilljenten': ('drilljente',),
'drilljentene': ('drilljente',),
'drilljenter': ('drilljente',),
'drillkorps': ('drillkorps',),
'drillkorpsa': ('drillkorps',),
'drillkorpsene': ('drillkorps',),
'drillkorpset': ('drillkorps',),
'drillskip': ('drillskip',),
'drillskipa': ('drillskip',),
'drillskipene': ('drillskip',),
'drillskipet': ('drillskip',),
'drink': ('drink',),
'drinken': ('drink',),
'drinkene': ('drink',),
'drinker': ('drink',),
'dritt': ('dritt',),
'dritta': ('dritt',),
'dritten': ('dritt',),
'drittene': ('dritt',),
'dritter': ('dritt',),
'drittet': ('dritt',),
'drittgutt': ('drittgutt',),
'drittgutten': ('drittgutt',),
'drittguttene': ('drittgutt',),
'drittgutter': ('drittgutt',),
'drittjobb': ('drittjobb',),
'drittjobben': ('drittjobb',),
'drittjobbene': ('drittjobb',),
'drittjobber': ('drittjobb',),
'drittsekk': ('drittsekk',),
'drittsekken': ('drittsekk',),
'drittsekkene': ('drittsekk',),
'drittsekker': ('drittsekk',),
'drittunge': ('drittunge',),
'drittungen': ('drittunge',),
'drittungene': ('drittunge',),
'drittunger': ('drittunge',),
'drittvær': ('drittvær',),
'drittværa': ('drittvær',),
'drittværene': ('drittvær',),
'drittværet': ('drittvær',),
'driv': ('driv',),
'driva': ('driv',),
'driven': ('driv',),
'drivene': ('driv',),
'driver': ('driv',),
'drivet': ('driv',),
'drivaksel': ('drivaksel',),
'drivakselen': ('drivaksel',),
'drivakslene': ('drivaksel',),
'drivaksler': ('drivaksel',),
'drivbenk': ('drivbenk',),
'drivbenken': ('drivbenk',),
'drivbenkene': ('drivbenk',),
'drivbenker': ('drivbenk',),
'drive': ('drive',),
'driven': ('drive',),
'drivene': ('drive',),
'driver': ('drive',),
'driva': ('drive',),
'drive': ('drive',),
'driven': ('drive',),
'drivene': ('drive',),
'driver': ('drive',),
'driver': ('driver',),
'drivere': ('driver',),
'driveren': ('driver',),
'driverer': ('driver',),
'driverne': ('driver',),
'drivfiska': ('drivfiske',),
'drivfiske': ('drivfiske',),
'drivfiskene': ('drivfiske',),
'drivfisker': ('drivfiske',),
'drivfisket': ('drivfiske',),
'drivgarn': ('drivgarn',),
'drivgarna': ('drivgarn',),
'drivgarnene': ('drivgarn',),
'drivgarnet': ('drivgarn',),
'drivgarnsfiska': ('drivgarnsfiske',),
'drivgarnsfiske': ('drivgarnsfiske',),
'drivgarnsfiskene': ('drivgarnsfiske',),
'drivgarnsfisker': ('drivgarnsfiske',),
'drivgarnsfisket': ('drivgarnsfiske',),
'drivgods': ('drivgods',),
'drivgodsa': ('drivgods',),
'drivgodsene': ('drivgods',),
'drivgodset': ('drivgods',),
'drivhjul': ('drivhjul',),
'drivhjula': ('drivhjul',),
'drivhjulene': ('drivhjul',),
'drivhjulet': ('drivhjul',),
'drivhus': ('drivhus',),
'drivhusa': ('drivhus',),
'drivhusene': ('drivhus',),
'drivhuset': ('drivhus',),
'drivhuseffekt': ('drivhuseffekt',),
'drivhuseffekten': ('drivhuseffekt',),
'drivhuseffektene': ('drivhuseffekt',),
'drivhuseffekter': ('drivhuseffekt',),
'drivhusmiljø': ('drivhusmiljø',),
'drivhusmiljøa': ('drivhusmiljø',),
'drivhusmiljøene': ('drivhusmiljø',),
'drivhusmiljøer': ('drivhusmiljø',),
'drivhusmiljøet': ('drivhusmiljø',),
'drivhusplanta': ('drivhusplante',),
'drivhusplante': ('drivhusplante',),
'drivhusplanten': ('drivhusplante',),
'drivhusplantene': ('drivhusplante',),
'drivhusplanter': ('drivhusplante',),
'drivis': ('drivis',),
'drivisen': ('drivis',),
'drivisene': ('drivis',),
'driviser': ('drivis',),
'drivjakt': ('drivjakt',),
'drivjakta': ('drivjakt',),
'drivjakten': ('drivjakt',),
'drivjaktene': ('drivjakt',),
'drivjakter': ('drivjakt',),
'drivkraft': ('drivkraft',),
'drivkrafta': ('drivkraft',),
'drivkraften': ('drivkraft',),
'drivkreftene': ('drivkraft',),
'drivkrefter': ('drivkraft',),
'drivmina': ('drivmine',),
'drivmine': ('drivmine',),
'drivminen': ('drivmine',),
'drivminene': ('drivmine',),
'drivminer': ('drivmine',),
'drivreim': ('drivreim',),
'drivreima': ('drivreim',),
'drivreimen': ('drivreim',),
'drivreimene': ('drivreim',),
'drivreimer': ('drivreim',),
'drivrem': ('drivrem',),
'drivremma': ('drivrem',),
'drivremmen': ('drivrem',),
'drivremmene': ('drivrem',),
'drivremmer': ('drivrem',),
'drivstoff': ('drivstoff',),
'drivstoffa': ('drivstoff',),
'drivstoffene': ('drivstoff',),
'drivstoffer': ('drivstoff',),
'drivstoffet': ('drivstoff',),
'drivtømmer': ('drivtømmer',),
'drivtømmera': ('drivtømmer',),
'drivtømmerene': ('drivtømmer',),
'drivtømmeret': ('drivtømmer',),
'drivtømra': ('drivtømmer',),
'drivtømre': ('drivtømmer',),
'drivtømrene': ('drivtømmer',),
'drivved': ('drivved',),
'drivveden': ('drivved',),
'drivvedene': ('drivved',),
'drivveder': ('drivved',),
'drivverk': ('drivverk',),
'drivverka': ('drivverk',),
'drivverkene': ('drivverk',),
'drivverker': ('drivverk',),
'drivverket': ('drivverk',),
'droge': ('droge',),
'drogen': ('droge',),
'drogene': ('droge',),
'droger': ('droge',),
'drogeri': ('drogeri',),
'drogeria': ('drogeri',),
'drogeriene': ('drogeri',),
'drogerier': ('drogeri',),
'drogeriet': ('drogeri',),
'drogist': ('drogist',),
'drogisten': ('drogist',),
'drogistene': ('drogist',),
'drogister': ('drogist',),
'dromedar': ('dromedar',),
'dromedaren': ('dromedar',),
'dromedarene': ('dromedar',),
'dromedarer': ('dromedar',),
'drone': ('drone',),
'dronen': ('drone',),
'dronene': ('drone',),
'droner': ('drone',),
'dronning': ('dronning',),
'dronninga': ('dronning',),
'dronningen': ('dronning',),
'dronningene': ('dronning',),
'dronninger': ('dronning',),
'dronningavl': ('dronningavl',),
'dronningavlen': ('dronningavl',),
'dronningavlene': ('dronningavl',),
'dronningavler': ('dronningavl',),
'dronningbia': ('dronningbie',),
'dronningbie': ('dronningbie',),
'dronningbien': ('dronningbie',),
'dronningbiene': ('dronningbie',),
'dronningbier': ('dronningbie',),
'dronninggambit': ('dronninggambit',),
'dronninggambiten': ('dronninggambit',),
'dronninggambitene': ('dronninggambit',),
'dronninggambiter': ('dronninggambit',),
'dropla': ('drople',),
'drople': ('drople',),
'droplen': ('drople',),
'droplene': ('drople',),
'dropler': ('drople',),
'dropp': ('dropp',),
'droppa': ('dropp',),
'droppene': ('dropp',),
'droppet': ('dropp',),
'drops': ('drops',),
'dropsa': ('drops',),
'dropsen': ('drops',),
'dropsene': ('drops',),
'dropset': ('drops',),
'dropseska': ('dropseske',),
'dropseske': ('dropseske',),
'dropsesken': ('dropseske',),
'dropseskene': ('dropseske',),
'dropsesker': ('dropseske',),
'dropspose': ('dropspose',),
'dropsposen': ('dropspose',),
'dropsposene': ('dropspose',),
'dropsposer': ('dropspose',),
'drosja': ('drosje',),
'drosje': ('drosje',),
'drosjen': ('drosje',),
'drosjene': ('drosje',),
'drosjer': ('drosje',),
'drosjebil': ('drosjebil',),
'drosjebilen': ('drosjebil',),
'drosjebilene': ('drosjebil',),
'drosjebiler': ('drosjebil',),
'drosjebuss': ('drosjebuss',),
'drosjebussen': ('drosjebuss',),
'drosjebussene': ('drosjebuss',),
'drosjebusser': ('drosjebuss',),
'drosjeeier': ('drosjeeier',),
'drosjeeiere': ('drosjeeier',),
'drosjeeieren': ('drosjeeier',),
'drosjeeierer': ('drosjeeier',),
'drosjeeierne': ('drosjeeier',),
'drosjeholdeplass': ('drosjeholdeplass',),
'drosjeholdeplassen': ('drosjeholdeplass',),
'drosjeholdeplassene': ('drosjeholdeplass',),
'drosjeholdeplasser': ('drosjeholdeplass',),
'drosjekø': ('drosjekø',),
'drosjekøen': ('drosjekø',),
'drosjekøene': ('drosjekø',),
'drosjekøer': ('drosjekø',),
'drosjesentral': ('drosjesentral',),
'drosjesentralen': ('drosjesentral',),
'drosjesentralene': ('drosjesentral',),
'drosjesentraler': ('drosjesentral',),
'drosjesjåfør': ('drosjesjåfør',),
'drosjesjåføren': ('drosjesjåfør',),
'drosjesjåførene': ('drosjesjåfør',),
'drosjesjåfører': ('drosjesjåfør',),
'drosjetakst': ('drosjetakst',),
'drosjetaksten': ('drosjetakst',),
'drosjetakstene': ('drosjetakst',),
'drosjetakster': ('drosjetakst',),
'drosselspole': ('drosselspole',),
'drosselspolen': ('drosselspole',),
'drosselspolene': ('drosselspole',),
'drosselspoler': ('drosselspole',),
'drott': ('drott',),
'drotten': ('drott',),
'drottene': ('drott',),
'drotter': ('drott',),
'drottkvætt': ('drottkvætt',),
'drottsete': ('drottsete',),
'drottseten': ('drottsete',),
'drottsetene': ('drottsete',),
'drottseter': ('drottsete',),
'drua': ('drue',),
'drue': ('drue',),
'druen': ('drue',),
'druene': ('drue',),
'druer': ('drue',),
'drueagurk': ('drueagurk',),
'drueagurken': ('drueagurk',),
'drueagurkene': ('drueagurk',),
'drueagurker': ('drueagurk',),
'druebrennevin': ('druebrennevin',),
'druebrennevinene': ('druebrennevin',),
'druebrenneviner': ('druebrennevin',),
'druebrennevinet': ('druebrennevin',),
'drueklase': ('drueklase',),
'drueklasen': ('drueklase',),
'drueklasene': ('drueklase',),
'drueklaser': ('drueklase',),
'druesaft': ('druesaft',),
'druesafta': ('druesaft',),
'druesaften': ('druesaft',),
'druesaftene': ('druesaft',),
'druesafter': ('druesaft',),
'druesukker': ('druesukker',),
'druesukkera': ('druesukker',),
'druesukkere': ('druesukker',),
'druesukkerene': ('druesukker',),
'druesukkeret': ('druesukker',),
'druesukkerne': ('druesukker',),
'druevin': ('druevin',),
'druevinen': ('druevin',),
'druevinene': ('druevin',),
'drueviner': ('druevin',),
'druide': ('druide',),
'druiden': ('druide',),
'druidene': ('druide',),
'druider': ('druide',),
'drukkenbolt': ('drukkenbolt',),
'drukkenbolten': ('drukkenbolt',),
'drukkenboltene': ('drukkenbolt',),
'drukkenbolter': ('drukkenbolt',),
'drukkenskap': ('drukkenskap',),
'drukkenskapen': ('drukkenskap',),
'drukkenskapene': ('drukkenskap',),
'drukkenskaper': ('drukkenskap',),
'drukning': ('drukning',),
'drukninga': ('drukning',),
'drukningen': ('drukning',),
'drukningene': ('drukning',),
'drukninger': ('drukning',),
'drukningsdød': ('drukningsdød',),
'drukningsdøden': ('drukningsdød',),
'drukningsdødene': ('drukningsdød',),
'drukningsdøder': ('drukningsdød',),
'drukningsulykka': ('drukningsulykke',),
'drukningsulykke': ('drukningsulykke',),
'drukningsulykken': ('drukningsulykke',),
'drukningsulykkene': ('drukningsulykke',),
'drukningsulykker': ('drukningsulykke',),
'druser': ('druser',),
'drusere': ('druser',),
'druseren': ('druser',),
'druserer': ('druser',),
'druserne': ('druser',),
'dryada': ('dryade',),
'dryade': ('dryade',),
'dryaden': ('dryade',),
'dryadene': ('dryade',),
'dryader': ('dryade',),
'dryghet': ('dryghet',),
'drygheta': ('dryghet',),
'drygheten': ('dryghet',),
'dryghetene': ('dryghet',),
'drygheter': ('dryghet',),
'drypp': ('drypp',),
'dryppa': ('drypp',),
'dryppene': ('drypp',),
'dryppet': ('drypp',),
'dryppert': ('dryppert',),
'drypperten': ('dryppert',),
'dryppertene': ('dryppert',),
'drypperter': ('dryppert',),
'dryppstein': ('dryppstein',),
'dryppsteinen': ('dryppstein',),
'dryppsteinene': ('dryppstein',),
'dryppsteiner': ('dryppstein',),
'dryppsteinsformasjon': ('dryppsteinsformasjon',),
'dryppsteinsformasjonen': ('dryppsteinsformasjon',),
'dryppsteinsformasjonene': ('dryppsteinsformasjon',),
'dryppsteinsformasjoner': ('dryppsteinsformasjon',),
'dryppsteinsgrotta': ('dryppsteinsgrotte',),
'dryppsteinsgrotte': ('dryppsteinsgrotte',),
'dryppsteinsgrotten': ('dryppsteinsgrotte',),
'dryppsteinsgrottene': ('dryppsteinsgrotte',),
'dryppsteinsgrotter': ('dryppsteinsgrotte',),
'dryss': ('dryss',),
'dryssa': ('dryss',),
'dryssene': ('dryss',),
'drysset': ('dryss',),
'dråpa': ('dråpa',),
'dråpaen': ('dråpa',),
'dråpaene': ('dråpa',),
'dråpaer': ('dråpa',),
'dråpe': ('dråpe',),
'dråpen': ('dråpe',),
'dråpene': ('dråpe',),
'dråper': ('dråpe',),
'dråpeform': ('dråpeform',),
'dråpeforma': ('dråpeform',),
'dråpeformen': ('dråpeform',),
'dråpeformene': ('dråpeform',),
'dråpeformer': ('dråpeform',),
'dråpeinfeksjon': ('dråpeinfeksjon',),
'dråpeinfeksjonen': ('dråpeinfeksjon',),
'dråpeinfeksjonene': ('dråpeinfeksjon',),
'dråpeinfeksjoner': ('dråpeinfeksjon',),
'dråpeteller': ('dråpeteller',),
'dråpetellere': ('dråpeteller',),
'dråpetelleren': ('dråpeteller',),
'dråpetellerer': ('dråpeteller',),
'dråpetellerne': ('dråpeteller',),
'drått': ('drått',),
'dråtten': ('drått',),
'dråttene': ('drått',),
'dråtter': ('drått',),
'drøftelse': ('drøftelse',),
'drøftelsen': ('drøftelse',),
'drøftelsene': ('drøftelse',),
'drøftelser': ('drøftelse',),
'drøfting': ('drøfting',),
'drøftinga': ('drøfting',),
'drøftingen': ('drøfting',),
'drøftingene': ('drøfting',),
'drøftinger': ('drøfting',),
'drøm': ('drøm',),
'drømmen': ('drøm',),
'drømmene': ('drøm',),
'drømmer': ('drøm',),
'drømmebilda': ('drømmebilde',),
'drømmebilde': ('drømmebilde',),
'drømmebildene': ('drømmebilde',),
'drømmebilder': ('drømmebilde',),
'drømmebildet': ('drømmebilde',),
'drømmedag': ('drømmedag',),
'drømmedagen': ('drømmedag',),
'drømmedagene': ('drømmedag',),
'drømmedager': ('drømmedag',),
'drømmeferie': ('drømmeferie',),
'drømmeferien': ('drømmeferie',),
'drømmeferiene': ('drømmeferie',),
'drømmeferier': ('drømmeferie',),
'drømmeforhold': ('drømmeforhold',),
'drømmeforholda': ('drømmeforhold',),
'drømmeforholdene': ('drømmeforhold',),
'drømmeforholdet': ('drømmeforhold',),
'drømmeland': ('drømmeland',),
'drømmelanda': ('drømmeland',),
'drømmelandene': ('drømmeland',),
'drømmelandet': ('drømmeland',),
'drømmepåska': ('drømmepåske',),
'drømmepåske': ('drømmepåske',),
'drømmepåsken': ('drømmepåske',),
'drømmepåskene': ('drømmepåske',),
'drømmepåsker': ('drømmepåske',),
'drømmer': ('drømmer',),
'drømmere': ('drømmer',),
'drømmeren': ('drømmer',),
'drømmerer': ('drømmer',),
'drømmerne': ('drømmer',),
'drømmeri': ('drømmeri',),
'drømmeria': ('drømmeri',),
'drømmeriene': ('drømmeri',),
'drømmerier': ('drømmeri',),
'drømmeriet': ('drømmeri',),
'drømmeslott': ('drømmeslott',),
'drømmeslotta': ('drømmeslott',),
'drømmeslottene': ('drømmeslott',),
'drømmeslottet': ('drømmeslott',),
'drømmesyn': ('drømmesyn',),
'drømmesyna': ('drømmesyn',),
'drømmesynene': ('drømmesyn',),
'drømmesyner': ('drømmesyn',),
'drømmesynet': ('drømmesyn',),
'drømmetilværelse': ('drømmetilværelse',),
'drømmetilværelsen': ('drømmetilværelse',),
'drømmetilværelsene': ('drømmetilværelse',),
'drømmetilværelser': ('drømmetilværelse',),
'drømmetur': ('drømmetur',),
'drømmeturen': ('drømmetur',),
'drømmeturene': ('drømmetur',),
'drømmeturer': ('drømmetur',),
'drømmetyder': ('drømmetyder',),
'drømmetydere': ('drømmetyder',),
'drømmetyderen': ('drømmetyder',),
'drømmetyderer': ('drømmetyder',),
'drømmetyderne': ('drømmetyder',),
'drømmeverden': ('drømmeverden',),
'drømmeverdenen': ('drømmeverden',),
'drømmeverdenene': ('drømmeverden',),
'drømmeverdener': ('drømmeverden',),
'drønn': ('drønn',),
'drønna': ('drønn',),
'drønnene': ('drønn',),
'drønnet': ('drønn',),
'drøpel': ('drøpel',),
'drøpelen': ('drøpel',),
'drøplene': ('drøpel',),
'drøpler': ('drøpel',),
'drøpel': ('drøpel',),
'drøpelen': ('drøpel',),
'drøplene': ('drøpel',),
'drøpler': ('drøpel',),
'drøpel-r': ('drøpel-r',),
'drøpel-r-en': ('drøpel-r',),
'drøpel-r-ene': ('drøpel-r',),
'drøpel-r-er': ('drøpel-r',),
'drøpel-r': ('drøpel-r',),
'drøpel-r-en': ('drøpel-r',),
'drøpel-r-ene': ('drøpel-r',),
'drøpel-r-er': ('drøpel-r',),
'drøs': ('drøs',),
'drøsa': ('drøs',),
'drøsen': ('drøs',),
'drøsene': ('drøs',),
'drøser': ('drøs',),
'drøset': ('drøs',),
'drøss': ('drøss',),
'drøssa': ('drøss',),
'drøssen': ('drøss',),
'drøssene': ('drøss',),
'drøsser': ('drøss',),
'drøsset': ('drøss',),
'drøv': ('drøv',),
'drøvel': ('drøvel',),
'drøvelen': ('drøvel',),
'drøvlene': ('drøvel',),
'drøvler': ('drøvel',),
'drøvel': ('drøvel',),
'drøvelen': ('drøvel',),
'drøvlene': ('drøvel',),
'drøvler': ('drøvel',),
'drøvel-r': ('drøvel-r',),
'drøvel-r-en': ('drøvel-r',),
'drøvel-r-ene': ('drøvel-r',),
'drøvel-r-er': ('drøvel-r',),
'drøvel-r': ('drøvel-r',),
'drøvel-r-en': ('drøvel-r',),
'drøvel-r-ene': ('drøvel-r',),
'drøvel-r-er': ('drøvel-r',),
'drøvtygger': ('drøvtygger',),
'drøvtyggere': ('drøvtygger',),
'drøvtyggeren': ('drøvtygger',),
'drøvtyggerer': ('drøvtygger',),
'drøvtyggerne': ('drøvtygger',),
'drøyde': ('drøyde',),
'drøyden': ('drøyde',),
'drøydene': ('drøyde',),
'drøyder': ('drøyde',),
'drøyhet': ('drøyhet',),
'drøyheta': ('drøyhet',),
'drøyheten': ('drøyhet',),
'drøyhetene': ('drøyhet',),
'drøyheter': ('drøyhet',),
'dualis': ('dualis',),
'dualisen': ('dualis',),
'dualisene': ('dualis',),
'dualiser': ('dualis',),
'dualisme': ('dualisme',),
'dualismen': ('dualisme',),
'dualismene': ('dualisme',),
'dualismer': ('dualisme',),
'dubleen': ('dublé',),
'dubleene': ('dublé',),
'dubleer': ('dublé',),
'dublé': ('dublé',),
'dubléen': ('dublé',),
'dubléene': ('dublé',),
'dubléer': ('dublé',),
'dubleringstog': ('dubleringstog',),
'dubleringstoga': ('dubleringstog',),
'dubleringstogene': ('dubleringstog',),
'dubleringstoget': ('dubleringstog',),
'dublett': ('dublett',),
'dubletten': ('dublett',),
'dublettene': ('dublett',),
'dubletter': ('dublett',),
'duc d\'albe': ('duc d\'albe',),
'duc d\'alben': ('duc d\'albe',),
'duc d\'albene': ('duc d\'albe',),
'duc d\'alber': ('duc d\'albe',),
'duce': ('duce',),
'duchesse': ('duchesse',),
'duchessen': ('duchesse',),
'duchessene': ('duchesse',),
'duchesser': ('duchesse',),
'dua': ('due',),
'due': ('due',),
'duen': ('due',),
'duene': ('due',),
'duer': ('due',),
'duehauk': ('duehauk',),
'duehauken': ('duehauk',),
'duehaukene': ('duehauk',),
'duehauker': ('duehauk',),
'duell': ('duell',),
'duellen': ('duell',),
'duellene': ('duell',),
'dueller': ('duell',),
'duellant': ('duellant',),
'duellanten': ('duellant',),
'duellantene': ('duellant',),
'duellanter': ('duellant',),
'duelus': ('duelus',),
'duelusa': ('duelus',),
'duelusen': ('duelus',),
'duelusene': ('duelus',),
'dueskyting': ('dueskyting',),
'dueskytinga': ('dueskyting',),
'dueskytingen': ('dueskyting',),
'dueskytingene': ('dueskyting',),
'dueskytinger': ('dueskyting',),
'dueslag': ('dueslag',),
'dueslaga': ('dueslag',),
'dueslagene': ('dueslag',),
'dueslaget': ('dueslag',),
'duestegg': ('duestegg',),
'duesteggen': ('duestegg',),
'duesteggene': ('duestegg',),
'duestegger': ('duestegg',),
'duett': ('duett',),
'duetten': ('duett',),
'duettene': ('duett',),
'duetter': ('duett',),
'duft': ('duft',),
'duften': ('duft',),
'duftene': ('duft',),
'dufter': ('duft',),
'dugg': ('dugg',),
'duggen': ('dugg',),
'duggene': ('dugg',),
'dugger': ('dugg',),
'duggdråpe': ('duggdråpe',),
'duggdråpen': ('duggdråpe',),
'duggdråpene': ('duggdråpe',),
'duggdråper': ('duggdråpe',),
'duggpil': ('duggpil',),
'duggpila': ('duggpil',),
'duggpilen': ('duggpil',),
'duggpilene': ('duggpil',),
'duggpiler': ('duggpil',),
'duggpunkt': ('duggpunkt',),
'duggpunkta': ('duggpunkt',),
'duggpunktene': ('duggpunkt',),
'duggpunkter': ('duggpunkt',),
'duggpunktet': ('duggpunkt',),
'dugleik': ('dugleik',),
'dugleiken': ('dugleik',),
'dugleikene': ('dugleik',),
'dugleiker': ('dugleik',),
'dugnad': ('dugnad',),
'dugnaden': ('dugnad',),
'dugnadene': ('dugnad',),
'dugnader': ('dugnad',),
'dugnadsarbeid': ('dugnadsarbeid',),
'dugnadsarbeida': ('dugnadsarbeid',),
'dugnadsarbeidene': ('dugnadsarbeid',),
'dugnadsarbeider': ('dugnadsarbeid',),
'dugnadsarbeidet': ('dugnadsarbeid',),
'dugnadsfolk': ('dugnadsfolk',),
'dugnadsfolka': ('dugnadsfolk',),
'dugnadsfolkene': ('dugnadsfolk',),
'dugnadsfolket': ('dugnadsfolk',),
'dugnadsgraut': ('dugnadsgraut',),
'dugnadsgrauten': ('dugnadsgraut',),
'dugnadsgrautene': ('dugnadsgraut',),
'dugnadsgrauter': ('dugnadsgraut',),
'dugnadsgrøt': ('dugnadsgrøt',),
'dugnadsgrøten': ('dugnadsgrøt',),
'dugnadsgrøtene': ('dugnadsgrøt',),
'dugnadsgrøter': ('dugnadsgrøt',),
'dugurd': ('dugurd',),
'dugurden': ('dugurd',),
'dugurdene': ('dugurd',),
'dugurder': ('dugurd',),
'duk': ('duk',),
'duken': ('duk',),
'dukene': ('duk',),
'duker': ('duk',),
'dukat': ('dukat',),
'dukaten': ('dukat',),
'dukatene': ('dukat',),
'dukater': ('dukat',),
'dukk': ('dukk',),
'dukka': ('dukk',),
'dukken': ('dukk',),
'dukkene': ('dukk',),
'dukker': ('dukk',),
'dukket': ('dukk',),
'dukka': ('dukke',),
'dukke': ('dukke',),
'dukken': ('dukke',),
'dukkene': ('dukke',),
'dukker': ('dukke',),
'dukkeansikt': ('dukkeansikt',),
'dukkeansikta': ('dukkeansikt',),
'dukkeansiktene': ('dukkeansikt',),
'dukkeansikter': ('dukkeansikt',),
'dukkeansiktet': ('dukkeansikt',),
'dukkeklær': ('dukkeklær',),
'dukkeklærne': ('dukkeklær',),
'dukkemann': ('dukkemann',),
'dukkemannen': ('dukkemann',),
'dukkemenn': ('dukkemann',),
'dukkemennene': ('dukkemann',),
'dukkert': ('dukkert',),
'dukkerten': ('dukkert',),
'dukkertene': ('dukkert',),
'dukkerter': ('dukkert',),
'dukkestova': ('dukkestove',),
'dukkestove': ('dukkestove',),
'dukkestoven': ('dukkestove',),
'dukkestovene': ('dukkestove',),
'dukkestover': ('dukkestove',),
'dukkestua': ('dukkestue',),
'dukkestue': ('dukkestue',),
'dukkestuen': ('dukkestue',),
'dukkestuene': ('dukkestue',),
'dukkestuer': ('dukkestue',),
'dukketeater': ('dukketeater',),
'dukketeateret': ('dukketeater',),
'dukketeatra': ('dukketeater',),
'dukketeatre': ('dukketeater',),
'dukketeatrene': ('dukketeater',),
'dukketeatret': ('dukketeater',),
'dukkevogn': ('dukkevogn',),
'dukkevogna': ('dukkevogn',),
'dukkevognen': ('dukkevogn',),
'dukkevognene': ('dukkevogn',),
'dukkevogner': ('dukkevogn',),
'duks': ('duks',),
'duksen': ('duks',),
'duksene': ('duks',),
'dukser': ('duks',),
'dult': ('dult',),
'dulten': ('dult',),
'dultene': ('dult',),
'dulter': ('dult',),
'duma': ('duma',),
'dumaen': ('duma',),
'dumaene': ('duma',),
'dumaer': ('duma',),
'dumdumkula': ('dumdumkule',),
'dumdumkule': ('dumdumkule',),
'dumdumkulen': ('dumdumkule',),
'dumdumkulene': ('dumdumkule',),
'dumdumkuler': ('dumdumkule',),
'dumhet': ('dumhet',),
'dumheta': ('dumhet',),
'dumheten': ('dumhet',),
'dumhetene': ('dumhet',),
'dumheter': ('dumhet',),
'dummenikk': ('dummenikk',),
'dummenikken': ('dummenikk',),
'dummenikkene': ('dummenikk',),
'dummenikker': ('dummenikk',),
'dummepeter': ('dummepeter',),
'dummepetere': ('dummepeter',),
'dummepeteren': ('dummepeter',),
'dummepeterer': ('dummepeter',),
'dummepeterne': ('dummepeter',),
'dumming': ('dumming',),
'dummingen': ('dumming',),
'dummingene': ('dumming',),
'dumminger': ('dumming',),
'dummy': ('dummy',),
'dummyen': ('dummy',),
'dummyene': ('dummy',),
'dummyer': ('dummy',),
'dump': ('dump',),
'dumpa': ('dump',),
'dumpene': ('dump',),
'dumpet': ('dump',),
'dump': ('dump',),
'dumpa': ('dump',),
'dumpen': ('dump',),
'dumpene': ('dump',),
'dumper': ('dump',),
'dumpekandidat': ('dumpekandidat',),
'dumpekandidaten': ('dumpekandidat',),
'dumpekandidatene': ('dumpekandidat',),
'dumpekandidater': ('dumpekandidat',),
'dumper': ('dumper',),
'dumpere': ('dumper',),
'dumperen': ('dumper',),
'dumperer': ('dumper',),
'dumperne': ('dumper',),
'dumphuska': ('dumphuske',),
'dumphuske': ('dumphuske',),
'dumphusken': ('dumphuske',),
'dumphuskene': ('dumphuske',),
'dumphusker': ('dumphuske',),
'dumping': ('dumping',),
'dumpinga': ('dumping',),
'dumpingen': ('dumping',),
'dumpingene': ('dumping',),
'dumpinger': ('dumping',),
'dumpingpris': ('dumpingpris',),
'dumpingprisen': ('dumpingpris',),
'dumpingprisene': ('dumpingpris',),
'dumpingpriser': ('dumpingpris',),
'dumpingvara': ('dumpingvare',),
'dumpingvare': ('dumpingvare',),
'dumpingvaren': ('dumpingvare',),
'dumpingvarene': ('dumpingvare',),
'dumpingvarer': ('dumpingvare',),
'dumrian': ('dumrian',),
'dumrianen': ('dumrian',),
'dumrianene': ('dumrian',),
'dumrianer': ('dumrian',),
'dun': ('dun',),
'duna': ('dun',),
'dunen': ('dun',),
'dunene': ('dun',),
'dunet': ('dun',),
'dunder': ('dunder',),
'dundere': ('dunder',),
'dunderen': ('dunder',),
'dunderer': ('dunder',),
'dunderne': ('dunder',),
'dundre': ('dunder',),
'dundrene': ('dunder',),
'dundrer': ('dunder',),
'dunder': ('dunder',),
'dunderet': ('dunder',),
'dundra': ('dunder',),
'dundre': ('dunder',),
'dundrene': ('dunder',),
'dundret': ('dunder',),
'dundyna': ('dundyne',),
'dundyne': ('dundyne',),
'dundynen': ('dundyne',),
'dundynene': ('dundyne',),
'dundyner': ('dundyne',),
'dunfjær': ('dunfjær',),
'dunfjæra': ('dunfjær',),
'dunfjæren': ('dunfjær',),
'dunfjærene': ('dunfjær',),
'dunfjærer': ('dunfjær',),
'dunfjør': ('dunfjør',),
'dunfjøra': ('dunfjør',),
'dunfjøren': ('dunfjør',),
'dunfjørene': ('dunfjør',),
'dunfjører': ('dunfjør',),
'dunge': ('dunge',),
'dungen': ('dunge',),
'dungene': ('dunge',),
'dunger': ('dunge',),
'dunhår': ('dunhår',),
'dunhåra': ('dunhår',),
'dunhårene': ('dunhår',),
'dunhåret': ('dunhår',),
'dunjakka': ('dunjakke',),
'dunjakke': ('dunjakke',),
'dunjakken': ('dunjakke',),
'dunjakkene': ('dunjakke',),
'dunjakker': ('dunjakke',),
'dunk': ('dunk',),
'dunken': ('dunk',),
'dunkene': ('dunk',),
'dunker': ('dunk',),
'dunk': ('dunk',),
'dunka': ('dunk',),
'dunken': ('dunk',),
'dunkene': ('dunk',),
'dunket': ('dunk',),
'dunker': ('dunker',),
'dunkere': ('dunker',),
'dunkeren': ('dunker',),
'dunkerer': ('dunker',),
'dunkerne': ('dunker',),
'dunkjevla': ('dunkjevle',),
'dunkjevle': ('dunkjevle',),
'dunkjevlen': ('dunkjevle',),
'dunkjevlene': ('dunkjevle',),
'dunkjevler': ('dunkjevle',),
'dunkjevlet': ('dunkjevle',),
'dunlerret': ('dunlerret',),
'dunlerreta': ('dunlerret',),
'dunlerretene': ('dunlerret',),
'dunlerreter': ('dunlerret',),
'dunlerretet': ('dunlerret',),
'dunnasje': ('dunnasje',),
'dunnasjen': ('dunnasje',),
'dunnasjene': ('dunnasje',),
'dunnasjer': ('dunnasje',),
'dunst': ('dunst',),
'dunsten': ('dunst',),
'dunstene': ('dunst',),
'dunster': ('dunst',),
'dunteppa': ('dunteppe',),
'dunteppe': ('dunteppe',),
'dunteppene': ('dunteppe',),
'duntepper': ('dunteppe',),
'dunteppet': ('dunteppe',),
'dununge': ('dununge',),
'dunungen': ('dununge',),
'dunungene': ('dununge',),
'dununger': ('dununge',),
'dunvær': ('dunvær',),
'dunværa': ('dunvær',),
'dunværene': ('dunvær',),
'dunværet': ('dunvær',),
'duo': ('duo',),
'duoen': ('duo',),
'duoene': ('duo',),
'duoer': ('duo',),
'duodes': ('duodes',),
'duodesen': ('duodes',),
'duodesene': ('duodes',),
'duodeser': ('duodes',),
'duplekser': ('duplekser',),
'dupleksere': ('duplekser',),
'duplekseren': ('duplekser',),
'duplekserer': ('duplekser',),
'duplekserne': ('duplekser',),
'duplekstelegrafering': ('duplekstelegrafering',),
'duplekstelegraferinga': ('duplekstelegrafering',),
'duplekstelegraferingen': ('duplekstelegrafering',),
'duplekstelegraferingene': ('duplekstelegrafering',),
'duplekstelegraferinger': ('duplekstelegrafering',),
'duplekstelegrafi': ('duplekstelegrafi',),
'duplekstelegrafien': ('duplekstelegrafi',),
'duplekstelegrafiene': ('duplekstelegrafi',),
'duplekstelegrafier': ('duplekstelegrafi',),
'duplikat': ('duplikat',),
'duplikata': ('duplikat',),
'duplikatene': ('duplikat',),
'duplikater': ('duplikat',),
'duplikatet': ('duplikat',),
'duplikator': ('duplikator',),
'duplikatoren': ('duplikator',),
'duplikatorene': ('duplikator',),
'duplikatorer': ('duplikator',),
'duplikatveksel': ('duplikatveksel',),
'duplikatvekselen': ('duplikatveksel',),
'duplikatvekslene': ('duplikatveksel',),
'duplikatveksler': ('duplikatveksel',),
'duplikk': ('duplikk',),
'duplikken': ('duplikk',),
'duplikkene': ('duplikk',),
'duplikker': ('duplikk',),
'dupp': ('dupp',),
'duppen': ('dupp',),
'duppene': ('dupp',),
'dupper': ('dupp',),
'dupp': ('dupp',),
'duppa': ('dupp',),
'duppen': ('dupp',),
'duppene': ('dupp',),
'dupper': ('dupp',),
'duppet': ('dupp',),
'duppa': ('duppe',),
'duppe': ('duppe',),
'duppen': ('duppe',),
'duppene': ('duppe',),
'dupper': ('duppe',),
'durakkord': ('durakkord',),
'durakkorden': ('durakkord',),
'durakkordene': ('durakkord',),
'durakkorder': ('durakkord',),
'duralumin': ('duralumin',),
'duralumina': ('duralumin',),
'duraluminene': ('duralumin',),
'duraluminet': ('duralumin',),
'durativ': ('durativ',),
'durativen': ('durativ',),
'durativene': ('durativ',),
'durativer': ('durativ',),
'durativ': ('durativ',),
'durativa': ('durativ',),
'durativene': ('durativ',),
'durativer': ('durativ',),
'durativet': ('durativ',),
'durometer': ('durometer',),
'durometeret': ('durometer',),
'durometra': ('durometer',),
'durometre': ('durometer',),
'durometrene': ('durometer',),
'durometret': ('durometer',),
'durra': ('durra',),
'durraen': ('durra',),
'durraene': ('durra',),
'durraer': ('durra',),
'durragrøpp': ('durragrøpp',),
'durragrøppa': ('durragrøpp',),
'durragrøppene': ('durragrøpp',),
'durragrøppet': ('durragrøpp',),
'durskala': ('durskala',),
'durskalaen': ('durskala',),
'durskalaene': ('durskala',),
'durskalaer': ('durskala',),
'durtoneart': ('durtoneart',),
'durtonearta': ('durtoneart',),
'durtonearten': ('durtoneart',),
'durtoneartene': ('durtoneart',),
'durtonearter': ('durtoneart',),
'dus': ('dus',),
'dusin': ('dusin',),
'dusina': ('dusin',),
'dusinene': ('dusin',),
'dusinet': ('dusin',),
'dusinmenneska': ('dusinmenneske',),
'dusinmenneske': ('dusinmenneske',),
'dusinmenneskene': ('dusinmenneske',),
'dusinmennesker': ('dusinmenneske',),
'dusinmennesket': ('dusinmenneske',),
'dusinvara': ('dusinvare',),
'dusinvare': ('dusinvare',),
'dusinvaren': ('dusinvare',),
'dusinvarene': ('dusinvare',),
'dusinvarer': ('dusinvare',),
'dusj': ('dusj',),
'dusjen': ('dusj',),
'dusjene': ('dusj',),
'dusjer': ('dusj',),
'dusjforheng': ('dusjforheng',),
'dusjforhenga': ('dusjforheng',),
'dusjforhengene': ('dusjforheng',),
'dusjforhenget': ('dusjforheng',),
'dusjkabinett': ('dusjkabinett',),
'dusjkabinetta': ('dusjkabinett',),
'dusjkabinettene': ('dusjkabinett',),
'dusjkabinetter': ('dusjkabinett',),
'dusjkabinettet': ('dusjkabinett',),
'dusk': ('dusk',),
'dusken': ('dusk',),
'duskene': ('dusk',),
'dusker': ('dusk',),
'duskehua': ('duskehue',),
'duskehue': ('duskehue',),
'duskehuen': ('duskehue',),
'duskehuene': ('duskehue',),
'duskehuer': ('duskehue',),
'duskehuva': ('duskehuve',),
'duskehuve': ('duskehuve',),
'duskehuven': ('duskehuve',),
'duskehuvene': ('duskehuve',),
'duskehuver': ('duskehuve',),
'duskelua': ('duskelue',),
'duskelue': ('duskelue',),
'duskeluen': ('duskelue',),
'duskeluene': ('duskelue',),
'duskeluer': ('duskelue',),
'duskeluva': ('duskeluve',),
'duskeluve': ('duskeluve',),
'duskeluven': ('duskeluve',),
'duskeluvene': ('duskeluve',),
'duskeluver': ('duskeluve',),
'duskregn': ('duskregn',),
'duskregna': ('duskregn',),
'duskregnene': ('duskregn',),
'duskregnet': ('duskregn',),
'dust': ('dust',),
'dusten': ('dust',),
'dustene': ('dust',),
'duster': ('dust',),
'dust': ('dust',),
'dusta': ('dust',),
'dustene': ('dust',),
'dustet': ('dust',),
'dust': ('dust',),
'dusta': ('dust',),
'dusten': ('dust',),
'dustene': ('dust',),
'duster': ('dust',),
'dustemikkel': ('dustemikkel',),
'dustemikkelen': ('dustemikkel',),
'dustemiklene': ('dustemikkel',),
'dustemikler': ('dustemikkel',),
'dusør': ('dusør',),
'dusøren': ('dusør',),
'dusørene': ('dusør',),
'dusører': ('dusør',),
'dvale': ('dvale',),
'dvalen': ('dvale',),
'dvalene': ('dvale',),
'dvaler': ('dvale',),
'dvaledrikk': ('dvaledrikk',),
'dvaledrikken': ('dvaledrikk',),
'dvaledrikkene': ('dvaledrikk',),
'dvaledrikker': ('dvaledrikk',),
'dvaletilstand': ('dvaletilstand',),
'dvaletilstanden': ('dvaletilstand',),
'dvaletilstandene': ('dvaletilstand',),
'dvaletilstander': ('dvaletilstand',),
'dveil': ('dveil',),
'dveilen': ('dveil',),
'dveilene': ('dveil',),
'dveiler': ('dveil',),
'dverg': ('dverg',),
'dvergen': ('dverg',),
'dvergene': ('dverg',),
'dverger': ('dverg',),
'dvergbjerk': ('dvergbjerk',),
'dvergbjerka': ('dvergbjerk',),
'dvergbjerken': ('dvergbjerk',),
'dvergbjerkene': ('dvergbjerk',),
'dvergbjerker': ('dvergbjerk',),
'dvergbjørk': ('dvergbjørk',),
'dvergbjørka': ('dvergbjørk',),
'dvergbjørken': ('dvergbjørk',),
'dvergbjørkene': ('dvergbjørk',),
'dvergbjørker': ('dvergbjørk',),
'dvergfalk': ('dvergfalk',),
'dvergfalken': ('dvergfalk',),
'dvergfalkene': ('dvergfalk',),
'dvergfalker': ('dvergfalk',),
'dvergfolk': ('dvergfolk',),
'dvergfolka': ('dvergfolk',),
'dvergfolkene': ('dvergfolk',),
'dvergfolket': ('dvergfolk',),
'dverghatt': ('dverghatt',),
'dverghatten': ('dverghatt',),
'dverghattene': ('dverghatt',),
'dverghatter': ('dverghatt',),
'dverghøns': ('dverghøns',),
'dverghønsa': ('dverghøns',),
'dverghønsene': ('dverghøns',),
'dverghønset': ('dverghøns',),
'dvergjamne': ('dvergjamne',),
'dvergjamnen': ('dvergjamne',),
'dvergjamnene': ('dvergjamne',),
'dvergjamner': ('dvergjamne',),
'dverglaks': ('dverglaks',),
'dverglaksen': ('dverglaks',),
'dverglaksene': ('dverglaks',),
'dverglakser': ('dverglaks',),
'dvergmispel': ('dvergmispel',),
'dvergmispelen': ('dvergmispel',),
'dvergmisplene': ('dvergmispel',),
'dvergmispler': ('dvergmispel',),
'dvergmus': ('dvergmus',),
'dvergmusa': ('dvergmus',),
'dvergmusen': ('dvergmus',),
'dvergmusene': ('dvergmus',),
'dvergmål': ('dvergmål',),
'dvergmåla': ('dvergmål',),
'dvergmålene': ('dvergmål',),
'dvergmålet': ('dvergmål',),
'dvergpinsjer': ('dvergpinsjer',),
'dvergpinsjere': ('dvergpinsjer',),
'dvergpinsjeren': ('dvergpinsjer',),
'dvergpinsjerer': ('dvergpinsjer',),
'dvergpinsjerne': ('dvergpinsjer',),
'dvergskott': ('dvergskott',),
'dvergskotta': ('dvergskott',),
'dvergskottene': ('dvergskott',),
'dvergskottet': ('dvergskott',),
'dvergsmia': ('dvergsmie',),
'dvergsmie': ('dvergsmie',),
'dvergsmiene': ('dvergsmie',),
'dvergsmier': ('dvergsmie',),
'dvergsmiet': ('dvergsmie',),
'dvergstjerna': ('dvergstjerne',),
'dvergstjerne': ('dvergstjerne',),
'dvergstjernen': ('dvergstjerne',),
'dvergstjernene': ('dvergstjerne',),
'dvergstjerner': ('dvergstjerne',),
'dvergvekst': ('dvergvekst',),
'dvergveksten': ('dvergvekst',),
'dvergvekstene': ('dvergvekst',),
'dvergvekster': ('dvergvekst',),
'dx-ing': ('dx-ing',),
'dx-inga': ('dx-ing',),
'dx-ingen': ('dx-ing',),
'dx-ingene': ('dx-ing',),
'dx-inger': ('dx-ing',),
'dyade': ('dyade',),
'dyaden': ('dyade',),
'dyadene': ('dyade',),
'dyader': ('dyade',),
'dybde': ('dybde',),
'dybden': ('dybde',),
'dybdene': ('dybde',),
'dybder': ('dybde',),
'dybdelæra': ('dybdelære',),
'dybdelære': ('dybdelære',),
'dybdelæren': ('dybdelære',),
'dybdelærene': ('dybdelære',),
'dybdelærer': ('dybdelære',),
'dybdelæret': ('dybdelære',),
'dybdemåler': ('dybdemåler',),
'dybdemålere': ('dybdemåler',),
'dybdemåleren': ('dybdemåler',),
'dybdemålerer': ('dybdemåler',),
'dybdemålerne': ('dybdemåler',),
'dybdepsykologi': ('dybdepsykologi',),
'dybdepsykologien': ('dybdepsykologi',),
'dybdepsykologiene': ('dybdepsykologi',),
'dybdepsykologier': ('dybdepsykologi',),
'dybdeskarphet': ('dybdeskarphet',),
'dybdeskarpheta': ('dybdeskarphet',),
'dybdeskarpheten': ('dybdeskarphet',),
'dybdeskarphetene': ('dybdeskarphet',),
'dybdeskarpheter': ('dybdeskarphet',),
'dybdesyn': ('dybdesyn',),
'dybdesyna': ('dybdesyn',),
'dybdesynene': ('dybdesyn',),
'dybdesyner': ('dybdesyn',),
'dybdesynet': ('dybdesyn',),
'dybdevirkning': ('dybdevirkning',),
'dybdevirkninga': ('dybdevirkning',),
'dybdevirkningen': ('dybdevirkning',),
'dybdevirkningene': ('dybdevirkning',),
'dybdevirkninger': ('dybdevirkning',),
'dyd': ('dyd',),
'dyden': ('dyd',),
'dydene': ('dyd',),
'dyder': ('dyd',),
'dydsmønster': ('dydsmønster',),
'dydsmønsteret': ('dydsmønster',),
'dydsmønstra': ('dydsmønster',),
'dydsmønstre': ('dydsmønster',),
'dydsmønstrene': ('dydsmønster',),
'dydsmønstret': ('dydsmønster',),
'dyffel': ('dyffel',),
'dyffela': ('dyffel',),
'dyffelen': ('dyffel',),
'dyffelene': ('dyffel',),
'dyffeler': ('dyffel',),
'dyffelet': ('dyffel',),
'dyffelcoat': ('dyffelcoat',),
'dyffelcoaten': ('dyffelcoat',),
'dyffelcoatene': ('dyffelcoat',),
'dyffelcoater': ('dyffelcoat',),
'dygd': ('dygd',),
'dygda': ('dygd',),
'dygden': ('dygd',),
'dygdene': ('dygd',),
'dygder': ('dygd',),
'dykdalb': ('dykdalb',),
'dykdalben': ('dykdalb',),
'dykdalbene': ('dykdalb',),
'dykdalber': ('dykdalb',),
'dykk': ('dykk',),
'dykka': ('dykk',),
'dykkene': ('dykk',),
'dykket': ('dykk',),
'dykkand': ('dykkand',),
'dykkanda': ('dykkand',),
'dykkanden': ('dykkand',),
'dykkendene': ('dykkand',),
'dykkender': ('dykkand',),
'dykker': ('dykker',),
'dykkere': ('dykker',),
'dykkeren': ('dykker',),
'dykkerer': ('dykker',),
'dykkerne': ('dykker',),
'dykker': ('dykker',),
'dykkere': ('dykker',),
'dykkeren': ('dykker',),
'dykkerer': ('dykker',),
'dykkerne': ('dykker',),
'dykker': ('dykker',),
'dykkere': ('dykker',),
'dykkeren': ('dykker',),
'dykkerer': ('dykker',),
'dykkerne': ('dykker',),
'dykkerdrakt': ('dykkerdrakt',),
'dykkerdrakta': ('dykkerdrakt',),
'dykkerdrakten': ('dykkerdrakt',),
'dykkerdraktene': ('dykkerdrakt',),
'dykkerdrakter': ('dykkerdrakt',),
'dykkerklokka': ('dykkerklokke',),
'dykkerklokke': ('dykkerklokke',),
'dykkerklokken': ('dykkerklokke',),
'dykkerklokkene': ('dykkerklokke',),
'dykkerklokker': ('dykkerklokke',),
'dykkermaska': ('dykkermaske',),
'dykkermaske': ('dykkermaske',),
'dykkermasken': ('dykkermaske',),
'dykkermaskene': ('dykkermaske',),
'dykkermasker': ('dykkermaske',),
'dykkersjuka': ('dykkersjuke',),
'dykkersjuke': ('dykkersjuke',),
'dykkersjuken': ('dykkersjuke',),
'dykkersjukene': ('dykkersjuke',),
'dykkersjuker': ('dykkersjuke',),
'dykkersyka': ('dykkersyke',),
'dykkersyke': ('dykkersyke',),
'dykkersyken': ('dykkersyke',),
'dykkersykene': ('dykkersyke',),
'dykkersyker': ('dykkersyke',),
'dykkert': ('dykkert',),
'dykkerten': ('dykkert',),
'dykkertene': ('dykkert',),
'dykkerter': ('dykkert',),
'dykkert': ('dykkert',),
'dykkerten': ('dykkert',),
'dykkertene': ('dykkert',),
'dykkerter': ('dykkert',),
'dykking': ('dykking',),
'dykkinga': ('dykking',),
'dykkingen': ('dykking',),
'dykkingene': ('dykking',),
'dykkinger': ('dykking',),
'dykkstil': ('dykkstil',),
'dykkstilen': ('dykkstil',),
'dykkstilene': ('dykkstil',),
'dykkstiler': ('dykkstil',),
'dyktighet': ('dyktighet',),
'dyktigheta': ('dyktighet',),
'dyktigheten': ('dyktighet',),
'dyktighetene': ('dyktighet',),
'dyktigheter': ('dyktighet',),
'dylla': ('dylle',),
'dylle': ('dylle',),
'dyllen': ('dylle',),
'dyllene': ('dylle',),
'dyller': ('dylle',),
'dyn': ('dyn',),
'dynen': ('dyn',),
'dynene': ('dyn',),
'dynamikk': ('dynamikk',),
'dynamikken': ('dynamikk',),
'dynamikkene': ('dynamikk',),
'dynamikker': ('dynamikk',),
'dynamisme': ('dynamisme',),
'dynamismen': ('dynamisme',),
'dynamismene': ('dynamisme',),
'dynamismer': ('dynamisme',),
'dynamitt': ('dynamitt',),
'dynamitten': ('dynamitt',),
'dynamittene': ('dynamitt',),
'dynamitter': ('dynamitt',),
'dynamittbomba': ('dynamittbombe',),
'dynamittbombe': ('dynamittbombe',),
'dynamittbomben': ('dynamittbombe',),
'dynamittbombene': ('dynamittbombe',),
'dynamittbomber': ('dynamittbombe',),
'dynamittgubbe': ('dynamittgubbe',),
'dynamittgubben': ('dynamittgubbe',),
'dynamittgubbene': ('dynamittgubbe',),
'dynamittgubber': ('dynamittgubbe',),
'dynamittpatron': ('dynamittpatron',),
'dynamittpatronen': ('dynamittpatron',),
'dynamittpatronene': ('dynamittpatron',),
'dynamittpatroner': ('dynamittpatron',),
'dynamo': ('dynamo',),
'dynamoen': ('dynamo',),
'dynamoene': ('dynamo',),
'dynamoer': ('dynamo',),
'dynamometer': ('dynamometer',),
'dynamometeret': ('dynamometer',),
'dynamometra': ('dynamometer',),
'dynamometre': ('dynamometer',),
'dynamometrene': ('dynamometer',),
'dynamometret': ('dynamometer',),
'dynast': ('dynast',),
'dynasten': ('dynast',),
'dynastene': ('dynast',),
'dynaster': ('dynast',),
'dynasti': ('dynasti',),
'dynastia': ('dynasti',),
'dynastiene': ('dynasti',),
'dynastier': ('dynasti',),
'dynastiet': ('dynasti',),
'dyne': ('dyne',),
'dynen': ('dyne',),
'dynene': ('dyne',),
'dyner': ('dyne',),
'dyna': ('dyne',),
'dyne': ('dyne',),
'dynen': ('dyne',),
'dynene': ('dyne',),
'dyner': ('dyne',),
'dynefyll': ('dynefyll',),
'dynefylla': ('dynefyll',),
'dynefyllen': ('dynefyll',),
'dynefyllene': ('dynefyll',),
'dynefyller': ('dynefyll',),
'dynefyllet': ('dynefyll',),
'dynejakka': ('dynejakke',),
'dynejakke': ('dynejakke',),
'dynejakken': ('dynejakke',),
'dynejakkene': ('dynejakke',),
'dynejakker': ('dynejakke',),
'dyneløfting': ('dyneløfting',),
'dyneløftinga': ('dyneløfting',),
'dyneløftingen': ('dyneløfting',),
'dyneløftingene': ('dyneløfting',),
'dyneløftinger': ('dyneløfting',),
'dynestoff': ('dynestoff',),
'dynestoffa': ('dynestoff',),
'dynestoffene': ('dynestoff',),
'dynestoffer': ('dynestoff',),
'dynestoffet': ('dynestoff',),
'dynetrekk': ('dynetrekk',),
'dynetrekka': ('dynetrekk',),
'dynetrekkene': ('dynetrekk',),
'dynetrekket': ('dynetrekk',),
'dynevar': ('dynevar',),
'dynevara': ('dynevar',),
'dynevarene': ('dynevar',),
'dynevaret': ('dynevar',),
'dynga': ('dynge',),
'dynge': ('dynge',),
'dyngen': ('dynge',),
'dyngene': ('dynge',),
'dynger': ('dynge',),
'dynkeapparat': ('dynkeapparat',),
'dynkeapparata': ('dynkeapparat',),
'dynkeapparatene': ('dynkeapparat',),
'dynkeapparater': ('dynkeapparat',),
'dynkeapparatet': ('dynkeapparat',),
'dynkeflaska': ('dynkeflaske',),
'dynkeflaske': ('dynkeflaske',),
'dynkeflasken': ('dynkeflaske',),
'dynkeflaskene': ('dynkeflaske',),
'dynkeflasker': ('dynkeflaske',),
'dynn': ('dynn',),
'dynna': ('dynn',),
'dynnene': ('dynn',),
'dynnet': ('dynn',),
'dynnfisk': ('dynnfisk',),
'dynnfisken': ('dynnfisk',),
'dynnfiskene': ('dynnfisk',),
'dynnfisker': ('dynnfisk',),
'dyp': ('dyp',),
'dypa': ('dyp',),
'dypene': ('dyp',),
'dypet': ('dyp',),
'dypbergart': ('dypbergart',),
'dypbergarta': ('dypbergart',),
'dypbergarten': ('dypbergart',),
'dypbergartene': ('dypbergart',),
'dypbergarter': ('dypbergart',),
'dypboring': ('dypboring',),
'dypboringa': ('dypboring',),
'dypboringen': ('dypboring',),
'dypboringene': ('dypboring',),
'dypboringer': ('dypboring',),
'dypdykking': ('dypdykking',),
'dypdykkinga': ('dypdykking',),
'dypdykkingen': ('dypdykking',),
'dypdykkingene': ('dypdykking',),
'dypdykkinger': ('dypdykking',),
'dypfryser': ('dypfryser',),
'dypfrysere': ('dypfryser',),
'dypfryseren': ('dypfryser',),
'dypfryserer': ('dypfryser',),
'dypfryserne': ('dypfryser',),
'dypgang': ('dypgang',),
'dypgangen': ('dypgang',),
'dypgangene': ('dypgang',),
'dypganger': ('dypgang',),
'dypgående': ('dypgående',),
'dypsnø': ('dypsnø',),
'dypsnøen': ('dypsnø',),
'dypsnøene': ('dypsnø',),
'dypsnøer': ('dypsnø',),
'dypstruktur': ('dypstruktur',),
'dypstrukturen': ('dypstruktur',),
'dypstrukturene': ('dypstruktur',),
'dypstrukturer': ('dypstruktur',),
'dyptallerken': ('dyptallerken',),
'dyptallerkenen': ('dyptallerken',),
'dyptallerkenene': ('dyptallerken',),
'dyptallerkener': ('dyptallerken',),
'dyptrykk': ('dyptrykk',),
'dyptrykka': ('dyptrykk',),
'dyptrykkene': ('dyptrykk',),
'dyptrykket': ('dyptrykk',),
'dypvannsfisk': ('dypvannsfisk',),
'dypvannsfisken': ('dypvannsfisk',),
'dypvannsfiskene': ('dypvannsfisk',),
'dypvannsfisker': ('dypvannsfisk',),
'dypvassfisk': ('dypvassfisk',),
'dypvassfisken': ('dypvassfisk',),
'dypvassfiskene': ('dypvassfisk',),
'dypvassfisker': ('dypvassfisk',),
'dyr': ('dyr',),
'dyra': ('dyr',),
'dyrene': ('dyr',),
'dyret': ('dyr',),
'dyreart': ('dyreart',),
'dyrearta': ('dyreart',),
'dyrearten': ('dyreart',),
'dyreartene': ('dyreart',),
'dyrearter': ('dyreart',),
'dyrebeskyttelse': ('dyrebeskyttelse',),
'dyrebeskyttelsen': ('dyrebeskyttelse',),
'dyrebeskyttelsene': ('dyrebeskyttelse',),
'dyrebeskyttelser': ('dyrebeskyttelse',),
'dyrebeskyttelsesforening': ('dyrebeskyttelsesforening',),
'dyrebeskyttelsesforeninga': ('dyrebeskyttelsesforening',),
'dyrebeskyttelsesforeningen': ('dyrebeskyttelsesforening',),
'dyrebeskyttelsesforeningene': ('dyrebeskyttelsesforening',),
'dyrebeskyttelsesforeninger': ('dyrebeskyttelsesforening',),
'dyreeventyr': ('dyreeventyr',),
'dyreeventyra': ('dyreeventyr',),
'dyreeventyrene': ('dyreeventyr',),
'dyreeventyret': ('dyreeventyr',),
'dyrefabel': ('dyrefabel',),
'dyrefabelen': ('dyrefabel',),
'dyrefablene': ('dyrefabel',),
'dyrefabler': ('dyrefabel',),
'dyreforsøk': ('dyreforsøk',),
'dyreforsøka': ('dyreforsøk',),
'dyreforsøkene': ('dyreforsøk',),
'dyreforsøket': ('dyreforsøk',),
'dyregrav': ('dyregrav',),
'dyregrava': ('dyregrav',),
'dyregraven': ('dyregrav',),
'dyregravene': ('dyregrav',),
'dyregraver': ('dyregrav',),
'dyrehage': ('dyrehage',),
'dyrehagen': ('dyrehage',),
'dyrehagene': ('dyrehage',),
'dyrehager': ('dyrehage',),
'dyreham': ('dyreham',),
'dyrehammen': ('dyreham',),
'dyrehammene': ('dyreham',),
'dyrehammer': ('dyreham',),
'dyrehår': ('dyrehår',),
'dyrehåra': ('dyrehår',),
'dyrehårene': ('dyrehår',),
'dyrehåret': ('dyrehår',),
'dyrehårsallergi': ('dyrehårsallergi',),
'dyrehårsallergien': ('dyrehårsallergi',),
'dyrehårsallergiene': ('dyrehårsallergi',),
'dyrehårsallergier': ('dyrehårsallergi',),
'dyrekjøtt': ('dyrekjøtt',),
'dyrekjøtta': ('dyrekjøtt',),
'dyrekjøttene': ('dyrekjøtt',),
'dyrekjøttet': ('dyrekjøtt',),
'dyrekrets': ('dyrekrets',),
'dyrekretsen': ('dyrekrets',),
'dyrekretsene': ('dyrekrets',),
'dyrekretser': ('dyrekrets',),
'dyreliv': ('dyreliv',),
'dyreliva': ('dyreliv',),
'dyrelivene': ('dyreliv',),
'dyrelivet': ('dyreliv',),
'dyrelåt': ('dyrelåt',),
'dyrelåten': ('dyrelåt',),
'dyrelåtene': ('dyrelåt',),
'dyrelåter': ('dyrelåt',),
'dyremishandling': ('dyremishandling',),
'dyremishandlinga': ('dyremishandling',),
'dyremishandlingen': ('dyremishandling',),
'dyremishandlingene': ('dyremishandling',),
'dyremishandlinger': ('dyremishandling',),
'dyreornamentikk': ('dyreornamentikk',),
'dyreornamentikken': ('dyreornamentikk',),
'dyreornamentikkene': ('dyreornamentikk',),
'dyreornamentikker': ('dyreornamentikk',),
'dyrepark': ('dyrepark',),
'dyreparken': ('dyrepark',),
'dyreparkene': ('dyrepark',),
'dyreparker': ('dyrepark',),
'dyrepasser': ('dyrepasser',),
'dyrepassere': ('dyrepasser',),
'dyrepasseren': ('dyrepasser',),
'dyrepasserer': ('dyrepasser',),
'dyrepasserne': ('dyrepasser',),
'dyreplankton': ('dyreplankton',),
'dyreplanktona': ('dyreplankton',),
'dyreplanktonene': ('dyreplankton',),
'dyreplanktoner': ('dyreplankton',),
'dyreplanktonet': ('dyreplankton',),
'dyrerika': ('dyrerike',),
'dyrerike': ('dyrerike',),
'dyrerikene': ('dyrerike',),
'dyreriker': ('dyrerike',),
'dyreriket': ('dyrerike',),
'dyreskjelv': ('dyreskjelv',),
'dyreskjelven': ('dyreskjelv',),
'dyreskjelvene': ('dyreskjelv',),
'dyreskjelver': ('dyreskjelv',),
'dyresteik': ('dyresteik',),
'dyresteika': ('dyresteik',),
'dyresteiken': ('dyresteik',),
'dyresteikene': ('dyresteik',),
'dyresteiker': ('dyresteik',),
'dyrestek': ('dyrestek',),
'dyresteka': ('dyrestek',),
'dyresteken': ('dyrestek',),
'dyrestekene': ('dyrestek',),
'dyresteker': ('dyrestek',),
'dyretemmer': ('dyretemmer',),
'dyretemmere': ('dyretemmer',),
'dyretemmeren': ('dyretemmer',),
'dyretemmerer': ('dyretemmer',),
'dyretemmerne': ('dyretemmer',),
'dyrevern': ('dyrevern',),
'dyreverna': ('dyrevern',),
'dyrevernene': ('dyrevern',),
'dyrevernet': ('dyrevern',),
'dyrkelse': ('dyrkelse',),
'dyrkelsen': ('dyrkelse',),
'dyrkelsene': ('dyrkelse',),
'dyrkelser': ('dyrkelse',),
'dyrker': ('dyrker',),
'dyrkere': ('dyrker',),
'dyrkeren': ('dyrker',),
'dyrkerer': ('dyrker',),
'dyrkerne': ('dyrker',),
'dyrking': ('dyrking',),
'dyrkinga': ('dyrking',),
'dyrkingen': ('dyrking',),
'dyrkingene': ('dyrking',),
'dyrkinger': ('dyrking',),
'dyrking': ('dyrking',),
'dyrkinga': ('dyrking',),
'dyrkingen': ('dyrking',),
'dyrkingene': ('dyrking',),
'dyrkinger': ('dyrking',),
'dyrkingsfelt': ('dyrkingsfelt',),
'dyrkingsfelta': ('dyrkingsfelt',),
'dyrkingsfeltene': ('dyrkingsfelt',),
'dyrkingsfelter': ('dyrkingsfelt',),
'dyrkingsfeltet': ('dyrkingsfelt',),
'dyrkingsforsøk': ('dyrkingsforsøk',),
'dyrkingsforsøka': ('dyrkingsforsøk',),
'dyrkingsforsøkene': ('dyrkingsforsøk',),
'dyrkingsforsøket': ('dyrkingsforsøk',),
'dyrkingsjord': ('dyrkingsjord',),
'dyrkingsjorda': ('dyrkingsjord',),
'dyrkingsjorden': ('dyrkingsjord',),
'dyrkingsjordene': ('dyrkingsjord',),
'dyrkingsjorder': ('dyrkingsjord',),
'dyrkingsland': ('dyrkingsland',),
'dyrkingslanda': ('dyrkingsland',),
'dyrkingslandene': ('dyrkingsland',),
'dyrkingslandet': ('dyrkingsland',),
'dyrkingsmedia': ('dyrkingsmedium',),
'dyrkingsmediene': ('dyrkingsmedium',),
'dyrkingsmedier': ('dyrkingsmedium',),
'dyrkingsmediet': ('dyrkingsmedium',),
'dyrkingsmedium': ('dyrkingsmedium',),
'dyrkingsmåte': ('dyrkingsmåte',),
'dyrkingsmåten': ('dyrkingsmåte',),
'dyrkingsmåtene': ('dyrkingsmåte',),
'dyrkingsmåter': ('dyrkingsmåte',),
'dyrkingstorv': ('dyrkingstorv',),
'dyrkingstorva': ('dyrkingstorv',),
'dyrkingstorven': ('dyrkingstorv',),
'dyrkingstorvene': ('dyrkingstorv',),
'dyrkingstorver': ('dyrkingstorv',),
'dyrkingstorvet': ('dyrkingstorv',),
'dyrkning': ('dyrkning',),
'dyrkninga': ('dyrkning',),
'dyrkningen': ('dyrkning',),
'dyrkningene': ('dyrkning',),
'dyrkninger': ('dyrkning',),
'dyrkningsfelt': ('dyrkningsfelt',),
'dyrkningsfelta': ('dyrkningsfelt',),
'dyrkningsfeltene': ('dyrkningsfelt',),
'dyrkningsfelter': ('dyrkningsfelt',),
'dyrkningsfeltet': ('dyrkningsfelt',),
'dyrkningsforsøk': ('dyrkningsforsøk',),
'dyrkningsforsøka': ('dyrkningsforsøk',),
'dyrkningsforsøkene': ('dyrkningsforsøk',),
'dyrkningsforsøket': ('dyrkningsforsøk',),
'dyrkningsjord': ('dyrkningsjord',),
'dyrkningsjorda': ('dyrkningsjord',),
'dyrkningsjorden': ('dyrkningsjord',),
'dyrkningsjordene': ('dyrkningsjord',),
'dyrkningsjorder': ('dyrkningsjord',),
'dyrkningsland': ('dyrkningsland',),
'dyrkningslanda': ('dyrkningsland',),
'dyrkningslandene': ('dyrkningsland',),
'dyrkningslandet': ('dyrkningsland',),
'dyrkningsmedia': ('dyrkningsmedium',),
'dyrkningsmediene': ('dyrkningsmedium',),
'dyrkningsmedier': ('dyrkningsmedium',),
'dyrkningsmediet': ('dyrkningsmedium',),
'dyrkningsmedium': ('dyrkningsmedium',),
'dyrkningsmåte': ('dyrkningsmåte',),
'dyrkningsmåten': ('dyrkningsmåte',),
'dyrkningsmåtene': ('dyrkningsmåte',),
'dyrkningsmåter': ('dyrkningsmåte',),
'dyrkningstorv': ('dyrkningstorv',),
'dyrkningstorva': ('dyrkningstorv',),
'dyrkningstorven': ('dyrkningstorv',),
'dyrkningstorvene': ('dyrkningstorv',),
'dyrkningstorver': ('dyrkningstorv',),
'dyrkningstorvet': ('dyrkningstorv',),
'dyrlege': ('dyrlege',),
'dyrlegen': ('dyrlege',),
'dyrlegene': ('dyrlege',),
'dyrleger': ('dyrlege',),
'dyrplager': ('dyrplager',),
'dyrplagere': ('dyrplager',),
'dyrplageren': ('dyrplager',),
'dyrplagerer': ('dyrplager',),
'dyrplagerne': ('dyrplager',),
'dyrplageri': ('dyrplageri',),
'dyrplageria': ('dyrplageri',),
'dyrplageriene': ('dyrplageri',),
'dyrplagerier': ('dyrplageri',),
'dyrplageriet': ('dyrplageri',),
'dyrtid': ('dyrtid',),
'dyrtida': ('dyrtid',),
'dyrtiden': ('dyrtid',),
'dyrtidene': ('dyrtid',),
'dyrtider': ('dyrtid',),
'dyrtidstillegg': ('dyrtidstillegg',),
'dyrtidstillegga': ('dyrtidstillegg',),
'dyrtidstilleggene': ('dyrtidstillegg',),
'dyrtidstillegget': ('dyrtidstillegg',),
'dyse': ('dyse',),
'dysen': ('dyse',),
'dysene': ('dyse',),
'dyser': ('dyse',),
'dysenteri': ('dysenteri',),
'dysenterien': ('dysenteri',),
'dysenteriene': ('dysenteri',),
'dysenterier': ('dysenteri',),
'dysfasi': ('dysfasi',),
'dysfasien': ('dysfasi',),
'dysfasiene': ('dysfasi',),
'dysfasier': ('dysfasi',),
'dysfunksjon': ('dysfunksjon',),
'dysfunksjonen': ('dysfunksjon',),
'dysfunksjonene': ('dysfunksjon',),
'dysfunksjoner': ('dysfunksjon',),
'dysleksi': ('dysleksi',),
'dysleksien': ('dysleksi',),
'dysleksiene': ('dysleksi',),
'dysleksier': ('dysleksi',),
'dyslektiker': ('dyslektiker',),
'dyslektikere': ('dyslektiker',),
'dyslektikeren': ('dyslektiker',),
'dyslektikerer': ('dyslektiker',),
'dyslektikerne': ('dyslektiker',),
'dysmenoreen': ('dysmenoré',),
'dysmenoreene': ('dysmenoré',),
'dysmenoreer': ('dysmenoré',),
'dysmenoré': ('dysmenoré',),
'dysmenoréen': ('dysmenoré',),
'dysmenoréene': ('dysmenoré',),
'dysmenoréer': ('dysmenoré',),
'dyspepsi': ('dyspepsi',),
'dyspepsien': ('dyspepsi',),
'dyspepsiene': ('dyspepsi',),
'dyspepsier': ('dyspepsi',),
'dysprosium': ('dysprosium',),
'dysprosiuma': ('dysprosium',),
'dysprosiumene': ('dysprosium',),
'dysprosiumet': ('dysprosium',),
'dyssa': ('dysse',),
'dysse': ('dysse',),
'dyssen': ('dysse',),
'dyssene': ('dysse',),
'dysser': ('dysse',),
'dyst': ('dyst',),
'dysten': ('dyst',),
'dystene': ('dyst',),
'dyster': ('dyst',),
'dytt': ('dytt',),
'dytten': ('dytt',),
'dyttene': ('dytt',),
'dytter': ('dytt',),
'dyttestry': ('dyttestry',),
'dyttestrya': ('dyttestry',),
'dyttestryene': ('dyttestry',),
'dyttestryet': ('dyttestry',),
'då': ('då',),
'dåen': ('då',),
'dåene': ('då',),
'dåer': ('då',),
'dåd': ('dåd',),
'dåden': ('dåd',),
'dådene': ('dåd',),
'dåder': ('dåd',),
'dådskraft': ('dådskraft',),
'dådskrafta': ('dådskraft',),
'dådskraften': ('dådskraft',),
'dådskreftene': ('dådskraft',),
'dådskrefter': ('dådskraft',),
'dådyr': ('dådyr',),
'dådyra': ('dådyr',),
'dådyrene': ('dådyr',),
'dådyret': ('dådyr',),
'dåe': ('dåe',),
'dåen': ('dåe',),
'dåene': ('dåe',),
'dåer': ('dåe',),
'dåhjort': ('dåhjort',),
'dåhjorten': ('dåhjort',),
'dåhjortene': ('dåhjort',),
'dåhjorter': ('dåhjort',),
'dåm': ('dåm',),
'dåmen': ('dåm',),
'dåmene': ('dåm',),
'dåmer': ('dåm',),
'dåp': ('dåp',),
'dåpen': ('dåp',),
'dåpene': ('dåp',),
'dåper': ('dåp',),
'dåpsattest': ('dåpsattest',),
'dåpsattesten': ('dåpsattest',),
'dåpsattestene': ('dåpsattest',),
'dåpsattester': ('dåpsattest',),
'dåpsbarn': ('dåpsbarn',),
'dåpsbarna': ('dåpsbarn',),
'dåpsbarnene': ('dåpsbarn',),
'dåpsbarnet': ('dåpsbarn',),
'dåpsbefaling': ('dåpsbefaling',),
'dåpsbefalinga': ('dåpsbefaling',),
'dåpsbefalingen': ('dåpsbefaling',),
'dåpsbefalingene': ('dåpsbefaling',),
'dåpsbefalinger': ('dåpsbefaling',),
'dåpsdag': ('dåpsdag',),
'dåpsdagen': ('dåpsdag',),
'dåpsdagene': ('dåpsdag',),
'dåpsdager': ('dåpsdag',),
'dåpskjole': ('dåpskjole',),
'dåpskjolen': ('dåpskjole',),
'dåpskjolene': ('dåpskjole',),
'dåpskjoler': ('dåpskjole',),
'dåpspakt': ('dåpspakt',),
'dåpspakta': ('dåpspakt',),
'dåpspakten': ('dåpspakt',),
'dåpspaktene': ('dåpspakt',),
'dåpspakter': ('dåpspakt',),
'dåpssakrament': ('dåpssakrament',),
'dåpssakramenta': ('dåpssakrament',),
'dåpssakramentene': ('dåpssakrament',),
'dåpssakramenter': ('dåpssakrament',),
'dåpssakramentet': ('dåpssakrament',),
'dåpssalme': ('dåpssalme',),
'dåpssalmen': ('dåpssalme',),
'dåpssalmene': ('dåpssalme',),
'dåpssalmer': ('dåpssalme',),
'dåpsvitna': ('dåpsvitne',),
'dåpsvitne': ('dåpsvitne',),
'dåpsvitnene': ('dåpsvitne',),
'dåpsvitner': ('dåpsvitne',),
'dåpsvitnet': ('dåpsvitne',),
'dåre': ('dåre',),
'dåren': ('dåre',),
'dårene': ('dåre',),
'dårer': ('dåre',),
'dårehus': ('dårehus',),
'dårehusa': ('dårehus',),
'dårehusene': ('dårehus',),
'dårehuset': ('dårehus',),
'dårekista': ('dårekiste',),
'dårekiste': ('dårekiste',),
'dårekisten': ('dårekiste',),
'dårekistene': ('dårekiste',),
'dårekister': ('dårekiste',),
'dårskap': ('dårskap',),
'dårskapen': ('dårskap',),
'dårskapene': ('dårskap',),
'dårskaper': ('dårskap',),
'dåsa': ('dåse',),
'dåse': ('dåse',),
'dåsen': ('dåse',),
'dåsene': ('dåse',),
'dåser': ('dåse',),
'dåsemikkel': ('dåsemikkel',),
'dåsemikkelen': ('dåsemikkel',),
'dåsemiklene': ('dåsemikkel',),
'dåsemikler': ('dåsemikkel',),
'død': ('død',),
'døden': ('død',),
'dødene': ('død',),
'døder': ('død',),
'dødball': ('dødball',),
'dødballen': ('dødball',),
'dødballene': ('dødball',),
'dødballer': ('dødball',),
'dødballsituasjon': ('dødballsituasjon',),
'dødballsituasjonen': ('dødballsituasjon',),
'dødballsituasjonene': ('dødballsituasjon',),
'dødballsituasjoner': ('dødballsituasjon',),
'dødelighet': ('dødelighet',),
'dødeligheta': ('dødelighet',),
'dødeligheten': ('dødelighet',),
'dødelighetene': ('dødelighet',),
'dødeligheter': ('dødelighet',),
'dødgang': ('dødgang',),
'dødgangen': ('dødgang',),
'dødgangene': ('dødgang',),
'dødganger': ('dødgang',),
'dødlinja': ('dødlinje',),
'dødlinje': ('dødlinje',),
'dødlinjen': ('dødlinje',),
'dødlinjene': ('dødlinje',),
'dødlinjer': ('dødlinje',),
'dødmannsknapp': ('dødmannsknapp',),
'dødmannsknappen': ('dødmannsknapp',),
'dødmannsknappene': ('dødmannsknapp',),
'dødmannsknapper': ('dødmannsknapp',),
'dødning': ('dødning',),
'dødningen': ('dødning',),
'dødningene': ('dødning',),
'dødninger': ('dødning',),
'dødninghoda': ('dødninghode',),
'dødninghode': ('dødninghode',),
'dødninghodene': ('dødninghode',),
'dødninghoder': ('dødninghode',),
'dødninghodet': ('dødninghode',),
'dødperiode': ('dødperiode',),
'dødperioden': ('dødperiode',),
'dødperiodene': ('dødperiode',),
'dødperioder': ('dødperiode',),
'dødpunkt': ('dødpunkt',),
'dødpunkta': ('dødpunkt',),
'dødpunktene': ('dødpunkt',),
'dødpunkter': ('dødpunkt',),
'dødpunktet': ('dødpunkt',),
'dødsalder': ('dødsalder',),
'dødsaldere': ('dødsalder',),
'dødsalderen': ('dødsalder',),
'dødsalderer': ('dødsalder',),
'dødsalderne': ('dødsalder',),
'dødsaldre': ('dødsalder',),
'dødsaldrene': ('dødsalder',),
'dødsaldrer': ('dødsalder',),
'dødsangst': ('dødsangst',),
'dødsangsten': ('dødsangst',),
'dødsangstene': ('dødsangst',),
'dødsangster': ('dødsangst',),
'dødsannonsa': ('dødsannonse',),
'dødsannonse': ('dødsannonse',),
'dødsannonsen': ('dødsannonse',),
'dødsannonsene': ('dødsannonse',),
'dødsannonser': ('dødsannonse',),
'dødsattest': ('dødsattest',),
'dødsattesten': ('dødsattest',),
'dødsattestene': ('dødsattest',),
'dødsattester': ('dødsattest',),
'dødsbo': ('dødsbo',),
'dødsboa': ('dødsbo',),
'dødsboene': ('dødsbo',),
'dødsboet': ('dødsbo',),
'dødsbu': ('dødsbu',),
'dødsbua': ('dødsbu',),
'dødsbuene': ('dødsbu',),
'dødsbuet': ('dødsbu',),
'dødsdag': ('dødsdag',),
'dødsdagen': ('dødsdag',),
'dødsdagene': ('dødsdag',),
'dødsdager': ('dødsdag',),
'dødsdans': ('dødsdans',),
'dødsdansen': ('dødsdans',),
'dødsdansene': ('dødsdans',),
'dødsdanser': ('dødsdans',),
'dødsdom': ('dødsdom',),
'dødsdommen': ('dødsdom',),
'dødsdommene': ('dødsdom',),
'dødsdommer': ('dødsdom',),
'dødsesong': ('dødsesong',),
'dødsesongen': ('dødsesong',),
'dødsesongene': ('dødsesong',),
'dødsesonger': ('dødsesong',),
'dødsfall': ('dødsfall',),
'dødsfalla': ('dødsfall',),
'dødsfallene': ('dødsfall',),
'dødsfallet': ('dødsfall',),
'dødsfare': ('dødsfare',),
'dødsfaren': ('dødsfare',),
'dødsfarene': ('dødsfare',),
'dødsfarer': ('dødsfare',),
'dødsfella': ('dødsfelle',),
'dødsfelle': ('dødsfelle',),
'dødsfellen': ('dødsfelle',),
'dødsfellene': ('dødsfelle',),
'dødsfeller': ('dødsfelle',),
'dødsfiende': ('dødsfiende',),
'dødsfienden': ('dødsfiende',),
'dødsfiendene': ('dødsfiende',),
'dødsfiender': ('dødsfiende',),
'dødsforakt': ('dødsforakt',),
'dødsforakten': ('dødsforakt',),
'dødsforaktene': ('dødsforakt',),
'dødsforakter': ('dødsforakt',),
'dødsformodningsdom': ('dødsformodningsdom',),
'dødsformodningsdommen': ('dødsformodningsdom',),
'dødsformodningsdommene': ('dødsformodningsdom',),
'dødsformodningsdommer': ('dødsformodningsdom',),
'dødsgjeng': ('dødsgjeng',),
'dødsgjengen': ('dødsgjeng',),
'dødsgjengene': ('dødsgjeng',),
'dødsgjenger': ('dødsgjeng',),
'dødshjelp': ('dødshjelp',),
'dødshjelpa': ('dødshjelp',),
'dødshjelpen': ('dødshjelp',),
'dødshjelpene': ('dødshjelp',),
'dødshjelper': ('dødshjelp',),
'dødskamp': ('dødskamp',),
'dødskampen': ('dødskamp',),
'dødskampene': ('dødskamp',),
'dødskamper': ('dødskamp',),
'dødsleia': ('dødsleie',),
'dødsleie': ('dødsleie',),
'dødsleiene': ('dødsleie',),
'dødsleier': ('dødsleie',),
'dødsleiet': ('dødsleie',),
'dødsmaska': ('dødsmaske',),
'dødsmaske': ('dødsmaske',),
'dødsmasken': ('dødsmaske',),
'dødsmaskene': ('dødsmaske',),
'dødsmasker': ('dødsmaske',),
'dødsmåte': ('dødsmåte',),
'dødsmåten': ('dødsmåte',),
'dødsmåtene': ('dødsmåte',),
'dødsmåter': ('dødsmåte',),
'dødsoffer': ('dødsoffer',),
'dødsofferet': ('dødsoffer',),
'dødsofra': ('dødsoffer',),
'dødsofre': ('dødsoffer',),
'dødsofrene': ('dødsoffer',),
'dødsona': ('dødsone',),
'dødsone': ('dødsone',),
'dødsonen': ('dødsone',),
'dødsonene': ('dødsone',),
'dødsoner': ('dødsone',),
'dødsrika': ('dødsrike',),
'dødsrike': ('dødsrike',),
'dødsrikene': ('dødsrike',),
'dødsriker': ('dødsrike',),
'dødsriket': ('dødsrike',),
'dødsrisiko': ('dødsrisiko',),
'dødsrisikoen': ('dødsrisiko',),
'dødsrisikoene': ('dødsrisiko',),
'dødsrisikoer': ('dødsrisiko',),
'dødssegler': ('dødssegler',),
'dødsseglere': ('dødssegler',),
'dødssegleren': ('dødssegler',),
'dødsseglerer': ('dødssegler',),
'dødsseglerne': ('dødssegler',),
'dødsseiler': ('dødsseiler',),
'dødsseilere': ('dødsseiler',),
'dødsseileren': ('dødsseiler',),
'dødsseilerer': ('dødsseiler',),
'dødsseilerne': ('dødsseiler',),
'dødsskvadron': ('dødsskvadron',),
'dødsskvadronen': ('dødsskvadron',),
'dødsskvadronene': ('dødsskvadron',),
'dødsskvadroner': ('dødsskvadron',),
'dødsstraff': ('dødsstraff',),
'dødsstraffen': ('dødsstraff',),
'dødsstraffene': ('dødsstraff',),
'dødsstraffer': ('dødsstraff',),
'dødsstøt': ('dødsstøt',),
'dødsstøta': ('dødsstøt',),
'dødsstøtene': ('dødsstøt',),
'dødsstøtet': ('dødsstøt',),
'dødssynd': ('dødssynd',),
'dødssynda': ('dødssynd',),
'dødssynden': ('dødssynd',),
'dødssyndene': ('dødssynd',),
'dødssynder': ('dødssynd',),
'dødsulykka': ('dødsulykke',),
'dødsulykke': ('dødsulykke',),
'dødsulykken': ('dødsulykke',),
'dødsulykkene': ('dødsulykke',),
'dødsulykker': ('dødsulykke',),
'dødsårsak': ('dødsårsak',),
'dødsårsaka': ('dødsårsak',),
'dødsårsaken': ('dødsårsak',),
'dødsårsakene': ('dødsårsak',),
'dødsårsaker': ('dødsårsak',),
'dødsøyeblikk': ('dødsøyeblikk',),
'dødsøyeblikka': ('dødsøyeblikk',),
'dødsøyeblikkene': ('dødsøyeblikk',),
'dødsøyeblikket': ('dødsøyeblikk',),
'dødtid': ('dødtid',),
'dødtida': ('dødtid',),
'dødtiden': ('dødtid',),
'dødtidene': ('dødtid',),
'dødtider': ('dødtid',),
'dødvann': ('dødvann',),
'dødvanna': ('dødvann',),
'dødvannene': ('dødvann',),
'dødvannet': ('dødvann',),
'dødvanne': ('dødvanne',),
'dødvatn': ('dødvatn',),
'dødvatna': ('dødvatn',),
'dødvatnene': ('dødvatn',),
'dødvatnet': ('dødvatn',),
'dødvekt': ('dødvekt',),
'dødvekta': ('dødvekt',),
'dødvekten': ('dødvekt',),
'dødvektene': ('dødvekt',),
'dødvekter': ('dødvekt',),
'dødvektlast': ('dødvektlast',),
'dødvektlasta': ('dødvektlast',),
'dødvektlasten': ('dødvektlast',),
'dødvektlastene': ('dødvektlast',),
'dødvektlaster': ('dødvektlast',),
'dødvekttonn': ('dødvekttonn',),
'dødvekttonna': ('dødvekttonn',),
'dødvekttonnene': ('dødvekttonn',),
'dødvekttonnet': ('dødvekttonn',),
'døgenikt': ('døgenikt',),
'døgenikten': ('døgenikt',),
'døgeniktene': ('døgenikt',),
'døgenikter': ('døgenikt',),
'døger': ('døger',),
'døgeret': ('døger',),
'døgerne': ('døger',),
'døgn': ('døgn',),
'døgna': ('døgn',),
'døgnene': ('døgn',),
'døgnet': ('døgn',),
'døgnboks': ('døgnboks',),
'døgnboksen': ('døgnboks',),
'døgnboksene': ('døgnboks',),
'døgnbokser': ('døgnboks',),
'døgndrift': ('døgndrift',),
'døgndrifta': ('døgndrift',),
'døgndriften': ('døgndrift',),
'døgndriftene': ('døgndrift',),
'døgndrifter': ('døgndrift',),
'døgndriftsordning': ('døgndriftsordning',),
'døgndriftsordninga': ('døgndriftsordning',),
'døgndriftsordningen': ('døgndriftsordning',),
'døgndriftsordningene': ('døgndriftsordning',),
'døgndriftsordninger': ('døgndriftsordning',),
'døgnflua': ('døgnflue',),
'døgnflue': ('døgnflue',),
'døgnfluen': ('døgnflue',),
'døgnfluene': ('døgnflue',),
'døgnfluer': ('døgnflue',),
'døgnmelodi': ('døgnmelodi',),
'døgnmelodien': ('døgnmelodi',),
'døgnmelodiene': ('døgnmelodi',),
'døgnmelodier': ('døgnmelodi',),
'døgnproduksjon': ('døgnproduksjon',),
'døgnproduksjonen': ('døgnproduksjon',),
'døgnproduksjonene': ('døgnproduksjon',),
'døgnproduksjoner': ('døgnproduksjon',),
'døgnrytme': ('døgnrytme',),
'døgnrytmen': ('døgnrytme',),
'døgnrytmene': ('døgnrytme',),
'døgnrytmer': ('døgnrytme',),
'døgnservice': ('døgnservice',),
'døgnservicen': ('døgnservice',),
'døgnservicene': ('døgnservice',),
'døgnservicer': ('døgnservice',),
'døl': ('døl',),
'dølen': ('døl',),
'dølene': ('døl',),
'døler': ('døl',),
'dølefe': ('dølefe',),
'dølefea': ('dølefe',),
'dølefeene': ('dølefe',),
'dølefeet': ('dølefe',),
'dølehest': ('dølehest',),
'dølehesten': ('dølehest',),
'dølehestene': ('dølehest',),
'dølehester': ('dølehest',),
'dølemål': ('dølemål',),
'dølemåla': ('dølemål',),
'dølemålene': ('dølemål',),
'dølemålet': ('dølemål',),
'dølevisa': ('dølevise',),
'dølevise': ('dølevise',),
'dølevisen': ('dølevise',),
'dølevisene': ('dølevise',),
'døleviser': ('dølevise',),
'dølgsmål': ('dølgsmål',),
'dølgsmåla': ('dølgsmål',),
'dølgsmålene': ('dølgsmål',),
'dølgsmålet': ('dølgsmål',),
'døma': ('døme',),
'døme': ('døme',),
'dømene': ('døme',),
'dømer': ('døme',),
'dømet': ('døme',),
'dømmeevna': ('dømmeevne',),
'dømmeevne': ('dømmeevne',),
'dømmeevnen': ('dømmeevne',),
'dømmeevnene': ('dømmeevne',),
'dømmeevner': ('dømmeevne',),
'dømmekraft': ('dømmekraft',),
'dømmekrafta': ('dømmekraft',),
'dømmekraften': ('dømmekraft',),
'dømmekreftene': ('dømmekraft',),
'dømmekrefter': ('dømmekraft',),
'dømmesjuka': ('dømmesjuke',),
'dømmesjuke': ('dømmesjuke',),
'dømmesjuken': ('dømmesjuke',),
'dømmesjukene': ('dømmesjuke',),
'dømmesjuker': ('dømmesjuke',),
'dømmesyka': ('dømmesyke',),
'dømmesyke': ('dømmesyke',),
'dømmesyken': ('dømmesyke',),
'dømmesykene': ('dømmesyke',),
'dømmesyker': ('dømmesyke',),
'dønn': ('dønn',),
'dønna': ('dønn',),
'dønnene': ('dønn',),
'dønnet': ('dønn',),
'dønning': ('dønning',),
'dønningen': ('dønning',),
'dønningene': ('dønning',),
'dønninger': ('dønning',),
'døpefat': ('døpefat',),
'døpefata': ('døpefat',),
'døpefatene': ('døpefat',),
'døpefater': ('døpefat',),
'døpefatet': ('døpefat',),
'døpefont': ('døpefont',),
'døpefonten': ('døpefont',),
'døpefontene': ('døpefont',),
'døpefonter': ('døpefont',),
'døpenavn': ('døpenavn',),
'døpenavna': ('døpenavn',),
'døpenavnene': ('døpenavn',),
'døpenavnet': ('døpenavn',),
'døper': ('døper',),
'døpere': ('døper',),
'døperen': ('døper',),
'døperer': ('døper',),
'døperne': ('døper',),
'døpevann': ('døpevann',),
'døpevanna': ('døpevann',),
'døpevannene': ('døpevann',),
'døpevannet': ('døpevann',),
'døpevatn': ('døpevatn',),
'døpevatna': ('døpevatn',),
'døpevatnene': ('døpevatn',),
'døpevatnet': ('døpevatn',),
'dør': ('dør',),
'døra': ('dør',),
'døren': ('dør',),
'dørene': ('dør',),
'dører': ('dør',),
'dørfylling': ('dørfylling',),
'dørfyllinga': ('dørfylling',),
'dørfyllingen': ('dørfylling',),
'dørfyllingene': ('dørfylling',),
'dørfyllinger': ('dørfylling',),
'dørgløtt': ('dørgløtt',),
'dørgløtta': ('dørgløtt',),
'dørgløtten': ('dørgløtt',),
'dørgløttene': ('dørgløtt',),
'dørgløtter': ('dørgløtt',),
'dørgløttet': ('dørgløtt',),
'dørhandtak': ('dørhandtak',),
'dørhandtaka': ('dørhandtak',),
'dørhandtakene': ('dørhandtak',),
'dørhandtaket': ('dørhandtak',),
'dørhella': ('dørhelle',),
'dørhelle': ('dørhelle',),
'dørhellen': ('dørhelle',),
'dørhellene': ('dørhelle',),
'dørheller': ('dørhelle',),
'dørhåndtak': ('dørhåndtak',),
'dørhåndtaka': ('dørhåndtak',),
'dørhåndtakene': ('dørhåndtak',),
'dørhåndtaket': ('dørhåndtak',),
'dørk': ('dørk',),
'dørken': ('dørk',),
'dørkene': ('dørk',),
'dørker': ('dørk',),
'dørkarm': ('dørkarm',),
'dørkarmen': ('dørkarm',),
'dørkarmene': ('dørkarm',),
'dørkarmer': ('dørkarm',),
'dørklinka': ('dørklinke',),
'dørklinke': ('dørklinke',),
'dørklinken': ('dørklinke',),
'dørklinkene': ('dørklinke',),
'dørklinker': ('dørklinke',),
'dørlås': ('dørlås',),
'dørlåsa': ('dørlås',),
'dørlåsen': ('dørlås',),
'dørlåsene': ('dørlås',),
'dørlåser': ('dørlås',),
'dørlåset': ('dørlås',),
'dørmatta': ('dørmatte',),
'dørmatte': ('dørmatte',),
'dørmatten': ('dørmatte',),
'dørmattene': ('dørmatte',),
'dørmatter': ('dørmatte',),
'dørramma': ('dørramme',),
'dørramme': ('dørramme',),
'dørrammen': ('dørramme',),
'dørrammene': ('dørramme',),
'dørrammer': ('dørramme',),
'dørselger': ('dørselger',),
'dørselgere': ('dørselger',),
'dørselgeren': ('dørselger',),
'dørselgerer': ('dørselger',),
'dørselgerne': ('dørselger',),
'dørskilt': ('dørskilt',),
'dørskilta': ('dørskilt',),
'dørskiltene': ('dørskilt',),
'dørskilter': ('dørskilt',),
'dørskiltet': ('dørskilt',),
'dørslag': ('dørslag',),
'dørslaga': ('dørslag',),
'dørslagene': ('dørslag',),
'dørslaget': ('dørslag',),
'dørstokk': ('dørstokk',),
'dørstokken': ('dørstokk',),
'dørstokkene': ('dørstokk',),
'dørstokker': ('dørstokk',),
'dørstokkmil': ('dørstokkmil',),
'dørstokkmila': ('dørstokkmil',),
'dørstokkmilen': ('dørstokkmil',),
'dørstokkmilene': ('dørstokkmil',),
'dørstopper': ('dørstopper',),
'dørstoppere': ('dørstopper',),
'dørstopperen': ('dørstopper',),
'dørstopperer': ('dørstopper',),
'dørstopperne': ('dørstopper',),
'dørtelefon': ('dørtelefon',),
'dørtelefonen': ('dørtelefon',),
'dørtelefonene': ('dørtelefon',),
'dørtelefoner': ('dørtelefon',),
'dørvakt': ('dørvakt',),
'dørvakta': ('dørvakt',),
'dørvakten': ('dørvakt',),
'dørvaktene': ('dørvakt',),
'dørvakter': ('dørvakt',),
'dørvokter': ('dørvokter',),
'dørvoktere': ('dørvokter',),
'dørvokteren': ('dørvokter',),
'dørvokterer': ('dørvokter',),
'dørvokterne': ('dørvokter',),
'døråpner': ('døråpner',),
'døråpnere': ('døråpner',),
'døråpneren': ('døråpner',),
'døråpnerer': ('døråpner',),
'døråpnerne': ('døråpner',),
'døs': ('døs',),
'døsen': ('døs',),
'døsene': ('døs',),
'døser': ('døs',),
'døveskole': ('døveskole',),
'døveskolen': ('døveskole',),
'døveskolene': ('døveskole',),
'døveskoler': ('døveskole',),
'døyt': ('døyt',),
'døyten': ('døyt',),
'døytene': ('døyt',),
'døyter': ('døyt',),
'e': ('e',),
'e\'en': ('e',),
'e-en': ('e',),
'e-ene': ('e',),
'e-er': ('e',),
'e': ('e',),
'ea': ('e',),
'een': ('e',),
'eene': ('e',),
'eer': ('e',),
'e-moll': ('e-moll',),
'e-mollen': ('e-moll',),
'e-mollene': ('e-moll',),
'e-moller': ('e-moll',),
'e-mål': ('e-mål',),
'e-måla': ('e-mål',),
'e-målene': ('e-mål',),
'e-målet': ('e-mål',),
'e-verk': ('e-verk',),
'e-verka': ('e-verk',),
'e-verkene': ('e-verk',),
'e-verker': ('e-verk',),
'e-verket': ('e-verk',),
'eau de cologne': ('eau de cologne',),
'eau de colognen': ('eau de cologne',),
'eau de colognene': ('eau de cologne',),
'eau de cologner': ('eau de cologne',),
'eau de vie': ('eau de vie',),
'eau de vien': ('eau de vie',),
'eau de viene': ('eau de vie',),
'eau de vier': ('eau de vie',),
'ebbe': ('ebbe',),
'ebben': ('ebbe',),
'ebbene': ('ebbe',),
'ebber': ('ebbe',),
'ebonitt': ('ebonitt',),
'ebonitten': ('ebonitt',),
'ebonittene': ('ebonitt',),
'ebonitter': ('ebonitt',),
'ecrusilke': ('ecrusilke',),
'ecrusilken': ('ecrusilke',),
'ecrusilkene': ('ecrusilke',),
'ecrusilker': ('ecrusilke',),
'ecu': ('ecu',),
'ecuen': ('ecu',),
'ecuene': ('ecu',),
'ecuadorianer': ('ecuadorianer',),
'ecuadorianere': ('ecuadorianer',),
'ecuadorianeren': ('ecuadorianer',),
'ecuadorianerer': ('ecuadorianer',),
'ecuadorianerne': ('ecuadorianer',),
'ed': ('ed',),
'eden': ('ed',),
'edene': ('ed',),
'eder': ('ed',),
'edamer': ('edamer',),
'edamere': ('edamer',),
'edameren': ('edamer',),
'edamerer': ('edamer',),
'edamerne': ('edamer',),
'edamerost': ('edamerost',),
'edamerosten': ('edamerost',),
'edamerostene': ('edamerost',),
'edameroster': ('edamerost',),
'edb-anlegg': ('edb-anlegg',),
'edb-anlegga': ('edb-anlegg',),
'edb-anleggene': ('edb-anlegg',),
'edb-anlegget': ('edb-anlegg',),
'edb-operatør': ('edb-operatør',),
'edb-operatøren': ('edb-operatør',),
'edb-operatørene': ('edb-operatør',),
'edb-operatører': ('edb-operatør',),
'edb-senter': ('edb-senter',),
'edb-senteret': ('edb-senter',),
'edb-sentra': ('edb-senter',),
'edb-sentre': ('edb-senter',),
'edb-sentrene': ('edb-senter',),
'edb-sentret': ('edb-senter',),
'edb-sentral': ('edb-sentral',),
'edb-sentralen': ('edb-sentral',),
'edb-sentralene': ('edb-sentral',),
'edb-sentraler': ('edb-sentral',),
'edb-terminal': ('edb-terminal',),
'edb-terminalen': ('edb-terminal',),
'edb-terminalene': ('edb-terminal',),
'edb-terminaler': ('edb-terminal',),
'edb-utstyr': ('edb-utstyr',),
'edb-utstyra': ('edb-utstyr',),
'edb-utstyrene': ('edb-utstyr',),
'edb-utstyret': ('edb-utstyr',),
'edd': ('edd',),
'edden': ('edd',),
'eddene': ('edd',),
'edder': ('edd',),
'eddadikt': ('eddadikt',),
'eddadikta': ('eddadikt',),
'eddadiktene': ('eddadikt',),
'eddadiktet': ('eddadikt',),
'eddakvad': ('eddakvad',),
'eddakvada': ('eddakvad',),
'eddakvadene': ('eddakvad',),
'eddakvadet': ('eddakvad',),
'edder': ('edder',),
'eddera': ('edder',),
'edderen': ('edder',),
'edderene': ('edder',),
'edderer': ('edder',),
'edderet': ('edder',),
'edderkopp': ('edderkopp',),
'edderkoppen': ('edderkopp',),
'edderkoppene': ('edderkopp',),
'edderkopper': ('edderkopp',),
'edderkoppdyr': ('edderkoppdyr',),
'edderkoppdyra': ('edderkoppdyr',),
'edderkoppdyrene': ('edderkoppdyr',),
'edderkoppdyret': ('edderkoppdyr',),
'edderkoppnett': ('edderkoppnett',),
'edderkoppnetta': ('edderkoppnett',),
'edderkoppnettene': ('edderkoppnett',),
'edderkoppnettet': ('edderkoppnett',),
'edderkoppspinn': ('edderkoppspinn',),
'edderkoppspinna': ('edderkoppspinn',),
'edderkoppspinnene': ('edderkoppspinn',),
'edderkoppspinnet': ('edderkoppspinn',),
'eddik': ('eddik',),
'eddiken': ('eddik',),
'eddikene': ('eddik',),
'eddiker': ('eddik',),
'eddikkrukka': ('eddikkrukke',),
'eddikkrukke': ('eddikkrukke',),
'eddikkrukken': ('eddikkrukke',),
'eddikkrukkene': ('eddikkrukke',),
'eddikkrukker': ('eddikkrukke',),
'eddiksyra': ('eddiksyre',),
'eddiksyre': ('eddiksyre',),
'eddiksyren': ('eddiksyre',),
'eddiksyrene': ('eddiksyre',),
'eddiksyrer': ('eddiksyre',),
'edelgass': ('edelgass',),
'edelgassen': ('edelgass',),
'edelgassene': ('edelgass',),
'edelgasser': ('edelgass',),
'edelgran': ('edelgran',),
'edelgrana': ('edelgran',),
'edelgranen': ('edelgran',),
'edelgranene': ('edelgran',),
'edelgraner': ('edelgran',),
'edellauvskog': ('edellauvskog',),
'edellauvskogen': ('edellauvskog',),
'edellauvskogene': ('edellauvskog',),
'edellauvskoger': ('edellauvskog',),
'edelløvskog': ('edelløvskog',),
'edelløvskogen': ('edelløvskog',),
'edelløvskogene': ('edelløvskog',),
'edelløvskoger': ('edelløvskog',),
'edelmetall': ('edelmetall',),
'edelmetalla': ('edelmetall',),
'edelmetallene': ('edelmetall',),
'edelmetaller': ('edelmetall',),
'edelmetallet': ('edelmetall',),
'edelstein': ('edelstein',),
'edelsteinen': ('edelstein',),
'edelsteinene': ('edelstein',),
'edelsteiner': ('edelstein',),
'edelsten': ('edelsten',),
'edelstenen': ('edelsten',),
'edelstenene': ('edelsten',),
'edelstener': ('edelsten',),
'edelweiss': ('edelweiss',),
'edelweissen': ('edelweiss',),
'edelweissene': ('edelweiss',),
'edelweisser': ('edelweiss',),
'eden': ('eden',),
'ederdun': ('ederdun',),
'ederduna': ('ederdun',),
'ederdunen': ('ederdun',),
'ederdunene': ('ederdun',),
'ederdunet': ('ederdun',),
'ederdunsdyna': ('ederdunsdyne',),
'ederdunsdyne': ('ederdunsdyne',),
'ederdunsdynen': ('ederdunsdyne',),
'ederdunsdynene': ('ederdunsdyne',),
'ederdunsdyner': ('ederdunsdyne',),
'edikt': ('edikt',),
'edikta': ('edikt',),
'ediktene': ('edikt',),
'edikter': ('edikt',),
'ediktet': ('edikt',),
'edisjon': ('edisjon',),
'edisjonen': ('edisjon',),
'edisjonene': ('edisjon',),
'edisjoner': ('edisjon',),
'edisjonsplikt': ('edisjonsplikt',),
'edisjonsplikta': ('edisjonsplikt',),
'edisjonsplikten': ('edisjonsplikt',),
'edisjonspliktene': ('edisjonsplikt',),
'edisjonsplikter': ('edisjonsplikt',),
'edisjonsrett': ('edisjonsrett',),
'edisjonsretten': ('edisjonsrett',),
'edisjonsrettene': ('edisjonsrett',),
'edisjonsretter': ('edisjonsrett',),
'edruelighet': ('edruelighet',),
'edrueligheta': ('edruelighet',),
'edrueligheten': ('edruelighet',),
'edruelighetene': ('edruelighet',),
'edrueligheter': ('edruelighet',),
'edruskap': ('edruskap',),
'edruskapen': ('edruskap',),
'edruskapene': ('edruskap',),
'edruskaper': ('edruskap',),
'edruskapsarbeid': ('edruskapsarbeid',),
'edruskapsarbeida': ('edruskapsarbeid',),
'edruskapsarbeidene': ('edruskapsarbeid',),
'edruskapsarbeidet': ('edruskapsarbeid',),
'edruskapsdirektorat': ('edruskapsdirektorat',),
'edruskapsdirektorata': ('edruskapsdirektorat',),
'edruskapsdirektoratene': ('edruskapsdirektorat',),
'edruskapsdirektorater': ('edruskapsdirektorat',),
'edruskapsdirektoratet': ('edruskapsdirektorat',),
'edruskapsnemnd': ('edruskapsnemnd',),
'edruskapsnemnda': ('edruskapsnemnd',),
'edruskapsnemnden': ('edruskapsnemnd',),
'edruskapsnemndene': ('edruskapsnemnd',),
'edruskapsnemnder': ('edruskapsnemnd',),
'edruskapsråd': ('edruskapsråd',),
'edruskapsråda': ('edruskapsråd',),
'edruskapsrådene': ('edruskapsråd',),
'edruskapsrådet': ('edruskapsråd',),
'edsavleggelse': ('edsavleggelse',),
'edsavleggelsen': ('edsavleggelse',),
'edsavleggelsene': ('edsavleggelse',),
'edsavleggelser': ('edsavleggelse',),
'edsformular': ('edsformular',),
'edsformulara': ('edsformular',),
'edsformularen': ('edsformular',),
'edsformularene': ('edsformular',),
'edsformularer': ('edsformular',),
'edsformularet': ('edsformular',),
'efemeride': ('efemeride',),
'efemeriden': ('efemeride',),
'efemeridene': ('efemeride',),
'efemerider': ('efemeride',),
'efeser': ('efeser',),
'efesere': ('efeser',),
'efeseren': ('efeser',),
'efeserer': ('efeser',),
'efeserne': ('efeser',),
'efeserbrev': ('efeserbrev',),
'efeserbreva': ('efeserbrev',),
'efeserbrevene': ('efeserbrev',),
'efeserbrever': ('efeserbrev',),
'efeserbrevet': ('efeserbrev',),
'effekt': ('effekt',),
'effekten': ('effekt',),
'effektene': ('effekt',),
'effekter': ('effekt',),
'effektgarn': ('effektgarn',),
'effektgarna': ('effektgarn',),
'effektgarnene': ('effektgarn',),
'effektgarnet': ('effektgarn',),
'effektivitet': ('effektivitet',),
'effektiviteten': ('effektivitet',),
'effektivitetene': ('effektivitet',),
'effektiviteter': ('effektivitet',),
'effektivitetsjag': ('effektivitetsjag',),
'effektivitetsjaga': ('effektivitetsjag',),
'effektivitetsjagene': ('effektivitetsjag',),
'effektivitetsjaget': ('effektivitetsjag',),
'efor': ('efor',),
'eforen': ('efor',),
'eforene': ('efor',),
'eforer': ('efor',),
'eforat': ('eforat',),
'eforata': ('eforat',),
'eforatene': ('eforat',),
'eforater': ('eforat',),
'eforatet': ('eforat',),
'efugl': ('efugl',),
'efuglen': ('efugl',),
'efuglene': ('efugl',),
'efugler': ('efugl',),
'eføy': ('eføy',),
'eføyen': ('eføy',),
'eføyene': ('eføy',),
'eføyer': ('eføy',),
'egalitet': ('egalitet',),
'egaliteten': ('egalitet',),
'egalitetene': ('egalitet',),
'egaliteter': ('egalitet',),
'egd': ('egd',),
'egden': ('egd',),
'egdene': ('egd',),
'egder': ('egd',),
'egde': ('egde',),
'egden': ('egde',),
'egdene': ('egde',),
'egder': ('egde',),
'egenaktivitet': ('egenaktivitet',),
'egenaktiviteten': ('egenaktivitet',),
'egenaktivitetene': ('egenaktivitet',),
'egenaktiviteter': ('egenaktivitet',),
'egenandel': ('egenandel',),
'egenandelen': ('egenandel',),
'egenandelene': ('egenandel',),
'egenandeler': ('egenandel',),
'egenart': ('egenart',),
'egenarta': ('egenart',),
'egenarten': ('egenart',),
'egenartene': ('egenart',),
'egenarter': ('egenart',),
'egenfinansiering': ('egenfinansiering',),
'egenfinansieringa': ('egenfinansiering',),
'egenfinansieringen': ('egenfinansiering',),
'egenfinansieringene': ('egenfinansiering',),
'egenfinansieringer': ('egenfinansiering',),
'egenfrekvens': ('egenfrekvens',),
'egenfrekvensen': ('egenfrekvens',),
'egenfrekvensene': ('egenfrekvens',),
'egenfrekvenser': ('egenfrekvens',),
'egenhet': ('egenhet',),
'egenheta': ('egenhet',),
'egenheten': ('egenhet',),
'egenhetene': ('egenhet',),
'egenheter': ('egenhet',),
'egeninnsats': ('egeninnsats',),
'egeninnsatsen': ('egeninnsats',),
'egeninnsatsene': ('egeninnsats',),
'egeninnsatser': ('egeninnsats',),
'egeninteresse': ('egeninteresse',),
'egeninteressen': ('egeninteresse',),
'egeninteressene': ('egeninteresse',),
'egeninteresser': ('egeninteresse',),
'egenkapital': ('egenkapital',),
'egenkapitalen': ('egenkapital',),
'egenkapitalene': ('egenkapital',),
'egenkapitaler': ('egenkapital',),
'egenmelding': ('egenmelding',),
'egenmeldinga': ('egenmelding',),
'egenmeldingen': ('egenmelding',),
'egenmeldingene': ('egenmelding',),
'egenmeldinger': ('egenmelding',),
'egennavn': ('egennavn',),
'egennavna': ('egennavn',),
'egennavnene': ('egennavn',),
'egennavnet': ('egennavn',),
'egennytta': ('egennytte',),
'egennytte': ('egennytte',),
'egennytten': ('egennytte',),
'egennyttene': ('egennytte',),
'egennytter': ('egennytte',),
'egenomsorg': ('egenomsorg',),
'egenomsorga': ('egenomsorg',),
'egenomsorgen': ('egenomsorg',),
'egenomsorgene': ('egenomsorg',),
'egenomsorger': ('egenomsorg',),
'egenproduksjon': ('egenproduksjon',),
'egenproduksjonen': ('egenproduksjon',),
'egenproduksjonene': ('egenproduksjon',),
'egenproduksjoner': ('egenproduksjon',),
'egenskap': ('egenskap',),
'egenskapen': ('egenskap',),
'egenskapene': ('egenskap',),
'egenskaper': ('egenskap',),
'egenvekt': ('egenvekt',),
'egenvekta': ('egenvekt',),
'egenvekten': ('egenvekt',),
'egenvektene': ('egenvekt',),
'egenvekter': ('egenvekt',),
'egenverd': ('egenverd',),
'egenverda': ('egenverd',),
'egenverdene': ('egenverd',),
'egenverdet': ('egenverd',),
'egenverdi': ('egenverdi',),
'egenverdien': ('egenverdi',),
'egenverdiene': ('egenverdi',),
'egenverdier': ('egenverdi',),
'egenvilje': ('egenvilje',),
'egenviljen': ('egenvilje',),
'egenviljene': ('egenvilje',),
'egenviljer': ('egenvilje',),
'egg': ('egg',),
'egga': ('egg',),
'eggene': ('egg',),
'egget': ('egg',),
'egg': ('egg',),
'egga': ('egg',),
'eggen': ('egg',),
'eggene': ('egg',),
'egger': ('egg',),
'eggcella': ('eggcelle',),
'eggcelle': ('eggcelle',),
'eggcellen': ('eggcelle',),
'eggcellene': ('eggcelle',),
'eggceller': ('eggcelle',),
'eggdeler': ('eggdeler',),
'eggdelere': ('eggdeler',),
'eggdeleren': ('eggdeler',),
'eggdelerer': ('eggdeler',),
'eggdelerne': ('eggdeler',),
'eggedeler': ('eggedeler',),
'eggedelere': ('eggedeler',),
'eggedeleren': ('eggedeler',),
'eggedelerer': ('eggedeler',),
'eggedelerne': ('eggedeler',),
'eggedosene': ('eggedosis',),
'eggedoser': ('eggedosis',),
'eggedosis': ('eggedosis',),
'eggedosisen': ('eggedosis',),
'eggedosisene': ('eggedosis',),
'eggedosiser': ('eggedosis',),
'eggeglas': ('eggeglas',),
'eggeglasa': ('eggeglas',),
'eggeglasene': ('eggeglas',),
'eggeglaset': ('eggeglas',),
'eggeglass': ('eggeglass',),
'eggeglassa': ('eggeglass',),
'eggeglassene': ('eggeglass',),
'eggeglasset': ('eggeglass',),
'eggegula': ('eggegule',),
'eggegule': ('eggegule',),
'eggegulen': ('eggegule',),
'eggegulene': ('eggegule',),
'eggeguler': ('eggegule',),
'eggehvita': ('eggehvite',),
'eggehvite': ('eggehvite',),
'eggehviten': ('eggehvite',),
'eggehvitene': ('eggehvite',),
'eggehviter': ('eggehvite',),
'eggehvitestoff': ('eggehvitestoff',),
'eggehvitestoffa': ('eggehvitestoff',),
'eggehvitestoffene': ('eggehvitestoff',),
'eggehvitestoffer': ('eggehvitestoff',),
'eggehvitestoffet': ('eggehvitestoff',),
'eggekrem': ('eggekrem',),
'eggekremen': ('eggekrem',),
'eggekremene': ('eggekrem',),
'eggekremer': ('eggekrem',),
'eggekvita': ('eggekvite',),
'eggekvite': ('eggekvite',),
'eggekviten': ('eggekvite',),
'eggekvitene': ('eggekvite',),
'eggekviter': ('eggekvite',),
'eggekvita': ('eggekvite',),
'eggekvite': ('eggekvite',),
'eggekviten': ('eggekvite',),
'eggekvitene': ('eggekvite',),
'eggekviter': ('eggekvite',),
'eggekvitestoff': ('eggekvitestoff',),
'eggekvitestoffa': ('eggekvitestoff',),
'eggekvitestoffene': ('eggekvitestoff',),
'eggekvitestoffer': ('eggekvitestoff',),
'eggekvitestoffet': ('eggekvitestoff',),
'eggeomelett': ('eggeomelett',),
'eggeomeletten': ('eggeomelett',),
'eggeomelettene': ('eggeomelett',),
'eggeomeletter': ('eggeomelett',),
'eggeplomma': ('eggeplomme',),
'eggeplomme': ('eggeplomme',),
'eggeplommen': ('eggeplomme',),
'eggeplommene': ('eggeplomme',),
'eggeplommer': ('eggeplomme',),
'eggerøra': ('eggerøre',),
'eggerøre': ('eggerøre',),
'eggerøren': ('eggerøre',),
'eggerørene': ('eggerøre',),
'eggerører': ('eggerøre',),
'eggeskal': ('eggeskal',),
'eggeskala': ('eggeskal',),
'eggeskalene': ('eggeskal',),
'eggeskalet': ('eggeskal',),
'eggeskall': ('eggeskall',),
'eggeskalla': ('eggeskall',),
'eggeskallene': ('eggeskall',),
'eggeskallet': ('eggeskall',),
'eggfiska': ('eggfiske',),
'eggfiske': ('eggfiske',),
'eggfiskene': ('eggfiske',),
'eggfisker': ('eggfiske',),
'eggfisket': ('eggfiske',),
'eggfrukt': ('eggfrukt',),
'eggfrukta': ('eggfrukt',),
'eggfrukten': ('eggfrukt',),
'eggfruktene': ('eggfrukt',),
'eggfrukter': ('eggfrukt',),
'eggleder': ('eggleder',),
'eggledere': ('eggleder',),
'egglederen': ('eggleder',),
'egglederer': ('eggleder',),
'egglederne': ('eggleder',),
'eggløsning': ('eggløsning',),
'eggløsninga': ('eggløsning',),
'eggløsningen': ('eggløsning',),
'eggløsningene': ('eggløsning',),
'eggløsninger': ('eggløsning',),
'eggløysing': ('eggløysing',),
'eggløysinga': ('eggløysing',),
'eggløysingen': ('eggløysing',),
'eggløysingene': ('eggløysing',),
'eggløysinger': ('eggløysing',),
'eggplanta': ('eggplante',),
'eggplante': ('eggplante',),
'eggplanten': ('eggplante',),
'eggplantene': ('eggplante',),
'eggplanter': ('eggplante',),
'eggplantesalat': ('eggplantesalat',),
'eggplantesalaten': ('eggplantesalat',),
'eggplantesalatene': ('eggplantesalat',),
'eggplantesalater': ('eggplantesalat',),
'eggproduksjon': ('eggproduksjon',),
'eggproduksjonen': ('eggproduksjon',),
'eggproduksjonene': ('eggproduksjon',),
'eggproduksjoner': ('eggproduksjon',),
'eggprodusent': ('eggprodusent',),
'eggprodusenten': ('eggprodusent',),
'eggprodusentene': ('eggprodusent',),
'eggprodusenter': ('eggprodusent',),
'eggsekk': ('eggsekk',),
'eggsekken': ('eggsekk',),
'eggsekkene': ('eggsekk',),
'eggsekker': ('eggsekk',),
'eggsentral': ('eggsentral',),
'eggsentralen': ('eggsentral',),
'eggsentralene': ('eggsentral',),
'eggsentraler': ('eggsentral',),
'eggstokk': ('eggstokk',),
'eggstokken': ('eggstokk',),
'eggstokkene': ('eggstokk',),
'eggstokker': ('eggstokk',),
'eggstokkbetennelse': ('eggstokkbetennelse',),
'eggstokkbetennelsen': ('eggstokkbetennelse',),
'eggstokkbetennelsene': ('eggstokkbetennelse',),
'eggstokkbetennelser': ('eggstokkbetennelse',),
'eggvær': ('eggvær',),
'eggværa': ('eggvær',),
'eggværene': ('eggvær',),
'eggværet': ('eggvær',),
'egn': ('egn',),
'egnen': ('egn',),
'egnene': ('egn',),
'egner': ('egn',),
'ego': ('ego',),
'egoa': ('ego',),
'egoene': ('ego',),
'egoet': ('ego',),
'egoisme': ('egoisme',),
'egoismen': ('egoisme',),
'egoismene': ('egoisme',),
'egoismer': ('egoisme',),
'egoist': ('egoist',),
'egoisten': ('egoist',),
'egoistene': ('egoist',),
'egoister': ('egoist',),
'egosentrisitet': ('egosentrisitet',),
'egosentrisiteten': ('egosentrisitet',),
'egosentrisitetene': ('egosentrisitet',),
'egosentrisiteter': ('egosentrisitet',),
'egotripp': ('egotripp',),
'egotrippen': ('egotripp',),
'egotrippene': ('egotripp',),
'egotripper': ('egotripp',),
'egypter': ('egypter',),
'egyptere': ('egypter',),
'egypteren': ('egypter',),
'egypterer': ('egypter',),
'egypterne': ('egypter',),
'egyptolog': ('egyptolog',),
'egyptologen': ('egyptolog',),
'egyptologene': ('egyptolog',),
'egyptologer': ('egyptolog',),
'egyptologi': ('egyptologi',),
'egyptologien': ('egyptologi',),
'egyptologiene': ('egyptologi',),
'egyptologier': ('egyptologi',),
'eid': ('eid',),
'eida': ('eid',),
'eidene': ('eid',),
'eidet': ('eid',),
'eidsvollsmann': ('eidsvollsmann',),
'eidsvollsmannen': ('eidsvollsmann',),
'eidsvollsmenn': ('eidsvollsmann',),
'eidsvollsmennene': ('eidsvollsmann',),
'eia': ('eie',),
'eie': ('eie',),
'eiene': ('eie',),
'eier': ('eie',),
'eiet': ('eie',),
'eieform': ('eieform',),
'eieforma': ('eieform',),
'eieformen': ('eieform',),
'eieformene': ('eieform',),
'eieformer': ('eieform',),
'eiendel': ('eiendel',),
'eiendelen': ('eiendel',),
'eiendelene': ('eiendel',),
'eiendeler': ('eiendel',),
'eiendom': ('eiendom',),
'eiendommen': ('eiendom',),
'eiendommene': ('eiendom',),
'eiendommer': ('eiendom',),
'eiendomsbesitter': ('eiendomsbesitter',),
'eiendomsbesittere': ('eiendomsbesitter',),
'eiendomsbesitteren': ('eiendomsbesitter',),
'eiendomsbesitterer': ('eiendomsbesitter',),
'eiendomsbesitterne': ('eiendomsbesitter',),
'eiendomshandel': ('eiendomshandel',),
'eiendomshandelen': ('eiendomshandel',),
'eiendomshandlene': ('eiendomshandel',),
'eiendomshandler': ('eiendomshandel',),
'eiendomsmegler': ('eiendomsmegler',),
'eiendomsmeglere': ('eiendomsmegler',),
'eiendomsmegleren': ('eiendomsmegler',),
'eiendomsmeglerer': ('eiendomsmegler',),
'eiendomsmeglerne': ('eiendomsmegler',),
'eiendomsmekler': ('eiendomsmekler',),
'eiendomsmeklere': ('eiendomsmekler',),
'eiendomsmekleren': ('eiendomsmekler',),
'eiendomsmeklerer': ('eiendomsmekler',),
'eiendomsmeklerne': ('eiendomsmekler',),
'eiendomspronomen': ('eiendomspronomen',),
'eiendomspronomena': ('eiendomspronomen',),
'eiendomspronomenene': ('eiendomspronomen',),
'eiendomspronomener': ('eiendomspronomen',),
'eiendomspronomenet': ('eiendomspronomen',),
'eiendomsrett': ('eiendomsrett',),
'eiendomsretten': ('eiendomsrett',),
'eiendomsrettene': ('eiendomsrett',),
'eiendomsretter': ('eiendomsrett',),
'eiendomsskatt': ('eiendomsskatt',),
'eiendomsskatten': ('eiendomsskatt',),
'eiendomsskattene': ('eiendomsskatt',),
'eiendomsskatter': ('eiendomsskatt',),
'eiendomsspekulasjon': ('eiendomsspekulasjon',),
'eiendomsspekulasjonen': ('eiendomsspekulasjon',),
'eiendomsspekulasjonene': ('eiendomsspekulasjon',),
'eiendomsspekulasjoner': ('eiendomsspekulasjon',),
'eiendomstvist': ('eiendomstvist',),
'eiendomstvisten': ('eiendomstvist',),
'eiendomstvistene': ('eiendomstvist',),
'eiendomstvister': ('eiendomstvist',),
'eier': ('eier',),
'eiere': ('eier',),
'eieren': ('eier',),
'eierer': ('eier',),
'eierne': ('eier',),
'eierandel': ('eierandel',),
'eierandelen': ('eierandel',),
'eierandelene': ('eierandel',),
'eierandeler': ('eierandel',),
'eierforhold': ('eierforhold',),
'eierforholda': ('eierforhold',),
'eierforholdene': ('eierforhold',),
'eierforholdet': ('eierforhold',),
'eierinteresse': ('eierinteresse',),
'eierinteressen': ('eierinteresse',),
'eierinteressene': ('eierinteresse',),
'eierinteresser': ('eierinteresse',),
'eierleilighet': ('eierleilighet',),
'eierleiligheta': ('eierleilighet',),
'eierleiligheten': ('eierleilighet',),
'eierleilighetene': ('eierleilighet',),
'eierleiligheter': ('eierleilighet',),
'eierlønn': ('eierlønn',),
'eierlønna': ('eierlønn',),
'eierlønnen': ('eierlønn',),
'eierlønnene': ('eierlønn',),
'eierlønner': ('eierlønn',),
'eiermann': ('eiermann',),
'eiermannen': ('eiermann',),
'eiermenn': ('eiermann',),
'eiermennene': ('eiermann',),
'eiermina': ('eiermine',),
'eiermine': ('eiermine',),
'eierminen': ('eiermine',),
'eierminene': ('eiermine',),
'eierminer': ('eiermine',),
'eigenaktivitet': ('eigenaktivitet',),
'eigenaktiviteten': ('eigenaktivitet',),
'eigenaktivitetene': ('eigenaktivitet',),
'eigenaktiviteter': ('eigenaktivitet',),
'eigenandel': ('eigenandel',),
'eigenandelen': ('eigenandel',),
'eigenandelene': ('eigenandel',),
'eigenandeler': ('eigenandel',),
'eigenart': ('eigenart',),
'eigenarta': ('eigenart',),
'eigenarten': ('eigenart',),
'eigenartene': ('eigenart',),
'eigenarter': ('eigenart',),
'eigenfinansiering': ('eigenfinansiering',),
'eigenfinansieringa': ('eigenfinansiering',),
'eigenfinansieringen': ('eigenfinansiering',),
'eigenfinansieringene': ('eigenfinansiering',),
'eigenfinansieringer': ('eigenfinansiering',),
'eigenfrekvens': ('eigenfrekvens',),
'eigenfrekvensen': ('eigenfrekvens',),
'eigenfrekvensene': ('eigenfrekvens',),
'eigenfrekvenser': ('eigenfrekvens',),
'eigeninnsats': ('eigeninnsats',),
'eigeninnsatsen': ('eigeninnsats',),
'eigeninnsatsene': ('eigeninnsats',),
'eigeninnsatser': ('eigeninnsats',),
'eigeninteresse': ('eigeninteresse',),
'eigeninteressen': ('eigeninteresse',),
'eigeninteressene': ('eigeninteresse',),
'eigeninteresser': ('eigeninteresse',),
'eigenkapital': ('eigenkapital',),
'eigenkapitalen': ('eigenkapital',),
'eigenkapitalene': ('eigenkapital',),
'eigenkapitaler': ('eigenkapital',),
'eigenmelding': ('eigenmelding',),
'eigenmeldinga': ('eigenmelding',),
'eigenmeldingen': ('eigenmelding',),
'eigenmeldingene': ('eigenmelding',),
'eigenmeldinger': ('eigenmelding',),
'eigennavn': ('eigennavn',),
'eigennavna': ('eigennavn',),
'eigennavnene': ('eigennavn',),
'eigennavnet': ('eigennavn',),
'eigennytta': ('eigennytte',),
'eigennytte': ('eigennytte',),
'eigennytten': ('eigennytte',),
'eigennyttene': ('eigennytte',),
'eigennytter': ('eigennytte',),
'eigenomsorg': ('eigenomsorg',),
'eigenomsorga': ('eigenomsorg',),
'eigenomsorgen': ('eigenomsorg',),
'eigenomsorgene': ('eigenomsorg',),
'eigenomsorger': ('eigenomsorg',),
'eigenproduksjon': ('eigenproduksjon',),
'eigenproduksjonen': ('eigenproduksjon',),
'eigenproduksjonene': ('eigenproduksjon',),
'eigenproduksjoner': ('eigenproduksjon',),
'eigenvekt': ('eigenvekt',),
'eigenvekta': ('eigenvekt',),
'eigenvekten': ('eigenvekt',),
'eigenvektene': ('eigenvekt',),
'eigenvekter': ('eigenvekt',),
'eigenverd': ('eigenverd',),
'eigenverda': ('eigenverd',),
'eigenverdene': ('eigenverd',),
'eigenverdet': ('eigenverd',),
'eigenverdi': ('eigenverdi',),
'eigenverdien': ('eigenverdi',),
'eigenverdiene': ('eigenverdi',),
'eigenverdier': ('eigenverdi',),
'eigenvilje': ('eigenvilje',),
'eigenviljen': ('eigenvilje',),
'eigenviljene': ('eigenvilje',),
'eigenviljer': ('eigenvilje',),
'eign': ('eign',),
'eigna': ('eign',),
'eignen': ('eign',),
'eignene': ('eign',),
'eigner': ('eign',),
'eik': ('eik',),
'eika': ('eik',),
'eiken': ('eik',),
'eikene': ('eik',),
'eiker': ('eik',),
'eikenøtt': ('eikenøtt',),
'eikenøtta': ('eikenøtt',),
'eikenøtten': ('eikenøtt',),
'eikenøttene': ('eikenøtt',),
'eikenøtter': ('eikenøtt',),
'eikepanel': ('eikepanel',),
'eikepanela': ('eikepanel',),
'eikepanelene': ('eikepanel',),
'eikepaneler': ('eikepanel',),
'eikepanelet': ('eikepanel',),
'eikeskog': ('eikeskog',),
'eikeskogen': ('eikeskog',),
'eikeskogene': ('eikeskog',),
'eikeskoger': ('eikeskog',),
'eim': ('eim',),
'eimen': ('eim',),
'eimene': ('eim',),
'eimer': ('eim',),
'einebusk': ('einebusk',),
'einebusken': ('einebusk',),
'einebuskene': ('einebusk',),
'einebusker': ('einebusk',),
'einebær': ('einebær',),
'einebæra': ('einebær',),
'einebærene': ('einebær',),
'einebæret': ('einebær',),
'einelåg': ('einelåg',),
'einelågen': ('einelåg',),
'einelågene': ('einelåg',),
'einelåger': ('einelåg',),
'einer': ('einer',),
'einere': ('einer',),
'eineren': ('einer',),
'einerer': ('einer',),
'einerne': ('einer',),
'einerbusk': ('einerbusk',),
'einerbusken': ('einerbusk',),
'einerbuskene': ('einerbusk',),
'einerbusker': ('einerbusk',),
'einerbær': ('einerbær',),
'einerbæra': ('einerbær',),
'einerbærene': ('einerbær',),
'einerbæret': ('einerbær',),
'einerlåg': ('einerlåg',),
'einerlågen': ('einerlåg',),
'einerlågene': ('einerlåg',),
'einerlåger': ('einerlåg',),
'einherje': ('einherje',),
'einherjen': ('einherje',),
'einherjene': ('einherje',),
'einherjer': ('einherje',),
'eining': ('eining',),
'eininga': ('eining',),
'einingen': ('eining',),
'einingene': ('eining',),
'eininger': ('eining',),
'einsling': ('einsling',),
'einslingen': ('einsling',),
'einslingene': ('einsling',),
'einslinger': ('einsling',),
'einstape': ('einstape',),
'einstapen': ('einstape',),
'einstapene': ('einstape',),
'einstaper': ('einstape',),
'einsteinium': ('einsteinium',),
'einsteiniuma': ('einsteinium',),
'einsteiniumene': ('einsteinium',),
'einsteiniumet': ('einsteinium',),
'einstøing': ('einstøing',),
'einstøingen': ('einstøing',),
'einstøingene': ('einstøing',),
'einstøinger': ('einstøing',),
'eir': ('eir',),
'eira': ('eir',),
'eirene': ('eir',),
'eiret': ('eir',),
'eitel': ('eitel',),
'eitelen': ('eitel',),
'eitlene': ('eitel',),
'eitler': ('eitel',),
'eitel': ('eitel',),
'eitelen': ('eitel',),
'eitlene': ('eitel',),
'eitler': ('eitel',),
'eiter': ('eiter',),
'eiteret': ('eiter',),
'eitra': ('eiter',),
'eitrene': ('eiter',),
'eitrer': ('eiter',),
'eitret': ('eiter',),
'eitermaur': ('eitermaur',),
'eitermauren': ('eitermaur',),
'eitermaurene': ('eitermaur',),
'eiterorm': ('eiterorm',),
'eiterormen': ('eiterorm',),
'eiterormene': ('eiterorm',),
'eiterormer': ('eiterorm',),
'ejakulasjon': ('ejakulasjon',),
'ejakulasjonen': ('ejakulasjon',),
'ejakulasjonene': ('ejakulasjon',),
'ejakulasjoner': ('ejakulasjon',),
'ejektor': ('ejektor',),
'ejektoren': ('ejektor',),
'ejektorene': ('ejektor',),
'ejektorer': ('ejektor',),
'ekall': ('ekall',),
'ekallen': ('ekall',),
'ekallene': ('ekall',),
'ekaller': ('ekall',),
'ekko': ('ekko',),
'ekkoa': ('ekko',),
'ekkoene': ('ekko',),
'ekkoer': ('ekko',),
'ekkoet': ('ekko',),
'ekkofon': ('ekkofon',),
'ekkofonen': ('ekkofon',),
'ekkofonene': ('ekkofon',),
'ekkofoner': ('ekkofon',),
'ekkolodd': ('ekkolodd',),
'ekkolodda': ('ekkolodd',),
'ekkoloddene': ('ekkolodd',),
'ekkolodder': ('ekkolodd',),
'ekkoloddet': ('ekkolodd',),
'ekkoord': ('ekkoord',),
'ekkoorda': ('ekkoord',),
'ekkoordene': ('ekkoord',),
'ekkoordet': ('ekkoord',),
'eklektiker': ('eklektiker',),
'eklektikere': ('eklektiker',),
'eklektikeren': ('eklektiker',),
'eklektikerer': ('eklektiker',),
'eklektikerne': ('eklektiker',),
'eklektisisme': ('eklektisisme',),
'eklektisismen': ('eklektisisme',),
'eklektisismene': ('eklektisisme',),
'eklektisismer': ('eklektisisme',),
'ekling': ('ekling',),
'eklingen': ('ekling',),
'eklingene': ('ekling',),
'eklinger': ('ekling',),
'eklipse': ('eklipse',),
'eklipsen': ('eklipse',),
'eklipsene': ('eklipse',),
'eklipser': ('eklipse',),
'ekliptikk': ('ekliptikk',),
'ekliptikken': ('ekliptikk',),
'ekliptikkene': ('ekliptikk',),
'ekliptikker': ('ekliptikk',),
'ekliptikkvinkel': ('ekliptikkvinkel',),
'ekliptikkvinkelen': ('ekliptikkvinkel',),
'ekliptikkvinklene': ('ekliptikkvinkel',),
'ekliptikkvinkler': ('ekliptikkvinkel',),
'ekonge': ('ekonge',),
'ekongen': ('ekonge',),
'ekongene': ('ekonge',),
'ekonger': ('ekonge',),
'ekornhale': ('ekornhale',),
'ekornhalen': ('ekornhale',),
'ekornhalene': ('ekornhale',),
'ekornhaler': ('ekornhale',),
'ekornhale': ('ekornhale',),
'ekornhalen': ('ekornhale',),
'ekornhalene': ('ekornhale',),
'ekornhaler': ('ekornhale',),
'ekornreda': ('ekornrede',),
'ekornrede': ('ekornrede',),
'ekornredene': ('ekornrede',),
'ekornreder': ('ekornrede',),
'ekornredet': ('ekornrede',),
'ekornreda': ('ekornrede',),
'ekornrede': ('ekornrede',),
'ekornredene': ('ekornrede',),
'ekornreder': ('ekornrede',),
'ekornredet': ('ekornrede',),
'ekornreir': ('ekornreir',),
'ekornreira': ('ekornreir',),
'ekornreirene': ('ekornreir',),
'ekornreiret': ('ekornreir',),
'ekornreir': ('ekornreir',),
'ekornreira': ('ekornreir',),
'ekornreirene': ('ekornreir',),
'ekornreiret': ('ekornreir',),
'ekra': ('ekre',),
'ekre': ('ekre',),
'ekren': ('ekre',),
'ekrene': ('ekre',),
'ekrer': ('ekre',),
'eksaltasjon': ('eksaltasjon',),
'eksaltasjonen': ('eksaltasjon',),
'eksaltasjonene': ('eksaltasjon',),
'eksaltasjoner': ('eksaltasjon',),
'eksamen': ('eksamen',),
'eksamenen': ('eksamen',),
'eksamenene': ('eksamen',),
'eksamener': ('eksamen',),
'eksamensbesvarelse': ('eksamensbesvarelse',),
'eksamensbesvarelsen': ('eksamensbesvarelse',),
'eksamensbesvarelsene': ('eksamensbesvarelse',),
'eksamensbesvarelser': ('eksamensbesvarelse',),
'eksamensfeber': ('eksamensfeber',),
'eksamensfebere': ('eksamensfeber',),
'eksamensfeberen': ('eksamensfeber',),
'eksamensfeberer': ('eksamensfeber',),
'eksamensfeberne': ('eksamensfeber',),
'eksamensfebre': ('eksamensfeber',),
'eksamensfebrene': ('eksamensfeber',),
'eksamensfebrer': ('eksamensfeber',),
'eksamenskandidat': ('eksamenskandidat',),
'eksamenskandidaten': ('eksamenskandidat',),
'eksamenskandidatene': ('eksamenskandidat',),
'eksamenskandidater': ('eksamenskandidat',),
'eksamenskommisjon': ('eksamenskommisjon',),
'eksamenskommisjonen': ('eksamenskommisjon',),
'eksamenskommisjonene': ('eksamenskommisjon',),
'eksamenskommisjoner': ('eksamenskommisjon',),
'eksamenslesing': ('eksamenslesing',),
'eksamenslesinga': ('eksamenslesing',),
'eksamenslesingen': ('eksamenslesing',),
'eksamenslesingene': ('eksamenslesing',),
'eksamenslesinger': ('eksamenslesing',),
'eksamenslesning': ('eksamenslesning',),
'eksamenslesninga': ('eksamenslesning',),
'eksamenslesningen': ('eksamenslesning',),
'eksamenslesningene': ('eksamenslesning',),
'eksamenslesninger': ('eksamenslesning',),
'eksamensoppgava': ('eksamensoppgave',),
'eksamensoppgave': ('eksamensoppgave',),
'eksamensoppgaven': ('eksamensoppgave',),
'eksamensoppgavene': ('eksamensoppgave',),
'eksamensoppgaver': ('eksamensoppgave',),
'eksamensordning': ('eksamensordning',),
'eksamensordninga': ('eksamensordning',),
'eksamensordningen': ('eksamensordning',),
'eksamensordningene': ('eksamensordning',),
'eksamensordninger': ('eksamensordning',),
'eksamensresultat': ('eksamensresultat',),
'eksamensresultata': ('eksamensresultat',),
'eksamensresultatene': ('eksamensresultat',),
'eksamensresultater': ('eksamensresultat',),
'eksamensresultatet': ('eksamensresultat',),
'eksamensvitnemål': ('eksamensvitnemål',),
'eksamensvitnemåla': ('eksamensvitnemål',),
'eksamensvitnemålene': ('eksamensvitnemål',),
'eksamensvitnemålet': ('eksamensvitnemål',),
'eksaminand': ('eksaminand',),
'eksaminanden': ('eksaminand',),
'eksaminandene': ('eksaminand',),
'eksaminander': ('eksaminand',),
'eksaminasjon': ('eksaminasjon',),
'eksaminasjonen': ('eksaminasjon',),
'eksaminasjonene': ('eksaminasjon',),
'eksaminasjoner': ('eksaminasjon',),
'eksaminator': ('eksaminator',),
'eksaminatoren': ('eksaminator',),
'eksaminatorene': ('eksaminator',),
'eksaminatorer': ('eksaminator',),
'eksegese': ('eksegese',),
'eksegesen': ('eksegese',),
'eksegesene': ('eksegese',),
'eksegeser': ('eksegese',),
'ekseget': ('ekseget',),
'eksegeten': ('ekseget',),
'eksegetene': ('ekseget',),
'eksegeter': ('ekseget',),
'eksekusjon': ('eksekusjon',),
'eksekusjonen': ('eksekusjon',),
'eksekusjonene': ('eksekusjon',),
'eksekusjoner': ('eksekusjon',),
'eksekusjonsgrunnlag': ('eksekusjonsgrunnlag',),
'eksekusjonsgrunnlaga': ('eksekusjonsgrunnlag',),
'eksekusjonsgrunnlagene': ('eksekusjonsgrunnlag',),
'eksekusjonsgrunnlaget': ('eksekusjonsgrunnlag',),
'eksekusjonsmakt': ('eksekusjonsmakt',),
'eksekusjonsmakta': ('eksekusjonsmakt',),
'eksekusjonsmakten': ('eksekusjonsmakt',),
'eksekusjonsmaktene': ('eksekusjonsmakt',),
'eksekusjonsmakter': ('eksekusjonsmakt',),
'eksekusjonspelotong': ('eksekusjonspelotong',),
'eksekusjonspelotongen': ('eksekusjonspelotong',),
'eksekusjonspelotongene': ('eksekusjonspelotong',),
'eksekusjonspelotonger': ('eksekusjonspelotong',),
'eksekutivmakt': ('eksekutivmakt',),
'eksekutivmakta': ('eksekutivmakt',),
'eksekutivmakten': ('eksekutivmakt',),
'eksekutivmaktene': ('eksekutivmakt',),
'eksekutivmakter': ('eksekutivmakt',),
'eksekutor': ('eksekutor',),
'eksekutoren': ('eksekutor',),
'eksekutorene': ('eksekutor',),
'eksekutorer': ('eksekutor',),
'eksekutør': ('eksekutør',),
'eksekutøren': ('eksekutør',),
'eksekutørene': ('eksekutør',),
'eksekutører': ('eksekutør',),
'eksellense': ('eksellense',),
'eksellensen': ('eksellense',),
'eksellensene': ('eksellense',),
'eksellenser': ('eksellense',),
'eksem': ('eksem',),
'eksema': ('eksem',),
'eksemen': ('eksem',),
'eksemene': ('eksem',),
'eksemer': ('eksem',),
'eksemet': ('eksem',),
'eksempel': ('eksempel',),
'eksempelet': ('eksempel',),
'eksempla': ('eksempel',),
'eksemplene': ('eksempel',),
'eksempler': ('eksempel',),
'eksemplet': ('eksempel',),
'eksempelsamling': ('eksempelsamling',),
'eksempelsamlinga': ('eksempelsamling',),
'eksempelsamlingen': ('eksempelsamling',),
'eksempelsamlingene': ('eksempelsamling',),
'eksempelsamlinger': ('eksempelsamling',),
'eksemplar': ('eksemplar',),
'eksemplara': ('eksemplar',),
'eksemplarene': ('eksemplar',),
'eksemplarer': ('eksemplar',),
'eksemplaret': ('eksemplar',),
'eksenterbevegelse': ('eksenterbevegelse',),
'eksenterbevegelsen': ('eksenterbevegelse',),
'eksenterbevegelsene': ('eksenterbevegelse',),
'eksenterbevegelser': ('eksenterbevegelse',),
'eksenterskiva': ('eksenterskive',),
'eksenterskive': ('eksenterskive',),
'eksenterskiven': ('eksenterskive',),
'eksenterskivene': ('eksenterskive',),
'eksenterskiver': ('eksenterskive',),
'eksentriker': ('eksentriker',),
'eksentrikere': ('eksentriker',),
'eksentrikeren': ('eksentriker',),
'eksentrikerer': ('eksentriker',),
'eksentrikerne': ('eksentriker',),
'eksentrisitet': ('eksentrisitet',),
'eksentrisiteten': ('eksentrisitet',),
'eksentrisitetene': ('eksentrisitet',),
'eksentrisiteter': ('eksentrisitet',),
'ekserpist': ('ekserpist',),
'ekserpisten': ('ekserpist',),
'ekserpistene': ('ekserpist',),
'ekserpister': ('ekserpist',),
'ekserpt': ('ekserpt',),
'ekserpta': ('ekserpt',),
'ekserptene': ('ekserpt',),
'ekserpter': ('ekserpt',),
'ekserptet': ('ekserpt',),
'ekserserreglement': ('ekserserreglement',),
'ekserserreglementa': ('ekserserreglement',),
'ekserserreglementene': ('ekserserreglement',),
'ekserserreglementer': ('ekserserreglement',),
'ekserserreglementet': ('ekserserreglement',),
'eksersis': ('eksersis',),
'eksersisen': ('eksersis',),
'eksersisene': ('eksersis',),
'eksersiser': ('eksersis',),
'eksess': ('eksess',),
'eksessen': ('eksess',),
'eksessene': ('eksess',),
'eksesser': ('eksess',),
'eksforlovede': ('eksforlovede',),
'eksforloveden': ('eksforlovede',),
'eksforlovedene': ('eksforlovede',),
'eksforloveder': ('eksforlovede',),
'ekshalasjon': ('ekshalasjon',),
'ekshalasjonen': ('ekshalasjon',),
'ekshalasjonene': ('ekshalasjon',),
'ekshalasjoner': ('ekshalasjon',),
'ekshibisjonisme': ('ekshibisjonisme',),
'ekshibisjonismen': ('ekshibisjonisme',),
'ekshibisjonismene': ('ekshibisjonisme',),
'ekshibisjonismer': ('ekshibisjonisme',),
'ekshibisjonist': ('ekshibisjonist',),
'ekshibisjonisten': ('ekshibisjonist',),
'ekshibisjonistene': ('ekshibisjonist',),
'ekshibisjonister': ('ekshibisjonist',),
'eksil': ('eksil',),
'eksila': ('eksil',),
'eksilene': ('eksil',),
'eksiler': ('eksil',),
'eksilet': ('eksil',),
'eksillitteratur': ('eksillitteratur',),
'eksillitteraturen': ('eksillitteratur',),
'eksillitteraturene': ('eksillitteratur',),
'eksillitteraturer': ('eksillitteratur',),
'eksilpolitiker': ('eksilpolitiker',),
'eksilpolitikere': ('eksilpolitiker',),
'eksilpolitikeren': ('eksilpolitiker',),
'eksilpolitikerer': ('eksilpolitiker',),
'eksilpolitikerne': ('eksilpolitiker',),
'eksilregjering': ('eksilregjering',),
'eksilregjeringa': ('eksilregjering',),
'eksilregjeringen': ('eksilregjering',),
'eksilregjeringene': ('eksilregjering',),
'eksilregjeringer': ('eksilregjering',),
'eksis': ('eksis',),
'eksisen': ('eksis',),
'eksisene': ('eksis',),
'eksiser': ('eksis',),
'eksistens': ('eksistens',),
'eksistensen': ('eksistens',),
'eksistensene': ('eksistens',),
'eksistenser': ('eksistens',),
'eksistensberettigelse': ('eksistensberettigelse',),
'eksistensberettigelsen': ('eksistensberettigelse',),
'eksistensberettigelsene': ('eksistensberettigelse',),
'eksistensberettigelser': ('eksistensberettigelse',),
'eksistensfilosof': ('eksistensfilosof',),
'eksistensfilosofen': ('eksistensfilosof',),
'eksistensfilosofene': ('eksistensfilosof',),
'eksistensfilosofer': ('eksistensfilosof',),
'eksistensgrunnlag': ('eksistensgrunnlag',),
'eksistensgrunnlaga': ('eksistensgrunnlag',),
'eksistensgrunnlagene': ('eksistensgrunnlag',),
'eksistensgrunnlaget': ('eksistensgrunnlag',),
'eksistensialisme': ('eksistensialisme',),
'eksistensialismen': ('eksistensialisme',),
'eksistensialismene': ('eksistensialisme',),
'eksistensialismer': ('eksistensialisme',),
'eksistensialist': ('eksistensialist',),
'eksistensialisten': ('eksistensialist',),
'eksistensialistene': ('eksistensialist',),
'eksistensialister': ('eksistensialist',),
'eksistensminimum': ('eksistensminimum',),
'eksistensminimuma': ('eksistensminimum',),
'eksistensminimumene': ('eksistensminimum',),
'eksistensminimumet': ('eksistensminimum',),
'eksistensmulighet': ('eksistensmulighet',),
'eksistensmuligheta': ('eksistensmulighet',),
'eksistensmuligheten': ('eksistensmulighet',),
'eksistensmulighetene': ('eksistensmulighet',),
'eksistensmuligheter': ('eksistensmulighet',),
'eksklamasjon': ('eksklamasjon',),
'eksklamasjonen': ('eksklamasjon',),
'eksklamasjonene': ('eksklamasjon',),
'eksklamasjoner': ('eksklamasjon',),
'eksklusivitet': ('eksklusivitet',),
'eksklusiviteten': ('eksklusivitet',),
'eksklusivitetene': ('eksklusivitet',),
'eksklusiviteter': ('eksklusivitet',),
'eksklusjon': ('eksklusjon',),
'eksklusjonen': ('eksklusjon',),
'eksklusjonene': ('eksklusjon',),
'eksklusjoner': ('eksklusjon',),
'ekskommunikasjon': ('ekskommunikasjon',),
'ekskommunikasjonen': ('ekskommunikasjon',),
'ekskommunikasjonene': ('ekskommunikasjon',),
'ekskommunikasjoner': ('ekskommunikasjon',),
'ekskona': ('ekskone',),
'ekskone': ('ekskone',),
'ekskonen': ('ekskone',),
'ekskonene': ('ekskone',),
'ekskoner': ('ekskone',),
'ekskonge': ('ekskonge',),
'ekskongen': ('ekskonge',),
'ekskongene': ('ekskonge',),
'ekskonger': ('ekskonge',),
'ekskrement': ('ekskrement',),
'ekskrementa': ('ekskrement',),
'ekskrementene': ('ekskrement',),
'ekskrementer': ('ekskrement',),
'ekskrementet': ('ekskrement',),
'ekskresjon': ('ekskresjon',),
'ekskresjonen': ('ekskresjon',),
'ekskresjonene': ('ekskresjon',),
'ekskresjoner': ('ekskresjon',),
'ekskret': ('ekskret',),
'ekskreta': ('ekskret',),
'ekskretene': ('ekskret',),
'ekskreter': ('ekskret',),
'ekskretet': ('ekskret',),
'ekskurs': ('ekskurs',),
'ekskursa': ('ekskurs',),
'ekskursen': ('ekskurs',),
'ekskursene': ('ekskurs',),
'ekskurser': ('ekskurs',),
'ekskurset': ('ekskurs',),
'ekskursjon': ('ekskursjon',),
'ekskursjonen': ('ekskursjon',),
'ekskursjonene': ('ekskursjon',),
'ekskursjoner': ('ekskursjon',),
'ekslibris': ('ekslibris',),
'ekslibrisa': ('ekslibris',),
'ekslibrisene': ('ekslibris',),
'ekslibriser': ('ekslibris',),
'ekslibriset': ('ekslibris',),
'eksmann': ('eksmann',),
'eksmannen': ('eksmann',),
'eksmenn': ('eksmann',),
'eksmennene': ('eksmann',),
'eksodus': ('eksodus',),
'eksodusen': ('eksodus',),
'eksodusene': ('eksodus',),
'eksoduser': ('eksodus',),
'eksorsisme': ('eksorsisme',),
'eksorsismen': ('eksorsisme',),
'eksorsismene': ('eksorsisme',),
'eksorsismer': ('eksorsisme',),
'eksorsist': ('eksorsist',),
'eksorsisten': ('eksorsist',),
'eksorsistene': ('eksorsist',),
'eksorsister': ('eksorsist',),
'eksos': ('eksos',),
'eksosen': ('eksos',),
'eksosene': ('eksos',),
'eksoser': ('eksos',),
'eksosforgiftning': ('eksosforgiftning',),
'eksosforgiftninga': ('eksosforgiftning',),
'eksosforgiftningen': ('eksosforgiftning',),
'eksosforgiftningene': ('eksosforgiftning',),
'eksosforgiftninger': ('eksosforgiftning',),
'eksoskanal': ('eksoskanal',),
'eksoskanalen': ('eksoskanal',),
'eksoskanalene': ('eksoskanal',),
'eksoskanaler': ('eksoskanal',),
'eksospotta': ('eksospotte',),
'eksospotte': ('eksospotte',),
'eksospotten': ('eksospotte',),
'eksospottene': ('eksospotte',),
'eksospotter': ('eksospotte',),
'eksosrør': ('eksosrør',),
'eksosrøra': ('eksosrør',),
'eksosrørene': ('eksosrør',),
'eksosrøret': ('eksosrør',),
'eksotisme': ('eksotisme',),
'eksotismen': ('eksotisme',),
'eksotismene': ('eksotisme',),
'eksotismer': ('eksotisme',),
'ekspansjon': ('ekspansjon',),
'ekspansjonen': ('ekspansjon',),
'ekspansjonene': ('ekspansjon',),
'ekspansjoner': ('ekspansjon',),
'ekspansjonsområda': ('ekspansjonsområde',),
'ekspansjonsområde': ('ekspansjonsområde',),
'ekspansjonsområdene': ('ekspansjonsområde',),
'ekspansjonsområder': ('ekspansjonsområde',),
'ekspansjonsområdet': ('ekspansjonsområde',),
'ekspansjonsplugg': ('ekspansjonsplugg',),
'ekspansjonspluggen': ('ekspansjonsplugg',),
'ekspansjonspluggene': ('ekspansjonsplugg',),
'ekspansjonsplugger': ('ekspansjonsplugg',),
'ekspansjonspolitikk': ('ekspansjonspolitikk',),
'ekspansjonspolitikken': ('ekspansjonspolitikk',),
'ekspansjonspolitikkene': ('ekspansjonspolitikk',),
'ekspansjonspolitikker': ('ekspansjonspolitikk',),
'ekspansjonstrang': ('ekspansjonstrang',),
'ekspansjonstrangen': ('ekspansjonstrang',),
'ekspansjonstrangene': ('ekspansjonstrang',),
'ekspansjonstranger': ('ekspansjonstrang',),
'ekspedisjon': ('ekspedisjon',),
'ekspedisjonen': ('ekspedisjon',),
'ekspedisjonene': ('ekspedisjon',),
'ekspedisjoner': ('ekspedisjon',),
'ekspedisjonsgebyr': ('ekspedisjonsgebyr',),
'ekspedisjonsgebyra': ('ekspedisjonsgebyr',),
'ekspedisjonsgebyrene': ('ekspedisjonsgebyr',),
'ekspedisjonsgebyrer': ('ekspedisjonsgebyr',),
'ekspedisjonsgebyret': ('ekspedisjonsgebyr',),
'ekspedisjonsluka': ('ekspedisjonsluke',),
'ekspedisjonsluke': ('ekspedisjonsluke',),
'ekspedisjonsluken': ('ekspedisjonsluke',),
'ekspedisjonslukene': ('ekspedisjonsluke',),
'ekspedisjonsluker': ('ekspedisjonsluke',),
'ekspedisjonssjef': ('ekspedisjonssjef',),
'ekspedisjonssjefen': ('ekspedisjonssjef',),
'ekspedisjonssjefene': ('ekspedisjonssjef',),
'ekspedisjonssjefer': ('ekspedisjonssjef',),
'ekspedisjonssjefsstilling': ('ekspedisjonssjefsstilling',),
'ekspedisjonssjefsstillinga': ('ekspedisjonssjefsstilling',),
'ekspedisjonssjefsstillingen': ('ekspedisjonssjefsstilling',),
'ekspedisjonssjefsstillingene': ('ekspedisjonssjefsstilling',),
'ekspedisjonssjefsstillinger': ('ekspedisjonssjefsstilling',),
'ekspedisjonssjefstilling': ('ekspedisjonssjefstilling',),
'ekspedisjonssjefstillinga': ('ekspedisjonssjefstilling',),
'ekspedisjonssjefstillingen': ('ekspedisjonssjefstilling',),
'ekspedisjonssjefstillingene': ('ekspedisjonssjefstilling',),
'ekspedisjonssjefstillinger': ('ekspedisjonssjefstilling',),
'ekspeditrisa': ('ekspeditrise',),
'ekspeditrise': ('ekspeditrise',),
'ekspeditrisen': ('ekspeditrise',),
'ekspeditrisene': ('ekspeditrise',),
'ekspeditriser': ('ekspeditrise',),
'ekspeditør': ('ekspeditør',),
'ekspeditøren': ('ekspeditør',),
'ekspeditørene': ('ekspeditør',),
'ekspeditører': ('ekspeditør',),
'ekspektanse': ('ekspektanse',),
'ekspektansen': ('ekspektanse',),
'ekspektansene': ('ekspektanse',),
'ekspektanser': ('ekspektanse',),
'ekspektanselista': ('ekspektanseliste',),
'ekspektanseliste': ('ekspektanseliste',),
'ekspektanselisten': ('ekspektanseliste',),
'ekspektanselistene': ('ekspektanseliste',),
'ekspektanselister': ('ekspektanseliste',),
'ekspektant': ('ekspektant',),
'ekspektanten': ('ekspektant',),
'ekspektantene': ('ekspektant',),
'ekspektanter': ('ekspektant',),
'eksperiment': ('eksperiment',),
'eksperimenta': ('eksperiment',),
'eksperimentene': ('eksperiment',),
'eksperimenter': ('eksperiment',),
'eksperimentet': ('eksperiment',),
'eksperimentalbiologi': ('eksperimentalbiologi',),
'eksperimentalbiologien': ('eksperimentalbiologi',),
'eksperimentalbiologiene': ('eksperimentalbiologi',),
'eksperimentalbiologier': ('eksperimentalbiologi',),
'eksperimentalpedagogikk': ('eksperimentalpedagogikk',),
'eksperimentalpedagogikken': ('eksperimentalpedagogikk',),
'eksperimentalpedagogikkene': ('eksperimentalpedagogikk',),
'eksperimentalpedagogikker': ('eksperimentalpedagogikk',),
'eksperimentalpsykologi': ('eksperimentalpsykologi',),
'eksperimentalpsykologien': ('eksperimentalpsykologi',),
'eksperimentalpsykologiene': ('eksperimentalpsykologi',),
'eksperimentalpsykologier': ('eksperimentalpsykologi',),
'eksperimentalvitenskap': ('eksperimentalvitenskap',),
'eksperimentalvitenskapen': ('eksperimentalvitenskap',),
'eksperimentalvitenskapene': ('eksperimentalvitenskap',),
'eksperimentalvitenskaper': ('eksperimentalvitenskap',),
'eksperimentator': ('eksperimentator',),
'eksperimentatoren': ('eksperimentator',),
'eksperimentatorene': ('eksperimentator',),
'eksperimentatorer': ('eksperimentator',),
'eksperimentfilm': ('eksperimentfilm',),
'eksperimentfilmen': ('eksperimentfilm',),
'eksperimentfilmene': ('eksperimentfilm',),
'eksperimentfilmer': ('eksperimentfilm',),
'eksperimentstadia': ('eksperimentstadium',),
'eksperimentstadiene': ('eksperimentstadium',),
'eksperimentstadier': ('eksperimentstadium',),
'eksperimentstadiet': ('eksperimentstadium',),
'eksperimentstadium': ('eksperimentstadium',),
'eksperimentteater': ('eksperimentteater',),
'eksperimentteateret': ('eksperimentteater',),
'eksperimentteatra': ('eksperimentteater',),
'eksperimentteatre': ('eksperimentteater',),
'eksperimentteatrene': ('eksperimentteater',),
'eksperimentteatret': ('eksperimentteater',),
'ekspert': ('ekspert',),
'eksperten': ('ekspert',),
'ekspertene': ('ekspert',),
'eksperter': ('ekspert',),
'ekspertgruppa': ('ekspertgruppe',),
'ekspertgruppe': ('ekspertgruppe',),
'ekspertgruppen': ('ekspertgruppe',),
'ekspertgruppene': ('ekspertgruppe',),
'ekspertgrupper': ('ekspertgruppe',),
'eksperthjelp': ('eksperthjelp',),
'eksperthjelpa': ('eksperthjelp',),
'eksperthjelpen': ('eksperthjelp',),
'eksperthjelpene': ('eksperthjelp',),
'eksperthjelper': ('eksperthjelp',),
'ekspertise': ('ekspertise',),
'ekspertisen': ('ekspertise',),
'ekspertisene': ('ekspertise',),
'ekspertiser': ('ekspertise',),
'ekspertsamfunn': ('ekspertsamfunn',),
'ekspertsamfunna': ('ekspertsamfunn',),
'ekspertsamfunnene': ('ekspertsamfunn',),
'ekspertsamfunnet': ('ekspertsamfunn',),
'ekspertstyra': ('ekspertstyre',),
'ekspertstyre': ('ekspertstyre',),
'ekspertstyrene': ('ekspertstyre',),
'ekspertstyrer': ('ekspertstyre',),
'ekspertstyret': ('ekspertstyre',),
'ekspertvelda': ('ekspertvelde',),
'ekspertvelde': ('ekspertvelde',),
'ekspertveldene': ('ekspertvelde',),
'ekspertvelder': ('ekspertvelde',),
'ekspertveldet': ('ekspertvelde',),
'ekspirasjon': ('ekspirasjon',),
'ekspirasjonen': ('ekspirasjon',),
'ekspirasjonene': ('ekspirasjon',),
'ekspirasjoner': ('ekspirasjon',),
'eksplementvinkel': ('eksplementvinkel',),
'eksplementvinkelen': ('eksplementvinkel',),
'eksplementvinklene': ('eksplementvinkel',),
'eksplementvinkler': ('eksplementvinkel',),
'eksplosiv': ('eksplosiv',),
'eksplosiva': ('eksplosiv',),
'eksplosivene': ('eksplosiv',),
'eksplosiver': ('eksplosiv',),
'eksplosivet': ('eksplosiv',),
'eksplosjon': ('eksplosjon',),
'eksplosjonen': ('eksplosjon',),
'eksplosjonene': ('eksplosjon',),
'eksplosjoner': ('eksplosjon',),
'eksplosjonsfare': ('eksplosjonsfare',),
'eksplosjonsfaren': ('eksplosjonsfare',),
'eksplosjonsfarene': ('eksplosjonsfare',),
'eksplosjonsfarer': ('eksplosjonsfare',),
'eksplosjonsmotor': ('eksplosjonsmotor',),
'eksplosjonsmotoren': ('eksplosjonsmotor',),
'eksplosjonsmotorene': ('eksplosjonsmotor',),
'eksplosjonsmotorer': ('eksplosjonsmotor',),
'eksponent': ('eksponent',),
'eksponenten': ('eksponent',),
'eksponentene': ('eksponent',),
'eksponenter': ('eksponent',),
'eksponentialligning': ('eksponentialligning',),
'eksponentialligninga': ('eksponentialligning',),
'eksponentialligningen': ('eksponentialligning',),
'eksponentialligningene': ('eksponentialligning',),
'eksponentialligninger': ('eksponentialligning',),
'eksponentiallikning': ('eksponentiallikning',),
'eksponentiallikninga': ('eksponentiallikning',),
'eksponentiallikningen': ('eksponentiallikning',),
'eksponentiallikningene': ('eksponentiallikning',),
'eksponentiallikninger': ('eksponentiallikning',),
'eksponeringshastighet': ('eksponeringshastighet',),
'eksponeringshastigheta': ('eksponeringshastighet',),
'eksponeringshastigheten': ('eksponeringshastighet',),
'eksponeringshastighetene': ('eksponeringshastighet',),
'eksponeringshastigheter': ('eksponeringshastighet',),
'eksponeringsmåler': ('eksponeringsmåler',),
'eksponeringsmålere': ('eksponeringsmåler',),
'eksponeringsmåleren': ('eksponeringsmåler',),
'eksponeringsmålerer': ('eksponeringsmåler',),
'eksponeringsmålerne': ('eksponeringsmåler',),
'eksponeringstid': ('eksponeringstid',),
'eksponeringstida': ('eksponeringstid',),
'eksponeringstiden': ('eksponeringstid',),
'eksponeringstidene': ('eksponeringstid',),
'eksponeringstider': ('eksponeringstid',),
'eksport': ('eksport',),
'eksporten': ('eksport',),
'eksportene': ('eksport',),
'eksporter': ('eksport',),
'eksportartikkel': ('eksportartikkel',),
'eksportartikkelen': ('eksportartikkel',),
'eksportartiklene': ('eksportartikkel',),
'eksportartikler': ('eksportartikkel',),
'eksportavgift': ('eksportavgift',),
'eksportavgifta': ('eksportavgift',),
'eksportavgiften': ('eksportavgift',),
'eksportavgiftene': ('eksportavgift',),
'eksportavgifter': ('eksportavgift',),
'eksportbedrift': ('eksportbedrift',),
'eksportbedriften': ('eksportbedrift',),
'eksportbedriftene': ('eksportbedrift',),
'eksportbedrifter': ('eksportbedrift',),
'eksportfirma': ('eksportfirma',),
'eksportfirmaene': ('eksportfirma',),
'eksportfirmaer': ('eksportfirma',),
'eksportfirmaet': ('eksportfirma',),
'eksportforbud': ('eksportforbud',),
'eksportforbuda': ('eksportforbud',),
'eksportforbudene': ('eksportforbud',),
'eksportforbudet': ('eksportforbud',),
'eksportgaranti': ('eksportgaranti',),
'eksportgarantien': ('eksportgaranti',),
'eksportgarantiene': ('eksportgaranti',),
'eksportgarantier': ('eksportgaranti',),
'eksportindustri': ('eksportindustri',),
'eksportindustrien': ('eksportindustri',),
'eksportindustriene': ('eksportindustri',),
'eksportindustrier': ('eksportindustri',),
'eksportmarked': ('eksportmarked',),
'eksportmarkeda': ('eksportmarked',),
'eksportmarkedene': ('eksportmarked',),
'eksportmarkeder': ('eksportmarked',),
'eksportmarkedet': ('eksportmarked',),
'eksportmarknad': ('eksportmarknad',),
'eksportmarknaden': ('eksportmarknad',),
'eksportmarknadene': ('eksportmarknad',),
'eksportmarknader': ('eksportmarknad',),
'eksportvara': ('eksportvare',),
'eksportvare': ('eksportvare',),
'eksportvaren': ('eksportvare',),
'eksportvarene': ('eksportvare',),
'eksportvarer': ('eksportvare',),
'eksportøl': ('eksportøl',),
'eksportøla': ('eksportøl',),
'eksportølene': ('eksportøl',),
'eksportølet': ('eksportøl',),
'eksportør': ('eksportør',),
'eksportøren': ('eksportør',),
'eksportørene': ('eksportør',),
'eksportører': ('eksportør',),
'eksposea': ('eksposé',),
'eksposeene': ('eksposé',),
'eksposeer': ('eksposé',),
'eksposeet': ('eksposé',),
'eksposé': ('eksposé',),
'eksposéa': ('eksposé',),
'eksposéene': ('eksposé',),
'eksposéer': ('eksposé',),
'eksposéet': ('eksposé',),
'eksposisjon': ('eksposisjon',),
'eksposisjonen': ('eksposisjon',),
'eksposisjonene': ('eksposisjon',),
'eksposisjoner': ('eksposisjon',),
'ekspresident': ('ekspresident',),
'ekspresidenten': ('ekspresident',),
'ekspresidentene': ('ekspresident',),
'ekspresidenter': ('ekspresident',),
'ekspresjonisme': ('ekspresjonisme',),
'ekspresjonismen': ('ekspresjonisme',),
'ekspresjonismene': ('ekspresjonisme',),
'ekspresjonismer': ('ekspresjonisme',),
'ekspresjonist': ('ekspresjonist',),
'ekspresjonisten': ('ekspresjonist',),
'ekspresjonistene': ('ekspresjonist',),
'ekspresjonister': ('ekspresjonist',),
'ekspress': ('ekspress',),
'ekspressen': ('ekspress',),
'ekspressene': ('ekspress',),
'ekspresser': ('ekspress',),
'ekspressbefordring': ('ekspressbefordring',),
'ekspressbefordringa': ('ekspressbefordring',),
'ekspressbefordringen': ('ekspressbefordring',),
'ekspressbefordringene': ('ekspressbefordring',),
'ekspressbefordringer': ('ekspressbefordring',),
'ekspressgods': ('ekspressgods',),
'ekspressgodsa': ('ekspressgods',),
'ekspressgodsene': ('ekspressgods',),
'ekspressgodset': ('ekspressgods',),
'ekspressivitet': ('ekspressivitet',),
'ekspressiviteten': ('ekspressivitet',),
'ekspressivitetene': ('ekspressivitet',),
'ekspressiviteter': ('ekspressivitet',),
'ekspresstog': ('ekspresstog',),
'ekspresstoga': ('ekspresstog',),
'ekspresstogene': ('ekspresstog',),
'ekspresstoget': ('ekspresstog',),
'ekspropriasjon': ('ekspropriasjon',),
'ekspropriasjonen': ('ekspropriasjon',),
'ekspropriasjonene': ('ekspropriasjon',),
'ekspropriasjoner': ('ekspropriasjon',),
'ekspropriasjonslov': ('ekspropriasjonslov',),
'ekspropriasjonsloven': ('ekspropriasjonslov',),
'ekspropriasjonslovene': ('ekspropriasjonslov',),
'ekspropriasjonslover': ('ekspropriasjonslov',),
'ekspropriasjonssak': ('ekspropriasjonssak',),
'ekspropriasjonssaka': ('ekspropriasjonssak',),
'ekspropriasjonssaken': ('ekspropriasjonssak',),
'ekspropriasjonssakene': ('ekspropriasjonssak',),
'ekspropriasjonssaker': ('ekspropriasjonssak',),
'ekstase': ('ekstase',),
'ekstasen': ('ekstase',),
'ekstasene': ('ekstase',),
'ekstaser': ('ekstase',),
'ekstatiker': ('ekstatiker',),
'ekstatikere': ('ekstatiker',),
'ekstatikeren': ('ekstatiker',),
'ekstatikerer': ('ekstatiker',),
'ekstatikerne': ('ekstatiker',),
'ekstemporallesing': ('ekstemporallesing',),
'ekstemporallesinga': ('ekstemporallesing',),
'ekstemporallesingen': ('ekstemporallesing',),
'ekstemporallesingene': ('ekstemporallesing',),
'ekstemporallesinger': ('ekstemporallesing',),
'ekstemporallesning': ('ekstemporallesning',),
'ekstemporallesninga': ('ekstemporallesning',),
'ekstemporallesningen': ('ekstemporallesning',),
'ekstemporallesningene': ('ekstemporallesning',),
'ekstemporallesninger': ('ekstemporallesning',),
'ekstensjon': ('ekstensjon',),
'ekstensjonen': ('ekstensjon',),
'ekstensjonene': ('ekstensjon',),
'ekstensjoner': ('ekstensjon',),
'eksteriør': ('eksteriør',),
'eksteriøra': ('eksteriør',),
'eksteriørene': ('eksteriør',),
'eksteriører': ('eksteriør',),
'eksteriøret': ('eksteriør',),
'eksternatskole': ('eksternatskole',),
'eksternatskolen': ('eksternatskole',),
'eksternatskolene': ('eksternatskole',),
'eksternatskoler': ('eksternatskole',),
'eksterritorialrett': ('eksterritorialrett',),
'eksterritorialretten': ('eksterritorialrett',),
'eksterritorialrettene': ('eksterritorialrett',),
'eksterritorialretter': ('eksterritorialrett',),
'ekstraarbeid': ('ekstraarbeid',),
'ekstraarbeida': ('ekstraarbeid',),
'ekstraarbeidene': ('ekstraarbeid',),
'ekstraarbeider': ('ekstraarbeid',),
'ekstraarbeidet': ('ekstraarbeid',),
'ekstraavgang': ('ekstraavgang',),
'ekstraavgangen': ('ekstraavgang',),
'ekstraavgangene': ('ekstraavgang',),
'ekstraavganger': ('ekstraavgang',),
'ekstrabehandling': ('ekstrabehandling',),
'ekstrabehandlinga': ('ekstrabehandling',),
'ekstrabehandlingen': ('ekstrabehandling',),
'ekstrabehandlingene': ('ekstrabehandling',),
'ekstrabehandlinger': ('ekstrabehandling',),
'ekstrabevilgning': ('ekstrabevilgning',),
'ekstrabevilgninga': ('ekstrabevilgning',),
'ekstrabevilgningen': ('ekstrabevilgning',),
'ekstrabevilgningene': ('ekstrabevilgning',),
'ekstrabevilgninger': ('ekstrabevilgning',),
'ekstrabuss': ('ekstrabuss',),
'ekstrabussen': ('ekstrabuss',),
'ekstrabussene': ('ekstrabuss',),
'ekstrabusser': ('ekstrabuss',),
'ekstraforpleining': ('ekstraforpleining',),
'ekstraforpleininga': ('ekstraforpleining',),
'ekstraforpleiningen': ('ekstraforpleining',),
'ekstraforpleiningene': ('ekstraforpleining',),
'ekstraforpleininger': ('ekstraforpleining',),
'ekstragoda': ('ekstragode',),
'ekstragode': ('ekstragode',),
'ekstragodene': ('ekstragode',),
'ekstragoder': ('ekstragode',),
'ekstragodet': ('ekstragode',),
'ekstrakt': ('ekstrakt',),
'ekstrakten': ('ekstrakt',),
'ekstraktene': ('ekstrakt',),
'ekstrakter': ('ekstrakt',),
'ekstrakt': ('ekstrakt',),
'ekstrakta': ('ekstrakt',),
'ekstraktene': ('ekstrakt',),
'ekstrakter': ('ekstrakt',),
'ekstraktet': ('ekstrakt',),
'ekstranummer': ('ekstranummer',),
'ekstranummeret': ('ekstranummer',),
'ekstranumra': ('ekstranummer',),
'ekstranumre': ('ekstranummer',),
'ekstranumrene': ('ekstranummer',),
'ekstraomgang': ('ekstraomgang',),
'ekstraomgangen': ('ekstraomgang',),
'ekstraomgangene': ('ekstraomgang',),
'ekstraomganger': ('ekstraomgang',),
'ekstraposisjon': ('ekstraposisjon',),
'ekstraposisjonen': ('ekstraposisjon',),
'ekstraposisjonene': ('ekstraposisjon',),
'ekstraposisjoner': ('ekstraposisjon',),
'ekstraskilling': ('ekstraskilling',),
'ekstraskillingen': ('ekstraskilling',),
'ekstraskillingene': ('ekstraskilling',),
'ekstraskillinger': ('ekstraskilling',),
'ekstratog': ('ekstratog',),
'ekstratoga': ('ekstratog',),
'ekstratogene': ('ekstratog',),
'ekstratoget': ('ekstratog',),
'ekstrautgava': ('ekstrautgave',),
'ekstrautgave': ('ekstrautgave',),
'ekstrautgaven': ('ekstrautgave',),
'ekstrautgavene': ('ekstrautgave',),
'ekstrautgaver': ('ekstrautgave',),
'ekstrautgift': ('ekstrautgift',),
'ekstrautgifta': ('ekstrautgift',),
'ekstrautgiften': ('ekstrautgift',),
'ekstrautgiftene': ('ekstrautgift',),
'ekstrautgifter': ('ekstrautgift',),
'ekstravaganse': ('ekstravaganse',),
'ekstravagansen': ('ekstravaganse',),
'ekstravagansene': ('ekstravaganse',),
'ekstravaganser': ('ekstravaganse',),
'ekstrem': ('ekstrem',),
'ekstrema': ('ekstrem',),
'ekstremene': ('ekstrem',),
'ekstremer': ('ekstrem',),
'ekstremet': ('ekstrem',),
'ekstremisme': ('ekstremisme',),
'ekstremismen': ('ekstremisme',),
'ekstremismene': ('ekstremisme',),
'ekstremismer': ('ekstremisme',),
'ekstremist': ('ekstremist',),
'ekstremisten': ('ekstremist',),
'ekstremistene': ('ekstremist',),
'ekstremister': ('ekstremist',),
'ekstremitet': ('ekstremitet',),
'ekstremiteten': ('ekstremitet',),
'ekstremitetene': ('ekstremitet',),
'ekstremiteter': ('ekstremitet',),
'ekte': ('ekte',),
'ektefelle': ('ektefelle',),
'ektefellen': ('ektefelle',),
'ektefellene': ('ektefelle',),
'ektefeller': ('ektefelle',),
'ektefolk': ('ektefolk',),
'ektefolka': ('ektefolk',),
'ektefolkene': ('ektefolk',),
'ektefolket': ('ektefolk',),
'ektemake': ('ektemake',),
'ektemaken': ('ektemake',),
'ektemakene': ('ektemake',),
'ektemaker': ('ektemake',),
'ektemann': ('ektemann',),
'ektemannen': ('ektemann',),
'ektemenn': ('ektemann',),
'ektemennene': ('ektemann',),
'ektepakt': ('ektepakt',),
'ektepakta': ('ektepakt',),
'ektepakten': ('ektepakt',),
'ektepaktene': ('ektepakt',),
'ektepakter': ('ektepakt',),
'ektepar': ('ektepar',),
'ektepara': ('ektepar',),
'ekteparene': ('ektepar',),
'ekteparet': ('ektepar',),
'ekteseng': ('ekteseng',),
'ektesenga': ('ekteseng',),
'ektesengen': ('ekteseng',),
'ektesengene': ('ekteseng',),
'ektesenger': ('ekteseng',),
'ekteskap': ('ekteskap',),
'ekteskapa': ('ekteskap',),
'ekteskapene': ('ekteskap',),
'ekteskaper': ('ekteskap',),
'ekteskapet': ('ekteskap',),
'ekteskapsbrott': ('ekteskapsbrott',),
'ekteskapsbrotta': ('ekteskapsbrott',),
'ekteskapsbrottene': ('ekteskapsbrott',),
'ekteskapsbrottet': ('ekteskapsbrott',),
'ekteskapsbrudd': ('ekteskapsbrudd',),
'ekteskapsbrudda': ('ekteskapsbrudd',),
'ekteskapsbruddene': ('ekteskapsbrudd',),
'ekteskapsbruddet': ('ekteskapsbrudd',),
'ekteskapsbyrå': ('ekteskapsbyrå',),
'ekteskapsbyråa': ('ekteskapsbyrå',),
'ekteskapsbyråene': ('ekteskapsbyrå',),
'ekteskapsbyråer': ('ekteskapsbyrå',),
'ekteskapsbyrået': ('ekteskapsbyrå',),
'ekteskapskandidat': ('ekteskapskandidat',),
'ekteskapskandidaten': ('ekteskapskandidat',),
'ekteskapskandidatene': ('ekteskapskandidat',),
'ekteskapskandidater': ('ekteskapskandidat',),
'ekteskapsløfta': ('ekteskapsløfte',),
'ekteskapsløfte': ('ekteskapsløfte',),
'ekteskapsløftene': ('ekteskapsløfte',),
'ekteskapsløfter': ('ekteskapsløfte',),
'ekteskapsløftet': ('ekteskapsløfte',),
'ekteskapstilbud': ('ekteskapstilbud',),
'ekteskapstilbuda': ('ekteskapstilbud',),
'ekteskapstilbudene': ('ekteskapstilbud',),
'ekteskapstilbudet': ('ekteskapstilbud',),
'ektestand': ('ektestand',),
'ektestanden': ('ektestand',),
'ektestandene': ('ektestand',),
'ektestander': ('ektestand',),
'ekthet': ('ekthet',),
'ektheta': ('ekthet',),
'ektheten': ('ekthet',),
'ekthetene': ('ekthet',),
'ektheter': ('ekthet',),
'ektoderm': ('ektoderm',),
'ektodermen': ('ektoderm',),
'ektodermene': ('ektoderm',),
'ektodermer': ('ektoderm',),
'ekvator': ('ekvator',),
'ekvatoren': ('ekvator',),
'ekvatorene': ('ekvator',),
'ekvatorer': ('ekvator',),
'ekvatorgrad': ('ekvatorgrad',),
'ekvatorgraden': ('ekvatorgrad',),
'ekvatorgradene': ('ekvatorgrad',),
'ekvatorgrader': ('ekvatorgrad',),
'ekvatorialbelta': ('ekvatorialbelte',),
'ekvatorialbelte': ('ekvatorialbelte',),
'ekvatorialbeltene': ('ekvatorialbelte',),
'ekvatorialbelter': ('ekvatorialbelte',),
'ekvatorialbeltet': ('ekvatorialbelte',),
'ekvatorialguineaner': ('ekvatorialguineaner',),
'ekvatorialguineanere': ('ekvatorialguineaner',),
'ekvatorialguineaneren': ('ekvatorialguineaner',),
'ekvatorialguineanerer': ('ekvatorialguineaner',),
'ekvatorialguineanerne': ('ekvatorialguineaner',),
'ekvidistanse': ('ekvidistanse',),
'ekvidistansen': ('ekvidistanse',),
'ekvidistansene': ('ekvidistanse',),
'ekvidistanser': ('ekvidistanse',),
'ekvilibrist': ('ekvilibrist',),
'ekvilibristen': ('ekvilibrist',),
'ekvilibristene': ('ekvilibrist',),
'ekvilibrister': ('ekvilibrist',),
'ekvipasje': ('ekvipasje',),
'ekvipasjen': ('ekvipasje',),
'ekvipasjene': ('ekvipasje',),
'ekvipasjer': ('ekvipasje',),
'ekvipering': ('ekvipering',),
'ekviperinga': ('ekvipering',),
'ekviperingen': ('ekvipering',),
'ekviperingene': ('ekvipering',),
'ekviperinger': ('ekvipering',),
'ekviperingsforretning': ('ekviperingsforretning',),
'ekviperingsforretninga': ('ekviperingsforretning',),
'ekviperingsforretningen': ('ekviperingsforretning',),
'ekviperingsforretningene': ('ekviperingsforretning',),
'ekviperingsforretninger': ('ekviperingsforretning',),
'ekvivalens': ('ekvivalens',),
'ekvivalensen': ('ekvivalens',),
'ekvivalensene': ('ekvivalens',),
'ekvivalenser': ('ekvivalens',),
'ekvivalent': ('ekvivalent',),
'ekvivalenten': ('ekvivalent',),
'ekvivalentene': ('ekvivalent',),
'ekvivalenter': ('ekvivalent',),
'ekvivalentvekt': ('ekvivalentvekt',),
'ekvivalentvekta': ('ekvivalentvekt',),
'ekvivalentvekten': ('ekvivalentvekt',),
'ekvivalentvektene': ('ekvivalentvekt',),
'ekvivalentvekter': ('ekvivalentvekt',),
'el': ('el',),
'ela': ('el',),
'elene': ('el',),
'elet': ('el',),
'elan': ('elan',),
'elanen': ('elan',),
'elanene': ('elan',),
'elaner': ('elan',),
'eland': ('eland',),
'elanden': ('eland',),
'elandene': ('eland',),
'elander': ('eland',),
'elastikk': ('elastikk',),
'elastikken': ('elastikk',),
'elastikkene': ('elastikk',),
'elastikker': ('elastikk',),
'elastisitet': ('elastisitet',),
'elastisiteten': ('elastisitet',),
'elastisitetene': ('elastisitet',),
'elastisiteter': ('elastisitet',),
'elbass': ('elbass',),
'elbassen': ('elbass',),
'elbassene': ('elbass',),
'elbasser': ('elbass',),
'elbil': ('elbil',),
'elbilen': ('elbil',),
'elbilene': ('elbil',),
'elbiler': ('elbil',),
'elbuss': ('elbuss',),
'elbussen': ('elbuss',),
'elbussene': ('elbuss',),
'elbusser': ('elbuss',),
'eld': ('eld',),
'elden': ('eld',),
'eldene': ('eld',),
'elder': ('eld',),
'eld': ('eld',),
'elden': ('eld',),
'eldene': ('eld',),
'elder': ('eld',),
'elddåp': ('elddåp',),
'elddåpen': ('elddåp',),
'elddåpene': ('elddåp',),
'elddåper': ('elddåp',),
'elddåp': ('elddåp',),
'elddåpen': ('elddåp',),
'elddåpene': ('elddåp',),
'elddåper': ('elddåp',),
'elde': ('elde',),
'elden': ('elde',),
'eldene': ('elde',),
'elder': ('elde',),
'eldflua': ('eldflue',),
'eldflue': ('eldflue',),
'eldfluen': ('eldflue',),
'eldfluene': ('eldflue',),
'eldfluer': ('eldflue',),
'eldflua': ('eldflue',),
'eldflue': ('eldflue',),
'eldfluen': ('eldflue',),
'eldfluene': ('eldflue',),
'eldfluer': ('eldflue',),
'eldgiing': ('eldgiing',),
'eldgiinga': ('eldgiing',),
'eldgiingen': ('eldgiing',),
'eldgiingene': ('eldgiing',),
'eldgiinger': ('eldgiing',),
'eldgiing': ('eldgiing',),
'eldgiinga': ('eldgiing',),
'eldgiingen': ('eldgiing',),
'eldgiingene': ('eldgiing',),
'eldgiinger': ('eldgiing',),
'eldgiving': ('eldgiving',),
'eldgivinga': ('eldgiving',),
'eldgivingen': ('eldgiving',),
'eldgivingene': ('eldgiving',),
'eldgivinger': ('eldgiving',),
'eldgiving': ('eldgiving',),
'eldgivinga': ('eldgiving',),
'eldgivingen': ('eldgiving',),
'eldgivingene': ('eldgiving',),
'eldgivinger': ('eldgiving',),
'eldgivning': ('eldgivning',),
'eldgivninga': ('eldgivning',),
'eldgivningen': ('eldgivning',),
'eldgivningene': ('eldgivning',),
'eldgivninger': ('eldgivning',),
'eldgivning': ('eldgivning',),
'eldgivninga': ('eldgivning',),
'eldgivningen': ('eldgivning',),
'eldgivningene': ('eldgivning',),
'eldgivninger': ('eldgivning',),
'eldgud': ('eldgud',),
'eldguden': ('eldgud',),
'eldgudene': ('eldgud',),
'eldguder': ('eldgud',),
'eldgud': ('eldgud',),
'eldguden': ('eldgud',),
'eldgudene': ('eldgud',),
'eldguder': ('eldgud',),
'eldhav': ('eldhav',),
'eldhava': ('eldhav',),
'eldhavene': ('eldhav',),
'eldhavet': ('eldhav',),
'eldhav': ('eldhav',),
'eldhava': ('eldhav',),
'eldhavene': ('eldhav',),
'eldhavet': ('eldhav',),
'eldhug': ('eldhug',),
'eldhugen': ('eldhug',),
'eldhugene': ('eldhug',),
'eldhuger': ('eldhug',),
'eldhus': ('eldhus',),
'eldhusa': ('eldhus',),
'eldhusene': ('eldhus',),
'eldhuset': ('eldhus',),
'eldkraft': ('eldkraft',),
'eldkrafta': ('eldkraft',),
'eldkraften': ('eldkraft',),
'eldkreftene': ('eldkraft',),
'eldkrefter': ('eldkraft',),
'eldkraft': ('eldkraft',),
'eldkrafta': ('eldkraft',),
'eldkraften': ('eldkraft',),
'eldkreftene': ('eldkraft',),
'eldkrefter': ('eldkraft',),
'eldkula': ('eldkule',),
'eldkule': ('eldkule',),
'eldkulen': ('eldkule',),
'eldkulene': ('eldkule',),
'eldkuler': ('eldkule',),
'eldkula': ('eldkule',),
'eldkule': ('eldkule',),
'eldkulen': ('eldkule',),
'eldkulene': ('eldkule',),
'eldkuler': ('eldkule',),
'eldkvede': ('eldkvede',),
'eldkveden': ('eldkvede',),
'eldkvedene': ('eldkvede',),
'eldkveder': ('eldkvede',),
'eldkvede': ('eldkvede',),
'eldkveden': ('eldkvede',),
'eldkvedene': ('eldkvede',),
'eldkveder': ('eldkvede',),
'eldlinja': ('eldlinje',),
'eldlinje': ('eldlinje',),
'eldlinjen': ('eldlinje',),
'eldlinjene': ('eldlinje',),
'eldlinjer': ('eldlinje',),
'eldlinja': ('eldlinje',),
'eldlinje': ('eldlinje',),
'eldlinjen': ('eldlinje',),
'eldlinjene': ('eldlinje',),
'eldlinjer': ('eldlinje',),
'eldmørja': ('eldmørje',),
'eldmørje': ('eldmørje',),
'eldmørjen': ('eldmørje',),
'eldmørjene': ('eldmørje',),
'eldmørjer': ('eldmørje',),
'eldmørja': ('eldmørje',),
'eldmørje': ('eldmørje',),
'eldmørjen': ('eldmørje',),
'eldmørjene': ('eldmørje',),
'eldmørjer': ('eldmørje',),
'eldorado': ('eldorado',),
'eldoradoa': ('eldorado',),
'eldoradoene': ('eldorado',),
'eldoradoer': ('eldorado',),
'eldoradoet': ('eldorado',),
'eldprøva': ('eldprøve',),
'eldprøve': ('eldprøve',),
'eldprøven': ('eldprøve',),
'eldprøvene': ('eldprøve',),
'eldprøver': ('eldprøve',),
'eldprøva': ('eldprøve',),
'eldprøve': ('eldprøve',),
'eldprøven': ('eldprøve',),
'eldprøvene': ('eldprøve',),
'eldprøver': ('eldprøve',),
'eldpåsetter': ('eldpåsetter',),
'eldpåsettere': ('eldpåsetter',),
'eldpåsetteren': ('eldpåsetter',),
'eldpåsetterer': ('eldpåsetter',),
'eldpåsetterne': ('eldpåsetter',),
'eldraka': ('eldrake',),
'eldrake': ('eldrake',),
'eldraken': ('eldrake',),
'eldrakene': ('eldrake',),
'eldraker': ('eldrake',),
'eldraka': ('eldrake',),
'eldrake': ('eldrake',),
'eldraken': ('eldrake',),
'eldrakene': ('eldrake',),
'eldraker': ('eldrake',),
'eldrebolig': ('eldrebolig',),
'eldreboligen': ('eldrebolig',),
'eldreboligene': ('eldrebolig',),
'eldreboliger': ('eldrebolig',),
'eldregn': ('eldregn',),
'eldregna': ('eldregn',),
'eldregnene': ('eldregn',),
'eldregnet': ('eldregn',),
'eldregn': ('eldregn',),
'eldregna': ('eldregn',),
'eldregnene': ('eldregn',),
'eldregnet': ('eldregn',),
'eldreinstitusjon': ('eldreinstitusjon',),
'eldreinstitusjonen': ('eldreinstitusjon',),
'eldreinstitusjonene': ('eldreinstitusjon',),
'eldreinstitusjoner': ('eldreinstitusjon',),
'eldreomsorg': ('eldreomsorg',),
'eldreomsorga': ('eldreomsorg',),
'eldreomsorgen': ('eldreomsorg',),
'eldreomsorgene': ('eldreomsorg',),
'eldreomsorger': ('eldreomsorg',),
'eldresenter': ('eldresenter',),
'eldresenteret': ('eldresenter',),
'eldresentra': ('eldresenter',),
'eldresentre': ('eldresenter',),
'eldresentrene': ('eldresenter',),
'eldresentret': ('eldresenter',),
'eldretreff': ('eldretreff',),
'eldretreffa': ('eldretreff',),
'eldretreffene': ('eldretreff',),
'eldretreffet': ('eldretreff',),
'eldrift': ('eldrift',),
'eldrifta': ('eldrift',),
'eldriften': ('eldrift',),
'eldriftene': ('eldrift',),
'eldrifter': ('eldrift',),
'eldsfare': ('eldsfare',),
'eldsfaren': ('eldsfare',),
'eldsfarene': ('eldsfare',),
'eldsfarer': ('eldsfare',),
'eldsfare': ('eldsfare',),
'eldsfaren': ('eldsfare',),
'eldsfarene': ('eldsfare',),
'eldsfarer': ('eldsfare',),
'eldsjel': ('eldsjel',),
'eldsjela': ('eldsjel',),
'eldsjelen': ('eldsjel',),
'eldsjelene': ('eldsjel',),
'eldsjeler': ('eldsjel',),
'eldsjel': ('eldsjel',),
'eldsjela': ('eldsjel',),
'eldsjelen': ('eldsjel',),
'eldsjelene': ('eldsjel',),
'eldsjeler': ('eldsjel',),
'eldskrift': ('eldskrift',),
'eldskrifta': ('eldskrift',),
'eldskriften': ('eldskrift',),
'eldskriftene': ('eldskrift',),
'eldskrifter': ('eldskrift',),
'eldslys': ('eldslys',),
'eldslysa': ('eldslys',),
'eldslysene': ('eldslys',),
'eldslyset': ('eldslys',),
'eldspåsetter': ('eldspåsetter',),
'eldspåsettere': ('eldspåsetter',),
'eldspåsetteren': ('eldspåsetter',),
'eldspåsetterer': ('eldspåsetter',),
'eldspåsetterne': ('eldspåsetter',),
'eldste': ('eldste',),
'eldsten': ('eldste',),
'eldstene': ('eldste',),
'eldstebroder': ('eldstebroder',),
'eldstebroderen': ('eldstebroder',),
'eldstebrødre': ('eldstebroder',),
'eldstebrødrene': ('eldstebroder',),
'eldsted': ('eldsted',),
'eldstedene': ('eldsted',),
'eldsteder': ('eldsted',),
'eldstedet': ('eldsted',),
'eldsted': ('eldsted',),
'eldstedene': ('eldsted',),
'eldsteder': ('eldsted',),
'eldstedet': ('eldsted',),
'eldstemann': ('eldstemann',),
'eldstemannen': ('eldstemann',),
'eldstemannene': ('eldstemann',),
'eldstemanner': ('eldstemann',),
'eldtunga': ('eldtunge',),
'eldtunge': ('eldtunge',),
'eldtungen': ('eldtunge',),
'eldtungene': ('eldtunge',),
'eldtunger': ('eldtunge',),
'eldtunga': ('eldtunge',),
'eldtunge': ('eldtunge',),
'eldtungen': ('eldtunge',),
'eldtungene': ('eldtunge',),
'eldtunger': ('eldtunge',),
'eldvann': ('eldvann',),
'eldvanna': ('eldvann',),
'eldvannene': ('eldvann',),
'eldvannet': ('eldvann',),
'eldvann': ('eldvann',),
'eldvanna': ('eldvann',),
'eldvannene': ('eldvann',),
'eldvannet': ('eldvann',),
'eldvatn': ('eldvatn',),
'eldvatna': ('eldvatn',),
'eldvatnene': ('eldvatn',),
'eldvatnet': ('eldvatn',),
'eldvogn': ('eldvogn',),
'eldvogna': ('eldvogn',),
'eldvognen': ('eldvogn',),
'eldvognene': ('eldvogn',),
'eldvogner': ('eldvogn',),
'eldvogn': ('eldvogn',),
'eldvogna': ('eldvogn',),
'eldvognen': ('eldvogn',),
'eldvognene': ('eldvogn',),
'eldvogner': ('eldvogn',),
'eldvåpen': ('eldvåpen',),
'eldvåpenet': ('eldvåpen',),
'eldvåpna': ('eldvåpen',),
'eldvåpnene': ('eldvåpen',),
'eldvåpen': ('eldvåpen',),
'eldvåpenet': ('eldvåpen',),
'eldvåpna': ('eldvåpen',),
'eldvåpnene': ('eldvåpen',),
'elefant': ('elefant',),
'elefanten': ('elefant',),
'elefantene': ('elefant',),
'elefanter': ('elefant',),
'elefanthud': ('elefanthud',),
'elefanthuda': ('elefanthud',),
'elefanthuden': ('elefanthud',),
'elefanthudene': ('elefanthud',),
'elefanthuder': ('elefanthud',),
'elefantiasis': ('elefantiasis',),
'elefantiasisen': ('elefantiasis',),
'elefantiasisene': ('elefantiasis',),
'elefantiasiser': ('elefantiasis',),
'elefantsjuka': ('elefantsjuke',),
'elefantsjuke': ('elefantsjuke',),
'elefantsjuken': ('elefantsjuke',),
'elefantsjukene': ('elefantsjuke',),
'elefantsjuker': ('elefantsjuke',),
'elefantskilpadda': ('elefantskilpadde',),
'elefantskilpadde': ('elefantskilpadde',),
'elefantskilpadden': ('elefantskilpadde',),
'elefantskilpaddene': ('elefantskilpadde',),
'elefantskilpadder': ('elefantskilpadde',),
'elefantstøttann': ('elefantstøttann',),
'elefantstøttanna': ('elefantstøttann',),
'elefantstøttannen': ('elefantstøttann',),
'elefantstøttennene': ('elefantstøttann',),
'elefantstøttenner': ('elefantstøttann',),
'elefantstøyttann': ('elefantstøyttann',),
'elefantstøyttanna': ('elefantstøyttann',),
'elefantstøyttannen': ('elefantstøyttann',),
'elefantstøyttennene': ('elefantstøyttann',),
'elefantstøyttenner': ('elefantstøyttann',),
'elefantsyka': ('elefantsyke',),
'elefantsyke': ('elefantsyke',),
'elefantsyken': ('elefantsyke',),
'elefantsykene': ('elefantsyke',),
'elefantsyker': ('elefantsyke',),
'elefanttann': ('elefanttann',),
'elefanttanna': ('elefanttann',),
'elefanttannen': ('elefanttann',),
'elefanttennene': ('elefanttann',),
'elefanttenner': ('elefanttann',),
'eleganse': ('eleganse',),
'elegansen': ('eleganse',),
'elegansene': ('eleganse',),
'eleganser': ('eleganse',),
'elegi': ('elegi',),
'elegien': ('elegi',),
'elegiene': ('elegi',),
'elegier': ('elegi',),
'elegiker': ('elegiker',),
'elegikere': ('elegiker',),
'elegikeren': ('elegiker',),
'elegikerer': ('elegiker',),
'elegikerne': ('elegiker',),
'eleksjon': ('eleksjon',),
'eleksjonen': ('eleksjon',),
'eleksjonene': ('eleksjon',),
'eleksjoner': ('eleksjon',),
'elektorat': ('elektorat',),
'elektorata': ('elektorat',),
'elektoratene': ('elektorat',),
'elektorater': ('elektorat',),
'elektoratet': ('elektorat',),
'elektrakompleks': ('elektrakompleks',),
'elektrakompleksa': ('elektrakompleks',),
'elektrakompleksene': ('elektrakompleks',),
'elektrakomplekser': ('elektrakompleks',),
'elektrakomplekset': ('elektrakompleks',),
'elektriker': ('elektriker',),
'elektrikere': ('elektriker',),
'elektrikeren': ('elektriker',),
'elektrikerer': ('elektriker',),
'elektrikerne': ('elektriker',),
'elektrisermaskin': ('elektrisermaskin',),
'elektrisermaskina': ('elektrisermaskin',),
'elektrisermaskinen': ('elektrisermaskin',),
'elektrisermaskinene': ('elektrisermaskin',),
'elektrisermaskiner': ('elektrisermaskin',),
'elektrisitet': ('elektrisitet',),
'elektrisiteten': ('elektrisitet',),
'elektrisitetene': ('elektrisitet',),
'elektrisiteter': ('elektrisitet',),
'elektrisitetsforsyning': ('elektrisitetsforsyning',),
'elektrisitetsforsyninga': ('elektrisitetsforsyning',),
'elektrisitetsforsyningen': ('elektrisitetsforsyning',),
'elektrisitetsforsyningene': ('elektrisitetsforsyning',),
'elektrisitetsforsyninger': ('elektrisitetsforsyning',),
'elektrisitetslæra': ('elektrisitetslære',),
'elektrisitetslære': ('elektrisitetslære',),
'elektrisitetslæren': ('elektrisitetslære',),
'elektrisitetslærene': ('elektrisitetslære',),
'elektrisitetslærer': ('elektrisitetslære',),
'elektrisitetsmengde': ('elektrisitetsmengde',),
'elektrisitetsmengden': ('elektrisitetsmengde',),
'elektrisitetsmengdene': ('elektrisitetsmengde',),
'elektrisitetsmengder': ('elektrisitetsmengde',),
'elektrisitetsmåler': ('elektrisitetsmåler',),
'elektrisitetsmålere': ('elektrisitetsmåler',),
'elektrisitetsmåleren': ('elektrisitetsmåler',),
'elektrisitetsmålerer': ('elektrisitetsmåler',),
'elektrisitetsmålerne': ('elektrisitetsmåler',),
'elektrisitetsverk': ('elektrisitetsverk',),
'elektrisitetsverka': ('elektrisitetsverk',),
'elektrisitetsverkene': ('elektrisitetsverk',),
'elektrisitetsverker': ('elektrisitetsverk',),
'elektrisitetsverket': ('elektrisitetsverk',),
'elektroanalysa': ('elektroanalyse',),
'elektroanalyse': ('elektroanalyse',),
'elektroanalysen': ('elektroanalyse',),
'elektroanalysene': ('elektroanalyse',),
'elektroanalyser': ('elektroanalyse',),
'elektrode': ('elektrode',),
'elektroden': ('elektrode',),
'elektrodene': ('elektrode',),
'elektroder': ('elektrode',),
'elektrodespenning': ('elektrodespenning',),
'elektrodespenninga': ('elektrodespenning',),
'elektrodespenningen': ('elektrodespenning',),
'elektrodespenningene': ('elektrodespenning',),
'elektrodespenninger': ('elektrodespenning',),
'elektrodestrøm': ('elektrodestrøm',),
'elektrodestrømmen': ('elektrodestrøm',),
'elektrodestrømmene': ('elektrodestrøm',),
'elektrodestrømmer': ('elektrodestrøm',),
'elektrodynamikk': ('elektrodynamikk',),
'elektrodynamikken': ('elektrodynamikk',),
'elektrodynamikkene': ('elektrodynamikk',),
'elektrodynamikker': ('elektrodynamikk',),
'elektrofoni': ('elektrofoni',),
'elektrofonien': ('elektrofoni',),
'elektrofoniene': ('elektrofoni',),
'elektrofonier': ('elektrofoni',),
'elektrohydraulikk': ('elektrohydraulikk',),
'elektrohydraulikken': ('elektrohydraulikk',),
'elektrohydraulikkene': ('elektrohydraulikk',),
'elektrohydraulikker': ('elektrohydraulikk',),
'elektroingeniør': ('elektroingeniør',),
'elektroingeniøren': ('elektroingeniør',),
'elektroingeniørene': ('elektroingeniør',),
'elektroingeniører': ('elektroingeniør',),
'elektrokardiografi': ('elektrokardiografi',),
'elektrokardiografien': ('elektrokardiografi',),
'elektrokardiografiene': ('elektrokardiografi',),
'elektrokardiografier': ('elektrokardiografi',),
'elektrokardiogram': ('elektrokardiogram',),
'elektrokardiogramma': ('elektrokardiogram',),
'elektrokardiogrammene': ('elektrokardiogram',),
'elektrokardiogrammer': ('elektrokardiogram',),
'elektrokardiogrammet': ('elektrokardiogram',),
'elektrokjemi': ('elektrokjemi',),
'elektrokjemien': ('elektrokjemi',),
'elektrokjemiene': ('elektrokjemi',),
'elektrokjemier': ('elektrokjemi',),
'elektrolyse': ('elektrolyse',),
'elektrolysen': ('elektrolyse',),
'elektrolysene': ('elektrolyse',),
'elektrolyser': ('elektrolyse',),
'elektrolytt': ('elektrolytt',),
'elektrolytten': ('elektrolytt',),
'elektrolyttene': ('elektrolytt',),
'elektrolytter': ('elektrolytt',),
'elektromagnet': ('elektromagnet',),
'elektromagneten': ('elektromagnet',),
'elektromagnetene': ('elektromagnet',),
'elektromagneter': ('elektromagnet',),
'elektromagnetisme': ('elektromagnetisme',),
'elektromagnetismen': ('elektromagnetisme',),
'elektromagnetismene': ('elektromagnetisme',),
'elektromagnetismer': ('elektromagnetisme',),
'elektromaskinist': ('elektromaskinist',),
'elektromaskinisten': ('elektromaskinist',),
'elektromaskinistene': ('elektromaskinist',),
'elektromaskinister': ('elektromaskinist',),
'elektrometallurgi': ('elektrometallurgi',),
'elektrometallurgien': ('elektrometallurgi',),
'elektrometallurgiene': ('elektrometallurgi',),
'elektrometallurgier': ('elektrometallurgi',),
'elektrometer': ('elektrometer',),
'elektrometeret': ('elektrometer',),
'elektrometra': ('elektrometer',),
'elektrometre': ('elektrometer',),
'elektrometrene': ('elektrometer',),
'elektrometret': ('elektrometer',),
'elektromotor': ('elektromotor',),
'elektromotoren': ('elektromotor',),
'elektromotorene': ('elektromotor',),
'elektromotorer': ('elektromotor',),
'elektron': ('elektron',),
'elektrona': ('elektron',),
'elektronene': ('elektron',),
'elektroner': ('elektron',),
'elektronet': ('elektron',),
'elektronblits': ('elektronblits',),
'elektronblitsen': ('elektronblits',),
'elektronblitsene': ('elektronblits',),
'elektronblitser': ('elektronblits',),
'elektronhjerne': ('elektronhjerne',),
'elektronhjernen': ('elektronhjerne',),
'elektronhjernene': ('elektronhjerne',),
'elektronhjerner': ('elektronhjerne',),
'elektronikk': ('elektronikk',),
'elektronikken': ('elektronikk',),
'elektronikkene': ('elektronikk',),
'elektronikker': ('elektronikk',),
'elektronmedia': ('elektronmedium',),
'elektronmediene': ('elektronmedium',),
'elektronmedier': ('elektronmedium',),
'elektronmediet': ('elektronmedium',),
'elektronmedium': ('elektronmedium',),
'elektronmikroskop': ('elektronmikroskop',),
'elektronmikroskopa': ('elektronmikroskop',),
'elektronmikroskopene': ('elektronmikroskop',),
'elektronmikroskoper': ('elektronmikroskop',),
'elektronmikroskopet': ('elektronmikroskop',),
'elektronrør': ('elektronrør',),
'elektronrøra': ('elektronrør',),
'elektronrørene': ('elektronrør',),
'elektronrøret': ('elektronrør',),
'elektronskal': ('elektronskal',),
'elektronskala': ('elektronskal',),
'elektronskalene': ('elektronskal',),
'elektronskalet': ('elektronskal',),
'elektronskall': ('elektronskall',),
'elektronskalla': ('elektronskall',),
'elektronskallene': ('elektronskall',),
'elektronskallet': ('elektronskall',),
'elektronvolt': ('elektronvolt',),
'elektronvolten': ('elektronvolt',),
'elektronvoltene': ('elektronvolt',),
'elektrooptikk': ('elektrooptikk',),
'elektrooptikken': ('elektrooptikk',),
'elektrooptikkene': ('elektrooptikk',),
'elektrooptikker': ('elektrooptikk',),
'elektrosjokk': ('elektrosjokk',),
'elektrosjokka': ('elektrosjokk',),
'elektrosjokkene': ('elektrosjokk',),
'elektrosjokket': ('elektrosjokk',),
'elektroskop': ('elektroskop',),
'elektroskopa': ('elektroskop',),
'elektroskopene': ('elektroskop',),
'elektroskoper': ('elektroskop',),
'elektroskopet': ('elektroskop',),
'elektrostatikk': ('elektrostatikk',),
'elektrostatikken': ('elektrostatikk',),
'elektrostatikkene': ('elektrostatikk',),
'elektrostatikker': ('elektrostatikk',),
'elektroteknikk': ('elektroteknikk',),
'elektroteknikken': ('elektroteknikk',),
'elektroteknikkene': ('elektroteknikk',),
'elektroteknikker': ('elektroteknikk',),
'elektroterapi': ('elektroterapi',),
'elektroterapien': ('elektroterapi',),
'elektroterapiene': ('elektroterapi',),
'elektroterapier': ('elektroterapi',),
'element': ('element',),
'elementa': ('element',),
'elementene': ('element',),
'elementer': ('element',),
'elementet': ('element',),
'elementanalysa': ('elementanalyse',),
'elementanalyse': ('elementanalyse',),
'elementanalysen': ('elementanalyse',),
'elementanalysene': ('elementanalyse',),
'elementanalyser': ('elementanalyse',),
'elementbygg': ('elementbygg',),
'elementbygga': ('elementbygg',),
'elementbyggene': ('elementbygg',),
'elementbygget': ('elementbygg',),
'elementhus': ('elementhus',),
'elementhusa': ('elementhus',),
'elementhusene': ('elementhus',),
'elementhuset': ('elementhus',),
'elementkjøkken': ('elementkjøkken',),
'elementkjøkkena': ('elementkjøkken',),
'elementkjøkkenene': ('elementkjøkken',),
'elementkjøkkener': ('elementkjøkken',),
'elementkjøkkenet': ('elementkjøkken',),
'elementæranalysa': ('elementæranalyse',),
'elementæranalyse': ('elementæranalyse',),
'elementæranalysen': ('elementæranalyse',),
'elementæranalysene': ('elementæranalyse',),
'elementæranalyser': ('elementæranalyse',),
'elementærbok': ('elementærbok',),
'elementærboka': ('elementærbok',),
'elementærboken': ('elementærbok',),
'elementærbøkene': ('elementærbok',),
'elementærbøker': ('elementærbok',),
'elementærladning': ('elementærladning',),
'elementærladninga': ('elementærladning',),
'elementærladningen': ('elementærladning',),
'elementærladningene': ('elementærladning',),
'elementærladninger': ('elementærladning',),
'elementærpartikkel': ('elementærpartikkel',),
'elementærpartikkelen': ('elementærpartikkel',),
'elementærpartiklene': ('elementærpartikkel',),
'elementærpartikler': ('elementærpartikkel',),
'elementærundervisning': ('elementærundervisning',),
'elementærundervisninga': ('elementærundervisning',),
'elementærundervisningen': ('elementærundervisning',),
'elementærundervisningene': ('elementærundervisning',),
'elementærundervisninger': ('elementærundervisning',),
'elenda': ('elende',),
'elende': ('elende',),
'elendene': ('elende',),
'elender': ('elende',),
'elendet': ('elende',),
'elendighet': ('elendighet',),
'elendigheta': ('elendighet',),
'elendigheten': ('elendighet',),
'elendighetene': ('elendighet',),
'elendigheter': ('elendighet',),
'elev': ('elev',),
'eleven': ('elev',),
'elevene': ('elev',),
'elever': ('elev',),
'elevaktivitet': ('elevaktivitet',),
'elevaktiviteten': ('elevaktivitet',),
'elevaktivitetene': ('elevaktivitet',),
'elevaktiviteter': ('elevaktivitet',),
'elevarbeid': ('elevarbeid',),
'elevarbeida': ('elevarbeid',),
'elevarbeidene': ('elevarbeid',),
'elevarbeider': ('elevarbeid',),
'elevarbeidet': ('elevarbeid',),
'elevasjon': ('elevasjon',),
'elevasjonen': ('elevasjon',),
'elevasjonene': ('elevasjon',),
'elevasjoner': ('elevasjon',),
'elevasjonsvinkel': ('elevasjonsvinkel',),
'elevasjonsvinkelen': ('elevasjonsvinkel',),
'elevasjonsvinklene': ('elevasjonsvinkel',),
'elevasjonsvinkler': ('elevasjonsvinkel',),
'elevator': ('elevator',),
'elevatoren': ('elevator',),
'elevatorene': ('elevator',),
'elevatorer': ('elevator',),
'elevdemokrati': ('elevdemokrati',),
'elevdemokratia': ('elevdemokrati',),
'elevdemokratiene': ('elevdemokrati',),
'elevdemokratier': ('elevdemokrati',),
'elevdemokratiet': ('elevdemokrati',),
'elevmateriala': ('elevmateriale',),
'elevmateriale': ('elevmateriale',),
'elevmaterialene': ('elevmateriale',),
'elevmaterialer': ('elevmateriale',),
'elevmaterialet': ('elevmateriale',),
'elevråd': ('elevråd',),
'elevråda': ('elevråd',),
'elevrådene': ('elevråd',),
'elevrådet': ('elevråd',),
'elevøvelse': ('elevøvelse',),
'elevøvelsen': ('elevøvelse',),
'elevøvelsene': ('elevøvelse',),
'elevøvelser': ('elevøvelse',),
'elevøving': ('elevøving',),
'elevøvinga': ('elevøving',),
'elevøvingen': ('elevøving',),
'elevøvingene': ('elevøving',),
'elevøvinger': ('elevøving',),
'elfenbein': ('elfenbein',),
'elfenbeina': ('elfenbein',),
'elfenbeinene': ('elfenbein',),
'elfenbeinet': ('elfenbein',),
'elfenbeinsfarge': ('elfenbeinsfarge',),
'elfenbeinsfargen': ('elfenbeinsfarge',),
'elfenbeinsfargene': ('elfenbeinsfarge',),
'elfenbeinsfarger': ('elfenbeinsfarge',),
'elfenbeinssvart': ('elfenbeinssvart',),
'elfenbeinstårn': ('elfenbeinstårn',),
'elfenbeinstårna': ('elfenbeinstårn',),
'elfenbeinstårnene': ('elfenbeinstårn',),
'elfenbeinstårnet': ('elfenbeinstårn',),
'elfenben': ('elfenben',),
'elfenbena': ('elfenben',),
'elfenbenene': ('elfenben',),
'elfenbenet': ('elfenben',),
'elfenben': ('elfenben',),
'elfenbena': ('elfenben',),
'elfenbenene': ('elfenben',),
'elfenbenet': ('elfenben',),
'elfenbensfarge': ('elfenbensfarge',),
'elfenbensfargen': ('elfenbensfarge',),
'elfenbensfargene': ('elfenbensfarge',),
'elfenbensfarger': ('elfenbensfarge',),
'elfenbenssvart': ('elfenbenssvart',),
'elfenbenstårn': ('elfenbenstårn',),
'elfenbenstårna': ('elfenbenstårn',),
'elfenbenstårnene': ('elfenbenstårn',),
'elfenbenstårnet': ('elfenbenstårn',),
'elg': ('elg',),
'elgen': ('elg',),
'elgene': ('elg',),
'elger': ('elg',),
'elgantilopa': ('elgantilope',),
'elgantilope': ('elgantilope',),
'elgantilopen': ('elgantilope',),
'elgantilopene': ('elgantilope',),
'elgantiloper': ('elgantilope',),
'elghorn': ('elghorn',),
'elghorna': ('elghorn',),
'elghornene': ('elghorn',),
'elghornet': ('elghorn',),
'elghud': ('elghud',),
'elghuda': ('elghud',),
'elghuden': ('elghud',),
'elghudene': ('elghud',),
'elghuder': ('elghud',),
'elghund': ('elghund',),
'elghunden': ('elghund',),
'elghundene': ('elghund',),
'elghunder': ('elghund',),
'elgitar': ('elgitar',),
'elgitaren': ('elgitar',),
'elgitarene': ('elgitar',),
'elgitarer': ('elgitar',),
'elgjakt': ('elgjakt',),
'elgjakta': ('elgjakt',),
'elgjakten': ('elgjakt',),
'elgjaktene': ('elgjakt',),
'elgjakter': ('elgjakt',),
'elgkolla': ('elgkolle',),
'elgkolle': ('elgkolle',),
'elgkollen': ('elgkolle',),
'elgkollene': ('elgkolle',),
'elgkoller': ('elgkolle',),
'elgku': ('elgku',),
'elgkua': ('elgku',),
'elgkuen': ('elgku',),
'elgkuene': ('elgku',),
'elgkuer': ('elgku',),
'elgkyr': ('elgku',),
'elgkyrne': ('elgku',),
'elglos': ('elglos',),
'elglosen': ('elglos',),
'elglosene': ('elglos',),
'elgloser': ('elglos',),
'elgokse': ('elgokse',),
'elgoksen': ('elgokse',),
'elgoksene': ('elgokse',),
'elgokser': ('elgokse',),
'elgsteik': ('elgsteik',),
'elgsteika': ('elgsteik',),
'elgsteiken': ('elgsteik',),
'elgsteikene': ('elgsteik',),
'elgsteiker': ('elgsteik',),
'elgstek': ('elgstek',),
'elgsteka': ('elgstek',),
'elgsteken': ('elgstek',),
'elgstekene': ('elgstek',),
'elgsteker': ('elgstek',),
'elgvald': ('elgvald',),
'elgvalda': ('elgvald',),
'elgvaldene': ('elgvald',),
'elgvaldet': ('elgvald',),
'eliksir': ('eliksir',),
'eliksiren': ('eliksir',),
'eliksirene': ('eliksir',),
'eliksirer': ('eliksir',),
'eliminasjon': ('eliminasjon',),
'eliminasjonen': ('eliminasjon',),
'eliminasjonene': ('eliminasjon',),
'eliminasjoner': ('eliminasjon',),
'eliminasjonsmetode': ('eliminasjonsmetode',),
'eliminasjonsmetoden': ('eliminasjonsmetode',),
'eliminasjonsmetodene': ('eliminasjonsmetode',),
'eliminasjonsmetoder': ('eliminasjonsmetode',),
'eling': ('eling',),
'elingen': ('eling',),
'elingene': ('eling',),
'elinger': ('eling',),
'eling': ('eling',),
'elingen': ('eling',),
'elingene': ('eling',),
'elinger': ('eling',),
'elite': ('elite',),
'eliten': ('elite',),
'elitene': ('elite',),
'eliter': ('elite',),
'elitehopper': ('elitehopper',),
'elitehoppere': ('elitehopper',),
'elitehopperen': ('elitehopper',),
'elitehopperer': ('elitehopper',),
'elitehopperne': ('elitehopper',),
'eliteidrett': ('eliteidrett',),
'eliteidretten': ('eliteidrett',),
'eliteidrettene': ('eliteidrett',),
'eliteidretter': ('eliteidrett',),
'elitekjører': ('elitekjører',),
'elitekjørere': ('elitekjører',),
'elitekjøreren': ('elitekjører',),
'elitekjørerer': ('elitekjører',),
'elitekjørerne': ('elitekjører',),
'eliteku': ('eliteku',),
'elitekua': ('eliteku',),
'elitekuen': ('eliteku',),
'elitekuene': ('eliteku',),
'elitekuer': ('eliteku',),
'elitekyr': ('eliteku',),
'elitekyrne': ('eliteku',),
'elitekultur': ('elitekultur',),
'elitekulturen': ('elitekultur',),
'elitekulturene': ('elitekultur',),
'elitekulturer': ('elitekultur',),
'elitemønstring': ('elitemønstring',),
'elitemønstringa': ('elitemønstring',),
'elitemønstringen': ('elitemønstring',),
'elitemønstringene': ('elitemønstring',),
'elitemønstringer': ('elitemønstring',),
'eliteserie': ('eliteserie',),
'eliteserien': ('eliteserie',),
'eliteseriene': ('eliteserie',),
'eliteserier': ('eliteserie',),
'elitetropp': ('elitetropp',),
'elitetroppen': ('elitetropp',),
'elitetroppene': ('elitetropp',),
'elitetropper': ('elitetropp',),
'elkraft': ('elkraft',),
'elkrafta': ('elkraft',),
'elkraften': ('elkraft',),
'elkreftene': ('elkraft',),
'elkrefter': ('elkraft',),
'ellevedel': ('ellevedel',),
'ellevedelen': ('ellevedel',),
'ellevedelene': ('ellevedel',),
'ellevedeler': ('ellevedel',),
'ellever': ('ellever',),
'ellevere': ('ellever',),
'elleveren': ('ellever',),
'elleverer': ('ellever',),
'elleverne': ('ellever',),
'ellevetal': ('ellevetal',),
'ellevetala': ('ellevetal',),
'ellevetalene': ('ellevetal',),
'ellevetalet': ('ellevetal',),
'ellevetall': ('ellevetall',),
'ellevetalla': ('ellevetall',),
'ellevetallene': ('ellevetall',),
'ellevetallet': ('ellevetall',),
'ellevetid': ('ellevetid',),
'ellevetida': ('ellevetid',),
'ellevetiden': ('ellevetid',),
'ellevetidene': ('ellevetid',),
'ellevetider': ('ellevetid',),
'elleveåring': ('elleveåring',),
'elleveåringen': ('elleveåring',),
'elleveåringene': ('elleveåring',),
'elleveåringer': ('elleveåring',),
'elleveårsalder': ('elleveårsalder',),
'elleveårsaldere': ('elleveårsalder',),
'elleveårsalderen': ('elleveårsalder',),
'elleveårsalderer': ('elleveårsalder',),
'elleveårsalderne': ('elleveårsalder',),
'elleveårsaldre': ('elleveårsalder',),
'elleveårsaldrene': ('elleveårsalder',),
'elleveårsaldrer': ('elleveårsalder',),
'ellevtedel': ('ellevtedel',),
'ellevtedelen': ('ellevtedel',),
'ellevtedelene': ('ellevtedel',),
'ellevtedeler': ('ellevtedel',),
'elling': ('elling',),
'ellinga': ('elling',),
'ellingen': ('elling',),
'ellingene': ('elling',),
'ellinger': ('elling',),
'ellipse': ('ellipse',),
'ellipsen': ('ellipse',),
'ellipsene': ('ellipse',),
'ellipser': ('ellipse',),
'ellipsebane': ('ellipsebane',),
'ellipsebanen': ('ellipsebane',),
'ellipsebanene': ('ellipsebane',),
'ellipsebaner': ('ellipsebane',),
'ellipsoide': ('ellipsoide',),
'ellipsoiden': ('ellipsoide',),
'ellipsoidene': ('ellipsoide',),
'ellipsoider': ('ellipsoide',),
'ellok': ('ellok',),
'elloka': ('ellok',),
'ellokene': ('ellok',),
'elloket': ('ellok',),
'elmotor': ('elmotor',),
'elmotoren': ('elmotor',),
'elmotorene': ('elmotor',),
'elmotorer': ('elmotor',),
'elmseld': ('elmseld',),
'elmselden': ('elmseld',),
'elmseldene': ('elmseld',),
'elmselder': ('elmseld',),
'elmsild': ('elmsild',),
'elmsilden': ('elmsild',),
'elmsildene': ('elmsild',),
'elmsilder': ('elmsild',),
'elmåler': ('elmåler',),
'elmålere': ('elmåler',),
'elmåleren': ('elmåler',),
'elmålerer': ('elmåler',),
'elmålerne': ('elmåler',),
'eloge': ('eloge',),
'elogen': ('eloge',),
'elogene': ('eloge',),
'eloger': ('eloge',),
'eloksør': ('eloksør',),
'eloksøren': ('eloksør',),
'eloksørene': ('eloksør',),
'eloksører': ('eloksør',),
'elorgel': ('elorgel',),
'elorgelet': ('elorgel',),
'elorgla': ('elorgel',),
'elorglene': ('elorgel',),
'elorgler': ('elorgel',),
'elorglet': ('elorgel',),
'elpiano': ('elpiano',),
'elpianoa': ('elpiano',),
'elpianoene': ('elpiano',),
'elpianoer': ('elpiano',),
'elpianoet': ('elpiano',),
'elsk': ('elsk',),
'elsken': ('elsk',),
'elskene': ('elsk',),
'elsker': ('elsk',),
'elsker': ('elsker',),
'elskere': ('elsker',),
'elskeren': ('elsker',),
'elskerer': ('elsker',),
'elskerne': ('elsker',),
'elskerinna': ('elskerinne',),
'elskerinne': ('elskerinne',),
'elskerinnen': ('elskerinne',),
'elskerinnene': ('elskerinne',),
'elskerinner': ('elskerinne',),
'elskerrolla': ('elskerrolle',),
'elskerrolle': ('elskerrolle',),
'elskerrollen': ('elskerrolle',),
'elskerrollene': ('elskerrolle',),
'elskerroller': ('elskerrolle',),
'elskling': ('elskling',),
'elsklingen': ('elskling',),
'elsklingene': ('elskling',),
'elsklinger': ('elskling',),
'elskov': ('elskov',),
'elskoven': ('elskov',),
'elskovene': ('elskov',),
'elskover': ('elskov',),
'elskovsdrikk': ('elskovsdrikk',),
'elskovsdrikken': ('elskovsdrikk',),
'elskovsdrikkene': ('elskovsdrikk',),
'elskovsdrikker': ('elskovsdrikk',),
'elskovsrus': ('elskovsrus',),
'elskovsrusa': ('elskovsrus',),
'elskovsrusen': ('elskovsrus',),
'elskovsrusene': ('elskovsrus',),
'elskovsruser': ('elskovsrus',),
'elskovsruset': ('elskovsrus',),
'elskverdighet': ('elskverdighet',),
'elskverdigheta': ('elskverdighet',),
'elskverdigheten': ('elskverdighet',),
'elskverdighetene': ('elskverdighet',),
'elskverdigheter': ('elskverdighet',),
'elta': ('elte',),
'elte': ('elte',),
'elten': ('elte',),
'eltene': ('elte',),
'elter': ('elte',),
'elteklo': ('elteklo',),
'eltekloa': ('elteklo',),
'eltekloen': ('elteklo',),
'elteklør': ('elteklo',),
'elteklørne': ('elteklo',),
'eltemaskin': ('eltemaskin',),
'eltemaskina': ('eltemaskin',),
'eltemaskinen': ('eltemaskin',),
'eltemaskinene': ('eltemaskin',),
'eltemaskiner': ('eltemaskin',),
'eltetrau': ('eltetrau',),
'eltetraua': ('eltetrau',),
'eltetrauene': ('eltetrau',),
'eltetrauet': ('eltetrau',),
'elusjon': ('elusjon',),
'elusjonen': ('elusjon',),
'elusjonene': ('elusjon',),
'elusjoner': ('elusjon',),
'elv': ('elv',),
'elven': ('elv',),
'elvene': ('elv',),
'elver': ('elv',),
'elv': ('elv',),
'elva': ('elv',),
'elven': ('elv',),
'elvene': ('elv',),
'elver': ('elv',),
'elveblest': ('elveblest',),
'elveblesten': ('elveblest',),
'elveblestene': ('elveblest',),
'elveblester': ('elveblest',),
'elvebredd': ('elvebredd',),
'elvebredda': ('elvebredd',),
'elvebredden': ('elvebredd',),
'elvebreddene': ('elvebredd',),
'elvebredder': ('elvebredd',),
'elvebåt': ('elvebåt',),
'elvebåten': ('elvebåt',),
'elvebåtene': ('elvebåt',),
'elvebåter': ('elvebåt',),
'elvedur': ('elvedur',),
'elveduren': ('elvedur',),
'elvedurene': ('elvedur',),
'elvedurer': ('elvedur',),
'elvefar': ('elvefar',),
'elvefara': ('elvefar',),
'elvefarene': ('elvefar',),
'elvefaret': ('elvefar',),
'elveløp': ('elveløp',),
'elveløpa': ('elveløp',),
'elveløpene': ('elveløp',),
'elveløpet': ('elveløp',),
'elvemunning': ('elvemunning',),
'elvemunninga': ('elvemunning',),
'elvemunningen': ('elvemunning',),
'elvemunningene': ('elvemunning',),
'elvemunninger': ('elvemunning',),
'elvepadling': ('elvepadling',),
'elvepadlinga': ('elvepadling',),
'elvepadlingen': ('elvepadling',),
'elvepadlingene': ('elvepadling',),
'elvepadlinger': ('elvepadling',),
'elveregulering': ('elveregulering',),
'elvereguleringa': ('elveregulering',),
'elvereguleringen': ('elveregulering',),
'elvereguleringene': ('elveregulering',),
'elvereguleringer': ('elveregulering',),
'elverk': ('elverk',),
'elverka': ('elverk',),
'elverkene': ('elverk',),
'elverker': ('elverk',),
'elverket': ('elverk',),
'elzevir': ('elzevir',),
'elzeviren': ('elzevir',),
'elzevirene': ('elzevir',),
'elzevirer': ('elzevir',),
'emalje': ('emalje',),
'emaljen': ('emalje',),
'emaljene': ('emalje',),
'emaljer': ('emalje',),
'emaljelakk': ('emaljelakk',),
'emaljelakken': ('emaljelakk',),
'emaljelakkene': ('emaljelakk',),
'emaljelakker': ('emaljelakk',),
'emaljør': ('emaljør',),
'emaljøren': ('emaljør',),
'emaljørene': ('emaljør',),
'emaljører': ('emaljør',),
'emanasjon': ('emanasjon',),
'emanasjonen': ('emanasjon',),
'emanasjonene': ('emanasjon',),
'emanasjoner': ('emanasjon',),
'emanasjonslæra': ('emanasjonslære',),
'emanasjonslære': ('emanasjonslære',),
'emanasjonslæren': ('emanasjonslære',),
'emanasjonslærene': ('emanasjonslære',),
'emanasjonslærer': ('emanasjonslære',),
'emansipasjon': ('emansipasjon',),
'emansipasjonen': ('emansipasjon',),
'emansipasjonene': ('emansipasjon',),
'emansipasjoner': ('emansipasjon',),
'emballasje': ('emballasje',),
'emballasjen': ('emballasje',),
'emballasjene': ('emballasje',),
'emballasjer': ('emballasje',),
'embargo': ('embargo',),
'embargoen': ('embargo',),
'embargoene': ('embargo',),
'embargoer': ('embargo',),
'embeta': ('embete',),
'embete': ('embete',),
'embetene': ('embete',),
'embeter': ('embete',),
'embetet': ('embete',),
'embetsbolig': ('embetsbolig',),
'embetsboligen': ('embetsbolig',),
'embetsboligene': ('embetsbolig',),
'embetsboliger': ('embetsbolig',),
'embetsdrakt': ('embetsdrakt',),
'embetsdrakta': ('embetsdrakt',),
'embetsdrakten': ('embetsdrakt',),
'embetsdraktene': ('embetsdrakt',),
'embetsdrakter': ('embetsdrakt',),
'embetsed': ('embetsed',),
'embetseden': ('embetsed',),
'embetsedene': ('embetsed',),
'embetseder': ('embetsed',),
'embetseksamen': ('embetseksamen',),
'embetseksamenen': ('embetseksamen',),
'embetseksamenene': ('embetseksamen',),
'embetseksamener': ('embetseksamen',),
'embetsmann': ('embetsmann',),
'embetsmannen': ('embetsmann',),
'embetsmenn': ('embetsmann',),
'embetsmennene': ('embetsmann',),
'embetsmannsplan': ('embetsmannsplan',),
'embetsmannsplana': ('embetsmannsplan',),
'embetsmannsplanene': ('embetsmannsplan',),
'embetsmannsplanet': ('embetsmannsplan',),
'embetsplikt': ('embetsplikt',),
'embetsplikta': ('embetsplikt',),
'embetsplikten': ('embetsplikt',),
'embetspliktene': ('embetsplikt',),
'embetsplikter': ('embetsplikt',),
'embetsstand': ('embetsstand',),
'embetsstanden': ('embetsstand',),
'embetsstendene': ('embetsstand',),
'embetsstender': ('embetsstand',),
'embetsvelda': ('embetsvelde',),
'embetsvelde': ('embetsvelde',),
'embetsveldene': ('embetsvelde',),
'embetsvelder': ('embetsvelde',),
'embetsveldet': ('embetsvelde',),
'embetsverk': ('embetsverk',),
'embetsverka': ('embetsverk',),
'embetsverkene': ('embetsverk',),
'embetsverket': ('embetsverk',),
'emblem': ('emblem',),
'emblema': ('emblem',),
'emblemene': ('emblem',),
'emblemer': ('emblem',),
'emblemet': ('emblem',),
'embonpoint': ('embonpoint',),
'embonpointa': ('embonpoint',),
'embonpointene': ('embonpoint',),
'embonpointet': ('embonpoint',),
'embouchure': ('embouchure',),
'embouchuren': ('embouchure',),
'embouchurene': ('embouchure',),
'embouchurer': ('embouchure',),
'embryo': ('embryo',),
'embryoa': ('embryo',),
'embryoene': ('embryo',),
'embryoer': ('embryo',),
'embryoet': ('embryo',),
'embryologi': ('embryologi',),
'embryologien': ('embryologi',),
'embryologiene': ('embryologi',),
'embryologier': ('embryologi',),
'emfase': ('emfase',),
'emfasen': ('emfase',),
'emfasene': ('emfase',),
'emfaser': ('emfase',),
'emfysem': ('emfysem',),
'emfysema': ('emfysem',),
'emfysemene': ('emfysem',),
'emfysemer': ('emfysem',),
'emfysemet': ('emfysem',),
'emigrant': ('emigrant',),
'emigranten': ('emigrant',),
'emigrantene': ('emigrant',),
'emigranter': ('emigrant',),
'emigrasjon': ('emigrasjon',),
'emigrasjonen': ('emigrasjon',),
'emigrasjonene': ('emigrasjon',),
'emigrasjoner': ('emigrasjon',),
'eminense': ('eminense',),
'eminensen': ('eminense',),
'eminensene': ('eminense',),
'eminenser': ('eminense',),
'emir': ('emir',),
'emiren': ('emir',),
'emirene': ('emir',),
'emirer': ('emir',),
'emirat': ('emirat',),
'emirata': ('emirat',),
'emiratene': ('emirat',),
'emirater': ('emirat',),
'emiratet': ('emirat',),
'emisjon': ('emisjon',),
'emisjonen': ('emisjon',),
'emisjonene': ('emisjon',),
'emisjoner': ('emisjon',),
'emisjonsbank': ('emisjonsbank',),
'emisjonsbanken': ('emisjonsbank',),
'emisjonsbankene': ('emisjonsbank',),
'emisjonsbanker': ('emisjonsbank',),
'emisjonskurs': ('emisjonskurs',),
'emisjonskursen': ('emisjonskurs',),
'emisjonskursene': ('emisjonskurs',),
'emisjonskurser': ('emisjonskurs',),
'emisjonsteori': ('emisjonsteori',),
'emisjonsteorien': ('emisjonsteori',),
'emisjonsteoriene': ('emisjonsteori',),
'emisjonsteorier': ('emisjonsteori',),
'emissær': ('emissær',),
'emissæren': ('emissær',),
'emissærene': ('emissær',),
'emissærer': ('emissær',),
'emna': ('emne',),
'emne': ('emne',),
'emnene': ('emne',),
'emner': ('emne',),
'emnet': ('emne',),
'emneeksamen': ('emneeksamen',),
'emneeksamenen': ('emneeksamen',),
'emneeksamenene': ('emneeksamen',),
'emneeksamener': ('emneeksamen',),
'emnekrets': ('emnekrets',),
'emnekretsen': ('emnekrets',),
'emnekretsene': ('emnekrets',),
'emnekretser': ('emnekrets',),
'emneområda': ('emneområde',),
'emneområde': ('emneområde',),
'emneområdene': ('emneområde',),
'emneområder': ('emneområde',),
'emneområdet': ('emneområde',),
'emneregister': ('emneregister',),
'emneregisteret': ('emneregister',),
'emneregistra': ('emneregister',),
'emneregistre': ('emneregister',),
'emneregistrene': ('emneregister',),
'emneregistret': ('emneregister',),
'emnevalg': ('emnevalg',),
'emnevalga': ('emnevalg',),
'emnevalgene': ('emnevalg',),
'emnevalget': ('emnevalg',),
'emning': ('emning',),
'emninga': ('emning',),
'emningen': ('emning',),
'emningene': ('emning',),
'emninger': ('emning',),
'emosjon': ('emosjon',),
'emosjonen': ('emosjon',),
'emosjonene': ('emosjon',),
'emosjoner': ('emosjon',),
'emosjonsneurose': ('emosjonsneurose',),
'emosjonsneurosen': ('emosjonsneurose',),
'emosjonsneurosene': ('emosjonsneurose',),
'emosjonsneuroser': ('emosjonsneurose',),
'emosjonsnevrose': ('emosjonsnevrose',),
'emosjonsnevrosen': ('emosjonsnevrose',),
'emosjonsnevrosene': ('emosjonsnevrose',),
'emosjonsnevroser': ('emosjonsnevrose',),
'empire': ('empire',),
'empiren': ('empire',),
'empirene': ('empire',),
'empirer': ('empire',),
'empiremøbel': ('empiremøbel',),
'empiremøbelet': ('empiremøbel',),
'empiremøbla': ('empiremøbel',),
'empiremøblene': ('empiremøbel',),
'empiremøbler': ('empiremøbel',),
'empiremøblet': ('empiremøbel',),
'empirestil': ('empirestil',),
'empirestilen': ('empirestil',),
'empirestilene': ('empirestil',),
'empirestiler': ('empirestil',),
'empiri': ('empiri',),
'empirien': ('empiri',),
'empiriene': ('empiri',),
'empirier': ('empiri',),
'empiriker': ('empiriker',),
'empirikere': ('empiriker',),
'empirikeren': ('empiriker',),
'empirikerer': ('empiriker',),
'empirikerne': ('empiriker',),
'empirisme': ('empirisme',),
'empirismen': ('empirisme',),
'empirismene': ('empirisme',),
'empirismer': ('empirisme',),
'empirist': ('empirist',),
'empiristen': ('empirist',),
'empiristene': ('empirist',),
'empirister': ('empirist',),
'emploi': ('emploi',),
'emploien': ('emploi',),
'emploiene': ('emploi',),
'emploier': ('emploi',),
'employeen': ('employé',),
'employeene': ('employé',),
'employeer': ('employé',),
'employé': ('employé',),
'employéen': ('employé',),
'employéene': ('employé',),
'employéer': ('employé',),
'emu': ('emu',),
'emuen': ('emu',),
'emuene': ('emu',),
'emuer': ('emu',),
'emulsjon': ('emulsjon',),
'emulsjonen': ('emulsjon',),
'emulsjonene': ('emulsjon',),
'emulsjoner': ('emulsjon',),
'enakter': ('enakter',),
'enaktere': ('enakter',),
'enakteren': ('enakter',),
'enakterer': ('enakter',),
'enakterne': ('enakter',),
'encyklika': ('encyklika',),
'encyklikaen': ('encyklika',),
'encyklikaene': ('encyklika',),
'encyklikaer': ('encyklika',),
'encyklopedi': ('encyklopedi',),
'encyklopedien': ('encyklopedi',),
'encyklopediene': ('encyklopedi',),
'encyklopedier': ('encyklopedi',),
'ende': ('ende',),
'enden': ('ende',),
'endene': ('ende',),
'ender': ('ende',),
'endeflata': ('endeflate',),
'endeflate': ('endeflate',),
'endeflaten': ('endeflate',),
'endeflatene': ('endeflate',),
'endeflater': ('endeflate',),
'endelikt': ('endelikt',),
'endelikta': ('endelikt',),
'endeliktene': ('endelikt',),
'endeliktet': ('endelikt',),
'endelse': ('endelse',),
'endelsen': ('endelse',),
'endelsene': ('endelse',),
'endelser': ('endelse',),
'endelykt': ('endelykt',),
'endelykta': ('endelykt',),
'endelykten': ('endelykt',),
'endelyktene': ('endelykt',),
'endelykter': ('endelykt',),
'endeløshet': ('endeløshet',),
'endeløsheta': ('endeløshet',),
'endeløsheten': ('endeløshet',),
'endeløshetene': ('endeløshet',),
'endeløsheter': ('endeløshet',),
'endeløysa': ('endeløyse',),
'endeløyse': ('endeløyse',),
'endeløysen': ('endeløyse',),
'endeløysene': ('endeløyse',),
'endeløyser': ('endeløyse',),
'endemi': ('endemi',),
'endemien': ('endemi',),
'endemiene': ('endemi',),
'endemier': ('endemi',),
'endemorene': ('endemorene',),
'endemorenen': ('endemorene',),
'endemorenene': ('endemorene',),
'endemorener': ('endemorene',),
'endemål': ('endemål',),
'endemåla': ('endemål',),
'endemålene': ('endemål',),
'endemålet': ('endemål',),
'endepunkt': ('endepunkt',),
'endepunkta': ('endepunkt',),
'endepunktene': ('endepunkt',),
'endepunkter': ('endepunkt',),
'endepunktet': ('endepunkt',),
'enderim': ('enderim',),
'enderima': ('enderim',),
'enderimene': ('enderim',),
'enderimet': ('enderim',),
'endestasjon': ('endestasjon',),
'endestasjonen': ('endestasjon',),
'endestasjonene': ('endestasjon',),
'endestasjoner': ('endestasjon',),
'endetarm': ('endetarm',),
'endetarmen': ('endetarm',),
'endetarmene': ('endetarm',),
'endetarmer': ('endetarm',),
'endetarmsåpning': ('endetarmsåpning',),
'endetarmsåpninga': ('endetarmsåpning',),
'endetarmsåpningen': ('endetarmsåpning',),
'endetarmsåpningene': ('endetarmsåpning',),
'endetarmsåpninger': ('endetarmsåpning',),
'endetid': ('endetid',),
'endetida': ('endetid',),
'endetiden': ('endetid',),
'endetidene': ('endetid',),
'endetider': ('endetid',),
'endetidsprofeti': ('endetidsprofeti',),
'endetidsprofetien': ('endetidsprofeti',),
'endetidsprofetiene': ('endetidsprofeti',),
'endetidsprofetier': ('endetidsprofeti',),
'ending': ('ending',),
'endinga': ('ending',),
'endingen': ('ending',),
'endingene': ('ending',),
'endinger': ('ending',),
'endiv': ('endiv',),
'endiven': ('endiv',),
'endivene': ('endiv',),
'endiver': ('endiv',),
'endoskop': ('endoskop',),
'endoskopa': ('endoskop',),
'endoskopene': ('endoskop',),
'endoskoper': ('endoskop',),
'endoskopet': ('endoskop',),
'endoskopi': ('endoskopi',),
'endoskopien': ('endoskopi',),
'endoskopiene': ('endoskopi',),
'endoskopier': ('endoskopi',),
'endossat': ('endossat',),
'endossaten': ('endossat',),
'endossatene': ('endossat',),
'endossater': ('endossat',),
'endossatar': ('endossatar',),
'endossataren': ('endossatar',),
'endossatarene': ('endossatar',),
'endossatarer': ('endossatar',),
'endossement': ('endossement',),
'endossementa': ('endossement',),
'endossementene': ('endossement',),
'endossementer': ('endossement',),
'endossementet': ('endossement',),
'endossent': ('endossent',),
'endossenten': ('endossent',),
'endossentene': ('endossent',),
'endossenter': ('endossent',),
'endring': ('endring',),
'endringa': ('endring',),
'endringen': ('endring',),
'endringene': ('endring',),
'endringer': ('endring',),
'endringsforslag': ('endringsforslag',),
'endringsforslaga': ('endringsforslag',),
'endringsforslagene': ('endringsforslag',),
'endringsforslaget': ('endringsforslag',),
'endringsforsøk': ('endringsforsøk',),
'endringsforsøka': ('endringsforsøk',),
'endringsforsøkene': ('endringsforsøk',),
'endringsforsøket': ('endringsforsøk',),
'endringsframlegg': ('endringsframlegg',),
'endringsframlegga': ('endringsframlegg',),
'endringsframleggene': ('endringsframlegg',),
'endringsframlegget': ('endringsframlegg',),
'endskap': ('endskap',),
'endskapen': ('endskap',),
'endskapene': ('endskap',),
'endskaper': ('endskap',),
'eneagent': ('eneagent',),
'eneagenten': ('eneagent',),
'eneagentene': ('eneagent',),
'eneagenter': ('eneagent',),
'enearving': ('enearving',),
'enearvingen': ('enearving',),
'enearvingene': ('enearving',),
'enearvinger': ('enearving',),
'enebarn': ('enebarn',),
'enebarna': ('enebarn',),
'enebarnene': ('enebarn',),
'enebarnet': ('enebarn',),
'enebolig': ('enebolig',),
'eneboligen': ('enebolig',),
'eneboligene': ('enebolig',),
'eneboliger': ('enebolig',),
'enecella': ('enecelle',),
'enecelle': ('enecelle',),
'enecellen': ('enecelle',),
'enecellene': ('enecelle',),
'eneceller': ('enecelle',),
'eneeier': ('eneeier',),
'eneeiere': ('eneeier',),
'eneeieren': ('eneeier',),
'eneeierer': ('eneeier',),
'eneeierne': ('eneeier',),
'eneeierforetak': ('eneeierforetak',),
'eneeierforetaka': ('eneeierforetak',),
'eneeierforetakene': ('eneeierforetak',),
'eneeierforetaket': ('eneeierforetak',),
'eneforhandler': ('eneforhandler',),
'eneforhandlere': ('eneforhandler',),
'eneforhandleren': ('eneforhandler',),
'eneforhandlerer': ('eneforhandler',),
'eneforhandlerne': ('eneforhandler',),
'eneform': ('eneform',),
'eneforma': ('eneform',),
'eneformen': ('eneform',),
'eneformene': ('eneform',),
'eneformer': ('eneform',),
'enehersker': ('enehersker',),
'eneherskere': ('enehersker',),
'eneherskeren': ('enehersker',),
'eneherskerer': ('enehersker',),
'eneherskerne': ('enehersker',),
'enemerka': ('enemerke',),
'enemerke': ('enemerke',),
'enemerkene': ('enemerke',),
'enemerker': ('enemerke',),
'enemerket': ('enemerke',),
'ener': ('ener',),
'enere': ('ener',),
'eneren': ('ener',),
'enerer': ('ener',),
'enerne': ('ener',),
'enerett': ('enerett',),
'eneretten': ('enerett',),
'enerettene': ('enerett',),
'eneretter': ('enerett',),
'energetikk': ('energetikk',),
'energetikken': ('energetikk',),
'energetikkene': ('energetikk',),
'energetikker': ('energetikk',),
'energi': ('energi',),
'energien': ('energi',),
'energiene': ('energi',),
'energier': ('energi',),
'energibehov': ('energibehov',),
'energibehova': ('energibehov',),
'energibehovene': ('energibehov',),
'energibehovet': ('energibehov',),
'energibunt': ('energibunt',),
'energibunten': ('energibunt',),
'energibuntene': ('energibunt',),
'energibunter': ('energibunt',),
'energiforbruk': ('energiforbruk',),
'energiforbruka': ('energiforbruk',),
'energiforbrukene': ('energiforbruk',),
'energiforbruket': ('energiforbruk',),
'energiform': ('energiform',),
'energiforma': ('energiform',),
'energiformen': ('energiform',),
'energiformene': ('energiform',),
'energiformer': ('energiform',),
'energiforsyning': ('energiforsyning',),
'energiforsyninga': ('energiforsyning',),
'energiforsyningen': ('energiforsyning',),
'energiforsyningene': ('energiforsyning',),
'energiforsyninger': ('energiforsyning',),
'energiforvandling': ('energiforvandling',),
'energiforvandlinga': ('energiforvandling',),
'energiforvandlingen': ('energiforvandling',),
'energiforvandlingene': ('energiforvandling',),
'energiforvandlinger': ('energiforvandling',),
'energikilde': ('energikilde',),
'energikilden': ('energikilde',),
'energikildene': ('energikilde',),
'energikilder': ('energikilde',),
'energikjelda': ('energikjelde',),
'energikjelde': ('energikjelde',),
'energikjelden': ('energikjelde',),
'energikjeldene': ('energikjelde',),
'energikjelder': ('energikjelde',),
'energikrisa': ('energikrise',),
'energikrise': ('energikrise',),
'energikrisen': ('energikrise',),
'energikrisene': ('energikrise',),
'energikriser': ('energikrise',),
'energipolitikk': ('energipolitikk',),
'energipolitikken': ('energipolitikk',),
'energipolitikkene': ('energipolitikk',),
'energipolitikker': ('energipolitikk',),
'energisparepæra': ('energisparepære',),
'energisparepære': ('energisparepære',),
'energisparepæren': ('energisparepære',),
'energisparepærene': ('energisparepære',),
'energisparepærer': ('energisparepære',),
'energisparing': ('energisparing',),
'energisparinga': ('energisparing',),
'energisparingen': ('energisparing',),
'energisparingene': ('energisparing',),
'energisparinger': ('energisparing',),
'energitap': ('energitap',),
'energitapa': ('energitap',),
'energitapene': ('energitap',),
'energitapet': ('energitap',),
'energiverk': ('energiverk',),
'energiverka': ('energiverk',),
'energiverkene': ('energiverk',),
'energiverker': ('energiverk',),
'energiverket': ('energiverk',),
'energiøkonomisering': ('energiøkonomisering',),
'energiøkonomiseringa': ('energiøkonomisering',),
'energiøkonomiseringen': ('energiøkonomisering',),
'energiøkonomiseringene': ('energiøkonomisering',),
'energiøkonomiseringer': ('energiøkonomisering',),
'enerom': ('enerom',),
'eneromma': ('enerom',),
'enerommene': ('enerom',),
'enerommet': ('enerom',),
'enetale': ('enetale',),
'enetalen': ('enetale',),
'enetalene': ('enetale',),
'enetaler': ('enetale',),
'enevelda': ('enevelde',),
'enevelde': ('enevelde',),
'eneveldene': ('enevelde',),
'enevelder': ('enevelde',),
'eneveldet': ('enevelde',),
'enevoldskonge': ('enevoldskonge',),
'enevoldskongen': ('enevoldskonge',),
'enevoldskongene': ('enevoldskonge',),
'enevoldskonger': ('enevoldskonge',),
'enevoldsmakt': ('enevoldsmakt',),
'enevoldsmakta': ('enevoldsmakt',),
'enevoldsmakten': ('enevoldsmakt',),
'enevoldsmaktene': ('enevoldsmakt',),
'enevoldsmakter': ('enevoldsmakt',),
'eneværelsa': ('eneværelse',),
'eneværelse': ('eneværelse',),
'eneværelsene': ('eneværelse',),
'eneværelser': ('eneværelse',),
'eneværelset': ('eneværelse',),
'enfamiliehus': ('enfamiliehus',),
'enfamiliehusa': ('enfamiliehus',),
'enfamiliehusene': ('enfamiliehus',),
'enfamiliehuset': ('enfamiliehus',),
'enfasemotor': ('enfasemotor',),
'enfasemotoren': ('enfasemotor',),
'enfasemotorene': ('enfasemotor',),
'enfasemotorer': ('enfasemotor',),
'enfasestrøm': ('enfasestrøm',),
'enfasestrømmen': ('enfasestrøm',),
'enfasestrømmene': ('enfasestrøm',),
'enfasestrømmer': ('enfasestrøm',),
'enfasesystem': ('enfasesystem',),
'enfasesystema': ('enfasesystem',),
'enfasesystemene': ('enfasesystem',),
'enfasesystemer': ('enfasesystem',),
'enfasesystemet': ('enfasesystem',),
'enfold': ('enfold',),
'enfolda': ('enfold',),
'enfoldene': ('enfold',),
'enfoldet': ('enfold',),
'enfoldighet': ('enfoldighet',),
'enfoldigheta': ('enfoldighet',),
'enfoldigheten': ('enfoldighet',),
'enfoldighetene': ('enfoldighet',),
'enfoldigheter': ('enfoldighet',),
'eng': ('eng',),
'enga': ('eng',),
'engen': ('eng',),
'engene': ('eng',),
'enger': ('eng',),
'engangsbeløp': ('engangsbeløp',),
'engangsbeløpa': ('engangsbeløp',),
'engangsbeløpene': ('engangsbeløp',),
'engangsbeløpet': ('engangsbeløp',),
'engangsbruk': ('engangsbruk',),
'engangsbruka': ('engangsbruk',),
'engangsbruken': ('engangsbruk',),
'engangsbrukene': ('engangsbruk',),
'engangsbruker': ('engangsbruk',),
'engangsbruket': ('engangsbruk',),
'engangsemballasje': ('engangsemballasje',),
'engangsemballasjen': ('engangsemballasje',),
'engangsemballasjene': ('engangsemballasje',),
'engangsemballasjer': ('engangsemballasje',),
'engangsforeteelse': ('engangsforeteelse',),
'engangsforeteelsen': ('engangsforeteelse',),
'engangsforeteelsene': ('engangsforeteelse',),
'engangsforeteelser': ('engangsforeteelse',),
'engangspakning': ('engangspakning',),
'engangspakninga': ('engangspakning',),
'engangspakningen': ('engangspakning',),
'engangspakningene': ('engangspakning',),
'engangspakninger': ('engangspakning',),
'engangssprøyta': ('engangssprøyte',),
'engangssprøyte': ('engangssprøyte',),
'engangssprøyten': ('engangssprøyte',),
'engangssprøytene': ('engangssprøyte',),
'engangssprøyter': ('engangssprøyte',),
'engangsutgift': ('engangsutgift',),
'engangsutgifta': ('engangsutgift',),
'engangsutgiften': ('engangsutgift',),
'engangsutgiftene': ('engangsutgift',),
'engangsutgifter': ('engangsutgift',),
'engasjement': ('engasjement',),
'engasjementa': ('engasjement',),
'engasjementene': ('engasjement',),
'engasjementer': ('engasjement',),
'engasjementet': ('engasjement',),
'engbeita': ('engbeite',),
'engbeite': ('engbeite',),
'engbeitene': ('engbeite',),
'engbeiter': ('engbeite',),
'engbeitet': ('engbeite',),
'engdyrking': ('engdyrking',),
'engdyrkinga': ('engdyrking',),
'engdyrkingen': ('engdyrking',),
'engdyrkingene': ('engdyrking',),
'engdyrkinger': ('engdyrking',),
'engel': ('engel',),
'engelen': ('engel',),
'englene': ('engel',),
'engler': ('engel',),
'engelsk': ('engelsk',),
'engelsken': ('engelsk',),
'engelskene': ('engelsk',),
'engelsker': ('engelsk',),
'engelskartium': ('engelskartium',),
'engelskartiumen': ('engelskartium',),
'engelskartiumene': ('engelskartium',),
'engelskartiumer': ('engelskartium',),
'engelsklinja': ('engelsklinje',),
'engelsklinje': ('engelsklinje',),
'engelsklinjen': ('engelsklinje',),
'engelsklinjene': ('engelsklinje',),
'engelsklinjer': ('engelsklinje',),
'engelskmann': ('engelskmann',),
'engelskmannen': ('engelskmann',),
'engelskmenn': ('engelskmann',),
'engelskmennene': ('engelskmann',),
'engelskmann': ('engelskmann',),
'engelskmannen': ('engelskmann',),
'engelskmenn': ('engelskmann',),
'engelskmennene': ('engelskmann',),
'engelskundervisning': ('engelskundervisning',),
'engelskundervisninga': ('engelskundervisning',),
'engelskundervisningen': ('engelskundervisning',),
'engelskundervisningene': ('engelskundervisning',),
'engelskundervisninger': ('engelskundervisning',),
'engifta': ('engifte',),
'engifte': ('engifte',),
'engiftene': ('engifte',),
'engifter': ('engifte',),
'engiftet': ('engifte',),
'engkarse': ('engkarse',),
'engkarsen': ('engkarse',),
'engkarsene': ('engkarse',),
'engkarser': ('engkarse',),
'engkultur': ('engkultur',),
'engkulturen': ('engkultur',),
'engkulturene': ('engkultur',),
'engkulturer': ('engkultur',),
'englebarn': ('englebarn',),
'englebarna': ('englebarn',),
'englebarnene': ('englebarn',),
'englebarnet': ('englebarn',),
'englehår': ('englehår',),
'englehåra': ('englehår',),
'englehårene': ('englehår',),
'englehåret': ('englehår',),
'englender': ('englender',),
'englendere': ('englender',),
'englenderen': ('englender',),
'englenderer': ('englender',),
'englenderne': ('englender',),
'englerøst': ('englerøst',),
'englerøsta': ('englerøst',),
'englerøsten': ('englerøst',),
'englerøstene': ('englerøst',),
'englerøster': ('englerøst',),
'engleskare': ('engleskare',),
'engleskaren': ('engleskare',),
'engleskarene': ('engleskare',),
'engleskarer': ('engleskare',),
'engnellik': ('engnellik',),
'engnelliken': ('engnellik',),
'engnellikene': ('engnellik',),
'engnelliker': ('engnellik',),
'engrosforretning': ('engrosforretning',),
'engrosforretninga': ('engrosforretning',),
'engrosforretningen': ('engrosforretning',),
'engrosforretningene': ('engrosforretning',),
'engrosforretninger': ('engrosforretning',),
'engroslager': ('engroslager',),
'engroslageret': ('engroslager',),
'engroslagra': ('engroslager',),
'engroslagre': ('engroslager',),
'engroslagrene': ('engroslager',),
'engrospris': ('engrospris',),
'engrosprisen': ('engrospris',),
'engrosprisene': ('engrospris',),
'engrospriser': ('engrospris',),
'engrossalg': ('engrossalg',),
'engrossalga': ('engrossalg',),
'engrossalgene': ('engrossalg',),
'engrossalget': ('engrossalg',),
'engslått': ('engslått',),
'engslåtten': ('engslått',),
'engslåttene': ('engslått',),
'engslåtter': ('engslått',),
'engsoleia': ('engsoleie',),
'engsoleie': ('engsoleie',),
'engsoleien': ('engsoleie',),
'engsoleiene': ('engsoleie',),
'engsoleier': ('engsoleie',),
'engstelse': ('engstelse',),
'engstelsen': ('engstelse',),
'engstelsene': ('engstelse',),
'engstelser': ('engstelse',),
'engsyra': ('engsyre',),
'engsyre': ('engsyre',),
'engsyren': ('engsyre',),
'engsyrene': ('engsyre',),
'engsyrer': ('engsyre',),
'enhet': ('enhet',),
'enheten': ('enhet',),
'enhetene': ('enhet',),
'enheter': ('enhet',),
'enhetsgevær': ('enhetsgevær',),
'enhetsgeværa': ('enhetsgevær',),
'enhetsgeværene': ('enhetsgevær',),
'enhetsgeværer': ('enhetsgevær',),
'enhetsgeværet': ('enhetsgevær',),
'enhetslast': ('enhetslast',),
'enhetslasta': ('enhetslast',),
'enhetslasten': ('enhetslast',),
'enhetslastene': ('enhetslast',),
'enhetslaster': ('enhetslast',),
'enhetsskole': ('enhetsskole',),
'enhetsskolen': ('enhetsskole',),
'enhetsskolene': ('enhetsskole',),
'enhetsskoler': ('enhetsskole',),
'enhjørning': ('enhjørning',),
'enhjørningen': ('enhjørning',),
'enhjørningene': ('enhjørning',),
'enhjørninger': ('enhjørning',),
'enighet': ('enighet',),
'enigheta': ('enighet',),
'enigheten': ('enighet',),
'enighetene': ('enighet',),
'enigheter': ('enighet',),
'enigma': ('enigma',),
'enigmaen': ('enigma',),
'enigmaene': ('enigma',),
'enigmaer': ('enigma',),
'ening': ('ening',),
'eninga': ('ening',),
'eningen': ('ening',),
'eningene': ('ening',),
'eninger': ('ening',),
'enjambement': ('enjambement',),
'enjambementa': ('enjambement',),
'enjambementene': ('enjambement',),
'enjambementer': ('enjambement',),
'enjambementet': ('enjambement',),
'enkét': ('enkét',),
'enkéten': ('enkét',),
'enkétene': ('enkét',),
'enkéter': ('enkét',),
'enka': ('enke',),
'enke': ('enke',),
'enken': ('enke',),
'enkene': ('enke',),
'enker': ('enke',),
'enkefrua': ('enkefrue',),
'enkefrue': ('enkefrue',),
'enkefruen': ('enkefrue',),
'enkefruene': ('enkefrue',),
'enkefruer': ('enkefrue',),
'enkelhet': ('enkelhet',),
'enkelheta': ('enkelhet',),
'enkelheten': ('enkelhet',),
'enkelhetene': ('enkelhet',),
'enkelheter': ('enkelhet',),
'enkeltbekkasin': ('enkeltbekkasin',),
'enkeltbekkasinen': ('enkeltbekkasin',),
'enkeltbekkasinene': ('enkeltbekkasin',),
'enkeltbekkasiner': ('enkeltbekkasin',),
'enkeltbillett': ('enkeltbillett',),
'enkeltbilletten': ('enkeltbillett',),
'enkeltbillettene': ('enkeltbillett',),
'enkeltbilletter': ('enkeltbillett',),
'enkeltdør': ('enkeltdør',),
'enkeltdøra': ('enkeltdør',),
'enkeltdøren': ('enkeltdør',),
'enkeltdørene': ('enkeltdør',),
'enkeltdører': ('enkeltdør',),
'enkeltfenomen': ('enkeltfenomen',),
'enkeltfenomena': ('enkeltfenomen',),
'enkeltfenomenene': ('enkeltfenomen',),
'enkeltfenomener': ('enkeltfenomen',),
'enkeltfenomenet': ('enkeltfenomen',),
'enkelthet': ('enkelthet',),
'enkeltheta': ('enkelthet',),
'enkeltheten': ('enkelthet',),
'enkelthetene': ('enkelthet',),
'enkeltheter': ('enkelthet',),
'enkeltløper': ('enkeltløper',),
'enkeltløpere': ('enkeltløper',),
'enkeltløperen': ('enkeltløper',),
'enkeltløperer': ('enkeltløper',),
'enkeltløperne': ('enkeltløper',),
'enkeltmannspakning': ('enkeltmannspakning',),
'enkeltmannspakninga': ('enkeltmannspakning',),
'enkeltmannspakningen': ('enkeltmannspakning',),
'enkeltmannspakningene': ('enkeltmannspakning',),
'enkeltmannspakninger': ('enkeltmannspakning',),
'enkeltmyntfot': ('enkeltmyntfot',),
'enkeltmyntfoten': ('enkeltmyntfot',),
'enkeltmyntføttene': ('enkeltmyntfot',),
'enkeltmyntføtter': ('enkeltmyntfot',),
'enkeltperson': ('enkeltperson',),
'enkeltpersonen': ('enkeltperson',),
'enkeltpersonene': ('enkeltperson',),
'enkeltpersoner': ('enkeltperson',),
'enkeltprestasjon': ('enkeltprestasjon',),
'enkeltprestasjonen': ('enkeltprestasjon',),
'enkeltprestasjonene': ('enkeltprestasjon',),
'enkeltprestasjoner': ('enkeltprestasjon',),
'enkeltrom': ('enkeltrom',),
'enkeltromma': ('enkeltrom',),
'enkeltrommene': ('enkeltrom',),
'enkeltrommet': ('enkeltrom',),
'enkeltspor': ('enkeltspor',),
'enkeltspora': ('enkeltspor',),
'enkeltsporene': ('enkeltspor',),
'enkeltsporet': ('enkeltspor',),
'enkeltvindu': ('enkeltvindu',),
'enkeltvindua': ('enkeltvindu',),
'enkeltvinduene': ('enkeltvindu',),
'enkeltvinduer': ('enkeltvindu',),
'enkeltvinduet': ('enkeltvindu',),
'enkeltværelsa': ('enkeltværelse',),
'enkeltværelse': ('enkeltværelse',),
'enkeltværelsene': ('enkeltværelse',),
'enkeltværelser': ('enkeltværelse',),
'enkeltværelset': ('enkeltværelse',),
'enkemann': ('enkemann',),
'enkemannen': ('enkemann',),
'enkemenn': ('enkemann',),
'enkemennene': ('enkemann',),
'enkemannssorg': ('enkemannssorg',),
'enkemannssorga': ('enkemannssorg',),
'enkemannssorgen': ('enkemannssorg',),
'enkemannssorgene': ('enkemannssorg',),
'enkemannssorger': ('enkemannssorg',),
'enkemannsstøt': ('enkemannsstøt',),
'enkemannsstøta': ('enkemannsstøt',),
'enkemannsstøtene': ('enkemannsstøt',),
'enkemannsstøtet': ('enkemannsstøt',),
'enkemannsstøyt': ('enkemannsstøyt',),
'enkemannsstøyten': ('enkemannsstøyt',),
'enkemannsstøytene': ('enkemannsstøyt',),
'enkemannsstøyter': ('enkemannsstøyt',),
'enketrygd': ('enketrygd',),
'enketrygda': ('enketrygd',),
'enketrygden': ('enketrygd',),
'enketrygdene': ('enketrygd',),
'enketrygder': ('enketrygd',),
'enklave': ('enklave',),
'enklaven': ('enklave',),
'enklavene': ('enklave',),
'enklaver': ('enklave',),
'enklise': ('enklise',),
'enklisen': ('enklise',),
'enklisene': ('enklise',),
'enkliser': ('enklise',),
'enmannskrets': ('enmannskrets',),
'enmannskretsen': ('enmannskrets',),
'enmannskretsene': ('enmannskrets',),
'enmannskretser': ('enmannskrets',),
'enmannspakka': ('enmannspakke',),
'enmannspakke': ('enmannspakke',),
'enmannspakken': ('enmannspakke',),
'enmannspakkene': ('enmannspakke',),
'enmannspakker': ('enmannspakke',),
'enmannsshow': ('enmannsshow',),
'enmannsshowa': ('enmannsshow',),
'enmannsshowene': ('enmannsshow',),
'enmannsshowet': ('enmannsshow',),
'enquête': ('enquête',),
'enquêten': ('enquête',),
'enquêtene': ('enquête',),
'enquêter': ('enquête',),
'enrom': ('enrom',),
'enromma': ('enrom',),
'enrommene': ('enrom',),
'enrommet': ('enrom',),
'ensartethet': ('ensartethet',),
'ensartetheta': ('ensartethet',),
'ensartetheten': ('ensartethet',),
'ensartethetene': ('ensartethet',),
'ensartetheter': ('ensartethet',),
'ensein': ('ensein',),
'enseinen': ('ensein',),
'enseinene': ('ensein',),
'enseiner': ('ensein',),
'ensembla': ('ensemble',),
'ensemble': ('ensemble',),
'ensemblene': ('ensemble',),
'ensembler': ('ensemble',),
'ensemblet': ('ensemble',),
'ensformighet': ('ensformighet',),
'ensformigheta': ('ensformighet',),
'ensformigheten': ('ensformighet',),
'ensformighetene': ('ensformighet',),
'ensformigheter': ('ensformighet',),
'ensilasje': ('ensilasje',),
'ensilasjen': ('ensilasje',),
'ensilasjene': ('ensilasje',),
'ensilasjer': ('ensilasje',),
'enskjærsplog': ('enskjærsplog',),
'enskjærsplogen': ('enskjærsplog',),
'enskjærsplogene': ('enskjærsplog',),
'enskjærsploger': ('enskjærsplog',),
'ensling': ('ensling',),
'enslingen': ('ensling',),
'enslingene': ('ensling',),
'enslinger': ('ensling',),
'ensomhet': ('ensomhet',),
'ensomheta': ('ensomhet',),
'ensomheten': ('ensomhet',),
'ensomhetene': ('ensomhet',),
'ensomheter': ('ensomhet',),
'ensomhetsfølelse': ('ensomhetsfølelse',),
'ensomhetsfølelsen': ('ensomhetsfølelse',),
'ensomhetsfølelsene': ('ensomhetsfølelse',),
'ensomhetsfølelser': ('ensomhetsfølelse',),
'ensretting': ('ensretting',),
'ensrettinga': ('ensretting',),
'ensrettingen': ('ensretting',),
'ensrettingene': ('ensretting',),
'ensrettinger': ('ensretting',),
'enstavelsesord': ('enstavelsesord',),
'enstavelsesorda': ('enstavelsesord',),
'enstavelsesordene': ('enstavelsesord',),
'enstavelsesordet': ('enstavelsesord',),
'enstavelsestonelag': ('enstavelsestonelag',),
'enstavelsestonelaga': ('enstavelsestonelag',),
'enstavelsestonelagene': ('enstavelsestonelag',),
'enstavelsestonelaget': ('enstavelsestonelag',),
'enstavingsord': ('enstavingsord',),
'enstavingsorda': ('enstavingsord',),
'enstavingsordene': ('enstavingsord',),
'enstavingsordet': ('enstavingsord',),
'enstavingstonelag': ('enstavingstonelag',),
'enstavingstonelaga': ('enstavingstonelag',),
'enstavingstonelagene': ('enstavingstonelag',),
'enstavingstonelaget': ('enstavingstonelag',),
'ental': ('ental',),
'entala': ('ental',),
'entalene': ('ental',),
'entalet': ('ental',),
'entall': ('entall',),
'entalla': ('entall',),
'entallene': ('entall',),
'entallet': ('entall',),
'entallsform': ('entallsform',),
'entallsforma': ('entallsform',),
'entallsformen': ('entallsform',),
'entallsformene': ('entallsform',),
'entallsformer': ('entallsform',),
'entalsform': ('entalsform',),
'entalsforma': ('entalsform',),
'entalsformen': ('entalsform',),
'entalsformene': ('entalsform',),
'entalsformer': ('entalsform',),
'entente': ('entente',),
'ententen': ('entente',),
'ententene': ('entente',),
'ententer': ('entente',),
'entertainer': ('entertainer',),
'entertainere': ('entertainer',),
'entertaineren': ('entertainer',),
'entertainerer': ('entertainer',),
'entertainerne': ('entertainer',),
'entitet': ('entitet',),
'entiteten': ('entitet',),
'entitetene': ('entitet',),
'entiteter': ('entitet',),
'entoderm': ('entoderm',),
'entodermen': ('entoderm',),
'entodermene': ('entoderm',),
'entodermer': ('entoderm',),
'entomolog': ('entomolog',),
'entomologen': ('entomolog',),
'entomologene': ('entomolog',),
'entomologer': ('entomolog',),
'entomologi': ('entomologi',),
'entomologien': ('entomologi',),
'entomologiene': ('entomologi',),
'entomologier': ('entomologi',),
'entreen': ('entré',),
'entreene': ('entré',),
'entreer': ('entré',),
'entré': ('entré',),
'entréen': ('entré',),
'entréene': ('entré',),
'entréer': ('entré',),
'entrébillett': ('entrébillett',),
'entrébilletten': ('entrébillett',),
'entrébillettene': ('entrébillett',),
'entrébilletter': ('entrébillett',),
'entrédør': ('entrédør',),
'entrédøra': ('entrédør',),
'entrédøren': ('entrédør',),
'entrédørene': ('entrédør',),
'entrédører': ('entrédør',),
'entrénøkkel': ('entrénøkkel',),
'entrénøkkelen': ('entrénøkkel',),
'entrénøklene': ('entrénøkkel',),
'entrénøkler': ('entrénøkkel',),
'entrecôte': ('entrecôte',),
'entrecôten': ('entrecôte',),
'entrecôtene': ('entrecôte',),
'entrecôter': ('entrecôte',),
'entreprenør': ('entreprenør',),
'entreprenøren': ('entreprenør',),
'entreprenørene': ('entreprenør',),
'entreprenører': ('entreprenør',),
'entreprenørfirma': ('entreprenørfirma',),
'entreprenørfirmaene': ('entreprenørfirma',),
'entreprenørfirmaer': ('entreprenørfirma',),
'entreprenørfirmaet': ('entreprenørfirma',),
'entreprise': ('entreprise',),
'entreprisen': ('entreprise',),
'entreprisene': ('entreprise',),
'entrepriser': ('entreprise',),
'entusiasme': ('entusiasme',),
'entusiasmen': ('entusiasme',),
'entusiasmene': ('entusiasme',),
'entusiasmer': ('entusiasme',),
'entusiast': ('entusiast',),
'entusiasten': ('entusiast',),
'entusiastene': ('entusiast',),
'entusiaster': ('entusiast',),
'envegskjøring': ('envegskjøring',),
'envegskjøringa': ('envegskjøring',),
'envegskjøringen': ('envegskjøring',),
'envegskjøringene': ('envegskjøring',),
'envegskjøringer': ('envegskjøring',),
'envegskommunikasjon': ('envegskommunikasjon',),
'envegskommunikasjonen': ('envegskommunikasjon',),
'envegskommunikasjonene': ('envegskommunikasjon',),
'envegskommunikasjoner': ('envegskommunikasjon',),
'enveiskjøring': ('enveiskjøring',),
'enveiskjøringa': ('enveiskjøring',),
'enveiskjøringen': ('enveiskjøring',),
'enveiskjøringene': ('enveiskjøring',),
'enveiskjøringer': ('enveiskjøring',),
'enveiskommunikasjon': ('enveiskommunikasjon',),
'enveiskommunikasjonen': ('enveiskommunikasjon',),
'enveiskommunikasjonene': ('enveiskommunikasjon',),
'enveiskommunikasjoner': ('enveiskommunikasjon',),
'envoyeen': ('envoyé',),
'envoyeene': ('envoyé',),
'envoyeer': ('envoyé',),
'envoyé': ('envoyé',),
'envoyéen': ('envoyé',),
'envoyéene': ('envoyé',),
'envoyéer': ('envoyé',),
'enzym': ('enzym',),
'enzyma': ('enzym',),
'enzymene': ('enzym',),
'enzymer': ('enzym',),
'enzymet': ('enzym',),
'enøre': ('enøre',),
'enøren': ('enøre',),
'enørene': ('enøre',),
'enører': ('enøre',),
'enøring': ('enøring',),
'enøringen': ('enøring',),
'enøringene': ('enøring',),
'enøringer': ('enøring',),
'eolsharpa': ('eolsharpe',),
'eolsharpe': ('eolsharpe',),
'eolsharpen': ('eolsharpe',),
'eolsharpene': ('eolsharpe',),
'eolsharper': ('eolsharpe',),
'ep': ('ep',),
'epen': ('ep',),
'epene': ('ep',),
'eper': ('ep',),
'ep-plata': ('ep-plate',),
'ep-plate': ('ep-plate',),
'ep-platen': ('ep-plate',),
'ep-platene': ('ep-plate',),
'ep-plater': ('ep-plate',),
'epidemi': ('epidemi',),
'epidemien': ('epidemi',),
'epidemiene': ('epidemi',),
'epidemier': ('epidemi',),
'epiderm': ('epiderm',),
'epidermen': ('epiderm',),
'epidermene': ('epiderm',),
'epidermer': ('epiderm',),
'epidiaskop': ('epidiaskop',),
'epidiaskopa': ('epidiaskop',),
'epidiaskopene': ('epidiaskop',),
'epidiaskoper': ('epidiaskop',),
'epidiaskopet': ('epidiaskop',),
'epiduralanestesi': ('epiduralanestesi',),
'epiduralanestesien': ('epiduralanestesi',),
'epiduralanestesiene': ('epiduralanestesi',),
'epiduralanestesier': ('epiduralanestesi',),
'epifor': ('epifor',),
'epiforen': ('epifor',),
'epiforene': ('epifor',),
'epiforer': ('epifor',),
'epifytt': ('epifytt',),
'epifytten': ('epifytt',),
'epifyttene': ('epifytt',),
'epifytter': ('epifytt',),
'epigon': ('epigon',),
'epigonen': ('epigon',),
'epigonene': ('epigon',),
'epigoner': ('epigon',),
'epigondikting': ('epigondikting',),
'epigondiktinga': ('epigondikting',),
'epigondiktingen': ('epigondikting',),
'epigondiktingene': ('epigondikting',),
'epigondiktinger': ('epigondikting',),
'epigondiktning': ('epigondiktning',),
'epigondiktninga': ('epigondiktning',),
'epigondiktningen': ('epigondiktning',),
'epigondiktningene': ('epigondiktning',),
'epigondiktninger': ('epigondiktning',),
'epigoneri': ('epigoneri',),
'epigoneria': ('epigoneri',),
'epigoneriene': ('epigoneri',),
'epigoneriet': ('epigoneri',),
'epigraf': ('epigraf',),
'epigrafen': ('epigraf',),
'epigrafene': ('epigraf',),
'epigrafer': ('epigraf',),
'epigrafiker': ('epigrafiker',),
'epigrafikere': ('epigrafiker',),
'epigrafikeren': ('epigrafiker',),
'epigrafikerer': ('epigrafiker',),
'epigrafikerne': ('epigrafiker',),
'epigrafikk': ('epigrafikk',),
'epigrafikken': ('epigrafikk',),
'epigrafikkene': ('epigrafikk',),
'epigrafikker': ('epigrafikk',),
'epigram': ('epigram',),
'epigramma': ('epigram',),
'epigrammene': ('epigram',),
'epigrammer': ('epigram',),
'epigrammet': ('epigram',),
'epiker': ('epiker',),
'epikere': ('epiker',),
'epikeren': ('epiker',),
'epikerer': ('epiker',),
'epikerne': ('epiker',),
'epikk': ('epikk',),
'epikken': ('epikk',),
'epikkene': ('epikk',),
'epikker': ('epikk',),
'epikureer': ('epikureer',),
'epikureere': ('epikureer',),
'epikureeren': ('epikureer',),
'epikureerer': ('epikureer',),
'epikureerne': ('epikureer',),
'epikureisme': ('epikureisme',),
'epikureismen': ('epikureisme',),
'epikureismene': ('epikureisme',),
'epikureismer': ('epikureisme',),
'epilepsi': ('epilepsi',),
'epilepsien': ('epilepsi',),
'epilepsiene': ('epilepsi',),
'epilepsier': ('epilepsi',),
'epileptiker': ('epileptiker',),
'epileptikere': ('epileptiker',),
'epileptikeren': ('epileptiker',),
'epileptikerer': ('epileptiker',),
'epileptikerne': ('epileptiker',),
'epilog': ('epilog',),
'epilogen': ('epilog',),
'epilogene': ('epilog',),
'epiloger': ('epilog',),
'episkop': ('episkop',),
'episkopa': ('episkop',),
'episkopene': ('episkop',),
'episkoper': ('episkop',),
'episkopet': ('episkop',),
'episkopat': ('episkopat',),
'episkopata': ('episkopat',),
'episkopatene': ('episkopat',),
'episkopater': ('episkopat',),
'episkopatet': ('episkopat',),
'episode': ('episode',),
'episoden': ('episode',),
'episodene': ('episode',),
'episoder': ('episode',),
'epistel': ('epistel',),
'epistelen': ('epistel',),
'epistlene': ('epistel',),
'epistler': ('epistel',),
'epistemologi': ('epistemologi',),
'epistemologien': ('epistemologi',),
'epistemologiene': ('epistemologi',),
'epistemologier': ('epistemologi',),
'epitaf': ('epitaf',),
'epitafa': ('epitaf',),
'epitafene': ('epitaf',),
'epitafer': ('epitaf',),
'epitafet': ('epitaf',),
'epitafia': ('epitafium',),
'epitafiene': ('epitafium',),
'epitafier': ('epitafium',),
'epitafiet': ('epitafium',),
'epitafium': ('epitafium',),
'epitel': ('epitel',),
'epitela': ('epitel',),
'epitelene': ('epitel',),
'epiteler': ('epitel',),
'epitelet': ('epitel',),
'epitelcella': ('epitelcelle',),
'epitelcelle': ('epitelcelle',),
'epitelcellen': ('epitelcelle',),
'epitelcellene': ('epitelcelle',),
'epitelceller': ('epitelcelle',),
'epitelvev': ('epitelvev',),
'epitelveva': ('epitelvev',),
'epitelvevene': ('epitelvev',),
'epitelvevet': ('epitelvev',),
'epitet': ('epitet',),
'epiteta': ('epitet',),
'epitetene': ('epitet',),
'epiteter': ('epitet',),
'epitetet': ('epitet',),
'epiteta': ('epiteton',),
'epitetaene': ('epiteton',),
'epiteton': ('epiteton',),
'epitetonet': ('epiteton',),
'epiteton ornans': ('epiteton ornans',),
'epla': ('eple',),
'eple': ('eple',),
'eplene': ('eple',),
'epler': ('eple',),
'eplet': ('eple',),
'eplekaka': ('eplekake',),
'eplekake': ('eplekake',),
'eplekaken': ('eplekake',),
'eplekakene': ('eplekake',),
'eplekaker': ('eplekake',),
'eplekart': ('eplekart',),
'eplekarten': ('eplekart',),
'eplekartene': ('eplekart',),
'eplekarter': ('eplekart',),
'eplemos': ('eplemos',),
'eplemosen': ('eplemos',),
'eplemosene': ('eplemos',),
'eplemoser': ('eplemos',),
'eplemost': ('eplemost',),
'eplemosten': ('eplemost',),
'eplemostene': ('eplemost',),
'eplemoster': ('eplemost',),
'eplenikkers': ('eplenikkers',),
'eplenikkersen': ('eplenikkers',),
'eplenikkersene': ('eplenikkers',),
'eplenikkerser': ('eplenikkers',),
'eplepai': ('eplepai',),
'eplepaien': ('eplepai',),
'eplepaiene': ('eplepai',),
'eplepaier': ('eplepai',),
'eplesider': ('eplesider',),
'eplesidere': ('eplesider',),
'eplesideren': ('eplesider',),
'eplesiderne': ('eplesider',),
'eplesidre': ('eplesider',),
'eplesidrene': ('eplesider',),
'eplesidrer': ('eplesider',),
'epleskrott': ('epleskrott',),
'epleskrotten': ('epleskrott',),
'epleskrottene': ('epleskrott',),
'epleskrotter': ('epleskrott',),
'epleslang': ('epleslang',),
'epleslangen': ('epleslang',),
'epleslangene': ('epleslang',),
'epleslanger': ('epleslang',),
'epleveps': ('epleveps',),
'eplevepsen': ('epleveps',),
'eplevepsene': ('epleveps',),
'eplevepser': ('epleveps',),
'epoke': ('epoke',),
'epoken': ('epoke',),
'epokene': ('epoke',),
'epoker': ('epoke',),
'epoksy': ('epoksy',),
'epoksyen': ('epoksy',),
'epoksyene': ('epoksy',),
'epoksyer': ('epoksy',),
'epoksybelegg': ('epoksybelegg',),
'epoksybelegga': ('epoksybelegg',),
'epoksybeleggene': ('epoksybelegg',),
'epoksybelegget': ('epoksybelegg',),
'epoksyharpiks': ('epoksyharpiks',),
'epoksyharpiksen': ('epoksyharpiks',),
'epoksyharpiksene': ('epoksyharpiks',),
'epoksyharpikser': ('epoksyharpiks',),
'epoksylakk': ('epoksylakk',),
'epoksylakken': ('epoksylakk',),
'epoksylakkene': ('epoksylakk',),
'epoksylakker': ('epoksylakk',),
'epoksylim': ('epoksylim',),
'epoksylima': ('epoksylim',),
'epoksylimene': ('epoksylim',),
'epoksylimet': ('epoksylim',),
'epoksymaling': ('epoksymaling',),
'epoksymalinga': ('epoksymaling',),
'epoksymalingen': ('epoksymaling',),
'epoksymalingene': ('epoksymaling',),
'epoksymalinger': ('epoksymaling',),
'epos': ('epos',),
'eposa': ('epos',),
'eposene': ('epos',),
'eposer': ('epos',),
'eposet': ('epos',),
'epålett': ('epålett',),
'epåletten': ('epålett',),
'epålettene': ('epålett',),
'epåletter': ('epålett',),
'erbium': ('erbium',),
'erbiuma': ('erbium',),
'erbiumene': ('erbium',),
'erbiumet': ('erbium',),
'ereksjon': ('ereksjon',),
'ereksjonen': ('ereksjon',),
'ereksjonene': ('ereksjon',),
'ereksjoner': ('ereksjon',),
'eremitasje': ('eremitasje',),
'eremitasjen': ('eremitasje',),
'eremitasjene': ('eremitasje',),
'eremitasjer': ('eremitasje',),
'eremitt': ('eremitt',),
'eremitten': ('eremitt',),
'eremittene': ('eremitt',),
'eremitter': ('eremitt',),
'eremittbolig': ('eremittbolig',),
'eremittboligen': ('eremittbolig',),
'eremittboligene': ('eremittbolig',),
'eremittboliger': ('eremittbolig',),
'eremittkreps': ('eremittkreps',),
'eremittkrepsen': ('eremittkreps',),
'eremittkrepsene': ('eremittkreps',),
'eremittkrepser': ('eremittkreps',),
'erfaring': ('erfaring',),
'erfaringa': ('erfaring',),
'erfaringen': ('erfaring',),
'erfaringene': ('erfaring',),
'erfaringer': ('erfaring',),
'erfaringsbakgrunn': ('erfaringsbakgrunn',),
'erfaringsbakgrunnen': ('erfaringsbakgrunn',),
'erfaringsbakgrunnene': ('erfaringsbakgrunn',),
'erfaringsbakgrunner': ('erfaringsbakgrunn',),
'erfaringsteologi': ('erfaringsteologi',),
'erfaringsteologien': ('erfaringsteologi',),
'erfaringsteologiene': ('erfaringsteologi',),
'erfaringsteologier': ('erfaringsteologi',),
'erfaringsverden': ('erfaringsverden',),
'erfaringsverdenen': ('erfaringsverden',),
'erfaringsverdenene': ('erfaringsverden',),
'erfaringsverdener': ('erfaringsverden',),
'erfaringsvitenskap': ('erfaringsvitenskap',),
'erfaringsvitenskapen': ('erfaringsvitenskap',),
'erfaringsvitenskapene': ('erfaringsvitenskap',),
'erfaringsvitenskaper': ('erfaringsvitenskap',),
'erfaringsvitskap': ('erfaringsvitskap',),
'erfaringsvitskapen': ('erfaringsvitskap',),
'erfaringsvitskapene': ('erfaringsvitskap',),
'erfaringsvitskaper': ('erfaringsvitskap',),
'erg': ('erg',),
'ergen': ('erg',),
'ergene': ('erg',),
'ergativ': ('ergativ',),
'ergativen': ('ergativ',),
'ergativene': ('ergativ',),
'ergativer': ('ergativ',),
'ergometer': ('ergometer',),
'ergometeret': ('ergometer',),
'ergometra': ('ergometer',),
'ergometre': ('ergometer',),
'ergometrene': ('ergometer',),
'ergometret': ('ergometer',),
'ergometersykkel': ('ergometersykkel',),
'ergometersykkelen': ('ergometersykkel',),
'ergometersyklene': ('ergometersykkel',),
'ergometersykler': ('ergometersykkel',),
'ergonomi': ('ergonomi',),
'ergonomien': ('ergonomi',),
'ergonomiene': ('ergonomi',),
'ergonomier': ('ergonomi',),
'ergoterapeut': ('ergoterapeut',),
'ergoterapeuten': ('ergoterapeut',),
'ergoterapeutene': ('ergoterapeut',),
'ergoterapeuter': ('ergoterapeut',),
'ergoterapi': ('ergoterapi',),
'ergoterapien': ('ergoterapi',),
'ergoterapiene': ('ergoterapi',),
'ergoterapier': ('ergoterapi',),
'ergrelse': ('ergrelse',),
'ergrelsen': ('ergrelse',),
'ergrelsene': ('ergrelse',),
'ergrelser': ('ergrelse',),
'erindring': ('erindring',),
'erindringa': ('erindring',),
'erindringen': ('erindring',),
'erindringene': ('erindring',),
'erindringer': ('erindring',),
'erindringsbilda': ('erindringsbilde',),
'erindringsbilde': ('erindringsbilde',),
'erindringsbildene': ('erindringsbilde',),
'erindringsbilder': ('erindringsbilde',),
'erindringsbildet': ('erindringsbilde',),
'erindringsforskyvning': ('erindringsforskyvning',),
'erindringsforskyvninga': ('erindringsforskyvning',),
'erindringsforskyvningen': ('erindringsforskyvning',),
'erindringsforskyvningene': ('erindringsforskyvning',),
'erindringsforskyvninger': ('erindringsforskyvning',),
'erindringsgava': ('erindringsgave',),
'erindringsgave': ('erindringsgave',),
'erindringsgaven': ('erindringsgave',),
'erindringsgavene': ('erindringsgave',),
'erindringsgaver': ('erindringsgave',),
'erindringstegn': ('erindringstegn',),
'erindringstegna': ('erindringstegn',),
'erindringstegnene': ('erindringstegn',),
'erindringstegnet': ('erindringstegn',),
'erinnye': ('erinnye',),
'erinnyen': ('erinnye',),
'erinnyene': ('erinnye',),
'erinnyer': ('erinnye',),
'eritreer': ('eritreer',),
'eritreere': ('eritreer',),
'eritreeren': ('eritreer',),
'eritreerer': ('eritreer',),
'eritreerne': ('eritreer',),
'erkebiskop': ('erkebiskop',),
'erkebiskopen': ('erkebiskop',),
'erkebiskopene': ('erkebiskop',),
'erkebiskoper': ('erkebiskop',),
'erkebisp': ('erkebisp',),
'erkebispen': ('erkebisp',),
'erkebispene': ('erkebisp',),
'erkebisper': ('erkebisp',),
'erkebispdømma': ('erkebispdømme',),
'erkebispdømme': ('erkebispdømme',),
'erkebispdømmene': ('erkebispdømme',),
'erkebispdømmer': ('erkebispdømme',),
'erkebispdømmet': ('erkebispdømme',),
'erkebispedømma': ('erkebispedømme',),
'erkebispedømme': ('erkebispedømme',),
'erkebispedømmene': ('erkebispedømme',),
'erkebispedømmer': ('erkebispedømme',),
'erkebispedømmet': ('erkebispedømme',),
'erkebispegard': ('erkebispegard',),
'erkebispegarden': ('erkebispegard',),
'erkebispegardene': ('erkebispegard',),
'erkebispegarder': ('erkebispegard',),
'erkebispegård': ('erkebispegård',),
'erkebispegården': ('erkebispegård',),
'erkebispegårdene': ('erkebispegård',),
'erkebispegårder': ('erkebispegård',),
'erkebispeseta': ('erkebispesete',),
'erkebispesete': ('erkebispesete',),
'erkebispesetene': ('erkebispesete',),
'erkebispeseter': ('erkebispesete',),
'erkebispesetet': ('erkebispesete',),
'erkebispestol': ('erkebispestol',),
'erkebispestolen': ('erkebispestol',),
'erkebispestolene': ('erkebispestol',),
'erkebispestoler': ('erkebispestol',),
'erkebispgard': ('erkebispgard',),
'erkebispgarden': ('erkebispgard',),
'erkebispgardene': ('erkebispgard',),
'erkebispgarder': ('erkebispgard',),
'erkebispgård': ('erkebispgård',),
'erkebispgården': ('erkebispgård',),
'erkebispgårdene': ('erkebispgård',),
'erkebispgårder': ('erkebispgård',),
'erkebispseta': ('erkebispsete',),
'erkebispsete': ('erkebispsete',),
'erkebispsetene': ('erkebispsete',),
'erkebispseter': ('erkebispsete',),
'erkebispsetet': ('erkebispsete',),
'erkebispstol': ('erkebispstol',),
'erkebispstolen': ('erkebispstol',),
'erkebispstolene': ('erkebispstol',),
'erkebispstoler': ('erkebispstol',),
'erkeengel': ('erkeengel',),
'erkeengelen': ('erkeengel',),
'erkeenglene': ('erkeengel',),
'erkeengler': ('erkeengel',),
'erkefiende': ('erkefiende',),
'erkefienden': ('erkefiende',),
'erkefiendene': ('erkefiende',),
'erkefiender': ('erkefiende',),
'erkefjols': ('erkefjols',),
'erkefjolsa': ('erkefjols',),
'erkefjolsene': ('erkefjols',),
'erkefjolset': ('erkefjols',),
'erkehertug': ('erkehertug',),
'erkehertugen': ('erkehertug',),
'erkehertugene': ('erkehertug',),
'erkehertuger': ('erkehertug',),
'erkekjeltring': ('erkekjeltring',),
'erkekjeltringen': ('erkekjeltring',),
'erkekjeltringene': ('erkekjeltring',),
'erkekjeltringer': ('erkekjeltring',),
'erkesludder': ('erkesludder',),
'erkesluddera': ('erkesludder',),
'erkesluddere': ('erkesludder',),
'erkesludderene': ('erkesludder',),
'erkesludderet': ('erkesludder',),
'erkesludderne': ('erkesludder',),
'erketosk': ('erketosk',),
'erketosken': ('erketosk',),
'erketoskene': ('erketosk',),
'erketosker': ('erketosk',),
'erketufs': ('erketufs',),
'erketufsen': ('erketufs',),
'erketufsene': ('erketufs',),
'erketufser': ('erketufs',),
'erkjennelse': ('erkjennelse',),
'erkjennelsen': ('erkjennelse',),
'erkjennelsene': ('erkjennelse',),
'erkjennelser': ('erkjennelse',),
'erkjennelsesteori': ('erkjennelsesteori',),
'erkjennelsesteorien': ('erkjennelsesteori',),
'erkjennelsesteoriene': ('erkjennelsesteori',),
'erkjennelsesteorier': ('erkjennelsesteori',),
'erkjennelsestrang': ('erkjennelsestrang',),
'erkjennelsestrangen': ('erkjennelsestrang',),
'erkjennelsestrangene': ('erkjennelsestrang',),
'erkjennelsestranger': ('erkjennelsestrang',),
'erkjentlighet': ('erkjentlighet',),
'erkjentligheta': ('erkjentlighet',),
'erkjentligheten': ('erkjentlighet',),
'erkjentlighetene': ('erkjentlighet',),
'erkjentligheter': ('erkjentlighet',),
'erkjentlighetsgava': ('erkjentlighetsgave',),
'erkjentlighetsgave': ('erkjentlighetsgave',),
'erkjentlighetsgaven': ('erkjentlighetsgave',),
'erkjentlighetsgavene': ('erkjentlighetsgave',),
'erkjentlighetsgaver': ('erkjentlighetsgave',),
'erklæring': ('erklæring',),
'erklæringa': ('erklæring',),
'erklæringen': ('erklæring',),
'erklæringene': ('erklæring',),
'erklæringer': ('erklæring',),
'erla': ('erle',),
'erle': ('erle',),
'erlen': ('erle',),
'erlene': ('erle',),
'erler': ('erle',),
'erma': ('erme',),
'erme': ('erme',),
'ermene': ('erme',),
'ermer': ('erme',),
'ermet': ('erme',),
'ermebeskytter': ('ermebeskytter',),
'ermebeskyttere': ('ermebeskytter',),
'ermebeskytteren': ('ermebeskytter',),
'ermebeskytterer': ('ermebeskytter',),
'ermebeskytterne': ('ermebeskytter',),
'ermeforkle': ('ermeforkle',),
'ermeforkleet': ('ermeforkle',),
'ermeforklær': ('ermeforkle',),
'ermeforklærne': ('ermeforkle',),
'ermehol': ('ermehol',),
'ermehola': ('ermehol',),
'ermeholene': ('ermehol',),
'ermeholet': ('ermehol',),
'ermehull': ('ermehull',),
'ermehulla': ('ermehull',),
'ermehullene': ('ermehull',),
'ermehuller': ('ermehull',),
'ermehullet': ('ermehull',),
'ermelinning': ('ermelinning',),
'ermelinninga': ('ermelinning',),
'ermelinningen': ('ermelinning',),
'ermelinningene': ('ermelinning',),
'ermelinninger': ('ermelinning',),
'ernæring': ('ernæring',),
'ernæringa': ('ernæring',),
'ernæringen': ('ernæring',),
'ernæringene': ('ernæring',),
'ernæringer': ('ernæring',),
'ernæringsekspert': ('ernæringsekspert',),
'ernæringseksperten': ('ernæringsekspert',),
'ernæringsekspertene': ('ernæringsekspert',),
'ernæringseksperter': ('ernæringsekspert',),
'ernæringsfysiolog': ('ernæringsfysiolog',),
'ernæringsfysiologen': ('ernæringsfysiolog',),
'ernæringsfysiologene': ('ernæringsfysiolog',),
'ernæringsfysiologer': ('ernæringsfysiolog',),
'ernæringslæra': ('ernæringslære',),
'ernæringslære': ('ernæringslære',),
'ernæringslæren': ('ernæringslære',),
'ernæringslærene': ('ernæringslære',),
'ernæringslærer': ('ernæringslære',),
'ernæringspolitikk': ('ernæringspolitikk',),
'ernæringspolitikken': ('ernæringspolitikk',),
'ernæringspolitikkene': ('ernæringspolitikk',),
'ernæringspolitikker': ('ernæringspolitikk',),
'ernæringssituasjon': ('ernæringssituasjon',),
'ernæringssituasjonen': ('ernæringssituasjon',),
'ernæringssituasjonene': ('ernæringssituasjon',),
'ernæringssituasjoner': ('ernæringssituasjon',),
'ernæringssjukdom': ('ernæringssjukdom',),
'ernæringssjukdommen': ('ernæringssjukdom',),
'ernæringssjukdommene': ('ernæringssjukdom',),
'ernæringssjukdommer': ('ernæringssjukdom',),
'ernæringssykdom': ('ernæringssykdom',),
'ernæringssykdommen': ('ernæringssykdom',),
'ernæringssykdommene': ('ernæringssykdom',),
'ernæringssykdommer': ('ernæringssykdom',),
'ernæringsvitenskap': ('ernæringsvitenskap',),
'ernæringsvitenskapen': ('ernæringsvitenskap',),
'ernæringsvitenskapene': ('ernæringsvitenskap',),
'ernæringsvitenskaper': ('ernæringsvitenskap',),
'ernæringsvitskap': ('ernæringsvitskap',),
'ernæringsvitskapen': ('ernæringsvitskap',),
'ernæringsvitskapene': ('ernæringsvitskap',),
'ernæringsvitskaper': ('ernæringsvitskap',),
'erobrer': ('erobrer',),
'erobrere': ('erobrer',),
'erobreren': ('erobrer',),
'erobrerer': ('erobrer',),
'erobrerne': ('erobrer',),
'erobring': ('erobring',),
'erobringa': ('erobring',),
'erobringen': ('erobring',),
'erobringene': ('erobring',),
'erobringer': ('erobring',),
'erobringslyst': ('erobringslyst',),
'erobringslysta': ('erobringslyst',),
'erobringslysten': ('erobringslyst',),
'erobringslystene': ('erobringslyst',),
'erobringslyster': ('erobringslyst',),
'erobringstog': ('erobringstog',),
'erobringstoga': ('erobringstog',),
'erobringstogene': ('erobringstog',),
'erobringstoget': ('erobringstog',),
'erobringstokt': ('erobringstokt',),
'erobringstokta': ('erobringstokt',),
'erobringstoktene': ('erobringstokt',),
'erobringstokter': ('erobringstokt',),
'erobringstoktet': ('erobringstokt',),
'eros': ('eros',),
'erosen': ('eros',),
'erosene': ('eros',),
'eroser': ('eros',),
'erosjon': ('erosjon',),
'erosjonen': ('erosjon',),
'erosjonene': ('erosjon',),
'erosjoner': ('erosjon',),
'erot': ('erot',),
'eroten': ('erot',),
'erotene': ('erot',),
'eroter': ('erot',),
'erotiker': ('erotiker',),
'erotikere': ('erotiker',),
'erotikeren': ('erotiker',),
'erotikerer': ('erotiker',),
'erotikerne': ('erotiker',),
'erotikk': ('erotikk',),
'erotikken': ('erotikk',),
'erotikkene': ('erotikk',),
'erotikker': ('erotikk',),
'erotoman': ('erotoman',),
'erotomanen': ('erotoman',),
'erotomanene': ('erotoman',),
'erotomaner': ('erotoman',),
'erotomani': ('erotomani',),
'erotomanien': ('erotomani',),
'erotomaniene': ('erotomani',),
'erotomanier': ('erotomani',),
'erstatning': ('erstatning',),
'erstatninga': ('erstatning',),
'erstatningen': ('erstatning',),
'erstatningene': ('erstatning',),
'erstatninger': ('erstatning',),
'erstatningsansvar': ('erstatningsansvar',),
'erstatningsansvara': ('erstatningsansvar',),
'erstatningsansvarene': ('erstatningsansvar',),
'erstatningsansvaret': ('erstatningsansvar',),
'erstatningskrav': ('erstatningskrav',),
'erstatningskrava': ('erstatningskrav',),
'erstatningskravene': ('erstatningskrav',),
'erstatningskravet': ('erstatningskrav',),
'erstatningsplikt': ('erstatningsplikt',),
'erstatningsplikta': ('erstatningsplikt',),
'erstatningsplikten': ('erstatningsplikt',),
'erstatningspliktene': ('erstatningsplikt',),
'erstatningsplikter': ('erstatningsplikt',),
'erstatningssak': ('erstatningssak',),
'erstatningssaka': ('erstatningssak',),
'erstatningssaken': ('erstatningssak',),
'erstatningssakene': ('erstatningssak',),
'erstatningssaker': ('erstatningssak',),
'erstatningssum': ('erstatningssum',),
'erstatningssummen': ('erstatningssum',),
'erstatningssummene': ('erstatningssum',),
'erstatningssummer': ('erstatningssum',),
'erstatningssøksmål': ('erstatningssøksmål',),
'erstatningssøksmåla': ('erstatningssøksmål',),
'erstatningssøksmålene': ('erstatningssøksmål',),
'erstatningssøksmålet': ('erstatningssøksmål',),
'ert': ('ert',),
'erta': ('ert',),
'erten': ('ert',),
'ertene': ('ert',),
'erter': ('ert',),
'ert': ('ert',),
'erteblomst': ('erteblomst',),
'erteblomsten': ('erteblomst',),
'erteblomstene': ('erteblomst',),
'erteblomster': ('erteblomst',),
'erteblomstfamilie': ('erteblomstfamilie',),
'erteblomstfamilien': ('erteblomstfamilie',),
'erteblomstfamiliene': ('erteblomstfamilie',),
'erteblomstfamilier': ('erteblomstfamilie',),
'ertekrok': ('ertekrok',),
'ertekroken': ('ertekrok',),
'ertekrokene': ('ertekrok',),
'ertekroker': ('ertekrok',),
'ertelyst': ('ertelyst',),
'ertelysta': ('ertelyst',),
'ertelysten': ('ertelyst',),
'ertelystene': ('ertelyst',),
'ertelyster': ('ertelyst',),
'erteplanta': ('erteplante',),
'erteplante': ('erteplante',),
'erteplanten': ('erteplante',),
'erteplantene': ('erteplante',),
'erteplanter': ('erteplante',),
'erteris': ('erteris',),
'erterisa': ('erteris',),
'erterisene': ('erteris',),
'erteriset': ('erteris',),
'ertersuppa': ('ertersuppe',),
'ertersuppe': ('ertersuppe',),
'ertersuppen': ('ertersuppe',),
'ertersuppene': ('ertersuppe',),
'ertersupper': ('ertersuppe',),
'erteskolm': ('erteskolm',),
'erteskolma': ('erteskolm',),
'erteskolmen': ('erteskolm',),
'erteskolmene': ('erteskolm',),
'erteskolmer': ('erteskolm',),
'ertestuing': ('ertestuing',),
'ertestuinga': ('ertestuing',),
'ertestuingen': ('ertestuing',),
'ertestuingene': ('ertestuing',),
'ertestuinger': ('ertestuing',),
'ertesuppa': ('ertesuppe',),
'ertesuppe': ('ertesuppe',),
'ertesuppen': ('ertesuppe',),
'ertesuppene': ('ertesuppe',),
'ertesupper': ('ertesuppe',),
'ertevikler': ('ertevikler',),
'erteviklere': ('ertevikler',),
'ertevikleren': ('ertevikler',),
'erteviklerer': ('ertevikler',),
'erteviklerne': ('ertevikler',),
'ertog': ('ertog',),
'ertogen': ('ertog',),
'ertogene': ('ertog',),
'ertoger': ('ertog',),
'erts': ('erts',),
'ertsen': ('erts',),
'ertsene': ('erts',),
'ertser': ('erts',),
'ertsforekomst': ('ertsforekomst',),
'ertsforekomsten': ('ertsforekomst',),
'ertsforekomstene': ('ertsforekomst',),
'ertsforekomster': ('ertsforekomst',),
'ertsmineral': ('ertsmineral',),
'ertsminerala': ('ertsmineral',),
'ertsmineralene': ('ertsmineral',),
'ertsmineraler': ('ertsmineral',),
'ertsmineralet': ('ertsmineral',),
'ertssjeider': ('ertssjeider',),
'ertssjeidere': ('ertssjeider',),
'ertssjeideren': ('ertssjeider',),
'ertssjeiderer': ('ertssjeider',),
'ertssjeiderne': ('ertssjeider',),
'erupsjon': ('erupsjon',),
'erupsjonen': ('erupsjon',),
'erupsjonene': ('erupsjon',),
'erupsjoner': ('erupsjon',),
'eruptiv': ('eruptiv',),
'eruptiva': ('eruptiv',),
'eruptivene': ('eruptiv',),
'eruptiver': ('eruptiv',),
'eruptivet': ('eruptiv',),
'erverv': ('erverv',),
'erverva': ('erverv',),
'ervervene': ('erverv',),
'ervervet': ('erverv',),
'ervervelse': ('ervervelse',),
'ervervelsen': ('ervervelse',),
'ervervelsene': ('ervervelse',),
'ervervelser': ('ervervelse',),
'ervervsevna': ('ervervsevne',),
'ervervsevne': ('ervervsevne',),
'ervervsevnen': ('ervervsevne',),
'ervervsevnene': ('ervervsevne',),
'ervervsevner': ('ervervsevne',),
'ervervskommune': ('ervervskommune',),
'ervervskommunen': ('ervervskommune',),
'ervervskommunene': ('ervervskommune',),
'ervervskommuner': ('ervervskommune',),
'escudo': ('escudo',),
'escudoen': ('escudo',),
'escudoene': ('escudo',),
'escudos': ('escudo',),
'esel': ('esel',),
'eselet': ('esel',),
'esla': ('esel',),
'eslene': ('esel',),
'esler': ('esel',),
'eslet': ('esel',),
'eselføl': ('eselføl',),
'eselføla': ('eselføl',),
'eselfølene': ('eselføl',),
'eselfølet': ('eselføl',),
'eselføll': ('eselføll',),
'eselfølla': ('eselføll',),
'eselføllene': ('eselføll',),
'eselføllet': ('eselføll',),
'eselspark': ('eselspark',),
'eselsparka': ('eselspark',),
'eselsparkene': ('eselspark',),
'eselsparket': ('eselspark',),
'eseløra': ('eseløre',),
'eseløre': ('eseløre',),
'eselørene': ('eseløre',),
'eselører': ('eseløre',),
'eseløret': ('eseløre',),
'esing': ('esing',),
'esinga': ('esing',),
'esingen': ('esing',),
'esingene': ('esing',),
'esinger': ('esing',),
'eskadre': ('eskadre',),
'eskadren': ('eskadre',),
'eskadrene': ('eskadre',),
'eskadrer': ('eskadre',),
'eskadrille': ('eskadrille',),
'eskadrillen': ('eskadrille',),
'eskadrillene': ('eskadrille',),
'eskadriller': ('eskadrille',),
'eskadron': ('eskadron',),
'eskadronen': ('eskadron',),
'eskadronene': ('eskadron',),
'eskadroner': ('eskadron',),
'eskapade': ('eskapade',),
'eskapaden': ('eskapade',),
'eskapadene': ('eskapade',),
'eskapader': ('eskapade',),
'eskapisme': ('eskapisme',),
'eskapismen': ('eskapisme',),
'eskapismene': ('eskapisme',),
'eskapismer': ('eskapisme',),
'eskapist': ('eskapist',),
'eskapisten': ('eskapist',),
'eskapistene': ('eskapist',),
'eskapister': ('eskapist',),
'eskatologi': ('eskatologi',),
'eskatologien': ('eskatologi',),
'eskatologiene': ('eskatologi',),
'eskatologier': ('eskatologi',),
'eska': ('eske',),
'eske': ('eske',),
'esken': ('eske',),
'eskene': ('eske',),
'esker': ('eske',),
'eskefabrikk': ('eskefabrikk',),
'eskefabrikken': ('eskefabrikk',),
'eskefabrikkene': ('eskefabrikk',),
'eskefabrikker': ('eskefabrikk',),
'eskekartong': ('eskekartong',),
'eskekartongen': ('eskekartong',),
'eskekartongene': ('eskekartong',),
'eskekartonger': ('eskekartong',),
'eskimo': ('eskimo',),
'eskimoen': ('eskimo',),
'eskimoene': ('eskimo',),
'eskimoer': ('eskimo',),
'eskimohund': ('eskimohund',),
'eskimohunden': ('eskimohund',),
'eskimohundene': ('eskimohund',),
'eskimohunder': ('eskimohund',),
'eskimoisk': ('eskimoisk',),
'eskimoisken': ('eskimoisk',),
'eskimoiskene': ('eskimoisk',),
'eskimoisker': ('eskimoisk',),
'eskimoisk-aleutisk': ('eskimoisk-aleutisk',),
'eskimoisk-aleutisken': ('eskimoisk-aleutisk',),
'eskimoisk-aleutiskene': ('eskimoisk-aleutisk',),
'eskimoisk-aleutisker': ('eskimoisk-aleutisk',),
'eskorte': ('eskorte',),
'eskorten': ('eskorte',),
'eskortene': ('eskorte',),
'eskorter': ('eskorte',),
'eskortefartøy': ('eskortefartøy',),
'eskortefartøya': ('eskortefartøy',),
'eskortefartøyene': ('eskortefartøy',),
'eskortefartøyer': ('eskortefartøy',),
'eskortefartøyet': ('eskortefartøy',),
'esoteriker': ('esoteriker',),
'esoterikere': ('esoteriker',),
'esoterikeren': ('esoteriker',),
'esoterikerer': ('esoteriker',),
'esoterikerne': ('esoteriker',),
'espalier': ('espalier',),
'espaliera': ('espalier',),
'espalierene': ('espalier',),
'espalierer': ('espalier',),
'espalieret': ('espalier',),
'esperanto': ('esperanto',),
'esperantoen': ('esperanto',),
'esperantoene': ('esperanto',),
'esperantoer': ('esperanto',),
'esplanade': ('esplanade',),
'esplanaden': ('esplanade',),
'esplanadene': ('esplanade',),
'esplanader': ('esplanade',),
'espresso': ('espresso',),
'espressoen': ('espresso',),
'espressoene': ('espresso',),
'espressoer': ('espresso',),
'espressobar': ('espressobar',),
'espressobaren': ('espressobar',),
'espressobarene': ('espressobar',),
'espressobarer': ('espressobar',),
'espressokaffe': ('espressokaffe',),
'espressokaffen': ('espressokaffe',),
'espressokaffene': ('espressokaffe',),
'espressokaffer': ('espressokaffe',),
'espressokanna': ('espressokanne',),
'espressokanne': ('espressokanne',),
'espressokannen': ('espressokanne',),
'espressokannene': ('espressokanne',),
'espressokanner': ('espressokanne',),
'espri': ('espri',),
'esprien': ('espri',),
'espriene': ('espri',),
'esprier': ('espri',),
'esprit': ('esprit',),
'espriten': ('esprit',),
'espritene': ('esprit',),
'espriter': ('esprit',),
'ess': ('ess',),
'essen': ('ess',),
'essene': ('ess',),
'esser': ('ess',),
'ess-moll': ('ess-moll',),
'ess-mollen': ('ess-moll',),
'ess-mollene': ('ess-moll',),
'ess-moller': ('ess-moll',),
'essay': ('essay',),
'essaya': ('essay',),
'essayene': ('essay',),
'essayer': ('essay',),
'essayet': ('essay',),
'essayforfatter': ('essayforfatter',),
'essayforfattere': ('essayforfatter',),
'essayforfatteren': ('essayforfatter',),
'essayforfatterer': ('essayforfatter',),
'essayforfatterne': ('essayforfatter',),
'essayist': ('essayist',),
'essayisten': ('essayist',),
'essayistene': ('essayist',),
'essayister': ('essayist',),
'essaysamling': ('essaysamling',),
'essaysamlinga': ('essaysamling',),
'essaysamlingen': ('essaysamling',),
'essaysamlingene': ('essaysamling',),
'essaysamlinger': ('essaysamling',),
'esse': ('esse',),
'essen': ('esse',),
'essene': ('esse',),
'esser': ('esse',),
'essens': ('essens',),
'essensen': ('essens',),
'essensene': ('essens',),
'essenser': ('essens',),
'establishment': ('establishment',),
'establishmenta': ('establishment',),
'establishmentene': ('establishment',),
'establishmentet': ('establishment',),
'ester': ('ester',),
'estere': ('ester',),
'esteren': ('ester',),
'esterer': ('ester',),
'esterne': ('ester',),
'ester': ('ester',),
'estere': ('ester',),
'esteren': ('ester',),
'esterer': ('ester',),
'esterne': ('ester',),
'estet': ('estet',),
'esteten': ('estet',),
'estetene': ('estet',),
'esteter': ('estet',),
'estetiker': ('estetiker',),
'estetikere': ('estetiker',),
'estetikeren': ('estetiker',),
'estetikerer': ('estetiker',),
'estetikerne': ('estetiker',),
'estetikk': ('estetikk',),
'estetikken': ('estetikk',),
'estetikkene': ('estetikk',),
'estetikker': ('estetikk',),
'estimat': ('estimat',),
'estimata': ('estimat',),
'estimatene': ('estimat',),
'estimater': ('estimat',),
'estimatet': ('estimat',),
'estime': ('estime',),
'estimen': ('estime',),
'estimene': ('estime',),
'estimer': ('estime',),
'estlender': ('estlender',),
'estlendere': ('estlender',),
'estlenderen': ('estlender',),
'estlenderer': ('estlender',),
'estlenderne': ('estlender',),
'estlending': ('estlending',),
'estlendingen': ('estlending',),
'estlendingene': ('estlending',),
'estlendinger': ('estlending',),
'estrade': ('estrade',),
'estraden': ('estrade',),
'estradene': ('estrade',),
'estrader': ('estrade',),
'estragon': ('estragon',),
'estragonen': ('estragon',),
'estragonene': ('estragon',),
'estragoner': ('estragon',),
'estragoneddik': ('estragoneddik',),
'estragoneddiken': ('estragoneddik',),
'estragoneddikene': ('estragoneddik',),
'estragoneddiker': ('estragoneddik',),
'etableringsforbud': ('etableringsforbud',),
'etableringsforbuda': ('etableringsforbud',),
'etableringsforbudene': ('etableringsforbud',),
'etableringsforbudet': ('etableringsforbud',),
'etableringskontroll': ('etableringskontroll',),
'etableringskontrollen': ('etableringskontroll',),
'etableringskontrollene': ('etableringskontroll',),
'etableringskontroller': ('etableringskontroll',),
'etableringslov': ('etableringslov',),
'etableringsloven': ('etableringslov',),
'etableringslovene': ('etableringslov',),
'etableringslover': ('etableringslov',),
'etablissement': ('etablissement',),
'etablissementa': ('etablissement',),
'etablissementene': ('etablissement',),
'etablissementer': ('etablissement',),
'etablissementet': ('etablissement',),
'etan': ('etan',),
'etana': ('etan',),
'etanene': ('etan',),
'etanet': ('etan',),
'etanol': ('etanol',),
'etanolen': ('etanol',),
'etanolene': ('etanol',),
'etanoler': ('etanol',),
'etappe': ('etappe',),
'etappen': ('etappe',),
'etappene': ('etappe',),
'etapper': ('etappe',),
'etappetid': ('etappetid',),
'etappetida': ('etappetid',),
'etappetiden': ('etappetid',),
'etappetidene': ('etappetid',),
'etappetider': ('etappetid',),
'etasje': ('etasje',),
'etasjen': ('etasje',),
'etasjene': ('etasje',),
'etasjer': ('etasje',),
'etasjere': ('etasjere',),
'etasjeren': ('etasjere',),
'etasjerene': ('etasjere',),
'etasjerer': ('etasjere',),
'etat': ('etat',),
'etaten': ('etat',),
'etatene': ('etat',),
'etater': ('etat',),
'etatsopplæring': ('etatsopplæring',),
'etatsopplæringa': ('etatsopplæring',),
'etatsopplæringen': ('etatsopplæring',),
'etatsopplæringene': ('etatsopplæring',),
'etatsopplæringer': ('etatsopplæring',),
'etatssjef': ('etatssjef',),
'etatssjefen': ('etatssjef',),
'etatssjefene': ('etatssjef',),
'etatssjefer': ('etatssjef',),
'eter': ('eter',),
'etere': ('eter',),
'eteren': ('eter',),
'eterer': ('eter',),
'eterne': ('eter',),
'eter': ('eter',),
'etere': ('eter',),
'eteren': ('eter',),
'eterer': ('eter',),
'eterne': ('eter',),
'eterbedøvelse': ('eterbedøvelse',),
'eterbedøvelsen': ('eterbedøvelse',),
'eterbedøvelsene': ('eterbedøvelse',),
'eterbedøvelser': ('eterbedøvelse',),
'etermedia': ('etermedium',),
'etermediene': ('etermedium',),
'etermedier': ('etermedium',),
'etermediet': ('etermedium',),
'etermedium': ('etermedium',),
'eternarkose': ('eternarkose',),
'eternarkosen': ('eternarkose',),
'eternarkosene': ('eternarkose',),
'eternarkoser': ('eternarkose',),
'eternit': ('eternit',),
'eterniten': ('eternit',),
'eternitene': ('eternit',),
'eterniter': ('eternit',),
'eternitplata': ('eternitplate',),
'eternitplate': ('eternitplate',),
'eternitplaten': ('eternitplate',),
'eternitplatene': ('eternitplate',),
'eternitplater': ('eternitplate',),
'eternittak': ('eternittak',),
'eternittaka': ('eternittak',),
'eternittakene': ('eternittak',),
'eternittaket': ('eternittak',),
'etiker': ('etiker',),
'etikere': ('etiker',),
'etikeren': ('etiker',),
'etikerer': ('etiker',),
'etikerne': ('etiker',),
'etikett': ('etikett',),
'etiketten': ('etikett',),
'etikettene': ('etikett',),
'etiketter': ('etikett',),
'etikette': ('etikette',),
'etiketten': ('etikette',),
'etikettene': ('etikette',),
'etiketter': ('etikette',),
'etikettehensyn': ('etikettehensyn',),
'etikettehensyna': ('etikettehensyn',),
'etikettehensynene': ('etikettehensyn',),
'etikettehensynet': ('etikettehensyn',),
'etikk': ('etikk',),
'etikken': ('etikk',),
'etikkene': ('etikk',),
'etikker': ('etikk',),
'etiopier': ('etiopier',),
'etiopiere': ('etiopier',),
'etiopieren': ('etiopier',),
'etiopierer': ('etiopier',),
'etiopierne': ('etiopier',),
'etnograf': ('etnograf',),
'etnografen': ('etnograf',),
'etnografene': ('etnograf',),
'etnografer': ('etnograf',),
'etnografi': ('etnografi',),
'etnografien': ('etnografi',),
'etnografiene': ('etnografi',),
'etnografier': ('etnografi',),
'etnolog': ('etnolog',),
'etnologen': ('etnolog',),
'etnologene': ('etnolog',),
'etnologer': ('etnolog',),
'etnologi': ('etnologi',),
'etnologien': ('etnologi',),
'etnologiene': ('etnologi',),
'etnologier': ('etnologi',),
'etnomusikk': ('etnomusikk',),
'etnomusikken': ('etnomusikk',),
'etnomusikkene': ('etnomusikk',),
'etnomusikker': ('etnomusikk',),
'etolog': ('etolog',),
'etologen': ('etolog',),
'etologene': ('etolog',),
'etologer': ('etolog',),
'etologi': ('etologi',),
'etologien': ('etologi',),
'etologiene': ('etologi',),
'etologier': ('etologi',),
'etos': ('etos',),
'etosen': ('etos',),
'etosene': ('etos',),
'etoser': ('etos',),
'etrurer': ('etrurer',),
'etrurere': ('etrurer',),
'etrureren': ('etrurer',),
'etrurerer': ('etrurer',),
'etrurerne': ('etrurer',),
'etrusker': ('etrusker',),
'etruskere': ('etrusker',),
'etruskeren': ('etrusker',),
'etruskerer': ('etrusker',),
'etruskerne': ('etrusker',),
'etser': ('etser',),
'etsere': ('etser',),
'etseren': ('etser',),
'etserer': ('etser',),
'etserne': ('etser',),
'etsning': ('etsning',),
'etsninga': ('etsning',),
'etsningen': ('etsning',),
'etsningene': ('etsning',),
'etsninger': ('etsning',),
'ett-tal': ('ett-tal',),
'ett-tala': ('ett-tal',),
'ett-talene': ('ett-tal',),
'ett-talet': ('ett-tal',),
'ett-tall': ('ett-tall',),
'ett-talla': ('ett-tall',),
'ett-tallene': ('ett-tall',),
'ett-tallet': ('ett-tall',),
'ett-tid': ('ett-tid',),
'ett-tida': ('ett-tid',),
'ett-tiden': ('ett-tid',),
'ett-tidene': ('ett-tid',),
'ett-tider': ('ett-tid',),
'ettal': ('ettal',),
'ettala': ('ettal',),
'ettalene': ('ettal',),
'ettalet': ('ettal',),
'ettall': ('ettall',),
'ettalla': ('ettall',),
'ettallene': ('ettall',),
'ettallet': ('ettall',),
'etterbarberingsvann': ('etterbarberingsvann',),
'etterbarberingsvanna': ('etterbarberingsvann',),
'etterbarberingsvannene': ('etterbarberingsvann',),
'etterbarberingsvannet': ('etterbarberingsvann',),
'etterbarberingsvatn': ('etterbarberingsvatn',),
'etterbarberingsvatna': ('etterbarberingsvatn',),
'etterbarberingsvatnene': ('etterbarberingsvatn',),
'etterbarberingsvatnet': ('etterbarberingsvatn',),
'etterbruk': ('etterbruk',),
'etterbruka': ('etterbruk',),
'etterbruken': ('etterbruk',),
'etterbrukene': ('etterbruk',),
'etterbruker': ('etterbruk',),
'etterbruket': ('etterbruk',),
'etterbyrd': ('etterbyrd',),
'etterbyrden': ('etterbyrd',),
'etterbyrdene': ('etterbyrd',),
'etterbyrder': ('etterbyrd',),
'etterdønning': ('etterdønning',),
'etterdønningen': ('etterdønning',),
'etterdønningene': ('etterdønning',),
'etterdønninger': ('etterdønning',),
'etterforsker': ('etterforsker',),
'etterforskere': ('etterforsker',),
'etterforskeren': ('etterforsker',),
'etterforskerer': ('etterforsker',),
'etterforskerne': ('etterforsker',),
'etterforsking': ('etterforsking',),
'etterforskinga': ('etterforsking',),
'etterforskingen': ('etterforsking',),
'etterforskingene': ('etterforsking',),
'etterforskinger': ('etterforsking',),
'etterforskning': ('etterforskning',),
'etterforskninga': ('etterforskning',),
'etterforskningen': ('etterforskning',),
'etterforskningene': ('etterforskning',),
'etterforskninger': ('etterforskning',),
'etterfølgelse': ('etterfølgelse',),
'etterfølgelsen': ('etterfølgelse',),
'etterfølgelsene': ('etterfølgelse',),
'etterfølgelser': ('etterfølgelse',),
'etterfølger': ('etterfølger',),
'etterfølgere': ('etterfølger',),
'etterfølgeren': ('etterfølger',),
'etterfølgerer': ('etterfølger',),
'etterfølgerne': ('etterfølger',),
'ettergiing': ('ettergiing',),
'ettergiinga': ('ettergiing',),
'ettergiingen': ('ettergiing',),
'ettergiingene': ('ettergiing',),
'ettergiinger': ('ettergiing',),
'ettergivelse': ('ettergivelse',),
'ettergivelsen': ('ettergivelse',),
'ettergivelsene': ('ettergivelse',),
'ettergivelser': ('ettergivelse',),
'ettergivenhet': ('ettergivenhet',),
'ettergivenheta': ('ettergivenhet',),
'ettergivenheten': ('ettergivenhet',),
'ettergivenhetene': ('ettergivenhet',),
'ettergivenheter': ('ettergivenhet',),
'ettergiving': ('ettergiving',),
'ettergivinga': ('ettergiving',),
'ettergivingen': ('ettergiving',),
'ettergivingene': ('ettergiving',),
'ettergivinger': ('ettergiving',),
'etterhogst': ('etterhogst',),
'etterhogsten': ('etterhogst',),
'etterhogstene': ('etterhogst',),
'etterhogster': ('etterhogst',),
'etterhugst': ('etterhugst',),
'etterhugsten': ('etterhugst',),
'etterhugstene': ('etterhugst',),
'etterhugster': ('etterhugst',),
'etterjulsvinter': ('etterjulsvinter',),
'etterjulsvintere': ('etterjulsvinter',),
'etterjulsvinteren': ('etterjulsvinter',),
'etterjulsvinterne': ('etterjulsvinter',),
'etterjulsvintre': ('etterjulsvinter',),
'etterjulsvintrene': ('etterjulsvinter',),
'etterjulsvintrer': ('etterjulsvinter',),
'etterklang': ('etterklang',),
'etterklangen': ('etterklang',),
'etterklangene': ('etterklang',),
'etterklanger': ('etterklang',),
'etterkommer': ('etterkommer',),
'etterkommere': ('etterkommer',),
'etterkommeren': ('etterkommer',),
'etterkommerer': ('etterkommer',),
'etterkommerne': ('etterkommer',),
'etterkrav': ('etterkrav',),
'etterkrava': ('etterkrav',),
'etterkravene': ('etterkrav',),
'etterkravet': ('etterkrav',),
'etterlatenskapene': ('etterlatenskaper',),
'etterlatenskaper': ('etterlatenskaper',),
'etterlattepensjon': ('etterlattepensjon',),
'etterlattepensjonen': ('etterlattepensjon',),
'etterlattepensjonene': ('etterlattepensjon',),
'etterlattepensjoner': ('etterlattepensjon',),
'etterledd': ('etterledd',),
'etterledda': ('etterledd',),
'etterleddene': ('etterledd',),
'etterleddet': ('etterledd',),
'etterlysing': ('etterlysing',),
'etterlysinga': ('etterlysing',),
'etterlysingen': ('etterlysing',),
'etterlysingene': ('etterlysing',),
'etterlysinger': ('etterlysing',),
'etterlysning': ('etterlysning',),
'etterlysninga': ('etterlysning',),
'etterlysningen': ('etterlysning',),
'etterlysningene': ('etterlysning',),
'etterlysninger': ('etterlysning',),
'ettermann': ('ettermann',),
'ettermannen': ('ettermann',),
'ettermenn': ('ettermann',),
'ettermennene': ('ettermann',),
'ettermat': ('ettermat',),
'ettermaten': ('ettermat',),
'ettermatene': ('ettermat',),
'ettermater': ('ettermat',),
'ettermiddag': ('ettermiddag',),
'ettermiddagen': ('ettermiddag',),
'ettermiddagene': ('ettermiddag',),
'ettermiddager': ('ettermiddag',),
'ettermiddagskaffe': ('ettermiddagskaffe',),
'ettermiddagskaffen': ('ettermiddagskaffe',),
'ettermiddagskaffene': ('ettermiddagskaffe',),
'ettermiddagskaffer': ('ettermiddagskaffe',),
'ettermodning': ('ettermodning',),
'ettermodninga': ('ettermodning',),
'ettermodningen': ('ettermodning',),
'ettermodningene': ('ettermodning',),
'ettermodninger': ('ettermodning',),
'ettermæla': ('ettermæle',),
'ettermæle': ('ettermæle',),
'ettermælene': ('ettermæle',),
'ettermæler': ('ettermæle',),
'ettermælet': ('ettermæle',),
'etternavn': ('etternavn',),
'etternavna': ('etternavn',),
'etternavnene': ('etternavn',),
'etternavnet': ('etternavn',),
'etternøler': ('etternøler',),
'etternølere': ('etternøler',),
'etternøleren': ('etternøler',),
'etternølerer': ('etternøler',),
'etternølerne': ('etternøler',),
'etterord': ('etterord',),
'etterorda': ('etterord',),
'etterordene': ('etterord',),
'etterordet': ('etterord',),
'etterplaprer': ('etterplaprer',),
'etterplaprere': ('etterplaprer',),
'etterplapreren': ('etterplaprer',),
'etterplaprerer': ('etterplaprer',),
'etterplaprerne': ('etterplaprer',),
'etterpåklokskap': ('etterpåklokskap',),
'etterpåklokskapen': ('etterpåklokskap',),
'etterpåklokskapene': ('etterpåklokskap',),
'etterpåklokskaper': ('etterpåklokskap',),
'etterrakst': ('etterrakst',),
'etterraksten': ('etterrakst',),
'etterrakstene': ('etterrakst',),
'etterrakster': ('etterrakst',),
'etterrakster': ('etterrakster',),
'etterraksteren': ('etterrakster',),
'etterrakstre': ('etterrakster',),
'etterrakstrene': ('etterrakster',),
'etterrakstrer': ('etterrakster',),
'etterretning': ('etterretning',),
'etterretninga': ('etterretning',),
'etterretningen': ('etterretning',),
'etterretningene': ('etterretning',),
'etterretninger': ('etterretning',),
'etterretningsagent': ('etterretningsagent',),
'etterretningsagenten': ('etterretningsagent',),
'etterretningsagentene': ('etterretningsagent',),
'etterretningsagenter': ('etterretningsagent',),
'etterretningssatellitt': ('etterretningssatellitt',),
'etterretningssatellitten': ('etterretningssatellitt',),
'etterretningssatellittene': ('etterretningssatellitt',),
'etterretningssatellitter': ('etterretningssatellitt',),
'etterretningstjeneste': ('etterretningstjeneste',),
'etterretningstjenesten': ('etterretningstjeneste',),
'etterretningstjenestene': ('etterretningstjeneste',),
'etterretningstjenester': ('etterretningstjeneste',),
'etterri': ('etterri',),
'etterria': ('etterri',),
'etterrien': ('etterri',),
'etterriene': ('etterri',),
'etterrier': ('etterri',),
'ettersjukdom': ('ettersjukdom',),
'ettersjukdommen': ('ettersjukdom',),
'ettersjukdommene': ('ettersjukdom',),
'ettersjukdommer': ('ettersjukdom',),
'etterskott': ('etterskott',),
'etterskotta': ('etterskott',),
'etterskottene': ('etterskott',),
'etterskottet': ('etterskott',),
'etterskottsbetaling': ('etterskottsbetaling',),
'etterskottsbetalinga': ('etterskottsbetaling',),
'etterskottsbetalingen': ('etterskottsbetaling',),
'etterskottsbetalingene': ('etterskottsbetaling',),
'etterskottsbetalinger': ('etterskottsbetaling',),
'etterskottsrenta': ('etterskottsrente',),
'etterskottsrente': ('etterskottsrente',),
'etterskottsrenten': ('etterskottsrente',),
'etterskottsrentene': ('etterskottsrente',),
'etterskottsrenter': ('etterskottsrente',),
'etterskrift': ('etterskrift',),
'etterskrifta': ('etterskrift',),
'etterskriften': ('etterskrift',),
'etterskriftene': ('etterskrift',),
'etterskrifter': ('etterskrift',),
'etterskudd': ('etterskudd',),
'etterskudda': ('etterskudd',),
'etterskuddene': ('etterskudd',),
'etterskuddet': ('etterskudd',),
'etterskuddsbetaling': ('etterskuddsbetaling',),
'etterskuddsbetalinga': ('etterskuddsbetaling',),
'etterskuddsbetalingen': ('etterskuddsbetaling',),
'etterskuddsbetalingene': ('etterskuddsbetaling',),
'etterskuddsbetalinger': ('etterskuddsbetaling',),
'etterskuddsbevilgning': ('etterskuddsbevilgning',),
'etterskuddsbevilgninga': ('etterskuddsbevilgning',),
'etterskuddsbevilgningen': ('etterskuddsbevilgning',),
'etterskuddsbevilgningene': ('etterskuddsbevilgning',),
'etterskuddsbevilgninger': ('etterskuddsbevilgning',),
'etterskuddsrenta': ('etterskuddsrente',),
'etterskuddsrente': ('etterskuddsrente',),
'etterskuddsrenten': ('etterskuddsrente',),
'etterskuddsrentene': ('etterskuddsrente',),
'etterskuddsrenter': ('etterskuddsrente',),
'etterslag': ('etterslag',),
'etterslaga': ('etterslag',),
'etterslagene': ('etterslag',),
'etterslaget': ('etterslag',),
'etterslekt': ('etterslekt',),
'etterslekta': ('etterslekt',),
'etterslekten': ('etterslekt',),
'etterslektene': ('etterslekt',),
'etterslekter': ('etterslekt',),
'ettersleng': ('ettersleng',),
'etterslengen': ('ettersleng',),
'etterslengene': ('ettersleng',),
'etterslenger': ('ettersleng',),
'etterslenger': ('etterslenger',),
'etterslengere': ('etterslenger',),
'etterslengeren': ('etterslenger',),
'etterslengerer': ('etterslenger',),
'etterslengerne': ('etterslenger',),
'etterslep': ('etterslep',),
'etterslepa': ('etterslep',),
'etterslepene': ('etterslep',),
'etterslepet': ('etterslep',),
'ettersleping': ('ettersleping',),
'etterslepinga': ('ettersleping',),
'etterslepingen': ('ettersleping',),
'etterslepingene': ('ettersleping',),
'etterslepinger': ('ettersleping',),
'etterslett': ('etterslett',),
'ettersletten': ('etterslett',),
'etterslettene': ('etterslett',),
'ettersletter': ('etterslett',),
'etterslått': ('etterslått',),
'etterslåtten': ('etterslått',),
'etterslåttene': ('etterslått',),
'etterslåtter': ('etterslått',),
'ettersmak': ('ettersmak',),
'ettersmaken': ('ettersmak',),
'ettersmakene': ('ettersmak',),
'ettersmaker': ('ettersmak',),
'ettersmekk': ('ettersmekk',),
'ettersmekka': ('ettersmekk',),
'ettersmekken': ('ettersmekk',),
'ettersmekkene': ('ettersmekk',),
'ettersmekker': ('ettersmekk',),
'ettersmekket': ('ettersmekk',),
'ettersommer': ('ettersommer',),
'ettersommere': ('ettersommer',),
'ettersommeren': ('ettersommer',),
'ettersommerne': ('ettersommer',),
'ettersomre': ('ettersommer',),
'ettersomrene': ('ettersommer',),
'ettersomrer': ('ettersommer',),
'etterspell': ('etterspell',),
'etterspella': ('etterspell',),
'etterspellene': ('etterspell',),
'etterspellet': ('etterspell',),
'etterspill': ('etterspill',),
'etterspilla': ('etterspill',),
'etterspillene': ('etterspill',),
'etterspillet': ('etterspill',),
'etterspørsel': ('etterspørsel',),
'etterspørselen': ('etterspørsel',),
'etterspørslene': ('etterspørsel',),
'etterspørsler': ('etterspørsel',),
'etterspørselsoverskott': ('etterspørselsoverskott',),
'etterspørselsoverskotta': ('etterspørselsoverskott',),
'etterspørselsoverskottene': ('etterspørselsoverskott',),
'etterspørselsoverskottet': ('etterspørselsoverskott',),
'etterspørselsoverskudd': ('etterspørselsoverskudd',),
'etterspørselsoverskudda': ('etterspørselsoverskudd',),
'etterspørselsoverskuddene': ('etterspørselsoverskudd',),
'etterspørselsoverskuddet': ('etterspørselsoverskudd',),
'etterstev': ('etterstev',),
'ettersteva': ('etterstev',),
'etterstevene': ('etterstev',),
'etterstevet': ('etterstev',),
'ettersykdom': ('ettersykdom',),
'ettersykdommen': ('ettersykdom',),
'ettersykdommene': ('ettersykdom',),
'ettersykdommer': ('ettersykdom',),
'ettersyn': ('ettersyn',),
'ettersyna': ('ettersyn',),
'ettersynene': ('ettersyn',),
'ettersynet': ('ettersyn',),
'ettersøking': ('ettersøking',),
'ettersøkinga': ('ettersøking',),
'ettersøkingen': ('ettersøking',),
'ettersøkingene': ('ettersøking',),
'ettersøkinger': ('ettersøking',),
'ettersøkning': ('ettersøkning',),
'ettersøkninga': ('ettersøkning',),
'ettersøkningen': ('ettersøkning',),
'ettersøkningene': ('ettersøkning',),
'ettersøkninger': ('ettersøkning',),
'ettertanke': ('ettertanke',),
'ettertanken': ('ettertanke',),
'ettertankene': ('ettertanke',),
'ettertanker': ('ettertanke',),
'ettertid': ('ettertid',),
'ettertida': ('ettertid',),
'ettertiden': ('ettertid',),
'ettertidene': ('ettertid',),
'ettertider': ('ettertid',),
'ettertrykk': ('ettertrykk',),
'ettertrykka': ('ettertrykk',),
'ettertrykkene': ('ettertrykk',),
'ettertrykket': ('ettertrykk',),
'etterutdannelse': ('etterutdannelse',),
'etterutdannelsen': ('etterutdannelse',),
'etterutdannelsene': ('etterutdannelse',),
'etterutdannelser': ('etterutdannelse',),
'etterutdanning': ('etterutdanning',),
'etterutdanninga': ('etterutdanning',),
'etterutdanningen': ('etterutdanning',),
'etterutdanningene': ('etterutdanning',),
'etterutdanninger': ('etterutdanning',),
'etterve': ('etterve',),
'etterveen': ('etterve',),
'etterveene': ('etterve',),
'etterveer': ('etterve',),
'ettervern': ('ettervern',),
'etterverna': ('ettervern',),
'ettervernene': ('ettervern',),
'ettervernet': ('ettervern',),
'ettervirkning': ('ettervirkning',),
'ettervirkninga': ('ettervirkning',),
'ettervirkningen': ('ettervirkning',),
'ettervirkningene': ('ettervirkning',),
'ettervirkninger': ('ettervirkning',),
'etterår': ('etterår',),
'etteråra': ('etterår',),
'etterårene': ('etterår',),
'etteråret': ('etterår',),
'ettgrepskran': ('ettgrepskran',),
'ettgrepskrana': ('ettgrepskran',),
'ettgrepskranen': ('ettgrepskran',),
'ettgrepskranene': ('ettgrepskran',),
'ettgrepskraner': ('ettgrepskran',),
'ettid': ('ettid',),
'ettida': ('ettid',),
'ettiden': ('ettid',),
'ettidene': ('ettid',),
'ettider': ('ettid',),
'ettkammersystem': ('ettkammersystem',),
'ettkammersystema': ('ettkammersystem',),
'ettkammersystemene': ('ettkammersystem',),
'ettkammersystemer': ('ettkammersystem',),
'ettkammersystemet': ('ettkammersystem',),
'ettmål': ('ettmål',),
'ettmåla': ('ettmål',),
'ettmålene': ('ettmål',),
'ettmålet': ('ettmål',),
'ettpartistat': ('ettpartistat',),
'ettpartistaten': ('ettpartistat',),
'ettpartistatene': ('ettpartistat',),
'ettpartistater': ('ettpartistat',),
'ettpartisystem': ('ettpartisystem',),
'ettpartisystema': ('ettpartisystem',),
'ettpartisystemene': ('ettpartisystem',),
'ettpartisystemer': ('ettpartisystem',),
'ettpartisystemet': ('ettpartisystem',),
'ettåring': ('ettåring',),
'ettåringen': ('ettåring',),
'ettåringene': ('ettåring',),
'ettåringer': ('ettåring',),
'ettårsalder': ('ettårsalder',),
'ettårsaldere': ('ettårsalder',),
'ettårsalderen': ('ettårsalder',),
'ettårsalderer': ('ettårsalder',),
'ettårsalderne': ('ettårsalder',),
'ettårsaldre': ('ettårsalder',),
'ettårsaldrene': ('ettårsalder',),
'ettårsaldrer': ('ettårsalder',),
'ettøre': ('ettøre',),
'ettøren': ('ettøre',),
'ettørene': ('ettøre',),
'ettører': ('ettøre',),
'ettøring': ('ettøring',),
'ettøringen': ('ettøring',),
'ettøringene': ('ettøring',),
'ettøringer': ('ettøring',),
'etui': ('etui',),
'etuia': ('etui',),
'etuiene': ('etui',),
'etuier': ('etui',),
'etuiet': ('etui',),
'etyde': ('etyde',),
'etyden': ('etyde',),
'etydene': ('etyde',),
'etyder': ('etyde',),
'etyl': ('etyl',),
'etyla': ('etyl',),
'etylene': ('etyl',),
'etylet': ('etyl',),
'etylalkohol': ('etylalkohol',),
'etylalkoholen': ('etylalkohol',),
'etylalkoholene': ('etylalkohol',),
'etylalkoholer': ('etylalkohol',),
'etylen': ('etylen',),
'etylena': ('etylen',),
'etylenene': ('etylen',),
'etylenet': ('etylen',),
'etymolog': ('etymolog',),
'etymologen': ('etymolog',),
'etymologene': ('etymolog',),
'etymologer': ('etymolog',),
'etymologi': ('etymologi',),
'etymologien': ('etymologi',),
'etymologiene': ('etymologi',),
'etymologier': ('etymologi',),
'etyn': ('etyn',),
'etyna': ('etyn',),
'etynene': ('etyn',),
'etynet': ('etyn',),
'eufemisme': ('eufemisme',),
'eufemismen': ('eufemisme',),
'eufemismene': ('eufemisme',),
'eufemismer': ('eufemisme',),
'eufoni': ('eufoni',),
'eufonien': ('eufoni',),
'eufoniene': ('eufoni',),
'eufonier': ('eufoni',),
'eufori': ('eufori',),
'euforien': ('eufori',),
'euforiene': ('eufori',),
'euforier': ('eufori',),
'eugenikk': ('eugenikk',),
'eugenikken': ('eugenikk',),
'eugenikkene': ('eugenikk',),
'eugenikker': ('eugenikk',),
'eukalyptus': ('eukalyptus',),
'eukalyptusen': ('eukalyptus',),
'eukalyptusene': ('eukalyptus',),
'eukalyptuser': ('eukalyptus',),
'eukalyptusolja': ('eukalyptusolje',),
'eukalyptusolje': ('eukalyptusolje',),
'eukalyptusoljen': ('eukalyptusolje',),
'eukalyptusoljene': ('eukalyptusolje',),
'eukalyptusoljer': ('eukalyptusolje',),
'eukalyptustre': ('eukalyptustre',),
'eukalyptustrea': ('eukalyptustre',),
'eukalyptustreet': ('eukalyptustre',),
'eukalyptustrær': ('eukalyptustre',),
'eukalyptustrærne': ('eukalyptustre',),
'eukaristi': ('eukaristi',),
'eukaristien': ('eukaristi',),
'eukaristiene': ('eukaristi',),
'eukaristier': ('eukaristi',),
'eunukk': ('eunukk',),
'eunukken': ('eunukk',),
'eunukkene': ('eunukk',),
'eunukker': ('eunukk',),
'eurasier': ('eurasier',),
'eurasiere': ('eurasier',),
'eurasieren': ('eurasier',),
'eurasierer': ('eurasier',),
'eurasierne': ('eurasier',),
'eurodollar': ('eurodollar',),
'eurodollaren': ('eurodollar',),
'eurodollarene': ('eurodollar',),
'eurokommunisme': ('eurokommunisme',),
'eurokommunismen': ('eurokommunisme',),
'eurokommunismene': ('eurokommunisme',),
'eurokommunismer': ('eurokommunisme',),
'eurokrat': ('eurokrat',),
'eurokraten': ('eurokrat',),
'eurokratene': ('eurokrat',),
'eurokrater': ('eurokrat',),
'europacup': ('europacup',),
'europacupen': ('europacup',),
'europacupene': ('europacup',),
'europacuper': ('europacup',),
'europamester': ('europamester',),
'europamestere': ('europamester',),
'europamesteren': ('europamester',),
'europamesterer': ('europamester',),
'europamesterne': ('europamester',),
'europamestre': ('europamester',),
'europamestrene': ('europamester',),
'europamestrer': ('europamester',),
'europamesterskap': ('europamesterskap',),
'europamesterskapa': ('europamesterskap',),
'europamesterskapene': ('europamesterskap',),
'europamesterskaper': ('europamesterskap',),
'europamesterskapet': ('europamesterskap',),
'europaveg': ('europaveg',),
'europavegen': ('europaveg',),
'europavegene': ('europaveg',),
'europaveger': ('europaveg',),
'europavei': ('europavei',),
'europaveien': ('europavei',),
'europaveiene': ('europavei',),
'europaveier': ('europavei',),
'europeer': ('europeer',),
'europeere': ('europeer',),
'europeeren': ('europeer',),
'europeerer': ('europeer',),
'europeerne': ('europeer',),
'europium': ('europium',),
'europiuma': ('europium',),
'europiumene': ('europium',),
'europiumet': ('europium',),
'eurovaluta': ('eurovaluta',),
'eurovalutaen': ('eurovaluta',),
'eurovalutaene': ('eurovaluta',),
'eurovalutaer': ('eurovaluta',),
'eurovisjonsprogram': ('eurovisjonsprogram',),
'eurovisjonsprogramma': ('eurovisjonsprogram',),
'eurovisjonsprogrammene': ('eurovisjonsprogram',),
'eurovisjonsprogrammer': ('eurovisjonsprogram',),
'eurovisjonsprogrammet': ('eurovisjonsprogram',),
'eurovisjonssending': ('eurovisjonssending',),
'eurovisjonssendinga': ('eurovisjonssending',),
'eurovisjonssendingen': ('eurovisjonssending',),
'eurovisjonssendingene': ('eurovisjonssending',),
'eurovisjonssendinger': ('eurovisjonssending',),
'eutanasi': ('eutanasi',),
'eutanasien': ('eutanasi',),
'eutanasiene': ('eutanasi',),
'eutanasier': ('eutanasi',),
'eutrofiering': ('eutrofiering',),
'eutrofieringa': ('eutrofiering',),
'eutrofieringen': ('eutrofiering',),
'eutrofieringene': ('eutrofiering',),
'eutrofieringer': ('eutrofiering',),
'eva': ('eva',),
'evaen': ('eva',),
'evaene': ('eva',),
'evaer': ('eva',),
'evadatter': ('evadatter',),
'evadattera': ('evadatter',),
'evadatteren': ('evadatter',),
'evadøtre': ('evadatter',),
'evadøtrene': ('evadatter',),
'evadøtrer': ('evadatter',),
'evadrakt': ('evadrakt',),
'evadrakta': ('evadrakt',),
'evadrakten': ('evadrakt',),
'evadraktene': ('evadrakt',),
'evadrakter': ('evadrakt',),
'evakueringsleir': ('evakueringsleir',),
'evakueringsleiren': ('evakueringsleir',),
'evakueringsleirene': ('evakueringsleir',),
'evakueringsleirer': ('evakueringsleir',),
'evakueringsordre': ('evakueringsordre',),
'evakueringsordren': ('evakueringsordre',),
'evakueringsordrene': ('evakueringsordre',),
'evakueringsordrer': ('evakueringsordre',),
'evakueringsplan': ('evakueringsplan',),
'evakueringsplanen': ('evakueringsplan',),
'evakueringsplanene': ('evakueringsplan',),
'evakueringsplaner': ('evakueringsplan',),
'evangelieforfatter': ('evangelieforfatter',),
'evangelieforfattere': ('evangelieforfatter',),
'evangelieforfatteren': ('evangelieforfatter',),
'evangelieforfatterer': ('evangelieforfatter',),
'evangelieforfatterne': ('evangelieforfatter',),
'evangelist': ('evangelist',),
'evangelisten': ('evangelist',),
'evangelistene': ('evangelist',),
'evangelister': ('evangelist',),
'evangelia': ('evangelium',),
'evangeliene': ('evangelium',),
'evangelier': ('evangelium',),
'evangeliet': ('evangelium',),
'evangelium': ('evangelium',),
'evaporator': ('evaporator',),
'evaporatoren': ('evaporator',),
'evaporatorene': ('evaporator',),
'evaporatorer': ('evaporator',),
'evasjon': ('evasjon',),
'evasjonen': ('evasjon',),
'evasjonene': ('evasjon',),
'evasjoner': ('evasjon',),
'evenement': ('evenement',),
'evenementa': ('evenement',),
'evenementene': ('evenement',),
'evenementer': ('evenement',),
'evenementet': ('evenement',),
'eventualitet': ('eventualitet',),
'eventualiteten': ('eventualitet',),
'eventualitetene': ('eventualitet',),
'eventualiteter': ('eventualitet',),
'eventuelt': ('eventuelt',),
'eventyr': ('eventyr',),
'eventyra': ('eventyr',),
'eventyrene': ('eventyr',),
'eventyret': ('eventyr',),
'eventyrdronning': ('eventyrdronning',),
'eventyrdronninga': ('eventyrdronning',),
'eventyrdronningen': ('eventyrdronning',),
'eventyrdronningene': ('eventyrdronning',),
'eventyrdronninger': ('eventyrdronning',),
'eventyrer': ('eventyrer',),
'eventyrere': ('eventyrer',),
'eventyreren': ('eventyrer',),
'eventyrerer': ('eventyrer',),
'eventyrerne': ('eventyrer',),
'eventyrforteller': ('eventyrforteller',),
'eventyrfortellere': ('eventyrforteller',),
'eventyrfortelleren': ('eventyrforteller',),
'eventyrfortellerer': ('eventyrforteller',),
'eventyrfortellerne': ('eventyrforteller',),
'eventyrland': ('eventyrland',),
'eventyrlanda': ('eventyrland',),
'eventyrlandene': ('eventyrland',),
'eventyrlandet': ('eventyrland',),
'eventyrlyst': ('eventyrlyst',),
'eventyrlysta': ('eventyrlyst',),
'eventyrlysten': ('eventyrlyst',),
'eventyrlystene': ('eventyrlyst',),
'eventyrlyster': ('eventyrlyst',),
'eventyrpolitikk': ('eventyrpolitikk',),
'eventyrpolitikken': ('eventyrpolitikk',),
'eventyrpolitikkene': ('eventyrpolitikk',),
'eventyrpolitikker': ('eventyrpolitikk',),
'eventyrprins': ('eventyrprins',),
'eventyrprinsen': ('eventyrprins',),
'eventyrprinsene': ('eventyrprins',),
'eventyrprinser': ('eventyrprins',),
'eventyrskikkelse': ('eventyrskikkelse',),
'eventyrskikkelsen': ('eventyrskikkelse',),
'eventyrskikkelsene': ('eventyrskikkelse',),
'eventyrskikkelser': ('eventyrskikkelse',),
'eventyrstil': ('eventyrstil',),
'eventyrstilen': ('eventyrstil',),
'eventyrstilene': ('eventyrstil',),
'eventyrstiler': ('eventyrstil',),
'eventyrverden': ('eventyrverden',),
'eventyrverdenen': ('eventyrverden',),
'eventyrverdenene': ('eventyrverden',),
'eventyrverdener': ('eventyrverden',),
'evergreen': ('evergreen',),
'evergreenen': ('evergreen',),
'evergreenene': ('evergreen',),
'evergreener': ('evergreen',),
'evergreens': ('evergreen',),
'evfemisme': ('evfemisme',),
'evfemismen': ('evfemisme',),
'evfemismene': ('evfemisme',),
'evfemismer': ('evfemisme',),
'evidens': ('evidens',),
'evidensen': ('evidens',),
'evidensene': ('evidens',),
'evidenser': ('evidens',),
'evighet': ('evighet',),
'evigheta': ('evighet',),
'evigheten': ('evighet',),
'evighetene': ('evighet',),
'evigheter': ('evighet',),
'evighetsblomst': ('evighetsblomst',),
'evighetsblomsten': ('evighetsblomst',),
'evighetsblomstene': ('evighetsblomst',),
'evighetsblomster': ('evighetsblomst',),
'evighetslengsel': ('evighetslengsel',),
'evighetslengselen': ('evighetslengsel',),
'evighetslengslene': ('evighetslengsel',),
'evighetslengsler': ('evighetslengsel',),
'evighetsmaskin': ('evighetsmaskin',),
'evighetsmaskina': ('evighetsmaskin',),
'evighetsmaskinen': ('evighetsmaskin',),
'evighetsmaskinene': ('evighetsmaskin',),
'evighetsmaskiner': ('evighetsmaskin',),
'evja': ('evje',),
'evje': ('evje',),
'evjen': ('evje',),
'evjene': ('evje',),
'evjer': ('evje',),
'evna': ('evne',),
'evne': ('evne',),
'evnen': ('evne',),
'evnene': ('evne',),
'evner': ('evne',),
'evneløshet': ('evneløshet',),
'evneløsheta': ('evneløshet',),
'evneløsheten': ('evneløshet',),
'evneløshetene': ('evneløshet',),
'evneløsheter': ('evneløshet',),
'evneløysa': ('evneløyse',),
'evneløyse': ('evneløyse',),
'evneløysen': ('evneløyse',),
'evneløysene': ('evneløyse',),
'evneløyser': ('evneløyse',),
'evnukk': ('evnukk',),
'evnukken': ('evnukk',),
'evnukkene': ('evnukk',),
'evnukker': ('evnukk',),
'evolusjon': ('evolusjon',),
'evolusjonen': ('evolusjon',),
'evolusjonene': ('evolusjon',),
'evolusjoner': ('evolusjon',),
'evolusjonisme': ('evolusjonisme',),
'evolusjonismen': ('evolusjonisme',),
'evolusjonismene': ('evolusjonisme',),
'evolusjonismer': ('evolusjonisme',),
'evolusjonist': ('evolusjonist',),
'evolusjonisten': ('evolusjonist',),
'evolusjonistene': ('evolusjonist',),
'evolusjonister': ('evolusjonist',),
'evolusjonsteori': ('evolusjonsteori',),
'evolusjonsteorien': ('evolusjonsteori',),
'evolusjonsteoriene': ('evolusjonsteori',),
'evolusjonsteorier': ('evolusjonsteori',),
'ex libris': ('ex libris',),
'ex librisa': ('ex libris',),
'ex librisene': ('ex libris',),
'ex libriser': ('ex libris',),
'ex libriset': ('ex libris',),
'examen artium': ('examen artium',),
'examen philosophicum': ('examen philosophicum',),
'eyeliner': ('eyeliner',),
'eyelinere': ('eyeliner',),
'eyelineren': ('eyeliner',),
'eyelinerer': ('eyeliner',),
'eyelinerne': ('eyeliner',),
'f': ('f',),
'f\'en': ('f',),
'f-en': ('f',),
'f-ene': ('f',),
'f-er': ('f',),
'fôr': ('fôr',),
'fôra': ('fôr',),
'fôrene': ('fôr',),
'fôret': ('fôr',),
'fôr': ('fôr',),
'fôra': ('fôr',),
'fôrene': ('fôr',),
'fôret': ('fôr',),
'fôrblanding': ('fôrblanding',),
'fôrblandinga': ('fôrblanding',),
'fôrblandingen': ('fôrblanding',),
'fôrblandingene': ('fôrblanding',),
'fôrblandinger': ('fôrblanding',),
'fôrenhet': ('fôrenhet',),
'fôrenheta': ('fôrenhet',),
'fôrenheten': ('fôrenhet',),
'fôrenhetene': ('fôrenhet',),
'fôrenheter': ('fôrenhet',),
'fôrgang': ('fôrgang',),
'fôrgangen': ('fôrgang',),
'fôrgangene': ('fôrgang',),
'fôrganger': ('fôrgang',),
'fôrhøster': ('fôrhøster',),
'fôrhøstere': ('fôrhøster',),
'fôrhøsteren': ('fôrhøster',),
'fôrhøsterer': ('fôrhøster',),
'fôrhøsterne': ('fôrhøster',),
'fôring': ('fôring',),
'fôringa': ('fôring',),
'fôringen': ('fôring',),
'fôringene': ('fôring',),
'fôringer': ('fôring',),
'fôring': ('fôring',),
'fôringa': ('fôring',),
'fôringen': ('fôring',),
'fôringene': ('fôring',),
'fôringer': ('fôring',),
'fôrkjøkken': ('fôrkjøkken',),
'fôrkjøkkena': ('fôrkjøkken',),
'fôrkjøkkenene': ('fôrkjøkken',),
'fôrkjøkkener': ('fôrkjøkken',),
'fôrkjøkkenet': ('fôrkjøkken',),
'fôrknipa': ('fôrknipe',),
'fôrknipe': ('fôrknipe',),
'fôrknipen': ('fôrknipe',),
'fôrknipene': ('fôrknipe',),
'fôrkniper': ('fôrknipe',),
'fôrmargkål': ('fôrmargkål',),
'fôrmargkålen': ('fôrmargkål',),
'fôrmargkålene': ('fôrmargkål',),
'fôrmargkåler': ('fôrmargkål',),
'fôrmargskål': ('fôrmargskål',),
'fôrmargskålen': ('fôrmargskål',),
'fôrmargskålene': ('fôrmargskål',),
'fôrmargskåler': ('fôrmargskål',),
'fôrverk': ('fôrverk',),
'fôrverka': ('fôrverk',),
'fôrverkene': ('fôrverk',),
'fôrverker': ('fôrverk',),
'fôrverket': ('fôrverk',),
'f-moll': ('f-moll',),
'f-mollen': ('f-moll',),
'f-mollene': ('f-moll',),
'f-moller': ('f-moll',),
'f-nøkkel': ('f-nøkkel',),
'f-nøkkelen': ('f-nøkkel',),
'f-nøklene': ('f-nøkkel',),
'f-nøkler': ('f-nøkkel',),
'fa': ('fa',),
'faen': ('fa',),
'faene': ('fa',),
'faer': ('fa',),
'fabel': ('fabel',),
'fabelen': ('fabel',),
'fablene': ('fabel',),
'fabler': ('fabel',),
'fabeldyr': ('fabeldyr',),
'fabeldyra': ('fabeldyr',),
'fabeldyrene': ('fabeldyr',),
'fabeldyret': ('fabeldyr',),
'fabrikant': ('fabrikant',),
'fabrikanten': ('fabrikant',),
'fabrikantene': ('fabrikant',),
'fabrikanter': ('fabrikant',),
'fabrikasjon': ('fabrikasjon',),
'fabrikasjonen': ('fabrikasjon',),
'fabrikasjonene': ('fabrikasjon',),
'fabrikasjoner': ('fabrikasjon',),
'fabrikat': ('fabrikat',),
'fabrikata': ('fabrikat',),
'fabrikatene': ('fabrikat',),
'fabrikater': ('fabrikat',),
'fabrikatet': ('fabrikat',),
'fabrikk': ('fabrikk',),
'fabrikken': ('fabrikk',),
'fabrikkene': ('fabrikk',),
'fabrikker': ('fabrikk',),
'fabrikk-kjører': ('fabrikk-kjører',),
'fabrikk-kjørere': ('fabrikk-kjører',),
'fabrikk-kjøreren': ('fabrikk-kjører',),
'fabrikk-kjørerer': ('fabrikk-kjører',),
'fabrikk-kjørerne': ('fabrikk-kjører',),
'fabrikkarbeider': ('fabrikkarbeider',),
'fabrikkarbeidere': ('fabrikkarbeider',),
'fabrikkarbeideren': ('fabrikkarbeider',),
'fabrikkarbeiderer': ('fabrikkarbeider',),
'fabrikkarbeiderne': ('fabrikkarbeider',),
'fabrikkeier': ('fabrikkeier',),
'fabrikkeiere': ('fabrikkeier',),
'fabrikkeieren': ('fabrikkeier',),
'fabrikkeierer': ('fabrikkeier',),
'fabrikkeierne': ('fabrikkeier',),
'fabrikkhall': ('fabrikkhall',),
'fabrikkhallen': ('fabrikkhall',),
'fabrikkhallene': ('fabrikkhall',),
'fabrikkhaller': ('fabrikkhall',),
'fabrikkjører': ('fabrikkjører',),
'fabrikkjørere': ('fabrikkjører',),
'fabrikkjøreren': ('fabrikkjører',),
'fabrikkjørerer': ('fabrikkjører',),
'fabrikkjørerne': ('fabrikkjører',),
'fabrikkmerka': ('fabrikkmerke',),
'fabrikkmerke': ('fabrikkmerke',),
'fabrikkmerkene': ('fabrikkmerke',),
'fabrikkmerker': ('fabrikkmerke',),
'fabrikkmerket': ('fabrikkmerke',),
'fabrikkskip': ('fabrikkskip',),
'fabrikkskipa': ('fabrikkskip',),
'fabrikkskipene': ('fabrikkskip',),
'fabrikkskipet': ('fabrikkskip',),
'fabrikktrål': ('fabrikktrål',),
'fabrikktrålen': ('fabrikktrål',),
'fabrikktrålene': ('fabrikktrål',),
'fabrikktråler': ('fabrikktrål',),
'fabrikktråler': ('fabrikktråler',),
'fabrikktrålere': ('fabrikktråler',),
'fabrikktråleren': ('fabrikktråler',),
'fabrikktrålerer': ('fabrikktråler',),
'fabrikktrålerne': ('fabrikktråler',),
'fabrikkvara': ('fabrikkvare',),
'fabrikkvare': ('fabrikkvare',),
'fabrikkvaren': ('fabrikkvare',),
'fabrikkvarene': ('fabrikkvare',),
'fabrikkvarer': ('fabrikkvare',),
'fabulist': ('fabulist',),
'fabulisten': ('fabulist',),
'fabulistene': ('fabulist',),
'fabulister': ('fabulist',),
'facts': ('facts',),
'factsene': ('facts',),
'fadder': ('fadder',),
'faddere': ('fadder',),
'fadderen': ('fadder',),
'fadderer': ('fadder',),
'fadderne': ('fadder',),
'fadderskap': ('fadderskap',),
'fadderskapa': ('fadderskap',),
'fadderskapene': ('fadderskap',),
'fadderskapet': ('fadderskap',),
'faderhand': ('faderhand',),
'faderhanda': ('faderhand',),
'faderhanden': ('faderhand',),
'faderhendene': ('faderhand',),
'faderhender': ('faderhand',),
'faderhendene': ('faderhånd',),
'faderhender': ('faderhånd',),
'faderhånd': ('faderhånd',),
'faderhånda': ('faderhånd',),
'faderhånden': ('faderhånd',),
'fadermorder': ('fadermorder',),
'fadermordere': ('fadermorder',),
'fadermorderen': ('fadermorder',),
'fadermorderer': ('fadermorder',),
'fadermorderne': ('fadermorder',),
'fadervår': ('fadervår',),
'fadervåra': ('fadervår',),
'fadervårene': ('fadervår',),
'fadervåret': ('fadervår',),
'fadese': ('fadese',),
'fadesen': ('fadese',),
'fadesene': ('fadese',),
'fadeser': ('fadese',),
'fading': ('fading',),
'fadinga': ('fading',),
'fadingen': ('fading',),
'fadingene': ('fading',),
'fadinger': ('fading',),
'fadingkontroll': ('fadingkontroll',),
'fadingkontrollen': ('fadingkontroll',),
'fadingkontrollene': ('fadingkontroll',),
'fadingkontroller': ('fadingkontroll',),
'faen': ('faen',),
'faenskap': ('faenskap',),
'faenskapa': ('faenskap',),
'faenskapen': ('faenskap',),
'faenskapene': ('faenskap',),
'faenskaper': ('faenskap',),
'faenskapet': ('faenskap',),
'faensmakt': ('faensmakt',),
'faensmakta': ('faensmakt',),
'faensmakten': ('faensmakt',),
'faensmaktene': ('faensmakt',),
'faensmakter': ('faensmakt',),
'fag': ('fag',),
'faga': ('fag',),
'fagene': ('fag',),
'faget': ('fag',),
'fagarbeider': ('fagarbeider',),
'fagarbeidere': ('fagarbeider',),
'fagarbeideren': ('fagarbeider',),
'fagarbeiderer': ('fagarbeider',),
'fagarbeiderne': ('fagarbeider',),
'fagbevegelse': ('fagbevegelse',),
'fagbevegelsen': ('fagbevegelse',),
'fagbevegelsene': ('fagbevegelse',),
'fagbevegelser': ('fagbevegelse',),
'fagbibliotek': ('fagbibliotek',),
'fagbiblioteka': ('fagbibliotek',),
'fagbibliotekene': ('fagbibliotek',),
'fagbiblioteker': ('fagbibliotek',),
'fagbiblioteket': ('fagbibliotek',),
'fagblad': ('fagblad',),
'fagblada': ('fagblad',),
'fagbladene': ('fagblad',),
'fagblader': ('fagblad',),
'fagbladet': ('fagblad',),
'fagbrev': ('fagbrev',),
'fagbreva': ('fagbrev',),
'fagbrevene': ('fagbrev',),
'fagbrever': ('fagbrev',),
'fagbrevet': ('fagbrev',),
'fagdommer': ('fagdommer',),
'fagdommere': ('fagdommer',),
'fagdommeren': ('fagdommer',),
'fagdommerer': ('fagdommer',),
'fagdommerne': ('fagdommer',),
'fagergjess': ('fagergås',),
'fagergjessene': ('fagergås',),
'fagergjæsene': ('fagergås',),
'fagergjæser': ('fagergås',),
'fagergås': ('fagergås',),
'fagergåsa': ('fagergås',),
'fagergåsen': ('fagergås',),
'fagfolk': ('fagfolk',),
'fagfolka': ('fagfolk',),
'fagfolkene': ('fagfolk',),
'fagfolket': ('fagfolk',),
'fagforbund': ('fagforbund',),
'fagforbunda': ('fagforbund',),
'fagforbundene': ('fagforbund',),
'fagforbundet': ('fagforbund',),
'fagforening': ('fagforening',),
'fagforeninga': ('fagforening',),
'fagforeningen': ('fagforening',),
'fagforeningene': ('fagforening',),
'fagforeninger': ('fagforening',),
'fagidiot': ('fagidiot',),
'fagidioten': ('fagidiot',),
'fagidiotene': ('fagidiot',),
'fagidioter': ('fagidiot',),
'fagkrets': ('fagkrets',),
'fagkretsen': ('fagkrets',),
'fagkretsene': ('fagkrets',),
'fagkretser': ('fagkrets',),
'fagkunnskap': ('fagkunnskap',),
'fagkunnskapen': ('fagkunnskap',),
'fagkunnskapene': ('fagkunnskap',),
'fagkunnskaper': ('fagkunnskap',),
'faglitteratur': ('faglitteratur',),
'faglitteraturen': ('faglitteratur',),
'faglitteraturene': ('faglitteratur',),
'faglitteraturer': ('faglitteratur',),
'faglærer': ('faglærer',),
'faglærere': ('faglærer',),
'faglæreren': ('faglærer',),
'faglærerer': ('faglærer',),
'faglærerne': ('faglærer',),
'fagmann': ('fagmann',),
'fagmannen': ('fagmann',),
'fagmenn': ('fagmann',),
'fagmennene': ('fagmann',),
'fagnad': ('fagnad',),
'fagnaden': ('fagnad',),
'fagnadene': ('fagnad',),
'fagnader': ('fagnad',),
'fagocytt': ('fagocytt',),
'fagocytten': ('fagocytt',),
'fagocyttene': ('fagocytt',),
'fagocytter': ('fagocytt',),
'fagområda': ('fagområde',),
'fagområde': ('fagområde',),
'fagområdene': ('fagområde',),
'fagområder': ('fagområde',),
'fagområdet': ('fagområde',),
'fagorganisasjon': ('fagorganisasjon',),
'fagorganisasjonen': ('fagorganisasjon',),
'fagorganisasjonene': ('fagorganisasjon',),
'fagorganisasjoner': ('fagorganisasjon',),
'fagott': ('fagott',),
'fagotten': ('fagott',),
'fagottene': ('fagott',),
'fagotter': ('fagott',),
'fagottist': ('fagottist',),
'fagottisten': ('fagottist',),
'fagottistene': ('fagottist',),
'fagottister': ('fagottist',),
'fagpressa': ('fagpresse',),
'fagpresse': ('fagpresse',),
'fagpressen': ('fagpresse',),
'fagpressene': ('fagpresse',),
'fagpresser': ('fagpresse',),
'fagprøva': ('fagprøve',),
'fagprøve': ('fagprøve',),
'fagprøven': ('fagprøve',),
'fagprøvene': ('fagprøve',),
'fagprøver': ('fagprøve',),
'fagsjargong': ('fagsjargong',),
'fagsjargongen': ('fagsjargong',),
'fagsjargongene': ('fagsjargong',),
'fagsjargonger': ('fagsjargong',),
'fagskole': ('fagskole',),
'fagskolen': ('fagskole',),
'fagskolene': ('fagskole',),
'fagskoler': ('fagskole',),
'fagspråk': ('fagspråk',),
'fagspråka': ('fagspråk',),
'fagspråkene': ('fagspråk',),
'fagspråket': ('fagspråk',),
'fagstudia': ('fagstudium',),
'fagstudiene': ('fagstudium',),
'fagstudier': ('fagstudium',),
'fagstudiet': ('fagstudium',),
'fagstudium': ('fagstudium',),
'fagutdannelse': ('fagutdannelse',),
'fagutdannelsen': ('fagutdannelse',),
'fagutdannelsene': ('fagutdannelse',),
'fagutdannelser': ('fagutdannelse',),
'fagutdanning': ('fagutdanning',),
'fagutdanninga': ('fagutdanning',),
'fagutdanningen': ('fagutdanning',),
'fagutdanningene': ('fagutdanning',),
'fagutdanninger': ('fagutdanning',),
'faguttrykk': ('faguttrykk',),
'faguttrykka': ('faguttrykk',),
'faguttrykkene': ('faguttrykk',),
'faguttrykket': ('faguttrykk',),
'fahrenheit': ('fahrenheit',),
'fahrenheitgrad': ('fahrenheitgrad',),
'fahrenheitgraden': ('fahrenheitgrad',),
'fahrenheitgradene': ('fahrenheitgrad',),
'fahrenheitgrader': ('fahrenheitgrad',),
'fahrenheitskala': ('fahrenheitskala',),
'fahrenheitskalaen': ('fahrenheitskala',),
'fahrenheitskalaene': ('fahrenheitskala',),
'fahrenheitskalaer': ('fahrenheitskala',),
'fahrenheittermometer': ('fahrenheittermometer',),
'fahrenheittermometeret': ('fahrenheittermometer',),
'fahrenheittermometra': ('fahrenheittermometer',),
'fahrenheittermometre': ('fahrenheittermometer',),
'fahrenheittermometrene': ('fahrenheittermometer',),
'fahrenheittermometret': ('fahrenheittermometer',),
'fait accompli': ('fait accompli',),
'fajanse': ('fajanse',),
'fajansen': ('fajanse',),
'fajansene': ('fajanse',),
'fajanser': ('fajanse',),
'fajanseblått': ('fajanseblått',),
'fajansefabrikk': ('fajansefabrikk',),
'fajansefabrikken': ('fajansefabrikk',),
'fajansefabrikkene': ('fajansefabrikk',),
'fajansefabrikker': ('fajansefabrikk',),
'fajansevase': ('fajansevase',),
'fajansevasen': ('fajansevase',),
'fajansevasene': ('fajansevase',),
'fajansevaser': ('fajansevase',),
'fakir': ('fakir',),
'fakiren': ('fakir',),
'fakirene': ('fakir',),
'fakirer': ('fakir',),
'fakkel': ('fakkel',),
'fakkelen': ('fakkel',),
'faklene': ('fakkel',),
'fakler': ('fakkel',),
'fakkeltog': ('fakkeltog',),
'fakkeltoga': ('fakkeltog',),
'fakkeltogene': ('fakkeltog',),
'fakkeltoget': ('fakkeltog',),
'faks': ('faks',),
'faksen': ('faks',),
'faksene': ('faks',),
'fakser': ('faks',),
'faks': ('faks',),
'faksa': ('faks',),
'faksene': ('faks',),
'fakset': ('faks',),
'faksimila': ('faksimile',),
'faksimile': ('faksimile',),
'faksimilen': ('faksimile',),
'faksimilene': ('faksimile',),
'faksimiler': ('faksimile',),
'faksimilet': ('faksimile',),
'faksimileutgava': ('faksimileutgave',),
'faksimileutgave': ('faksimileutgave',),
'faksimileutgaven': ('faksimileutgave',),
'faksimileutgavene': ('faksimileutgave',),
'faksimileutgaver': ('faksimileutgave',),
'faktaruta': ('faktarute',),
'faktarute': ('faktarute',),
'faktaruten': ('faktarute',),
'faktarutene': ('faktarute',),
'faktaruter': ('faktarute',),
'fakta': ('fakte',),
'fakte': ('fakte',),
'fakten': ('fakte',),
'faktene': ('fakte',),
'fakter': ('fakte',),
'faktisitet': ('faktisitet',),
'faktisiteten': ('faktisitet',),
'faktisitetene': ('faktisitet',),
'faktisiteter': ('faktisitet',),
'faktor': ('faktor',),
'faktoren': ('faktor',),
'faktorene': ('faktor',),
'faktorer': ('faktor',),
'faktoranalysa': ('faktoranalyse',),
'faktoranalyse': ('faktoranalyse',),
'faktoranalysen': ('faktoranalyse',),
'faktoranalysene': ('faktoranalyse',),
'faktoranalyser': ('faktoranalyse',),
'faktori': ('faktori',),
'faktoria': ('faktori',),
'faktoriene': ('faktori',),
'faktorier': ('faktori',),
'faktoriet': ('faktori',),
'faktoring': ('faktoring',),
'faktoringen': ('faktoring',),
'faktoringene': ('faktoring',),
'faktoringer': ('faktoring',),
'faktoringselskap': ('faktoringselskap',),
'faktoringselskapa': ('faktoringselskap',),
'faktoringselskapene': ('faktoringselskap',),
'faktoringselskaper': ('faktoringselskap',),
'faktoringselskapet': ('faktoringselskap',),
'faktotum': ('faktotum',),
'faktotuma': ('faktotum',),
'faktotumene': ('faktotum',),
'faktotumer': ('faktotum',),
'faktotumet': ('faktotum',),
'fakta': ('faktum',),
'faktaene': ('faktum',),
'faktum': ('faktum',),
'faktumet': ('faktum',),
'faktura': ('faktura',),
'fakturaen': ('faktura',),
'fakturaene': ('faktura',),
'fakturaer': ('faktura',),
'fakturabeløp': ('fakturabeløp',),
'fakturabeløpa': ('fakturabeløp',),
'fakturabeløpene': ('fakturabeløp',),
'fakturabeløpet': ('fakturabeløp',),
'fakturabok': ('fakturabok',),
'fakturaboka': ('fakturabok',),
'fakturaboken': ('fakturabok',),
'fakturabøkene': ('fakturabok',),
'fakturabøker': ('fakturabok',),
'fakturadato': ('fakturadato',),
'fakturadatoen': ('fakturadato',),
'fakturadatoene': ('fakturadato',),
'fakturadatoer': ('fakturadato',),
'fakturakreditt': ('fakturakreditt',),
'fakturakreditten': ('fakturakreditt',),
'fakturakredittene': ('fakturakreditt',),
'fakturakreditter': ('fakturakreditt',),
'fakturaskriving': ('fakturaskriving',),
'fakturaskrivinga': ('fakturaskriving',),
'fakturaskrivingen': ('fakturaskriving',),
'fakturaskrivingene': ('fakturaskriving',),
'fakturaskrivinger': ('fakturaskriving',),
'fakultet': ('fakultet',),
'fakulteta': ('fakultet',),
'fakultetene': ('fakultet',),
'fakulteter': ('fakultet',),
'fakultetet': ('fakultet',),
'fakultetsmøta': ('fakultetsmøte',),
'fakultetsmøte': ('fakultetsmøte',),
'fakultetsmøtene': ('fakultetsmøte',),
'fakultetsmøter': ('fakultetsmøte',),
'fakultetsmøtet': ('fakultetsmøte',),
'fakultetsråd': ('fakultetsråd',),
'fakultetsråda': ('fakultetsråd',),
'fakultetsrådene': ('fakultetsråd',),
'fakultetsrådet': ('fakultetsråd',),
'fakultetsstyra': ('fakultetsstyre',),
'fakultetsstyre': ('fakultetsstyre',),
'fakultetsstyrene': ('fakultetsstyre',),
'fakultetsstyrer': ('fakultetsstyre',),
'fakultetsstyret': ('fakultetsstyre',),
'falangist': ('falangist',),
'falangisten': ('falangist',),
'falangistene': ('falangist',),
'falangister': ('falangist',),
'falangistorganisasjon': ('falangistorganisasjon',),
'falangistorganisasjonen': ('falangistorganisasjon',),
'falangistorganisasjonene': ('falangistorganisasjon',),
'falangistorganisasjoner': ('falangistorganisasjon',),
'falangene': ('falanks',),
'falanger': ('falanks',),
'falanks': ('falanks',),
'falanksen': ('falanks',),
'falanksene': ('falanks',),
'falankser': ('falanks',),
'fald': ('fald',),
'falden': ('fald',),
'faldene': ('fald',),
'falder': ('fald',),
'falk': ('falk',),
'falken': ('falk',),
'falkene': ('falk',),
'falker': ('falk',),
'falkeblikk': ('falkeblikk',),
'falkeblikka': ('falkeblikk',),
'falkeblikkene': ('falkeblikk',),
'falkeblikket': ('falkeblikk',),
'falkefamilie': ('falkefamilie',),
'falkefamilien': ('falkefamilie',),
'falkefamiliene': ('falkefamilie',),
'falkefamilier': ('falkefamilie',),
'falkejakt': ('falkejakt',),
'falkejakta': ('falkejakt',),
'falkejakten': ('falkejakt',),
'falkejaktene': ('falkejakt',),
'falkejakter': ('falkejakt',),
'falklender': ('falklender',),
'falklendere': ('falklender',),
'falklenderen': ('falklender',),
'falklenderer': ('falklender',),
'falklenderne': ('falklender',),
'falklending': ('falklending',),
'falklendingen': ('falklending',),
'falklendingene': ('falklending',),
'falklendinger': ('falklending',),
'falkoner': ('falkoner',),
'falkoneren': ('falkoner',),
'falkonerene': ('falkoner',),
'falkonerer': ('falkoner',),
'falkonett': ('falkonett',),
'falkonetten': ('falkonett',),
'falkonettene': ('falkonett',),
'falkonetter': ('falkonett',),
'fall': ('fall',),
'falla': ('fall',),
'fallene': ('fall',),
'fallet': ('fall',),
'fall': ('fall',),
'falla': ('fall',),
'fallen': ('fall',),
'fallene': ('fall',),
'faller': ('fall',),
'fallet': ('fall',),
'fall-lem': ('fall-lem',),
'fall-lemmen': ('fall-lem',),
'fall-lemmene': ('fall-lem',),
'fall-lemmer': ('fall-lem',),
'fall-lov': ('fall-lov',),
'fall-loven': ('fall-lov',),
'fall-lovene': ('fall-lov',),
'fall-lover': ('fall-lov',),
'fall-luka': ('fall-luke',),
'fall-luke': ('fall-luke',),
'fall-luken': ('fall-luke',),
'fall-lukene': ('fall-luke',),
'fall-luker': ('fall-luke',),
'fallbevegelse': ('fallbevegelse',),
'fallbevegelsen': ('fallbevegelse',),
'fallbevegelsene': ('fallbevegelse',),
'fallbevegelser': ('fallbevegelse',),
'fallbom': ('fallbom',),
'fallbommen': ('fallbom',),
'fallbommene': ('fallbom',),
'fallbommer': ('fallbom',),
'fallbord': ('fallbord',),
'fallborda': ('fallbord',),
'fallbordene': ('fallbord',),
'fallborder': ('fallbord',),
'fallbordet': ('fallbord',),
'falldør': ('falldør',),
'falldøra': ('falldør',),
'falldøren': ('falldør',),
'falldørene': ('falldør',),
'falldører': ('falldør',),
'falle': ('falle',),
'fallen': ('falle',),
'fallene': ('falle',),
'faller': ('falle',),
'fallekniv': ('fallekniv',),
'fallekniven': ('fallekniv',),
'falleknivene': ('fallekniv',),
'fallekniver': ('fallekniv',),
'fallem': ('fallem',),
'fallemmen': ('fallem',),
'fallemmene': ('fallem',),
'fallemmer': ('fallem',),
'fallent': ('fallent',),
'fallenten': ('fallent',),
'fallentene': ('fallent',),
'fallenter': ('fallent',),
'fallesjuka': ('fallesjuke',),
'fallesjuke': ('fallesjuke',),
'fallesjuken': ('fallesjuke',),
'fallesjukene': ('fallesjuke',),
'fallesjuker': ('fallesjuke',),
'fallesyka': ('fallesyke',),
'fallesyke': ('fallesyke',),
'fallesyken': ('fallesyke',),
'fallesykene': ('fallesyke',),
'fallesyker': ('fallesyke',),
'fallgruva': ('fallgruve',),
'fallgruve': ('fallgruve',),
'fallgruven': ('fallgruve',),
'fallgruvene': ('fallgruve',),
'fallgruver': ('fallgruve',),
'fallhastighet': ('fallhastighet',),
'fallhastigheta': ('fallhastighet',),
'fallhastigheten': ('fallhastighet',),
'fallhastighetene': ('fallhastighet',),
'fallhastigheter': ('fallhastighet',),
'fallhøgd': ('fallhøgd',),
'fallhøgda': ('fallhøgd',),
'fallhøgdene': ('fallhøgd',),
'fallhøgder': ('fallhøgd',),
'fallhøyde': ('fallhøyde',),
'fallhøyden': ('fallhøyde',),
'fallhøydene': ('fallhøyde',),
'fallhøyder': ('fallhøyde',),
'fallitt': ('fallitt',),
'fallitten': ('fallitt',),
'fallittene': ('fallitt',),
'fallitter': ('fallitt',),
'fallittbo': ('fallittbo',),
'fallittboa': ('fallittbo',),
'fallittboene': ('fallittbo',),
'fallittboet': ('fallittbo',),
'fallittbu': ('fallittbu',),
'fallittbua': ('fallittbu',),
'fallittbuene': ('fallittbu',),
'fallittbuet': ('fallittbu',),
'fallitterklæring': ('fallitterklæring',),
'fallitterklæringa': ('fallitterklæring',),
'fallitterklæringen': ('fallitterklæring',),
'fallitterklæringene': ('fallitterklæring',),
'fallitterklæringer': ('fallitterklæring',),
'fallklaff': ('fallklaff',),
'fallklaffen': ('fallklaff',),
'fallklaffene': ('fallklaff',),
'fallklaffer': ('fallklaff',),
'fallos': ('fallos',),
'fallosen': ('fallos',),
'fallosene': ('fallos',),
'falloser': ('fallos',),
'fallossymbol': ('fallossymbol',),
'fallossymbola': ('fallossymbol',),
'fallossymbolene': ('fallossymbol',),
'fallossymboler': ('fallossymbol',),
'fallossymbolet': ('fallossymbol',),
'fallov': ('fallov',),
'falloven': ('fallov',),
'fallovene': ('fallov',),
'fallover': ('fallov',),
'fallreip': ('fallreip',),
'fallreipa': ('fallreip',),
'fallreipene': ('fallreip',),
'fallreipet': ('fallreip',),
'fallseier': ('fallseier',),
'fallseiere': ('fallseier',),
'fallseieren': ('fallseier',),
'fallseierne': ('fallseier',),
'fallseire': ('fallseier',),
'fallseirene': ('fallseier',),
'fallseirer': ('fallseier',),
'fallskjerm': ('fallskjerm',),
'fallskjermen': ('fallskjerm',),
'fallskjermene': ('fallskjerm',),
'fallskjermer': ('fallskjerm',),
'fallskjermgodtgjørelse': ('fallskjermgodtgjørelse',),
'fallskjermgodtgjørelsen': ('fallskjermgodtgjørelse',),
'fallskjermgodtgjørelsene': ('fallskjermgodtgjørelse',),
'fallskjermgodtgjørelser': ('fallskjermgodtgjørelse',),
'fallskjermgodtgjøring': ('fallskjermgodtgjøring',),
'fallskjermgodtgjøringa': ('fallskjermgodtgjøring',),
'fallskjermgodtgjøringen': ('fallskjermgodtgjøring',),
'fallskjermgodtgjøringene': ('fallskjermgodtgjøring',),
'fallskjermgodtgjøringer': ('fallskjermgodtgjøring',),
'fallskjermhopper': ('fallskjermhopper',),
'fallskjermhoppere': ('fallskjermhopper',),
'fallskjermhopperen': ('fallskjermhopper',),
'fallskjermhopperer': ('fallskjermhopper',),
'fallskjermhopperne': ('fallskjermhopper',),
'fallskjermjeger': ('fallskjermjeger',),
'fallskjermjegere': ('fallskjermjeger',),
'fallskjermjegeren': ('fallskjermjeger',),
'fallskjermjegerer': ('fallskjermjeger',),
'fallskjermjegerne': ('fallskjermjeger',),
'fallskjermsoldat': ('fallskjermsoldat',),
'fallskjermsoldaten': ('fallskjermsoldat',),
'fallskjermsoldatene': ('fallskjermsoldat',),
'fallskjermsoldater': ('fallskjermsoldat',),
'fallskjermtropp': ('fallskjermtropp',),
'fallskjermtroppen': ('fallskjermtropp',),
'fallskjermtroppene': ('fallskjermtropp',),
'fallskjermtropper': ('fallskjermtropp',),
'falluka': ('falluke',),
'falluke': ('falluke',),
'falluken': ('falluke',),
'fallukene': ('falluke',),
'falluker': ('falluke',),
'falløks': ('falløks',),
'falløksa': ('falløks',),
'falløksen': ('falløks',),
'falløksene': ('falløks',),
'falløkser': ('falløks',),
'falseapparat': ('falseapparat',),
'falseapparata': ('falseapparat',),
'falseapparatene': ('falseapparat',),
'falseapparater': ('falseapparat',),
'falseapparatet': ('falseapparat',),
'falsemaskin': ('falsemaskin',),
'falsemaskina': ('falsemaskin',),
'falsemaskinen': ('falsemaskin',),
'falsemaskinene': ('falsemaskin',),
'falsemaskiner': ('falsemaskin',),
'falseprøva': ('falseprøve',),
'falseprøve': ('falseprøve',),
'falseprøven': ('falseprøve',),
'falseprøvene': ('falseprøve',),
'falseprøver': ('falseprøve',),
'falser': ('falser',),
'falsere': ('falser',),
'falseren': ('falser',),
'falserer': ('falser',),
'falserne': ('falser',),
'falsett': ('falsett',),
'falsetten': ('falsett',),
'falsettene': ('falsett',),
'falsetter': ('falsett',),
'falsett-tone': ('falsett-tone',),
'falsett-tonen': ('falsett-tone',),
'falsett-tonene': ('falsett-tone',),
'falsett-toner': ('falsett-tone',),
'falsettone': ('falsettone',),
'falsettonen': ('falsettone',),
'falsettonene': ('falsettone',),
'falsettoner': ('falsettone',),
'falsettstemme': ('falsettstemme',),
'falsettstemmen': ('falsettstemme',),
'falsettstemmene': ('falsettstemme',),
'falsettstemmer': ('falsettstemme',),
'falshøvel': ('falshøvel',),
'falshøvelen': ('falshøvel',),
'falshøvlene': ('falshøvel',),
'falshøvler': ('falshøvel',),
'falsifikasjon': ('falsifikasjon',),
'falsifikasjonen': ('falsifikasjon',),
'falsifikasjonene': ('falsifikasjon',),
'falsifikasjoner': ('falsifikasjon',),
'falsifikat': ('falsifikat',),
'falsifikata': ('falsifikat',),
'falsifikatene': ('falsifikat',),
'falsifikater': ('falsifikat',),
'falsifikatet': ('falsifikat',),
'falsk': ('falsk',),
'falsken': ('falsk',),
'falskene': ('falsk',),
'falsker': ('falsk',),
'falskhet': ('falskhet',),
'falskheta': ('falskhet',),
'falskheten': ('falskhet',),
'falskhetene': ('falskhet',),
'falskheter': ('falskhet',),
'falskmyntner': ('falskmyntner',),
'falskmyntnere': ('falskmyntner',),
'falskmyntneren': ('falskmyntner',),
'falskmyntnerer': ('falskmyntner',),
'falskmyntnerne': ('falskmyntner',),
'falskmyntneri': ('falskmyntneri',),
'falskmyntneria': ('falskmyntneri',),
'falskmyntneriene': ('falskmyntneri',),
'falskmyntneriet': ('falskmyntneri',),
'falskner': ('falskner',),
'falsknere': ('falskner',),
'falskneren': ('falskner',),
'falsknerer': ('falskner',),
'falsknerne': ('falskner',),
'falskneri': ('falskneri',),
'falskneria': ('falskneri',),
'falskneriene': ('falskneri',),
'falsknerier': ('falskneri',),
'falskneriet': ('falskneri',),
'falskspeller': ('falskspeller',),
'falskspellere': ('falskspeller',),
'falskspelleren': ('falskspeller',),
'falskspellerer': ('falskspeller',),
'falskspellerne': ('falskspeller',),
'falskspiller': ('falskspiller',),
'falskspillere': ('falskspiller',),
'falskspilleren': ('falskspiller',),
'falskspillerer': ('falskspiller',),
'falskspillerne': ('falskspiller',),
'falspanel': ('falspanel',),
'falspanela': ('falspanel',),
'falspanelene': ('falspanel',),
'falspaneler': ('falspanel',),
'falspanelet': ('falspanel',),
'falsrør': ('falsrør',),
'falsrøra': ('falsrør',),
'falsrørene': ('falsrør',),
'falsrøret': ('falsrør',),
'falstang': ('falstang',),
'falstanga': ('falstang',),
'falstangen': ('falstang',),
'falstengene': ('falstang',),
'falstenger': ('falstang',),
'falsa': ('falsum',),
'falsaene': ('falsum',),
'falsum': ('falsum',),
'falsuma': ('falsum',),
'falsumene': ('falsum',),
'falsumer': ('falsum',),
'falsumet': ('falsum',),
'familiaritet': ('familiaritet',),
'familiariteten': ('familiaritet',),
'familiaritetene': ('familiaritet',),
'familiariteter': ('familiaritet',),
'familie': ('familie',),
'familien': ('familie',),
'familiene': ('familie',),
'familier': ('familie',),
'familieaksjeselskap': ('familieaksjeselskap',),
'familieaksjeselskapa': ('familieaksjeselskap',),
'familieaksjeselskapene': ('familieaksjeselskap',),
'familieaksjeselskaper': ('familieaksjeselskap',),
'familieaksjeselskapet': ('familieaksjeselskap',),
'familieanliggende': ('familieanliggende',),
'familieanliggendene': ('familieanliggende',),
'familieanliggender': ('familieanliggende',),
'familieanliggendet': ('familieanliggende',),
'familieband': ('familieband',),
'familiebanda': ('familieband',),
'familiebandene': ('familieband',),
'familiebandet': ('familieband',),
'familiebedrift': ('familiebedrift',),
'familiebedriften': ('familiebedrift',),
'familiebedriftene': ('familiebedrift',),
'familiebedrifter': ('familiebedrift',),
'familiebegivenhet': ('familiebegivenhet',),
'familiebegivenheta': ('familiebegivenhet',),
'familiebegivenheten': ('familiebegivenhet',),
'familiebegivenhetene': ('familiebegivenhet',),
'familiebegivenheter': ('familiebegivenhet',),
'familiebånd': ('familiebånd',),
'familiebånda': ('familiebånd',),
'familiebåndene': ('familiebånd',),
'familiebåndet': ('familiebånd',),
'familiedrama': ('familiedrama',),
'familiedramaene': ('familiedrama',),
'familiedramaer': ('familiedrama',),
'familiedramaet': ('familiedrama',),
'familieenka': ('familieenke',),
'familieenke': ('familieenke',),
'familieenken': ('familieenke',),
'familieenkene': ('familieenke',),
'familieenker': ('familieenke',),
'familieenkemann': ('familieenkemann',),
'familieenkemannen': ('familieenkemann',),
'familieenkemenn': ('familieenkemann',),
'familieenkemennene': ('familieenkemann',),
'familieforsørger': ('familieforsørger',),
'familieforsørgere': ('familieforsørger',),
'familieforsørgeren': ('familieforsørger',),
'familieforsørgerer': ('familieforsørger',),
'familieforsørgerne': ('familieforsørger',),
'familienavn': ('familienavn',),
'familienavna': ('familienavn',),
'familienavnene': ('familienavn',),
'familienavnet': ('familienavn',),
'familieplanlegging': ('familieplanlegging',),
'familieplanlegginga': ('familieplanlegging',),
'familieplanleggingen': ('familieplanlegging',),
'familieplanleggingene': ('familieplanlegging',),
'familieplanlegginger': ('familieplanlegging',),
'familierådgiing': ('familierådgiing',),
'familierådgiinga': ('familierådgiing',),
'familierådgiingen': ('familierådgiing',),
'familierådgiingene': ('familierådgiing',),
'familierådgiinger': ('familierådgiing',),
'familierådgiving': ('familierådgiving',),
'familierådgivinga': ('familierådgiving',),
'familierådgivingen': ('familierådgiving',),
'familierådgivingene': ('familierådgiving',),
'familierådgivinger': ('familierådgiving',),
'familierådgivning': ('familierådgivning',),
'familierådgivninga': ('familierådgivning',),
'familierådgivningen': ('familierådgivning',),
'familierådgivningene': ('familierådgivning',),
'familierådgivninger': ('familierådgivning',),
'familieselskap': ('familieselskap',),
'familieselskapa': ('familieselskap',),
'familieselskapene': ('familieselskap',),
'familieselskaper': ('familieselskap',),
'familieselskapet': ('familieselskap',),
'familieterapi': ('familieterapi',),
'familieterapien': ('familieterapi',),
'familieterapiene': ('familieterapi',),
'familieterapier': ('familieterapi',),
'familietillegg': ('familietillegg',),
'familietillegga': ('familietillegg',),
'familietilleggene': ('familietillegg',),
'familietillegget': ('familietillegg',),
'familietradisjon': ('familietradisjon',),
'familietradisjonen': ('familietradisjon',),
'familietradisjonene': ('familietradisjon',),
'familietradisjoner': ('familietradisjon',),
'familievern': ('familievern',),
'familieverna': ('familievern',),
'familievernene': ('familievern',),
'familievernet': ('familievern',),
'familievernkontor': ('familievernkontor',),
'familievernkontora': ('familievernkontor',),
'familievernkontorene': ('familievernkontor',),
'familievernkontorer': ('familievernkontor',),
'familievernkontoret': ('familievernkontor',),
'famn': ('famn',),
'famnen': ('famn',),
'famnene': ('famn',),
'famner': ('famn',),
'famn': ('famn',),
'famnen': ('famn',),
'famnene': ('famn',),
'famner': ('famn',),
'famntak': ('famntak',),
'famntaka': ('famntak',),
'famntakene': ('famntak',),
'famntaket': ('famntak',),
'famntak': ('famntak',),
'famntaka': ('famntak',),
'famntakene': ('famntak',),
'famntaket': ('famntak',),
'fanatiker': ('fanatiker',),
'fanatikere': ('fanatiker',),
'fanatikeren': ('fanatiker',),
'fanatikerer': ('fanatiker',),
'fanatikerne': ('fanatiker',),
'fanatisme': ('fanatisme',),
'fanatismen': ('fanatisme',),
'fanatismene': ('fanatisme',),
'fanatismer': ('fanatisme',),
'fanbrev': ('fanbrev',),
'fanbreva': ('fanbrev',),
'fanbrevene': ('fanbrev',),
'fanbrever': ('fanbrev',),
'fanbrevet': ('fanbrev',),
'fandango': ('fandango',),
'fandangoen': ('fandango',),
'fandangoene': ('fandango',),
'fandangoer': ('fandango',),
'fanden': ('fanden',),
'fandenskap': ('fandenskap',),
'fandenskapa': ('fandenskap',),
'fandenskapen': ('fandenskap',),
'fandenskapene': ('fandenskap',),
'fandenskaper': ('fandenskap',),
'fandenskapet': ('fandenskap',),
'fandensmakt': ('fandensmakt',),
'fandensmakta': ('fandensmakt',),
'fandensmakten': ('fandensmakt',),
'fandensmaktene': ('fandensmakt',),
'fandensmakter': ('fandensmakt',),
'fana': ('fane',),
'fane': ('fane',),
'fanen': ('fane',),
'fanene': ('fane',),
'faner': ('fane',),
'fanebærer': ('fanebærer',),
'fanebærere': ('fanebærer',),
'fanebæreren': ('fanebærer',),
'fanebærerer': ('fanebærer',),
'fanebærerne': ('fanebærer',),
'faneflukt': ('faneflukt',),
'faneflukta': ('faneflukt',),
'faneflukten': ('faneflukt',),
'fanefluktene': ('faneflukt',),
'faneflukter': ('faneflukt',),
'fanejunker': ('fanejunker',),
'fanejunkere': ('fanejunker',),
'fanejunkeren': ('fanejunker',),
'fanejunkerer': ('fanejunker',),
'fanejunkerne': ('fanejunker',),
'fanekort': ('fanekort',),
'fanekorta': ('fanekort',),
'fanekortene': ('fanekort',),
'fanekortet': ('fanekort',),
'fanevakt': ('fanevakt',),
'fanevakta': ('fanevakt',),
'fanevakten': ('fanevakt',),
'fanevaktene': ('fanevakt',),
'fanevakter': ('fanevakt',),
'fanfare': ('fanfare',),
'fanfaren': ('fanfare',),
'fanfarene': ('fanfare',),
'fanfarer': ('fanfare',),
'fanfarehorn': ('fanfarehorn',),
'fanfarehorna': ('fanfarehorn',),
'fanfarehornene': ('fanfarehorn',),
'fanfarehornet': ('fanfarehorn',),
'fang': ('fang',),
'fanga': ('fang',),
'fangene': ('fang',),
'fanget': ('fang',),
'fang': ('fang',),
'fanga': ('fang',),
'fangene': ('fang',),
'fanget': ('fang',),
'fangarm': ('fangarm',),
'fangarmen': ('fangarm',),
'fangarmene': ('fangarm',),
'fangarmer': ('fangarm',),
'fange': ('fange',),
'fangen': ('fange',),
'fangene': ('fange',),
'fanger': ('fange',),
'fanga': ('fange',),
'fange': ('fange',),
'fangene': ('fange',),
'fanger': ('fange',),
'fanget': ('fange',),
'fangecella': ('fangecelle',),
'fangecelle': ('fangecelle',),
'fangecellen': ('fangecelle',),
'fangecellene': ('fangecelle',),
'fangeceller': ('fangecelle',),
'fangedrakt': ('fangedrakt',),
'fangedrakta': ('fangedrakt',),
'fangedrakten': ('fangedrakt',),
'fangedraktene': ('fangedrakt',),
'fangedrakter': ('fangedrakt',),
'fangehol': ('fangehol',),
'fangehola': ('fangehol',),
'fangeholene': ('fangehol',),
'fangeholet': ('fangehol',),
'fangehull': ('fangehull',),
'fangehulla': ('fangehull',),
'fangehullene': ('fangehull',),
'fangehuller': ('fangehull',),
'fangehullet': ('fangehull',),
'fangeleir': ('fangeleir',),
'fangeleiren': ('fangeleir',),
'fangeleirene': ('fangeleir',),
'fangeleirer': ('fangeleir',),
'fangenskap': ('fangenskap',),
'fangenskapa': ('fangenskap',),
'fangenskapene': ('fangenskap',),
'fangenskapet': ('fangenskap',),
'fanger': ('fanger',),
'fangere': ('fanger',),
'fangeren': ('fanger',),
'fangerer': ('fanger',),
'fangerne': ('fanger',),
'fangetransport': ('fangetransport',),
'fangetransporten': ('fangetransport',),
'fangetransportene': ('fangetransport',),
'fangetransporter': ('fangetransport',),
'fangevokter': ('fangevokter',),
'fangevoktere': ('fangevokter',),
'fangevokteren': ('fangevokter',),
'fangevokterer': ('fangevokter',),
'fangevokterne': ('fangevokter',),
'fangkube': ('fangkube',),
'fangkuben': ('fangkube',),
'fangkubene': ('fangkube',),
'fangkuber': ('fangkube',),
'fanglina': ('fangline',),
'fangline': ('fangline',),
'fanglinen': ('fangline',),
'fanglinene': ('fangline',),
'fangliner': ('fangline',),
'fangskinn': ('fangskinn',),
'fangskinna': ('fangskinn',),
'fangskinnene': ('fangskinn',),
'fangskinnet': ('fangskinn',),
'fangsnor': ('fangsnor',),
'fangsnora': ('fangsnor',),
'fangsnoren': ('fangsnor',),
'fangsnorene': ('fangsnor',),
'fangsnorer': ('fangsnor',),
'fangst': ('fangst',),
'fangsten': ('fangst',),
'fangstene': ('fangst',),
'fangster': ('fangst',),
'fangstbåt': ('fangstbåt',),
'fangstbåten': ('fangstbåt',),
'fangstbåtene': ('fangstbåt',),
'fangstbåter': ('fangstbåt',),
'fangstdirigering': ('fangstdirigering',),
'fangstdirigeringa': ('fangstdirigering',),
'fangstdirigeringen': ('fangstdirigering',),
'fangstdirigeringene': ('fangstdirigering',),
'fangstdirigeringer': ('fangstdirigering',),
'fangstfartøy': ('fangstfartøy',),
'fangstfartøya': ('fangstfartøy',),
'fangstfartøyene': ('fangstfartøy',),
'fangstfartøyer': ('fangstfartøy',),
'fangstfartøyet': ('fangstfartøy',),
'fangstfelt': ('fangstfelt',),
'fangstfelta': ('fangstfelt',),
'fangstfeltene': ('fangstfelt',),
'fangstfelter': ('fangstfelt',),
'fangstfeltet': ('fangstfelt',),
'fangstflåte': ('fangstflåte',),
'fangstflåten': ('fangstflåte',),
'fangstflåtene': ('fangstflåte',),
'fangstflåter': ('fangstflåte',),
'fangstmann': ('fangstmann',),
'fangstmannen': ('fangstmann',),
'fangstmenn': ('fangstmann',),
'fangstmennene': ('fangstmann',),
'fangstmåte': ('fangstmåte',),
'fangstmåten': ('fangstmåte',),
'fangstmåtene': ('fangstmåte',),
'fangstmåter': ('fangstmåte',),
'fangstregulering': ('fangstregulering',),
'fangstreguleringa': ('fangstregulering',),
'fangstreguleringen': ('fangstregulering',),
'fangstreguleringene': ('fangstregulering',),
'fangstreguleringer': ('fangstregulering',),
'fangstsesong': ('fangstsesong',),
'fangstsesongen': ('fangstsesong',),
'fangstsesongene': ('fangstsesong',),
'fangstsesonger': ('fangstsesong',),
'fangstskuta': ('fangstskute',),
'fangstskute': ('fangstskute',),
'fangstskuten': ('fangstskute',),
'fangstskutene': ('fangstskute',),
'fangstskuter': ('fangstskute',),
'fanken': ('fanken',),
'fankeren': ('fankeren',),
'fanklubb': ('fanklubb',),
'fanklubben': ('fanklubb',),
'fanklubbene': ('fanklubb',),
'fanklubber': ('fanklubb',),
'fans': ('fans',),
'fansen': ('fans',),
'fansene': ('fans',),
'fanser': ('fans',),
'fant': ('fant',),
'fanten': ('fant',),
'fantene': ('fant',),
'fanter': ('fant',),
'fantasi': ('fantasi',),
'fantasien': ('fantasi',),
'fantasiene': ('fantasi',),
'fantasier': ('fantasi',),
'fantasifoster': ('fantasifoster',),
'fantasifosteret': ('fantasifoster',),
'fantasifostra': ('fantasifoster',),
'fantasifostre': ('fantasifoster',),
'fantasifostrene': ('fantasifoster',),
'fantasifostret': ('fantasifoster',),
'fantasiverden': ('fantasiverden',),
'fantasiverdenen': ('fantasiverden',),
'fantasiverdenene': ('fantasiverden',),
'fantasiverdener': ('fantasiverden',),
'fantast': ('fantast',),
'fantasten': ('fantast',),
'fantastene': ('fantast',),
'fantaster': ('fantast',),
'fantasteri': ('fantasteri',),
'fantasteria': ('fantasteri',),
'fantasteriene': ('fantasteri',),
'fantasterier': ('fantasteri',),
'fantasteriet': ('fantasteri',),
'fantefølga': ('fantefølge',),
'fantefølge': ('fantefølge',),
'fantefølgene': ('fantefølge',),
'fantefølger': ('fantefølge',),
'fantefølget': ('fantefølge',),
'fantefølgja': ('fantefølgje',),
'fantefølgje': ('fantefølgje',),
'fantefølgjene': ('fantefølgje',),
'fantefølgjer': ('fantefølgje',),
'fantefølgjet': ('fantefølgje',),
'fanteri': ('fanteri',),
'fanteria': ('fanteri',),
'fanteriene': ('fanteri',),
'fanterier': ('fanteri',),
'fanteriet': ('fanteri',),
'fantestrek': ('fantestrek',),
'fantestreken': ('fantestrek',),
'fantestrekene': ('fantestrek',),
'fantestreker': ('fantestrek',),
'fantestykka': ('fantestykke',),
'fantestykke': ('fantestykke',),
'fantestykkene': ('fantestykke',),
'fantestykker': ('fantestykke',),
'fantestykket': ('fantestykke',),
'fantom': ('fantom',),
'fantoma': ('fantom',),
'fantomene': ('fantom',),
'fantomer': ('fantom',),
'fantomet': ('fantom',),
'fantombegavelse': ('fantombegavelse',),
'fantombegavelsen': ('fantombegavelse',),
'fantombegavelsene': ('fantombegavelse',),
'fantombegavelser': ('fantombegavelse',),
'fantomredning': ('fantomredning',),
'fantomredninga': ('fantomredning',),
'fantomredningen': ('fantomredning',),
'fantomredningene': ('fantomredning',),
'fantomredninger': ('fantomredning',),
'fantomresultat': ('fantomresultat',),
'fantomresultata': ('fantomresultat',),
'fantomresultatene': ('fantomresultat',),
'fantomresultater': ('fantomresultat',),
'fantomresultatet': ('fantomresultat',),
'fantomsmerte': ('fantomsmerte',),
'fantomsmerten': ('fantomsmerte',),
'fantomsmertene': ('fantomsmerte',),
'fantomsmerter': ('fantomsmerte',),
'fantomsvangerskap': ('fantomsvangerskap',),
'fantomsvangerskapa': ('fantomsvangerskap',),
'fantomsvangerskapene': ('fantomsvangerskap',),
'fantomsvangerskapet': ('fantomsvangerskap',),
'fantord': ('fantord',),
'fantorda': ('fantord',),
'fantordene': ('fantord',),
'fantordet': ('fantord',),
'far': ('far',),
'faren': ('far',),
'fedre': ('far',),
'fedrene': ('far',),
'far': ('far',),
'fara': ('far',),
'farene': ('far',),
'faret': ('far',),
'farad': ('farad',),
'faraden': ('farad',),
'faradene': ('farad',),
'faradayeffekt': ('faradayeffekt',),
'faradayeffekten': ('faradayeffekt',),
'faradayeffektene': ('faradayeffekt',),
'faradayeffekter': ('faradayeffekt',),
'farang': ('farang',),
'farangen': ('farang',),
'farangene': ('farang',),
'faranger': ('farang',),
'farao': ('farao',),
'faraoen': ('farao',),
'faraoene': ('farao',),
'faraoer': ('farao',),
'farbror': ('farbror',),
'farbroren': ('farbror',),
'farbrødre': ('farbror',),
'farbrødrene': ('farbror',),
'fare': ('fare',),
'faren': ('fare',),
'farene': ('fare',),
'farer': ('fare',),
'faredag': ('faredag',),
'faredagen': ('faredag',),
'faredagene': ('faredag',),
'faredager': ('faredag',),
'fareklassa': ('fareklasse',),
'fareklasse': ('fareklasse',),
'fareklassen': ('fareklasse',),
'fareklassene': ('fareklasse',),
'fareklasser': ('fareklasse',),
'faremoment': ('faremoment',),
'faremomenta': ('faremoment',),
'faremomentene': ('faremoment',),
'faremomenter': ('faremoment',),
'faremomentet': ('faremoment',),
'faresignal': ('faresignal',),
'faresignala': ('faresignal',),
'faresignalene': ('faresignal',),
'faresignaler': ('faresignal',),
'faresignalet': ('faresignal',),
'fareskilt': ('fareskilt',),
'fareskilta': ('fareskilt',),
'fareskiltene': ('fareskilt',),
'fareskilter': ('fareskilt',),
'fareskiltet': ('fareskilt',),
'faresona': ('faresone',),
'faresone': ('faresone',),
'faresonen': ('faresone',),
'faresonene': ('faresone',),
'faresoner': ('faresone',),
'farfar': ('farfar',),
'farfaren': ('farfar',),
'farfedre': ('farfar',),
'farfedrene': ('farfar',),
'farge': ('farge',),
'fargen': ('farge',),
'fargene': ('farge',),
'farger': ('farge',),
'farge-TV': ('farge-TV',),
'farge-TVen': ('farge-TV',),
'farge-TVene': ('farge-TV',),
'farge-TVer': ('farge-TV',),
'farge-tv': ('farge-tv',),
'farge-tven': ('farge-tv',),
'farge-tvene': ('farge-tv',),
'farge-tver': ('farge-tv',),
'fargeband': ('fargeband',),
'fargebanda': ('fargeband',),
'fargebandene': ('fargeband',),
'fargebandet': ('fargeband',),
'fargebilda': ('fargebilde',),
'fargebilde': ('fargebilde',),
'fargebildene': ('fargebilde',),
'fargebilder': ('fargebilde',),
'fargebildet': ('fargebilde',),
'fargeblyant': ('fargeblyant',),
'fargeblyanten': ('fargeblyant',),
'fargeblyantene': ('fargeblyant',),
'fargeblyanter': ('fargeblyant',),
'fargebånd': ('fargebånd',),
'fargebånda': ('fargebånd',),
'fargebåndene': ('fargebånd',),
'fargebåndet': ('fargebånd',),
'fargecella': ('fargecelle',),
'fargecelle': ('fargecelle',),
'fargecellen': ('fargecelle',),
'fargecellene': ('fargecelle',),
'fargeceller': ('fargecelle',),
'fargefilm': ('fargefilm',),
'fargefilmen': ('fargefilm',),
'fargefilmene': ('fargefilm',),
'fargefilmer': ('fargefilm',),
'fargefilter': ('fargefilter',),
'fargefilteret': ('fargefilter',),
'fargefiltra': ('fargefilter',),
'fargefiltre': ('fargefilter',),
'fargefiltrene': ('fargefilter',),
'fargefiltret': ('fargefilter',),
'fargefjerner': ('fargefjerner',),
'fargefjernere': ('fargefjerner',),
'fargefjerneren': ('fargefjerner',),
'fargefjernerer': ('fargefjerner',),
'fargefjernerne': ('fargefjerner',),
'fargefjernsyn': ('fargefjernsyn',),
'fargefjernsyna': ('fargefjernsyn',),
'fargefjernsynene': ('fargefjernsyn',),
'fargefjernsynet': ('fargefjernsyn',),
'fargefotografi': ('fargefotografi',),
'fargefotografia': ('fargefotografi',),
'fargefotografiene': ('fargefotografi',),
'fargefotografier': ('fargefotografi',),
'fargefotografiet': ('fargefotografi',),
'fargehandel': ('fargehandel',),
'fargehandelen': ('fargehandel',),
'fargehandlene': ('fargehandel',),
'fargehandler': ('fargehandel',),
'fargehandler': ('fargehandler',),
'fargehandlere': ('fargehandler',),
'fargehandleren': ('fargehandler',),
'fargehandlerer': ('fargehandler',),
'fargehandlerne': ('fargehandler',),
'fargehørsel': ('fargehørsel',),
'fargehørselen': ('fargehørsel',),
'fargehørsla': ('fargehørsel',),
'fargehørslene': ('fargehørsel',),
'fargehørsler': ('fargehørsel',),
'fargeklatt': ('fargeklatt',),
'fargeklatten': ('fargeklatt',),
'fargeklattene': ('fargeklatt',),
'fargeklatter': ('fargeklatt',),
'fargekritt': ('fargekritt',),
'fargekritta': ('fargekritt',),
'fargekrittene': ('fargekritt',),
'fargekrittet': ('fargekritt',),
'fargenyanse': ('fargenyanse',),
'fargenyansen': ('fargenyanse',),
'fargenyansene': ('fargenyanse',),
'fargenyanser': ('fargenyanse',),
'fargeprakt': ('fargeprakt',),
'fargeprakta': ('fargeprakt',),
'fargeprakten': ('fargeprakt',),
'fargepraktene': ('fargeprakt',),
'fargeprakter': ('fargeprakt',),
'fargeri': ('fargeri',),
'fargeria': ('fargeri',),
'fargeriene': ('fargeri',),
'fargerier': ('fargeri',),
'fargeriet': ('fargeri',),
'fargesending': ('fargesending',),
'fargesendinga': ('fargesending',),
'fargesendingen': ('fargesending',),
'fargesendingene': ('fargesending',),
'fargesendinger': ('fargesending',),
'fargeskala': ('fargeskala',),
'fargeskalaen': ('fargeskala',),
'fargeskalaene': ('fargeskala',),
'fargeskalaer': ('fargeskala',),
'fargestift': ('fargestift',),
'fargestiften': ('fargestift',),
'fargestiftene': ('fargestift',),
'fargestifter': ('fargestift',),
'fargestoff': ('fargestoff',),
'fargestoffa': ('fargestoff',),
'fargestoffene': ('fargestoff',),
'fargestoffer': ('fargestoff',),
'fargestoffet': ('fargestoff',),
'fargetrykk': ('fargetrykk',),
'fargetrykka': ('fargetrykk',),
'fargetrykkene': ('fargetrykk',),
'fargetrykket': ('fargetrykk',),
'farin': ('farin',),
'farina': ('farin',),
'farinen': ('farin',),
'farinene': ('farin',),
'fariner': ('farin',),
'farinet': ('farin',),
'fariseer': ('fariseer',),
'fariseere': ('fariseer',),
'fariseeren': ('fariseer',),
'fariseerer': ('fariseer',),
'fariseerne': ('fariseer',),
'fariseisme': ('fariseisme',),
'fariseismen': ('fariseisme',),
'fariseismene': ('fariseisme',),
'fariseismer': ('fariseisme',),
'fark': ('fark',),
'farken': ('fark',),
'farkene': ('fark',),
'farker': ('fark',),
'fark': ('fark',),
'farka': ('fark',),
'farkene': ('fark',),
'farket': ('fark',),
'farkost': ('farkost',),
'farkosten': ('farkost',),
'farkostene': ('farkost',),
'farkoster': ('farkost',),
'farlei': ('farlei',),
'farleia': ('farlei',),
'farleien': ('farlei',),
'farleiene': ('farlei',),
'farleier': ('farlei',),
'farm': ('farm',),
'farmen': ('farm',),
'farmene': ('farm',),
'farmer': ('farm',),
'farm': ('farm',),
'farmen': ('farm',),
'farmene': ('farm',),
'farmer': ('farm',),
'farmakolog': ('farmakolog',),
'farmakologen': ('farmakolog',),
'farmakologene': ('farmakolog',),
'farmakologer': ('farmakolog',),
'farmakologi': ('farmakologi',),
'farmakologien': ('farmakologi',),
'farmakologiene': ('farmakologi',),
'farmakologier': ('farmakologi',),
'farmaka': ('farmakon',),
'farmakaene': ('farmakon',),
'farmakon': ('farmakon',),
'farmakonet': ('farmakon',),
'farmakope': ('farmakope',),
'farmakopeen': ('farmakope',),
'farmakopeene': ('farmakope',),
'farmakopeer': ('farmakope',),
'farmaka': ('farmakum',),
'farmakaene': ('farmakum',),
'farmakum': ('farmakum',),
'farmakumet': ('farmakum',),
'farmann': ('farmann',),
'farmannen': ('farmann',),
'farmenn': ('farmann',),
'farmennene': ('farmann',),
'farmasi': ('farmasi',),
'farmasien': ('farmasi',),
'farmasiene': ('farmasi',),
'farmasier': ('farmasi',),
'farmasøyt': ('farmasøyt',),
'farmasøyten': ('farmasøyt',),
'farmasøytene': ('farmasøyt',),
'farmasøyter': ('farmasøyt',),
'farmer': ('farmer',),
'farmere': ('farmer',),
'farmeren': ('farmer',),
'farmerer': ('farmer',),
'farmerne': ('farmer',),
'farmor': ('farmor',),
'farmora': ('farmor',),
'farmoren': ('farmor',),
'farmødre': ('farmor',),
'farmødrene': ('farmor',),
'farmødrer': ('farmor',),
'farsarv': ('farsarv',),
'farsarven': ('farsarv',),
'farsarvene': ('farsarv',),
'farsarver': ('farsarv',),
'farsbinding': ('farsbinding',),
'farsbindinga': ('farsbinding',),
'farsbindingen': ('farsbinding',),
'farsbindingene': ('farsbinding',),
'farsbindinger': ('farsbinding',),
'farsdag': ('farsdag',),
'farsdagen': ('farsdag',),
'farsdagene': ('farsdag',),
'farsdager': ('farsdag',),
'farse': ('farse',),
'farsen': ('farse',),
'farsene': ('farse',),
'farser': ('farse',),
'farsgard': ('farsgard',),
'farsgarden': ('farsgard',),
'farsgardene': ('farsgard',),
'farsgarder': ('farsgard',),
'farsgård': ('farsgård',),
'farsgården': ('farsgård',),
'farsgårdene': ('farsgård',),
'farsgårder': ('farsgård',),
'farsi': ('farsi',),
'farsien': ('farsi',),
'farsiene': ('farsi',),
'farsier': ('farsi',),
'farskap': ('farskap',),
'farskapa': ('farskap',),
'farskapen': ('farskap',),
'farskapene': ('farskap',),
'farskaper': ('farskap',),
'farskapet': ('farskap',),
'farskapssak': ('farskapssak',),
'farskapssaka': ('farskapssak',),
'farskapssaken': ('farskapssak',),
'farskapssakene': ('farskapssak',),
'farskapssaker': ('farskapssak',),
'farsnavn': ('farsnavn',),
'farsnavna': ('farsnavn',),
'farsnavnene': ('farsnavn',),
'farsnavnet': ('farsnavn',),
'farsott': ('farsott',),
'farsotta': ('farsott',),
'farsotten': ('farsott',),
'farsottene': ('farsott',),
'farsotter': ('farsott',),
'farssida': ('farsside',),
'farsside': ('farsside',),
'farssiden': ('farsside',),
'farssidene': ('farsside',),
'farssider': ('farsside',),
'farsslekt': ('farsslekt',),
'farsslekta': ('farsslekt',),
'farsslekten': ('farsslekt',),
'farsslektene': ('farsslekt',),
'farsslekter': ('farsslekt',),
'fart': ('fart',),
'farten': ('fart',),
'fartene': ('fart',),
'farter': ('fart',),
'fartsbegrensning': ('fartsbegrensning',),
'fartsbegrensninga': ('fartsbegrensning',),
'fartsbegrensningen': ('fartsbegrensning',),
'fartsbegrensningene': ('fartsbegrensning',),
'fartsbegrensninger': ('fartsbegrensning',),
'fartsfeber': ('fartsfeber',),
'fartsfebere': ('fartsfeber',),
'fartsfeberen': ('fartsfeber',),
'fartsfeberne': ('fartsfeber',),
'fartsfebre': ('fartsfeber',),
'fartsfebrene': ('fartsfeber',),
'fartsfebrer': ('fartsfeber',),
'fartsgrensa': ('fartsgrense',),
'fartsgrense': ('fartsgrense',),
'fartsgrensen': ('fartsgrense',),
'fartsgrensene': ('fartsgrense',),
'fartsgrenser': ('fartsgrense',),
'fartskontroll': ('fartskontroll',),
'fartskontrollen': ('fartskontroll',),
'fartskontrollene': ('fartskontroll',),
'fartskontroller': ('fartskontroll',),
'fartsmåler': ('fartsmåler',),
'fartsmålere': ('fartsmåler',),
'fartsmåleren': ('fartsmåler',),
'fartsmålerer': ('fartsmåler',),
'fartsmålerne': ('fartsmåler',),
'fartsplan': ('fartsplan',),
'fartsplanen': ('fartsplan',),
'fartsplanene': ('fartsplan',),
'fartsplaner': ('fartsplan',),
'fartsskriver': ('fartsskriver',),
'fartsskrivere': ('fartsskriver',),
'fartsskriveren': ('fartsskriver',),
'fartsskriverer': ('fartsskriver',),
'fartsskriverne': ('fartsskriver',),
'fartsstripa': ('fartsstripe',),
'fartsstripe': ('fartsstripe',),
'fartsstripen': ('fartsstripe',),
'fartsstripene': ('fartsstripe',),
'fartsstriper': ('fartsstripe',),
'fartstid': ('fartstid',),
'fartstida': ('fartstid',),
'fartstiden': ('fartstid',),
'fartstidene': ('fartstid',),
'fartstider': ('fartstid',),
'fartsøkning': ('fartsøkning',),
'fartsøkninga': ('fartsøkning',),
'fartsøkningen': ('fartsøkning',),
'fartsøkningene': ('fartsøkning',),
'fartsøkninger': ('fartsøkning',),
'fartøy': ('fartøy',),
'fartøya': ('fartøy',),
'fartøyene': ('fartøy',),
'fartøyer': ('fartøy',),
'fartøyet': ('fartøy',),
'farvann': ('farvann',),
'farvanna': ('farvann',),
'farvannene': ('farvann',),
'farvannet': ('farvann',),
'farvannsmerka': ('farvannsmerke',),
'farvannsmerke': ('farvannsmerke',),
'farvannsmerkene': ('farvannsmerke',),
'farvannsmerker': ('farvannsmerke',),
'farvannsmerket': ('farvannsmerke',),
'farvatn': ('farvatn',),
'farvatna': ('farvatn',),
'farvatnene': ('farvatn',),
'farvatnet': ('farvatn',),
'farvatnsmerka': ('farvatnsmerke',),
'farvatnsmerke': ('farvatnsmerke',),
'farvatnsmerkene': ('farvatnsmerke',),
'farvatnsmerker': ('farvatnsmerke',),
'farvatnsmerket': ('farvatnsmerke',),
'farvel': ('farvel',),
'farvela': ('farvel',),
'farvelene': ('farvel',),
'farvelet': ('farvel',),
'fas': ('fas',),
'fasen': ('fas',),
'fasene': ('fas',),
'faser': ('fas',),
'fasade': ('fasade',),
'fasaden': ('fasade',),
'fasadene': ('fasade',),
'fasader': ('fasade',),
'fasaderekka': ('fasaderekke',),
'fasaderekke': ('fasaderekke',),
'fasaderekken': ('fasaderekke',),
'fasaderekkene': ('fasaderekke',),
'fasaderekker': ('fasaderekke',),
'fasadestein': ('fasadestein',),
'fasadesteinen': ('fasadestein',),
'fasadesteinene': ('fasadestein',),
'fasadesteiner': ('fasadestein',),
'fasan': ('fasan',),
'fasanen': ('fasan',),
'fasanene': ('fasan',),
'fasaner': ('fasan',),
'fasanbord': ('fasanbord',),
'fasanborda': ('fasanbord',),
'fasanbordene': ('fasanbord',),
'fasanborder': ('fasanbord',),
'fasanbordet': ('fasanbord',),
'fascisme': ('fascisme',),
'fascismen': ('fascisme',),
'fascismene': ('fascisme',),
'fascismer': ('fascisme',),
'fascist': ('fascist',),
'fascisten': ('fascist',),
'fascistene': ('fascist',),
'fascister': ('fascist',),
'fase': ('fase',),
'fasen': ('fase',),
'fasene': ('fase',),
'faser': ('fase',),
'faseforskyvning': ('faseforskyvning',),
'faseforskyvninga': ('faseforskyvning',),
'faseforskyvningen': ('faseforskyvning',),
'faseforskyvningene': ('faseforskyvning',),
'faseforskyvninger': ('faseforskyvning',),
'fasett': ('fasett',),
'fasetten': ('fasett',),
'fasettene': ('fasett',),
'fasetter': ('fasett',),
'fasettøya': ('fasettøye',),
'fasettøye': ('fasettøye',),
'fasettøyene': ('fasettøye',),
'fasettøyer': ('fasettøye',),
'fasettøyet': ('fasettøye',),
'fasettøyne': ('fasettøye',),
'fasettøynene': ('fasettøye',),
'fashion': ('fashion',),
'fashøvel': ('fashøvel',),
'fashøvelen': ('fashøvel',),
'fashøvlene': ('fashøvel',),
'fashøvler': ('fashøvel',),
'fasilitet': ('fasilitet',),
'fasiliteten': ('fasilitet',),
'fasilitetene': ('fasilitet',),
'fasiliteter': ('fasilitet',),
'fasit': ('fasit',),
'fasiten': ('fasit',),
'fasitene': ('fasit',),
'fasiter': ('fasit',),
'fasitsvar': ('fasitsvar',),
'fasitsvara': ('fasitsvar',),
'fasitsvarene': ('fasitsvar',),
'fasitsvaret': ('fasitsvar',),
'faskin': ('faskin',),
'faskinen': ('faskin',),
'faskinene': ('faskin',),
'faskiner': ('faskin',),
'fasle': ('fasle',),
'faslen': ('fasle',),
'faslene': ('fasle',),
'fasler': ('fasle',),
'fasong': ('fasong',),
'fasongen': ('fasong',),
'fasongene': ('fasong',),
'fasonger': ('fasong',),
'fasongjern': ('fasongjern',),
'fasongjerna': ('fasongjern',),
'fasongjernene': ('fasongjern',),
'fasongjernet': ('fasongjern',),
'fasongstål': ('fasongstål',),
'fasongståla': ('fasongstål',),
'fasongstålene': ('fasongstål',),
'fasongstålet': ('fasongstål',),
'fastback': ('fastback',),
'fastbacken': ('fastback',),
'fastbackene': ('fastback',),
'fastbacker': ('fastback',),
'fasta': ('faste',),
'faste': ('faste',),
'fasten': ('faste',),
'fastene': ('faste',),
'faster': ('faste',),
'fastegudstjeneste': ('fastegudstjeneste',),
'fastegudstjenesten': ('fastegudstjeneste',),
'fastegudstjenestene': ('fastegudstjeneste',),
'fastegudstjenester': ('fastegudstjeneste',),
'fastekur': ('fastekur',),
'fastekuren': ('fastekur',),
'fastekurene': ('fastekur',),
'fastekurer': ('fastekur',),
'fastelavn': ('fastelavn',),
'fastelavnen': ('fastelavn',),
'fastelavnene': ('fastelavn',),
'fastelavner': ('fastelavn',),
'fastelavnsbolle': ('fastelavnsbolle',),
'fastelavnsbollen': ('fastelavnsbolle',),
'fastelavnsbollene': ('fastelavnsbolle',),
'fastelavnsboller': ('fastelavnsbolle',),
'fastelavnsmoro': ('fastelavnsmoro',),
'fastelavnsmoroa': ('fastelavnsmoro',),
'fastelavnsmoroen': ('fastelavnsmoro',),
'fastelavnsmoroene': ('fastelavnsmoro',),
'fastelavnsmoroer': ('fastelavnsmoro',),
'fastelavnsris': ('fastelavnsris',),
'fastelavnsrisa': ('fastelavnsris',),
'fastelavnsrisene': ('fastelavnsris',),
'fastelavnsriset': ('fastelavnsris',),
'fastelavnssøndag': ('fastelavnssøndag',),
'fastelavnssøndagen': ('fastelavnssøndag',),
'fastelavnssøndagene': ('fastelavnssøndag',),
'fastelavnssøndager': ('fastelavnssøndag',),
'faster': ('faster',),
'fasteren': ('faster',),
'fastra': ('faster',),
'fastre': ('faster',),
'fastrene': ('faster',),
'fastrer': ('faster',),
'fastetid': ('fastetid',),
'fastetida': ('fastetid',),
'fastetiden': ('fastetid',),
'fastetidene': ('fastetid',),
'fastetider': ('fastetid',),
'fastfrysing': ('fastfrysing',),
'fastfrysinga': ('fastfrysing',),
'fastfrysingen': ('fastfrysing',),
'fastfrysingene': ('fastfrysing',),
'fastfrysinger': ('fastfrysing',),
'fasthet': ('fasthet',),
'fastheta': ('fasthet',),
'fastheten': ('fasthet',),
'fasthetene': ('fasthet',),
'fastheter': ('fasthet',),
'fastland': ('fastland',),
'fastlanda': ('fastland',),
'fastlandene': ('fastland',),
'fastlandet': ('fastland',),
'fastmark': ('fastmark',),
'fastmarka': ('fastmark',),
'fastmarken': ('fastmark',),
'fastmarkene': ('fastmark',),
'fastmarker': ('fastmark',),
'fastnøkkel': ('fastnøkkel',),
'fastnøkkelen': ('fastnøkkel',),
'fastnøklene': ('fastnøkkel',),
'fastnøkler': ('fastnøkkel',),
'fat': ('fat',),
'fata': ('fat',),
'fatene': ('fat',),
'fater': ('fat',),
'fatet': ('fat',),
'fatalisme': ('fatalisme',),
'fatalismen': ('fatalisme',),
'fatalismene': ('fatalisme',),
'fatalismer': ('fatalisme',),
'fatalist': ('fatalist',),
'fatalisten': ('fatalist',),
'fatalistene': ('fatalist',),
'fatalister': ('fatalist',),
'fatalitet': ('fatalitet',),
'fataliteten': ('fatalitet',),
'fatalitetene': ('fatalitet',),
'fataliteter': ('fatalitet',),
'fatamorgana': ('fatamorgana',),
'fatamorganaene': ('fatamorgana',),
'fatamorganaer': ('fatamorgana',),
'fatamorganaet': ('fatamorgana',),
'fating': ('fating',),
'fatingen': ('fating',),
'fatingene': ('fating',),
'fatinger': ('fating',),
'fatle': ('fatle',),
'fatlen': ('fatle',),
'fatlene': ('fatle',),
'fatler': ('fatle',),
'fatning': ('fatning',),
'fatninga': ('fatning',),
'fatningen': ('fatning',),
'fatningene': ('fatning',),
'fatninger': ('fatning',),
'fatteevna': ('fatteevne',),
'fatteevne': ('fatteevne',),
'fatteevnen': ('fatteevne',),
'fatteevnene': ('fatteevne',),
'fatteevner': ('fatteevne',),
'fatter': ('fatter',),
'fattere': ('fatter',),
'fatteren': ('fatter',),
'fatterer': ('fatter',),
'fatterne': ('fatter',),
'fattigdom': ('fattigdom',),
'fattigdommen': ('fattigdom',),
'fattigdommene': ('fattigdom',),
'fattigdommer': ('fattigdom',),
'fattigkassa': ('fattigkasse',),
'fattigkasse': ('fattigkasse',),
'fattigkassen': ('fattigkasse',),
'fattigkassene': ('fattigkasse',),
'fattigkasser': ('fattigkasse',),
'fattigkvarter': ('fattigkvarter',),
'fattigkvartera': ('fattigkvarter',),
'fattigkvarterene': ('fattigkvarter',),
'fattigkvarterer': ('fattigkvarter',),
'fattigkvarteret': ('fattigkvarter',),
'fattigmann': ('fattigmann',),
'fattigmannen': ('fattigmann',),
'fattigmenn': ('fattigmann',),
'fattigmennene': ('fattigmann',),
'fattigmannsbakkels': ('fattigmannsbakkels',),
'fattigmannsbakkelsen': ('fattigmannsbakkels',),
'fattigmannsbakkelsene': ('fattigmannsbakkels',),
'fattigmannsbakkelser': ('fattigmannsbakkels',),
'fattigmannsbakkelse': ('fattigmannsbakkelse',),
'fattigmannsbakkelsen': ('fattigmannsbakkelse',),
'fattigmannsbakkelsene': ('fattigmannsbakkelse',),
'fattigmannsbakkelser': ('fattigmannsbakkelse',),
'fattigmannsbarn': ('fattigmannsbarn',),
'fattigmannsbarna': ('fattigmannsbarn',),
'fattigmannsbarnene': ('fattigmannsbarn',),
'fattigmannsbarnet': ('fattigmannsbarn',),
'fattigmannsstempel': ('fattigmannsstempel',),
'fattigmannsstempelet': ('fattigmannsstempel',),
'fattigmannsstempla': ('fattigmannsstempel',),
'fattigmannsstemplene': ('fattigmannsstempel',),
'fattigmannsstempler': ('fattigmannsstempel',),
'fattigmannsstemplet': ('fattigmannsstempel',),
'fattigmannstrøst': ('fattigmannstrøst',),
'fattigmannstrøsta': ('fattigmannstrøst',),
'fattigmannstrøsten': ('fattigmannstrøst',),
'fattigmannstrøstene': ('fattigmannstrøst',),
'fattigmannstrøster': ('fattigmannstrøst',),
'fata': ('fatum',),
'fataene': ('fatum',),
'fatum': ('fatum',),
'fatumet': ('fatum',),
'fatwa': ('fatwa',),
'fatwaen': ('fatwa',),
'fatwaene': ('fatwa',),
'fatwaer': ('fatwa',),
'fatøl': ('fatøl',),
'fatøla': ('fatøl',),
'fatølene': ('fatøl',),
'fatølet': ('fatøl',),
'fauka': ('fauke',),
'fauke': ('fauke',),
'fauken': ('fauke',),
'faukene': ('fauke',),
'fauker': ('fauke',),
'faun': ('faun',),
'faunen': ('faun',),
'faunene': ('faun',),
'fauner': ('faun',),
'fauna': ('fauna',),
'faunaen': ('fauna',),
'faunaene': ('fauna',),
'faunaer': ('fauna',),
'fauvisme': ('fauvisme',),
'fauvismen': ('fauvisme',),
'fauvismene': ('fauvisme',),
'fauvismer': ('fauvisme',),
'fauvist': ('fauvist',),
'fauvisten': ('fauvist',),
'fauvistene': ('fauvist',),
'fauvister': ('fauvist',),
'favn': ('favn',),
'favnen': ('favn',),
'favnene': ('favn',),
'favner': ('favn',),
'favn': ('favn',),
'favnen': ('favn',),
'favnene': ('favn',),
'favner': ('favn',),
'favntak': ('favntak',),
'favntaka': ('favntak',),
'favntakene': ('favntak',),
'favntaket': ('favntak',),
'favntak': ('favntak',),
'favntaka': ('favntak',),
'favntakene': ('favntak',),
'favntaket': ('favntak',),
'favoritt': ('favoritt',),
'favoritten': ('favoritt',),
'favorittene': ('favoritt',),
'favoritter': ('favoritt',),
'favorittlag': ('favorittlag',),
'favorittlaga': ('favorittlag',),
'favorittlagene': ('favorittlag',),
'favorittlaget': ('favorittlag',),
'favorittmelodi': ('favorittmelodi',),
'favorittmelodien': ('favorittmelodi',),
'favorittmelodiene': ('favorittmelodi',),
'favorittmelodier': ('favorittmelodi',),
'favorittplata': ('favorittplate',),
'favorittplate': ('favorittplate',),
'favorittplaten': ('favorittplate',),
'favorittplatene': ('favorittplate',),
'favorittplater': ('favorittplate',),
'favorittseier': ('favorittseier',),
'favorittseiere': ('favorittseier',),
'favorittseieren': ('favorittseier',),
'favorittseierne': ('favorittseier',),
'favorittseire': ('favorittseier',),
'favorittseirene': ('favorittseier',),
'favorittseirer': ('favorittseier',),
'favorittstempel': ('favorittstempel',),
'favorittstempelet': ('favorittstempel',),
'favorittstempla': ('favorittstempel',),
'favorittstemplene': ('favorittstempel',),
'favorittstempler': ('favorittstempel',),
'favorittstemplet': ('favorittstempel',),
'favør': ('favør',),
'favøren': ('favør',),
'favørene': ('favør',),
'favører': ('favør',),
'favørpris': ('favørpris',),
'favørprisen': ('favørpris',),
'favørprisene': ('favørpris',),
'favørpriser': ('favørpris',),
'fe': ('fe',),
'feen': ('fe',),
'feene': ('fe',),
'feer': ('fe',),
'fe': ('fe',),
'fea': ('fe',),
'feene': ('fe',),
'feet': ('fe',),
'feal': ('feal',),
'feala': ('feal',),
'fealene': ('feal',),
'fealet': ('feal',),
'fealslag': ('fealslag',),
'fealslaga': ('fealslag',),
'fealslagene': ('fealslag',),
'fealslaget': ('fealslag',),
'feavl': ('feavl',),
'feavlen': ('feavl',),
'feavlene': ('feavl',),
'feavler': ('feavl',),
'feavlslag': ('feavlslag',),
'feavlslaga': ('feavlslag',),
'feavlslagene': ('feavlslag',),
'feavlslaget': ('feavlslag',),
'feber': ('feber',),
'febere': ('feber',),
'feberen': ('feber',),
'feberne': ('feber',),
'febre': ('feber',),
'febrene': ('feber',),
'febrer': ('feber',),
'feberdrøm': ('feberdrøm',),
'feberdrømmen': ('feberdrøm',),
'feberdrømmene': ('feberdrøm',),
'feberdrømmer': ('feberdrøm',),
'feberfantasi': ('feberfantasi',),
'feberfantasien': ('feberfantasi',),
'feberfantasiene': ('feberfantasi',),
'feberfantasier': ('feberfantasi',),
'feberørska': ('feberørske',),
'feberørske': ('feberørske',),
'feberørsken': ('feberørske',),
'feberørskene': ('feberørske',),
'feberørsker': ('feberørske',),
'februar': ('februar',),
'fecit': ('fecit',),
'fedd': ('fedd',),
'fedda': ('fedd',),
'feddene': ('fedd',),
'feddet': ('fedd',),
'fedme': ('fedme',),
'fedmen': ('fedme',),
'fedmene': ('fedme',),
'fedmer': ('fedme',),
'fedrearv': ('fedrearv',),
'fedrearven': ('fedrearv',),
'fedrearvene': ('fedrearv',),
'fedrearver': ('fedrearv',),
'fedredyrkelse': ('fedredyrkelse',),
'fedredyrkelsen': ('fedredyrkelse',),
'fedredyrkelsene': ('fedredyrkelse',),
'fedredyrkelser': ('fedredyrkelse',),
'fedredyrking': ('fedredyrking',),
'fedredyrkinga': ('fedredyrking',),
'fedredyrkingen': ('fedredyrking',),
'fedredyrkingene': ('fedredyrking',),
'fedredyrkinger': ('fedredyrking',),
'fedrekult': ('fedrekult',),
'fedrekulten': ('fedrekult',),
'fedrekultene': ('fedrekult',),
'fedrekulter': ('fedrekult',),
'fedrekultus': ('fedrekultus',),
'fedrekultusen': ('fedrekultus',),
'fedrekultusene': ('fedrekultus',),
'fedrekultuser': ('fedrekultus',),
'fedreland': ('fedreland',),
'fedrelanda': ('fedreland',),
'fedrelandene': ('fedreland',),
'fedrelandet': ('fedreland',),
'fedrelandskjærlighet': ('fedrelandskjærlighet',),
'fedrelandskjærligheta': ('fedrelandskjærlighet',),
'fedrelandskjærligheten': ('fedrelandskjærlighet',),
'fedrelandskjærlighetene': ('fedrelandskjærlighet',),
'fedrelandskjærligheter': ('fedrelandskjærlighet',),
'fedrelandssalme': ('fedrelandssalme',),
'fedrelandssalmen': ('fedrelandssalme',),
'fedrelandssalmene': ('fedrelandssalme',),
'fedrelandssalmer': ('fedrelandssalme',),
'fedrenearv': ('fedrenearv',),
'fedrenearven': ('fedrenearv',),
'fedrenearvene': ('fedrenearv',),
'fedrenearver': ('fedrenearv',),
'fedrift': ('fedrift',),
'fedrifta': ('fedrift',),
'fedriften': ('fedrift',),
'fedriftene': ('fedrift',),
'fedrifter': ('fedrift',),
'feedback': ('feedback',),
'feedbacken': ('feedback',),
'feedbackene': ('feedback',),
'feedbacks': ('feedback',),
'fefot': ('fefot',),
'fefoten': ('fefot',),
'feføttene': ('fefot',),
'feføtter': ('fefot',),
'fehoda': ('fehode',),
'fehode': ('fehode',),
'fehodene': ('fehode',),
'fehoder': ('fehode',),
'fehodet': ('fehode',),
'fei': ('fei',),
'feide': ('feide',),
'feiden': ('feide',),
'feidene': ('feide',),
'feider': ('feide',),
'feiebrett': ('feiebrett',),
'feiebretta': ('feiebrett',),
'feiebrettene': ('feiebrett',),
'feiebretter': ('feiebrett',),
'feiebrettet': ('feiebrett',),
'feiekost': ('feiekost',),
'feiekosten': ('feiekost',),
'feiekostene': ('feiekost',),
'feiekoster': ('feiekost',),
'feier': ('feier',),
'feiere': ('feier',),
'feieren': ('feier',),
'feierer': ('feier',),
'feierne': ('feier',),
'feiging': ('feiging',),
'feigingen': ('feiging',),
'feigingene': ('feiging',),
'feiginger': ('feiging',),
'feil': ('feil',),
'feila': ('feil',),
'feilen': ('feil',),
'feilene': ('feil',),
'feilernæring': ('feilernæring',),
'feilernæringa': ('feilernæring',),
'feilernæringen': ('feilernæring',),
'feilernæringene': ('feilernæring',),
'feilernæringer': ('feilernæring',),
'feilgrensa': ('feilgrense',),
'feilgrense': ('feilgrense',),
'feilgrensen': ('feilgrense',),
'feilgrensene': ('feilgrense',),
'feilgrenser': ('feilgrense',),
'feilgrep': ('feilgrep',),
'feilgrepa': ('feilgrep',),
'feilgrepene': ('feilgrep',),
'feilgrepet': ('feilgrep',),
'feilkilde': ('feilkilde',),
'feilkilden': ('feilkilde',),
'feilkildene': ('feilkilde',),
'feilkilder': ('feilkilde',),
'feilkjelda': ('feilkjelde',),
'feilkjelde': ('feilkjelde',),
'feilkjelden': ('feilkjelde',),
'feilkjeldene': ('feilkjelde',),
'feilkjelder': ('feilkjelde',),
'feilmargin': ('feilmargin',),
'feilmarginen': ('feilmargin',),
'feilmarginene': ('feilmargin',),
'feilmarginer': ('feilmargin',),
'feilmelding': ('feilmelding',),
'feilmeldinga': ('feilmelding',),
'feilmeldingen': ('feilmelding',),
'feilmeldingene': ('feilmelding',),
'feilmeldinger': ('feilmelding',),
'feilpasning': ('feilpasning',),
'feilpasninga': ('feilpasning',),
'feilpasningen': ('feilpasning',),
'feilpasningene': ('feilpasning',),
'feilpasninger': ('feilpasning',),
'feilreaksjon': ('feilreaksjon',),
'feilreaksjonen': ('feilreaksjon',),
'feilreaksjonene': ('feilreaksjon',),
'feilreaksjoner': ('feilreaksjon',),
'feilsitat': ('feilsitat',),
'feilsitata': ('feilsitat',),
'feilsitatene': ('feilsitat',),
'feilsitater': ('feilsitat',),
'feilsitatet': ('feilsitat',),
'feilskjær': ('feilskjær',),
'feilskjæra': ('feilskjær',),
'feilskjærene': ('feilskjær',),
'feilskjæret': ('feilskjær',),
'feilslag': ('feilslag',),
'feilslaga': ('feilslag',),
'feilslagene': ('feilslag',),
'feilslaget': ('feilslag',),
'feilslutning': ('feilslutning',),
'feilslutninga': ('feilslutning',),
'feilslutningen': ('feilslutning',),
'feilslutningene': ('feilslutning',),
'feilslutninger': ('feilslutning',),
'feilspor': ('feilspor',),
'feilspora': ('feilspor',),
'feilsporene': ('feilspor',),
'feilsporet': ('feilspor',),
'feilsøking': ('feilsøking',),
'feilsøkinga': ('feilsøking',),
'feilsøkingen': ('feilsøking',),
'feilsøkingene': ('feilsøking',),
'feilsøkinger': ('feilsøking',),
'feiltak': ('feiltak',),
'feiltaka': ('feiltak',),
'feiltakene': ('feiltak',),
'feiltaket': ('feiltak',),
'feiltakelse': ('feiltakelse',),
'feiltakelsen': ('feiltakelse',),
'feiltakelsene': ('feiltakelse',),
'feiltakelser': ('feiltakelse',),
'feiltrinn': ('feiltrinn',),
'feiltrinna': ('feiltrinn',),
'feiltrinnene': ('feiltrinn',),
'feiltrinnet': ('feiltrinn',),
'feiltrykk': ('feiltrykk',),
'feiltrykka': ('feiltrykk',),
'feiltrykkene': ('feiltrykk',),
'feiltrykket': ('feiltrykk',),
'feilvara': ('feilvare',),
'feilvare': ('feilvare',),
'feilvaren': ('feilvare',),
'feilvarene': ('feilvare',),
'feilvarer': ('feilvare',),
'feinschmecker': ('feinschmecker',),
'feinschmeckere': ('feinschmecker',),
'feinschmeckeren': ('feinschmecker',),
'feinschmeckerer': ('feinschmecker',),
'feinschmeckerne': ('feinschmecker',),
'feisel': ('feisel',),
'feiselen': ('feisel',),
'feislene': ('feisel',),
'feisler': ('feisel',),
'feita': ('feite',),
'feite': ('feite',),
'feiten': ('feite',),
'feitene': ('feite',),
'feiter': ('feite',),
'feitedyr': ('feitedyr',),
'feitedyra': ('feitedyr',),
'feitedyrene': ('feitedyr',),
'feitedyret': ('feitedyr',),
'feitegris': ('feitegris',),
'feitegrisen': ('feitegris',),
'feitegrisene': ('feitegris',),
'feitegriser': ('feitegris',),
'feitetirsdag': ('feitetirsdag',),
'feitetirsdagen': ('feitetirsdag',),
'feitetirsdagene': ('feitetirsdag',),
'feitetirsdager': ('feitetirsdag',),
'feitevara': ('feitevare',),
'feitevare': ('feitevare',),
'feitevaren': ('feitevare',),
'feitevarene': ('feitevare',),
'feitevarer': ('feitevare',),
'feitost': ('feitost',),
'feitosten': ('feitost',),
'feitostene': ('feitost',),
'feitoster': ('feitost',),
'feitsild': ('feitsild',),
'feitsilda': ('feitsild',),
'feitsilden': ('feitsild',),
'feitsildene': ('feitsild',),
'feitsilder': ('feitsild',),
'feitsildfiska': ('feitsildfiske',),
'feitsildfiske': ('feitsildfiske',),
'feitsildfiskene': ('feitsildfiske',),
'feitsildfisker': ('feitsildfiske',),
'feitsildfisket': ('feitsildfiske',),
'feittrykk': ('feittrykk',),
'feittrykka': ('feittrykk',),
'feittrykken': ('feittrykk',),
'feittrykkene': ('feittrykk',),
'feittrykker': ('feittrykk',),
'feittrykket': ('feittrykk',),
'fekar': ('fekar',),
'fekaren': ('fekar',),
'fekarene': ('fekar',),
'fekarer': ('fekar',),
'fektekonkurranse': ('fektekonkurranse',),
'fektekonkurransen': ('fektekonkurranse',),
'fektekonkurransene': ('fektekonkurranse',),
'fektekonkurranser': ('fektekonkurranse',),
'fektekunst': ('fektekunst',),
'fektekunsten': ('fektekunst',),
'fektekunstene': ('fektekunst',),
'fektekunster': ('fektekunst',),
'fektemester': ('fektemester',),
'fektemestere': ('fektemester',),
'fektemesteren': ('fektemester',),
'fektemesterer': ('fektemester',),
'fektemesterne': ('fektemester',),
'fektemestre': ('fektemester',),
'fektemestrene': ('fektemester',),
'fektemestrer': ('fektemester',),
'fekter': ('fekter',),
'fektere': ('fekter',),
'fekteren': ('fekter',),
'fekterer': ('fekter',),
'fekterne': ('fekter',),
'fekting': ('fekting',),
'fektinga': ('fekting',),
'fektingen': ('fekting',),
'fektingene': ('fekting',),
'fektinger': ('fekting',),
'fektning': ('fektning',),
'fektninga': ('fektning',),
'fektningen': ('fektning',),
'fektningene': ('fektning',),
'fektninger': ('fektning',),
'fekunditet': ('fekunditet',),
'fekunditeten': ('fekunditet',),
'fekunditetene': ('fekunditet',),
'fekunditeter': ('fekunditet',),
'fela': ('fele',),
'fele': ('fele',),
'felen': ('fele',),
'felene': ('fele',),
'feler': ('fele',),
'feleboge': ('feleboge',),
'felebogen': ('feleboge',),
'felebogene': ('feleboge',),
'feleboger': ('feleboge',),
'felebue': ('felebue',),
'felebuen': ('felebue',),
'felebuene': ('felebue',),
'felebuer': ('felebue',),
'felehals': ('felehals',),
'felehalsen': ('felehals',),
'felehalsene': ('felehals',),
'felehalser': ('felehals',),
'felekappleik': ('felekappleik',),
'felekappleiken': ('felekappleik',),
'felekappleikene': ('felekappleik',),
'felekappleiker': ('felekappleik',),
'feleslått': ('feleslått',),
'feleslåtten': ('feleslått',),
'feleslåttene': ('feleslått',),
'feleslåtter': ('feleslått',),
'felespeller': ('felespeller',),
'felespellere': ('felespeller',),
'felespelleren': ('felespeller',),
'felespellerer': ('felespeller',),
'felespellerne': ('felespeller',),
'felespiller': ('felespiller',),
'felespillere': ('felespiller',),
'felespilleren': ('felespiller',),
'felespillerer': ('felespiller',),
'felespillerne': ('felespiller',),
'felestreng': ('felestreng',),
'felestrengen': ('felestreng',),
'felestrengene': ('felestreng',),
'felestrenger': ('felestreng',),
'felg': ('felg',),
'felgen': ('felg',),
'felgene': ('felg',),
'felger': ('felg',),
'felgbrems': ('felgbrems',),
'felgbremsen': ('felgbrems',),
'felgbremsene': ('felgbrems',),
'felgbremser': ('felgbrems',),
'felgbremsa': ('felgbremse',),
'felgbremse': ('felgbremse',),
'felgbremsen': ('felgbremse',),
'felgbremsene': ('felgbremse',),
'felgbremser': ('felgbremse',),
'fell': ('fell',),
'fellen': ('fell',),
'fellene': ('fell',),
'feller': ('fell',),
'fellah': ('fellah',),
'fellahen': ('fellah',),
'fellahene': ('fellah',),
'fellaher': ('fellah',),
'felle': ('felle',),
'fellen': ('felle',),
'fellene': ('felle',),
'feller': ('felle',),
'fella': ('felle',),
'felle': ('felle',),
'fellen': ('felle',),
'fellene': ('felle',),
'feller': ('felle',),
'felles': ('felles',),
'fellesanlegg': ('fellesanlegg',),
'fellesanlegga': ('fellesanlegg',),
'fellesanleggene': ('fellesanlegg',),
'fellesanlegget': ('fellesanlegg',),
'fellesantenna': ('fellesantenne',),
'fellesantenne': ('fellesantenne',),
'fellesantennen': ('fellesantenne',),
'fellesantennene': ('fellesantenne',),
'fellesantenner': ('fellesantenne',),
'fellesbeita': ('fellesbeite',),
'fellesbeite': ('fellesbeite',),
'fellesbeitene': ('fellesbeite',),
'fellesbeiter': ('fellesbeite',),
'fellesbeitet': ('fellesbeite',),
'fellesbetegnelse': ('fellesbetegnelse',),
'fellesbetegnelsen': ('fellesbetegnelse',),
'fellesbetegnelsene': ('fellesbetegnelse',),
'fellesbetegnelser': ('fellesbetegnelse',),
'felleseia': ('felleseie',),
'felleseie': ('felleseie',),
'felleseiene': ('felleseie',),
'felleseier': ('felleseie',),
'felleseiet': ('felleseie',),
'fellesferie': ('fellesferie',),
'fellesferien': ('fellesferie',),
'fellesferiene': ('fellesferie',),
'fellesferier': ('fellesferie',),
'fellesfjøs': ('fellesfjøs',),
'fellesfjøsa': ('fellesfjøs',),
'fellesfjøsen': ('fellesfjøs',),
'fellesfjøsene': ('fellesfjøs',),
'fellesfjøset': ('fellesfjøs',),
'fellesforbruk': ('fellesforbruk',),
'fellesforbruka': ('fellesforbruk',),
'fellesforbrukene': ('fellesforbruk',),
'fellesforbruket': ('fellesforbruk',),
'felleshavari': ('felleshavari',),
'felleshavaria': ('felleshavari',),
'felleshavariene': ('felleshavari',),
'felleshavarier': ('felleshavari',),
'felleshavariet': ('felleshavari',),
'felleskjønn': ('felleskjønn',),
'felleskjønna': ('felleskjønn',),
'felleskjønnene': ('felleskjønn',),
'felleskjønnet': ('felleskjønn',),
'felleslista': ('fellesliste',),
'fellesliste': ('fellesliste',),
'felleslisten': ('fellesliste',),
'felleslistene': ('fellesliste',),
'felleslister': ('fellesliste',),
'fellesmarked': ('fellesmarked',),
'fellesmarkeda': ('fellesmarked',),
'fellesmarkedene': ('fellesmarked',),
'fellesmarkeder': ('fellesmarked',),
'fellesmarkedet': ('fellesmarked',),
'fellesmarknad': ('fellesmarknad',),
'fellesmarknaden': ('fellesmarknad',),
'fellesmarknadene': ('fellesmarknad',),
'fellesmarknader': ('fellesmarknad',),
'fellesnavn': ('fellesnavn',),
'fellesnavna': ('fellesnavn',),
'fellesnavnene': ('fellesnavn',),
'fellesnavnet': ('fellesnavn',),
'fellesnevner': ('fellesnevner',),
'fellesnevnere': ('fellesnevner',),
'fellesnevneren': ('fellesnevner',),
'fellesnevnerer': ('fellesnevner',),
'fellesnevnerne': ('fellesnevner',),
'fellesseter': ('fellesseter',),
'fellessetere': ('fellesseter',),
'fellesseteren': ('fellesseter',),
'fellesseterne': ('fellesseter',),
'fellessetra': ('fellesseter',),
'fellessetre': ('fellesseter',),
'fellessetrene': ('fellesseter',),
'fellessetrer': ('fellesseter',),
'fellesskap': ('fellesskap',),
'fellesskapa': ('fellesskap',),
'fellesskapene': ('fellesskap',),
'fellesskaper': ('fellesskap',),
'fellesskapet': ('fellesskap',),
'fellesstart': ('fellesstart',),
'fellesstarten': ('fellesstart',),
'fellesstartene': ('fellesstart',),
'fellesstarter': ('fellesstart',),
'felling': ('felling',),
'fellinga': ('felling',),
'fellingen': ('felling',),
'fellingene': ('felling',),
'fellinger': ('felling',),
'fellingskvote': ('fellingskvote',),
'fellingskvoten': ('fellingskvote',),
'fellingskvotene': ('fellingskvote',),
'fellingskvoter': ('fellingskvote',),
'fellingstillatelse': ('fellingstillatelse',),
'fellingstillatelsen': ('fellingstillatelse',),
'fellingstillatelsene': ('fellingstillatelse',),
'fellingstillatelser': ('fellingstillatelse',),
'felt': ('felt',),
'felten': ('felt',),
'feltene': ('felt',),
'felter': ('felt',),
'felt': ('felt',),
'felta': ('felt',),
'feltene': ('felt',),
'felter': ('felt',),
'feltet': ('felt',),
'feltanalysa': ('feltanalyse',),
'feltanalyse': ('feltanalyse',),
'feltanalysen': ('feltanalyse',),
'feltanalysene': ('feltanalyse',),
'feltanalyser': ('feltanalyse',),
'feltarbeid': ('feltarbeid',),
'feltarbeida': ('feltarbeid',),
'feltarbeidene': ('feltarbeid',),
'feltarbeider': ('feltarbeid',),
'feltarbeidet': ('feltarbeid',),
'feltartilleri': ('feltartilleri',),
'feltartilleria': ('feltartilleri',),
'feltartilleriene': ('feltartilleri',),
'feltartillerier': ('feltartilleri',),
'feltartilleriet': ('feltartilleri',),
'feltfot': ('feltfot',),
'feltfoten': ('feltfot',),
'feltføttene': ('feltfot',),
'feltføtter': ('feltfot',),
'felthaubits': ('felthaubits',),
'felthaubitsen': ('felthaubits',),
'felthaubitsene': ('felthaubits',),
'felthaubitser': ('felthaubits',),
'feltherre': ('feltherre',),
'feltherren': ('feltherre',),
'feltherrene': ('feltherre',),
'feltherrer': ('feltherre',),
'feltkjøkken': ('feltkjøkken',),
'feltkjøkkena': ('feltkjøkken',),
'feltkjøkkenene': ('feltkjøkken',),
'feltkjøkkener': ('feltkjøkken',),
'feltkjøkkenet': ('feltkjøkken',),
'feltlasarett': ('feltlasarett',),
'feltlasaretta': ('feltlasarett',),
'feltlasarettene': ('feltlasarett',),
'feltlasaretter': ('feltlasarett',),
'feltlasarettet': ('feltlasarett',),
'feltmarsjall': ('feltmarsjall',),
'feltmarsjallen': ('feltmarsjall',),
'feltmarsjallene': ('feltmarsjall',),
'feltmarsjaller': ('feltmarsjall',),
'feltmarskalk': ('feltmarskalk',),
'feltmarskalken': ('feltmarskalk',),
'feltmarskalkene': ('feltmarskalk',),
'feltmarskalker': ('feltmarskalk',),
'feltpost': ('feltpost',),
'feltposten': ('feltpost',),
'feltpostene': ('feltpost',),
'feltposter': ('feltpost',),
'feltprest': ('feltprest',),
'feltpresten': ('feltprest',),
'feltprestene': ('feltprest',),
'feltprester': ('feltprest',),
'feltrop': ('feltrop',),
'feltropa': ('feltrop',),
'feltropene': ('feltrop',),
'feltropet': ('feltrop',),
'feltseng': ('feltseng',),
'feltsenga': ('feltseng',),
'feltsengen': ('feltseng',),
'feltsengene': ('feltseng',),
'feltsenger': ('feltseng',),
'feltsjukehus': ('feltsjukehus',),
'feltsjukehusa': ('feltsjukehus',),
'feltsjukehusene': ('feltsjukehus',),
'feltsjukehuset': ('feltsjukehus',),
'feltspat': ('feltspat',),
'feltspaten': ('feltspat',),
'feltspatene': ('feltspat',),
'feltspater': ('feltspat',),
'feltstol': ('feltstol',),
'feltstolen': ('feltstol',),
'feltstolene': ('feltstol',),
'feltstoler': ('feltstol',),
'feltsykehus': ('feltsykehus',),
'feltsykehusa': ('feltsykehus',),
'feltsykehusene': ('feltsykehus',),
'feltsykehuset': ('feltsykehus',),
'felttog': ('felttog',),
'felttoga': ('felttog',),
'felttogene': ('felttog',),
'felttoget': ('felttog',),
'feltundersøkelse': ('feltundersøkelse',),
'feltundersøkelsen': ('feltundersøkelse',),
'feltundersøkelsene': ('feltundersøkelse',),
'feltundersøkelser': ('feltundersøkelse',),
'feltuniform': ('feltuniform',),
'feltuniforma': ('feltuniform',),
'feltuniformen': ('feltuniform',),
'feltuniformene': ('feltuniform',),
'feltuniformer': ('feltuniform',),
'felås': ('felås',),
'felåsa': ('felås',),
'felåsen': ('felås',),
'felåsene': ('felås',),
'felåser': ('felås',),
'felåset': ('felås',),
'femakter': ('femakter',),
'femaktere': ('femakter',),
'femakteren': ('femakter',),
'femakterer': ('femakter',),
'femakterne': ('femakter',),
'fembladrosa': ('fembladrose',),
'fembladrose': ('fembladrose',),
'fembladrosen': ('fembladrose',),
'fembladrosene': ('fembladrose',),
'fembladroser': ('fembladrose',),
'fembøring': ('fembøring',),
'fembøringen': ('fembøring',),
'fembøringene': ('fembøring',),
'fembøringer': ('fembøring',),
'femdagersuka': ('femdagersuke',),
'femdagersuke': ('femdagersuke',),
'femdagersuken': ('femdagersuke',),
'femdagersukene': ('femdagersuke',),
'femdagersuker': ('femdagersuke',),
'femdagersveka': ('femdagersveke',),
'femdagersveke': ('femdagersveke',),
'femdagersveken': ('femdagersveke',),
'femdagersvekene': ('femdagersveke',),
'femdagersveker': ('femdagersveke',),
'femdel': ('femdel',),
'femdelen': ('femdel',),
'femdelene': ('femdel',),
'femdeler': ('femdel',),
'feminina': ('femininum',),
'femininaene': ('femininum',),
'femininene': ('femininum',),
'femininer': ('femininum',),
'femininet': ('femininum',),
'femininum': ('femininum',),
'femininumet': ('femininum',),
'feminisme': ('feminisme',),
'feminismen': ('feminisme',),
'feminismene': ('feminisme',),
'feminismer': ('feminisme',),
'feminist': ('feminist',),
'feministen': ('feminist',),
'feministene': ('feminist',),
'feminister': ('feminist',),
'femkamp': ('femkamp',),
'femkampen': ('femkamp',),
'femkampene': ('femkamp',),
'femkamper': ('femkamp',),
'femkant': ('femkant',),
'femkanten': ('femkant',),
'femkantene': ('femkant',),
'femkanter': ('femkant',),
'femklang': ('femklang',),
'femklangen': ('femklang',),
'femklangene': ('femklang',),
'femklanger': ('femklang',),
'femkrona': ('femkrone',),
'femkrone': ('femkrone',),
'femkronen': ('femkrone',),
'femkronene': ('femkrone',),
'femkroner': ('femkrone',),
'femkroning': ('femkroning',),
'femkroningen': ('femkroning',),
'femkroningene': ('femkroning',),
'femkroninger': ('femkroning',),
'femling': ('femling',),
'femlingen': ('femling',),
'femlingene': ('femling',),
'femlinger': ('femling',),
'femmaster': ('femmaster',),
'femmastere': ('femmaster',),
'femmasteren': ('femmaster',),
'femmasterer': ('femmaster',),
'femmasterne': ('femmaster',),
'femme fatale': ('femme fatale',),
'femmer': ('femmer',),
'femmere': ('femmer',),
'femmeren': ('femmer',),
'femmerer': ('femmer',),
'femmerne': ('femmer',),
'femmeter': ('femmeter',),
'femmetere': ('femmeter',),
'femmeteren': ('femmeter',),
'femmeterer': ('femmeter',),
'femmeterne': ('femmeter',),
'femromsleilighet': ('femromsleilighet',),
'femromsleiligheta': ('femromsleilighet',),
'femromsleiligheten': ('femromsleilighet',),
'femromsleilighetene': ('femromsleilighet',),
'femromsleiligheter': ('femromsleilighet',),
'femseter': ('femseter',),
'femsetere': ('femseter',),
'femseteren': ('femseter',),
'femseterer': ('femseter',),
'femseterne': ('femseter',),
'femtal': ('femtal',),
'femtala': ('femtal',),
'femtalene': ('femtal',),
'femtalet': ('femtal',),
'femtall': ('femtall',),
'femtalla': ('femtall',),
'femtallene': ('femtall',),
'femtallet': ('femtall',),
'femtedag': ('femtedag',),
'femtedagen': ('femtedag',),
'femtedagene': ('femtedag',),
'femtedager': ('femtedag',),
'femtedel': ('femtedel',),
'femtedelen': ('femtedel',),
'femtedelene': ('femtedel',),
'femtedeler': ('femtedel',),
'femtegir': ('femtegir',),
'femtegira': ('femtegir',),
'femtegirene': ('femtegir',),
'femtegiret': ('femtegir',),
'femtekolonne': ('femtekolonne',),
'femtekolonnen': ('femtekolonne',),
'femtekolonnene': ('femtekolonne',),
'femtekolonner': ('femtekolonne',),
'femtekolonnist': ('femtekolonnist',),
'femtekolonnisten': ('femtekolonnist',),
'femtekolonnistene': ('femtekolonnist',),
'femtekolonnister': ('femtekolonnist',),
'femtendel': ('femtendel',),
'femtendelen': ('femtendel',),
'femtendelene': ('femtendel',),
'femtendeler': ('femtendel',),
'femtenhundretal': ('femtenhundretal',),
'femtenhundretala': ('femtenhundretal',),
'femtenhundretalene': ('femtenhundretal',),
'femtenhundretalet': ('femtenhundretal',),
'femtenhundretall': ('femtenhundretall',),
'femtenhundretalla': ('femtenhundretall',),
'femtenhundretallene': ('femtenhundretall',),
'femtenhundretallet': ('femtenhundretall',),
'femtenåring': ('femtenåring',),
'femtenåringen': ('femtenåring',),
'femtenåringene': ('femtenåring',),
'femtenåringer': ('femtenåring',),
'femtenårsalder': ('femtenårsalder',),
'femtenårsaldere': ('femtenårsalder',),
'femtenårsalderen': ('femtenårsalder',),
'femtenårsalderer': ('femtenårsalder',),
'femtenårsalderne': ('femtenårsalder',),
'femtenårsaldre': ('femtenårsalder',),
'femtenårsaldrene': ('femtenårsalder',),
'femtenårsaldrer': ('femtenårsalder',),
'femtid': ('femtid',),
'femtida': ('femtid',),
'femtiden': ('femtid',),
'femtidene': ('femtid',),
'femtider': ('femtid',),
'femtidel': ('femtidel',),
'femtidelen': ('femtidel',),
'femtidelene': ('femtidel',),
'femtideler': ('femtidel',),
'femtikilometer': ('femtikilometer',),
'femtikilometere': ('femtikilometer',),
'femtikilometeren': ('femtikilometer',),
'femtikilometerer': ('femtikilometer',),
'femtikilometerne': ('femtikilometer',),
'femtikroneseddel': ('femtikroneseddel',),
'femtikroneseddelen': ('femtikroneseddel',),
'femtikronesedlene': ('femtikroneseddel',),
'femtikronesedler': ('femtikroneseddel',),
'femtilapp': ('femtilapp',),
'femtilappen': ('femtilapp',),
'femtilappene': ('femtilapp',),
'femtilapper': ('femtilapp',),
'femtiliter': ('femtiliter',),
'femtilitere': ('femtiliter',),
'femtiliteren': ('femtiliter',),
'femtiliterer': ('femtiliter',),
'femtiliterne': ('femtiliter',),
'femtiår': ('femtiår',),
'femtiåra': ('femtiår',),
'femtiårene': ('femtiår',),
'femtiåret': ('femtiår',),
'femtiåring': ('femtiåring',),
'femtiåringen': ('femtiåring',),
'femtiåringene': ('femtiåring',),
'femtiåringer': ('femtiåring',),
'femtiårsdag': ('femtiårsdag',),
'femtiårsdagen': ('femtiårsdag',),
'femtiårsdagene': ('femtiårsdag',),
'femtiårsdager': ('femtiårsdag',),
'femtiårsjubilea': ('femtiårsjubileum',),
'femtiårsjubileene': ('femtiårsjubileum',),
'femtiårsjubileer': ('femtiårsjubileum',),
'femtiårsjubileet': ('femtiårsjubileum',),
'femtiårsjubileum': ('femtiårsjubileum',),
'femtiøre': ('femtiøre',),
'femtiøren': ('femtiøre',),
'femtiørene': ('femtiøre',),
'femtiører': ('femtiøre',),
'femtiøring': ('femtiøring',),
'femtiøringen': ('femtiøring',),
'femtiøringene': ('femtiøring',),
'femtiøringer': ('femtiøring',),
'femåring': ('femåring',),
'femåringen': ('femåring',),
'femåringene': ('femåring',),
'femåringer': ('femåring',),
'femårsalder': ('femårsalder',),
'femårsaldere': ('femårsalder',),
'femårsalderen': ('femårsalder',),
'femårsalderer': ('femårsalder',),
'femårsalderne': ('femårsalder',),
'femårsaldre': ('femårsalder',),
'femårsaldrene': ('femårsalder',),
'femårsaldrer': ('femårsalder',),
'femårsplan': ('femårsplan',),
'femårsplanen': ('femårsplan',),
'femårsplanene': ('femårsplan',),
'femårsplaner': ('femårsplan',),
'femøre': ('femøre',),
'femøren': ('femøre',),
'femørene': ('femøre',),
'femører': ('femøre',),
'femøring': ('femøring',),
'femøringen': ('femøring',),
'femøringene': ('femøring',),
'femøringer': ('femøring',),
'fenad': ('fenad',),
'fenaden': ('fenad',),
'fenadene': ('fenad',),
'fenader': ('fenad',),
'fenadknok': ('fenadknok',),
'fenadknoken': ('fenadknok',),
'fenadknokene': ('fenadknok',),
'fenadknoker': ('fenadknok',),
'fenadknoke': ('fenadknoke',),
'fenadknoken': ('fenadknoke',),
'fenadknokene': ('fenadknoke',),
'fenadknoker': ('fenadknoke',),
'fenadlår': ('fenadlår',),
'fenadlåra': ('fenadlår',),
'fenadlårene': ('fenadlår',),
'fenadlåret': ('fenadlår',),
'fenalår': ('fenalår',),
'fenalåra': ('fenalår',),
'fenalårene': ('fenalår',),
'fenalåret': ('fenalår',),
'fender': ('fender',),
'fendere': ('fender',),
'fenderen': ('fender',),
'fenderer': ('fender',),
'fenderne': ('fender',),
'fendre': ('fender',),
'fendrene': ('fender',),
'fendrer': ('fender',),
'fenderputa': ('fenderpute',),
'fenderpute': ('fenderpute',),
'fenderputen': ('fenderpute',),
'fenderputene': ('fenderpute',),
'fenderputer': ('fenderpute',),
'fenga': ('fenge',),
'fenge': ('fenge',),
'fengene': ('fenge',),
'fenger': ('fenge',),
'fenget': ('fenge',),
'fenghetta': ('fenghette',),
'fenghette': ('fenghette',),
'fenghetten': ('fenghette',),
'fenghettene': ('fenghette',),
'fenghetter': ('fenghette',),
'fenghol': ('fenghol',),
'fenghola': ('fenghol',),
'fengholene': ('fenghol',),
'fengholet': ('fenghol',),
'fenghull': ('fenghull',),
'fenghulla': ('fenghull',),
'fenghullene': ('fenghull',),
'fenghuller': ('fenghull',),
'fenghullet': ('fenghull',),
'fengsel': ('fengsel',),
'fengselet': ('fengsel',),
'fengsla': ('fengsel',),
'fengslene': ('fengsel',),
'fengsler': ('fengsel',),
'fengslet': ('fengsel',),
'fengselsbetjent': ('fengselsbetjent',),
'fengselsbetjenten': ('fengselsbetjent',),
'fengselsbetjentene': ('fengselsbetjent',),
'fengselsbetjenter': ('fengselsbetjent',),
'fengselscella': ('fengselscelle',),
'fengselscelle': ('fengselscelle',),
'fengselscellen': ('fengselscelle',),
'fengselscellene': ('fengselscelle',),
'fengselsceller': ('fengselscelle',),
'fengselsfugl': ('fengselsfugl',),
'fengselsfuglen': ('fengselsfugl',),
'fengselsfuglene': ('fengselsfugl',),
'fengselsfugler': ('fengselsfugl',),
'fengselsmur': ('fengselsmur',),
'fengselsmuren': ('fengselsmur',),
'fengselsmurene': ('fengselsmur',),
'fengselsmurer': ('fengselsmur',),
'fengselsopphold': ('fengselsopphold',),
'fengselsoppholda': ('fengselsopphold',),
'fengselsoppholdene': ('fengselsopphold',),
'fengselsoppholdet': ('fengselsopphold',),
'fengselsprest': ('fengselsprest',),
'fengselspresten': ('fengselsprest',),
'fengselsprestene': ('fengselsprest',),
'fengselsprester': ('fengselsprest',),
'fengselspsykose': ('fengselspsykose',),
'fengselspsykosen': ('fengselspsykose',),
'fengselspsykosene': ('fengselspsykose',),
'fengselspsykoser': ('fengselspsykose',),
'fengselsskole': ('fengselsskole',),
'fengselsskolen': ('fengselsskole',),
'fengselsskolene': ('fengselsskole',),
'fengselsskoler': ('fengselsskole',),
'fengselsstraff': ('fengselsstraff',),
'fengselsstraffen': ('fengselsstraff',),
'fengselsstraffene': ('fengselsstraff',),
'fengselsstraffer': ('fengselsstraff',),
'fengselsvesen': ('fengselsvesen',),
'fengselsvesena': ('fengselsvesen',),
'fengselsvesenene': ('fengselsvesen',),
'fengselsvesener': ('fengselsvesen',),
'fengselsvesenet': ('fengselsvesen',),
'fengsling': ('fengsling',),
'fengslinga': ('fengsling',),
'fengslingen': ('fengsling',),
'fengslingene': ('fengsling',),
'fengslinger': ('fengsling',),
'fengslingskjennelse': ('fengslingskjennelse',),
'fengslingskjennelsen': ('fengslingskjennelse',),
'fengslingskjennelsene': ('fengslingskjennelse',),
'fengslingskjennelser': ('fengslingskjennelse',),
'fennek': ('fennek',),
'fenneken': ('fennek',),
'fennekene': ('fennek',),
'fenneker': ('fennek',),
'fennik': ('fennik',),
'fenniken': ('fennik',),
'fennikene': ('fennik',),
'fenniker': ('fennik',),
'fennikel': ('fennikel',),
'fennikelen': ('fennikel',),
'fenniklene': ('fennikel',),
'fennikler': ('fennikel',),
'fennikelolja': ('fennikelolje',),
'fennikelolje': ('fennikelolje',),
'fennikeloljen': ('fennikelolje',),
'fennikeloljene': ('fennikelolje',),
'fennikeloljer': ('fennikelolje',),
'fennolog': ('fennolog',),
'fennologen': ('fennolog',),
'fennologene': ('fennolog',),
'fennologer': ('fennolog',),
'fennologi': ('fennologi',),
'fennologien': ('fennologi',),
'fennologiene': ('fennologi',),
'fennologier': ('fennologi',),
'fennoman': ('fennoman',),
'fennomanen': ('fennoman',),
'fennomanene': ('fennoman',),
'fennomaner': ('fennoman',),
'fenol': ('fenol',),
'fenolen': ('fenol',),
'fenolene': ('fenol',),
'fenoler': ('fenol',),
'fenolharpiks': ('fenolharpiks',),
'fenolharpiksen': ('fenolharpiks',),
'fenolharpiksene': ('fenolharpiks',),
'fenolharpikser': ('fenolharpiks',),
'fenologi': ('fenologi',),
'fenologien': ('fenologi',),
'fenologiene': ('fenologi',),
'fenologier': ('fenologi',),
'fenolplast': ('fenolplast',),
'fenolplasten': ('fenolplast',),
'fenolplastene': ('fenolplast',),
'fenolplaster': ('fenolplast',),
'fenomen': ('fenomen',),
'fenomena': ('fenomen',),
'fenomenene': ('fenomen',),
'fenomener': ('fenomen',),
'fenomenet': ('fenomen',),
'fenomenologi': ('fenomenologi',),
'fenomenologien': ('fenomenologi',),
'fenomenologiene': ('fenomenologi',),
'fenomenologier': ('fenomenologi',),
'fenotype': ('fenotype',),
'fenotypen': ('fenotype',),
'fenotypene': ('fenotype',),
'fenotyper': ('fenotype',),
'fenrik': ('fenrik',),
'fenriken': ('fenrik',),
'fenrikene': ('fenrik',),
'fenriker': ('fenrik',),
'ferd': ('ferd',),
'ferda': ('ferd',),
'ferden': ('ferd',),
'ferdene': ('ferd',),
'ferder': ('ferd',),
'ferdafolk': ('ferdafolk',),
'ferdafolka': ('ferdafolk',),
'ferdafolkene': ('ferdafolk',),
'ferdafolket': ('ferdafolk',),
'ferdafolk': ('ferdafolk',),
'ferdafolka': ('ferdafolk',),
'ferdafolkene': ('ferdafolk',),
'ferdafolket': ('ferdafolk',),
'ferdaskrin': ('ferdaskrin',),
'ferdaskrina': ('ferdaskrin',),
'ferdaskrinene': ('ferdaskrin',),
'ferdaskrinet': ('ferdaskrin',),
'ferdaskrin': ('ferdaskrin',),
'ferdaskrina': ('ferdaskrin',),
'ferdaskrinene': ('ferdaskrin',),
'ferdaskrinet': ('ferdaskrin',),
'ferde': ('ferde',),
'ferdefolk': ('ferdefolk',),
'ferdefolka': ('ferdefolk',),
'ferdefolkene': ('ferdefolk',),
'ferdefolket': ('ferdefolk',),
'ferdefolk': ('ferdefolk',),
'ferdefolka': ('ferdefolk',),
'ferdefolkene': ('ferdefolk',),
'ferdefolket': ('ferdefolk',),
'ferdeskrin': ('ferdeskrin',),
'ferdeskrina': ('ferdeskrin',),
'ferdeskrinene': ('ferdeskrin',),
'ferdeskrinet': ('ferdeskrin',),
'ferdeskrin': ('ferdeskrin',),
'ferdeskrina': ('ferdeskrin',),
'ferdeskrinene': ('ferdeskrin',),
'ferdeskrinet': ('ferdeskrin',),
'ferdigattest': ('ferdigattest',),
'ferdigattesten': ('ferdigattest',),
'ferdigattestene': ('ferdigattest',),
'ferdigattester': ('ferdigattest',),
'ferdigbetong': ('ferdigbetong',),
'ferdigbetongen': ('ferdigbetong',),
'ferdigbetongene': ('ferdigbetong',),
'ferdigbetonger': ('ferdigbetong',),
'ferdigdato': ('ferdigdato',),
'ferdigdatoen': ('ferdigdato',),
'ferdigdatoene': ('ferdigdato',),
'ferdigdatoer': ('ferdigdato',),
'ferdighet': ('ferdighet',),
'ferdigheta': ('ferdighet',),
'ferdigheten': ('ferdighet',),
'ferdighetene': ('ferdighet',),
'ferdigheter': ('ferdighet',),
'ferdighetsfag': ('ferdighetsfag',),
'ferdighetsfaga': ('ferdighetsfag',),
'ferdighetsfagene': ('ferdighetsfag',),
'ferdighetsfaget': ('ferdighetsfag',),
'ferdighus': ('ferdighus',),
'ferdighusa': ('ferdighus',),
'ferdighusene': ('ferdighus',),
'ferdighuset': ('ferdighus',),
'ferdigmat': ('ferdigmat',),
'ferdigmaten': ('ferdigmat',),
'ferdigmatene': ('ferdigmat',),
'ferdigmater': ('ferdigmat',),
'ferdigstilling': ('ferdigstilling',),
'ferdigstillinga': ('ferdigstilling',),
'ferdigstillingen': ('ferdigstilling',),
'ferdigstillingene': ('ferdigstilling',),
'ferdigstillinger': ('ferdigstilling',),
'ferdigvara': ('ferdigvare',),
'ferdigvare': ('ferdigvare',),
'ferdigvaren': ('ferdigvare',),
'ferdigvarene': ('ferdigvare',),
'ferdigvarer': ('ferdigvare',),
'ferdsel': ('ferdsel',),
'ferdselen': ('ferdsel',),
'ferdsla': ('ferdsel',),
'ferdslene': ('ferdsel',),
'ferdsler': ('ferdsel',),
'ferdselsveg': ('ferdselsveg',),
'ferdselsvegen': ('ferdselsveg',),
'ferdselsvegene': ('ferdselsveg',),
'ferdselsveger': ('ferdselsveg',),
'ferdselsvei': ('ferdselsvei',),
'ferdselsveien': ('ferdselsvei',),
'ferdselsveiene': ('ferdselsvei',),
'ferdselsveier': ('ferdselsvei',),
'ferdselsåra': ('ferdselsåre',),
'ferdselsåre': ('ferdselsåre',),
'ferdselsåren': ('ferdselsåre',),
'ferdselsårene': ('ferdselsåre',),
'ferdselsårer': ('ferdselsåre',),
'ferdskriver': ('ferdskriver',),
'ferdskrivere': ('ferdskriver',),
'ferdskriveren': ('ferdskriver',),
'ferdskriverer': ('ferdskriver',),
'ferdskriverne': ('ferdskriver',),
'ferdsla': ('ferdsle',),
'ferdsle': ('ferdsle',),
'ferdslen': ('ferdsle',),
'ferdslene': ('ferdsle',),
'ferdsler': ('ferdsle',),
'ferdsskriver': ('ferdsskriver',),
'ferdsskrivere': ('ferdsskriver',),
'ferdsskriveren': ('ferdsskriver',),
'ferdsskriverer': ('ferdsskriver',),
'ferdsskriverne': ('ferdsskriver',),
'ferga': ('ferge',),
'ferge': ('ferge',),
'fergen': ('ferge',),
'fergene': ('ferge',),
'ferger': ('ferge',),
'fergeforbindelse': ('fergeforbindelse',),
'fergeforbindelsen': ('fergeforbindelse',),
'fergeforbindelsene': ('fergeforbindelse',),
'fergeforbindelser': ('fergeforbindelse',),
'fergehamn': ('fergehamn',),
'fergehamna': ('fergehamn',),
'fergehamnen': ('fergehamn',),
'fergehamnene': ('fergehamn',),
'fergehamner': ('fergehamn',),
'fergehavn': ('fergehavn',),
'fergehavna': ('fergehavn',),
'fergehavnen': ('fergehavn',),
'fergehavnene': ('fergehavn',),
'fergehavner': ('fergehavn',),
'fergeleia': ('fergeleie',),
'fergeleie': ('fergeleie',),
'fergeleiene': ('fergeleie',),
'fergeleier': ('fergeleie',),
'fergeleiet': ('fergeleie',),
'fergemann': ('fergemann',),
'fergemannen': ('fergemann',),
'fergemenn': ('fergemann',),
'fergemennene': ('fergemann',),
'ferie': ('ferie',),
'ferien': ('ferie',),
'feriene': ('ferie',),
'ferier': ('ferie',),
'ferieavløser': ('ferieavløser',),
'ferieavløsere': ('ferieavløser',),
'ferieavløseren': ('ferieavløser',),
'ferieavløserer': ('ferieavløser',),
'ferieavløserne': ('ferieavløser',),
'feriegodtgjørelse': ('feriegodtgjørelse',),
'feriegodtgjørelsen': ('feriegodtgjørelse',),
'feriegodtgjørelsene': ('feriegodtgjørelse',),
'feriegodtgjørelser': ('feriegodtgjørelse',),
'feriegodtgjøring': ('feriegodtgjøring',),
'feriegodtgjøringa': ('feriegodtgjøring',),
'feriegodtgjøringen': ('feriegodtgjøring',),
'feriegodtgjøringene': ('feriegodtgjøring',),
'feriegodtgjøringer': ('feriegodtgjøring',),
'feriekoloni': ('feriekoloni',),
'feriekolonien': ('feriekoloni',),
'feriekoloniene': ('feriekoloni',),
'feriekolonier': ('feriekoloni',),
'ferielukning': ('ferielukning',),
'ferielukninga': ('ferielukning',),
'ferielukningen': ('ferielukning',),
'ferielukningene': ('ferielukning',),
'ferielukninger': ('ferielukning',),
'ferieopphold': ('ferieopphold',),
'ferieoppholda': ('ferieopphold',),
'ferieoppholdene': ('ferieopphold',),
'ferieoppholdet': ('ferieopphold',),
'feriepengene': ('feriepenger',),
'feriepenger': ('feriepenger',),
'feriereisa': ('feriereise',),
'feriereise': ('feriereise',),
'feriereisen': ('feriereise',),
'feriereisene': ('feriereise',),
'feriereiser': ('feriereise',),
'ferieskatt': ('ferieskatt',),
'ferieskatten': ('ferieskatt',),
'ferieskattene': ('ferieskatt',),
'ferieskatter': ('ferieskatt',),
'ferietur': ('ferietur',),
'ferieturen': ('ferietur',),
'ferieturene': ('ferietur',),
'ferieturer': ('ferietur',),
'ferievikar': ('ferievikar',),
'ferievikaren': ('ferievikar',),
'ferievikarene': ('ferievikar',),
'ferievikarer': ('ferievikar',),
'ferieår': ('ferieår',),
'ferieåra': ('ferieår',),
'ferieårene': ('ferieår',),
'ferieåret': ('ferieår',),
'ferist': ('ferist',),
'ferista': ('ferist',),
'feristen': ('ferist',),
'feristene': ('ferist',),
'ferister': ('ferist',),
'ferja': ('ferje',),
'ferje': ('ferje',),
'ferjen': ('ferje',),
'ferjene': ('ferje',),
'ferjer': ('ferje',),
'ferjeforbindelse': ('ferjeforbindelse',),
'ferjeforbindelsen': ('ferjeforbindelse',),
'ferjeforbindelsene': ('ferjeforbindelse',),
'ferjeforbindelser': ('ferjeforbindelse',),
'ferjehamn': ('ferjehamn',),
'ferjehamna': ('ferjehamn',),
'ferjehamnen': ('ferjehamn',),
'ferjehamnene': ('ferjehamn',),
'ferjehamner': ('ferjehamn',),
'ferjehavn': ('ferjehavn',),
'ferjehavna': ('ferjehavn',),
'ferjehavnen': ('ferjehavn',),
'ferjehavnene': ('ferjehavn',),
'ferjehavner': ('ferjehavn',),
'ferjeleia': ('ferjeleie',),
'ferjeleie': ('ferjeleie',),
'ferjeleiene': ('ferjeleie',),
'ferjeleier': ('ferjeleie',),
'ferjeleiet': ('ferjeleie',),
'ferjemann': ('ferjemann',),
'ferjemannen': ('ferjemann',),
'ferjemenn': ('ferjemann',),
'ferjemennene': ('ferjemann',),
'fermate': ('fermate',),
'fermateen': ('fermate',),
'fermateene': ('fermate',),
'fermateer': ('fermate',),
'ferment': ('ferment',),
'fermenta': ('ferment',),
'fermentene': ('ferment',),
'fermenter': ('ferment',),
'fermentet': ('ferment',),
'fermion': ('fermion',),
'fermiona': ('fermion',),
'fermionene': ('fermion',),
'fermioner': ('fermion',),
'fermionet': ('fermion',),
'fermium': ('fermium',),
'fermiuma': ('fermium',),
'fermiumene': ('fermium',),
'fermiumet': ('fermium',),
'ferniss': ('ferniss',),
'fernissen': ('ferniss',),
'fernissene': ('ferniss',),
'fernisser': ('ferniss',),
'feromon': ('feromon',),
'feromona': ('feromon',),
'feromonene': ('feromon',),
'feromoner': ('feromon',),
'feromonet': ('feromon',),
'ferrokrom': ('ferrokrom',),
'ferrokromma': ('ferrokrom',),
'ferrokrommene': ('ferrokrom',),
'ferrokrommet': ('ferrokrom',),
'ferrolegering': ('ferrolegering',),
'ferrolegeringa': ('ferrolegering',),
'ferrolegeringen': ('ferrolegering',),
'ferrolegeringene': ('ferrolegering',),
'ferrolegeringer': ('ferrolegering',),
'ferromangan': ('ferromangan',),
'ferromangana': ('ferromangan',),
'ferromanganene': ('ferromangan',),
'ferromanganet': ('ferromangan',),
'ferrosilisium': ('ferrosilisium',),
'ferrosilisiuma': ('ferrosilisium',),
'ferrosilisiumene': ('ferrosilisium',),
'ferrosilisiumet': ('ferrosilisium',),
'ferrotypi': ('ferrotypi',),
'ferrotypien': ('ferrotypi',),
'ferrotypiene': ('ferrotypi',),
'ferrotypier': ('ferrotypi',),
'ferskenhud': ('ferskenhud',),
'ferskenhuda': ('ferskenhud',),
'ferskenhuden': ('ferskenhud',),
'ferskenhudene': ('ferskenhud',),
'ferskenhuder': ('ferskenhud',),
'ferskentre': ('ferskentre',),
'ferskentrea': ('ferskentre',),
'ferskentreet': ('ferskentre',),
'ferskentrær': ('ferskentre',),
'ferskentrærne': ('ferskentre',),
'ferskfisk': ('ferskfisk',),
'ferskfisken': ('ferskfisk',),
'ferskfiskene': ('ferskfisk',),
'ferskfisker': ('ferskfisk',),
'ferskmat': ('ferskmat',),
'ferskmaten': ('ferskmat',),
'ferskmatene': ('ferskmat',),
'ferskmater': ('ferskmat',),
'ferskvann': ('ferskvann',),
'ferskvanna': ('ferskvann',),
'ferskvannene': ('ferskvann',),
'ferskvannet': ('ferskvann',),
'ferskvannsfisk': ('ferskvannsfisk',),
'ferskvannsfisken': ('ferskvannsfisk',),
'ferskvannsfiskene': ('ferskvannsfisk',),
'ferskvannsfisker': ('ferskvannsfisk',),
'ferskvannskreps': ('ferskvannskreps',),
'ferskvannskrepsen': ('ferskvannskreps',),
'ferskvannskrepsene': ('ferskvannskreps',),
'ferskvannskrepser': ('ferskvannskreps',),
'ferskvassfisk': ('ferskvassfisk',),
'ferskvassfisken': ('ferskvassfisk',),
'ferskvassfiskene': ('ferskvassfisk',),
'ferskvassfisker': ('ferskvassfisk',),
'ferskvasskreps': ('ferskvasskreps',),
'ferskvasskrepsen': ('ferskvasskreps',),
'ferskvasskrepsene': ('ferskvasskreps',),
'ferskvasskrepser': ('ferskvasskreps',),
'ferskvatn': ('ferskvatn',),
'ferskvatna': ('ferskvatn',),
'ferskvatnene': ('ferskvatn',),
'ferskvatnet': ('ferskvatn',),
'fert': ('fert',),
'ferten': ('fert',),
'fertene': ('fert',),
'ferter': ('fert',),
'fertilitet': ('fertilitet',),
'fertiliteten': ('fertilitet',),
'fertilitetene': ('fertilitet',),
'fertiliteter': ('fertilitet',),
'fertilitetsrate': ('fertilitetsrate',),
'fertilitetsraten': ('fertilitetsrate',),
'fertilitetsratene': ('fertilitetsrate',),
'fertilitetsrater': ('fertilitetsrate',),
'ferøkt': ('ferøkt',),
'ferøkta': ('ferøkt',),
'ferøkten': ('ferøkt',),
'ferøktene': ('ferøkt',),
'ferøkter': ('ferøkt',),
'fesjå': ('fesjå',),
'fesjåa': ('fesjå',),
'fesjåene': ('fesjå',),
'fesjået': ('fesjå',),
'fess': ('fess',),
'fessen': ('fess',),
'fessene': ('fess',),
'fesser': ('fess',),
'fess': ('fess',),
'fessen': ('fess',),
'fessene': ('fess',),
'fesser': ('fess',),
'fest': ('fest',),
'festen': ('fest',),
'festene': ('fest',),
'fester': ('fest',),
'festantrekk': ('festantrekk',),
'festantrekka': ('festantrekk',),
'festantrekkene': ('festantrekk',),
'festantrekket': ('festantrekk',),
'festblankett': ('festblankett',),
'festblanketten': ('festblankett',),
'festblankettene': ('festblankett',),
'festblanketter': ('festblankett',),
'festa': ('feste',),
'feste': ('feste',),
'festene': ('feste',),
'fester': ('feste',),
'festet': ('feste',),
'festebrev': ('festebrev',),
'festebreva': ('festebrev',),
'festebrevene': ('festebrev',),
'festebrever': ('festebrev',),
'festebrevet': ('festebrev',),
'festekontrakt': ('festekontrakt',),
'festekontrakten': ('festekontrakt',),
'festekontraktene': ('festekontrakt',),
'festekontrakter': ('festekontrakt',),
'festemøy': ('festemøy',),
'festemøya': ('festemøy',),
'festemøyen': ('festemøy',),
'festemøyene': ('festemøy',),
'festemøyer': ('festemøy',),
'festepunkt': ('festepunkt',),
'festepunkta': ('festepunkt',),
'festepunktene': ('festepunkt',),
'festepunkter': ('festepunkt',),
'festepunktet': ('festepunkt',),
'fester': ('fester',),
'festere': ('fester',),
'festeren': ('fester',),
'festerer': ('fester',),
'festerne': ('fester',),
'festesmurning': ('festesmurning',),
'festesmurninga': ('festesmurning',),
'festesmurningen': ('festesmurning',),
'festesmurningene': ('festesmurning',),
'festesmurninger': ('festesmurning',),
'festesmøring': ('festesmøring',),
'festesmøringa': ('festesmøring',),
'festesmøringen': ('festesmøring',),
'festesmøringene': ('festesmøring',),
'festesmøringer': ('festesmøring',),
'festetomt': ('festetomt',),
'festetomta': ('festetomt',),
'festetomten': ('festetomt',),
'festetomtene': ('festetomt',),
'festetomter': ('festetomt',),
'festforestilling': ('festforestilling',),
'festforestillinga': ('festforestilling',),
'festforestillingen': ('festforestilling',),
'festforestillingene': ('festforestilling',),
'festforestillinger': ('festforestilling',),
'festgudstjeneste': ('festgudstjeneste',),
'festgudstjenesten': ('festgudstjeneste',),
'festgudstjenestene': ('festgudstjeneste',),
'festgudstjenester': ('festgudstjeneste',),
'festival': ('festival',),
'festivalen': ('festival',),
'festivalene': ('festival',),
'festivaler': ('festival',),
'festivitas': ('festivitas',),
'festivitasen': ('festivitas',),
'festivitasene': ('festivitas',),
'festivitaser': ('festivitas',),
'festivitet': ('festivitet',),
'festiviteten': ('festivitet',),
'festivitetene': ('festivitet',),
'festiviteter': ('festivitet',),
'festmåltid': ('festmåltid',),
'festmåltida': ('festmåltid',),
'festmåltidene': ('festmåltid',),
'festmåltider': ('festmåltid',),
'festmåltidet': ('festmåltid',),
'festning': ('festning',),
'festninga': ('festning',),
'festningen': ('festning',),
'festningene': ('festning',),
'festninger': ('festning',),
'festningsgrav': ('festningsgrav',),
'festningsgrava': ('festningsgrav',),
'festningsgraven': ('festningsgrav',),
'festningsgravene': ('festningsgrav',),
'festningsgraver': ('festningsgrav',),
'festningsmur': ('festningsmur',),
'festningsmuren': ('festningsmur',),
'festningsmurene': ('festningsmur',),
'festningsmurer': ('festningsmur',),
'festningsverk': ('festningsverk',),
'festningsverka': ('festningsverk',),
'festningsverkene': ('festningsverk',),
'festningsverker': ('festningsverk',),
'festningsverket': ('festningsverk',),
'festningsvoll': ('festningsvoll',),
'festningsvollen': ('festningsvoll',),
'festningsvollene': ('festningsvoll',),
'festningsvoller': ('festningsvoll',),
'festrus': ('festrus',),
'festrusa': ('festrus',),
'festrusen': ('festrus',),
'festrusene': ('festrus',),
'festruser': ('festrus',),
'festruset': ('festrus',),
'festskrift': ('festskrift',),
'festskrifta': ('festskrift',),
'festskriftene': ('festskrift',),
'festskrifter': ('festskrift',),
'festskriftet': ('festskrift',),
'festspell': ('festspell',),
'festspella': ('festspell',),
'festspellene': ('festspell',),
'festspellet': ('festspell',),
'festspill': ('festspill',),
'festspilla': ('festspill',),
'festspillene': ('festspill',),
'festspillet': ('festspill',),
'feststemning': ('feststemning',),
'feststemninga': ('feststemning',),
'feststemningen': ('feststemning',),
'feststemningene': ('feststemning',),
'feststemninger': ('feststemning',),
'festtale': ('festtale',),
'festtalen': ('festtale',),
'festtalene': ('festtale',),
'festtaler': ('festtale',),
'festtelegram': ('festtelegram',),
'festtelegramma': ('festtelegram',),
'festtelegrammene': ('festtelegram',),
'festtelegrammer': ('festtelegram',),
'festtelegrammet': ('festtelegram',),
'fetedyr': ('fetedyr',),
'fetedyra': ('fetedyr',),
'fetedyrene': ('fetedyr',),
'fetedyret': ('fetedyr',),
'fetegris': ('fetegris',),
'fetegrisen': ('fetegris',),
'fetegrisene': ('fetegris',),
'fetegriser': ('fetegris',),
'fetetirsdag': ('fetetirsdag',),
'fetetirsdagen': ('fetetirsdag',),
'fetetirsdagene': ('fetetirsdag',),
'fetetirsdager': ('fetetirsdag',),
'fetevara': ('fetevare',),
'fetevare': ('fetevare',),
'fetevaren': ('fetevare',),
'fetevarene': ('fetevare',),
'fetevarer': ('fetevare',),
'fetisj': ('fetisj',),
'fetisjen': ('fetisj',),
'fetisjene': ('fetisj',),
'fetisjer': ('fetisj',),
'fetisjisme': ('fetisjisme',),
'fetisjismen': ('fetisjisme',),
'fetisjismene': ('fetisjisme',),
'fetisjismer': ('fetisjisme',),
'fetisjist': ('fetisjist',),
'fetisjisten': ('fetisjist',),
'fetisjistene': ('fetisjist',),
'fetisjister': ('fetisjist',),
'fetisjtilbeder': ('fetisjtilbeder',),
'fetisjtilbedere': ('fetisjtilbeder',),
'fetisjtilbederen': ('fetisjtilbeder',),
'fetisjtilbederer': ('fetisjtilbeder',),
'fetisjtilbederne': ('fetisjtilbeder',),
'fetost': ('fetost',),
'fetosten': ('fetost',),
'fetostene': ('fetost',),
'fetoster': ('fetost',),
'fetsild': ('fetsild',),
'fetsilda': ('fetsild',),
'fetsilden': ('fetsild',),
'fetsildene': ('fetsild',),
'fetsilder': ('fetsild',),
'fetsildfiska': ('fetsildfiske',),
'fetsildfiske': ('fetsildfiske',),
'fetsildfiskene': ('fetsildfiske',),
'fetsildfisker': ('fetsildfiske',),
'fetsildfisket': ('fetsildfiske',),
'fett': ('fett',),
'fetta': ('fett',),
'fettene': ('fett',),
'fettet': ('fett',),
'fettavleiring': ('fettavleiring',),
'fettavleiringa': ('fettavleiring',),
'fettavleiringen': ('fettavleiring',),
'fettavleiringene': ('fettavleiring',),
'fettavleiringer': ('fettavleiring',),
'fettcella': ('fettcelle',),
'fettcelle': ('fettcelle',),
'fettcellen': ('fettcelle',),
'fettcellene': ('fettcelle',),
'fettceller': ('fettcelle',),
'fettemulsjon': ('fettemulsjon',),
'fettemulsjonen': ('fettemulsjon',),
'fettemulsjonene': ('fettemulsjon',),
'fettemulsjoner': ('fettemulsjon',),
'fetter': ('fetter',),
'fettere': ('fetter',),
'fetteren': ('fetter',),
'fetterer': ('fetter',),
'fetterne': ('fetter',),
'fettflekk': ('fettflekk',),
'fettflekken': ('fettflekk',),
'fettflekkene': ('fettflekk',),
'fettflekker': ('fettflekk',),
'fettinnhold': ('fettinnhold',),
'fettinnholda': ('fettinnhold',),
'fettinnholdene': ('fettinnhold',),
'fettinnholdet': ('fettinnhold',),
'fettlær': ('fettlær',),
'fettlæra': ('fettlær',),
'fettlærene': ('fettlær',),
'fettlæret': ('fettlær',),
'fettlærsstøvel': ('fettlærsstøvel',),
'fettlærsstøvelen': ('fettlærsstøvel',),
'fettlærsstøvlene': ('fettlærsstøvel',),
'fettlærsstøvler': ('fettlærsstøvel',),
'fettrykk': ('fettrykk',),
'fettrykka': ('fettrykk',),
'fettrykken': ('fettrykk',),
'fettrykkene': ('fettrykk',),
'fettrykker': ('fettrykk',),
'fettrykket': ('fettrykk',),
'fettstift': ('fettstift',),
'fettstiften': ('fettstift',),
'fettstiftene': ('fettstift',),
'fettstifter': ('fettstift',),
'fettstoff': ('fettstoff',),
'fettstoffa': ('fettstoff',),
'fettstoffene': ('fettstoff',),
'fettstoffer': ('fettstoff',),
'fettstoffet': ('fettstoff',),
'fettsuging': ('fettsuging',),
'fettsuginga': ('fettsuging',),
'fettsugingen': ('fettsuging',),
'fettsugingene': ('fettsuging',),
'fettsuginger': ('fettsuging',),
'fettsvulst': ('fettsvulst',),
'fettsvulsten': ('fettsvulst',),
'fettsvulstene': ('fettsvulst',),
'fettsvulster': ('fettsvulst',),
'fettsyra': ('fettsyre',),
'fettsyre': ('fettsyre',),
'fettsyren': ('fettsyre',),
'fettsyrene': ('fettsyre',),
'fettsyrer': ('fettsyre',),
'fettvev': ('fettvev',),
'fettveva': ('fettvev',),
'fettvevene': ('fettvev',),
'fettvevet': ('fettvev',),
'fiasko': ('fiasko',),
'fiaskoen': ('fiasko',),
'fiaskoene': ('fiasko',),
'fiaskoer': ('fiasko',),
'fiber': ('fiber',),
'fibere': ('fiber',),
'fiberen': ('fiber',),
'fiberer': ('fiber',),
'fiberne': ('fiber',),
'fibre': ('fiber',),
'fibrene': ('fiber',),
'fibrer': ('fiber',),
'fiberglas': ('fiberglas',),
'fiberglasa': ('fiberglas',),
'fiberglasene': ('fiberglas',),
'fiberglaset': ('fiberglas',),
'fiberglass': ('fiberglass',),
'fiberglassa': ('fiberglass',),
'fiberglassene': ('fiberglass',),
'fiberglasset': ('fiberglass',),
'fiberoptikk': ('fiberoptikk',),
'fiberoptikken': ('fiberoptikk',),
'fiberoptikkene': ('fiberoptikk',),
'fiberoptikker': ('fiberoptikk',),
'fiberplata': ('fiberplate',),
'fiberplate': ('fiberplate',),
'fiberplaten': ('fiberplate',),
'fiberplatene': ('fiberplate',),
'fiberplater': ('fiberplate',),
'fibrose': ('fibrose',),
'fibrosen': ('fibrose',),
'fibrosene': ('fibrose',),
'fibroser': ('fibrose',),
'fideikomiss': ('fideikomiss',),
'fideikomissa': ('fideikomiss',),
'fideikomissene': ('fideikomiss',),
'fideikomisser': ('fideikomiss',),
'fideikomisset': ('fideikomiss',),
'fidibus': ('fidibus',),
'fidibusen': ('fidibus',),
'fidibusene': ('fidibus',),
'fidibuser': ('fidibus',),
'fidus': ('fidus',),
'fidusen': ('fidus',),
'fidusene': ('fidus',),
'fiduser': ('fidus',),
'fidusmaleri': ('fidusmaleri',),
'fidusmaleria': ('fidusmaleri',),
'fidusmaleriene': ('fidusmaleri',),
'fidusmalerier': ('fidusmaleri',),
'fidusmaleriet': ('fidusmaleri',),
'fiende': ('fiende',),
'fienden': ('fiende',),
'fiendene': ('fiende',),
'fiender': ('fiende',),
'fiendehær': ('fiendehær',),
'fiendehæren': ('fiendehær',),
'fiendehærene': ('fiendehær',),
'fiendehærer': ('fiendehær',),
'fiendeland': ('fiendeland',),
'fiendelanda': ('fiendeland',),
'fiendelandene': ('fiendeland',),
'fiendelandet': ('fiendeland',),
'fiendskap': ('fiendskap',),
'fiendskapa': ('fiendskap',),
'fiendskapen': ('fiendskap',),
'fiendskapene': ('fiendskap',),
'fiendskaper': ('fiendskap',),
'fiendskapet': ('fiendskap',),
'fiff': ('fiff',),
'fiffen': ('fiff',),
'fiffene': ('fiff',),
'fiffer': ('fiff',),
'fiff': ('fiff',),
'fiffa': ('fiff',),
'fiffene': ('fiff',),
'fiffet': ('fiff',),
'fight': ('fight',),
'fighten': ('fight',),
'fightene': ('fight',),
'fighter': ('fight',),
'fighter': ('fighter',),
'fightere': ('fighter',),
'fighteren': ('fighter',),
'fighterer': ('fighter',),
'fighterne': ('fighter',),
'fighting spirit': ('fighting spirit',),
'figur': ('figur',),
'figuren': ('figur',),
'figurene': ('figur',),
'figurer': ('figur',),
'figuralmusikk': ('figuralmusikk',),
'figuralmusikken': ('figuralmusikk',),
'figuralmusikkene': ('figuralmusikk',),
'figuralmusikker': ('figuralmusikk',),
'figurant': ('figurant',),
'figuranten': ('figurant',),
'figurantene': ('figurant',),
'figuranter': ('figurant',),
'figurasjon': ('figurasjon',),
'figurasjonen': ('figurasjon',),
'figurasjonene': ('figurasjon',),
'figurasjoner': ('figurasjon',),
'fijianer': ('fijianer',),
'fijianere': ('fijianer',),
'fijianeren': ('fijianer',),
'fijianerer': ('fijianer',),
'fijianerne': ('fijianer',),
'fik': ('fik',),
'fiken': ('fik',),
'fikene': ('fik',),
'fiker': ('fik',),
'fiken': ('fiken',),
'fikenen': ('fiken',),
'fikenene': ('fiken',),
'fikener': ('fiken',),
'fikenblad': ('fikenblad',),
'fikenblada': ('fikenblad',),
'fikenbladene': ('fikenblad',),
'fikenblader': ('fikenblad',),
'fikenbladet': ('fikenblad',),
'fikenvin': ('fikenvin',),
'fikenvinen': ('fikenvin',),
'fikenvinene': ('fikenvin',),
'fikenviner': ('fikenvin',),
'fikl': ('fikl',),
'fikla': ('fikl',),
'fiklene': ('fikl',),
'fiklet': ('fikl',),
'fiklearbeid': ('fiklearbeid',),
'fiklearbeida': ('fiklearbeid',),
'fiklearbeidene': ('fiklearbeid',),
'fiklearbeider': ('fiklearbeid',),
'fiklearbeidet': ('fiklearbeid',),
'fiksativ': ('fiksativ',),
'fiksativa': ('fiksativ',),
'fiksativene': ('fiksativ',),
'fiksativer': ('fiksativ',),
'fiksativet': ('fiksativ',),
'fikserbad': ('fikserbad',),
'fikserbada': ('fikserbad',),
'fikserbadene': ('fikserbad',),
'fikserbadet': ('fikserbad',),
'fikserbilda': ('fikserbilde',),
'fikserbilde': ('fikserbilde',),
'fikserbildene': ('fikserbilde',),
'fikserbilder': ('fikserbilde',),
'fikserbildet': ('fikserbilde',),
'fiksersalt': ('fiksersalt',),
'fiksersalta': ('fiksersalt',),
'fiksersaltene': ('fiksersalt',),
'fiksersalter': ('fiksersalt',),
'fiksersaltet': ('fiksersalt',),
'fikservæska': ('fikservæske',),
'fikservæske': ('fikservæske',),
'fikservæsken': ('fikservæske',),
'fikservæskene': ('fikservæske',),
'fikservæsker': ('fikservæske',),
'fiksfakseri': ('fiksfakseri',),
'fiksfakseria': ('fiksfakseri',),
'fiksfakseriene': ('fiksfakseri',),
'fiksfakserier': ('fiksfakseri',),
'fiksfakseriet': ('fiksfakseri',),
'fiksjon': ('fiksjon',),
'fiksjonen': ('fiksjon',),
'fiksjonene': ('fiksjon',),
'fiksjoner': ('fiksjon',),
'fiksjonsdikting': ('fiksjonsdikting',),
'fiksjonsdiktinga': ('fiksjonsdikting',),
'fiksjonsdiktingen': ('fiksjonsdikting',),
'fiksjonsdiktingene': ('fiksjonsdikting',),
'fiksjonsdiktinger': ('fiksjonsdikting',),
'fiksjonsdiktning': ('fiksjonsdiktning',),
'fiksjonsdiktninga': ('fiksjonsdiktning',),
'fiksjonsdiktningen': ('fiksjonsdiktning',),
'fiksjonsdiktningene': ('fiksjonsdiktning',),
'fiksjonsdiktninger': ('fiksjonsdiktning',),
'fiksjonsprosa': ('fiksjonsprosa',),
'fiksjonsprosaen': ('fiksjonsprosa',),
'fiksjonsprosaene': ('fiksjonsprosa',),
'fiksjonsprosaer': ('fiksjonsprosa',),
'fikspunkt': ('fikspunkt',),
'fikspunkta': ('fikspunkt',),
'fikspunktene': ('fikspunkt',),
'fikspunkter': ('fikspunkt',),
'fikspunktet': ('fikspunkt',),
'fiksstjerna': ('fiksstjerne',),
'fiksstjerne': ('fiksstjerne',),
'fiksstjernen': ('fiksstjerne',),
'fiksstjernene': ('fiksstjerne',),
'fiksstjerner': ('fiksstjerne',),
'fil': ('fil',),
'filen': ('fil',),
'filene': ('fil',),
'filer': ('fil',),
'fil': ('fil',),
'fila': ('fil',),
'filen': ('fil',),
'filene': ('fil',),
'filer': ('fil',),
'filantrop': ('filantrop',),
'filantropen': ('filantrop',),
'filantropene': ('filantrop',),
'filantroper': ('filantrop',),
'filantropi': ('filantropi',),
'filantropien': ('filantropi',),
'filantropiene': ('filantropi',),
'filantropier': ('filantropi',),
'filateli': ('filateli',),
'filatelien': ('filateli',),
'filateliene': ('filateli',),
'filatelier': ('filateli',),
'filatelist': ('filatelist',),
'filatelisten': ('filatelist',),
'filatelistene': ('filatelist',),
'filatelister': ('filatelist',),
'filbehandling': ('filbehandling',),
'filbehandlinga': ('filbehandling',),
'filbehandlingen': ('filbehandling',),
'filbehandlingene': ('filbehandling',),
'filbehandlinger': ('filbehandling',),
'filet': ('filet',),
'fileten': ('filet',),
'filetene': ('filet',),
'fileter': ('filet',),
'filet': ('filet',),
'fileta': ('filet',),
'filetene': ('filet',),
'fileter': ('filet',),
'filetet': ('filet',),
'filett': ('filett',),
'filetten': ('filett',),
'filettene': ('filett',),
'filetter': ('filett',),
'filharmoniker': ('filharmoniker',),
'filharmonikere': ('filharmoniker',),
'filharmonikeren': ('filharmoniker',),
'filharmonikerer': ('filharmoniker',),
'filharmonikerne': ('filharmoniker',),
'filial': ('filial',),
'filialen': ('filial',),
'filialene': ('filial',),
'filialer': ('filial',),
'filibuster': ('filibuster',),
'filibustere': ('filibuster',),
'filibusteren': ('filibuster',),
'filibusterer': ('filibuster',),
'filibusterne': ('filibuster',),
'filibusterdebatt': ('filibusterdebatt',),
'filibusterdebatten': ('filibusterdebatt',),
'filibusterdebattene': ('filibusterdebatt',),
'filibusterdebatter': ('filibusterdebatt',),
'filibustertaktikk': ('filibustertaktikk',),
'filibustertaktikken': ('filibustertaktikk',),
'filibustertaktikkene': ('filibustertaktikk',),
'filibustertaktikker': ('filibustertaktikk',),
'filigran': ('filigran',),
'filigrana': ('filigran',),
'filigranene': ('filigran',),
'filigraner': ('filigran',),
'filigranet': ('filigran',),
'filigransarbeid': ('filigransarbeid',),
'filigransarbeida': ('filigransarbeid',),
'filigransarbeidene': ('filigransarbeid',),
'filigransarbeider': ('filigransarbeid',),
'filigransarbeidet': ('filigransarbeid',),
'filipens': ('filipens',),
'filipensen': ('filipens',),
'filipensene': ('filipens',),
'filipenser': ('filipens',),
'filipine': ('filipine',),
'filipinen': ('filipine',),
'filipinene': ('filipine',),
'filipiner': ('filipine',),
'filippiner': ('filippiner',),
'filippinere': ('filippiner',),
'filippineren': ('filippiner',),
'filippinerer': ('filippiner',),
'filippinerne': ('filippiner',),
'filister': ('filister',),
'filistere': ('filister',),
'filisteren': ('filister',),
'filisterer': ('filister',),
'filisterne': ('filister',),
'filistre': ('filister',),
'filistrene': ('filister',),
'filistrer': ('filister',),
'filisteri': ('filisteri',),
'filisteria': ('filisteri',),
'filisteriene': ('filisteri',),
'filisterier': ('filisteri',),
'filisteriet': ('filisteri',),
'filla': ('fille',),
'fille': ('fille',),
'fillen': ('fille',),
'fillene': ('fille',),
'filler': ('fille',),
'fillebikkja': ('fillebikkje',),
'fillebikkje': ('fillebikkje',),
'fillebikkjen': ('fillebikkje',),
'fillebikkjene': ('fillebikkje',),
'fillebikkjer': ('fillebikkje',),
'filledokka': ('filledokke',),
'filledokke': ('filledokke',),
'filledokken': ('filledokke',),
'filledokkene': ('filledokke',),
'filledokker': ('filledokke',),
'filledukka': ('filledukke',),
'filledukke': ('filledukke',),
'filledukken': ('filledukke',),
'filledukkene': ('filledukke',),
'filledukker': ('filledukke',),
'fillefant': ('fillefant',),
'fillefanten': ('fillefant',),
'fillefantene': ('fillefant',),
'fillefanter': ('fillefant',),
'filleonkel': ('filleonkel',),
'filleonkelen': ('filleonkel',),
'filleonklene': ('filleonkel',),
'filleonkler': ('filleonkel',),
'filleproletariat': ('filleproletariat',),
'filleproletariata': ('filleproletariat',),
'filleproletariatene': ('filleproletariat',),
'filleproletariater': ('filleproletariat',),
'filleproletariatet': ('filleproletariat',),
'filler': ('filler',),
'filleren': ('filler',),
'fillerene': ('filler',),
'filleri': ('filleri',),
'filleria': ('filleri',),
'filleriene': ('filleri',),
'fillerier': ('filleri',),
'filleriet': ('filleri',),
'fillerya': ('fillerye',),
'fillerye': ('fillerye',),
'filleryen': ('fillerye',),
'filleryene': ('fillerye',),
'filleryer': ('fillerye',),
'fillesak': ('fillesak',),
'fillesaka': ('fillesak',),
'fillesaken': ('fillesak',),
'fillesakene': ('fillesak',),
'fillesaker': ('fillesak',),
'filletanta': ('filletante',),
'filletante': ('filletante',),
'filletanten': ('filletante',),
'filletantene': ('filletante',),
'filletanter': ('filletante',),
'filleting': ('filleting',),
'filletinga': ('filleting',),
'filletingen': ('filleting',),
'filletingene': ('filleting',),
'film': ('film',),
'filmen': ('film',),
'filmene': ('film',),
'filmer': ('film',),
'filmarkiv': ('filmarkiv',),
'filmarkiva': ('filmarkiv',),
'filmarkivene': ('filmarkiv',),
'filmarkiver': ('filmarkiv',),
'filmarkivet': ('filmarkiv',),
'filmatelier': ('filmatelier',),
'filmateliera': ('filmatelier',),
'filmatelierene': ('filmatelier',),
'filmatelierer': ('filmatelier',),
'filmatelieret': ('filmatelier',),
'filmbyrå': ('filmbyrå',),
'filmbyråa': ('filmbyrå',),
'filmbyråene': ('filmbyrå',),
'filmbyråer': ('filmbyrå',),
'filmbyrået': ('filmbyrå',),
'filmforestilling': ('filmforestilling',),
'filmforestillinga': ('filmforestilling',),
'filmforestillingen': ('filmforestilling',),
'filmforestillingene': ('filmforestilling',),
'filmforestillinger': ('filmforestilling',),
'filmfotograf': ('filmfotograf',),
'filmfotografen': ('filmfotograf',),
'filmfotografene': ('filmfotograf',),
'filmfotografer': ('filmfotograf',),
'filmhastighet': ('filmhastighet',),
'filmhastigheta': ('filmhastighet',),
'filmhastigheten': ('filmhastighet',),
'filmhastighetene': ('filmhastighet',),
'filmhastigheter': ('filmhastighet',),
'filmhelt': ('filmhelt',),
'filmhelten': ('filmhelt',),
'filmheltene': ('filmhelt',),
'filmhelter': ('filmhelt',),
'filmidol': ('filmidol',),
'filmidola': ('filmidol',),
'filmidolene': ('filmidol',),
'filmidoler': ('filmidol',),
'filmidolet': ('filmidol',),
'filmindustri': ('filmindustri',),
'filmindustrien': ('filmindustri',),
'filmindustriene': ('filmindustri',),
'filmindustrier': ('filmindustri',),
'filmkassett': ('filmkassett',),
'filmkassetten': ('filmkassett',),
'filmkassettene': ('filmkassett',),
'filmkassetter': ('filmkassett',),
'filmkontroll': ('filmkontroll',),
'filmkontrollen': ('filmkontroll',),
'filmkontrollene': ('filmkontroll',),
'filmkontroller': ('filmkontroll',),
'filmmusikk': ('filmmusikk',),
'filmmusikken': ('filmmusikk',),
'filmmusikkene': ('filmmusikk',),
'filmmusikker': ('filmmusikk',),
'filmstjerna': ('filmstjerne',),
'filmstjerne': ('filmstjerne',),
'filmstjernen': ('filmstjerne',),
'filmstjernene': ('filmstjerne',),
'filmstjerner': ('filmstjerne',),
'filmstripp': ('filmstripp',),
'filmstrippen': ('filmstripp',),
'filmstrippene': ('filmstripp',),
'filmstripper': ('filmstripp',),
'filmteam': ('filmteam',),
'filmteama': ('filmteam',),
'filmteamene': ('filmteam',),
'filmteamet': ('filmteam',),
'filolog': ('filolog',),
'filologen': ('filolog',),
'filologene': ('filolog',),
'filologer': ('filolog',),
'filologi': ('filologi',),
'filologien': ('filologi',),
'filologiene': ('filologi',),
'filologier': ('filologi',),
'filosof': ('filosof',),
'filosofen': ('filosof',),
'filosofene': ('filosof',),
'filosofer': ('filosof',),
'filosofi': ('filosofi',),
'filosofien': ('filosofi',),
'filosofiene': ('filosofi',),
'filosofier': ('filosofi',),
'filosofikum': ('filosofikum',),
'filosofikumen': ('filosofikum',),
'filosofikumene': ('filosofikum',),
'filosofikumer': ('filosofikum',),
'filspon': ('filspon',),
'filsponen': ('filspon',),
'filsponene': ('filspon',),
'filsponer': ('filspon',),
'filt': ('filt',),
'filten': ('filt',),
'filtene': ('filt',),
'filter': ('filt',),
'filter': ('filter',),
'filteret': ('filter',),
'filtra': ('filter',),
'filtre': ('filter',),
'filtrene': ('filter',),
'filtret': ('filter',),
'filterkaffe': ('filterkaffe',),
'filterkaffen': ('filterkaffe',),
'filterkaffene': ('filterkaffe',),
'filterkaffer': ('filterkaffe',),
'filtersigarett': ('filtersigarett',),
'filtersigaretten': ('filtersigarett',),
'filtersigarettene': ('filtersigarett',),
'filtersigaretter': ('filtersigarett',),
'filthatt': ('filthatt',),
'filthatten': ('filthatt',),
'filthattene': ('filthatt',),
'filthatter': ('filthatt',),
'filtrat': ('filtrat',),
'filtrata': ('filtrat',),
'filtratene': ('filtrat',),
'filtrater': ('filtrat',),
'filtratet': ('filtrat',),
'filtrerapparat': ('filtrerapparat',),
'filtrerapparata': ('filtrerapparat',),
'filtrerapparatene': ('filtrerapparat',),
'filtrerapparater': ('filtrerapparat',),
'filtrerapparatet': ('filtrerapparat',),
'filtrerpapir': ('filtrerpapir',),
'filtrerpapira': ('filtrerpapir',),
'filtrerpapirene': ('filtrerpapir',),
'filtrerpapirer': ('filtrerpapir',),
'filtrerpapiret': ('filtrerpapir',),
'filtsko': ('filtsko',),
'filtskoa': ('filtsko',),
'filtskoen': ('filtsko',),
'filtskoene': ('filtsko',),
'filtskor': ('filtsko',),
'filtskorne': ('filtsko',),
'filttøffel': ('filttøffel',),
'filttøffelen': ('filttøffel',),
'filttøflene': ('filttøffel',),
'filttøfler': ('filttøffel',),
'filur': ('filur',),
'filuren': ('filur',),
'filurene': ('filur',),
'filurer': ('filur',),
'filureri': ('filureri',),
'filureria': ('filureri',),
'filureriene': ('filureri',),
'filurerier': ('filureri',),
'filureriet': ('filureri',),
'fimbulvinter': ('fimbulvinter',),
'fimbulvintere': ('fimbulvinter',),
'fimbulvinteren': ('fimbulvinter',),
'fimbulvinterne': ('fimbulvinter',),
'fimbulvintre': ('fimbulvinter',),
'fimbulvintrene': ('fimbulvinter',),
'fimbulvintrer': ('fimbulvinter',),
'fin de siècle': ('fin de siècle',),
'finale': ('finale',),
'finalen': ('finale',),
'finalene': ('finale',),
'finaler': ('finale',),
'finaleheat': ('finaleheat',),
'finaleheata': ('finaleheat',),
'finaleheatene': ('finaleheat',),
'finaleheatet': ('finaleheat',),
'finalekamp': ('finalekamp',),
'finalekampen': ('finalekamp',),
'finalekampene': ('finalekamp',),
'finalekamper': ('finalekamp',),
'finalist': ('finalist',),
'finalisten': ('finalist',),
'finalistene': ('finalist',),
'finalister': ('finalist',),
'finans': ('finans',),
'finansen': ('finans',),
'finansene': ('finans',),
'finanser': ('finans',),
'finansbudsjett': ('finansbudsjett',),
'finansbudsjetta': ('finansbudsjett',),
'finansbudsjettene': ('finansbudsjett',),
'finansbudsjetter': ('finansbudsjett',),
'finansbudsjettet': ('finansbudsjett',),
'finansdebatt': ('finansdebatt',),
'finansdebatten': ('finansdebatt',),
'finansdebattene': ('finansdebatt',),
'finansdebatter': ('finansdebatt',),
'finansdepartement': ('finansdepartement',),
'finansdepartementa': ('finansdepartement',),
'finansdepartementene': ('finansdepartement',),
'finansdepartementer': ('finansdepartement',),
'finansdepartementet': ('finansdepartement',),
'finansiering': ('finansiering',),
'finansieringa': ('finansiering',),
'finansieringen': ('finansiering',),
'finansieringene': ('finansiering',),
'finansieringer': ('finansiering',),
'finansieringsanalysa': ('finansieringsanalyse',),
'finansieringsanalyse': ('finansieringsanalyse',),
'finansieringsanalysen': ('finansieringsanalyse',),
'finansieringsanalysene': ('finansieringsanalyse',),
'finansieringsanalyser': ('finansieringsanalyse',),
'finansieringsplan': ('finansieringsplan',),
'finansieringsplanen': ('finansieringsplan',),
'finansieringsplanene': ('finansieringsplan',),
'finansieringsplaner': ('finansieringsplan',),
'finansminister': ('finansminister',),
'finansministere': ('finansminister',),
'finansministeren': ('finansminister',),
'finansministerer': ('finansminister',),
'finansministerne': ('finansminister',),
'finansministre': ('finansminister',),
'finansministrene': ('finansminister',),
'finansministrer': ('finansminister',),
'finanspolitikk': ('finanspolitikk',),
'finanspolitikken': ('finanspolitikk',),
'finanspolitikkene': ('finanspolitikk',),
'finanspolitikker': ('finanspolitikk',),
'finansråd': ('finansråd',),
'finansråden': ('finansråd',),
'finansrådene': ('finansråd',),
'finansråder': ('finansråd',),
'finansrådmann': ('finansrådmann',),
'finansrådmannen': ('finansrådmann',),
'finansrådmenn': ('finansrådmann',),
'finansrådmennene': ('finansrådmann',),
'finbrød': ('finbrød',),
'finbrøda': ('finbrød',),
'finbrødene': ('finbrød',),
'finbrødet': ('finbrød',),
'finer': ('finer',),
'fineren': ('finer',),
'finerene': ('finer',),
'finerer': ('finer',),
'finerplata': ('finerplate',),
'finerplate': ('finerplate',),
'finerplaten': ('finerplate',),
'finerplatene': ('finerplate',),
'finerplater': ('finerplate',),
'finersag': ('finersag',),
'finersaga': ('finersag',),
'finersagen': ('finersag',),
'finersagene': ('finersag',),
'finersager': ('finersag',),
'finesse': ('finesse',),
'finessen': ('finesse',),
'finessene': ('finesse',),
'finesser': ('finesse',),
'finfølelse': ('finfølelse',),
'finfølelsen': ('finfølelse',),
'finfølelsene': ('finfølelse',),
'finfølelser': ('finfølelse',),
'finger': ('finger',),
'fingeren': ('finger',),
'fingre': ('finger',),
'fingrene': ('finger',),
'fingrer': ('finger',),
'fingeravtrykk': ('fingeravtrykk',),
'fingeravtrykka': ('fingeravtrykk',),
'fingeravtrykkene': ('fingeravtrykk',),
'fingeravtrykket': ('fingeravtrykk',),
'fingerbøl': ('fingerbøl',),
'fingerbøla': ('fingerbøl',),
'fingerbølene': ('fingerbøl',),
'fingerbølet': ('fingerbøl',),
'fingerbør': ('fingerbør',),
'fingerbøra': ('fingerbør',),
'fingerbørene': ('fingerbør',),
'fingerbøret': ('fingerbør',),
'fingerferdighet': ('fingerferdighet',),
'fingerferdigheta': ('fingerferdighet',),
'fingerferdigheten': ('fingerferdighet',),
'fingerferdighetene': ('fingerferdighet',),
'fingerferdigheter': ('fingerferdighet',),
'fingergrep': ('fingergrep',),
'fingergrepa': ('fingergrep',),
'fingergrepene': ('fingergrep',),
'fingergrepet': ('fingergrep',),
'fingerkyss': ('fingerkyss',),
'fingerkyssa': ('fingerkyss',),
'fingerkyssen': ('fingerkyss',),
'fingerkyssene': ('fingerkyss',),
'fingerkysset': ('fingerkyss',),
'fingermaling': ('fingermaling',),
'fingermalinga': ('fingermaling',),
'fingermalingen': ('fingermaling',),
'fingermalingene': ('fingermaling',),
'fingermalinger': ('fingermaling',),
'fingerpek': ('fingerpek',),
'fingerpeka': ('fingerpek',),
'fingerpekene': ('fingerpek',),
'fingerpeket': ('fingerpek',),
'fingersetning': ('fingersetning',),
'fingersetninga': ('fingersetning',),
'fingersetningen': ('fingersetning',),
'fingersetningene': ('fingersetning',),
'fingersetninger': ('fingersetning',),
'fingerspiss': ('fingerspiss',),
'fingerspissen': ('fingerspiss',),
'fingerspissene': ('fingerspiss',),
'fingerspisser': ('fingerspiss',),
'fingerspråk': ('fingerspråk',),
'fingerspråka': ('fingerspråk',),
'fingerspråkene': ('fingerspråk',),
'fingerspråket': ('fingerspråk',),
'fingertupp': ('fingertupp',),
'fingertuppen': ('fingertupp',),
'fingertuppene': ('fingertupp',),
'fingertupper': ('fingertupp',),
'fingervante': ('fingervante',),
'fingervanten': ('fingervante',),
'fingervantene': ('fingervante',),
'fingervanter': ('fingervante',),
'fingervott': ('fingervott',),
'fingervotten': ('fingervott',),
'fingervottene': ('fingervott',),
'fingervotter': ('fingervott',),
'finhet': ('finhet',),
'finheta': ('finhet',),
'finheten': ('finhet',),
'finhetene': ('finhet',),
'finheter': ('finhet',),
'finis': ('finis',),
'finisen': ('finis',),
'finisene': ('finis',),
'finiser': ('finis',),
'finish': ('finish',),
'finishen': ('finish',),
'finishene': ('finish',),
'finisher': ('finish',),
'finitt': ('finitt',),
'finitta': ('finitt',),
'finittene': ('finitt',),
'finitter': ('finitt',),
'finittet': ('finitt',),
'fink': ('fink',),
'finken': ('fink',),
'finkene': ('fink',),
'finker': ('fink',),
'finke': ('finke',),
'finken': ('finke',),
'finkene': ('finke',),
'finker': ('finke',),
'finkefamilie': ('finkefamilie',),
'finkefamilien': ('finkefamilie',),
'finkefamiliene': ('finkefamilie',),
'finkefamilier': ('finkefamilie',),
'finklær': ('finklær',),
'finklærne': ('finklær',),
'finkultur': ('finkultur',),
'finkulturen': ('finkultur',),
'finkulturene': ('finkultur',),
'finkulturer': ('finkultur',),
'finlandssvensk': ('finlandssvensk',),
'finlandssvensken': ('finlandssvensk',),
'finlandssvenskene': ('finlandssvensk',),
'finlandssvensker': ('finlandssvensk',),
'finlandssvenske': ('finlandssvenske',),
'finlandssvensken': ('finlandssvenske',),
'finlandssvenskene': ('finlandssvenske',),
'finlandssvensker': ('finlandssvenske',),
'finlender': ('finlender',),
'finlendere': ('finlender',),
'finlenderen': ('finlender',),
'finlenderer': ('finlender',),
'finlenderne': ('finlender',),
'finlending': ('finlending',),
'finlendingen': ('finlending',),
'finlendingene': ('finlending',),
'finlendinger': ('finlending',),
'finmekaniker': ('finmekaniker',),
'finmekanikere': ('finmekaniker',),
'finmekanikeren': ('finmekaniker',),
'finmekanikerer': ('finmekaniker',),
'finmekanikerne': ('finmekaniker',),
'finmekanikk': ('finmekanikk',),
'finmekanikken': ('finmekanikk',),
'finmekanikkene': ('finmekanikk',),
'finmekanikker': ('finmekanikk',),
'finmel': ('finmel',),
'finmela': ('finmel',),
'finmelene': ('finmel',),
'finmelet': ('finmel',),
'finmjøl': ('finmjøl',),
'finmjøla': ('finmjøl',),
'finmjølene': ('finmjøl',),
'finmjølet': ('finmjøl',),
'finn': ('finn',),
'finnen': ('finn',),
'finnene': ('finn',),
'finner': ('finn',),
'finne': ('finne',),
'finnen': ('finne',),
'finnene': ('finne',),
'finner': ('finne',),
'finne': ('finne',),
'finnen': ('finne',),
'finnene': ('finne',),
'finner': ('finne',),
'finna': ('finne',),
'finne': ('finne',),
'finnen': ('finne',),
'finnene': ('finne',),
'finner': ('finne',),
'finneferd': ('finneferd',),
'finneferda': ('finneferd',),
'finneferden': ('finneferd',),
'finneferdene': ('finneferd',),
'finneferder': ('finneferd',),
'finnegand': ('finnegand',),
'finneganden': ('finnegand',),
'finnegandene': ('finnegand',),
'finnegander': ('finnegand',),
'finnelønn': ('finnelønn',),
'finnelønna': ('finnelønn',),
'finnelønnen': ('finnelønn',),
'finnelønnene': ('finnelønn',),
'finnelønner': ('finnelønn',),
'finner': ('finner',),
'finnere': ('finner',),
'finneren': ('finner',),
'finnerer': ('finner',),
'finnerne': ('finner',),
'finnerlønn': ('finnerlønn',),
'finnerlønna': ('finnerlønn',),
'finnerlønnen': ('finnerlønn',),
'finnerlønnene': ('finnerlønn',),
'finnerlønner': ('finnerlønn',),
'finnferd': ('finnferd',),
'finnferda': ('finnferd',),
'finnferden': ('finnferd',),
'finnferdene': ('finnferd',),
'finnferder': ('finnferd',),
'finngand': ('finngand',),
'finnganden': ('finngand',),
'finngandene': ('finngand',),
'finngander': ('finngand',),
'finnhval': ('finnhval',),
'finnhvalen': ('finnhval',),
'finnhvalene': ('finnhval',),
'finnhvaler': ('finnhval',),
'finnjolla': ('finnjolle',),
'finnjolle': ('finnjolle',),
'finnjollen': ('finnjolle',),
'finnjollene': ('finnjolle',),
'finnjoller': ('finnjolle',),
'finnkval': ('finnkval',),
'finnkvalen': ('finnkval',),
'finnkvalene': ('finnkval',),
'finnkvaler': ('finnkval',),
'finnmarking': ('finnmarking',),
'finnmarkingen': ('finnmarking',),
'finnmarkingene': ('finnmarking',),
'finnmarkinger': ('finnmarking',),
'finnmarksfiska': ('finnmarksfiske',),
'finnmarksfiske': ('finnmarksfiske',),
'finnmarksfiskene': ('finnmarksfiske',),
'finnmarksfisker': ('finnmarksfiske',),
'finnmarksfisket': ('finnmarksfiske',),
'finnmarkshua': ('finnmarkshue',),
'finnmarkshue': ('finnmarkshue',),
'finnmarkshuen': ('finnmarkshue',),
'finnmarkshuene': ('finnmarkshue',),
'finnmarkshuer': ('finnmarkshue',),
'finnmarkshuva': ('finnmarkshuve',),
'finnmarkshuve': ('finnmarkshuve',),
'finnmarkshuven': ('finnmarkshuve',),
'finnmarkshuvene': ('finnmarkshuve',),
'finnmarkshuver': ('finnmarkshuve',),
'finnmarkslua': ('finnmarkslue',),
'finnmarkslue': ('finnmarkslue',),
'finnmarksluen': ('finnmarkslue',),
'finnmarksluene': ('finnmarkslue',),
'finnmarksluer': ('finnmarkslue',),
'finnmarksluva': ('finnmarksluve',),
'finnmarksluve': ('finnmarksluve',),
'finnmarksluven': ('finnmarksluve',),
'finnmarksluvene': ('finnmarksluve',),
'finnmarksluver': ('finnmarksluve',),
'finnmarkspors': ('finnmarkspors',),
'finnmarksporsen': ('finnmarkspors',),
'finnmarksporsene': ('finnmarkspors',),
'finnmarksporser': ('finnmarkspors',),
'finnmudd': ('finnmudd',),
'finnmudden': ('finnmudd',),
'finnmuddene': ('finnmudd',),
'finnmudder': ('finnmudd',),
'finnmutt': ('finnmutt',),
'finnmutten': ('finnmutt',),
'finnmuttene': ('finnmutt',),
'finnmutter': ('finnmutt',),
'finnskjegg': ('finnskjegg',),
'finnskjegga': ('finnskjegg',),
'finnskjeggen': ('finnskjegg',),
'finnskjeggene': ('finnskjegg',),
'finnskjegger': ('finnskjegg',),
'finnskjegget': ('finnskjegg',),
'finntopp': ('finntopp',),
'finntoppen': ('finntopp',),
'finntoppene': ('finntopp',),
'finntopper': ('finntopp',),
'finpapir': ('finpapir',),
'finpapira': ('finpapir',),
'finpapirene': ('finpapir',),
'finpapirer': ('finpapir',),
'finpapiret': ('finpapir',),
'finpuss': ('finpuss',),
'finpussen': ('finpuss',),
'finpussene': ('finpuss',),
'finpusser': ('finpuss',),
'finsk': ('finsk',),
'finsken': ('finsk',),
'finskene': ('finsk',),
'finsker': ('finsk',),
'finsmed': ('finsmed',),
'finsmeden': ('finsmed',),
'finsmedene': ('finsmed',),
'finsmeder': ('finsmed',),
'finsteinhogger': ('finsteinhogger',),
'finsteinhoggere': ('finsteinhogger',),
'finsteinhoggeren': ('finsteinhogger',),
'finsteinhoggerer': ('finsteinhogger',),
'finsteinhoggerne': ('finsteinhogger',),
'finsteinhugger': ('finsteinhugger',),
'finsteinhuggere': ('finsteinhugger',),
'finsteinhuggeren': ('finsteinhugger',),
'finsteinhuggerer': ('finsteinhugger',),
'finsteinhuggerne': ('finsteinhugger',),
'finta': ('finte',),
'finte': ('finte',),
'finten': ('finte',),
'fintene': ('finte',),
'finter': ('finte',),
'finvask': ('finvask',),
'finvasken': ('finvask',),
'finvaskene': ('finvask',),
'finvasker': ('finvask',),
'fiol': ('fiol',),
'fiolen': ('fiol',),
'fiolene': ('fiol',),
'fioler': ('fiol',),
'fiolfamilie': ('fiolfamilie',),
'fiolfamilien': ('fiolfamilie',),
'fiolfamiliene': ('fiolfamilie',),
'fiolfamilier': ('fiolfamilie',),
'fiolin': ('fiolin',),
'fiolinen': ('fiolin',),
'fiolinene': ('fiolin',),
'fioliner': ('fiolin',),
'fiolinboge': ('fiolinboge',),
'fiolinbogen': ('fiolinboge',),
'fiolinbogene': ('fiolinboge',),
'fiolinboger': ('fiolinboge',),
'fiolinbue': ('fiolinbue',),
'fiolinbuen': ('fiolinbue',),
'fiolinbuene': ('fiolinbue',),
'fiolinbuer': ('fiolinbue',),
'fiolinist': ('fiolinist',),
'fiolinisten': ('fiolinist',),
'fiolinistene': ('fiolinist',),
'fiolinister': ('fiolinist',),
'fiolinkonsert': ('fiolinkonsert',),
'fiolinkonserten': ('fiolinkonsert',),
'fiolinkonsertene': ('fiolinkonsert',),
'fiolinkonserter': ('fiolinkonsert',),
'fiolinspell': ('fiolinspell',),
'fiolinspella': ('fiolinspell',),
'fiolinspellene': ('fiolinspell',),
'fiolinspellet': ('fiolinspell',),
'fiolinspill': ('fiolinspill',),
'fiolinspilla': ('fiolinspill',),
'fiolinspillene': ('fiolinspill',),
'fiolinspillet': ('fiolinspill',),
'fiolinstreng': ('fiolinstreng',),
'fiolinstrengen': ('fiolinstreng',),
'fiolinstrengene': ('fiolinstreng',),
'fiolinstrenger': ('fiolinstreng',),
'fiolonsell': ('fiolonsell',),
'fiolonsellen': ('fiolonsell',),
'fiolonsellene': ('fiolonsell',),
'fiolonseller': ('fiolonsell',),
'fipp': ('fipp',),
'fippen': ('fipp',),
'fippene': ('fipp',),
'fipper': ('fipp',),
'fippskjegg': ('fippskjegg',),
'fippskjegga': ('fippskjegg',),
'fippskjeggene': ('fippskjegg',),
'fippskjegget': ('fippskjegg',),
'firblad': ('firblad',),
'firblada': ('firblad',),
'firbladen': ('firblad',),
'firbladene': ('firblad',),
'firblader': ('firblad',),
'firbladet': ('firblad',),
'fireakter': ('fireakter',),
'fireaktere': ('fireakter',),
'fireakteren': ('fireakter',),
'fireakterer': ('fireakter',),
'fireakterne': ('fireakter',),
'firedel': ('firedel',),
'firedelen': ('firedel',),
'firedelene': ('firedel',),
'firedeler': ('firedel',),
'firefoting': ('firefoting',),
'firefotingen': ('firefoting',),
'firefotingene': ('firefoting',),
'firefotinger': ('firefoting',),
'fireføtting': ('fireføtting',),
'fireføttingen': ('fireføtting',),
'fireføttingene': ('fireføtting',),
'fireføttinger': ('fireføtting',),
'firehjulstrekk': ('firehjulstrekk',),
'firehjulstrekka': ('firehjulstrekk',),
'firehjulstrekkene': ('firehjulstrekk',),
'firehjulstrekket': ('firehjulstrekk',),
'firemannsbolig': ('firemannsbolig',),
'firemannsboligen': ('firemannsbolig',),
'firemannsboligene': ('firemannsbolig',),
'firemannsboliger': ('firemannsbolig',),
'firemannsrom': ('firemannsrom',),
'firemannsromma': ('firemannsrom',),
'firemannsrommene': ('firemannsrom',),
'firemannsrommet': ('firemannsrom',),
'firemannstelt': ('firemannstelt',),
'firemannstelta': ('firemannstelt',),
'firemannsteltene': ('firemannstelt',),
'firemannstelter': ('firemannstelt',),
'firemannsteltet': ('firemannstelt',),
'firemaster': ('firemaster',),
'firemastere': ('firemaster',),
'firemasteren': ('firemaster',),
'firemasterer': ('firemaster',),
'firemasterne': ('firemaster',),
'firepart': ('firepart',),
'fireparten': ('firepart',),
'firepartene': ('firepart',),
'fireparter': ('firepart',),
'firer': ('firer',),
'firere': ('firer',),
'fireren': ('firer',),
'firerer': ('firer',),
'firerne': ('firer',),
'fireromsleilighet': ('fireromsleilighet',),
'fireromsleiligheta': ('fireromsleilighet',),
'fireromsleiligheten': ('fireromsleilighet',),
'fireromsleilighetene': ('fireromsleilighet',),
'fireromsleiligheter': ('fireromsleilighet',),
'fireseter': ('fireseter',),
'firesetere': ('fireseter',),
'fireseteren': ('fireseter',),
'fireseterer': ('fireseter',),
'fireseterne': ('fireseter',),
'firetaktsmotor': ('firetaktsmotor',),
'firetaktsmotoren': ('firetaktsmotor',),
'firetaktsmotorene': ('firetaktsmotor',),
'firetaktsmotorer': ('firetaktsmotor',),
'firetal': ('firetal',),
'firetala': ('firetal',),
'firetalene': ('firetal',),
'firetalet': ('firetal',),
'firetall': ('firetall',),
'firetalla': ('firetall',),
'firetallene': ('firetall',),
'firetallet': ('firetall',),
'firetid': ('firetid',),
'firetida': ('firetid',),
'firetiden': ('firetid',),
'firetidene': ('firetid',),
'firetider': ('firetid',),
'firetur': ('firetur',),
'fireturen': ('firetur',),
'fireturene': ('firetur',),
'fireturer': ('firetur',),
'fireåring': ('fireåring',),
'fireåringen': ('fireåring',),
'fireåringene': ('fireåring',),
'fireåringer': ('fireåring',),
'firfisla': ('firfisle',),
'firfisle': ('firfisle',),
'firfislen': ('firfisle',),
'firfislene': ('firfisle',),
'firfisler': ('firfisle',),
'firfoting': ('firfoting',),
'firfotingen': ('firfoting',),
'firfotingene': ('firfoting',),
'firfotinger': ('firfoting',),
'firføtting': ('firføtting',),
'firføttingen': ('firføtting',),
'firføttingene': ('firføtting',),
'firføttinger': ('firføtting',),
'firhjulstrekk': ('firhjulstrekk',),
'firhjulstrekka': ('firhjulstrekk',),
'firhjulstrekkene': ('firhjulstrekk',),
'firhjulstrekket': ('firhjulstrekk',),
'firkant': ('firkant',),
'firkanten': ('firkant',),
'firkantene': ('firkant',),
'firkanter': ('firkant',),
'firklang': ('firklang',),
'firklangen': ('firklang',),
'firklangene': ('firklang',),
'firklanger': ('firklang',),
'firkløver': ('firkløver',),
'firkløvere': ('firkløver',),
'firkløveren': ('firkløver',),
'firkløverer': ('firkløver',),
'firkløverne': ('firkløver',),
'firkløver': ('firkløver',),
'firkløvera': ('firkløver',),
'firkløverene': ('firkløver',),
'firkløverer': ('firkløver',),
'firkløveret': ('firkløver',),
'firkort': ('firkort',),
'firkorta': ('firkort',),
'firkortene': ('firkort',),
'firkortet': ('firkort',),
'firling': ('firling',),
'firlingen': ('firling',),
'firlingene': ('firling',),
'firlinger': ('firling',),
'firma': ('firma',),
'firmaene': ('firma',),
'firmaer': ('firma',),
'firmaet': ('firma',),
'firmabil': ('firmabil',),
'firmabilen': ('firmabil',),
'firmabilene': ('firmabil',),
'firmabiler': ('firmabil',),
'firmafest': ('firmafest',),
'firmafesten': ('firmafest',),
'firmafestene': ('firmafest',),
'firmafester': ('firmafest',),
'firmament': ('firmament',),
'firmamenta': ('firmament',),
'firmamentene': ('firmament',),
'firmamenter': ('firmament',),
'firmamentet': ('firmament',),
'firmamerka': ('firmamerke',),
'firmamerke': ('firmamerke',),
'firmamerkene': ('firmamerke',),
'firmamerker': ('firmamerke',),
'firmamerket': ('firmamerke',),
'firmanavn': ('firmanavn',),
'firmanavna': ('firmanavn',),
'firmanavnene': ('firmanavn',),
'firmanavnet': ('firmanavn',),
'firmaregister': ('firmaregister',),
'firmaregisteret': ('firmaregister',),
'firmaregistra': ('firmaregister',),
'firmaregistre': ('firmaregister',),
'firmaregistrene': ('firmaregister',),
'firmaregistret': ('firmaregister',),
'firmaster': ('firmaster',),
'firmastere': ('firmaster',),
'firmasteren': ('firmaster',),
'firmasterer': ('firmaster',),
'firmasterne': ('firmaster',),
'firmenning': ('firmenning',),
'firmenningen': ('firmenning',),
'firmenningene': ('firmenning',),
'firmenninger': ('firmenning',),
'firseter': ('firseter',),
'firsetere': ('firseter',),
'firseteren': ('firseter',),
'firseterer': ('firseter',),
'firseterne': ('firseter',),
'firspann': ('firspann',),
'firspanna': ('firspann',),
'firspannene': ('firspann',),
'firspannet': ('firspann',),
'firsprang': ('firsprang',),
'firspranga': ('firsprang',),
'firsprangene': ('firsprang',),
'firspranget': ('firsprang',),
'fis': ('fis',),
'fisen': ('fis',),
'fisene': ('fis',),
'fiser': ('fis',),
'fisjon': ('fisjon',),
'fisjonen': ('fisjon',),
'fisjonene': ('fisjon',),
'fisjoner': ('fisjon',),
'fisjonsenergi': ('fisjonsenergi',),
'fisjonsenergien': ('fisjonsenergi',),
'fisjonsenergiene': ('fisjonsenergi',),
'fisjonsenergier': ('fisjonsenergi',),
'fisk': ('fisk',),
'fisken': ('fisk',),
'fiskene': ('fisk',),
'fisker': ('fisk',),
'fisk': ('fisk',),
'fisken': ('fisk',),
'fiskene': ('fisk',),
'fisker': ('fisk',),
'fiskal': ('fiskal',),
'fiskalen': ('fiskal',),
'fiskalene': ('fiskal',),
'fiskaler': ('fiskal',),
'fiskaltoll': ('fiskaltoll',),
'fiskaltollen': ('fiskaltoll',),
'fiskaltollene': ('fiskaltoll',),
'fiskaltoller': ('fiskaltoll',),
'fiskand': ('fiskand',),
'fiskanda': ('fiskand',),
'fiskanden': ('fiskand',),
'fiskendene': ('fiskand',),
'fiskender': ('fiskand',),
'fiska': ('fiske',),
'fiske': ('fiske',),
'fiskene': ('fiske',),
'fisker': ('fiske',),
'fisket': ('fiske',),
'fiskeal': ('fiskeal',),
'fiskeala': ('fiskeal',),
'fiskealene': ('fiskeal',),
'fiskealet': ('fiskeal',),
'fiskeavfall': ('fiskeavfall',),
'fiskeavfalla': ('fiskeavfall',),
'fiskeavfallene': ('fiskeavfall',),
'fiskeavfallet': ('fiskeavfall',),
'fiskeavl': ('fiskeavl',),
'fiskeavlen': ('fiskeavl',),
'fiskeavlene': ('fiskeavl',),
'fiskeavler': ('fiskeavl',),
'fiskebanke': ('fiskebanke',),
'fiskebanken': ('fiskebanke',),
'fiskebankene': ('fiskebanke',),
'fiskebanker': ('fiskebanke',),
'fiskebein': ('fiskebein',),
'fiskebeina': ('fiskebein',),
'fiskebeinene': ('fiskebein',),
'fiskebeinet': ('fiskebein',),
'fiskebeinsmønster': ('fiskebeinsmønster',),
'fiskebeinsmønsteret': ('fiskebeinsmønster',),
'fiskebeinsmønstra': ('fiskebeinsmønster',),
'fiskebeinsmønstre': ('fiskebeinsmønster',),
'fiskebeinsmønstrene': ('fiskebeinsmønster',),
'fiskebeinsmønstret': ('fiskebeinsmønster',),
'fiskeben': ('fiskeben',),
'fiskebena': ('fiskeben',),
'fiskebenene': ('fiskeben',),
'fiskebenet': ('fiskeben',),
'fiskebestand': ('fiskebestand',),
'fiskebestanden': ('fiskebestand',),
'fiskebestandene': ('fiskebestand',),
'fiskebestander': ('fiskebestand',),
'fiskebil': ('fiskebil',),
'fiskebilen': ('fiskebil',),
'fiskebilene': ('fiskebil',),
'fiskebiler': ('fiskebil',),
'fiskeblod': ('fiskeblod',),
'fiskebloda': ('fiskeblod',),
'fiskeblodene': ('fiskeblod',),
'fiskeblodet': ('fiskeblod',),
'fiskebollboks': ('fiskebollboks',),
'fiskebollboksen': ('fiskebollboks',),
'fiskebollboksene': ('fiskebollboks',),
'fiskebollbokser': ('fiskebollboks',),
'fiskebolle': ('fiskebolle',),
'fiskebollen': ('fiskebolle',),
'fiskebollene': ('fiskebolle',),
'fiskeboller': ('fiskebolle',),
'fiskebruk': ('fiskebruk',),
'fiskebruka': ('fiskebruk',),
'fiskebrukene': ('fiskebruk',),
'fiskebruket': ('fiskebruk',),
'fiskebåt': ('fiskebåt',),
'fiskebåten': ('fiskebåt',),
'fiskebåtene': ('fiskebåt',),
'fiskebåter': ('fiskebåt',),
'fiskedød': ('fiskedød',),
'fiskedøden': ('fiskedød',),
'fiskedødene': ('fiskedød',),
'fiskedøder': ('fiskedød',),
'fiskeelv': ('fiskeelv',),
'fiskeelva': ('fiskeelv',),
'fiskeelven': ('fiskeelv',),
'fiskeelvene': ('fiskeelv',),
'fiskeelver': ('fiskeelv',),
'fiskefangst': ('fiskefangst',),
'fiskefangsten': ('fiskefangst',),
'fiskefangstene': ('fiskefangst',),
'fiskefangster': ('fiskefangst',),
'fiskefarse': ('fiskefarse',),
'fiskefarsen': ('fiskefarse',),
'fiskefarsene': ('fiskefarse',),
'fiskefarser': ('fiskefarse',),
'fiskefartøy': ('fiskefartøy',),
'fiskefartøya': ('fiskefartøy',),
'fiskefartøyene': ('fiskefartøy',),
'fiskefartøyer': ('fiskefartøy',),
'fiskefartøyet': ('fiskefartøy',),
'fiskefelt': ('fiskefelt',),
'fiskefelta': ('fiskefelt',),
'fiskefeltene': ('fiskefelt',),
'fiskefelter': ('fiskefelt',),
'fiskefeltet': ('fiskefelt',),
'fiskegarn': ('fiskegarn',),
'fiskegarna': ('fiskegarn',),
'fiskegarnene': ('fiskegarn',),
'fiskegarnet': ('fiskegarn',),
'fiskegrateng': ('fiskegrateng',),
'fiskegratengen': ('fiskegrateng',),
'fiskegratengene': ('fiskegrateng',),
'fiskegratenger': ('fiskegrateng',),
'fiskehall': ('fiskehall',),
'fiskehallen': ('fiskehall',),
'fiskehallene': ('fiskehall',),
'fiskehaller': ('fiskehall',),
'fiskekaka': ('fiskekake',),
'fiskekake': ('fiskekake',),
'fiskekaken': ('fiskekake',),
'fiskekakene': ('fiskekake',),
'fiskekaker': ('fiskekake',),
'fiskekort': ('fiskekort',),
'fiskekorta': ('fiskekort',),
'fiskekortene': ('fiskekort',),
'fiskekortet': ('fiskekort',),
'fiskelever': ('fiskelever',),
'fiskelevere': ('fiskelever',),
'fiskeleveren': ('fiskelever',),
'fiskeleverer': ('fiskelever',),
'fiskeleverne': ('fiskelever',),
'fiskelevra': ('fiskelever',),
'fiskelevre': ('fiskelever',),
'fiskelevrene': ('fiskelever',),
'fiskelevrer': ('fiskelever',),
'fiskelim': ('fiskelim',),
'fiskelima': ('fiskelim',),
'fiskelimene': ('fiskelim',),
'fiskelimet': ('fiskelim',),
'fiskelus': ('fiskelus',),
'fiskelusa': ('fiskelus',),
'fiskelusen': ('fiskelus',),
'fiskelusene': ('fiskelus',),
'fiskelykka': ('fiskelykke',),
'fiskelykke': ('fiskelykke',),
'fiskelykken': ('fiskelykke',),
'fiskelykkene': ('fiskelykke',),
'fiskelykker': ('fiskelykke',),
'fiskemat': ('fiskemat',),
'fiskematen': ('fiskemat',),
'fiskematene': ('fiskemat',),
'fiskemater': ('fiskemat',),
'fiskematforretning': ('fiskematforretning',),
'fiskematforretninga': ('fiskematforretning',),
'fiskematforretningen': ('fiskematforretning',),
'fiskematforretningene': ('fiskematforretning',),
'fiskematforretninger': ('fiskematforretning',),
'fiskemed': ('fiskemed',),
'fiskemeda': ('fiskemed',),
'fiskemedene': ('fiskemed',),
'fiskemedet': ('fiskemed',),
'fiskemel': ('fiskemel',),
'fiskemela': ('fiskemel',),
'fiskemelene': ('fiskemel',),
'fiskemelet': ('fiskemel',),
'fiskemjøl': ('fiskemjøl',),
'fiskemjøla': ('fiskemjøl',),
'fiskemjølene': ('fiskemjøl',),
'fiskemjølet': ('fiskemjøl',),
'fiskeplass': ('fiskeplass',),
'fiskeplassen': ('fiskeplass',),
'fiskeplassene': ('fiskeplass',),
'fiskeplasser': ('fiskeplass',),
'fiskeprodukt': ('fiskeprodukt',),
'fiskeprodukta': ('fiskeprodukt',),
'fiskeproduktene': ('fiskeprodukt',),
'fiskeprodukter': ('fiskeprodukt',),
'fiskeproduktet': ('fiskeprodukt',),
'fiskepudding': ('fiskepudding',),
'fiskepuddingen': ('fiskepudding',),
'fiskepuddingene': ('fiskepudding',),
'fiskepuddinger': ('fiskepudding',),
'fisker': ('fisker',),
'fiskere': ('fisker',),
'fiskeren': ('fisker',),
'fiskerer': ('fisker',),
'fiskerne': ('fisker',),
'fiskerbåt': ('fiskerbåt',),
'fiskerbåten': ('fiskerbåt',),
'fiskerbåtene': ('fiskerbåt',),
'fiskerbåter': ('fiskerbåt',),
'fiskerestaurant': ('fiskerestaurant',),
'fiskerestauranten': ('fiskerestaurant',),
'fiskerestaurantene': ('fiskerestaurant',),
'fiskerestauranter': ('fiskerestaurant',),
'fiskerett': ('fiskerett',),
'fiskeretten': ('fiskerett',),
'fiskerettene': ('fiskerett',),
'fiskeretter': ('fiskerett',),
'fiskerett': ('fiskerett',),
'fiskeretten': ('fiskerett',),
'fiskerettene': ('fiskerett',),
'fiskeretter': ('fiskerett',),
'fiskerfagskole': ('fiskerfagskole',),
'fiskerfagskolen': ('fiskerfagskole',),
'fiskerfagskolene': ('fiskerfagskole',),
'fiskerfagskoler': ('fiskerfagskole',),
'fiskerfartøy': ('fiskerfartøy',),
'fiskerfartøya': ('fiskerfartøy',),
'fiskerfartøyene': ('fiskerfartøy',),
'fiskerfartøyer': ('fiskerfartøy',),
'fiskerfartøyet': ('fiskerfartøy',),
'fiskerhamn': ('fiskerhamn',),
'fiskerhamna': ('fiskerhamn',),
'fiskerhamnen': ('fiskerhamn',),
'fiskerhamnene': ('fiskerhamn',),
'fiskerhamner': ('fiskerhamn',),
'fiskerhavn': ('fiskerhavn',),
'fiskerhavna': ('fiskerhavn',),
'fiskerhavnen': ('fiskerhavn',),
'fiskerhavnene': ('fiskerhavn',),
'fiskerhavner': ('fiskerhavn',),
'fiskeri': ('fiskeri',),
'fiskeria': ('fiskeri',),
'fiskeriene': ('fiskeri',),
'fiskerier': ('fiskeri',),
'fiskeriet': ('fiskeri',),
'fiskeriavtale': ('fiskeriavtale',),
'fiskeriavtalen': ('fiskeriavtale',),
'fiskeriavtalene': ('fiskeriavtale',),
'fiskeriavtaler': ('fiskeriavtale',),
'fiskeridepartement': ('fiskeridepartement',),
'fiskeridepartementa': ('fiskeridepartement',),
'fiskeridepartementene': ('fiskeridepartement',),
'fiskeridepartementer': ('fiskeridepartement',),
'fiskeridepartementet': ('fiskeridepartement',),
'fiskeridirektorat': ('fiskeridirektorat',),
'fiskeridirektorata': ('fiskeridirektorat',),
'fiskeridirektoratene': ('fiskeridirektorat',),
'fiskeridirektorater': ('fiskeridirektorat',),
'fiskeridirektoratet': ('fiskeridirektorat',),
'fiskerigrensa': ('fiskerigrense',),
'fiskerigrense': ('fiskerigrense',),
'fiskerigrensen': ('fiskerigrense',),
'fiskerigrensene': ('fiskerigrense',),
'fiskerigrenser': ('fiskerigrense',),
'fiskeriminister': ('fiskeriminister',),
'fiskeriministere': ('fiskeriminister',),
'fiskeriministeren': ('fiskeriminister',),
'fiskeriministerer': ('fiskeriminister',),
'fiskeriministerne': ('fiskeriminister',),
'fiskeriministre': ('fiskeriminister',),
'fiskeriministrene': ('fiskeriminister',),
'fiskeriministrer': ('fiskeriminister',),
'fiskerinasjon': ('fiskerinasjon',),
'fiskerinasjonen': ('fiskerinasjon',),
'fiskerinasjonene': ('fiskerinasjon',),
'fiskerinasjoner': ('fiskerinasjon',),
'fiskerioppsyn': ('fiskerioppsyn',),
'fiskerioppsyna': ('fiskerioppsyn',),
'fiskerioppsynene': ('fiskerioppsyn',),
'fiskerioppsynet': ('fiskerioppsyn',),
'fiskerisona': ('fiskerisone',),
'fiskerisone': ('fiskerisone',),
'fiskerisonen': ('fiskerisone',),
'fiskerisonene': ('fiskerisone',),
'fiskerisoner': ('fiskerisone',),
'fiskeskjell': ('fiskeskjell',),
'fiskeskjella': ('fiskeskjell',),
'fiskeskjellen': ('fiskeskjell',),
'fiskeskjellene': ('fiskeskjell',),
'fiskeskjellet': ('fiskeskjell',),
'fiskeskøyta': ('fiskeskøyte',),
'fiskeskøyte': ('fiskeskøyte',),
'fiskeskøyten': ('fiskeskøyte',),
'fiskeskøytene': ('fiskeskøyte',),
'fiskeskøyter': ('fiskeskøyte',),
'fiskeslag': ('fiskeslag',),
'fiskeslaga': ('fiskeslag',),
'fiskeslagene': ('fiskeslag',),
'fiskeslaget': ('fiskeslag',),
'fiskesnøra': ('fiskesnøre',),
'fiskesnøre': ('fiskesnøre',),
'fiskesnørene': ('fiskesnøre',),
'fiskesnører': ('fiskesnøre',),
'fiskesnøret': ('fiskesnøre',),
'fiskestang': ('fiskestang',),
'fiskestanga': ('fiskestang',),
'fiskestangen': ('fiskestang',),
'fiskestengene': ('fiskestang',),
'fiskestenger': ('fiskestang',),
'fiskesuppa': ('fiskesuppe',),
'fiskesuppe': ('fiskesuppe',),
'fiskesuppen': ('fiskesuppe',),
'fiskesuppene': ('fiskesuppe',),
'fiskesupper': ('fiskesuppe',),
'fisketorg': ('fisketorg',),
'fisketorga': ('fisketorg',),
'fisketorgene': ('fisketorg',),
'fisketorget': ('fisketorg',),
'fisketrapp': ('fisketrapp',),
'fisketrappa': ('fisketrapp',),
'fisketrappen': ('fisketrapp',),
'fisketrappene': ('fisketrapp',),
'fisketrapper': ('fisketrapp',),
'fiskevann': ('fiskevann',),
'fiskevanna': ('fiskevann',),
'fiskevannene': ('fiskevann',),
'fiskevannet': ('fiskevann',),
'fiskevatn': ('fiskevatn',),
'fiskevatna': ('fiskevatn',),
'fiskevatnene': ('fiskevatn',),
'fiskevatnet': ('fiskevatn',),
'fiskevær': ('fiskevær',),
'fiskeværa': ('fiskevær',),
'fiskeværene': ('fiskevær',),
'fiskeværet': ('fiskevær',),
'fiskeørn': ('fiskeørn',),
'fiskeørna': ('fiskeørn',),
'fiskeørnen': ('fiskeørn',),
'fiskeørnene': ('fiskeørn',),
'fiskeørner': ('fiskeørn',),
'fiskeøyelinsa': ('fiskeøyelinse',),
'fiskeøyelinse': ('fiskeøyelinse',),
'fiskeøyelinsen': ('fiskeøyelinse',),
'fiskeøyelinsene': ('fiskeøyelinse',),
'fiskeøyelinser': ('fiskeøyelinse',),
'fiskeøyeobjektiv': ('fiskeøyeobjektiv',),
'fiskeøyeobjektiva': ('fiskeøyeobjektiv',),
'fiskeøyeobjektivene': ('fiskeøyeobjektiv',),
'fiskeøyeobjektiver': ('fiskeøyeobjektiv',),
'fiskeøyeobjektivet': ('fiskeøyeobjektiv',),
'fislefant': ('fislefant',),
'fislefanten': ('fislefant',),
'fislefantene': ('fislefant',),
'fislefanter': ('fislefant',),
'fisletut': ('fisletut',),
'fisletuten': ('fisletut',),
'fisletutene': ('fisletut',),
'fisletuter': ('fisletut',),
'fiss': ('fiss',),
'fissen': ('fiss',),
'fissene': ('fiss',),
'fisser': ('fiss',),
'fiss-moll': ('fiss-moll',),
'fiss-mollen': ('fiss-moll',),
'fiss-mollene': ('fiss-moll',),
'fiss-moller': ('fiss-moll',),
'fissil': ('fissil',),
'fissila': ('fissil',),
'fissilene': ('fissil',),
'fissiler': ('fissil',),
'fissilet': ('fissil',),
'fistel': ('fistel',),
'fistelen': ('fistel',),
'fistlene': ('fistel',),
'fistler': ('fistel',),
'fistel': ('fistel',),
'fistelen': ('fistel',),
'fistlene': ('fistel',),
'fistler': ('fistel',),
'fistelleia': ('fistelleie',),
'fistelleie': ('fistelleie',),
'fistelleiene': ('fistelleie',),
'fistelleier': ('fistelleie',),
'fistelleiet': ('fistelleie',),
'fistelstemme': ('fistelstemme',),
'fistelstemmen': ('fistelstemme',),
'fistelstemmene': ('fistelstemme',),
'fistelstemmer': ('fistelstemme',),
'fitta': ('fitte',),
'fitte': ('fitte',),
'fitten': ('fitte',),
'fittene': ('fitte',),
'fitter': ('fitte',),
'fitting': ('fitting',),
'fittingen': ('fitting',),
'fittingene': ('fitting',),
'fittings': ('fitting',),
'fjas': ('fjas',),
'fjasa': ('fjas',),
'fjasene': ('fjas',),
'fjaset': ('fjas',),
'fjed': ('fjed',),
'fjeda': ('fjed',),
'fjedene': ('fjed',),
'fjedet': ('fjed',),
'fjel': ('fjel',),
'fjela': ('fjel',),
'fjelen': ('fjel',),
'fjelene': ('fjel',),
'fjeler': ('fjel',),
'fjell': ('fjell',),
'fjella': ('fjell',),
'fjellene': ('fjell',),
'fjellet': ('fjell',),
'fjell-land': ('fjell-land',),
'fjell-landa': ('fjell-land',),
'fjell-landene': ('fjell-land',),
'fjell-landet': ('fjell-land',),
'fjell-luft': ('fjell-luft',),
'fjell-lufta': ('fjell-luft',),
'fjell-luften': ('fjell-luft',),
'fjell-luftene': ('fjell-luft',),
'fjell-lufter': ('fjell-luft',),
'fjelland': ('fjelland',),
'fjellanda': ('fjelland',),
'fjellandene': ('fjelland',),
'fjellandet': ('fjelland',),
'fjellaure': ('fjellaure',),
'fjellauren': ('fjellaure',),
'fjellaurene': ('fjellaure',),
'fjellaurer': ('fjellaure',),
'fjellbeita': ('fjellbeite',),
'fjellbeite': ('fjellbeite',),
'fjellbeitene': ('fjellbeite',),
'fjellbeiter': ('fjellbeite',),
'fjellbeitet': ('fjellbeite',),
'fjellbjerk': ('fjellbjerk',),
'fjellbjerka': ('fjellbjerk',),
'fjellbjerken': ('fjellbjerk',),
'fjellbjerkene': ('fjellbjerk',),
'fjellbjerker': ('fjellbjerk',),
'fjellbjørk': ('fjellbjørk',),
'fjellbjørka': ('fjellbjørk',),
'fjellbjørken': ('fjellbjørk',),
'fjellbjørkene': ('fjellbjørk',),
'fjellbjørker': ('fjellbjørk',),
'fjellbrun': ('fjellbrun',),
'fjellbruna': ('fjellbrun',),
'fjellbrunen': ('fjellbrun',),
'fjellbrunene': ('fjellbrun',),
'fjellbruner': ('fjellbrun',),
'fjellbygd': ('fjellbygd',),
'fjellbygda': ('fjellbygd',),
'fjellbygden': ('fjellbygd',),
'fjellbygdene': ('fjellbygd',),
'fjellbygder': ('fjellbygd',),
'fjellflokk': ('fjellflokk',),
'fjellflokken': ('fjellflokk',),
'fjellflokkene': ('fjellflokk',),
'fjellflokker': ('fjellflokk',),
'fjellflora': ('fjellflora',),
'fjellfloraen': ('fjellflora',),
'fjellfloraene': ('fjellflora',),
'fjellfloraer': ('fjellflora',),
'fjellformasjon': ('fjellformasjon',),
'fjellformasjonen': ('fjellformasjon',),
'fjellformasjonene': ('fjellformasjon',),
'fjellformasjoner': ('fjellformasjon',),
'fjellfot': ('fjellfot',),
'fjellfoten': ('fjellfot',),
'fjellføttene': ('fjellfot',),
'fjellføtter': ('fjellfot',),
'fjellfuru': ('fjellfuru',),
'fjellfurua': ('fjellfuru',),
'fjellfuruen': ('fjellfuru',),
'fjellfuruene': ('fjellfuru',),
'fjellfuruer': ('fjellfuru',),
'fjellgard': ('fjellgard',),
'fjellgarden': ('fjellgard',),
'fjellgardene': ('fjellgard',),
'fjellgarder': ('fjellgard',),
'fjellgård': ('fjellgård',),
'fjellgården': ('fjellgård',),
'fjellgårdene': ('fjellgård',),
'fjellgårder': ('fjellgård',),
'fjellheim': ('fjellheim',),
'fjellheimen': ('fjellheim',),
'fjellheimene': ('fjellheim',),
'fjellheimer': ('fjellheim',),
'fjellkjede': ('fjellkjede',),
'fjellkjeden': ('fjellkjede',),
'fjellkjedene': ('fjellkjede',),
'fjellkjeder': ('fjellkjede',),
'fjellklatrer': ('fjellklatrer',),
'fjellklatrere': ('fjellklatrer',),
'fjellklatreren': ('fjellklatrer',),
'fjellklatrerer': ('fjellklatrer',),
'fjellklatrerne': ('fjellklatrer',),
'fjellklatring': ('fjellklatring',),
'fjellklatringa': ('fjellklatring',),
'fjellklatringen': ('fjellklatring',),
'fjellklatringene': ('fjellklatring',),
'fjellklatringer': ('fjellklatring',),
'fjellovergang': ('fjellovergang',),
'fjellovergangen': ('fjellovergang',),
'fjellovergangene': ('fjellovergang',),
'fjelloverganger': ('fjellovergang',),
'fjellplatå': ('fjellplatå',),
'fjellplatåa': ('fjellplatå',),
'fjellplatåene': ('fjellplatå',),
'fjellplatåer': ('fjellplatå',),
'fjellplatået': ('fjellplatå',),
'fjellregion': ('fjellregion',),
'fjellregionen': ('fjellregion',),
'fjellregionene': ('fjellregion',),
'fjellregioner': ('fjellregion',),
'fjellrev': ('fjellrev',),
'fjellreven': ('fjellrev',),
'fjellrevene': ('fjellrev',),
'fjellrever': ('fjellrev',),
'fjellrotta': ('fjellrotte',),
'fjellrotte': ('fjellrotte',),
'fjellrotten': ('fjellrotte',),
'fjellrottene': ('fjellrotte',),
'fjellrotter': ('fjellrotte',),
'fjellrypa': ('fjellrype',),
'fjellrype': ('fjellrype',),
'fjellrypen': ('fjellrype',),
'fjellrypene': ('fjellrype',),
'fjellryper': ('fjellrype',),
'fjellsame': ('fjellsame',),
'fjellsamen': ('fjellsame',),
'fjellsamene': ('fjellsame',),
'fjellsamer': ('fjellsame',),
'fjellsikring': ('fjellsikring',),
'fjellsikringa': ('fjellsikring',),
'fjellsikringen': ('fjellsikring',),
'fjellsikringene': ('fjellsikring',),
'fjellsikringer': ('fjellsikring',),
'fjellsikringstjeneste': ('fjellsikringstjeneste',),
'fjellsikringstjenesten': ('fjellsikringstjeneste',),
'fjellsikringstjenestene': ('fjellsikringstjeneste',),
'fjellsikringstjenester': ('fjellsikringstjeneste',),
'fjellskar': ('fjellskar',),
'fjellskara': ('fjellskar',),
'fjellskarene': ('fjellskar',),
'fjellskaret': ('fjellskar',),
'fjellsmør': ('fjellsmør',),
'fjellsmøra': ('fjellsmør',),
'fjellsmørene': ('fjellsmør',),
'fjellsmøret': ('fjellsmør',),
'fjellstova': ('fjellstove',),
'fjellstove': ('fjellstove',),
'fjellstoven': ('fjellstove',),
'fjellstovene': ('fjellstove',),
'fjellstover': ('fjellstove',),
'fjellstua': ('fjellstue',),
'fjellstue': ('fjellstue',),
'fjellstuen': ('fjellstue',),
'fjellstuene': ('fjellstue',),
'fjellstuer': ('fjellstue',),
'fjelltind': ('fjelltind',),
'fjelltinden': ('fjelltind',),
'fjelltindene': ('fjelltind',),
'fjelltinder': ('fjelltind',),
'fjelltopp': ('fjelltopp',),
'fjelltoppen': ('fjelltopp',),
'fjelltoppene': ('fjelltopp',),
'fjelltopper': ('fjelltopp',),
'fjelluft': ('fjelluft',),
'fjellufta': ('fjelluft',),
'fjelluften': ('fjelluft',),
'fjelluftene': ('fjelluft',),
'fjellufter': ('fjelluft',),
'fjellvann': ('fjellvann',),
'fjellvanna': ('fjellvann',),
'fjellvannene': ('fjellvann',),
'fjellvannet': ('fjellvann',),
'fjellvatn': ('fjellvatn',),
'fjellvatna': ('fjellvatn',),
'fjellvatnene': ('fjellvatn',),
'fjellvatnet': ('fjellvatn',),
'fjellvegg': ('fjellvegg',),
'fjellveggen': ('fjellvegg',),
'fjellveggene': ('fjellvegg',),
'fjellvegger': ('fjellvegg',),
'fjellvett': ('fjellvett',),
'fjellvetta': ('fjellvett',),
'fjellvettene': ('fjellvett',),
'fjellvettet': ('fjellvett',),
'fjellvettregel': ('fjellvettregel',),
'fjellvettregelen': ('fjellvettregel',),
'fjellvettreglene': ('fjellvettregel',),
'fjellvettregler': ('fjellvettregel',),
'fjellvidda': ('fjellvidde',),
'fjellvidde': ('fjellvidde',),
'fjellvidden': ('fjellvidde',),
'fjellviddene': ('fjellvidde',),
'fjellvidder': ('fjellvidde',),
'fjellvåk': ('fjellvåk',),
'fjellvåken': ('fjellvåk',),
'fjellvåkene': ('fjellvåk',),
'fjellvåker': ('fjellvåk',),
'fjellørret': ('fjellørret',),
'fjellørreten': ('fjellørret',),
'fjellørretene': ('fjellørret',),
'fjellørreter': ('fjellørret',),
'fjerdedel': ('fjerdedel',),
'fjerdedelen': ('fjerdedel',),
'fjerdedelene': ('fjerdedel',),
'fjerdedeler': ('fjerdedel',),
'fjerdegir': ('fjerdegir',),
'fjerdegira': ('fjerdegir',),
'fjerdegirene': ('fjerdegir',),
'fjerdegiret': ('fjerdegir',),
'fjerdepart': ('fjerdepart',),
'fjerdeparten': ('fjerdepart',),
'fjerdepartene': ('fjerdepart',),
'fjerdeparter': ('fjerdepart',),
'fjerding': ('fjerding',),
'fjerdingen': ('fjerding',),
'fjerdingene': ('fjerding',),
'fjerdinger': ('fjerding',),
'fjernadopsjon': ('fjernadopsjon',),
'fjernadopsjonen': ('fjernadopsjon',),
'fjernadopsjonene': ('fjernadopsjon',),
'fjernadopsjoner': ('fjernadopsjon',),
'fjernkontroll': ('fjernkontroll',),
'fjernkontrollen': ('fjernkontroll',),
'fjernkontrollene': ('fjernkontroll',),
'fjernkontroller': ('fjernkontroll',),
'fjernlinsa': ('fjernlinse',),
'fjernlinse': ('fjernlinse',),
'fjernlinsen': ('fjernlinse',),
'fjernlinsene': ('fjernlinse',),
'fjernlinser': ('fjernlinse',),
'fjernlys': ('fjernlys',),
'fjernlysa': ('fjernlys',),
'fjernlysene': ('fjernlys',),
'fjernlyset': ('fjernlys',),
'fjernskriver': ('fjernskriver',),
'fjernskrivere': ('fjernskriver',),
'fjernskriveren': ('fjernskriver',),
'fjernskriverer': ('fjernskriver',),
'fjernskriverne': ('fjernskriver',),
'fjernstyring': ('fjernstyring',),
'fjernstyringa': ('fjernstyring',),
'fjernstyringen': ('fjernstyring',),
'fjernstyringene': ('fjernstyring',),
'fjernstyringer': ('fjernstyring',),
'fjernsyn': ('fjernsyn',),
'fjernsyna': ('fjernsyn',),
'fjernsynene': ('fjernsyn',),
'fjernsynet': ('fjernsyn',),
'fjernsynsantenna': ('fjernsynsantenne',),
'fjernsynsantenne': ('fjernsynsantenne',),
'fjernsynsantennen': ('fjernsynsantenne',),
'fjernsynsantennene': ('fjernsynsantenne',),
'fjernsynsantenner': ('fjernsynsantenne',),
'fjernsynsapparat': ('fjernsynsapparat',),
'fjernsynsapparata': ('fjernsynsapparat',),
'fjernsynsapparatene': ('fjernsynsapparat',),
'fjernsynsapparater': ('fjernsynsapparat',),
'fjernsynsapparatet': ('fjernsynsapparat',),
'fjernsynsbilda': ('fjernsynsbilde',),
'fjernsynsbilde': ('fjernsynsbilde',),
'fjernsynsbildene': ('fjernsynsbilde',),
'fjernsynsbilder': ('fjernsynsbilde',),
'fjernsynsbildet': ('fjernsynsbilde',),
'fjernsynsdebatt': ('fjernsynsdebatt',),
'fjernsynsdebatten': ('fjernsynsdebatt',),
'fjernsynsdebattene': ('fjernsynsdebatt',),
'fjernsynsdebatter': ('fjernsynsdebatt',),
'fjernsynskamera': ('fjernsynskamera',),
'fjernsynskameraene': ('fjernsynskamera',),
'fjernsynskameraer': ('fjernsynskamera',),
'fjernsynskameraet': ('fjernsynskamera',),
'fjernsynskanal': ('fjernsynskanal',),
'fjernsynskanalen': ('fjernsynskanal',),
'fjernsynskanalene': ('fjernsynskanal',),
'fjernsynskanaler': ('fjernsynskanal',),
'fjernsynslisens': ('fjernsynslisens',),
'fjernsynslisensen': ('fjernsynslisens',),
'fjernsynslisensene': ('fjernsynslisens',),
'fjernsynslisenser': ('fjernsynslisens',),
'fjernsynsmottaker': ('fjernsynsmottaker',),
'fjernsynsmottakere': ('fjernsynsmottaker',),
'fjernsynsmottakeren': ('fjernsynsmottaker',),
'fjernsynsmottakerer': ('fjernsynsmottaker',),
'fjernsynsmottakerne': ('fjernsynsmottaker',),
'fjernsynsoverføring': ('fjernsynsoverføring',),
'fjernsynsoverføringa': ('fjernsynsoverføring',),
'fjernsynsoverføringen': ('fjernsynsoverføring',),
'fjernsynsoverføringene': ('fjernsynsoverføring',),
'fjernsynsoverføringer': ('fjernsynsoverføring',),
'fjernsynsovervåking': ('fjernsynsovervåking',),
'fjernsynsovervåkinga': ('fjernsynsovervåking',),
'fjernsynsovervåkingen': ('fjernsynsovervåking',),
'fjernsynsovervåkingene': ('fjernsynsovervåking',),
'fjernsynsovervåkinger': ('fjernsynsovervåking',),
'fjernsynsovervåkning': ('fjernsynsovervåkning',),
'fjernsynsovervåkninga': ('fjernsynsovervåkning',),
'fjernsynsovervåkningen': ('fjernsynsovervåkning',),
'fjernsynsovervåkningene': ('fjernsynsovervåkning',),
'fjernsynsovervåkninger': ('fjernsynsovervåkning',),
'fjernsynsprogram': ('fjernsynsprogram',),
'fjernsynsprogramma': ('fjernsynsprogram',),
'fjernsynsprogrammene': ('fjernsynsprogram',),
'fjernsynsprogrammer': ('fjernsynsprogram',),
'fjernsynsprogrammet': ('fjernsynsprogram',),
'fjernsynsseer': ('fjernsynsseer',),
'fjernsynsseere': ('fjernsynsseer',),
'fjernsynsseeren': ('fjernsynsseer',),
'fjernsynsseerer': ('fjernsynsseer',),
'fjernsynsseerne': ('fjernsynsseer',),
'fjernsynsserie': ('fjernsynsserie',),
'fjernsynsserien': ('fjernsynsserie',),
'fjernsynsseriene': ('fjernsynsserie',),
'fjernsynsserier': ('fjernsynsserie',),
'fjernsynsskjerm': ('fjernsynsskjerm',),
'fjernsynsskjermen': ('fjernsynsskjerm',),
'fjernsynsskjermene': ('fjernsynsskjerm',),
'fjernsynsskjermer': ('fjernsynsskjerm',),
'fjernsynsteater': ('fjernsynsteater',),
'fjernsynsteateret': ('fjernsynsteater',),
'fjernsynsteatra': ('fjernsynsteater',),
'fjernsynsteatre': ('fjernsynsteater',),
'fjernsynsteatrene': ('fjernsynsteater',),
'fjernsynsteatret': ('fjernsynsteater',),
'fjernsynsvert': ('fjernsynsvert',),
'fjernsynsverten': ('fjernsynsvert',),
'fjernsynsvertene': ('fjernsynsvert',),
'fjernsynsverter': ('fjernsynsvert',),
'fjernsynsvertinna': ('fjernsynsvertinne',),
'fjernsynsvertinne': ('fjernsynsvertinne',),
'fjernsynsvertinnen': ('fjernsynsvertinne',),
'fjernsynsvertinnene': ('fjernsynsvertinne',),
'fjernsynsvertinner': ('fjernsynsvertinne',),
'fjerntog': ('fjerntog',),
'fjerntoga': ('fjerntog',),
'fjerntogene': ('fjerntog',),
'fjerntoget': ('fjerntog',),
'fjernvalg': ('fjernvalg',),
'fjernvalga': ('fjernvalg',),
'fjernvalgene': ('fjernvalg',),
'fjernvalget': ('fjernvalg',),
'fjernvarme': ('fjernvarme',),
'fjernvarmen': ('fjernvarme',),
'fjernvarmene': ('fjernvarme',),
'fjernvarmer': ('fjernvarme',),
'fjernvarmeanlegg': ('fjernvarmeanlegg',),
'fjernvarmeanlegga': ('fjernvarmeanlegg',),
'fjernvarmeanleggene': ('fjernvarmeanlegg',),
'fjernvarmeanlegget': ('fjernvarmeanlegg',),
'fjert': ('fjert',),
'fjerten': ('fjert',),
'fjertene': ('fjert',),
'fjerter': ('fjert',),
'fjes': ('fjes',),
'fjesa': ('fjes',),
'fjesene': ('fjes',),
'fjeset': ('fjes',),
'fjesing': ('fjesing',),
'fjesingen': ('fjesing',),
'fjesingene': ('fjesing',),
'fjesinger': ('fjesing',),
'fjesk': ('fjesk',),
'fjeska': ('fjesk',),
'fjeskene': ('fjesk',),
'fjesket': ('fjesk',),
'fjoll': ('fjoll',),
'fjollen': ('fjoll',),
'fjollene': ('fjoll',),
'fjoller': ('fjoll',),
'fjoll': ('fjoll',),
'fjolla': ('fjoll',),
'fjollene': ('fjoll',),
'fjollet': ('fjoll',),
'fjolla': ('fjolle',),
'fjolle': ('fjolle',),
'fjollen': ('fjolle',),
'fjollene': ('fjolle',),
'fjoller': ('fjolle',),
'fjolleri': ('fjolleri',),
'fjolleria': ('fjolleri',),
'fjolleriene': ('fjolleri',),
'fjollerier': ('fjolleri',),
'fjolleriet': ('fjolleri',),
'fjols': ('fjols',),
'fjolsa': ('fjols',),
'fjolsene': ('fjols',),
'fjolset': ('fjols',),
'fjomp': ('fjomp',),
'fjompen': ('fjomp',),
'fjompene': ('fjomp',),
'fjomper': ('fjomp',),
'fjompenisse': ('fjompenisse',),
'fjompenissen': ('fjompenisse',),
'fjompenissene': ('fjompenisse',),
'fjompenisser': ('fjompenisse',),
'fjon': ('fjon',),
'fjona': ('fjon',),
'fjonene': ('fjon',),
'fjoner': ('fjon',),
'fjonet': ('fjon',),
'fjor': ('fjor',),
'fjord': ('fjord',),
'fjorden': ('fjord',),
'fjordene': ('fjord',),
'fjorder': ('fjord',),
'fjordarm': ('fjordarm',),
'fjordarmen': ('fjordarm',),
'fjordarmene': ('fjordarm',),
'fjordarmer': ('fjordarm',),
'fjordbotn': ('fjordbotn',),
'fjordbotnen': ('fjordbotn',),
'fjordbotnene': ('fjordbotn',),
'fjordbotner': ('fjordbotn',),
'fjordbotn': ('fjordbotn',),
'fjordbotnen': ('fjordbotn',),
'fjordbotnene': ('fjordbotn',),
'fjordbotner': ('fjordbotn',),
'fjordbunn': ('fjordbunn',),
'fjordbunnen': ('fjordbunn',),
'fjordbunnene': ('fjordbunn',),
'fjordbunner': ('fjordbunn',),
'fjordbygd': ('fjordbygd',),
'fjordbygda': ('fjordbygd',),
'fjordbygden': ('fjordbygd',),
'fjordbygdene': ('fjordbygd',),
'fjordbygder': ('fjordbygd',),
'fjordgap': ('fjordgap',),
'fjordgapa': ('fjordgap',),
'fjordgapene': ('fjordgap',),
'fjordgapet': ('fjordgap',),
'fjordhest': ('fjordhest',),
'fjordhesten': ('fjordhest',),
'fjordhestene': ('fjordhest',),
'fjordhester': ('fjordhest',),
'fjording': ('fjording',),
'fjordingen': ('fjording',),
'fjordingene': ('fjording',),
'fjordinger': ('fjording',),
'fjordsel': ('fjordsel',),
'fjordselen': ('fjordsel',),
'fjordselene': ('fjordsel',),
'fjordseler': ('fjordsel',),
'fjorhøst': ('fjorhøst',),
'fjorhøsten': ('fjorhøst',),
'fjorhøstene': ('fjorhøst',),
'fjorhøster': ('fjorhøst',),
'fjorsommer': ('fjorsommer',),
'fjorsommere': ('fjorsommer',),
'fjorsommeren': ('fjorsommer',),
'fjorsommerne': ('fjorsommer',),
'fjorsomre': ('fjorsommer',),
'fjorsomrene': ('fjorsommer',),
'fjorsomrer': ('fjorsommer',),
'fjortendel': ('fjortendel',),
'fjortendelen': ('fjortendel',),
'fjortendelene': ('fjortendel',),
'fjortendeler': ('fjortendel',),
'fjortenåring': ('fjortenåring',),
'fjortenåringen': ('fjortenåring',),
'fjortenåringene': ('fjortenåring',),
'fjortenåringer': ('fjortenåring',),
'fjortenårsalder': ('fjortenårsalder',),
'fjortenårsaldere': ('fjortenårsalder',),
'fjortenårsalderen': ('fjortenårsalder',),
'fjortenårsalderer': ('fjortenårsalder',),
'fjortenårsalderne': ('fjortenårsalder',),
'fjortenårsaldre': ('fjortenårsalder',),
'fjortenårsaldrene': ('fjortenårsalder',),
'fjortenårsaldrer': ('fjortenårsalder',),
'fjorvinter': ('fjorvinter',),
'fjorvintere': ('fjorvinter',),
'fjorvinteren': ('fjorvinter',),
'fjorvinterne': ('fjorvinter',),
'fjorvintre': ('fjorvinter',),
'fjorvintrene': ('fjorvinter',),
'fjorvintrer': ('fjorvinter',),
'fjorvår': ('fjorvår',),
'fjorvåren': ('fjorvår',),
'fjorvårene': ('fjorvår',),
'fjorvårer': ('fjorvår',),
'fjorår': ('fjorår',),
'fjoråra': ('fjorår',),
'fjorårene': ('fjorår',),
'fjoråret': ('fjorår',),
'fjott': ('fjott',),
'fjotten': ('fjott',),
'fjottene': ('fjott',),
'fjotter': ('fjott',),
'fjun': ('fjun',),
'fjuna': ('fjun',),
'fjunene': ('fjun',),
'fjunet': ('fjun',),
'fjær': ('fjær',),
'fjæra': ('fjær',),
'fjæren': ('fjær',),
'fjærene': ('fjær',),
'fjærer': ('fjær',),
'fjærdrakt': ('fjærdrakt',),
'fjærdrakta': ('fjærdrakt',),
'fjærdrakten': ('fjærdrakt',),
'fjærdraktene': ('fjærdrakt',),
'fjærdrakter': ('fjærdrakt',),
'fjæra': ('fjære',),
'fjære': ('fjære',),
'fjæren': ('fjære',),
'fjærene': ('fjære',),
'fjærer': ('fjære',),
'fjæreknapp': ('fjæreknapp',),
'fjæreknappen': ('fjæreknapp',),
'fjæreknappene': ('fjæreknapp',),
'fjæreknapper': ('fjæreknapp',),
'fjæremakk': ('fjæremakk',),
'fjæremakken': ('fjæremakk',),
'fjæremakkene': ('fjæremakk',),
'fjæremakker': ('fjæremakk',),
'fjæremark': ('fjæremark',),
'fjæremarken': ('fjæremark',),
'fjæremarkene': ('fjæremark',),
'fjæremarker': ('fjæremark',),
'fjæremål': ('fjæremål',),
'fjæremåla': ('fjæremål',),
'fjæremålene': ('fjæremål',),
'fjæremålet': ('fjæremål',),
'fjæresand': ('fjæresand',),
'fjæresanden': ('fjæresand',),
'fjæresandene': ('fjæresand',),
'fjæresander': ('fjæresand',),
'fjærestein': ('fjærestein',),
'fjæresteinen': ('fjærestein',),
'fjæresteinene': ('fjærestein',),
'fjæresteiner': ('fjærestein',),
'fjærfe': ('fjærfe',),
'fjærfea': ('fjærfe',),
'fjærfeene': ('fjærfe',),
'fjærfeet': ('fjærfe',),
'fjærham': ('fjærham',),
'fjærhammen': ('fjærham',),
'fjærhammene': ('fjærham',),
'fjærhammer': ('fjærham',),
'fjæring': ('fjæring',),
'fjæringa': ('fjæring',),
'fjæringen': ('fjæring',),
'fjæringene': ('fjæring',),
'fjæringer': ('fjæring',),
'fjærmadrass': ('fjærmadrass',),
'fjærmadrassen': ('fjærmadrass',),
'fjærmadrassene': ('fjærmadrass',),
'fjærmadrasser': ('fjærmadrass',),
'fjærsky': ('fjærsky',),
'fjærskya': ('fjærsky',),
'fjærskyen': ('fjærsky',),
'fjærskyene': ('fjærsky',),
'fjærskyer': ('fjærsky',),
'fjærvekt': ('fjærvekt',),
'fjærvekta': ('fjærvekt',),
'fjærvekten': ('fjærvekt',),
'fjærvektene': ('fjærvekt',),
'fjærvekter': ('fjærvekt',),
'fjærvekter': ('fjærvekter',),
'fjærvektere': ('fjærvekter',),
'fjærvekteren': ('fjærvekter',),
'fjærvekterer': ('fjærvekter',),
'fjærvekterne': ('fjærvekter',),
'fjærvektklassa': ('fjærvektklasse',),
'fjærvektklasse': ('fjærvektklasse',),
'fjærvektklassen': ('fjærvektklasse',),
'fjærvektklassene': ('fjærvektklasse',),
'fjærvektklasser': ('fjærvektklasse',),
'fjærvektsklassa': ('fjærvektsklasse',),
'fjærvektsklasse': ('fjærvektsklasse',),
'fjærvektsklassen': ('fjærvektsklasse',),
'fjærvektsklassene': ('fjærvektsklasse',),
'fjærvektsklasser': ('fjærvektsklasse',),
'fjøl': ('fjøl',),
'fjøla': ('fjøl',),
'fjølen': ('fjøl',),
'fjølene': ('fjøl',),
'fjøler': ('fjøl',),
'fjør': ('fjør',),
'fjøra': ('fjør',),
'fjøren': ('fjør',),
'fjørene': ('fjør',),
'fjører': ('fjør',),
'fjørdrakt': ('fjørdrakt',),
'fjørdrakta': ('fjørdrakt',),
'fjørdrakten': ('fjørdrakt',),
'fjørdraktene': ('fjørdrakt',),
'fjørdrakter': ('fjørdrakt',),
'fjørfe': ('fjørfe',),
'fjørfea': ('fjørfe',),
'fjørfeene': ('fjørfe',),
'fjørfeet': ('fjørfe',),
'fjørham': ('fjørham',),
'fjørhammen': ('fjørham',),
'fjørhammene': ('fjørham',),
'fjørhammer': ('fjørham',),
'fjøring': ('fjøring',),
'fjøringa': ('fjøring',),
'fjøringen': ('fjøring',),
'fjøringene': ('fjøring',),
'fjøringer': ('fjøring',),
'fjørmadrass': ('fjørmadrass',),
'fjørmadrassen': ('fjørmadrass',),
'fjørmadrassene': ('fjørmadrass',),
'fjørmadrasser': ('fjørmadrass',),
'fjørsky': ('fjørsky',),
'fjørskya': ('fjørsky',),
'fjørskyen': ('fjørsky',),
'fjørskyene': ('fjørsky',),
'fjørskyer': ('fjørsky',),
'fjørvekt': ('fjørvekt',),
'fjørvekta': ('fjørvekt',),
'fjørvekten': ('fjørvekt',),
'fjørvektene': ('fjørvekt',),
'fjørvekter': ('fjørvekt',),
'fjørvekter': ('fjørvekter',),
'fjørvektere': ('fjørvekter',),
'fjørvekteren': ('fjørvekter',),
'fjørvekterer': ('fjørvekter',),
'fjørvekterne': ('fjørvekter',),
'fjørvektklassa': ('fjørvektklasse',),
'fjørvektklasse': ('fjørvektklasse',),
'fjørvektklassen': ('fjørvektklasse',),
'fjørvektklassene': ('fjørvektklasse',),
'fjørvektklasser': ('fjørvektklasse',),
'fjørvektsklassa': ('fjørvektsklasse',),
'fjørvektsklasse': ('fjørvektsklasse',),
'fjørvektsklassen': ('fjørvektsklasse',),
'fjørvektsklassene': ('fjørvektsklasse',),
'fjørvektsklasser': ('fjørvektsklasse',),
'fjøs': ('fjøs',),
'fjøsa': ('fjøs',),
'fjøsen': ('fjøs',),
'fjøsene': ('fjøs',),
'fjøset': ('fjøs',),
'fjøsbygning': ('fjøsbygning',),
'fjøsbygninga': ('fjøsbygning',),
'fjøsbygningen': ('fjøsbygning',),
'fjøsbygningene': ('fjøsbygning',),
'fjøsbygninger': ('fjøsbygning',),
'fjøsdrift': ('fjøsdrift',),
'fjøsdrifta': ('fjøsdrift',),
'fjøsdriften': ('fjøsdrift',),
'fjøsdriftene': ('fjøsdrift',),
'fjøsdrifter': ('fjøsdrift',),
'fjøskontroll': ('fjøskontroll',),
'fjøskontrollen': ('fjøskontroll',),
'fjøskontrollene': ('fjøskontroll',),
'fjøskontroller': ('fjøskontroll',),
'fjøsnisse': ('fjøsnisse',),
'fjøsnissen': ('fjøsnisse',),
'fjøsnissene': ('fjøsnisse',),
'fjøsnisser': ('fjøsnisse',),
'fjøsrøkt': ('fjøsrøkt',),
'fjøsrøkta': ('fjøsrøkt',),
'fjøsrøkten': ('fjøsrøkt',),
'fjøsrøktene': ('fjøsrøkt',),
'fjøsrøkter': ('fjøsrøkt',),
'fjøsrøkter': ('fjøsrøkter',),
'fjøsrøktere': ('fjøsrøkter',),
'fjøsrøkteren': ('fjøsrøkter',),
'fjøsrøkterer': ('fjøsrøkter',),
'fjøsrøkterne': ('fjøsrøkter',),
'fjøstid': ('fjøstid',),
'fjøstida': ('fjøstid',),
'fjøstiden': ('fjøstid',),
'fjøstidene': ('fjøstid',),
'fjøstider': ('fjøstid',),
'flabb': ('flabb',),
'flabben': ('flabb',),
'flabbene': ('flabb',),
'flabber': ('flabb',),
'flaga': ('flage',),
'flage': ('flage',),
'flagen': ('flage',),
'flagene': ('flage',),
'flager': ('flage',),
'flagell': ('flagell',),
'flagellen': ('flagell',),
'flagellene': ('flagell',),
'flageller': ('flagell',),
'flagellant': ('flagellant',),
'flagellanten': ('flagellant',),
'flagellantene': ('flagellant',),
'flagellanter': ('flagellant',),
'flagellat': ('flagellat',),
'flagellaten': ('flagellat',),
'flagellatene': ('flagellat',),
'flagellater': ('flagellat',),
'flageolett': ('flageolett',),
'flageoletten': ('flageolett',),
'flageolettene': ('flageolett',),
'flageoletter': ('flageolett',),
'flageolett-tone': ('flageolett-tone',),
'flageolett-tonen': ('flageolett-tone',),
'flageolett-tonene': ('flageolett-tone',),
'flageolett-toner': ('flageolett-tone',),
'flageolettfløyta': ('flageolettfløyte',),
'flageolettfløyte': ('flageolettfløyte',),
'flageolettfløyten': ('flageolettfløyte',),
'flageolettfløytene': ('flageolettfløyte',),
'flageolettfløyter': ('flageolettfløyte',),
'flageolettone': ('flageolettone',),
'flageolettonen': ('flageolettone',),
'flageolettonene': ('flageolettone',),
'flageolettoner': ('flageolettone',),
'flagg': ('flagg',),
'flagga': ('flagg',),
'flaggene': ('flagg',),
'flagget': ('flagg',),
'flaggdag': ('flaggdag',),
'flaggdagen': ('flaggdag',),
'flaggdagene': ('flaggdag',),
'flaggdager': ('flaggdag',),
'flaggdiskriminering': ('flaggdiskriminering',),
'flaggdiskrimineringa': ('flaggdiskriminering',),
'flaggdiskrimineringen': ('flaggdiskriminering',),
'flaggdiskrimineringene': ('flaggdiskriminering',),
'flaggdiskrimineringer': ('flaggdiskriminering',),
'flaggduk': ('flaggduk',),
'flaggduken': ('flaggduk',),
'flaggdukene': ('flaggduk',),
'flaggduker': ('flaggduk',),
'flaggermus': ('flaggermus',),
'flaggermusa': ('flaggermus',),
'flaggermusen': ('flaggermus',),
'flaggermusene': ('flaggermus',),
'flaggermuserma': ('flaggermuserme',),
'flaggermuserme': ('flaggermuserme',),
'flaggermusermene': ('flaggermuserme',),
'flaggermusermer': ('flaggermuserme',),
'flaggermusermet': ('flaggermuserme',),
'flaggkaptein': ('flaggkaptein',),
'flaggkapteinen': ('flaggkaptein',),
'flaggkapteinene': ('flaggkaptein',),
'flaggkapteiner': ('flaggkaptein',),
'flagglina': ('flaggline',),
'flaggline': ('flaggline',),
'flagglinen': ('flaggline',),
'flagglinene': ('flaggline',),
'flaggliner': ('flaggline',),
'flaggskip': ('flaggskip',),
'flaggskipa': ('flaggskip',),
'flaggskipene': ('flaggskip',),
'flaggskipet': ('flaggskip',),
'flaggspett': ('flaggspett',),
'flaggspetten': ('flaggspett',),
'flaggspettene': ('flaggspett',),
'flaggspetter': ('flaggspett',),
'flaggspetta': ('flaggspette',),
'flaggspette': ('flaggspette',),
'flaggspetten': ('flaggspette',),
'flaggspettene': ('flaggspette',),
'flaggspetter': ('flaggspette',),
'flaggstang': ('flaggstang',),
'flaggstanga': ('flaggstang',),
'flaggstangen': ('flaggstang',),
'flaggstengene': ('flaggstang',),
'flaggstenger': ('flaggstang',),
'flaggstikk': ('flaggstikk',),
'flaggstikka': ('flaggstikk',),
'flaggstikkene': ('flaggstikk',),
'flaggstikket': ('flaggstikk',),
'flak': ('flak',),
'flaka': ('flak',),
'flakene': ('flak',),
'flaket': ('flak',),
'flak': ('flak',),
'flaka': ('flak',),
'flakene': ('flak',),
'flaket': ('flak',),
'flak': ('flak',),
'flaka': ('flak',),
'flakene': ('flak',),
'flaket': ('flak',),
'flakong': ('flakong',),
'flakongen': ('flakong',),
'flakongene': ('flakong',),
'flakonger': ('flakong',),
'flaks': ('flaks',),
'flaksen': ('flaks',),
'flaksene': ('flaks',),
'flakser': ('flaks',),
'flaks': ('flaks',),
'flaksa': ('flaks',),
'flaksene': ('flaks',),
'flakset': ('flaks',),
'flamenco': ('flamenco',),
'flamencoen': ('flamenco',),
'flamencoene': ('flamenco',),
'flamencoer': ('flamenco',),
'flamingo': ('flamingo',),
'flamingoen': ('flamingo',),
'flamingoene': ('flamingo',),
'flamingoer': ('flamingo',),
'flamlender': ('flamlender',),
'flamlendere': ('flamlender',),
'flamlenderen': ('flamlender',),
'flamlenderer': ('flamlender',),
'flamlenderne': ('flamlender',),
'flamlending': ('flamlending',),
'flamlendingen': ('flamlending',),
'flamlendingene': ('flamlending',),
'flamlendinger': ('flamlending',),
'flammégarn': ('flammégarn',),
'flammégarna': ('flammégarn',),
'flammégarnene': ('flammégarn',),
'flammégarnet': ('flammégarn',),
'flamme': ('flamme',),
'flammen': ('flamme',),
'flammene': ('flamme',),
'flammer': ('flamme',),
'flammebjerk': ('flammebjerk',),
'flammebjerka': ('flammebjerk',),
'flammebjerken': ('flammebjerk',),
'flammebjerkene': ('flammebjerk',),
'flammebjerker': ('flammebjerk',),
'flammebjørk': ('flammebjørk',),
'flammebjørka': ('flammebjørk',),
'flammebjørken': ('flammebjørk',),
'flammebjørkene': ('flammebjørk',),
'flammebjørker': ('flammebjørk',),
'flammehav': ('flammehav',),
'flammehava': ('flammehav',),
'flammehavene': ('flammehav',),
'flammehavet': ('flammehav',),
'flammekaster': ('flammekaster',),
'flammekastere': ('flammekaster',),
'flammekasteren': ('flammekaster',),
'flammekasterer': ('flammekaster',),
'flammekasterne': ('flammekaster',),
'flammeved': ('flammeved',),
'flammeveden': ('flammeved',),
'flammevedene': ('flammeved',),
'flammeveder': ('flammeved',),
'flamsk': ('flamsk',),
'flamsken': ('flamsk',),
'flamskene': ('flamsk',),
'flamsker': ('flamsk',),
'flamskvev': ('flamskvev',),
'flamskveven': ('flamskvev',),
'flamskvevene': ('flamskvev',),
'flamskvever': ('flamskvev',),
'flana': ('flane',),
'flane': ('flane',),
'flanen': ('flane',),
'flanene': ('flane',),
'flaner': ('flane',),
'flanell': ('flanell',),
'flanellen': ('flanell',),
'flanellene': ('flanell',),
'flaneller': ('flanell',),
'flanellograf': ('flanellograf',),
'flanellografen': ('flanellograf',),
'flanellografene': ('flanellograf',),
'flanellografer': ('flanellograf',),
'flanellsgarn': ('flanellsgarn',),
'flanellsgarna': ('flanellsgarn',),
'flanellsgarnene': ('flanellsgarn',),
'flanellsgarnet': ('flanellsgarn',),
'flanellslaken': ('flanellslaken',),
'flanellslakena': ('flanellslaken',),
'flanellslakenene': ('flanellslaken',),
'flanellslakener': ('flanellslaken',),
'flanellslakenet': ('flanellslaken',),
'flanellsskjorta': ('flanellsskjorte',),
'flanellsskjorte': ('flanellsskjorte',),
'flanellsskjorten': ('flanellsskjorte',),
'flanellsskjortene': ('flanellsskjorte',),
'flanellsskjorter': ('flanellsskjorte',),
'flanelltavla': ('flanelltavle',),
'flanelltavle': ('flanelltavle',),
'flanelltavlen': ('flanelltavle',),
'flanelltavlene': ('flanelltavle',),
'flanelltavler': ('flanelltavle',),
'flaneri': ('flaneri',),
'flaneria': ('flaneri',),
'flaneriene': ('flaneri',),
'flanerier': ('flaneri',),
'flaneriet': ('flaneri',),
'flanke': ('flanke',),
'flanken': ('flanke',),
'flankene': ('flanke',),
'flanker': ('flanke',),
'flankeangrep': ('flankeangrep',),
'flankeangrepa': ('flankeangrep',),
'flankeangrepene': ('flankeangrep',),
'flankeangrepet': ('flankeangrep',),
'flankebevegelse': ('flankebevegelse',),
'flankebevegelsen': ('flankebevegelse',),
'flankebevegelsene': ('flankebevegelse',),
'flankebevegelser': ('flankebevegelse',),
'flanør': ('flanør',),
'flanøren': ('flanør',),
'flanørene': ('flanør',),
'flanører': ('flanør',),
'flaps': ('flaps',),
'flapsene': ('flaps',),
'flash': ('flash',),
'flasha': ('flash',),
'flashen': ('flash',),
'flashene': ('flash',),
'flashet': ('flash',),
'flashback': ('flashback',),
'flashbacken': ('flashback',),
'flashbackene': ('flashback',),
'flashbacks': ('flashback',),
'flask': ('flask',),
'flasken': ('flask',),
'flaskene': ('flask',),
'flasker': ('flask',),
'flaska': ('flaske',),
'flaske': ('flaske',),
'flasken': ('flaske',),
'flaskene': ('flaske',),
'flasker': ('flaske',),
'flaskebarn': ('flaskebarn',),
'flaskebarna': ('flaskebarn',),
'flaskebarnene': ('flaskebarn',),
'flaskebarnet': ('flaskebarn',),
'flaskehals': ('flaskehals',),
'flaskehalsen': ('flaskehals',),
'flaskehalsene': ('flaskehals',),
'flaskehalser': ('flaskehals',),
'flaskepant': ('flaskepant',),
'flaskepanten': ('flaskepant',),
'flaskepantene': ('flaskepant',),
'flaskepanter': ('flaskepant',),
'flaskepost': ('flaskepost',),
'flaskeposten': ('flaskepost',),
'flaskepostene': ('flaskepost',),
'flaskeposter': ('flaskepost',),
'flaskeskip': ('flaskeskip',),
'flaskeskipa': ('flaskeskip',),
'flaskeskipene': ('flaskeskip',),
'flaskeskipet': ('flaskeskip',),
'flaskeskår': ('flaskeskår',),
'flaskeskåra': ('flaskeskår',),
'flaskeskårene': ('flaskeskår',),
'flaskeskåret': ('flaskeskår',),
'flaskeåpner': ('flaskeåpner',),
'flaskeåpnere': ('flaskeåpner',),
'flaskeåpneren': ('flaskeåpner',),
'flaskeåpnerer': ('flaskeåpner',),
'flaskeåpnerne': ('flaskeåpner',),
'flass': ('flass',),
'flassa': ('flass',),
'flassene': ('flass',),
'flasset': ('flass',),
'flat': ('flat',),
'flata': ('flat',),
'flaten': ('flat',),
'flatene': ('flat',),
'flater': ('flat',),
'flat': ('flat',),
'flata': ('flat',),
'flaten': ('flat',),
'flatene': ('flat',),
'flater': ('flat',),
'flatbrød': ('flatbrød',),
'flatbrøda': ('flatbrød',),
'flatbrødene': ('flatbrød',),
'flatbrødet': ('flatbrød',),
'flatbygd': ('flatbygd',),
'flatbygda': ('flatbygd',),
'flatbygden': ('flatbygd',),
'flatbygdene': ('flatbygd',),
'flatbygder': ('flatbygd',),
'flata': ('flate',),
'flate': ('flate',),
'flaten': ('flate',),
'flatene': ('flate',),
'flater': ('flate',),
'flata': ('flate',),
'flate': ('flate',),
'flaten': ('flate',),
'flatene': ('flate',),
'flater': ('flate',),
'flata': ('flate',),
'flate': ('flate',),
'flaten': ('flate',),
'flatene': ('flate',),
'flater': ('flate',),
'flatehogst': ('flatehogst',),
'flatehogsten': ('flatehogst',),
'flatehogstene': ('flatehogst',),
'flatehogster': ('flatehogst',),
'flatehugst': ('flatehugst',),
'flatehugsten': ('flatehugst',),
'flatehugstene': ('flatehugst',),
'flatehugster': ('flatehugst',),
'flateinnhold': ('flateinnhold',),
'flateinnholda': ('flateinnhold',),
'flateinnholdene': ('flateinnhold',),
'flateinnholdet': ('flateinnhold',),
'flatemål': ('flatemål',),
'flatemåla': ('flatemål',),
'flatemålene': ('flatemål',),
'flatemålet': ('flatemål',),
'flatfela': ('flatfele',),
'flatfele': ('flatfele',),
'flatfelen': ('flatfele',),
'flatfelene': ('flatfele',),
'flatfeler': ('flatfele',),
'flathand': ('flathand',),
'flathanda': ('flathand',),
'flathanden': ('flathand',),
'flathendene': ('flathand',),
'flathender': ('flathand',),
'flathendene': ('flathånd',),
'flathender': ('flathånd',),
'flathånd': ('flathånd',),
'flathånda': ('flathånd',),
'flathånden': ('flathånd',),
'flatjern': ('flatjern',),
'flatjerna': ('flatjern',),
'flatjernene': ('flatjern',),
'flatjernet': ('flatjern',),
'flatland': ('flatland',),
'flatlanda': ('flatland',),
'flatlandene': ('flatland',),
'flatlandet': ('flatland',),
'flatlenda': ('flatlende',),
'flatlende': ('flatlende',),
'flatlendene': ('flatlende',),
'flatlender': ('flatlende',),
'flatlendet': ('flatlende',),
'flatlus': ('flatlus',),
'flatlusa': ('flatlus',),
'flatlusen': ('flatlus',),
'flatlusene': ('flatlus',),
'flatmakk': ('flatmakk',),
'flatmakken': ('flatmakk',),
'flatmakkene': ('flatmakk',),
'flatmakker': ('flatmakk',),
'flatmark': ('flatmark',),
'flatmarka': ('flatmark',),
'flatmarken': ('flatmark',),
'flatmarkene': ('flatmark',),
'flatmarker': ('flatmark',),
'flatmark': ('flatmark',),
'flatmarka': ('flatmark',),
'flatmarken': ('flatmark',),
'flatmarkene': ('flatmark',),
'flatmarker': ('flatmark',),
'flatorm': ('flatorm',),
'flatormen': ('flatorm',),
'flatormene': ('flatorm',),
'flatormer': ('flatorm',),
'flatseng': ('flatseng',),
'flatsenga': ('flatseng',),
'flatsengen': ('flatseng',),
'flatsengene': ('flatseng',),
'flatsenger': ('flatseng',),
'flatsida': ('flatside',),
'flatside': ('flatside',),
'flatsiden': ('flatside',),
'flatsidene': ('flatside',),
'flatsider': ('flatside',),
'flatstål': ('flatstål',),
'flatståla': ('flatstål',),
'flatstålene': ('flatstål',),
'flatstålet': ('flatstål',),
'flattallerken': ('flattallerken',),
'flattallerkenen': ('flattallerken',),
'flattallerkenene': ('flattallerken',),
'flattallerkener': ('flattallerken',),
'flattrykk': ('flattrykk',),
'flattrykka': ('flattrykk',),
'flattrykkene': ('flattrykk',),
'flattrykket': ('flattrykk',),
'flause': ('flause',),
'flausen': ('flause',),
'flausene': ('flause',),
'flauser': ('flause',),
'flegma': ('flegma',),
'flegmaa': ('flegma',),
'flegmaene': ('flegma',),
'flegmaet': ('flegma',),
'flegmatiker': ('flegmatiker',),
'flegmatikere': ('flegmatiker',),
'flegmatikeren': ('flegmatiker',),
'flegmatikerer': ('flegmatiker',),
'flegmatikerne': ('flegmatiker',),
'fleip': ('fleip',),
'fleipen': ('fleip',),
'fleipene': ('fleip',),
'fleiper': ('fleip',),
'fleip': ('fleip',),
'fleipa': ('fleip',),
'fleipene': ('fleip',),
'fleipet': ('fleip',),
'fleis': ('fleis',),
'fleisen': ('fleis',),
'fleisene': ('fleis',),
'fleiser': ('fleis',),
'flekk': ('flekk',),
'flekken': ('flekk',),
'flekkene': ('flekk',),
'flekker': ('flekk',),
'flekkfeber': ('flekkfeber',),
'flekkfebere': ('flekkfeber',),
'flekkfeberen': ('flekkfeber',),
'flekkfeberne': ('flekkfeber',),
'flekkfebre': ('flekkfeber',),
'flekkfebrene': ('flekkfeber',),
'flekkfebrer': ('flekkfeber',),
'flekkfjerner': ('flekkfjerner',),
'flekkfjernere': ('flekkfjerner',),
'flekkfjerneren': ('flekkfjerner',),
'flekkfjernerer': ('flekkfjerner',),
'flekkfjernerne': ('flekkfjerner',),
'flekktyfus': ('flekktyfus',),
'flekktyfusen': ('flekktyfus',),
'flekktyfusene': ('flekktyfus',),
'flekktyfuser': ('flekktyfus',),
'fleksibilitet': ('fleksibilitet',),
'fleksibiliteten': ('fleksibilitet',),
'fleksibilitetene': ('fleksibilitet',),
'fleksibiliteter': ('fleksibilitet',),
'fleksitid': ('fleksitid',),
'fleksitida': ('fleksitid',),
'fleksitiden': ('fleksitid',),
'fleksitidene': ('fleksitid',),
'fleksitider': ('fleksitid',),
'fleksjon': ('fleksjon',),
'fleksjonen': ('fleksjon',),
'fleksjonene': ('fleksjon',),
'fleksjoner': ('fleksjon',),
'fleng': ('fleng',),
'flenga': ('flenge',),
'flenge': ('flenge',),
'flengen': ('flenge',),
'flengene': ('flenge',),
'flenger': ('flenge',),
'flens': ('flens',),
'flensen': ('flens',),
'flensene': ('flens',),
'flenser': ('flens',),
'flerbruksplan': ('flerbruksplan',),
'flerbruksplanen': ('flerbruksplan',),
'flerbruksplanene': ('flerbruksplan',),
'flerbruksplaner': ('flerbruksplan',),
'flergenerasjonsbolig': ('flergenerasjonsbolig',),
'flergenerasjonsboligen': ('flergenerasjonsbolig',),
'flergenerasjonsboligene': ('flergenerasjonsbolig',),
'flergenerasjonsboliger': ('flergenerasjonsbolig',),
'flergifta': ('flergifte',),
'flergifte': ('flergifte',),
'flergiftene': ('flergifte',),
'flergifter': ('flergifte',),
'flergiftet': ('flergifte',),
'flerguderi': ('flerguderi',),
'flerguderia': ('flerguderi',),
'flerguderiene': ('flerguderi',),
'flerguderiet': ('flerguderi',),
'flerkoneri': ('flerkoneri',),
'flerkoneria': ('flerkoneri',),
'flerkoneriene': ('flerkoneri',),
'flerkonerier': ('flerkoneri',),
'flerkoneriet': ('flerkoneri',),
'flermanneri': ('flermanneri',),
'flermanneria': ('flermanneri',),
'flermanneriene': ('flermanneri',),
'flermannerier': ('flermanneri',),
'flermanneriet': ('flermanneri',),
'flerpartisystem': ('flerpartisystem',),
'flerpartisystema': ('flerpartisystem',),
'flerpartisystemene': ('flerpartisystem',),
'flerpartisystemer': ('flerpartisystem',),
'flerpartisystemet': ('flerpartisystem',),
'flerplanskryss': ('flerplanskryss',),
'flerplanskryssa': ('flerplanskryss',),
'flerplanskryssene': ('flerplanskryss',),
'flerplanskrysset': ('flerplanskryss',),
'flerra': ('flerre',),
'flerre': ('flerre',),
'flerren': ('flerre',),
'flerrene': ('flerre',),
'flerrer': ('flerre',),
'flerreisekort': ('flerreisekort',),
'flerreisekorta': ('flerreisekort',),
'flerreisekortene': ('flerreisekort',),
'flerreisekortet': ('flerreisekort',),
'flertal': ('flertal',),
'flertala': ('flertal',),
'flertalene': ('flertal',),
'flertalet': ('flertal',),
'flertall': ('flertall',),
'flertalla': ('flertall',),
'flertallene': ('flertall',),
'flertallet': ('flertall',),
'flertallsform': ('flertallsform',),
'flertallsforma': ('flertallsform',),
'flertallsformen': ('flertallsform',),
'flertallsformene': ('flertallsform',),
'flertallsformer': ('flertallsform',),
'flertallsregjering': ('flertallsregjering',),
'flertallsregjeringa': ('flertallsregjering',),
'flertallsregjeringen': ('flertallsregjering',),
'flertallsregjeringene': ('flertallsregjering',),
'flertallsregjeringer': ('flertallsregjering',),
'flertallsvalg': ('flertallsvalg',),
'flertallsvalga': ('flertallsvalg',),
'flertallsvalgene': ('flertallsvalg',),
'flertallsvalget': ('flertallsvalg',),
'flertalsform': ('flertalsform',),
'flertalsforma': ('flertalsform',),
'flertalsformen': ('flertalsform',),
'flertalsformene': ('flertalsform',),
'flertalsformer': ('flertalsform',),
'flertalsregjering': ('flertalsregjering',),
'flertalsregjeringa': ('flertalsregjering',),
'flertalsregjeringen': ('flertalsregjering',),
'flertalsregjeringene': ('flertalsregjering',),
'flertalsregjeringer': ('flertalsregjering',),
'flertalsvalg': ('flertalsvalg',),
'flertalsvalga': ('flertalsvalg',),
'flertalsvalgene': ('flertalsvalg',),
'flertalsvalget': ('flertalsvalg',),
'flertrinnsrakett': ('flertrinnsrakett',),
'flertrinnsraketten': ('flertrinnsrakett',),
'flertrinnsrakettene': ('flertrinnsrakett',),
'flertrinnsraketter': ('flertrinnsrakett',),
'fles': ('fles',),
'flesa': ('fles',),
'flesen': ('fles',),
'flesene': ('fles',),
'fleser': ('fles',),
'flesk': ('flesk',),
'fleska': ('flesk',),
'fleskene': ('flesk',),
'flesket': ('flesk',),
'fleskebit': ('fleskebit',),
'fleskebiten': ('fleskebit',),
'fleskebitene': ('fleskebit',),
'fleskebiter': ('fleskebit',),
'fleskefabrikk': ('fleskefabrikk',),
'fleskefabrikken': ('fleskefabrikk',),
'fleskefabrikkene': ('fleskefabrikk',),
'fleskefabrikker': ('fleskefabrikk',),
'fleskepannekaka': ('fleskepannekake',),
'fleskepannekake': ('fleskepannekake',),
'fleskepannekaken': ('fleskepannekake',),
'fleskepannekakene': ('fleskepannekake',),
'fleskepannekaker': ('fleskepannekake',),
'fleskepølsa': ('fleskepølse',),
'fleskepølse': ('fleskepølse',),
'fleskepølsen': ('fleskepølse',),
'fleskepølsene': ('fleskepølse',),
'fleskepølser': ('fleskepølse',),
'fleskesvor': ('fleskesvor',),
'fleskesvoren': ('fleskesvor',),
'fleskesvorene': ('fleskesvor',),
'fleskesvorer': ('fleskesvor',),
'flestepart': ('flestepart',),
'flesteparten': ('flestepart',),
'flestepartene': ('flestepart',),
'flesteparter': ('flestepart',),
'fletning': ('fletning',),
'fletninga': ('fletning',),
'fletningen': ('fletning',),
'fletningene': ('fletning',),
'fletninger': ('fletning',),
'fletta': ('flette',),
'flette': ('flette',),
'fletten': ('flette',),
'flettene': ('flette',),
'fletter': ('flette',),
'fletteband': ('fletteband',),
'flettebanda': ('fletteband',),
'flettebandene': ('fletteband',),
'flettebandet': ('fletteband',),
'flettebånd': ('flettebånd',),
'flettebånda': ('flettebånd',),
'flettebåndene': ('flettebånd',),
'flettebåndet': ('flettebånd',),
'fletting': ('fletting',),
'flettinga': ('fletting',),
'flettingen': ('fletting',),
'flettingene': ('fletting',),
'flettinger': ('fletting',),
'flettsko': ('flettsko',),
'flettskoa': ('flettsko',),
'flettskoen': ('flettsko',),
'flettskoene': ('flettsko',),
'flettskor': ('flettsko',),
'flettskorne': ('flettsko',),
'flettverk': ('flettverk',),
'flettverka': ('flettverk',),
'flettverkene': ('flettverk',),
'flettverker': ('flettverk',),
'flettverket': ('flettverk',),
'flettverksgjerda': ('flettverksgjerde',),
'flettverksgjerde': ('flettverksgjerde',),
'flettverksgjerdene': ('flettverksgjerde',),
'flettverksgjerder': ('flettverksgjerde',),
'flettverksgjerdet': ('flettverksgjerde',),
'flid': ('flid',),
'fliden': ('flid',),
'flidene': ('flid',),
'flider': ('flid',),
'flik': ('flik',),
'fliken': ('flik',),
'flikene': ('flik',),
'fliker': ('flik',),
'flikk': ('flikk',),
'flikken': ('flikk',),
'flikkene': ('flikk',),
'flikker': ('flikk',),
'flikkflakk': ('flikkflakk',),
'flikkflakka': ('flikkflakk',),
'flikkflakken': ('flikkflakk',),
'flikkflakkene': ('flikkflakk',),
'flikkflakker': ('flikkflakk',),
'flikkflakket': ('flikkflakk',),
'flimmer': ('flimmer',),
'flimmera': ('flimmer',),
'flimmerene': ('flimmer',),
'flimmeret': ('flimmer',),
'flimra': ('flimmer',),
'flimre': ('flimmer',),
'flimrene': ('flimmer',),
'flimmerhår': ('flimmerhår',),
'flimmerhåra': ('flimmerhår',),
'flimmerhårene': ('flimmerhår',),
'flimmerhåret': ('flimmerhår',),
'flint': ('flint',),
'flinten': ('flint',),
'flintene': ('flint',),
'flinter': ('flint',),
'flintestein': ('flintestein',),
'flintesteinen': ('flintestein',),
'flintesteinene': ('flintestein',),
'flintesteiner': ('flintestein',),
'flintporselen': ('flintporselen',),
'flintporselena': ('flintporselen',),
'flintporselenene': ('flintporselen',),
'flintporselener': ('flintporselen',),
'flintporselenet': ('flintporselen',),
'flintstein': ('flintstein',),
'flintsteinen': ('flintstein',),
'flintsteinene': ('flintstein',),
'flintsteiner': ('flintstein',),
'flintøks': ('flintøks',),
'flintøksa': ('flintøks',),
'flintøksen': ('flintøks',),
'flintøksene': ('flintøks',),
'flintøkser': ('flintøks',),
'flipp': ('flipp',),
'flippen': ('flipp',),
'flippene': ('flipp',),
'flipper': ('flipp',),
'flipp': ('flipp',),
'flippa': ('flipp',),
'flippene': ('flipp',),
'flippet': ('flipp',),
'flipperspell': ('flipperspell',),
'flipperspella': ('flipperspell',),
'flipperspellene': ('flipperspell',),
'flipperspellet': ('flipperspell',),
'flipperspill': ('flipperspill',),
'flipperspilla': ('flipperspill',),
'flipperspillene': ('flipperspill',),
'flipperspillet': ('flipperspill',),
'flippover': ('flippover',),
'flippovere': ('flippover',),
'flippoveren': ('flippover',),
'flippoverer': ('flippover',),
'flippoverne': ('flippover',),
'flir': ('flir',),
'flira': ('flir',),
'fliren': ('flir',),
'flirene': ('flir',),
'fliret': ('flir',),
'flire': ('flire',),
'fliren': ('flire',),
'flirene': ('flire',),
'flirer': ('flire',),
'flis': ('flis',),
'flisa': ('flis',),
'flisen': ('flis',),
'flisene': ('flis',),
'fliser': ('flis',),
'flis': ('flis',),
'flisa': ('flis',),
'flisen': ('flis',),
'flisene': ('flis',),
'fliser': ('flis',),
'flise': ('flise',),
'flisen': ('flise',),
'flisene': ('flise',),
'fliser': ('flise',),
'flisemosaikk': ('flisemosaikk',),
'flisemosaikken': ('flisemosaikk',),
'flisemosaikkene': ('flisemosaikk',),
'flisemosaikker': ('flisemosaikk',),
'flisespikker': ('flisespikker',),
'flisespikkere': ('flisespikker',),
'flisespikkeren': ('flisespikker',),
'flisespikkerer': ('flisespikker',),
'flisespikkerne': ('flisespikker',),
'flisespikkeri': ('flisespikkeri',),
'flisespikkeria': ('flisespikkeri',),
'flisespikkeriene': ('flisespikkeri',),
'flisespikkerier': ('flisespikkeri',),
'flisespikkeriet': ('flisespikkeri',),
'flismosaikk': ('flismosaikk',),
'flismosaikken': ('flismosaikk',),
'flismosaikkene': ('flismosaikk',),
'flismosaikker': ('flismosaikk',),
'flitra': ('flitter',),
'flitre': ('flitter',),
'flitrene': ('flitter',),
'flitret': ('flitter',),
'flitter': ('flitter',),
'flitteret': ('flitter',),
'flitterstas': ('flitterstas',),
'flitterstasen': ('flitterstas',),
'flitterstasene': ('flitterstas',),
'flitterstaser': ('flitterstas',),
'flittiglise': ('flittiglise',),
'flittiglisen': ('flittiglise',),
'flittiglisene': ('flittiglise',),
'flittigliser': ('flittiglise',),
'flod': ('flod',),
'floden': ('flod',),
'flodene': ('flod',),
'floder': ('flod',),
'flod': ('flod',),
'floda': ('flod',),
'floden': ('flod',),
'flodene': ('flod',),
'floder': ('flod',),
'flodbølga': ('flodbølge',),
'flodbølge': ('flodbølge',),
'flodbølgen': ('flodbølge',),
'flodbølgene': ('flodbølge',),
'flodbølger': ('flodbølge',),
'flodbølgja': ('flodbølgje',),
'flodbølgje': ('flodbølgje',),
'flodbølgjen': ('flodbølgje',),
'flodbølgjene': ('flodbølgje',),
'flodbølgjer': ('flodbølgje',),
'flodhest': ('flodhest',),
'flodhesten': ('flodhest',),
'flodhestene': ('flodhest',),
'flodhester': ('flodhest',),
'flodkreps': ('flodkreps',),
'flodkrepsen': ('flodkreps',),
'flodkrepsene': ('flodkreps',),
'flodkrepser': ('flodkreps',),
'flog': ('flog',),
'floga': ('flog',),
'flogene': ('flog',),
'floget': ('flog',),
'floghavre': ('floghavre',),
'floghavren': ('floghavre',),
'floghavrene': ('floghavre',),
'floghavrer': ('floghavre',),
'floing': ('floing',),
'floingen': ('floing',),
'floingene': ('floing',),
'floinger': ('floing',),
'floke': ('floke',),
'floken': ('floke',),
'flokene': ('floke',),
'floker': ('floke',),
'flokk': ('flokk',),
'flokken': ('flokk',),
'flokkene': ('flokk',),
'flokker': ('flokk',),
'flokkdyr': ('flokkdyr',),
'flokkdyra': ('flokkdyr',),
'flokkdyrene': ('flokkdyr',),
'flokkdyret': ('flokkdyr',),
'flokketal': ('flokketal',),
'flokketala': ('flokketal',),
'flokketalene': ('flokketal',),
'flokketalet': ('flokketal',),
'flokketall': ('flokketall',),
'flokketalla': ('flokketall',),
'flokketallene': ('flokketall',),
'flokketallet': ('flokketall',),
'flokkinstinkt': ('flokkinstinkt',),
'flokkinstinkta': ('flokkinstinkt',),
'flokkinstinktene': ('flokkinstinkt',),
'flokkinstinkter': ('flokkinstinkt',),
'flokkinstinktet': ('flokkinstinkt',),
'floks': ('floks',),
'floksen': ('floks',),
'floksene': ('floks',),
'flokser': ('floks',),
'floksa': ('flokse',),
'flokse': ('flokse',),
'floksen': ('flokse',),
'floksene': ('flokse',),
'flokser': ('flokse',),
'flom': ('flom',),
'flommen': ('flom',),
'flommene': ('flom',),
'flommer': ('flom',),
'flomfare': ('flomfare',),
'flomfaren': ('flomfare',),
'flomfarene': ('flomfare',),
'flomfarer': ('flomfare',),
'flomkatastrofa': ('flomkatastrofe',),
'flomkatastrofe': ('flomkatastrofe',),
'flomkatastrofen': ('flomkatastrofe',),
'flomkatastrofene': ('flomkatastrofe',),
'flomkatastrofer': ('flomkatastrofe',),
'flomlys': ('flomlys',),
'flomlysa': ('flomlys',),
'flomlysene': ('flomlys',),
'flomlyset': ('flomlys',),
'flomskade': ('flomskade',),
'flomskaden': ('flomskade',),
'flomskadene': ('flomskade',),
'flomskader': ('flomskade',),
'flomål': ('flomål',),
'flomåla': ('flomål',),
'flomålene': ('flomål',),
'flomålet': ('flomål',),
'flopp': ('flopp',),
'floppen': ('flopp',),
'floppene': ('flopp',),
'flopper': ('flopp',),
'floppstil': ('floppstil',),
'floppstilen': ('floppstil',),
'floppstilene': ('floppstil',),
'floppstiler': ('floppstil',),
'flora': ('flora',),
'floraen': ('flora',),
'floraene': ('flora',),
'floraer': ('flora',),
'floragram': ('floragram',),
'floragramma': ('floragram',),
'floragrammene': ('floragram',),
'floragrammer': ('floragram',),
'floragrammet': ('floragram',),
'florentiner': ('florentiner',),
'florentinere': ('florentiner',),
'florentineren': ('florentiner',),
'florentinerer': ('florentiner',),
'florentinerne': ('florentiner',),
'florett': ('florett',),
'floretten': ('florett',),
'florettene': ('florett',),
'floretter': ('florett',),
'florin': ('florin',),
'florinen': ('florin',),
'florinene': ('florin',),
'floriner': ('florin',),
'flormel': ('flormel',),
'flormela': ('flormel',),
'flormelene': ('flormel',),
'flormelet': ('flormel',),
'flormelis': ('flormelis',),
'flormelisen': ('flormelis',),
'flormelisene': ('flormelis',),
'flormeliser': ('flormelis',),
'flormjøl': ('flormjøl',),
'flormjøla': ('flormjøl',),
'flormjølene': ('flormjøl',),
'flormjølet': ('flormjøl',),
'floskel': ('floskel',),
'floskelen': ('floskel',),
'flosklene': ('floskel',),
'floskler': ('floskel',),
'floss': ('floss',),
'flossen': ('floss',),
'flossene': ('floss',),
'flosser': ('floss',),
'floss': ('floss',),
'flossen': ('floss',),
'flossene': ('floss',),
'flosser': ('floss',),
'flossbommesi': ('flossbommesi',),
'flossbommesien': ('flossbommesi',),
'flossbommesiene': ('flossbommesi',),
'flossbommesier': ('flossbommesi',),
'flosshatt': ('flosshatt',),
'flosshatten': ('flosshatt',),
'flosshattene': ('flosshatt',),
'flosshatter': ('flosshatt',),
'flotasjon': ('flotasjon',),
'flotasjonen': ('flotasjon',),
'flotasjonene': ('flotasjon',),
'flotasjoner': ('flotasjon',),
'flotell': ('flotell',),
'flotella': ('flotell',),
'flotellene': ('flotell',),
'floteller': ('flotell',),
'flotellet': ('flotell',),
'flotilje': ('flotilje',),
'flotiljen': ('flotilje',),
'flotiljene': ('flotilje',),
'flotiljer': ('flotilje',),
'flott': ('flott',),
'flotta': ('flott',),
'flottene': ('flott',),
'flottet': ('flott',),
'flott': ('flott',),
'flotta': ('flott',),
'flotten': ('flott',),
'flottene': ('flott',),
'flotter': ('flott',),
'flottenfeier': ('flottenfeier',),
'flottenfeiere': ('flottenfeier',),
'flottenfeieren': ('flottenfeier',),
'flottenfeierer': ('flottenfeier',),
'flottenfeierne': ('flottenfeier',),
'flottenheimer': ('flottenheimer',),
'flottenheimere': ('flottenheimer',),
'flottenheimeren': ('flottenheimer',),
'flottenheimerer': ('flottenheimer',),
'flottenheimerne': ('flottenheimer',),
'flottør': ('flottør',),
'flottøren': ('flottør',),
'flottørene': ('flottør',),
'flottører': ('flottør',),
'flottørfly': ('flottørfly',),
'flottørflya': ('flottørfly',),
'flottørflyene': ('flottørfly',),
'flottørflyet': ('flottørfly',),
'flu': ('flu',),
'flua': ('flu',),
'fluen': ('flu',),
'fluene': ('flu',),
'fluer': ('flu',),
'flua': ('flue',),
'flue': ('flue',),
'fluen': ('flue',),
'fluene': ('flue',),
'fluer': ('flue',),
'fluefanger': ('fluefanger',),
'fluefangere': ('fluefanger',),
'fluefangeren': ('fluefanger',),
'fluefangerer': ('fluefanger',),
'fluefangerne': ('fluefanger',),
'fluefiska': ('fluefiske',),
'fluefiske': ('fluefiske',),
'fluefiskene': ('fluefiske',),
'fluefisker': ('fluefiske',),
'fluefisket': ('fluefiske',),
'fluepapir': ('fluepapir',),
'fluepapira': ('fluepapir',),
'fluepapirene': ('fluepapir',),
'fluepapirer': ('fluepapir',),
'fluepapiret': ('fluepapir',),
'fluesmekka': ('fluesmekke',),
'fluesmekke': ('fluesmekke',),
'fluesmekken': ('fluesmekke',),
'fluesmekkene': ('fluesmekke',),
'fluesmekker': ('fluesmekke',),
'fluesmekker': ('fluesmekker',),
'fluesmekkere': ('fluesmekker',),
'fluesmekkeren': ('fluesmekker',),
'fluesmekkerer': ('fluesmekker',),
'fluesmekkerne': ('fluesmekker',),
'fluesnapper': ('fluesnapper',),
'fluesnappere': ('fluesnapper',),
'fluesnapperen': ('fluesnapper',),
'fluesnapperer': ('fluesnapper',),
'fluesnapperne': ('fluesnapper',),
'fluesopp': ('fluesopp',),
'fluesoppen': ('fluesopp',),
'fluesoppene': ('fluesopp',),
'fluesopper': ('fluesopp',),
'fluesverm': ('fluesverm',),
'fluesvermen': ('fluesverm',),
'fluesvermene': ('fluesverm',),
'fluesvermer': ('fluesverm',),
'fluevekt': ('fluevekt',),
'fluevekta': ('fluevekt',),
'fluevekten': ('fluevekt',),
'fluevektene': ('fluevekt',),
'fluevekter': ('fluevekt',),
'fluevekter': ('fluevekter',),
'fluevektere': ('fluevekter',),
'fluevekteren': ('fluevekter',),
'fluevekterer': ('fluevekter',),
'fluevekterne': ('fluevekter',),
'fluevektklassa': ('fluevektklasse',),
'fluevektklasse': ('fluevektklasse',),
'fluevektklassen': ('fluevektklasse',),
'fluevektklassene': ('fluevektklasse',),
'fluevektklasser': ('fluevektklasse',),
'fluevektsklassa': ('fluevektsklasse',),
'fluevektsklasse': ('fluevektsklasse',),
'fluevektsklassen': ('fluevektsklasse',),
'fluevektsklassene': ('fluevektsklasse',),
'fluevektsklasser': ('fluevektsklasse',),
'fluid': ('fluid',),
'fluida': ('fluid',),
'fluidene': ('fluid',),
'fluider': ('fluid',),
'fluidet': ('fluid',),
'fluiditet': ('fluiditet',),
'fluiditeten': ('fluiditet',),
'fluiditetene': ('fluiditet',),
'fluiditeter': ('fluiditet',),
'fluida': ('fluidum',),
'fluidaene': ('fluidum',),
'fluidum': ('fluidum',),
'fluiduma': ('fluidum',),
'fluidumene': ('fluidum',),
'fluidumer': ('fluidum',),
'fluidumet': ('fluidum',),
'fluks': ('fluks',),
'fluksen': ('fluks',),
'fluksene': ('fluks',),
'flukser': ('fluks',),
'fluksmeter': ('fluksmeter',),
'fluksmeteret': ('fluksmeter',),
'fluksmetra': ('fluksmeter',),
'fluksmetre': ('fluksmeter',),
'fluksmetrene': ('fluksmeter',),
'fluksmetret': ('fluksmeter',),
'flukt': ('flukt',),
'flukta': ('flukt',),
'flukten': ('flukt',),
'fluktene': ('flukt',),
'flukter': ('flukt',),
'fluktdyr': ('fluktdyr',),
'fluktdyra': ('fluktdyr',),
'fluktdyrene': ('fluktdyr',),
'fluktdyret': ('fluktdyr',),
'fluktforsøk': ('fluktforsøk',),
'fluktforsøka': ('fluktforsøk',),
'fluktforsøkene': ('fluktforsøk',),
'fluktforsøket': ('fluktforsøk',),
'fluktstol': ('fluktstol',),
'fluktstolen': ('fluktstol',),
'fluktstolene': ('fluktstol',),
'fluktstoler': ('fluktstol',),
'fluktuasjon': ('fluktuasjon',),
'fluktuasjonen': ('fluktuasjon',),
'fluktuasjonene': ('fluktuasjon',),
'fluktuasjoner': ('fluktuasjon',),
'fluor': ('fluor',),
'fluora': ('fluor',),
'fluoren': ('fluor',),
'fluorene': ('fluor',),
'fluorer': ('fluor',),
'fluoret': ('fluor',),
'fluorescens': ('fluorescens',),
'fluorescensen': ('fluorescens',),
'fluorescensene': ('fluorescens',),
'fluorescenser': ('fluorescens',),
'fluorid': ('fluorid',),
'fluorida': ('fluorid',),
'fluoridene': ('fluorid',),
'fluorider': ('fluorid',),
'fluoridet': ('fluorid',),
'fluortablett': ('fluortablett',),
'fluortabletten': ('fluortablett',),
'fluortablettene': ('fluortablett',),
'fluortabletter': ('fluortablett',),
'fluortannkrem': ('fluortannkrem',),
'fluortannkremen': ('fluortannkrem',),
'fluortannkremene': ('fluortannkrem',),
'fluortannkremer': ('fluortannkrem',),
'flusk': ('flusk',),
'flusken': ('flusk',),
'fluskene': ('flusk',),
'flusker': ('flusk',),
'fluss': ('fluss',),
'flussen': ('fluss',),
'flussene': ('fluss',),
'flusser': ('fluss',),
'fluss-syra': ('fluss-syre',),
'fluss-syre': ('fluss-syre',),
'fluss-syren': ('fluss-syre',),
'fluss-syrene': ('fluss-syre',),
'fluss-syrer': ('fluss-syre',),
'flussmiddel': ('flussmiddel',),
'flussmiddelet': ('flussmiddel',),
'flussmidla': ('flussmiddel',),
'flussmidlene': ('flussmiddel',),
'flussmidler': ('flussmiddel',),
'flussmidlet': ('flussmiddel',),
'flussyra': ('flussyre',),
'flussyre': ('flussyre',),
'flussyren': ('flussyre',),
'flussyrene': ('flussyre',),
'flussyrer': ('flussyre',),
'fly': ('fly',),
'flya': ('fly',),
'flyene': ('fly',),
'flyet': ('fly',),
'fly': ('fly',),
'flya': ('fly',),
'flyene': ('fly',),
'flyet': ('fly',),
'fly': ('fly',),
'flya': ('fly',),
'flyen': ('fly',),
'flyene': ('fly',),
'flyer': ('fly',),
'flyalarm': ('flyalarm',),
'flyalarmen': ('flyalarm',),
'flyalarmene': ('flyalarm',),
'flyalarmer': ('flyalarm',),
'flyangrep': ('flyangrep',),
'flyangrepa': ('flyangrep',),
'flyangrepene': ('flyangrep',),
'flyangrepet': ('flyangrep',),
'flybensin': ('flybensin',),
'flybensinen': ('flybensin',),
'flybensinene': ('flybensin',),
'flybensiner': ('flybensin',),
'flybrett': ('flybrett',),
'flybretta': ('flybrett',),
'flybrettene': ('flybrett',),
'flybretter': ('flybrett',),
'flybrettet': ('flybrett',),
'flybuss': ('flybuss',),
'flybussen': ('flybuss',),
'flybussene': ('flybuss',),
'flybusser': ('flybuss',),
'flybussterminal': ('flybussterminal',),
'flybussterminalen': ('flybussterminal',),
'flybussterminalene': ('flybussterminal',),
'flybussterminaler': ('flybussterminal',),
'flybåt': ('flybåt',),
'flybåten': ('flybåt',),
'flybåtene': ('flybåt',),
'flybåter': ('flybåt',),
'flyer': ('flyer',),
'flyere': ('flyer',),
'flyeren': ('flyer',),
'flyerer': ('flyer',),
'flyerne': ('flyer',),
'flyfilla': ('flyfille',),
'flyfille': ('flyfille',),
'flyfillen': ('flyfille',),
'flyfillene': ('flyfille',),
'flyfiller': ('flyfille',),
'flyforbindelse': ('flyforbindelse',),
'flyforbindelsen': ('flyforbindelse',),
'flyforbindelsene': ('flyforbindelse',),
'flyforbindelser': ('flyforbindelse',),
'flyfoto': ('flyfoto',),
'flyfotoa': ('flyfoto',),
'flyfotoene': ('flyfoto',),
'flyfotoer': ('flyfoto',),
'flyfotoet': ('flyfoto',),
'flyfotografi': ('flyfotografi',),
'flyfotografia': ('flyfotografi',),
'flyfotografiene': ('flyfotografi',),
'flyfotografier': ('flyfotografi',),
'flyfotografiet': ('flyfotografi',),
'flygeblad': ('flygeblad',),
'flygeblada': ('flygeblad',),
'flygebladene': ('flygeblad',),
'flygeblader': ('flygeblad',),
'flygebladet': ('flygeblad',),
'flygefisk': ('flygefisk',),
'flygefisken': ('flygefisk',),
'flygefiskene': ('flygefisk',),
'flygefisker': ('flygefisk',),
'flygehud': ('flygehud',),
'flygehuda': ('flygehud',),
'flygehuden': ('flygehud',),
'flygehudene': ('flygehud',),
'flygehuder': ('flygehud',),
'flygel': ('flygel',),
'flygelen': ('flygel',),
'flyglene': ('flygel',),
'flygler': ('flygel',),
'flygel': ('flygel',),
'flygelet': ('flygel',),
'flygla': ('flygel',),
'flyglene': ('flygel',),
'flygler': ('flygel',),
'flyglet': ('flygel',),
'flygeleder': ('flygeleder',),
'flygeledere': ('flygeleder',),
'flygelederen': ('flygeleder',),
'flygelederer': ('flygeleder',),
'flygelederne': ('flygeleder',),
'flygemaskin': ('flygemaskin',),
'flygemaskina': ('flygemaskin',),
'flygemaskinen': ('flygemaskin',),
'flygemaskinene': ('flygemaskin',),
'flygemaskiner': ('flygemaskin',),
'flygende tallerken': ('flygende tallerken',),
'flygende tallerkenen': ('flygende tallerken',),
'flygende tallerkenene': ('flygende tallerken',),
'flygende tallerkener': ('flygende tallerken',),
'flyger': ('flyger',),
'flygere': ('flyger',),
'flygeren': ('flyger',),
'flygerer': ('flyger',),
'flygerne': ('flyger',),
'flygesand': ('flygesand',),
'flygesanden': ('flygesand',),
'flygesandene': ('flygesand',),
'flygesander': ('flygesand',),
'flyging': ('flyging',),
'flyginga': ('flyging',),
'flygingen': ('flyging',),
'flygingene': ('flyging',),
'flyginger': ('flyging',),
'flyging': ('flyging',),
'flyginga': ('flyging',),
'flygingen': ('flyging',),
'flygingene': ('flyging',),
'flyginger': ('flyging',),
'flyhavari': ('flyhavari',),
'flyhavaria': ('flyhavari',),
'flyhavariene': ('flyhavari',),
'flyhavarier': ('flyhavari',),
'flyhavariet': ('flyhavari',),
'flyhøgd': ('flyhøgd',),
'flyhøgda': ('flyhøgd',),
'flyhøgdene': ('flyhøgd',),
'flyhøgder': ('flyhøgd',),
'flyhøyde': ('flyhøyde',),
'flyhøyden': ('flyhøyde',),
'flyhøydene': ('flyhøyde',),
'flyhøyder': ('flyhøyde',),
'flying': ('flying',),
'flyinga': ('flying',),
'flyingen': ('flying',),
'flyingene': ('flying',),
'flyinger': ('flying',),
'flying': ('flying',),
'flyinga': ('flying',),
'flyingen': ('flying',),
'flyingene': ('flying',),
'flyinger': ('flying',),
'flying start': ('flying start',),
'flyinstruks': ('flyinstruks',),
'flyinstruksen': ('flyinstruks',),
'flyinstruksene': ('flyinstruks',),
'flyinstrukser': ('flyinstruks',),
'flykaprer': ('flykaprer',),
'flykaprere': ('flykaprer',),
'flykapreren': ('flykaprer',),
'flykaprerer': ('flykaprer',),
'flykaprerne': ('flykaprer',),
'flykapring': ('flykapring',),
'flykapringa': ('flykapring',),
'flykapringen': ('flykapring',),
'flykapringene': ('flykapring',),
'flykapringer': ('flykapring',),
'flykorridor': ('flykorridor',),
'flykorridoren': ('flykorridor',),
'flykorridorene': ('flykorridor',),
'flykorridorer': ('flykorridor',),
'flykrasj': ('flykrasj',),
'flykrasja': ('flykrasj',),
'flykrasjen': ('flykrasj',),
'flykrasjene': ('flykrasj',),
'flykrasjet': ('flykrasj',),
'flykropp': ('flykropp',),
'flykroppen': ('flykropp',),
'flykroppene': ('flykropp',),
'flykropper': ('flykropp',),
'flyktning': ('flyktning',),
'flyktningen': ('flyktning',),
'flyktningene': ('flyktning',),
'flyktninger': ('flyktning',),
'flyktninghjelp': ('flyktninghjelp',),
'flyktninghjelpa': ('flyktninghjelp',),
'flyktninghjelpen': ('flyktninghjelp',),
'flyktninghjelpene': ('flyktninghjelp',),
'flyktninghjelper': ('flyktninghjelp',),
'flyktningleir': ('flyktningleir',),
'flyktningleiren': ('flyktningleir',),
'flyktningleirene': ('flyktningleir',),
'flyktningleirer': ('flyktningleir',),
'flyktningorganisasjon': ('flyktningorganisasjon',),
'flyktningorganisasjonen': ('flyktningorganisasjon',),
'flyktningorganisasjonene': ('flyktningorganisasjon',),
'flyktningorganisasjoner': ('flyktningorganisasjon',),
'flymedisin': ('flymedisin',),
'flymedisinen': ('flymedisin',),
'flymedisinene': ('flymedisin',),
'flymedisiner': ('flymedisin',),
'flymekaniker': ('flymekaniker',),
'flymekanikere': ('flymekaniker',),
'flymekanikeren': ('flymekaniker',),
'flymekanikerer': ('flymekaniker',),
'flymekanikerne': ('flymekaniker',),
'flymotor': ('flymotor',),
'flymotoren': ('flymotor',),
'flymotorene': ('flymotor',),
'flymotorer': ('flymotor',),
'flyndra': ('flyndre',),
'flyndre': ('flyndre',),
'flyndren': ('flyndre',),
'flyndrene': ('flyndre',),
'flyndrer': ('flyndre',),
'flyndrefilet': ('flyndrefilet',),
'flyndrefileten': ('flyndrefilet',),
'flyndrefiletene': ('flyndrefilet',),
'flyndrefileter': ('flyndrefilet',),
'flyplass': ('flyplass',),
'flyplassen': ('flyplass',),
'flyplassene': ('flyplass',),
'flyplasser': ('flyplass',),
'flypost': ('flypost',),
'flyposten': ('flypost',),
'flypostene': ('flypost',),
'flyposter': ('flypost',),
'flyruta': ('flyrute',),
'flyrute': ('flyrute',),
'flyruten': ('flyrute',),
'flyrutene': ('flyrute',),
'flyruter': ('flyrute',),
'flyrutenett': ('flyrutenett',),
'flyrutenetta': ('flyrutenett',),
'flyrutenettene': ('flyrutenett',),
'flyrutenettet': ('flyrutenett',),
'flyselskap': ('flyselskap',),
'flyselskapa': ('flyselskap',),
'flyselskapene': ('flyselskap',),
'flyselskaper': ('flyselskap',),
'flyselskapet': ('flyselskap',),
'flysertifikat': ('flysertifikat',),
'flysertifikata': ('flysertifikat',),
'flysertifikatene': ('flysertifikat',),
'flysertifikater': ('flysertifikat',),
'flysertifikatet': ('flysertifikat',),
'flyskrekk': ('flyskrekk',),
'flyskrekken': ('flyskrekk',),
'flyskrekkene': ('flyskrekk',),
'flyskrekker': ('flyskrekk',),
'flystasjon': ('flystasjon',),
'flystasjonen': ('flystasjon',),
'flystasjonene': ('flystasjon',),
'flystasjoner': ('flystasjon',),
'flystripa': ('flystripe',),
'flystripe': ('flystripe',),
'flystripen': ('flystripe',),
'flystripene': ('flystripe',),
'flystriper': ('flystripe',),
'flystyrt': ('flystyrt',),
'flystyrten': ('flystyrt',),
'flystyrtene': ('flystyrt',),
'flystyrter': ('flystyrt',),
'flystøy': ('flystøy',),
'flystøyen': ('flystøy',),
'flystøyene': ('flystøy',),
'flystøyer': ('flystøy',),
'flystøykommisjon': ('flystøykommisjon',),
'flystøykommisjonen': ('flystøykommisjon',),
'flystøykommisjonene': ('flystøykommisjon',),
'flystøykommisjoner': ('flystøykommisjon',),
'flyt': ('flyt',),
'flyten': ('flyt',),
'flytene': ('flyt',),
'flyter': ('flyt',),
'flytebro': ('flytebro',),
'flytebroa': ('flytebro',),
'flytebroen': ('flytebro',),
'flytebroene': ('flytebro',),
'flytebroer': ('flytebro',),
'flytebru': ('flytebru',),
'flytebrua': ('flytebru',),
'flytebruen': ('flytebru',),
'flytebruene': ('flytebru',),
'flytebruer': ('flytebru',),
'flytebrygga': ('flytebrygge',),
'flytebrygge': ('flytebrygge',),
'flytebryggen': ('flytebrygge',),
'flytebryggene': ('flytebrygge',),
'flytebrygger': ('flytebrygge',),
'flytedokk': ('flytedokk',),
'flytedokka': ('flytedokk',),
'flytedokken': ('flytedokk',),
'flytedokkene': ('flytedokk',),
'flytedokker': ('flytedokk',),
'flytekran': ('flytekran',),
'flytekrana': ('flytekran',),
'flytekranen': ('flytekran',),
'flytekranene': ('flytekran',),
'flytekraner': ('flytekran',),
'flyterminal': ('flyterminal',),
'flyterminalen': ('flyterminal',),
'flyterminalene': ('flyterminal',),
'flyterminaler': ('flyterminal',),
'flytetrål': ('flytetrål',),
'flytetrålen': ('flytetrål',),
'flytetrålene': ('flytetrål',),
'flytetråler': ('flytetrål',),
'flytevekt': ('flytevekt',),
'flytevekta': ('flytevekt',),
'flytevekten': ('flytevekt',),
'flytevektene': ('flytevekt',),
'flytevekter': ('flytevekt',),
'flytevest': ('flytevest',),
'flytevesten': ('flytevest',),
'flytevestene': ('flytevest',),
'flytevester': ('flytevest',),
'flytholt': ('flytholt',),
'flytholta': ('flytholt',),
'flytholten': ('flytholt',),
'flytholtene': ('flytholt',),
'flytholter': ('flytholt',),
'flytholtet': ('flytholt',),
'flytid': ('flytid',),
'flytida': ('flytid',),
'flytiden': ('flytid',),
'flytidene': ('flytid',),
'flytider': ('flytid',),
'flytorpedo': ('flytorpedo',),
'flytorpedoen': ('flytorpedo',),
'flytorpedoene': ('flytorpedo',),
'flytorpedoer': ('flytorpedo',),
'flytrafikk': ('flytrafikk',),
'flytrafikken': ('flytrafikk',),
'flytrafikkene': ('flytrafikk',),
'flytrafikker': ('flytrafikk',),
'flytransport': ('flytransport',),
'flytransporten': ('flytransport',),
'flytransportene': ('flytransport',),
'flytransporter': ('flytransport',),
'flytskjema': ('flytskjema',),
'flytskjemaene': ('flytskjema',),
'flytskjemaer': ('flytskjema',),
'flytskjemaet': ('flytskjema',),
'flyttblokk': ('flyttblokk',),
'flyttblokka': ('flyttblokk',),
'flyttblokken': ('flyttblokk',),
'flyttblokkene': ('flyttblokk',),
'flyttblokker': ('flyttblokk',),
'flytteattest': ('flytteattest',),
'flytteattesten': ('flytteattest',),
'flytteattestene': ('flytteattest',),
'flytteattester': ('flytteattest',),
'flyttebyrå': ('flyttebyrå',),
'flyttebyråa': ('flyttebyrå',),
'flyttebyråene': ('flyttebyrå',),
'flyttebyråer': ('flyttebyrå',),
'flyttebyrået': ('flyttebyrå',),
'flyttedag': ('flyttedag',),
'flyttedagen': ('flyttedag',),
'flyttedagene': ('flyttedag',),
'flyttedager': ('flyttedag',),
'flyttefolk': ('flyttefolk',),
'flyttefolka': ('flyttefolk',),
'flyttefolkene': ('flyttefolk',),
'flyttefolket': ('flyttefolk',),
'flyttegodtgjørelse': ('flyttegodtgjørelse',),
'flyttegodtgjørelsen': ('flyttegodtgjørelse',),
'flyttegodtgjørelsene': ('flyttegodtgjørelse',),
'flyttegodtgjørelser': ('flyttegodtgjørelse',),
'flyttegodtgjøring': ('flyttegodtgjøring',),
'flyttegodtgjøringa': ('flyttegodtgjøring',),
'flyttegodtgjøringen': ('flyttegodtgjøring',),
'flyttegodtgjøringene': ('flyttegodtgjøring',),
'flyttegodtgjøringer': ('flyttegodtgjøring',),
'flyttelass': ('flyttelass',),
'flyttelassa': ('flyttelass',),
'flyttelassene': ('flyttelass',),
'flyttelasset': ('flyttelass',),
'flyttesjau': ('flyttesjau',),
'flyttesjauen': ('flyttesjau',),
'flyttesjauene': ('flyttesjau',),
'flyttesjauer': ('flyttesjau',),
'flyttfolk': ('flyttfolk',),
'flyttfolka': ('flyttfolk',),
'flyttfolkene': ('flyttfolk',),
'flyttfolket': ('flyttfolk',),
'flyttfugl': ('flyttfugl',),
'flyttfuglen': ('flyttfugl',),
'flyttfuglene': ('flyttfugl',),
'flyttfugler': ('flyttfugl',),
'flyttsame': ('flyttsame',),
'flyttsamen': ('flyttsame',),
'flyttsamene': ('flyttsame',),
'flyttsamer': ('flyttsame',),
'flyulykka': ('flyulykke',),
'flyulykke': ('flyulykke',),
'flyulykken': ('flyulykke',),
'flyulykkene': ('flyulykke',),
'flyulykker': ('flyulykke',),
'flyveng': ('flyveng',),
'flyvengen': ('flyveng',),
'flyvengene': ('flyveng',),
'flyvenger': ('flyveng',),
'flyveng': ('flyveng',),
'flyvengen': ('flyveng',),
'flyvengene': ('flyveng',),
'flyvenger': ('flyveng',),
'flyvertinna': ('flyvertinne',),
'flyvertinne': ('flyvertinne',),
'flyvertinnen': ('flyvertinne',),
'flyvertinnene': ('flyvertinne',),
'flyvertinner': ('flyvertinne',),
'flyving': ('flyving',),
'flyvingen': ('flyving',),
'flyvingene': ('flyving',),
'flyvinger': ('flyving',),
'flyvinge': ('flyvinge',),
'flyvingen': ('flyvinge',),
'flyvingene': ('flyvinge',),
'flyvinger': ('flyvinge',),
'flyvinge': ('flyvinge',),
'flyvingen': ('flyvinge',),
'flyvingene': ('flyvinge',),
'flyvinger': ('flyvinge',),
'flyvåpen': ('flyvåpen',),
'flyvåpenet': ('flyvåpen',),
'flyvåpna': ('flyvåpen',),
'flyvåpnene': ('flyvåpen',),
'flå': ('flå',),
'flåen': ('flå',),
'flåene': ('flå',),
'flåer': ('flå',),
'flå': ('flå',),
'flåa': ('flå',),
'flåen': ('flå',),
'flåene': ('flå',),
'flåer': ('flå',),
'flær': ('flå',),
'flærne': ('flå',),
'flå': ('flå',),
'flåa': ('flå',),
'flåen': ('flå',),
'flåene': ('flå',),
'flåer': ('flå',),
'flær': ('flå',),
'flærne': ('flå',),
'flåer': ('flåer',),
'flåere': ('flåer',),
'flåeren': ('flåer',),
'flåerer': ('flåer',),
'flåerne': ('flåer',),
'flåeri': ('flåeri',),
'flåeria': ('flåeri',),
'flåeriene': ('flåeri',),
'flåerier': ('flåeri',),
'flåeriet': ('flåeri',),
'flåhakka': ('flåhakke',),
'flåhakke': ('flåhakke',),
'flåhakken': ('flåhakke',),
'flåhakkene': ('flåhakke',),
'flåhakker': ('flåhakke',),
'flåkjeft': ('flåkjeft',),
'flåkjeften': ('flåkjeft',),
'flåkjeftene': ('flåkjeft',),
'flåkjefter': ('flåkjeft',),
'flås': ('flås',),
'flåsen': ('flås',),
'flåsene': ('flås',),
'flåser': ('flås',),
'flåte': ('flåte',),
'flåten': ('flåte',),
'flåtene': ('flåte',),
'flåter': ('flåte',),
'flåteavdeling': ('flåteavdeling',),
'flåteavdelinga': ('flåteavdeling',),
'flåteavdelingen': ('flåteavdeling',),
'flåteavdelingene': ('flåteavdeling',),
'flåteavdelinger': ('flåteavdeling',),
'flåtebesøk': ('flåtebesøk',),
'flåtebesøka': ('flåtebesøk',),
'flåtebesøkene': ('flåtebesøk',),
'flåtebesøket': ('flåtebesøk',),
'flåtemanøver': ('flåtemanøver',),
'flåtemanøvere': ('flåtemanøver',),
'flåtemanøveren': ('flåtemanøver',),
'flåtemanøverne': ('flåtemanøver',),
'flåtemanøvre': ('flåtemanøver',),
'flåtemanøvrene': ('flåtemanøver',),
'flåtemanøvrer': ('flåtemanøver',),
'flåtestasjon': ('flåtestasjon',),
'flåtestasjonen': ('flåtestasjon',),
'flåtestasjonene': ('flåtestasjon',),
'flåtestasjoner': ('flåtestasjon',),
'flått': ('flått',),
'flåtten': ('flått',),
'flåttene': ('flått',),
'flåtter': ('flått',),
'flæ': ('flæ',),
'flæa': ('flæ',),
'flæene': ('flæ',),
'flæer': ('flæ',),
'flæet': ('flæ',),
'flæ': ('flæ',),
'flæa': ('flæ',),
'flæene': ('flæ',),
'flæer': ('flæ',),
'flæet': ('flæ',),
'flæra': ('flære',),
'flære': ('flære',),
'flæren': ('flære',),
'flærene': ('flære',),
'flærer': ('flære',),
'flø': ('flø',),
'fløa': ('flø',),
'fløene': ('flø',),
'fløet': ('flø',),
'fløka': ('fløke',),
'fløke': ('fløke',),
'fløkene': ('fløke',),
'fløker': ('fløke',),
'fløket': ('fløke',),
'flørt': ('flørt',),
'flørten': ('flørt',),
'flørtene': ('flørt',),
'flørter': ('flørt',),
'fløte': ('fløte',),
'fløten': ('fløte',),
'fløtene': ('fløte',),
'fløter': ('fløte',),
'fløteboks': ('fløteboks',),
'fløteboksen': ('fløteboks',),
'fløteboksene': ('fløteboks',),
'fløtebokser': ('fløteboks',),
'fløtefjes': ('fløtefjes',),
'fløtefjesa': ('fløtefjes',),
'fløtefjesene': ('fløtefjes',),
'fløtefjeset': ('fløtefjes',),
'fløtekrem': ('fløtekrem',),
'fløtekremen': ('fløtekrem',),
'fløtekremene': ('fløtekrem',),
'fløtekremer': ('fløtekrem',),
'fløtemelk': ('fløtemelk',),
'fløtemelka': ('fløtemelk',),
'fløtemelken': ('fløtemelk',),
'fløtemelkene': ('fløtemelk',),
'fløtemelker': ('fløtemelk',),
'fløtemjølk': ('fløtemjølk',),
'fløtemjølka': ('fløtemjølk',),
'fløtemjølken': ('fløtemjølk',),
'fløtemjølkene': ('fløtemjølk',),
'fløtemjølker': ('fløtemjølk',),
'fløtemysost': ('fløtemysost',),
'fløtemysosten': ('fløtemysost',),
'fløtemysostene': ('fløtemysost',),
'fløtemysoster': ('fløtemysost',),
'fløtepus': ('fløtepus',),
'fløtepusen': ('fløtepus',),
'fløtepusene': ('fløtepus',),
'fløtepuser': ('fløtepus',),
'fløter': ('fløter',),
'fløtere': ('fløter',),
'fløteren': ('fløter',),
'fløterer': ('fløter',),
'fløterne': ('fløter',),
'fløterhake': ('fløterhake',),
'fløterhaken': ('fløterhake',),
'fløterhakene': ('fløterhake',),
'fløterhaker': ('fløterhake',),
'fløtesaus': ('fløtesaus',),
'fløtesausen': ('fløtesaus',),
'fløtesausene': ('fløtesaus',),
'fløtesauser': ('fløtesaus',),
'fløting': ('fløting',),
'fløtinga': ('fløting',),
'fløtingen': ('fløting',),
'fløtingene': ('fløting',),
'fløtinger': ('fløting',),
'fløtingsdistrikt': ('fløtingsdistrikt',),
'fløtingsdistrikta': ('fløtingsdistrikt',),
'fløtingsdistriktene': ('fløtingsdistrikt',),
'fløtingsdistrikter': ('fløtingsdistrikt',),
'fløtingsdistriktet': ('fløtingsdistrikt',),
'fløtning': ('fløtning',),
'fløtninga': ('fløtning',),
'fløtningen': ('fløtning',),
'fløtningene': ('fløtning',),
'fløtninger': ('fløtning',),
'fløtningsdistrikt': ('fløtningsdistrikt',),
'fløtningsdistrikta': ('fløtningsdistrikt',),
'fløtningsdistriktene': ('fløtningsdistrikt',),
'fløtningsdistrikter': ('fløtningsdistrikt',),
'fløtningsdistriktet': ('fløtningsdistrikt',),
'fløttmann': ('fløttmann',),
'fløttmannen': ('fløttmann',),
'fløttmenn': ('fløttmann',),
'fløttmennene': ('fløttmann',),
'fløy': ('fløy',),
'fløya': ('fløy',),
'fløyen': ('fløy',),
'fløyene': ('fløy',),
'fløyer': ('fløy',),
'fløyalter': ('fløyalter',),
'fløyaltera': ('fløyalter',),
'fløyaltere': ('fløyalter',),
'fløyalteret': ('fløyalter',),
'fløyaltra': ('fløyalter',),
'fløyaltre': ('fløyalter',),
'fløyaltrene': ('fløyalter',),
'fløyaltret': ('fløyalter',),
'fløydør': ('fløydør',),
'fløydøra': ('fløydør',),
'fløydøren': ('fløydør',),
'fløydørene': ('fløydør',),
'fløydører': ('fløydør',),
'fløyel': ('fløyel',),
'fløyela': ('fløyel',),
'fløyelen': ('fløyel',),
'fløyelene': ('fløyel',),
'fløyeler': ('fløyel',),
'fløyelet': ('fløyel',),
'fløyelsblomst': ('fløyelsblomst',),
'fløyelsblomsten': ('fløyelsblomst',),
'fløyelsblomstene': ('fløyelsblomst',),
'fløyelsblomster': ('fløyelsblomst',),
'fløyelsbuksa': ('fløyelsbukse',),
'fløyelsbukse': ('fløyelsbukse',),
'fløyelsbuksen': ('fløyelsbukse',),
'fløyelsbuksene': ('fløyelsbukse',),
'fløyelsbukser': ('fløyelsbukse',),
'fløyelsgraut': ('fløyelsgraut',),
'fløyelsgrauten': ('fløyelsgraut',),
'fløyelsgrautene': ('fløyelsgraut',),
'fløyelsgrauter': ('fløyelsgraut',),
'fløyelsgrøt': ('fløyelsgrøt',),
'fløyelsgrøten': ('fløyelsgrøt',),
'fløyelsgrøtene': ('fløyelsgrøt',),
'fløyelsgrøter': ('fløyelsgrøt',),
'fløymann': ('fløymann',),
'fløymannen': ('fløymann',),
'fløymenn': ('fløymann',),
'fløymennene': ('fløymann',),
'fløyparti': ('fløyparti',),
'fløypartia': ('fløyparti',),
'fløypartiene': ('fløyparti',),
'fløypartier': ('fløyparti',),
'fløypartiet': ('fløyparti',),
'fløyt': ('fløyt',),
'fløyten': ('fløyt',),
'fløytene': ('fløyt',),
'fløyter': ('fløyt',),
'fløyt': ('fløyt',),
'fløyta': ('fløyt',),
'fløytene': ('fløyt',),
'fløytet': ('fløyt',),
'fløyte': ('fløyte',),
'fløyten': ('fløyte',),
'fløytene': ('fløyte',),
'fløyter': ('fløyte',),
'fløyta': ('fløyte',),
'fløyte': ('fløyte',),
'fløyten': ('fløyte',),
'fløytene': ('fløyte',),
'fløyter': ('fløyte',),
'fløyteboks': ('fløyteboks',),
'fløyteboksen': ('fløyteboks',),
'fløyteboksene': ('fløyteboks',),
'fløytebokser': ('fløyteboks',),
'fløytefjes': ('fløytefjes',),
'fløytefjesa': ('fløytefjes',),
'fløytefjesene': ('fløytefjes',),
'fløytefjeset': ('fløytefjes',),
'fløytekrem': ('fløytekrem',),
'fløytekremen': ('fløytekrem',),
'fløytekremene': ('fløytekrem',),
'fløytekremer': ('fløytekrem',),
'fløytemelk': ('fløytemelk',),
'fløytemelka': ('fløytemelk',),
'fløytemelken': ('fløytemelk',),
'fløytemelkene': ('fløytemelk',),
'fløytemelker': ('fløytemelk',),
'fløytemjølk': ('fløytemjølk',),
'fløytemjølka': ('fløytemjølk',),
'fløytemjølken': ('fløytemjølk',),
'fløytemjølkene': ('fløytemjølk',),
'fløytemjølker': ('fløytemjølk',),
'fløytemysost': ('fløytemysost',),
'fløytemysosten': ('fløytemysost',),
'fløytemysostene': ('fløytemysost',),
'fløytemysoster': ('fløytemysost',),
'fløyten': ('fløyten',),
'fløytenist': ('fløytenist',),
'fløytenisten': ('fløytenist',),
'fløytenistene': ('fløytenist',),
'fløytenister': ('fløytenist',),
'fløytepus': ('fløytepus',),
'fløytepusen': ('fløytepus',),
'fløytepusene': ('fløytepus',),
'fløytepuser': ('fløytepus',),
'fløyter': ('fløyter',),
'fløytere': ('fløyter',),
'fløyteren': ('fløyter',),
'fløyterer': ('fløyter',),
'fløyterne': ('fløyter',),
'fløyterhake': ('fløyterhake',),
'fløyterhaken': ('fløyterhake',),
'fløyterhakene': ('fløyterhake',),
'fløyterhaker': ('fløyterhake',),
'fløytesaus': ('fløytesaus',),
'fløytesausen': ('fløytesaus',),
'fløytesausene': ('fløytesaus',),
'fløytesauser': ('fløytesaus',),
'fløytespeller': ('fløytespeller',),
'fløytespellere': ('fløytespeller',),
'fløytespelleren': ('fløytespeller',),
'fløytespellerer': ('fløytespeller',),
'fløytespellerne': ('fløytespeller',),
'fløytespiller': ('fløytespiller',),
'fløytespillere': ('fløytespiller',),
'fløytespilleren': ('fløytespiller',),
'fløytespillerer': ('fløytespiller',),
'fløytespillerne': ('fløytespiller',),
'fløyting': ('fløyting',),
'fløytinga': ('fløyting',),
'fløytingen': ('fløyting',),
'fløytingene': ('fløyting',),
'fløytinger': ('fløyting',),
'fløytingsdistrikt': ('fløytingsdistrikt',),
'fløytingsdistrikta': ('fløytingsdistrikt',),
'fløytingsdistriktene': ('fløytingsdistrikt',),
'fløytingsdistrikter': ('fløytingsdistrikt',),
'fløytingsdistriktet': ('fløytingsdistrikt',),
'fløytist': ('fløytist',),
'fløytisten': ('fløytist',),
'fløytistene': ('fløytist',),
'fløytister': ('fløytist',),
'fnatt': ('fnatt',),
'fnatta': ('fnatt',),
'fnattene': ('fnatt',),
'fnattet': ('fnatt',),
'fnis': ('fnis',),
'fnisa': ('fnis',),
'fnisene': ('fnis',),
'fniset': ('fnis',),
'fnisealder': ('fnisealder',),
'fnisealdere': ('fnisealder',),
'fnisealderen': ('fnisealder',),
'fnisealderer': ('fnisealder',),
'fnisealderne': ('fnisealder',),
'fnisealdre': ('fnisealder',),
'fnisealdrene': ('fnisealder',),
'fnisealdrer': ('fnisealder',),
'fnokk': ('fnokk',),
'fnokken': ('fnokk',),
'fnokkene': ('fnokk',),
'fnokker': ('fnokk',),
'fnugg': ('fnugg',),
'fnugga': ('fnugg',),
'fnuggene': ('fnugg',),
'fnugget': ('fnugg',),
'fnys': ('fnys',),
'fnysa': ('fnys',),
'fnysene': ('fnys',),
'fnyset': ('fnys',),
'foajeen': ('foajé',),
'foajeene': ('foajé',),
'foajeer': ('foajé',),
'foajé': ('foajé',),
'foajéen': ('foajé',),
'foajéene': ('foajé',),
'foajéer': ('foajé',),
'fobi': ('fobi',),
'fobien': ('fobi',),
'fobiene': ('fobi',),
'fobier': ('fobi',),
'fogd': ('fogd',),
'fogden': ('fogd',),
'fogdene': ('fogd',),
'fogder': ('fogd',),
'fogdekontor': ('fogdekontor',),
'fogdekontora': ('fogdekontor',),
'fogdekontorene': ('fogdekontor',),
'fogdekontorer': ('fogdekontor',),
'fogdekontoret': ('fogdekontor',),
'fogderi': ('fogderi',),
'fogderia': ('fogderi',),
'fogderiene': ('fogderi',),
'fogderier': ('fogderi',),
'fogderiet': ('fogderi',),
'fokk': ('fokk',),
'fokka': ('fokk',),
'fokkene': ('fokk',),
'fokket': ('fokk',),
'fokk': ('fokk',),
'fokka': ('fokk',),
'fokken': ('fokk',),
'fokkene': ('fokk',),
'fokker': ('fokk',),
'fokkemast': ('fokkemast',),
'fokkemasta': ('fokkemast',),
'fokkemasten': ('fokkemast',),
'fokkemastene': ('fokkemast',),
'fokkemaster': ('fokkemast',),
'fokksand': ('fokksand',),
'fokksanden': ('fokksand',),
'fokksandene': ('fokksand',),
'fokksander': ('fokksand',),
'fokksnø': ('fokksnø',),
'fokksnøen': ('fokksnø',),
'fokksnøene': ('fokksnø',),
'fokksnøer': ('fokksnø',),
'fokkvær': ('fokkvær',),
'fokkværa': ('fokkvær',),
'fokkværene': ('fokkvær',),
'fokkværet': ('fokkvær',),
'fokus': ('fokus',),
'fokusa': ('fokus',),
'fokusene': ('fokus',),
'fokuser': ('fokus',),
'fokuset': ('fokus',),
'fold': ('fold',),
'folden': ('fold',),
'foldene': ('fold',),
'folder': ('fold',),
'fold': ('fold',),
'folden': ('fold',),
'foldene': ('fold',),
'folder': ('fold',),
'foldedør': ('foldedør',),
'foldedøra': ('foldedør',),
'foldedøren': ('foldedør',),
'foldedørene': ('foldedør',),
'foldedører': ('foldedør',),
'folder': ('folder',),
'foldere': ('folder',),
'folderen': ('folder',),
'folderer': ('folder',),
'folderne': ('folder',),
'foldeskjørt': ('foldeskjørt',),
'foldeskjørta': ('foldeskjørt',),
'foldeskjørtene': ('foldeskjørt',),
'foldeskjørter': ('foldeskjørt',),
'foldeskjørtet': ('foldeskjørt',),
'foldevegg': ('foldevegg',),
'foldeveggen': ('foldevegg',),
'foldeveggene': ('foldevegg',),
'foldevegger': ('foldevegg',),
'fole': ('fole',),
'folen': ('fole',),
'folene': ('fole',),
'foler': ('fole',),
'foliant': ('foliant',),
'folianten': ('foliant',),
'foliantene': ('foliant',),
'folianter': ('foliant',),
'folie': ('folie',),
'folien': ('folie',),
'foliene': ('folie',),
'folier': ('folie',),
'folio': ('folio',),
'folioen': ('folio',),
'folioene': ('folio',),
'folioer': ('folio',),
'folioark': ('folioark',),
'folioarka': ('folioark',),
'folioarkene': ('folioark',),
'folioarket': ('folioark',),
'folioformat': ('folioformat',),
'folioformata': ('folioformat',),
'folioformatene': ('folioformat',),
'folioformater': ('folioformat',),
'folioformatet': ('folioformat',),
'folioinnskott': ('folioinnskott',),
'folioinnskotta': ('folioinnskott',),
'folioinnskottene': ('folioinnskott',),
'folioinnskottet': ('folioinnskott',),
'folioinnskudd': ('folioinnskudd',),
'folioinnskudda': ('folioinnskudd',),
'folioinnskuddene': ('folioinnskudd',),
'folioinnskuddet': ('folioinnskudd',),
'foliokonti': ('foliokonto',),
'foliokontiene': ('foliokonto',),
'foliokonto': ('foliokonto',),
'foliokontoen': ('foliokonto',),
'foliokontoene': ('foliokonto',),
'foliokontoer': ('foliokonto',),
'folk': ('folk',),
'folka': ('folk',),
'folkene': ('folk',),
'folket': ('folk',),
'folkeakademi': ('folkeakademi',),
'folkeakademia': ('folkeakademi',),
'folkeakademiene': ('folkeakademi',),
'folkeakademier': ('folkeakademi',),
'folkeakademiet': ('folkeakademi',),
'folkeaksjon': ('folkeaksjon',),
'folkeaksjonen': ('folkeaksjon',),
'folkeaksjonene': ('folkeaksjon',),
'folkeaksjoner': ('folkeaksjon',),
'folkeavstemning': ('folkeavstemning',),
'folkeavstemninga': ('folkeavstemning',),
'folkeavstemningen': ('folkeavstemning',),
'folkeavstemningene': ('folkeavstemning',),
'folkeavstemninger': ('folkeavstemning',),
'folkebibliotek': ('folkebibliotek',),
'folkebiblioteka': ('folkebibliotek',),
'folkebibliotekene': ('folkebibliotek',),
'folkebiblioteker': ('folkebibliotek',),
'folkebiblioteket': ('folkebibliotek',),
'folkeboksamling': ('folkeboksamling',),
'folkeboksamlinga': ('folkeboksamling',),
'folkeboksamlingen': ('folkeboksamling',),
'folkeboksamlingene': ('folkeboksamling',),
'folkeboksamlinger': ('folkeboksamling',),
'folkedans': ('folkedans',),
'folkedansen': ('folkedans',),
'folkedansene': ('folkedans',),
'folkedanser': ('folkedans',),
'folkedemokrati': ('folkedemokrati',),
'folkedemokratia': ('folkedemokrati',),
'folkedemokratiene': ('folkedemokrati',),
'folkedemokratier': ('folkedemokrati',),
'folkedemokratiet': ('folkedemokrati',),
'folkedikting': ('folkedikting',),
'folkediktinga': ('folkedikting',),
'folkediktingen': ('folkedikting',),
'folkediktingene': ('folkedikting',),
'folkediktinger': ('folkedikting',),
'folkediktning': ('folkediktning',),
'folkediktninga': ('folkediktning',),
'folkediktningen': ('folkediktning',),
'folkediktningene': ('folkediktning',),
'folkediktninger': ('folkediktning',),
'folkedjup': ('folkedjup',),
'folkedjupa': ('folkedjup',),
'folkedjupene': ('folkedjup',),
'folkedjupet': ('folkedjup',),
'folkedrakt': ('folkedrakt',),
'folkedrakta': ('folkedrakt',),
'folkedrakten': ('folkedrakt',),
'folkedraktene': ('folkedrakt',),
'folkedrakter': ('folkedrakt',),
'folkedyp': ('folkedyp',),
'folkedypa': ('folkedyp',),
'folkedypene': ('folkedyp',),
'folkedypet': ('folkedyp',),
'folkeetymologi': ('folkeetymologi',),
'folkeetymologien': ('folkeetymologi',),
'folkeetymologiene': ('folkeetymologi',),
'folkeetymologier': ('folkeetymologi',),
'folkeeventyr': ('folkeeventyr',),
'folkeeventyra': ('folkeeventyr',),
'folkeeventyrene': ('folkeeventyr',),
'folkeeventyret': ('folkeeventyr',),
'folkeferd': ('folkeferd',),
'folkeferda': ('folkeferd',),
'folkeferdene': ('folkeferd',),
'folkeferdet': ('folkeferd',),
'folkehav': ('folkehav',),
'folkehava': ('folkehav',),
'folkehavene': ('folkehav',),
'folkehavet': ('folkehav',),
'folkehelsa': ('folkehelse',),
'folkehelse': ('folkehelse',),
'folkehelsen': ('folkehelse',),
'folkehelsene': ('folkehelse',),
'folkehelser': ('folkehelse',),
'folkehjelp': ('folkehjelp',),
'folkehjelpa': ('folkehjelp',),
'folkehjelpen': ('folkehjelp',),
'folkehjelpene': ('folkehjelp',),
'folkehjelper': ('folkehjelp',),
'folkehøgskole': ('folkehøgskole',),
'folkehøgskolen': ('folkehøgskole',),
'folkehøgskolene': ('folkehøgskole',),
'folkehøgskoler': ('folkehøgskole',),
'folkehøyskole': ('folkehøyskole',),
'folkehøyskolen': ('folkehøyskole',),
'folkehøyskolene': ('folkehøyskole',),
'folkehøyskoler': ('folkehøyskole',),
'folkekirka': ('folkekirke',),
'folkekirke': ('folkekirke',),
'folkekirken': ('folkekirke',),
'folkekirkene': ('folkekirke',),
'folkekirker': ('folkekirke',),
'folkekjerka': ('folkekjerke',),
'folkekjerke': ('folkekjerke',),
'folkekjerken': ('folkekjerke',),
'folkekjerkene': ('folkekjerke',),
'folkekjerker': ('folkekjerke',),
'folkekommissær': ('folkekommissær',),
'folkekommissæren': ('folkekommissær',),
'folkekommissærene': ('folkekommissær',),
'folkekommissærer': ('folkekommissær',),
'folkekommune': ('folkekommune',),
'folkekommunen': ('folkekommune',),
'folkekommunene': ('folkekommune',),
'folkekommuner': ('folkekommune',),
'folkekrav': ('folkekrav',),
'folkekrava': ('folkekrav',),
'folkekravene': ('folkekrav',),
'folkekravet': ('folkekrav',),
'folkekultur': ('folkekultur',),
'folkekulturen': ('folkekultur',),
'folkekulturene': ('folkekultur',),
'folkekulturer': ('folkekultur',),
'folkekunst': ('folkekunst',),
'folkekunsten': ('folkekunst',),
'folkekunstene': ('folkekunst',),
'folkekunster': ('folkekunst',),
'folkelesing': ('folkelesing',),
'folkelesinga': ('folkelesing',),
'folkelesingen': ('folkelesing',),
'folkelesingene': ('folkelesing',),
'folkelesinger': ('folkelesing',),
'folkelesning': ('folkelesning',),
'folkelesninga': ('folkelesning',),
'folkelesningen': ('folkelesning',),
'folkelesningene': ('folkelesning',),
'folkelesninger': ('folkelesning',),
'folkeliv': ('folkeliv',),
'folkeliva': ('folkeliv',),
'folkelivene': ('folkeliv',),
'folkelivet': ('folkeliv',),
'folkelivsdikting': ('folkelivsdikting',),
'folkelivsdiktinga': ('folkelivsdikting',),
'folkelivsdiktingen': ('folkelivsdikting',),
'folkelivsdiktingene': ('folkelivsdikting',),
'folkelivsdiktinger': ('folkelivsdikting',),
'folkelivsdiktning': ('folkelivsdiktning',),
'folkelivsdiktninga': ('folkelivsdiktning',),
'folkelivsdiktningen': ('folkelivsdiktning',),
'folkelivsdiktningene': ('folkelivsdiktning',),
'folkelivsdiktninger': ('folkelivsdiktning',),
'folkelivsgransker': ('folkelivsgransker',),
'folkelivsgranskere': ('folkelivsgransker',),
'folkelivsgranskeren': ('folkelivsgransker',),
'folkelivsgranskerer': ('folkelivsgransker',),
'folkelivsgranskerne': ('folkelivsgransker',),
'folkelivsgransking': ('folkelivsgransking',),
'folkelivsgranskinga': ('folkelivsgransking',),
'folkelivsgranskingen': ('folkelivsgransking',),
'folkelivsgranskingene': ('folkelivsgransking',),
'folkelivsgranskinger': ('folkelivsgransking',),
'folkelynna': ('folkelynne',),
'folkelynne': ('folkelynne',),
'folkelynnene': ('folkelynne',),
'folkelynner': ('folkelynne',),
'folkelynnet': ('folkelynne',),
'folkemasse': ('folkemasse',),
'folkemassen': ('folkemasse',),
'folkemassene': ('folkemasse',),
'folkemasser': ('folkemasse',),
'folkemedisin': ('folkemedisin',),
'folkemedisinen': ('folkemedisin',),
'folkemedisinene': ('folkemedisin',),
'folkemedisiner': ('folkemedisin',),
'folkemeining': ('folkemeining',),
'folkemeininga': ('folkemeining',),
'folkemeiningen': ('folkemeining',),
'folkemeiningene': ('folkemeining',),
'folkemeininger': ('folkemeining',),
'folkemening': ('folkemening',),
'folkemeninga': ('folkemening',),
'folkemeningen': ('folkemening',),
'folkemeningene': ('folkemening',),
'folkemeninger': ('folkemening',),
'folkeminna': ('folkeminne',),
'folkeminne': ('folkeminne',),
'folkeminnene': ('folkeminne',),
'folkeminner': ('folkeminne',),
'folkeminnet': ('folkeminne',),
'folkeminnegransking': ('folkeminnegransking',),
'folkeminnegranskinga': ('folkeminnegransking',),
'folkeminnegranskingen': ('folkeminnegransking',),
'folkeminnegranskingene': ('folkeminnegransking',),
'folkeminnegranskinger': ('folkeminnegransking',),
'folkeminnevitenskap': ('folkeminnevitenskap',),
'folkeminnevitenskapen': ('folkeminnevitenskap',),
'folkeminnevitenskapene': ('folkeminnevitenskap',),
'folkeminnevitenskaper': ('folkeminnevitenskap',),
'folkeminnevitskap': ('folkeminnevitskap',),
'folkeminnevitskapen': ('folkeminnevitskap',),
'folkeminnevitskapene': ('folkeminnevitskap',),
'folkeminnevitskaper': ('folkeminnevitskap',),
'folkemord': ('folkemord',),
'folkemorda': ('folkemord',),
'folkemordene': ('folkemord',),
'folkemordet': ('folkemord',),
'folkemunn': ('folkemunn',),
'folkemunnen': ('folkemunn',),
'folkemunnene': ('folkemunn',),
'folkemunner': ('folkemunn',),
'folkemusea': ('folkemuseum',),
'folkemuseene': ('folkemuseum',),
'folkemuseer': ('folkemuseum',),
'folkemuseet': ('folkemuseum',),
'folkemuseum': ('folkemuseum',),
'folkemusikk': ('folkemusikk',),
'folkemusikken': ('folkemusikk',),
'folkemusikkene': ('folkemusikk',),
'folkemusikker': ('folkemusikk',),
'folkemål': ('folkemål',),
'folkemåla': ('folkemål',),
'folkemålene': ('folkemål',),
'folkemålet': ('folkemål',),
'folkemålsdikting': ('folkemålsdikting',),
'folkemålsdiktinga': ('folkemålsdikting',),
'folkemålsdiktingen': ('folkemålsdikting',),
'folkemålsdiktingene': ('folkemålsdikting',),
'folkemålsdiktinger': ('folkemålsdikting',),
'folkemålsdiktning': ('folkemålsdiktning',),
'folkemålsdiktninga': ('folkemålsdiktning',),
'folkemålsdiktningen': ('folkemålsdiktning',),
'folkemålsdiktningene': ('folkemålsdiktning',),
'folkemålsdiktninger': ('folkemålsdiktning',),
'folkemøta': ('folkemøte',),
'folkemøte': ('folkemøte',),
'folkemøtene': ('folkemøte',),
'folkemøter': ('folkemøte',),
'folkemøtet': ('folkemøte',),
'folkens': ('folkens',),
'folkeopinion': ('folkeopinion',),
'folkeopinionen': ('folkeopinion',),
'folkeopinionene': ('folkeopinion',),
'folkeopinioner': ('folkeopinion',),
'folkeopplysning': ('folkeopplysning',),
'folkeopplysninga': ('folkeopplysning',),
'folkeopplysningen': ('folkeopplysning',),
'folkeopplysningene': ('folkeopplysning',),
'folkeopplysninger': ('folkeopplysning',),
'folkeparti': ('folkeparti',),
'folkepartia': ('folkeparti',),
'folkepartiene': ('folkeparti',),
'folkepartier': ('folkeparti',),
'folkepartiet': ('folkeparti',),
'folkepensjon': ('folkepensjon',),
'folkepensjonen': ('folkepensjon',),
'folkepensjonene': ('folkepensjon',),
'folkepensjoner': ('folkepensjon',),
'folkerase': ('folkerase',),
'folkerasen': ('folkerase',),
'folkerasene': ('folkerase',),
'folkeraser': ('folkerase',),
'folkeregister': ('folkeregister',),
'folkeregisteret': ('folkeregister',),
'folkeregistra': ('folkeregister',),
'folkeregistre': ('folkeregister',),
'folkeregistrene': ('folkeregister',),
'folkeregistret': ('folkeregister',),
'folkereisning': ('folkereisning',),
'folkereisninga': ('folkereisning',),
'folkereisningen': ('folkereisning',),
'folkereisningene': ('folkereisning',),
'folkereisninger': ('folkereisning',),
'folkerepublikk': ('folkerepublikk',),
'folkerepublikken': ('folkerepublikk',),
'folkerepublikkene': ('folkerepublikk',),
'folkerepublikker': ('folkerepublikk',),
'folkerett': ('folkerett',),
'folkeretten': ('folkerett',),
'folkerettene': ('folkerett',),
'folkeretter': ('folkerett',),
'folkeskare': ('folkeskare',),
'folkeskaren': ('folkeskare',),
'folkeskarene': ('folkeskare',),
'folkeskarer': ('folkeskare',),
'folkeskikk': ('folkeskikk',),
'folkeskikken': ('folkeskikk',),
'folkeskikkene': ('folkeskikk',),
'folkeskikker': ('folkeskikk',),
'folkeskole': ('folkeskole',),
'folkeskolen': ('folkeskole',),
'folkeskolene': ('folkeskole',),
'folkeskoler': ('folkeskole',),
'folkeslag': ('folkeslag',),
'folkeslaga': ('folkeslag',),
'folkeslagene': ('folkeslag',),
'folkeslaget': ('folkeslag',),
'folkesnakk': ('folkesnakk',),
'folkesnakka': ('folkesnakk',),
'folkesnakken': ('folkesnakk',),
'folkesnakkene': ('folkesnakk',),
'folkesnakker': ('folkesnakk',),
'folkesnakket': ('folkesnakk',),
'folkestemning': ('folkestemning',),
'folkestemninga': ('folkestemning',),
'folkestemningen': ('folkestemning',),
'folkestemningene': ('folkestemning',),
'folkestemninger': ('folkestemning',),
'folkestyra': ('folkestyre',),
'folkestyre': ('folkestyre',),
'folkestyrene': ('folkestyre',),
'folkestyrer': ('folkestyre',),
'folkestyret': ('folkestyre',),
'folketal': ('folketal',),
'folketala': ('folketal',),
'folketalene': ('folketal',),
'folketalet': ('folketal',),
'folketaler': ('folketaler',),
'folketalere': ('folketaler',),
'folketaleren': ('folketaler',),
'folketalerer': ('folketaler',),
'folketalerne': ('folketaler',),
'folketall': ('folketall',),
'folketalla': ('folketall',),
'folketallene': ('folketall',),
'folketallet': ('folketall',),
'folketannrøkt': ('folketannrøkt',),
'folketannrøkta': ('folketannrøkt',),
'folketannrøkten': ('folketannrøkt',),
'folketannrøktene': ('folketannrøkt',),
'folketannrøkter': ('folketannrøkt',),
'folketelling': ('folketelling',),
'folketellinga': ('folketelling',),
'folketellingen': ('folketelling',),
'folketellingene': ('folketelling',),
'folketellinger': ('folketelling',),
'folketetthet': ('folketetthet',),
'folketettheta': ('folketetthet',),
'folketettheten': ('folketetthet',),
'folketetthetene': ('folketetthet',),
'folketettheter': ('folketetthet',),
'folketing': ('folketing',),
'folketinga': ('folketing',),
'folketingene': ('folketing',),
'folketinget': ('folketing',),
'folketone': ('folketone',),
'folketonen': ('folketone',),
'folketonene': ('folketone',),
'folketoner': ('folketone',),
'folketro': ('folketro',),
'folketroa': ('folketro',),
'folketroen': ('folketro',),
'folketroene': ('folketro',),
'folketroer': ('folketro',),
'folketrygd': ('folketrygd',),
'folketrygda': ('folketrygd',),
'folketrygden': ('folketrygd',),
'folketrygdene': ('folketrygd',),
'folketrygder': ('folketrygd',),
'folkevandring': ('folkevandring',),
'folkevandringa': ('folkevandring',),
'folkevandringen': ('folkevandring',),
'folkevandringene': ('folkevandring',),
'folkevandringer': ('folkevandring',),
'folkevett': ('folkevett',),
'folkevetta': ('folkevett',),
'folkevettene': ('folkevett',),
'folkevettet': ('folkevett',),
'folkevilje': ('folkevilje',),
'folkeviljen': ('folkevilje',),
'folkeviljene': ('folkevilje',),
'folkeviljer': ('folkevilje',),
'folkevisa': ('folkevise',),
'folkevise': ('folkevise',),
'folkevisen': ('folkevise',),
'folkevisene': ('folkevise',),
'folkeviser': ('folkevise',),
'folkevisedans': ('folkevisedans',),
'folkevisedansen': ('folkevisedans',),
'folkevisedansene': ('folkevisedans',),
'folkevisedanser': ('folkevisedans',),
'folkeviseleik': ('folkeviseleik',),
'folkeviseleiken': ('folkeviseleik',),
'folkeviseleikene': ('folkeviseleik',),
'folkeviseleiker': ('folkeviseleik',),
'folkevrimlene': ('folkevrimmel',),
'folkevrimler': ('folkevrimmel',),
'folkevrimmel': ('folkevrimmel',),
'folkevrimmelen': ('folkevrimmel',),
'folklore': ('folklore',),
'folkloren': ('folklore',),
'folklorene': ('folklore',),
'folklorer': ('folklore',),
'folklorist': ('folklorist',),
'folkloristen': ('folklorist',),
'folkloristene': ('folklorist',),
'folklorister': ('folklorist',),
'folkloristikk': ('folkloristikk',),
'folkloristikken': ('folkloristikk',),
'folkloristikkene': ('folkloristikk',),
'folkloristikker': ('folkloristikk',),
'foll': ('foll',),
'folla': ('foll',),
'follene': ('foll',),
'follet': ('foll',),
'follekniv': ('follekniv',),
'follekniven': ('follekniv',),
'folleknivene': ('follekniv',),
'follekniver': ('follekniv',),
'folunge': ('folunge',),
'folungen': ('folunge',),
'folungene': ('folunge',),
'folunger': ('folunge',),
'fomlene': ('fommel',),
'fomler': ('fommel',),
'fommel': ('fommel',),
'fommelen': ('fommel',),
'fon': ('fon',),
'fonen': ('fon',),
'fonene': ('fon',),
'foner': ('fon',),
'fond': ('fond',),
'fonden': ('fond',),
'fondene': ('fond',),
'fonder': ('fond',),
'fond': ('fond',),
'fonda': ('fond',),
'fondene': ('fond',),
'fondet': ('fond',),
'fonds': ('fonds',),
'fondsavdeling': ('fondsavdeling',),
'fondsavdelinga': ('fondsavdeling',),
'fondsavdelingen': ('fondsavdeling',),
'fondsavdelingene': ('fondsavdeling',),
'fondsavdelinger': ('fondsavdeling',),
'fondsbørs': ('fondsbørs',),
'fondsbørsen': ('fondsbørs',),
'fondsbørsene': ('fondsbørs',),
'fondsbørser': ('fondsbørs',),
'fondsmegler': ('fondsmegler',),
'fondsmeglere': ('fondsmegler',),
'fondsmegleren': ('fondsmegler',),
'fondsmeglerer': ('fondsmegler',),
'fondsmeglerne': ('fondsmegler',),
'fondsmekler': ('fondsmekler',),
'fondsmeklere': ('fondsmekler',),
'fondsmekleren': ('fondsmekler',),
'fondsmeklerer': ('fondsmekler',),
'fondsmeklerne': ('fondsmekler',),
'fondvegg': ('fondvegg',),
'fondveggen': ('fondvegg',),
'fondveggene': ('fondvegg',),
'fondvegger': ('fondvegg',),
'fondy': ('fondy',),
'fondyen': ('fondy',),
'fondyene': ('fondy',),
'fondyer': ('fondy',),
'fonem': ('fonem',),
'fonema': ('fonem',),
'fonemene': ('fonem',),
'fonemer': ('fonem',),
'fonemet': ('fonem',),
'fonemikk': ('fonemikk',),
'fonemikken': ('fonemikk',),
'fonemikkene': ('fonemikk',),
'fonemikker': ('fonemikk',),
'fonetiker': ('fonetiker',),
'fonetikere': ('fonetiker',),
'fonetikeren': ('fonetiker',),
'fonetikerer': ('fonetiker',),
'fonetikerne': ('fonetiker',),
'fonetikk': ('fonetikk',),
'fonetikken': ('fonetikk',),
'fonetikkene': ('fonetikk',),
'fonetikker': ('fonetikk',),
'fonn': ('fonn',),
'fonna': ('fonn',),
'fonnen': ('fonn',),
'fonnene': ('fonn',),
'fonner': ('fonn',),
'fonograf': ('fonograf',),
'fonografen': ('fonograf',),
'fonografene': ('fonograf',),
'fonografer': ('fonograf',),
'fonolog': ('fonolog',),
'fonologen': ('fonolog',),
'fonologene': ('fonolog',),
'fonologer': ('fonolog',),
'fonologi': ('fonologi',),
'fonologien': ('fonologi',),
'fonologiene': ('fonologi',),
'fonologier': ('fonologi',),
'fonometer': ('fonometer',),
'fonometeret': ('fonometer',),
'fonometra': ('fonometer',),
'fonometre': ('fonometer',),
'fonometrene': ('fonometer',),
'fonometret': ('fonometer',),
'font': ('font',),
'fonten': ('font',),
'fontene': ('font',),
'fonter': ('font',),
'fontanell': ('fontanell',),
'fontanellen': ('fontanell',),
'fontanellene': ('fontanell',),
'fontaneller': ('fontanell',),
'fontene': ('fontene',),
'fontenen': ('fontene',),
'fontenene': ('fontene',),
'fontener': ('fontene',),
'forakt': ('forakt',),
'forakten': ('forakt',),
'foraktene': ('forakt',),
'forakter': ('forakt',),
'forandring': ('forandring',),
'forandringa': ('forandring',),
'forandringen': ('forandring',),
'forandringene': ('forandring',),
'forandringer': ('forandring',),
'forankring': ('forankring',),
'forankringa': ('forankring',),
'forankringen': ('forankring',),
'forankringene': ('forankring',),
'forankringer': ('forankring',),
'foranledning': ('foranledning',),
'foranledninga': ('foranledning',),
'foranledningen': ('foranledning',),
'foranledningene': ('foranledning',),
'foranledninger': ('foranledning',),
'foranstaltning': ('foranstaltning',),
'foranstaltninga': ('foranstaltning',),
'foranstaltningen': ('foranstaltning',),
'foranstaltningene': ('foranstaltning',),
'foranstaltninger': ('foranstaltning',),
'forarbeid': ('forarbeid',),
'forarbeida': ('forarbeid',),
'forarbeidene': ('forarbeid',),
'forarbeider': ('forarbeid',),
'forarbeidet': ('forarbeid',),
'forargelse': ('forargelse',),
'forargelsen': ('forargelse',),
'forargelsene': ('forargelse',),
'forargelser': ('forargelse',),
'forband': ('forband',),
'forbanda': ('forband',),
'forbandene': ('forband',),
'forbandet': ('forband',),
'forbannelse': ('forbannelse',),
'forbannelsen': ('forbannelse',),
'forbannelsene': ('forbannelse',),
'forbannelser': ('forbannelse',),
'forbauselse': ('forbauselse',),
'forbauselsen': ('forbauselse',),
'forbauselsene': ('forbauselse',),
'forbauselser': ('forbauselse',),
'forbedring': ('forbedring',),
'forbedringa': ('forbedring',),
'forbedringen': ('forbedring',),
'forbedringene': ('forbedring',),
'forbedringer': ('forbedring',),
'forbehold': ('forbehold',),
'forbeholda': ('forbehold',),
'forbeholdene': ('forbehold',),
'forbeholdet': ('forbehold',),
'forberedelse': ('forberedelse',),
'forberedelsen': ('forberedelse',),
'forberedelsene': ('forberedelse',),
'forberedelser': ('forberedelse',),
'forberedelsesarbeid': ('forberedelsesarbeid',),
'forberedelsesarbeida': ('forberedelsesarbeid',),
'forberedelsesarbeidene': ('forberedelsesarbeid',),
'forberedelsesarbeider': ('forberedelsesarbeid',),
'forberedelsesarbeidet': ('forberedelsesarbeid',),
'forbifart': ('forbifart',),
'forbifarten': ('forbifart',),
'forbifartene': ('forbifart',),
'forbifarter': ('forbifart',),
'forbigåelse': ('forbigåelse',),
'forbigåelsen': ('forbigåelse',),
'forbigåelsene': ('forbigåelse',),
'forbigåelser': ('forbigåelse',),
'forbikjøring': ('forbikjøring',),
'forbikjøringa': ('forbikjøring',),
'forbikjøringen': ('forbikjøring',),
'forbikjøringene': ('forbikjøring',),
'forbikjøringer': ('forbikjøring',),
'forbikjøringsfelt': ('forbikjøringsfelt',),
'forbikjøringsfelta': ('forbikjøringsfelt',),
'forbikjøringsfeltene': ('forbikjøringsfelt',),
'forbikjøringsfelter': ('forbikjøringsfelt',),
'forbikjøringsfeltet': ('forbikjøringsfelt',),
'forbilda': ('forbilde',),
'forbilde': ('forbilde',),
'forbildene': ('forbilde',),
'forbilder': ('forbilde',),
'forbildet': ('forbilde',),
'forbindelse': ('forbindelse',),
'forbindelsen': ('forbindelse',),
'forbindelsene': ('forbindelse',),
'forbindelser': ('forbindelse',),
'forbindelsesledd': ('forbindelsesledd',),
'forbindelsesledda': ('forbindelsesledd',),
'forbindelsesleddene': ('forbindelsesledd',),
'forbindelsesleddet': ('forbindelsesledd',),
'forbindelseslinja': ('forbindelseslinje',),
'forbindelseslinje': ('forbindelseslinje',),
'forbindelseslinjen': ('forbindelseslinje',),
'forbindelseslinjene': ('forbindelseslinje',),
'forbindelseslinjer': ('forbindelseslinje',),
'forbindelsesoffiser': ('forbindelsesoffiser',),
'forbindelsesoffiseren': ('forbindelsesoffiser',),
'forbindelsesoffiserene': ('forbindelsesoffiser',),
'forbindelsesoffiserer': ('forbindelsesoffiser',),
'forbindelsesrør': ('forbindelsesrør',),
'forbindelsesrøra': ('forbindelsesrør',),
'forbindelsesrørene': ('forbindelsesrør',),
'forbindelsesrøret': ('forbindelsesrør',),
'forbinding': ('forbinding',),
'forbindinga': ('forbinding',),
'forbindingen': ('forbinding',),
'forbindingene': ('forbinding',),
'forbindinger': ('forbinding',),
'forbindingssakene': ('forbindingssaker',),
'forbindingssaker': ('forbindingssaker',),
'forbindtlighet': ('forbindtlighet',),
'forbindtligheta': ('forbindtlighet',),
'forbindtligheten': ('forbindtlighet',),
'forbindtlighetene': ('forbindtlighet',),
'forbindtligheter': ('forbindtlighet',),
'forblad': ('forblad',),
'forblada': ('forblad',),
'forbladene': ('forblad',),
'forblader': ('forblad',),
'forbladet': ('forblad',),
'forblendingsstein': ('forblendingsstein',),
'forblendingssteinen': ('forblendingsstein',),
'forblendingssteinene': ('forblendingsstein',),
'forblendingssteiner': ('forblendingsstein',),
'forblødning': ('forblødning',),
'forblødninga': ('forblødning',),
'forblødningen': ('forblødning',),
'forblødningene': ('forblødning',),
'forblødninger': ('forblødning',),
'forbokstav': ('forbokstav',),
'forbokstaven': ('forbokstav',),
'forbokstavene': ('forbokstav',),
'forbokstaver': ('forbokstav',),
'forbrenning': ('forbrenning',),
'forbrenninga': ('forbrenning',),
'forbrenningen': ('forbrenning',),
'forbrenningene': ('forbrenning',),
'forbrenninger': ('forbrenning',),
'forbrenningsanlegg': ('forbrenningsanlegg',),
'forbrenningsanlegga': ('forbrenningsanlegg',),
'forbrenningsanleggene': ('forbrenningsanlegg',),
'forbrenningsanlegget': ('forbrenningsanlegg',),
'forbrenningsmotor': ('forbrenningsmotor',),
'forbrenningsmotoren': ('forbrenningsmotor',),
'forbrenningsmotorene': ('forbrenningsmotor',),
'forbrenningsmotorer': ('forbrenningsmotor',),
'forbruk': ('forbruk',),
'forbruka': ('forbruk',),
'forbrukene': ('forbruk',),
'forbruket': ('forbruk',),
'forbruker': ('forbruker',),
'forbrukere': ('forbruker',),
'forbrukeren': ('forbruker',),
'forbrukerer': ('forbruker',),
'forbrukerne': ('forbruker',),
'forbrukeranalysa': ('forbrukeranalyse',),
'forbrukeranalyse': ('forbrukeranalyse',),
'forbrukeranalysen': ('forbrukeranalyse',),
'forbrukeranalysene': ('forbrukeranalyse',),
'forbrukeranalyser': ('forbrukeranalyse',),
'forbrukerlæra': ('forbrukerlære',),
'forbrukerlære': ('forbrukerlære',),
'forbrukerlæren': ('forbrukerlære',),
'forbrukerlærene': ('forbrukerlære',),
'forbrukerlærer': ('forbrukerlære',),
'forbrukerombud': ('forbrukerombud',),
'forbrukerombuda': ('forbrukerombud',),
'forbrukerombudene': ('forbrukerombud',),
'forbrukerombudet': ('forbrukerombud',),
'forbrukerråd': ('forbrukerråd',),
'forbrukerråda': ('forbrukerråd',),
'forbrukerrådene': ('forbrukerråd',),
'forbrukerrådet': ('forbrukerråd',),
'forbrukersamfunn': ('forbrukersamfunn',),
'forbrukersamfunna': ('forbrukersamfunn',),
'forbrukersamfunnene': ('forbrukersamfunn',),
'forbrukersamfunnet': ('forbrukersamfunn',),
'forbruksartikkel': ('forbruksartikkel',),
'forbruksartikkelen': ('forbruksartikkel',),
'forbruksartiklene': ('forbruksartikkel',),
'forbruksartikler': ('forbruksartikkel',),
'forbruksgoda': ('forbruksgode',),
'forbruksgode': ('forbruksgode',),
'forbruksgodene': ('forbruksgode',),
'forbruksgoder': ('forbruksgode',),
'forbruksgodet': ('forbruksgode',),
'forbruksskatt': ('forbruksskatt',),
'forbruksskatten': ('forbruksskatt',),
'forbruksskattene': ('forbruksskatt',),
'forbruksskatter': ('forbruksskatt',),
'forbruksvara': ('forbruksvare',),
'forbruksvare': ('forbruksvare',),
'forbruksvaren': ('forbruksvare',),
'forbruksvarene': ('forbruksvare',),
'forbruksvarer': ('forbruksvare',),
'forbrytelse': ('forbrytelse',),
'forbrytelsen': ('forbrytelse',),
'forbrytelsene': ('forbrytelse',),
'forbrytelser': ('forbrytelse',),
'forbryter': ('forbryter',),
'forbrytere': ('forbryter',),
'forbryteren': ('forbryter',),
'forbryterer': ('forbryter',),
'forbryterne': ('forbryter',),
'forbryteralbum': ('forbryteralbum',),
'forbryteralbuma': ('forbryteralbum',),
'forbryteralbumene': ('forbryteralbum',),
'forbryteralbumer': ('forbryteralbum',),
'forbryteralbumet': ('forbryteralbum',),
'forbryterbande': ('forbryterbande',),
'forbryterbanden': ('forbryterbande',),
'forbryterbandene': ('forbryterbande',),
'forbryterbander': ('forbryterbande',),
'forbryterbane': ('forbryterbane',),
'forbryterbanen': ('forbryterbane',),
'forbryterbanene': ('forbryterbane',),
'forbryterbaner': ('forbryterbane',),
'forbryterspira': ('forbryterspire',),
'forbryterspire': ('forbryterspire',),
'forbryterspiren': ('forbryterspire',),
'forbryterspirene': ('forbryterspire',),
'forbryterspirer': ('forbryterspire',),
'forbryterspråk': ('forbryterspråk',),
'forbryterspråka': ('forbryterspråk',),
'forbryterspråkene': ('forbryterspråk',),
'forbryterspråket': ('forbryterspråk',),
'forbrødring': ('forbrødring',),
'forbrødringa': ('forbrødring',),
'forbrødringen': ('forbrødring',),
'forbrødringene': ('forbrødring',),
'forbrødringer': ('forbrødring',),
'forbud': ('forbud',),
'forbuda': ('forbud',),
'forbudene': ('forbud',),
'forbudet': ('forbud',),
'forbudsskilt': ('forbudsskilt',),
'forbudsskilta': ('forbudsskilt',),
'forbudsskiltene': ('forbudsskilt',),
'forbudsskilter': ('forbudsskilt',),
'forbudsskiltet': ('forbudsskilt',),
'forbund': ('forbund',),
'forbunda': ('forbund',),
'forbundene': ('forbund',),
'forbundet': ('forbund',),
'forbundsdag': ('forbundsdag',),
'forbundsdagen': ('forbundsdag',),
'forbundsdagene': ('forbundsdag',),
'forbundsdager': ('forbundsdag',),
'forbundsfelle': ('forbundsfelle',),
'forbundsfellen': ('forbundsfelle',),
'forbundsfellene': ('forbundsfelle',),
'forbundsfeller': ('forbundsfelle',),
'forbundskansler': ('forbundskansler',),
'forbundskanslere': ('forbundskansler',),
'forbundskansleren': ('forbundskansler',),
'forbundskanslerer': ('forbundskansler',),
'forbundskanslerne': ('forbundskansler',),
'forbundsstat': ('forbundsstat',),
'forbundsstaten': ('forbundsstat',),
'forbundsstatene': ('forbundsstat',),
'forbundsstater': ('forbundsstat',),
'forbygning': ('forbygning',),
'forbygninga': ('forbygning',),
'forbygningen': ('forbygning',),
'forbygningene': ('forbygning',),
'forbygninger': ('forbygning',),
'forbønn': ('forbønn',),
'forbønna': ('forbønn',),
'forbønnen': ('forbønn',),
'forbønnene': ('forbønn',),
'forbønner': ('forbønn',),
'force majeure': ('force majeure',),
'fordampingsevna': ('fordampingsevne',),
'fordampingsevne': ('fordampingsevne',),
'fordampingsevnen': ('fordampingsevne',),
'fordampingsevnene': ('fordampingsevne',),
'fordampingsevner': ('fordampingsevne',),
'fordampingsflata': ('fordampingsflate',),
'fordampingsflate': ('fordampingsflate',),
'fordampingsflaten': ('fordampingsflate',),
'fordampingsflatene': ('fordampingsflate',),
'fordampingsflater': ('fordampingsflate',),
'fordampingsvarme': ('fordampingsvarme',),
'fordampingsvarmen': ('fordampingsvarme',),
'fordampingsvarmene': ('fordampingsvarme',),
'fordampingsvarmer': ('fordampingsvarme',),
'fordampningsevna': ('fordampningsevne',),
'fordampningsevne': ('fordampningsevne',),
'fordampningsevnen': ('fordampningsevne',),
'fordampningsevnene': ('fordampningsevne',),
'fordampningsevner': ('fordampningsevne',),
'fordampningsflata': ('fordampningsflate',),
'fordampningsflate': ('fordampningsflate',),
'fordampningsflaten': ('fordampningsflate',),
'fordampningsflatene': ('fordampningsflate',),
'fordampningsflater': ('fordampningsflate',),
'fordampningsvarme': ('fordampningsvarme',),
'fordampningsvarmen': ('fordampningsvarme',),
'fordampningsvarmene': ('fordampningsvarme',),
'fordampningsvarmer': ('fordampningsvarme',),
'fordekk': ('fordekk',),
'fordekka': ('fordekk',),
'fordekkene': ('fordekk',),
'fordekket': ('fordekk',),
'fordel': ('fordel',),
'fordelen': ('fordel',),
'fordelene': ('fordel',),
'fordeler': ('fordel',),
'fordeler': ('fordeler',),
'fordelere': ('fordeler',),
'fordeleren': ('fordeler',),
'fordelerer': ('fordeler',),
'fordelerne': ('fordeler',),
'fordeling': ('fordeling',),
'fordelinga': ('fordeling',),
'fordelingen': ('fordeling',),
'fordelingene': ('fordeling',),
'fordelinger': ('fordeling',),
'fordelingskurve': ('fordelingskurve',),
'fordelingskurven': ('fordelingskurve',),
'fordelingskurvene': ('fordelingskurve',),
'fordelingskurver': ('fordelingskurve',),
'fordelingsnøkkel': ('fordelingsnøkkel',),
'fordelingsnøkkelen': ('fordelingsnøkkel',),
'fordelingsnøklene': ('fordelingsnøkkel',),
'fordelingsnøkler': ('fordelingsnøkkel',),
'forderv': ('forderv',),
'forderva': ('forderv',),
'fordervene': ('forderv',),
'fordervet': ('forderv',),
'fordervelse': ('fordervelse',),
'fordervelsen': ('fordervelse',),
'fordervelsene': ('fordervelse',),
'fordervelser': ('fordervelse',),
'fordevinder': ('fordevinder',),
'fordevindere': ('fordevinder',),
'fordevinderen': ('fordevinder',),
'fordevinderer': ('fordevinder',),
'fordevinderne': ('fordevinder',),
'fordjupingsfag': ('fordjupingsfag',),
'fordjupingsfaga': ('fordjupingsfag',),
'fordjupingsfagene': ('fordjupingsfag',),
'fordjupingsfaget': ('fordjupingsfag',),
'fordjupningsfag': ('fordjupningsfag',),
'fordjupningsfaga': ('fordjupningsfag',),
'fordjupningsfagene': ('fordjupningsfag',),
'fordjupningsfaget': ('fordjupningsfag',),
'fordobling': ('fordobling',),
'fordoblinga': ('fordobling',),
'fordoblingen': ('fordobling',),
'fordoblingene': ('fordobling',),
'fordoblinger': ('fordobling',),
'fordoblingstid': ('fordoblingstid',),
'fordoblingstida': ('fordoblingstid',),
'fordoblingstiden': ('fordoblingstid',),
'fordoblingstidene': ('fordoblingstid',),
'fordoblingstider': ('fordoblingstid',),
'fordom': ('fordom',),
'fordommen': ('fordom',),
'fordommene': ('fordom',),
'fordommer': ('fordom',),
'fordragelighet': ('fordragelighet',),
'fordrageligheta': ('fordragelighet',),
'fordrageligheten': ('fordragelighet',),
'fordragelighetene': ('fordragelighet',),
'fordrageligheter': ('fordragelighet',),
'fordrer': ('fordrer',),
'fordrere': ('fordrer',),
'fordreren': ('fordrer',),
'fordrerer': ('fordrer',),
'fordrerne': ('fordrer',),
'fordring': ('fordring',),
'fordringa': ('fordring',),
'fordringen': ('fordring',),
'fordringene': ('fordring',),
'fordringer': ('fordring',),
'fordringshaver': ('fordringshaver',),
'fordringshavere': ('fordringshaver',),
'fordringshaveren': ('fordringshaver',),
'fordringshaverer': ('fordringshaver',),
'fordringshaverne': ('fordringshaver',),
'fordringskreditt': ('fordringskreditt',),
'fordringskreditten': ('fordringskreditt',),
'fordringskredittene': ('fordringskreditt',),
'fordringskreditter': ('fordringskreditt',),
'fordunsting': ('fordunsting',),
'fordunstinga': ('fordunsting',),
'fordunstingen': ('fordunsting',),
'fordunstingene': ('fordunsting',),
'fordunstinger': ('fordunsting',),
'fordunstning': ('fordunstning',),
'fordunstninga': ('fordunstning',),
'fordunstningen': ('fordunstning',),
'fordunstningene': ('fordunstning',),
'fordunstninger': ('fordunstning',),
'fordypelse': ('fordypelse',),
'fordypelsen': ('fordypelse',),
'fordypelsene': ('fordypelse',),
'fordypelser': ('fordypelse',),
'fordypingsfag': ('fordypingsfag',),
'fordypingsfaga': ('fordypingsfag',),
'fordypingsfagene': ('fordypingsfag',),
'fordypingsfaget': ('fordypingsfag',),
'fordypningsfag': ('fordypningsfag',),
'fordypningsfaga': ('fordypningsfag',),
'fordypningsfagene': ('fordypningsfag',),
'fordypningsfaget': ('fordypningsfag',),
'fordømmelse': ('fordømmelse',),
'fordømmelsen': ('fordømmelse',),
'fordømmelsene': ('fordømmelse',),
'fordømmelser': ('fordømmelse',),
'fordømming': ('fordømming',),
'fordømminga': ('fordømming',),
'fordømmingen': ('fordømming',),
'fordømmingene': ('fordømming',),
'fordømminger': ('fordømming',),
'fordøyelse': ('fordøyelse',),
'fordøyelsen': ('fordøyelse',),
'fordøyelsene': ('fordøyelse',),
'fordøyelser': ('fordøyelse',),
'fordøyelsesbesvær': ('fordøyelsesbesvær',),
'fordøyelsesbesværa': ('fordøyelsesbesvær',),
'fordøyelsesbesværene': ('fordøyelsesbesvær',),
'fordøyelsesbesværet': ('fordøyelsesbesvær',),
'fordøyelseskanal': ('fordøyelseskanal',),
'fordøyelseskanalen': ('fordøyelseskanal',),
'fordøyelseskanalene': ('fordøyelseskanal',),
'fordøyelseskanaler': ('fordøyelseskanal',),
'foredling': ('foredling',),
'foredlinga': ('foredling',),
'foredlingen': ('foredling',),
'foredlingene': ('foredling',),
'foredlinger': ('foredling',),
'foredlingsindustri': ('foredlingsindustri',),
'foredlingsindustrien': ('foredlingsindustri',),
'foredlingsindustriene': ('foredlingsindustri',),
'foredlingsindustrier': ('foredlingsindustri',),
'foredrag': ('foredrag',),
'foredraga': ('foredrag',),
'foredragene': ('foredrag',),
'foredraget': ('foredrag',),
'foredragsholder': ('foredragsholder',),
'foredragsholdere': ('foredragsholder',),
'foredragsholderen': ('foredragsholder',),
'foredragsholderer': ('foredragsholder',),
'foredragsholderne': ('foredragsholder',),
'foredragsrekka': ('foredragsrekke',),
'foredragsrekke': ('foredragsrekke',),
'foredragsrekken': ('foredragsrekke',),
'foredragsrekkene': ('foredragsrekke',),
'foredragsrekker': ('foredragsrekke',),
'foregangskvinna': ('foregangskvinne',),
'foregangskvinne': ('foregangskvinne',),
'foregangskvinnen': ('foregangskvinne',),
'foregangskvinnene': ('foregangskvinne',),
'foregangskvinner': ('foregangskvinne',),
'foregangsland': ('foregangsland',),
'foregangslanda': ('foregangsland',),
'foregangslandene': ('foregangsland',),
'foregangslandet': ('foregangsland',),
'foregangsmann': ('foregangsmann',),
'foregangsmannen': ('foregangsmann',),
'foregangsmenn': ('foregangsmann',),
'foregangsmennene': ('foregangsmann',),
'foregivende': ('foregivende',),
'foregivendene': ('foregivende',),
'foregivender': ('foregivende',),
'foregivendet': ('foregivende',),
'forehand': ('forehand',),
'forehanden': ('forehand',),
'forehandene': ('forehand',),
'forehander': ('forehand',),
'forehavende': ('forehavende',),
'forehavendene': ('forehavende',),
'forehavender': ('forehavende',),
'forehavendet': ('forehavende',),
'forekommenhet': ('forekommenhet',),
'forekommenheta': ('forekommenhet',),
'forekommenheten': ('forekommenhet',),
'forekommenhetene': ('forekommenhet',),
'forekommenheter': ('forekommenhet',),
'forekomst': ('forekomst',),
'forekomsten': ('forekomst',),
'forekomstene': ('forekomst',),
'forekomster': ('forekomst',),
'foreldelse': ('foreldelse',),
'foreldelsen': ('foreldelse',),
'foreldelsene': ('foreldelse',),
'foreldelser': ('foreldelse',),
'foreldelsesfrist': ('foreldelsesfrist',),
'foreldelsesfristen': ('foreldelsesfrist',),
'foreldelsesfristene': ('foreldelsesfrist',),
'foreldelsesfrister': ('foreldelsesfrist',),
'forelder': ('forelder',),
'forelderen': ('forelder',),
'foreldra': ('forelder',),
'foreldre': ('forelder',),
'foreldrene': ('forelder',),
'foreldreaksjon': ('foreldreaksjon',),
'foreldreaksjonen': ('foreldreaksjon',),
'foreldreaksjonene': ('foreldreaksjon',),
'foreldreaksjoner': ('foreldreaksjon',),
'foreldregenerasjon': ('foreldregenerasjon',),
'foreldregenerasjonen': ('foreldregenerasjon',),
'foreldregenerasjonene': ('foreldregenerasjon',),
'foreldregenerasjoner': ('foreldregenerasjon',),
'foreldremyndighet': ('foreldremyndighet',),
'foreldremyndigheta': ('foreldremyndighet',),
'foreldremyndigheten': ('foreldremyndighet',),
'foreldremyndighetene': ('foreldremyndighet',),
'foreldremyndigheter': ('foreldremyndighet',),
'foreldreråd': ('foreldreråd',),
'foreldreråda': ('foreldreråd',),
'foreldrerådene': ('foreldreråd',),
'foreldrerådet': ('foreldreråd',),
'forelegg': ('forelegg',),
'forelegga': ('forelegg',),
'foreleggene': ('forelegg',),
'forelegget': ('forelegg',),
'foreleser': ('foreleser',),
'forelesere': ('foreleser',),
'foreleseren': ('foreleser',),
'foreleserer': ('foreleser',),
'foreleserne': ('foreleser',),
'forelesning': ('forelesning',),
'forelesninga': ('forelesning',),
'forelesningen': ('forelesning',),
'forelesningene': ('forelesning',),
'forelesninger': ('forelesning',),
'forelesningsplikt': ('forelesningsplikt',),
'forelesningsplikta': ('forelesningsplikt',),
'forelesningsplikten': ('forelesningsplikt',),
'forelesningspliktene': ('forelesningsplikt',),
'forelesningsplikter': ('forelesningsplikt',),
'forelesningsrekka': ('forelesningsrekke',),
'forelesningsrekke': ('forelesningsrekke',),
'forelesningsrekken': ('forelesningsrekke',),
'forelesningsrekkene': ('forelesningsrekke',),
'forelesningsrekker': ('forelesningsrekke',),
'forelskelse': ('forelskelse',),
'forelskelsen': ('forelskelse',),
'forelskelsene': ('forelskelse',),
'forelskelser': ('forelskelse',),
'forening': ('forening',),
'foreninga': ('forening',),
'foreningen': ('forening',),
'foreningene': ('forening',),
'foreninger': ('forening',),
'foreningsliv': ('foreningsliv',),
'foreningsliva': ('foreningsliv',),
'foreningslivene': ('foreningsliv',),
'foreningslivet': ('foreningsliv',),
'foreningsmedlem': ('foreningsmedlem',),
'foreningsmedlemma': ('foreningsmedlem',),
'foreningsmedlemmene': ('foreningsmedlem',),
'foreningsmedlemmer': ('foreningsmedlem',),
'foreningsmedlemmet': ('foreningsmedlem',),
'foreningsmøta': ('foreningsmøte',),
'foreningsmøte': ('foreningsmøte',),
'foreningsmøtene': ('foreningsmøte',),
'foreningsmøter': ('foreningsmøte',),
'foreningsmøtet': ('foreningsmøte',),
'foreningsvirksomhet': ('foreningsvirksomhet',),
'foreningsvirksomheta': ('foreningsvirksomhet',),
'foreningsvirksomheten': ('foreningsvirksomhet',),
'foreningsvirksomhetene': ('foreningsvirksomhet',),
'foreningsvirksomheter': ('foreningsvirksomhet',),
'forenkling': ('forenkling',),
'forenklinga': ('forenkling',),
'forenklingen': ('forenkling',),
'forenklingene': ('forenkling',),
'forenklinger': ('forenkling',),
'forespørsel': ('forespørsel',),
'forespørselen': ('forespørsel',),
'forespørslene': ('forespørsel',),
'forespørsler': ('forespørsel',),
'forestilling': ('forestilling',),
'forestillinga': ('forestilling',),
'forestillingen': ('forestilling',),
'forestillingene': ('forestilling',),
'forestillinger': ('forestilling',),
'forestillingsbilda': ('forestillingsbilde',),
'forestillingsbilde': ('forestillingsbilde',),
'forestillingsbildene': ('forestillingsbilde',),
'forestillingsbilder': ('forestillingsbilde',),
'forestillingsbildet': ('forestillingsbilde',),
'forestillingsevna': ('forestillingsevne',),
'forestillingsevne': ('forestillingsevne',),
'forestillingsevnen': ('forestillingsevne',),
'forestillingsevnene': ('forestillingsevne',),
'forestillingsevner': ('forestillingsevne',),
'forestillingskrets': ('forestillingskrets',),
'forestillingskretsen': ('forestillingskrets',),
'forestillingskretsene': ('forestillingskrets',),
'forestillingskretser': ('forestillingskrets',),
'foretagende': ('foretagende',),
'foretagendene': ('foretagende',),
'foretagender': ('foretagende',),
'foretagendet': ('foretagende',),
'foretak': ('foretak',),
'foretaka': ('foretak',),
'foretakene': ('foretak',),
'foretaket': ('foretak',),
'foretakende': ('foretakende',),
'foretakendene': ('foretakende',),
'foretakender': ('foretakende',),
'foretakendet': ('foretakende',),
'foretakseier': ('foretakseier',),
'foretakseiere': ('foretakseier',),
'foretakseieren': ('foretakseier',),
'foretakseierer': ('foretakseier',),
'foretakseierne': ('foretakseier',),
'foretaksform': ('foretaksform',),
'foretaksforma': ('foretaksform',),
'foretaksformen': ('foretaksform',),
'foretaksformene': ('foretaksform',),
'foretaksformer': ('foretaksform',),
'foretaksomhet': ('foretaksomhet',),
'foretaksomheta': ('foretaksomhet',),
'foretaksomheten': ('foretaksomhet',),
'foretaksomhetene': ('foretaksomhet',),
'foretaksomheter': ('foretaksomhet',),
'foretaksøkonomi': ('foretaksøkonomi',),
'foretaksøkonomien': ('foretaksøkonomi',),
'foretaksøkonomiene': ('foretaksøkonomi',),
'foretaksøkonomier': ('foretaksøkonomi',),
'foreteelse': ('foreteelse',),
'foreteelsen': ('foreteelse',),
'foreteelsene': ('foreteelse',),
'foreteelser': ('foreteelse',),
'foretreda': ('foretrede',),
'foretrede': ('foretrede',),
'foretredene': ('foretrede',),
'foretreder': ('foretrede',),
'foretredet': ('foretrede',),
'forevigelse': ('forevigelse',),
'forevigelsen': ('forevigelse',),
'forevigelsene': ('forevigelse',),
'forevigelser': ('forevigelse',),
'foreviser': ('foreviser',),
'forevisere': ('foreviser',),
'foreviseren': ('foreviser',),
'foreviserer': ('foreviser',),
'foreviserne': ('foreviser',),
'forfader': ('forfader',),
'forfaderen': ('forfader',),
'forfedre': ('forfader',),
'forfedrene': ('forfader',),
'forfall': ('forfall',),
'forfalla': ('forfall',),
'forfallene': ('forfall',),
'forfallet': ('forfall',),
'forfall': ('forfall',),
'forfalla': ('forfall',),
'forfallene': ('forfall',),
'forfallet': ('forfall',),
'forfallsdag': ('forfallsdag',),
'forfallsdagen': ('forfallsdag',),
'forfallsdagene': ('forfallsdag',),
'forfallsdager': ('forfallsdag',),
'forfallstid': ('forfallstid',),
'forfallstida': ('forfallstid',),
'forfallstiden': ('forfallstid',),
'forfallstidene': ('forfallstid',),
'forfallstider': ('forfallstid',),
'forfalsking': ('forfalsking',),
'forfalskinga': ('forfalsking',),
'forfalskingen': ('forfalsking',),
'forfalskingene': ('forfalsking',),
'forfalskinger': ('forfalsking',),
'forfalskning': ('forfalskning',),
'forfalskninga': ('forfalskning',),
'forfalskningen': ('forfalskning',),
'forfalskningene': ('forfalskning',),
'forfalskninger': ('forfalskning',),
'forfatning': ('forfatning',),
'forfatninga': ('forfatning',),
'forfatningen': ('forfatning',),
'forfatningene': ('forfatning',),
'forfatninger': ('forfatning',),
'forfatningsbrott': ('forfatningsbrott',),
'forfatningsbrotta': ('forfatningsbrott',),
'forfatningsbrottene': ('forfatningsbrott',),
'forfatningsbrottet': ('forfatningsbrott',),
'forfatningsbrudd': ('forfatningsbrudd',),
'forfatningsbrudda': ('forfatningsbrudd',),
'forfatningsbruddene': ('forfatningsbrudd',),
'forfatningsbruddet': ('forfatningsbrudd',),
'forfatter': ('forfatter',),
'forfattere': ('forfatter',),
'forfatteren': ('forfatter',),
'forfatterer': ('forfatter',),
'forfatterne': ('forfatter',),
'forfatterforening': ('forfatterforening',),
'forfatterforeninga': ('forfatterforening',),
'forfatterforeningen': ('forfatterforening',),
'forfatterforeningene': ('forfatterforening',),
'forfatterforeninger': ('forfatterforening',),
'forfatterhonorar': ('forfatterhonorar',),
'forfatterhonorara': ('forfatterhonorar',),
'forfatterhonorarene': ('forfatterhonorar',),
'forfatterhonorarer': ('forfatterhonorar',),
'forfatterhonoraret': ('forfatterhonorar',),
'forfatteri': ('forfatteri',),
'forfatteria': ('forfatteri',),
'forfatteriene': ('forfatteri',),
'forfatterier': ('forfatteri',),
'forfatteriet': ('forfatteri',),
'forfatterrett': ('forfatterrett',),
'forfatterretten': ('forfatterrett',),
'forfatterrettene': ('forfatterrett',),
'forfatterretter': ('forfatterrett',),
'forfatterskap': ('forfatterskap',),
'forfatterskapa': ('forfatterskap',),
'forfatterskapene': ('forfatterskap',),
'forfatterskapet': ('forfatterskap',),
'forfedre': ('forfedre',),
'forfedrene': ('forfedre',),
'forferdelse': ('forferdelse',),
'forferdelsen': ('forferdelse',),
'forferdelsene': ('forferdelse',),
'forferdelser': ('forferdelse',),
'forfilm': ('forfilm',),
'forfilmen': ('forfilm',),
'forfilmene': ('forfilm',),
'forfilmer': ('forfilm',),
'forfjor': ('forfjor',),
'forflytning': ('forflytning',),
'forflytninga': ('forflytning',),
'forflytningen': ('forflytning',),
'forflytningene': ('forflytning',),
'forflytninger': ('forflytning',),
'forfriskning': ('forfriskning',),
'forfriskninga': ('forfriskning',),
'forfriskningen': ('forfriskning',),
'forfriskningene': ('forfriskning',),
'forfriskninger': ('forfriskning',),
'forfrysning': ('forfrysning',),
'forfrysninga': ('forfrysning',),
'forfrysningen': ('forfrysning',),
'forfrysningene': ('forfrysning',),
'forfrysninger': ('forfrysning',),
'forfølgelse': ('forfølgelse',),
'forfølgelsen': ('forfølgelse',),
'forfølgelsene': ('forfølgelse',),
'forfølgelser': ('forfølgelse',),
'forfølgelsesmani': ('forfølgelsesmani',),
'forfølgelsesmanien': ('forfølgelsesmani',),
'forfølgelsesmaniene': ('forfølgelsesmani',),
'forfølgelsesmanier': ('forfølgelsesmani',),
'forfølgelsesritt': ('forfølgelsesritt',),
'forfølgelsesritta': ('forfølgelsesritt',),
'forfølgelsesrittene': ('forfølgelsesritt',),
'forfølgelsesrittet': ('forfølgelsesritt',),
'forfølgelsesvanvett': ('forfølgelsesvanvett',),
'forfølgelsesvanvetta': ('forfølgelsesvanvett',),
'forfølgelsesvanvettene': ('forfølgelsesvanvett',),
'forfølgelsesvanvettet': ('forfølgelsesvanvett',),
'forfølgelsesvanvidd': ('forfølgelsesvanvidd',),
'forfølgelsesvanvidda': ('forfølgelsesvanvidd',),
'forfølgelsesvanviddene': ('forfølgelsesvanvidd',),
'forfølgelsesvanviddet': ('forfølgelsesvanvidd',),
'forfølger': ('forfølger',),
'forfølgere': ('forfølger',),
'forfølgeren': ('forfølger',),
'forfølgerer': ('forfølger',),
'forfølgerne': ('forfølger',),
'forfølging': ('forfølging',),
'forfølginga': ('forfølging',),
'forfølgingen': ('forfølging',),
'forfølgingene': ('forfølging',),
'forfølginger': ('forfølging',),
'forfølgning': ('forfølgning',),
'forfølgninga': ('forfølgning',),
'forfølgningen': ('forfølgning',),
'forfølgningene': ('forfølgning',),
'forfølgninger': ('forfølgning',),
'forfører': ('forfører',),
'forførere': ('forfører',),
'forføreren': ('forfører',),
'forførerer': ('forfører',),
'forførerne': ('forfører',),
'forføyning': ('forføyning',),
'forføyninga': ('forføyning',),
'forføyningen': ('forføyning',),
'forføyningene': ('forføyning',),
'forføyninger': ('forføyning',),
'forgard': ('forgard',),
'forgarden': ('forgard',),
'forgardene': ('forgard',),
'forgarder': ('forgard',),
'forgasser': ('forgasser',),
'forgassere': ('forgasser',),
'forgasseren': ('forgasser',),
'forgasserer': ('forgasser',),
'forgasserne': ('forgasser',),
'forgiftning': ('forgiftning',),
'forgiftninga': ('forgiftning',),
'forgiftningen': ('forgiftning',),
'forgiftningene': ('forgiftning',),
'forgiftninger': ('forgiftning',),
'forgjenger': ('forgjenger',),
'forgjengere': ('forgjenger',),
'forgjengeren': ('forgjenger',),
'forgjengerer': ('forgjenger',),
'forgjengerne': ('forgjenger',),
'forglemmegei': ('forglemmegei',),
'forglemmegeien': ('forglemmegei',),
'forglemmegeiene': ('forglemmegei',),
'forglemmegeier': ('forglemmegei',),
'forglemmelse': ('forglemmelse',),
'forglemmelsen': ('forglemmelse',),
'forglemmelsene': ('forglemmelse',),
'forglemmelser': ('forglemmelse',),
'forglømmelse': ('forglømmelse',),
'forglømmelsen': ('forglømmelse',),
'forglømmelsene': ('forglømmelse',),
'forglømmelser': ('forglømmelse',),
'forgodtbefinnenda': ('forgodtbefinnende',),
'forgodtbefinnende': ('forgodtbefinnende',),
'forgodtbefinnendene': ('forgodtbefinnende',),
'forgodtbefinnender': ('forgodtbefinnende',),
'forgodtbefinnendet': ('forgodtbefinnende',),
'forgreining': ('forgreining',),
'forgreininga': ('forgreining',),
'forgreiningen': ('forgreining',),
'forgreiningene': ('forgreining',),
'forgreininger': ('forgreining',),
'forgrening': ('forgrening',),
'forgreninga': ('forgrening',),
'forgreningen': ('forgrening',),
'forgreningene': ('forgrening',),
'forgreninger': ('forgrening',),
'forgrunn': ('forgrunn',),
'forgrunnen': ('forgrunn',),
'forgrunnene': ('forgrunn',),
'forgrunner': ('forgrunn',),
'forgrunnsfigur': ('forgrunnsfigur',),
'forgrunnsfiguren': ('forgrunnsfigur',),
'forgrunnsfigurene': ('forgrunnsfigur',),
'forgrunnsfigurer': ('forgrunnsfigur',),
'forgrunnsskikkelse': ('forgrunnsskikkelse',),
'forgrunnsskikkelsen': ('forgrunnsskikkelse',),
'forgrunnsskikkelsene': ('forgrunnsskikkelse',),
'forgrunnsskikkelser': ('forgrunnsskikkelse',),
'forgubbing': ('forgubbing',),
'forgubbinga': ('forgubbing',),
'forgubbingen': ('forgubbing',),
'forgubbingene': ('forgubbing',),
'forgubbinger': ('forgubbing',),
'forgåelse': ('forgåelse',),
'forgåelsen': ('forgåelse',),
'forgåelsene': ('forgåelse',),
'forgåelser': ('forgåelse',),
'forgård': ('forgård',),
'forgården': ('forgård',),
'forgårdene': ('forgård',),
'forgårder': ('forgård',),
'forgårs': ('forgårs',),
'forhalingstaktikk': ('forhalingstaktikk',),
'forhalingstaktikken': ('forhalingstaktikk',),
'forhalingstaktikkene': ('forhalingstaktikk',),
'forhalingstaktikker': ('forhalingstaktikk',),
'forhalingsvinsj': ('forhalingsvinsj',),
'forhalingsvinsjen': ('forhalingsvinsj',),
'forhalingsvinsjene': ('forhalingsvinsj',),
'forhalingsvinsjer': ('forhalingsvinsj',),
'forhall': ('forhall',),
'forhallen': ('forhall',),
'forhallene': ('forhall',),
'forhaller': ('forhall',),
'forhand': ('forhand',),
'forhandler': ('forhandler',),
'forhandlere': ('forhandler',),
'forhandleren': ('forhandler',),
'forhandlerer': ('forhandler',),
'forhandlerne': ('forhandler',),
'forhandling': ('forhandling',),
'forhandlinga': ('forhandling',),
'forhandlingen': ('forhandling',),
'forhandlingene': ('forhandling',),
'forhandlinger': ('forhandling',),
'forhandlingsbord': ('forhandlingsbord',),
'forhandlingsborda': ('forhandlingsbord',),
'forhandlingsbordene': ('forhandlingsbord',),
'forhandlingsborder': ('forhandlingsbord',),
'forhandlingsbordet': ('forhandlingsbord',),
'forhandlingsemna': ('forhandlingsemne',),
'forhandlingsemne': ('forhandlingsemne',),
'forhandlingsemnene': ('forhandlingsemne',),
'forhandlingsemner': ('forhandlingsemne',),
'forhandlingsemnet': ('forhandlingsemne',),
'forhandlingsgrunnlag': ('forhandlingsgrunnlag',),
'forhandlingsgrunnlaga': ('forhandlingsgrunnlag',),
'forhandlingsgrunnlagene': ('forhandlingsgrunnlag',),
'forhandlingsgrunnlaget': ('forhandlingsgrunnlag',),
'forhandlingsposisjon': ('forhandlingsposisjon',),
'forhandlingsposisjonen': ('forhandlingsposisjon',),
'forhandlingsposisjonene': ('forhandlingsposisjon',),
'forhandlingsposisjoner': ('forhandlingsposisjon',),
'forhandlingsrett': ('forhandlingsrett',),
'forhandlingsretten': ('forhandlingsrett',),
'forhandlingsrettene': ('forhandlingsrett',),
'forhandlingsretter': ('forhandlingsrett',),
'forhandlingsrunde': ('forhandlingsrunde',),
'forhandlingsrunden': ('forhandlingsrunde',),
'forhandlingsrundene': ('forhandlingsrunde',),
'forhandlingsrunder': ('forhandlingsrunde',),
'forhandsavgjørelse': ('forhandsavgjørelse',),
'forhandsavgjørelsen': ('forhandsavgjørelse',),
'forhandsavgjørelsene': ('forhandsavgjørelse',),
'forhandsavgjørelser': ('forhandsavgjørelse',),
'forhandsdom': ('forhandsdom',),
'forhandsdommen': ('forhandsdom',),
'forhandsdommene': ('forhandsdom',),
'forhandsdommer': ('forhandsdom',),
'forhandsmelding': ('forhandsmelding',),
'forhandsmeldinga': ('forhandsmelding',),
'forhandsmeldingen': ('forhandsmelding',),
'forhandsmeldingene': ('forhandsmelding',),
'forhandsmeldinger': ('forhandsmelding',),
'forhandsomtale': ('forhandsomtale',),
'forhandsomtalen': ('forhandsomtale',),
'forhandsomtalene': ('forhandsomtale',),
'forhandsomtaler': ('forhandsomtale',),
'forhandssalg': ('forhandssalg',),
'forhandssalga': ('forhandssalg',),
'forhandssalgene': ('forhandssalg',),
'forhandssalget': ('forhandssalg',),
'forhandsstemme': ('forhandsstemme',),
'forhandsstemmen': ('forhandsstemme',),
'forhandsstemmene': ('forhandsstemme',),
'forhandsstemmer': ('forhandsstemme',),
'forhandstilsagn': ('forhandstilsagn',),
'forhandstilsagna': ('forhandstilsagn',),
'forhandstilsagnene': ('forhandstilsagn',),
'forhandstilsagnet': ('forhandstilsagn',),
'forheng': ('forheng',),
'forhenga': ('forheng',),
'forhengene': ('forheng',),
'forhenget': ('forheng',),
'forhindring': ('forhindring',),
'forhindringa': ('forhindring',),
'forhindringen': ('forhindring',),
'forhindringene': ('forhindring',),
'forhindringer': ('forhindring',),
'forhistoria': ('forhistorie',),
'forhistorie': ('forhistorie',),
'forhistorien': ('forhistorie',),
'forhistoriene': ('forhistorie',),
'forhistorier': ('forhistorie',),
'forhjul': ('forhjul',),
'forhjula': ('forhjul',),
'forhjulene': ('forhjul',),
'forhjulet': ('forhjul',),
'forhjulsdrift': ('forhjulsdrift',),
'forhjulsdrifta': ('forhjulsdrift',),
'forhjulsdriften': ('forhjulsdrift',),
'forhjulsdriftene': ('forhjulsdrift',),
'forhjulsdrifter': ('forhjulsdrift',),
'forhjulsnav': ('forhjulsnav',),
'forhjulsnava': ('forhjulsnav',),
'forhjulsnavene': ('forhjulsnav',),
'forhjulsnavet': ('forhjulsnav',),
'forhjulsstilling': ('forhjulsstilling',),
'forhjulsstillinga': ('forhjulsstilling',),
'forhjulsstillingen': ('forhjulsstilling',),
'forhjulsstillingene': ('forhjulsstilling',),
'forhjulsstillinger': ('forhjulsstilling',),
'forhogning': ('forhogning',),
'forhogninga': ('forhogning',),
'forhogningen': ('forhogning',),
'forhogningene': ('forhogning',),
'forhogninger': ('forhogning',),
'forhold': ('forhold',),
'forholda': ('forhold',),
'forholdene': ('forhold',),
'forholdet': ('forhold',),
'forholdsordre': ('forholdsordre',),
'forholdsordren': ('forholdsordre',),
'forholdsordrene': ('forholdsordre',),
'forholdsordrer': ('forholdsordre',),
'forholdsregel': ('forholdsregel',),
'forholdsregelen': ('forholdsregel',),
'forholdsreglene': ('forholdsregel',),
'forholdsregler': ('forholdsregel',),
'forholdstal': ('forholdstal',),
'forholdstala': ('forholdstal',),
'forholdstalene': ('forholdstal',),
'forholdstalet': ('forholdstal',),
'forholdstall': ('forholdstall',),
'forholdstalla': ('forholdstall',),
'forholdstallene': ('forholdstall',),
'forholdstallet': ('forholdstall',),
'forholdstallsvalg': ('forholdstallsvalg',),
'forholdstallsvalga': ('forholdstallsvalg',),
'forholdstallsvalgene': ('forholdstallsvalg',),
'forholdstallsvalget': ('forholdstallsvalg',),
'forholdstalsvalg': ('forholdstalsvalg',),
'forholdstalsvalga': ('forholdstalsvalg',),
'forholdstalsvalgene': ('forholdstalsvalg',),
'forholdstalsvalget': ('forholdstalsvalg',),
'forhud': ('forhud',),
'forhuda': ('forhud',),
'forhuden': ('forhud',),
'forhudene': ('forhud',),
'forhuder': ('forhud',),
'forhudning': ('forhudning',),
'forhudninga': ('forhudning',),
'forhudningen': ('forhudning',),
'forhudningene': ('forhudning',),
'forhudninger': ('forhudning',),
'forhudningspapp': ('forhudningspapp',),
'forhudningspappen': ('forhudningspapp',),
'forhudningspappene': ('forhudningspapp',),
'forhudningspapper': ('forhudningspapp',),
'forhugning': ('forhugning',),
'forhugninga': ('forhugning',),
'forhugningen': ('forhugning',),
'forhugningene': ('forhugning',),
'forhugninger': ('forhugning',),
'forhåndsavgjørelse': ('forhåndsavgjørelse',),
'forhåndsavgjørelsen': ('forhåndsavgjørelse',),
'forhåndsavgjørelsene': ('forhåndsavgjørelse',),
'forhåndsavgjørelser': ('forhåndsavgjørelse',),
'forhåndsdom': ('forhåndsdom',),
'forhåndsdommen': ('forhåndsdom',),
'forhåndsdommene': ('forhåndsdom',),
'forhåndsdommer': ('forhåndsdom',),
'forhåndsmelding': ('forhåndsmelding',),
'forhåndsmeldinga': ('forhåndsmelding',),
'forhåndsmeldingen': ('forhåndsmelding',),
'forhåndsmeldingene': ('forhåndsmelding',),
'forhåndsmeldinger': ('forhåndsmelding',),
'forhåndsomtale': ('forhåndsomtale',),
'forhåndsomtalen': ('forhåndsomtale',),
'forhåndsomtalene': ('forhåndsomtale',),
'forhåndsomtaler': ('forhåndsomtale',),
'forhåndssalg': ('forhåndssalg',),
'forhåndssalga': ('forhåndssalg',),
'forhåndssalgene': ('forhåndssalg',),
'forhåndssalget': ('forhåndssalg',),
'forhåndsstemme': ('forhåndsstemme',),
'forhåndsstemmen': ('forhåndsstemme',),
'forhåndsstemmene': ('forhåndsstemme',),
'forhåndsstemmer': ('forhåndsstemme',),
'forhåndstilsagn': ('forhåndstilsagn',),
'forhåndstilsagna': ('forhåndstilsagn',),
'forhåndstilsagnene': ('forhåndstilsagn',),
'forhåndstilsagnet': ('forhåndstilsagn',),
'forhåpning': ('forhåpning',),
'forhåpninga': ('forhåpning',),
'forhåpningen': ('forhåpning',),
'forhåpningene': ('forhåpning',),
'forhåpninger': ('forhåpning',),
'forhør': ('forhør',),
'forhøra': ('forhør',),
'forhørene': ('forhør',),
'forhøret': ('forhør',),
'forhørsdommer': ('forhørsdommer',),
'forhørsdommere': ('forhørsdommer',),
'forhørsdommeren': ('forhørsdommer',),
'forhørsdommerer': ('forhørsdommer',),
'forhørsdommerne': ('forhørsdommer',),
'forhørsmetode': ('forhørsmetode',),
'forhørsmetoden': ('forhørsmetode',),
'forhørsmetodene': ('forhørsmetode',),
'forhørsmetoder': ('forhørsmetode',),
'forhørsrett': ('forhørsrett',),
'forhørsretten': ('forhørsrett',),
'forhørsrettene': ('forhørsrett',),
'forhørsretter': ('forhørsrett',),
'forhøyelse': ('forhøyelse',),
'forhøyelsen': ('forhøyelse',),
'forhøyelsene': ('forhøyelse',),
'forhøyelser': ('forhøyelse',),
'forhøyning': ('forhøyning',),
'forhøyninga': ('forhøyning',),
'forhøyningen': ('forhøyning',),
'forhøyningene': ('forhøyning',),
'forhøyninger': ('forhøyning',),
'forint': ('forint',),
'forinten': ('forint',),
'forintene': ('forint',),
'forinter': ('forint',),
'forjettelse': ('forjettelse',),
'forjettelsen': ('forjettelse',),
'forjettelsene': ('forjettelse',),
'forjettelser': ('forjettelse',),
'fork': ('fork',),
'forken': ('fork',),
'forkene': ('fork',),
'forker': ('fork',),
'forkalking': ('forkalking',),
'forkalkinga': ('forkalking',),
'forkalkingen': ('forkalking',),
'forkalkingene': ('forkalking',),
'forkalkinger': ('forkalking',),
'forkalkning': ('forkalkning',),
'forkalkninga': ('forkalkning',),
'forkalkningen': ('forkalkning',),
'forkalkningene': ('forkalkning',),
'forkalkninger': ('forkalkning',),
'forkammer': ('forkammer',),
'forkammeret': ('forkammer',),
'forkamra': ('forkammer',),
'forkamre': ('forkammer',),
'forkamrene': ('forkammer',),
'forkant': ('forkant',),
'forkanten': ('forkant',),
'forkantene': ('forkant',),
'forkanter': ('forkant',),
'forkastelsesreaksjon': ('forkastelsesreaksjon',),
'forkastelsesreaksjonen': ('forkastelsesreaksjon',),
'forkastelsesreaksjonene': ('forkastelsesreaksjon',),
'forkastelsesreaksjoner': ('forkastelsesreaksjon',),
'forkastning': ('forkastning',),
'forkastninga': ('forkastning',),
'forkastningen': ('forkastning',),
'forkastningene': ('forkastning',),
'forkastninger': ('forkastning',),
'forkim': ('forkim',),
'forkima': ('forkim',),
'forkimen': ('forkim',),
'forkimene': ('forkim',),
'forkimer': ('forkim',),
'forkimet': ('forkim',),
'forkjemper': ('forkjemper',),
'forkjempere': ('forkjemper',),
'forkjemperen': ('forkjemper',),
'forkjemperer': ('forkjemper',),
'forkjemperne': ('forkjemper',),
'forkjærlighet': ('forkjærlighet',),
'forkjærligheta': ('forkjærlighet',),
'forkjærligheten': ('forkjærlighet',),
'forkjærlighetene': ('forkjærlighet',),
'forkjærligheter': ('forkjærlighet',),
'forkjølelse': ('forkjølelse',),
'forkjølelsen': ('forkjølelse',),
'forkjølelsene': ('forkjølelse',),
'forkjølelser': ('forkjølelse',),
'forkjøp': ('forkjøp',),
'forkjøpa': ('forkjøp',),
'forkjøpene': ('forkjøp',),
'forkjøpet': ('forkjøp',),
'forkjøpsrett': ('forkjøpsrett',),
'forkjøpsretten': ('forkjøpsrett',),
'forkjøpsrettene': ('forkjøpsrett',),
'forkjøpsretter': ('forkjøpsrett',),
'forkjørsrett': ('forkjørsrett',),
'forkjørsretten': ('forkjørsrett',),
'forkjørsrettene': ('forkjørsrett',),
'forkjørsretter': ('forkjørsrett',),
'forkjørsveg': ('forkjørsveg',),
'forkjørsvegen': ('forkjørsveg',),
'forkjørsvegene': ('forkjørsveg',),
'forkjørsveger': ('forkjørsveg',),
'forkjørsvei': ('forkjørsvei',),
'forkjørsveien': ('forkjørsvei',),
'forkjørsveiene': ('forkjørsvei',),
'forkjørsveier': ('forkjørsvei',),
'forklarelse': ('forklarelse',),
'forklarelsen': ('forklarelse',),
'forklarelsene': ('forklarelse',),
'forklarelser': ('forklarelse',),
'forklarelsesdag': ('forklarelsesdag',),
'forklarelsesdagen': ('forklarelsesdag',),
'forklarelsesdagene': ('forklarelsesdag',),
'forklarelsesdager': ('forklarelsesdag',),
'forklaring': ('forklaring',),
'forklaringa': ('forklaring',),
'forklaringen': ('forklaring',),
'forklaringene': ('forklaring',),
'forklaringer': ('forklaring',),
'forkle': ('forkle',),
'forkleet': ('forkle',),
'forklær': ('forkle',),
'forklærne': ('forkle',),
'forkledning': ('forkledning',),
'forkledninga': ('forkledning',),
'forkledningen': ('forkledning',),
'forkledningene': ('forkledning',),
'forkledninger': ('forkledning',),
'forkleinelse': ('forkleinelse',),
'forkleinelsen': ('forkleinelse',),
'forkleinelsene': ('forkleinelse',),
'forkleinelser': ('forkleinelse',),
'forkortelse': ('forkortelse',),
'forkortelsen': ('forkortelse',),
'forkortelsene': ('forkortelse',),
'forkortelser': ('forkortelse',),
'forkorting': ('forkorting',),
'forkortinga': ('forkorting',),
'forkortingen': ('forkorting',),
'forkortingene': ('forkorting',),
'forkortinger': ('forkorting',),
'forkunnskap': ('forkunnskap',),
'forkunnskapen': ('forkunnskap',),
'forkunnskapene': ('forkunnskap',),
'forkunnskaper': ('forkunnskap',),
'forkvinna': ('forkvinne',),
'forkvinne': ('forkvinne',),
'forkvinnen': ('forkvinne',),
'forkvinnene': ('forkvinne',),
'forkvinner': ('forkvinne',),
'forkynnelse': ('forkynnelse',),
'forkynnelsen': ('forkynnelse',),
'forkynnelsene': ('forkynnelse',),
'forkynnelser': ('forkynnelse',),
'forkynner': ('forkynner',),
'forkynnere': ('forkynner',),
'forkynneren': ('forkynner',),
'forkynnerer': ('forkynner',),
'forkynnerne': ('forkynner',),
'forkynning': ('forkynning',),
'forkynninga': ('forkynning',),
'forkynningen': ('forkynning',),
'forkynningene': ('forkynning',),
'forkynninger': ('forkynning',),
'forlader': ('forlader',),
'forladere': ('forlader',),
'forladeren': ('forlader',),
'forladerer': ('forlader',),
'forladerne': ('forlader',),
'forladning': ('forladning',),
'forladninga': ('forladning',),
'forladningen': ('forladning',),
'forladningene': ('forladning',),
'forladninger': ('forladning',),
'forlag': ('forlag',),
'forlaga': ('forlag',),
'forlagene': ('forlag',),
'forlaget': ('forlag',),
'forlagsrett': ('forlagsrett',),
'forlagsretten': ('forlagsrett',),
'forlagsrettene': ('forlagsrett',),
'forlagsretter': ('forlagsrett',),
'forlagssjef': ('forlagssjef',),
'forlagssjefen': ('forlagssjef',),
'forlagssjefene': ('forlagssjef',),
'forlagssjefer': ('forlagssjef',),
'forlagsvirksomhet': ('forlagsvirksomhet',),
'forlagsvirksomheta': ('forlagsvirksomhet',),
'forlagsvirksomheten': ('forlagsvirksomhet',),
'forlagsvirksomhetene': ('forlagsvirksomhet',),
'forlagsvirksomheter': ('forlagsvirksomhet',),
'forlangende': ('forlangende',),
'forlangendene': ('forlangende',),
'forlangender': ('forlangende',),
'forlangendet': ('forlangende',),
'forlatelse': ('forlatelse',),
'forlatelsen': ('forlatelse',),
'forlatelsene': ('forlatelse',),
'forlatelser': ('forlatelse',),
'forledd': ('forledd',),
'forledda': ('forledd',),
'forleddene': ('forledd',),
'forleddet': ('forledd',),
'forlegenhet': ('forlegenhet',),
'forlegenheta': ('forlegenhet',),
'forlegenheten': ('forlegenhet',),
'forlegenhetene': ('forlegenhet',),
'forlegenheter': ('forlegenhet',),
'forlegger': ('forlegger',),
'forleggere': ('forlegger',),
'forleggeren': ('forlegger',),
'forleggerer': ('forlegger',),
'forleggerne': ('forlegger',),
'forlegger': ('forlegger',),
'forleggere': ('forlegger',),
'forleggeren': ('forlegger',),
'forleggerer': ('forlegger',),
'forleggerne': ('forlegger',),
'forlegning': ('forlegning',),
'forlegninga': ('forlegning',),
'forlegningen': ('forlegning',),
'forlegningene': ('forlegning',),
'forlegninger': ('forlegning',),
'forlengelse': ('forlengelse',),
'forlengelsen': ('forlengelse',),
'forlengelsene': ('forlengelse',),
'forlengelser': ('forlengelse',),
'forlengning': ('forlengning',),
'forlengninga': ('forlengning',),
'forlengningen': ('forlengning',),
'forlengningene': ('forlengning',),
'forlengninger': ('forlengning',),
'forlik': ('forlik',),
'forlika': ('forlik',),
'forlikene': ('forlik',),
'forliket': ('forlik',),
'forliksklage': ('forliksklage',),
'forliksklagen': ('forliksklage',),
'forliksklagene': ('forliksklage',),
'forliksklager': ('forliksklage',),
'forliksmann': ('forliksmann',),
'forliksmannen': ('forliksmann',),
'forliksmenn': ('forliksmann',),
'forliksmennene': ('forliksmann',),
'forliksmegling': ('forliksmegling',),
'forliksmeglinga': ('forliksmegling',),
'forliksmeglingen': ('forliksmegling',),
'forliksmeglingene': ('forliksmegling',),
'forliksmeglinger': ('forliksmegling',),
'forliksmekling': ('forliksmekling',),
'forliksmeklinga': ('forliksmekling',),
'forliksmeklingen': ('forliksmekling',),
'forliksmeklingene': ('forliksmekling',),
'forliksmeklinger': ('forliksmekling',),
'forliksråd': ('forliksråd',),
'forliksråda': ('forliksråd',),
'forliksrådene': ('forliksråd',),
'forliksrådet': ('forliksråd',),
'forliksvilkår': ('forliksvilkår',),
'forliksvilkåra': ('forliksvilkår',),
'forliksvilkårene': ('forliksvilkår',),
'forliksvilkåret': ('forliksvilkår',),
'forlis': ('forlis',),
'forlisa': ('forlis',),
'forlisene': ('forlis',),
'forliset': ('forlis',),
'forlodd': ('forlodd',),
'forlodden': ('forlodd',),
'forloddene': ('forlodd',),
'forlodder': ('forlodd',),
'forlovede': ('forlovede',),
'forloveden': ('forlovede',),
'forlovedene': ('forlovede',),
'forloveder': ('forlovede',),
'forlovelse': ('forlovelse',),
'forlovelsen': ('forlovelse',),
'forlovelsene': ('forlovelse',),
'forlovelser': ('forlovelse',),
'forlovelsesring': ('forlovelsesring',),
'forlovelsesringen': ('forlovelsesring',),
'forlovelsesringene': ('forlovelsesring',),
'forlovelsesringer': ('forlovelsesring',),
'forlover': ('forlover',),
'forlovere': ('forlover',),
'forloveren': ('forlover',),
'forloverer': ('forlover',),
'forloverne': ('forlover',),
'forlydende': ('forlydende',),
'forlydendene': ('forlydende',),
'forlydender': ('forlydende',),
'forlydendet': ('forlydende',),
'forlystelse': ('forlystelse',),
'forlystelsen': ('forlystelse',),
'forlystelsene': ('forlystelse',),
'forlystelser': ('forlystelse',),
'forlystelsessted': ('forlystelsessted',),
'forlystelsesstedene': ('forlystelsessted',),
'forlystelsessteder': ('forlystelsessted',),
'forlystelsesstedet': ('forlystelsessted',),
'forløp': ('forløp',),
'forløpa': ('forløp',),
'forløpene': ('forløp',),
'forløpet': ('forløp',),
'forløper': ('forløper',),
'forløpere': ('forløper',),
'forløperen': ('forløper',),
'forløperer': ('forløper',),
'forløperne': ('forløper',),
'forløser': ('forløser',),
'forløsere': ('forløser',),
'forløseren': ('forløser',),
'forløserer': ('forløser',),
'forløserne': ('forløser',),
'forløsning': ('forløsning',),
'forløsninga': ('forløsning',),
'forløsningen': ('forløsning',),
'forløsningene': ('forløsning',),
'forløsninger': ('forløsning',),
'forløsningsreligion': ('forløsningsreligion',),
'forløsningsreligionen': ('forløsningsreligion',),
'forløsningsreligionene': ('forløsningsreligion',),
'forløsningsreligioner': ('forløsningsreligion',),
'forløsningsverk': ('forløsningsverk',),
'forløsningsverka': ('forløsningsverk',),
'forløsningsverkene': ('forløsningsverk',),
'forløsningsverker': ('forløsningsverk',),
'forløsningsverket': ('forløsningsverk',),
'forløyser': ('forløyser',),
'forløysere': ('forløyser',),
'forløyseren': ('forløyser',),
'forløyserer': ('forløyser',),
'forløyserne': ('forløyser',),
'form': ('form',),
'forma': ('form',),
'formen': ('form',),
'formene': ('form',),
'former': ('form',),
'formaldehyd': ('formaldehyd',),
'formaldehyda': ('formaldehyd',),
'formaldehydene': ('formaldehyd',),
'formaldehydet': ('formaldehyd',),
'formalia': ('formalia',),
'formaliene': ('formalia',),
'formaliene': ('formalier',),
'formalier': ('formalier',),
'formalin': ('formalin',),
'formalina': ('formalin',),
'formalinen': ('formalin',),
'formalinene': ('formalin',),
'formaliner': ('formalin',),
'formalinet': ('formalin',),
'formalisme': ('formalisme',),
'formalismen': ('formalisme',),
'formalismene': ('formalisme',),
'formalismer': ('formalisme',),
'formalist': ('formalist',),
'formalisten': ('formalist',),
'formalistene': ('formalist',),
'formalister': ('formalist',),
'formalitet': ('formalitet',),
'formaliteten': ('formalitet',),
'formalitetene': ('formalitet',),
'formaliteter': ('formalitet',),
'formalitetsprosedyre': ('formalitetsprosedyre',),
'formalitetsprosedyren': ('formalitetsprosedyre',),
'formalitetsprosedyrene': ('formalitetsprosedyre',),
'formalitetsprosedyrer': ('formalitetsprosedyre',),
'formalprosedyre': ('formalprosedyre',),
'formalprosedyren': ('formalprosedyre',),
'formalprosedyrene': ('formalprosedyre',),
'formalprosedyrer': ('formalprosedyre',),
'formalvitenskap': ('formalvitenskap',),
'formalvitenskapen': ('formalvitenskap',),
'formalvitenskapene': ('formalvitenskap',),
'formalvitenskaper': ('formalvitenskap',),
'formalvitskap': ('formalvitskap',),
'formalvitskapen': ('formalvitskap',),
'formalvitskapene': ('formalvitskap',),
'formalvitskaper': ('formalvitskap',),
'formaning': ('formaning',),
'formaninga': ('formaning',),
'formaningen': ('formaning',),
'formaningene': ('formaning',),
'formaninger': ('formaning',),
'formaningstale': ('formaningstale',),
'formaningstalen': ('formaningstale',),
'formaningstalene': ('formaningstale',),
'formaningstaler': ('formaningstale',),
'formann': ('formann',),
'formannen': ('formann',),
'formenn': ('formann',),
'formennene': ('formann',),
'formannskap': ('formannskap',),
'formannskapa': ('formannskap',),
'formannskapene': ('formannskap',),
'formannskaper': ('formannskap',),
'formannskapet': ('formannskap',),
'formannskapsmøta': ('formannskapsmøte',),
'formannskapsmøte': ('formannskapsmøte',),
'formannskapsmøtene': ('formannskapsmøte',),
'formannskapsmøter': ('formannskapsmøte',),
'formannskapsmøtet': ('formannskapsmøte',),
'formannskapssekretær': ('formannskapssekretær',),
'formannskapssekretæren': ('formannskapssekretær',),
'formannskapssekretærene': ('formannskapssekretær',),
'formannskapssekretærer': ('formannskapssekretær',),
'formannsskifta': ('formannsskifte',),
'formannsskifte': ('formannsskifte',),
'formannsskiftene': ('formannsskifte',),
'formannsskifter': ('formannsskifte',),
'formannsskiftet': ('formannsskifte',),
'formannsvalg': ('formannsvalg',),
'formannsvalga': ('formannsvalg',),
'formannsvalgene': ('formannsvalg',),
'formannsvalget': ('formannsvalg',),
'formannsverv': ('formannsverv',),
'formannsverva': ('formannsverv',),
'formannsvervene': ('formannsverv',),
'formannsvervet': ('formannsverv',),
'formasjon': ('formasjon',),
'formasjonen': ('formasjon',),
'formasjonene': ('formasjon',),
'formasjoner': ('formasjon',),
'formasjonsflyging': ('formasjonsflyging',),
'formasjonsflyginga': ('formasjonsflyging',),
'formasjonsflygingen': ('formasjonsflyging',),
'formasjonsflygingene': ('formasjonsflyging',),
'formasjonsflyginger': ('formasjonsflyging',),
'formasjonsflying': ('formasjonsflying',),
'formasjonsflyinga': ('formasjonsflying',),
'formasjonsflyingen': ('formasjonsflying',),
'formasjonsflyingene': ('formasjonsflying',),
'formasjonsflyinger': ('formasjonsflying',),
'formast': ('formast',),
'formasta': ('formast',),
'formasten': ('formast',),
'formastene': ('formast',),
'formaster': ('formast',),
'formastelse': ('formastelse',),
'formastelsen': ('formastelse',),
'formastelsene': ('formastelse',),
'formastelser': ('formastelse',),
'format': ('format',),
'formata': ('format',),
'formatene': ('format',),
'formater': ('format',),
'formatet': ('format',),
'formel': ('formel',),
'formelen': ('formel',),
'formlene': ('formel',),
'formler': ('formel',),
'formelspråk': ('formelspråk',),
'formelspråka': ('formelspråk',),
'formelspråkene': ('formelspråk',),
'formelspråket': ('formelspråk',),
'formelverk': ('formelverk',),
'formelverka': ('formelverk',),
'formelverkene': ('formelverk',),
'formelverker': ('formelverk',),
'formelverket': ('formelverk',),
'formendring': ('formendring',),
'formendringa': ('formendring',),
'formendringen': ('formendring',),
'formendringene': ('formendring',),
'formendringer': ('formendring',),
'formendringsevna': ('formendringsevne',),
'formendringsevne': ('formendringsevne',),
'formendringsevnen': ('formendringsevne',),
'formendringsevnene': ('formendringsevne',),
'formendringsevner': ('formendringsevne',),
'formening': ('formening',),
'formeninga': ('formening',),
'formeningen': ('formening',),
'formeningene': ('formening',),
'formeninger': ('formening',),
'former': ('former',),
'formere': ('former',),
'formeren': ('former',),
'formerer': ('former',),
'formerne': ('former',),
'formering': ('formering',),
'formeringa': ('formering',),
'formeringen': ('formering',),
'formeringene': ('formering',),
'formeringer': ('formering',),
'formgiing': ('formgiing',),
'formgiinga': ('formgiing',),
'formgiingen': ('formgiing',),
'formgiingene': ('formgiing',),
'formgiinger': ('formgiing',),
'formgiver': ('formgiver',),
'formgivere': ('formgiver',),
'formgiveren': ('formgiver',),
'formgiverer': ('formgiver',),
'formgiverne': ('formgiver',),
'formgiving': ('formgiving',),
'formgivinga': ('formgiving',),
'formgivingen': ('formgiving',),
'formgivingene': ('formgiving',),
'formgivinger': ('formgiving',),
'formgivning': ('formgivning',),
'formgivninga': ('formgivning',),
'formgivningen': ('formgivning',),
'formgivningene': ('formgivning',),
'formgivninger': ('formgivning',),
'formiddag': ('formiddag',),
'formiddagen': ('formiddag',),
'formiddagene': ('formiddag',),
'formiddager': ('formiddag',),
'formiddagsbryllup': ('formiddagsbryllup',),
'formiddagsbryllupa': ('formiddagsbryllup',),
'formiddagsbryllupene': ('formiddagsbryllup',),
'formiddagsbrylluper': ('formiddagsbryllup',),
'formiddagsbryllupet': ('formiddagsbryllup',),
'formiddagsvakt': ('formiddagsvakt',),
'formiddagsvakta': ('formiddagsvakt',),
'formiddagsvakten': ('formiddagsvakt',),
'formiddagsvaktene': ('formiddagsvakt',),
'formiddagsvakter': ('formiddagsvakt',),
'formidler': ('formidler',),
'formidlere': ('formidler',),
'formidleren': ('formidler',),
'formidlerer': ('formidler',),
'formidlerne': ('formidler',),
'formidling': ('formidling',),
'formidlinga': ('formidling',),
'formidlingen': ('formidling',),
'formidlingene': ('formidling',),
'formidlinger': ('formidling',),
'formidlingstjeneste': ('formidlingstjeneste',),
'formidlingstjenesten': ('formidlingstjeneste',),
'formidlingstjenestene': ('formidlingstjeneste',),
'formidlingstjenester': ('formidlingstjeneste',),
'forming': ('forming',),
'forminga': ('forming',),
'formingen': ('forming',),
'formingene': ('forming',),
'forminger': ('forming',),
'formingsfag': ('formingsfag',),
'formingsfaga': ('formingsfag',),
'formingsfagene': ('formingsfag',),
'formingsfaget': ('formingsfag',),
'formingslærer': ('formingslærer',),
'formingslærere': ('formingslærer',),
'formingslæreren': ('formingslærer',),
'formingslærerer': ('formingslærer',),
'formingslærerne': ('formingslærer',),
'forminskelse': ('forminskelse',),
'forminskelsen': ('forminskelse',),
'forminskelsene': ('forminskelse',),
'forminskelser': ('forminskelse',),
'forminskelsesord': ('forminskelsesord',),
'forminskelsesorda': ('forminskelsesord',),
'forminskelsesordene': ('forminskelsesord',),
'forminskelsesordet': ('forminskelsesord',),
'forminskelsessuffiks': ('forminskelsessuffiks',),
'forminskelsessuffiksa': ('forminskelsessuffiks',),
'forminskelsessuffiksene': ('forminskelsessuffiks',),
'forminskelsessuffikser': ('forminskelsessuffiks',),
'forminskelsessuffikset': ('forminskelsessuffiks',),
'forminskingsord': ('forminskingsord',),
'forminskingsorda': ('forminskingsord',),
'forminskingsordene': ('forminskingsord',),
'forminskingsordet': ('forminskingsord',),
'forminskingssuffiks': ('forminskingssuffiks',),
'forminskingssuffiksa': ('forminskingssuffiks',),
'forminskingssuffiksene': ('forminskingssuffiks',),
'forminskingssuffikser': ('forminskingssuffiks',),
'forminskingssuffikset': ('forminskingssuffiks',),
'forminskning': ('forminskning',),
'forminskninga': ('forminskning',),
'forminskningen': ('forminskning',),
'forminskningene': ('forminskning',),
'forminskninger': ('forminskning',),
'forminskningsord': ('forminskningsord',),
'forminskningsorda': ('forminskningsord',),
'forminskningsordene': ('forminskningsord',),
'forminskningsordet': ('forminskningsord',),
'forminskningssuffiks': ('forminskningssuffiks',),
'forminskningssuffiksa': ('forminskningssuffiks',),
'forminskningssuffiksene': ('forminskningssuffiks',),
'forminskningssuffikser': ('forminskningssuffiks',),
'forminskningssuffikset': ('forminskningssuffiks',),
'formjern': ('formjern',),
'formjerna': ('formjern',),
'formjernene': ('formjern',),
'formjernet': ('formjern',),
'formkaka': ('formkake',),
'formkake': ('formkake',),
'formkaken': ('formkake',),
'formkakene': ('formkake',),
'formkaker': ('formkake',),
'formkurve': ('formkurve',),
'formkurven': ('formkurve',),
'formkurvene': ('formkurve',),
'formkurver': ('formkurve',),
'formloff': ('formloff',),
'formloffen': ('formloff',),
'formloffene': ('formloff',),
'formloffer': ('formloff',),
'formlæra': ('formlære',),
'formlære': ('formlære',),
'formlæren': ('formlære',),
'formlærene': ('formlære',),
'formlærer': ('formlære',),
'formoder': ('formoder',),
'formoderen': ('formoder',),
'formødre': ('formoder',),
'formødrene': ('formoder',),
'formødrer': ('formoder',),
'formodning': ('formodning',),
'formodninga': ('formodning',),
'formodningen': ('formodning',),
'formodningene': ('formodning',),
'formodninger': ('formodning',),
'formolding': ('formolding',),
'formoldinga': ('formolding',),
'formoldingen': ('formolding',),
'formoldingene': ('formolding',),
'formoldinger': ('formolding',),
'formonn': ('formonn',),
'formonna': ('formonn',),
'formonnen': ('formonn',),
'formonnene': ('formonn',),
'formonner': ('formonn',),
'formonnet': ('formonn',),
'formosaner': ('formosaner',),
'formosanere': ('formosaner',),
'formosaneren': ('formosaner',),
'formosanerer': ('formosaner',),
'formosanerne': ('formosaner',),
'formsak': ('formsak',),
'formsaka': ('formsak',),
'formsaken': ('formsak',),
'formsakene': ('formsak',),
'formsaker': ('formsak',),
'formskrift': ('formskrift',),
'formskrifta': ('formskrift',),
'formskriften': ('formskrift',),
'formskriftene': ('formskrift',),
'formskrifter': ('formskrift',),
'formspråk': ('formspråk',),
'formspråka': ('formspråk',),
'formspråkene': ('formspråk',),
'formspråket': ('formspråk',),
'formtre': ('formtre',),
'formtrea': ('formtre',),
'formtreet': ('formtre',),
'formtrær': ('formtre',),
'formtrærne': ('formtre',),
'formue': ('formue',),
'formuen': ('formue',),
'formuene': ('formue',),
'formuer': ('formue',),
'formuerett': ('formuerett',),
'formueretten': ('formuerett',),
'formuerettene': ('formuerett',),
'formueretter': ('formuerett',),
'formuesbeskatning': ('formuesbeskatning',),
'formuesbeskatninga': ('formuesbeskatning',),
'formuesbeskatningen': ('formuesbeskatning',),
'formuesbeskatningene': ('formuesbeskatning',),
'formuesbeskatninger': ('formuesbeskatning',),
'formuesfellesskap': ('formuesfellesskap',),
'formuesfellesskapa': ('formuesfellesskap',),
'formuesfellesskapene': ('formuesfellesskap',),
'formuesfellesskaper': ('formuesfellesskap',),
'formuesfellesskapet': ('formuesfellesskap',),
'formuesskatt': ('formuesskatt',),
'formuesskatten': ('formuesskatt',),
'formuesskattene': ('formuesskatt',),
'formuesskatter': ('formuesskatt',),
'formular': ('formular',),
'formulara': ('formular',),
'formularen': ('formular',),
'formularene': ('formular',),
'formularer': ('formular',),
'formularet': ('formular',),
'formulding': ('formulding',),
'formuldinga': ('formulding',),
'formuldingen': ('formulding',),
'formuldingene': ('formulding',),
'formuldinger': ('formulding',),
'formulering': ('formulering',),
'formuleringa': ('formulering',),
'formuleringen': ('formulering',),
'formuleringene': ('formulering',),
'formuleringer': ('formulering',),
'formverk': ('formverk',),
'formverka': ('formverk',),
'formverkene': ('formverk',),
'formverker': ('formverk',),
'formverket': ('formverk',),
'formynder': ('formynder',),
'formyndere': ('formynder',),
'formynderen': ('formynder',),
'formynderer': ('formynder',),
'formynderne': ('formynder',),
'formynderi': ('formynderi',),
'formynderia': ('formynderi',),
'formynderiene': ('formynderi',),
'formynderier': ('formynderi',),
'formynderiet': ('formynderi',),
'formynderskap': ('formynderskap',),
'formynderskapa': ('formynderskap',),
'formynderskapene': ('formynderskap',),
'formynderskapet': ('formynderskap',),
'formynderstat': ('formynderstat',),
'formynderstaten': ('formynderstat',),
'formynderstatene': ('formynderstat',),
'formynderstater': ('formynderstat',),
'formål': ('formål',),
'formåla': ('formål',),
'formålene': ('formål',),
'formålet': ('formål',),
'formålsparagraf': ('formålsparagraf',),
'formålsparagrafen': ('formålsparagraf',),
'formålsparagrafene': ('formålsparagraf',),
'formålsparagrafer': ('formålsparagraf',),
'formørkelse': ('formørkelse',),
'formørkelsen': ('formørkelse',),
'formørkelsene': ('formørkelse',),
'formørkelser': ('formørkelse',),
'formørkning': ('formørkning',),
'formørkninga': ('formørkning',),
'formørkningen': ('formørkning',),
'formørkningene': ('formørkning',),
'formørkninger': ('formørkning',),
'fornaldarsaga': ('fornaldarsaga',),
'fornaldarsagaen': ('fornaldarsaga',),
'fornaldarsagaene': ('fornaldarsaga',),
'fornaldarsagaer': ('fornaldarsaga',),
'fornavn': ('fornavn',),
'fornavna': ('fornavn',),
'fornavnene': ('fornavn',),
'fornavnet': ('fornavn',),
'fornedrelse': ('fornedrelse',),
'fornedrelsen': ('fornedrelse',),
'fornedrelsene': ('fornedrelse',),
'fornedrelser': ('fornedrelse',),
'fornekter': ('fornekter',),
'fornektere': ('fornekter',),
'fornekteren': ('fornekter',),
'fornekterer': ('fornekter',),
'fornekterne': ('fornekter',),
'fornemmelse': ('fornemmelse',),
'fornemmelsen': ('fornemmelse',),
'fornemmelsene': ('fornemmelse',),
'fornemmelser': ('fornemmelse',),
'fornminna': ('fornminne',),
'fornminne': ('fornminne',),
'fornminnene': ('fornminne',),
'fornminner': ('fornminne',),
'fornminnet': ('fornminne',),
'fornorskingsarbeid': ('fornorskingsarbeid',),
'fornorskingsarbeida': ('fornorskingsarbeid',),
'fornorskingsarbeidene': ('fornorskingsarbeid',),
'fornorskingsarbeidet': ('fornorskingsarbeid',),
'fornorskingsordbok': ('fornorskingsordbok',),
'fornorskingsordboka': ('fornorskingsordbok',),
'fornorskingsordboken': ('fornorskingsordbok',),
'fornorskingsordbøkene': ('fornorskingsordbok',),
'fornorskingsordbøker': ('fornorskingsordbok',),
'fornorskningsarbeid': ('fornorskningsarbeid',),
'fornorskningsarbeida': ('fornorskningsarbeid',),
'fornorskningsarbeidene': ('fornorskningsarbeid',),
'fornorskningsarbeidet': ('fornorskningsarbeid',),
'fornorskningsordbok': ('fornorskningsordbok',),
'fornorskningsordboka': ('fornorskningsordbok',),
'fornorskningsordboken': ('fornorskningsordbok',),
'fornorskningsordbøkene': ('fornorskningsordbok',),
'fornorskningsordbøker': ('fornorskningsordbok',),
'fornuft': ('fornuft',),
'fornuften': ('fornuft',),
'fornuftene': ('fornuft',),
'fornufter': ('fornuft',),
'fornuftekteskap': ('fornuftekteskap',),
'fornuftekteskapa': ('fornuftekteskap',),
'fornuftekteskapene': ('fornuftekteskap',),
'fornuftekteskaper': ('fornuftekteskap',),
'fornuftekteskapet': ('fornuftekteskap',),
'fornuftsekteskap': ('fornuftsekteskap',),
'fornuftsekteskapa': ('fornuftsekteskap',),
'fornuftsekteskapene': ('fornuftsekteskap',),
'fornuftsekteskaper': ('fornuftsekteskap',),
'fornuftsekteskapet': ('fornuftsekteskap',),
'fornuftstro': ('fornuftstro',),
'fornuftstroa': ('fornuftstro',),
'fornuftstroen': ('fornuftstro',),
'fornuftstroene': ('fornuftstro',),
'fornuftstroer': ('fornuftstro',),
'fornuftstru': ('fornuftstru',),
'fornuftstrua': ('fornuftstru',),
'fornuftstruen': ('fornuftstru',),
'fornuftstruene': ('fornuftstru',),
'fornuftstruer': ('fornuftstru',),
'fornuftsvesen': ('fornuftsvesen',),
'fornuftsvesena': ('fornuftsvesen',),
'fornuftsvesenene': ('fornuftsvesen',),
'fornuftsvesener': ('fornuftsvesen',),
'fornuftsvesenet': ('fornuftsvesen',),
'fornufttro': ('fornufttro',),
'fornufttroa': ('fornufttro',),
'fornufttroen': ('fornufttro',),
'fornufttroene': ('fornufttro',),
'fornufttroer': ('fornufttro',),
'fornufttru': ('fornufttru',),
'fornufttrua': ('fornufttru',),
'fornufttruen': ('fornufttru',),
'fornufttruene': ('fornufttru',),
'fornufttruer': ('fornufttru',),
'fornuftvesen': ('fornuftvesen',),
'fornuftvesena': ('fornuftvesen',),
'fornuftvesenene': ('fornuftvesen',),
'fornuftvesener': ('fornuftvesen',),
'fornuftvesenet': ('fornuftvesen',),
'fornyelse': ('fornyelse',),
'fornyelsen': ('fornyelse',),
'fornyelsene': ('fornyelse',),
'fornyelser': ('fornyelse',),
'fornyelsesdato': ('fornyelsesdato',),
'fornyelsesdatoen': ('fornyelsesdato',),
'fornyelsesdatoene': ('fornyelsesdato',),
'fornyelsesdatoer': ('fornyelsesdato',),
'fornyelseskontrakt': ('fornyelseskontrakt',),
'fornyelseskontrakten': ('fornyelseskontrakt',),
'fornyelseskontraktene': ('fornyelseskontrakt',),
'fornyelseskontrakter': ('fornyelseskontrakt',),
'fornyer': ('fornyer',),
'fornyere': ('fornyer',),
'fornyeren': ('fornyer',),
'fornyerer': ('fornyer',),
'fornyerne': ('fornyer',),
'fornyrdislag': ('fornyrdislag',),
'fornyrdislaga': ('fornyrdislag',),
'fornyrdislagene': ('fornyrdislag',),
'fornyrdislaget': ('fornyrdislag',),
'fornærmelse': ('fornærmelse',),
'fornærmelsen': ('fornærmelse',),
'fornærmelsene': ('fornærmelse',),
'fornærmelser': ('fornærmelse',),
'fornøyelse': ('fornøyelse',),
'fornøyelsen': ('fornøyelse',),
'fornøyelsene': ('fornøyelse',),
'fornøyelser': ('fornøyelse',),
'fornøyelsespark': ('fornøyelsespark',),
'fornøyelsesparken': ('fornøyelsespark',),
'fornøyelsesparkene': ('fornøyelsespark',),
'fornøyelsesparker': ('fornøyelsespark',),
'fornøyelsestur': ('fornøyelsestur',),
'fornøyelsesturen': ('fornøyelsestur',),
'fornøyelsesturene': ('fornøyelsestur',),
'fornøyelsesturer': ('fornøyelsestur',),
'forord': ('forord',),
'fororda': ('forord',),
'forordene': ('forord',),
'forordet': ('forord',),
'forordning': ('forordning',),
'forordninga': ('forordning',),
'forordningen': ('forordning',),
'forordningene': ('forordning',),
'forordninger': ('forordning',),
'forpakning': ('forpakning',),
'forpakninga': ('forpakning',),
'forpakningen': ('forpakning',),
'forpakningene': ('forpakning',),
'forpakninger': ('forpakning',),
'forpakter': ('forpakter',),
'forpaktere': ('forpakter',),
'forpakteren': ('forpakter',),
'forpakterer': ('forpakter',),
'forpakterne': ('forpakter',),
'forpakterbolig': ('forpakterbolig',),
'forpakterboligen': ('forpakterbolig',),
'forpakterboligene': ('forpakterbolig',),
'forpakterboliger': ('forpakterbolig',),
'forpaktning': ('forpaktning',),
'forpaktninga': ('forpaktning',),
'forpaktningen': ('forpaktning',),
'forpaktningene': ('forpaktning',),
'forpaktninger': ('forpaktning',),
'forpaktningsavgift': ('forpaktningsavgift',),
'forpaktningsavgifta': ('forpaktningsavgift',),
'forpaktningsavgiften': ('forpaktningsavgift',),
'forpaktningsavgiftene': ('forpaktningsavgift',),
'forpaktningsavgifter': ('forpaktningsavgift',),
'forpaktningskontrakt': ('forpaktningskontrakt',),
'forpaktningskontrakten': ('forpaktningskontrakt',),
'forpaktningskontraktene': ('forpaktningskontrakt',),
'forpaktningskontrakter': ('forpaktningskontrakt',),
'forpaktningstid': ('forpaktningstid',),
'forpaktningstida': ('forpaktningstid',),
'forpaktningstiden': ('forpaktningstid',),
'forpaktningstidene': ('forpaktningstid',),
'forpaktningstider': ('forpaktningstid',),
'forpart': ('forpart',),
'forparten': ('forpart',),
'forpartene': ('forpart',),
'forparter': ('forpart',),
'forplantingsdrift': ('forplantingsdrift',),
'forplantingsdrifta': ('forplantingsdrift',),
'forplantingsdriften': ('forplantingsdrift',),
'forplantingsdriftene': ('forplantingsdrift',),
'forplantingsdrifter': ('forplantingsdrift',),
'forplantingslæra': ('forplantingslære',),
'forplantingslære': ('forplantingslære',),
'forplantingslæren': ('forplantingslære',),
'forplantingslærene': ('forplantingslære',),
'forplantingslærer': ('forplantingslære',),
'forplantingsorgan': ('forplantingsorgan',),
'forplantingsorgana': ('forplantingsorgan',),
'forplantingsorganene': ('forplantingsorgan',),
'forplantingsorganer': ('forplantingsorgan',),
'forplantingsorganet': ('forplantingsorgan',),
'forplantning': ('forplantning',),
'forplantninga': ('forplantning',),
'forplantningen': ('forplantning',),
'forplantningene': ('forplantning',),
'forplantninger': ('forplantning',),
'forplantningsdrift': ('forplantningsdrift',),
'forplantningsdrifta': ('forplantningsdrift',),
'forplantningsdriften': ('forplantningsdrift',),
'forplantningsdriftene': ('forplantningsdrift',),
'forplantningsdrifter': ('forplantningsdrift',),
'forplantningslæra': ('forplantningslære',),
'forplantningslære': ('forplantningslære',),
'forplantningslæren': ('forplantningslære',),
'forplantningslærene': ('forplantningslære',),
'forplantningslærer': ('forplantningslære',),
'forplantningsorgan': ('forplantningsorgan',),
'forplantningsorgana': ('forplantningsorgan',),
'forplantningsorganene': ('forplantningsorgan',),
'forplantningsorganer': ('forplantningsorgan',),
'forplantningsorganet': ('forplantningsorgan',),
'forpleining': ('forpleining',),
'forpleininga': ('forpleining',),
'forpleiningen': ('forpleining',),
'forpleiningene': ('forpleining',),
'forpleininger': ('forpleining',),
'forpliktelse': ('forpliktelse',),
'forpliktelsen': ('forpliktelse',),
'forpliktelsene': ('forpliktelse',),
'forpliktelser': ('forpliktelse',),
'forpost': ('forpost',),
'forposten': ('forpost',),
'forpostene': ('forpost',),
'forposter': ('forpost',),
'forpostfektning': ('forpostfektning',),
'forpostfektninga': ('forpostfektning',),
'forpostfektningen': ('forpostfektning',),
'forpostfektningene': ('forpostfektning',),
'forpostfektninger': ('forpostfektning',),
'forposttrefning': ('forposttrefning',),
'forposttrefninga': ('forposttrefning',),
'forposttrefningen': ('forposttrefning',),
'forposttrefningene': ('forposttrefning',),
'forposttrefninger': ('forposttrefning',),
'forprosjekt': ('forprosjekt',),
'forprosjekta': ('forprosjekt',),
'forprosjektene': ('forprosjekt',),
'forprosjekter': ('forprosjekt',),
'forprosjektet': ('forprosjekt',),
'forrang': ('forrang',),
'forrangen': ('forrang',),
'forrangene': ('forrang',),
'forranger': ('forrang',),
'forretning': ('forretning',),
'forretninga': ('forretning',),
'forretningen': ('forretning',),
'forretningene': ('forretning',),
'forretninger': ('forretning',),
'forretningsbank': ('forretningsbank',),
'forretningsbanken': ('forretningsbank',),
'forretningsbankene': ('forretningsbank',),
'forretningsbanker': ('forretningsbank',),
'forretningsbrev': ('forretningsbrev',),
'forretningsbreva': ('forretningsbrev',),
'forretningsbrevene': ('forretningsbrev',),
'forretningsbrever': ('forretningsbrev',),
'forretningsbrevet': ('forretningsbrev',),
'forretningsbygg': ('forretningsbygg',),
'forretningsbygga': ('forretningsbygg',),
'forretningsbyggene': ('forretningsbygg',),
'forretningsbygget': ('forretningsbygg',),
'forretningsforbindelse': ('forretningsforbindelse',),
'forretningsforbindelsen': ('forretningsforbindelse',),
'forretningsforbindelsene': ('forretningsforbindelse',),
'forretningsforbindelser': ('forretningsforbindelse',),
'forretningsfører': ('forretningsfører',),
'forretningsførere': ('forretningsfører',),
'forretningsføreren': ('forretningsfører',),
'forretningsførerer': ('forretningsfører',),
'forretningsførerne': ('forretningsfører',),
'forretningsgang': ('forretningsgang',),
'forretningsgangen': ('forretningsgang',),
'forretningsgangene': ('forretningsgang',),
'forretningsganger': ('forretningsgang',),
'forretningshemmelighet': ('forretningshemmelighet',),
'forretningshemmeligheta': ('forretningshemmelighet',),
'forretningshemmeligheten': ('forretningshemmelighet',),
'forretningshemmelighetene': ('forretningshemmelighet',),
'forretningshemmeligheter': ('forretningshemmelighet',),
'forretningskonvolutt': ('forretningskonvolutt',),
'forretningskonvolutten': ('forretningskonvolutt',),
'forretningskonvoluttene': ('forretningskonvolutt',),
'forretningskonvolutter': ('forretningskonvolutt',),
'forretningskorrespondanse': ('forretningskorrespondanse',),
'forretningskorrespondansen': ('forretningskorrespondanse',),
'forretningskorrespondansene': ('forretningskorrespondanse',),
'forretningskorrespondanser': ('forretningskorrespondanse',),
'forretningsliv': ('forretningsliv',),
'forretningsliva': ('forretningsliv',),
'forretningslivene': ('forretningsliv',),
'forretningslivet': ('forretningsliv',),
'forretningsmann': ('forretningsmann',),
'forretningsmannen': ('forretningsmann',),
'forretningsmenn': ('forretningsmann',),
'forretningsmennene': ('forretningsmann',),
'forretningsministeria': ('forretningsministerium',),
'forretningsministeriene': ('forretningsministerium',),
'forretningsministerier': ('forretningsministerium',),
'forretningsministeriet': ('forretningsministerium',),
'forretningsministerium': ('forretningsministerium',),
'forretningsmoral': ('forretningsmoral',),
'forretningsmoralen': ('forretningsmoral',),
'forretningsmoralene': ('forretningsmoral',),
'forretningsmoraler': ('forretningsmoral',),
'forretningsorden': ('forretningsorden',),
'forretningsordenen': ('forretningsorden',),
'forretningsordenene': ('forretningsorden',),
'forretningsordener': ('forretningsorden',),
'forretningsreisa': ('forretningsreise',),
'forretningsreise': ('forretningsreise',),
'forretningsreisen': ('forretningsreise',),
'forretningsreisene': ('forretningsreise',),
'forretningsreiser': ('forretningsreise',),
'forretningssenter': ('forretningssenter',),
'forretningssenteret': ('forretningssenter',),
'forretningssentra': ('forretningssenter',),
'forretningssentre': ('forretningssenter',),
'forretningssentrene': ('forretningssenter',),
'forretningssentret': ('forretningssenter',),
'forretningsstand': ('forretningsstand',),
'forretningsstanden': ('forretningsstand',),
'forretningsstandene': ('forretningsstand',),
'forretningsstander': ('forretningsstand',),
'forretningsstrøk': ('forretningsstrøk',),
'forretningsstrøka': ('forretningsstrøk',),
'forretningsstrøkene': ('forretningsstrøk',),
'forretningsstrøket': ('forretningsstrøk',),
'forretningstransaksjon': ('forretningstransaksjon',),
'forretningstransaksjonen': ('forretningstransaksjon',),
'forretningstransaksjonene': ('forretningstransaksjon',),
'forretningstransaksjoner': ('forretningstransaksjon',),
'forretningsverden': ('forretningsverden',),
'forretningsverdenen': ('forretningsverden',),
'forretningsverdenene': ('forretningsverden',),
'forretningsverdener': ('forretningsverden',),
'forretningsvirksomhet': ('forretningsvirksomhet',),
'forretningsvirksomheta': ('forretningsvirksomhet',),
'forretningsvirksomheten': ('forretningsvirksomhet',),
'forretningsvirksomhetene': ('forretningsvirksomhet',),
'forretningsvirksomheter': ('forretningsvirksomhet',),
'forrett': ('forrett',),
'forretten': ('forrett',),
'forrettene': ('forrett',),
'forretter': ('forrett',),
'forrett': ('forrett',),
'forretten': ('forrett',),
'forrettene': ('forrett',),
'forretter': ('forrett',),
'forrigg': ('forrigg',),
'forriggen': ('forrigg',),
'forriggene': ('forrigg',),
'forrigger': ('forrigg',),
'forrom': ('forrom',),
'forromma': ('forrom',),
'forrommene': ('forrom',),
'forrommet': ('forrom',),
'forråd': ('forråd',),
'forråda': ('forråd',),
'forrådene': ('forråd',),
'forrådet': ('forråd',),
'forrådskammer': ('forrådskammer',),
'forrådskammeret': ('forrådskammer',),
'forrådskamra': ('forrådskammer',),
'forrådskamre': ('forrådskammer',),
'forrådskamrene': ('forrådskammer',),
'forråtnelse': ('forråtnelse',),
'forråtnelsen': ('forråtnelse',),
'forråtnelsene': ('forråtnelse',),
'forråtnelser': ('forråtnelse',),
'forråtnelsesbakterie': ('forråtnelsesbakterie',),
'forråtnelsesbakterien': ('forråtnelsesbakterie',),
'forråtnelsesbakteriene': ('forråtnelsesbakterie',),
'forråtnelsesbakterier': ('forråtnelsesbakterie',),
'forråtnelsesprosess': ('forråtnelsesprosess',),
'forråtnelsesprosessen': ('forråtnelsesprosess',),
'forråtnelsesprosessene': ('forråtnelsesprosess',),
'forråtnelsesprosesser': ('forråtnelsesprosess',),
'forræder': ('forræder',),
'forrædere': ('forræder',),
'forræderen': ('forræder',),
'forræderer': ('forræder',),
'forræderne': ('forræder',),
'forræderi': ('forræderi',),
'forræderia': ('forræderi',),
'forræderiene': ('forræderi',),
'forræderier': ('forræderi',),
'forræderiet': ('forræderi',),
'forsagelse': ('forsagelse',),
'forsagelsen': ('forsagelse',),
'forsagelsene': ('forsagelse',),
'forsagelser': ('forsagelse',),
'forsakelse': ('forsakelse',),
'forsakelsen': ('forsakelse',),
'forsakelsene': ('forsakelse',),
'forsakelser': ('forsakelse',),
'forsalg': ('forsalg',),
'forsalga': ('forsalg',),
'forsalgene': ('forsalg',),
'forsalget': ('forsalg',),
'forsamling': ('forsamling',),
'forsamlinga': ('forsamling',),
'forsamlingen': ('forsamling',),
'forsamlingene': ('forsamling',),
'forsamlinger': ('forsamling',),
'forsamlingshus': ('forsamlingshus',),
'forsamlingshusa': ('forsamlingshus',),
'forsamlingshusene': ('forsamlingshus',),
'forsamlingshuset': ('forsamlingshus',),
'forsanger': ('forsanger',),
'forsangere': ('forsanger',),
'forsangeren': ('forsanger',),
'forsangerer': ('forsanger',),
'forsangerne': ('forsanger',),
'forsats': ('forsats',),
'forsatsen': ('forsats',),
'forsatsene': ('forsats',),
'forsatser': ('forsats',),
'forsatsblad': ('forsatsblad',),
'forsatsblada': ('forsatsblad',),
'forsatsbladene': ('forsatsblad',),
'forsatsblader': ('forsatsblad',),
'forsatsbladet': ('forsatsblad',),
'forse': ('forse',),
'forsen': ('forse',),
'forsene': ('forse',),
'forser': ('forse',),
'forseelse': ('forseelse',),
'forseelsen': ('forseelse',),
'forseelsene': ('forseelse',),
'forseelser': ('forseelse',),
'forsegling': ('forsegling',),
'forseglinga': ('forsegling',),
'forseglingen': ('forsegling',),
'forseglingene': ('forsegling',),
'forseglinger': ('forsegling',),
'forsendelse': ('forsendelse',),
'forsendelsen': ('forsendelse',),
'forsendelsene': ('forsendelse',),
'forsendelser': ('forsendelse',),
'forsending': ('forsending',),
'forsendinga': ('forsending',),
'forsendingen': ('forsending',),
'forsendingene': ('forsending',),
'forsendinger': ('forsending',),
'forsenking': ('forsenking',),
'forsenkinga': ('forsenking',),
'forsenkingen': ('forsenking',),
'forsenkingene': ('forsenking',),
'forsenkinger': ('forsenking',),
'forsenkning': ('forsenkning',),
'forsenkninga': ('forsenkning',),
'forsenkningen': ('forsenkning',),
'forsenkningene': ('forsenkning',),
'forsenkninger': ('forsenkning',),
'forseta': ('forsete',),
'forsete': ('forsete',),
'forsetene': ('forsete',),
'forseter': ('forsete',),
'forsetet': ('forsete',),
'forsett': ('forsett',),
'forsetta': ('forsett',),
'forsettene': ('forsett',),
'forsetter': ('forsett',),
'forsettet': ('forsett',),
'forsida': ('forside',),
'forside': ('forside',),
'forsiden': ('forside',),
'forsidene': ('forside',),
'forsider': ('forside',),
'forsidejenta': ('forsidejente',),
'forsidejente': ('forsidejente',),
'forsidejenten': ('forsidejente',),
'forsidejentene': ('forsidejente',),
'forsidejenter': ('forsidejente',),
'forsideoppslag': ('forsideoppslag',),
'forsideoppslaga': ('forsideoppslag',),
'forsideoppslagene': ('forsideoppslag',),
'forsideoppslaget': ('forsideoppslag',),
'forsikring': ('forsikring',),
'forsikringa': ('forsikring',),
'forsikringen': ('forsikring',),
'forsikringene': ('forsikring',),
'forsikringer': ('forsikring',),
'forsikringsagent': ('forsikringsagent',),
'forsikringsagenten': ('forsikringsagent',),
'forsikringsagentene': ('forsikringsagent',),
'forsikringsagenter': ('forsikringsagent',),
'forsikringsgjenstand': ('forsikringsgjenstand',),
'forsikringsgjenstanden': ('forsikringsgjenstand',),
'forsikringsgjenstandene': ('forsikringsgjenstand',),
'forsikringsgjenstander': ('forsikringsgjenstand',),
'forsikringsmatematikk': ('forsikringsmatematikk',),
'forsikringsmatematikken': ('forsikringsmatematikk',),
'forsikringsmatematikkene': ('forsikringsmatematikk',),
'forsikringsmatematikker': ('forsikringsmatematikk',),
'forsikringspolise': ('forsikringspolise',),
'forsikringspolisen': ('forsikringspolise',),
'forsikringspolisene': ('forsikringspolise',),
'forsikringspoliser': ('forsikringspolise',),
'forsikringspremie': ('forsikringspremie',),
'forsikringspremien': ('forsikringspremie',),
'forsikringspremiene': ('forsikringspremie',),
'forsikringspremier': ('forsikringspremie',),
'forsikringsselskap': ('forsikringsselskap',),
'forsikringsselskapa': ('forsikringsselskap',),
'forsikringsselskapene': ('forsikringsselskap',),
'forsikringsselskaper': ('forsikringsselskap',),
'forsikringsselskapet': ('forsikringsselskap',),
'forsikringssum': ('forsikringssum',),
'forsikringssummen': ('forsikringssum',),
'forsikringssummene': ('forsikringssum',),
'forsikringssummer': ('forsikringssum',),
'forsikringstaker': ('forsikringstaker',),
'forsikringstakere': ('forsikringstaker',),
'forsikringstakeren': ('forsikringstaker',),
'forsikringstakerer': ('forsikringstaker',),
'forsikringstakerne': ('forsikringstaker',),
'forsiktighet': ('forsiktighet',),
'forsiktigheta': ('forsiktighet',),
'forsiktigheten': ('forsiktighet',),
'forsiktighetene': ('forsiktighet',),
'forsiktigheter': ('forsiktighet',),
'forsiktighetsforanstaltning': ('forsiktighetsforanstaltning',),
'forsiktighetsforanstaltninga': ('forsiktighetsforanstaltning',),
'forsiktighetsforanstaltningen': ('forsiktighetsforanstaltning',),
'forsiktighetsforanstaltningene': ('forsiktighetsforanstaltning',),
'forsiktighetsforanstaltninger': ('forsiktighetsforanstaltning',),
'forsiktighetsregel': ('forsiktighetsregel',),
'forsiktighetsregelen': ('forsiktighetsregel',),
'forsiktighetsreglene': ('forsiktighetsregel',),
'forsiktighetsregler': ('forsiktighetsregel',),
'forsinkelse': ('forsinkelse',),
'forsinkelsen': ('forsinkelse',),
'forsinkelsene': ('forsinkelse',),
'forsinkelser': ('forsinkelse',),
'forsinking': ('forsinking',),
'forsinkinga': ('forsinking',),
'forsinkingen': ('forsinking',),
'forsinkingene': ('forsinking',),
'forsinkinger': ('forsinking',),
'forsiring': ('forsiring',),
'forsiringa': ('forsiring',),
'forsiringen': ('forsiring',),
'forsiringene': ('forsiring',),
'forsiringer': ('forsiring',),
'forskaling': ('forskaling',),
'forskalinga': ('forskaling',),
'forskalingen': ('forskaling',),
'forskalingene': ('forskaling',),
'forskalinger': ('forskaling',),
'forskalingssnekker': ('forskalingssnekker',),
'forskalingssnekkere': ('forskalingssnekker',),
'forskalingssnekkeren': ('forskalingssnekker',),
'forskalingssnekkerer': ('forskalingssnekker',),
'forskalingssnekkerne': ('forskalingssnekker',),
'forskansning': ('forskansning',),
'forskansninga': ('forskansning',),
'forskansningen': ('forskansning',),
'forskansningene': ('forskansning',),
'forskansninger': ('forskansning',),
'forsker': ('forsker',),
'forskere': ('forsker',),
'forskeren': ('forsker',),
'forskerer': ('forsker',),
'forskerne': ('forsker',),
'forskerblikk': ('forskerblikk',),
'forskerblikka': ('forskerblikk',),
'forskerblikkene': ('forskerblikk',),
'forskerblikket': ('forskerblikk',),
'forskerflukt': ('forskerflukt',),
'forskerflukta': ('forskerflukt',),
'forskerflukten': ('forskerflukt',),
'forskerfluktene': ('forskerflukt',),
'forskerflukter': ('forskerflukt',),
'forskergleda': ('forskerglede',),
'forskerglede': ('forskerglede',),
'forskergleden': ('forskerglede',),
'forskergledene': ('forskerglede',),
'forskergleder': ('forskerglede',),
'forskergruppa': ('forskergruppe',),
'forskergruppe': ('forskergruppe',),
'forskergruppen': ('forskergruppe',),
'forskergruppene': ('forskergruppe',),
'forskergrupper': ('forskergruppe',),
'forskerånd': ('forskerånd',),
'forskerånden': ('forskerånd',),
'forskeråndene': ('forskerånd',),
'forskerånder': ('forskerånd',),
'forsking': ('forsking',),
'forskinga': ('forsking',),
'forskingen': ('forsking',),
'forskingene': ('forsking',),
'forskinger': ('forsking',),
'forskingsbibliotek': ('forskingsbibliotek',),
'forskingsbiblioteka': ('forskingsbibliotek',),
'forskingsbibliotekene': ('forskingsbibliotek',),
'forskingsbiblioteker': ('forskingsbibliotek',),
'forskingsbiblioteket': ('forskingsbibliotek',),
'forskingsekspedisjon': ('forskingsekspedisjon',),
'forskingsekspedisjonen': ('forskingsekspedisjon',),
'forskingsekspedisjonene': ('forskingsekspedisjon',),
'forskingsekspedisjoner': ('forskingsekspedisjon',),
'forskingsinstitutt': ('forskingsinstitutt',),
'forskingsinstitutta': ('forskingsinstitutt',),
'forskingsinstituttene': ('forskingsinstitutt',),
'forskingsinstitutter': ('forskingsinstitutt',),
'forskingsinstituttet': ('forskingsinstitutt',),
'forskingsoppgava': ('forskingsoppgave',),
'forskingsoppgave': ('forskingsoppgave',),
'forskingsoppgaven': ('forskingsoppgave',),
'forskingsoppgavene': ('forskingsoppgave',),
'forskingsoppgaver': ('forskingsoppgave',),
'forskingsprosjekt': ('forskingsprosjekt',),
'forskingsprosjekta': ('forskingsprosjekt',),
'forskingsprosjektene': ('forskingsprosjekt',),
'forskingsprosjekter': ('forskingsprosjekt',),
'forskingsprosjektet': ('forskingsprosjekt',),
'forskingsresultat': ('forskingsresultat',),
'forskingsresultata': ('forskingsresultat',),
'forskingsresultatene': ('forskingsresultat',),
'forskingsresultater': ('forskingsresultat',),
'forskingsresultatet': ('forskingsresultat',),
'forskingsråd': ('forskingsråd',),
'forskingsråda': ('forskingsråd',),
'forskingsrådene': ('forskingsråd',),
'forskingsrådet': ('forskingsråd',),
'forskingsstasjon': ('forskingsstasjon',),
'forskingsstasjonen': ('forskingsstasjon',),
'forskingsstasjonene': ('forskingsstasjon',),
'forskingsstasjoner': ('forskingsstasjon',),
'forskingsstilling': ('forskingsstilling',),
'forskingsstillinga': ('forskingsstilling',),
'forskingsstillingen': ('forskingsstilling',),
'forskingsstillingene': ('forskingsstilling',),
'forskingsstillinger': ('forskingsstilling',),
'forskingsstipend': ('forskingsstipend',),
'forskingsstipenda': ('forskingsstipend',),
'forskingsstipendene': ('forskingsstipend',),
'forskingsstipender': ('forskingsstipend',),
'forskingsstipendet': ('forskingsstipend',),
'forskingsstipend': ('forskingsstipend',),
'forskingsstipenda': ('forskingsstipend',),
'forskingsstipendene': ('forskingsstipend',),
'forskingsstipender': ('forskingsstipend',),
'forskingsstipendet': ('forskingsstipend',),
'forskingsstipend': ('forskingsstipend',),
'forskingsstipenda': ('forskingsstipend',),
'forskingsstipendene': ('forskingsstipend',),
'forskingsstipender': ('forskingsstipend',),
'forskingsstipendet': ('forskingsstipend',),
'forskingsstipendiat': ('forskingsstipendiat',),
'forskingsstipendiaten': ('forskingsstipendiat',),
'forskingsstipendiatene': ('forskingsstipendiat',),
'forskingsstipendiater': ('forskingsstipendiat',),
'forskingsstipendia': ('forskingsstipendium',),
'forskingsstipendiene': ('forskingsstipendium',),
'forskingsstipendier': ('forskingsstipendium',),
'forskingsstipendiet': ('forskingsstipendium',),
'forskingsstipendium': ('forskingsstipendium',),
'forskingsstipendia': ('forskingsstipendium',),
'forskingsstipendiene': ('forskingsstipendium',),
'forskingsstipendier': ('forskingsstipendium',),
'forskingsstipendiet': ('forskingsstipendium',),
'forskingsstipendium': ('forskingsstipendium',),
'forskingsstipendia': ('forskingsstipendium',),
'forskingsstipendiene': ('forskingsstipendium',),
'forskingsstipendier': ('forskingsstipendium',),
'forskingsstipendiet': ('forskingsstipendium',),
'forskingsstipendium': ('forskingsstipendium',),
'forskingstermin': ('forskingstermin',),
'forskingsterminen': ('forskingstermin',),
'forskingsterminene': ('forskingstermin',),
'forskingsterminer': ('forskingstermin',),
'forskjell': ('forskjell',),
'forskjellen': ('forskjell',),
'forskjellene': ('forskjell',),
'forskjeller': ('forskjell',),
'forskjellsbehandling': ('forskjellsbehandling',),
'forskjellsbehandlinga': ('forskjellsbehandling',),
'forskjellsbehandlingen': ('forskjellsbehandling',),
'forskjellsbehandlingene': ('forskjellsbehandling',),
'forskjellsbehandlinger': ('forskjellsbehandling',),
'forskjerm': ('forskjerm',),
'forskjermen': ('forskjerm',),
'forskjermene': ('forskjerm',),
'forskjermer': ('forskjerm',),
'forskjærer': ('forskjærer',),
'forskjærere': ('forskjærer',),
'forskjæreren': ('forskjærer',),
'forskjærerer': ('forskjærer',),
'forskjærerne': ('forskjærer',),
'forskjærkniv': ('forskjærkniv',),
'forskjærkniven': ('forskjærkniv',),
'forskjærknivene': ('forskjærkniv',),
'forskjærkniver': ('forskjærkniv',),
'forskning': ('forskning',),
'forskninga': ('forskning',),
'forskningen': ('forskning',),
'forskningene': ('forskning',),
'forskninger': ('forskning',),
'forskningsbibliotek': ('forskningsbibliotek',),
'forskningsbiblioteka': ('forskningsbibliotek',),
'forskningsbibliotekene': ('forskningsbibliotek',),
'forskningsbiblioteker': ('forskningsbibliotek',),
'forskningsbiblioteket': ('forskningsbibliotek',),
'forskningsekspedisjon': ('forskningsekspedisjon',),
'forskningsekspedisjonen': ('forskningsekspedisjon',),
'forskningsekspedisjonene': ('forskningsekspedisjon',),
'forskningsekspedisjoner': ('forskningsekspedisjon',),
'forskningsinstitutt': ('forskningsinstitutt',),
'forskningsinstitutta': ('forskningsinstitutt',),
'forskningsinstituttene': ('forskningsinstitutt',),
'forskningsinstitutter': ('forskningsinstitutt',),
'forskningsinstituttet': ('forskningsinstitutt',),
'forskningsoppgava': ('forskningsoppgave',),
'forskningsoppgave': ('forskningsoppgave',),
'forskningsoppgaven': ('forskningsoppgave',),
'forskningsoppgavene': ('forskningsoppgave',),
'forskningsoppgaver': ('forskningsoppgave',),
'forskningsprosjekt': ('forskningsprosjekt',),
'forskningsprosjekta': ('forskningsprosjekt',),
'forskningsprosjektene': ('forskningsprosjekt',),
'forskningsprosjekter': ('forskningsprosjekt',),
'forskningsprosjektet': ('forskningsprosjekt',),
'forskningsresultat': ('forskningsresultat',),
'forskningsresultata': ('forskningsresultat',),
'forskningsresultatene': ('forskningsresultat',),
'forskningsresultater': ('forskningsresultat',),
'forskningsresultatet': ('forskningsresultat',),
'forskningsråd': ('forskningsråd',),
'forskningsråda': ('forskningsråd',),
'forskningsrådene': ('forskningsråd',),
'forskningsrådet': ('forskningsråd',),
'forskningsstasjon': ('forskningsstasjon',),
'forskningsstasjonen': ('forskningsstasjon',),
'forskningsstasjonene': ('forskningsstasjon',),
'forskningsstasjoner': ('forskningsstasjon',),
'forskningsstilling': ('forskningsstilling',),
'forskningsstillinga': ('forskningsstilling',),
'forskningsstillingen': ('forskningsstilling',),
'forskningsstillingene': ('forskningsstilling',),
'forskningsstillinger': ('forskningsstilling',),
'forskningsstipend': ('forskningsstipend',),
'forskningsstipenda': ('forskningsstipend',),
'forskningsstipendene': ('forskningsstipend',),
'forskningsstipender': ('forskningsstipend',),
'forskningsstipendet': ('forskningsstipend',),
'forskningsstipend': ('forskningsstipend',),
'forskningsstipenda': ('forskningsstipend',),
'forskningsstipendene': ('forskningsstipend',),
'forskningsstipender': ('forskningsstipend',),
'forskningsstipendet': ('forskningsstipend',),
'forskningsstipend': ('forskningsstipend',),
'forskningsstipenda': ('forskningsstipend',),
'forskningsstipendene': ('forskningsstipend',),
'forskningsstipender': ('forskningsstipend',),
'forskningsstipendet': ('forskningsstipend',),
'forskningsstipendiat': ('forskningsstipendiat',),
'forskningsstipendiaten': ('forskningsstipendiat',),
'forskningsstipendiatene': ('forskningsstipendiat',),
'forskningsstipendiater': ('forskningsstipendiat',),
'forskningsstipendia': ('forskningsstipendium',),
'forskningsstipendiene': ('forskningsstipendium',),
'forskningsstipendier': ('forskningsstipendium',),
'forskningsstipendiet': ('forskningsstipendium',),
'forskningsstipendium': ('forskningsstipendium',),
'forskningsstipendia': ('forskningsstipendium',),
'forskningsstipendiene': ('forskningsstipendium',),
'forskningsstipendier': ('forskningsstipendium',),
'forskningsstipendiet': ('forskningsstipendium',),
'forskningsstipendium': ('forskningsstipendium',),
'forskningsstipendia': ('forskningsstipendium',),
'forskningsstipendiene': ('forskningsstipendium',),
'forskningsstipendier': ('forskningsstipendium',),
'forskningsstipendiet': ('forskningsstipendium',),
'forskningsstipendium': ('forskningsstipendium',),
'forskningstermin': ('forskningstermin',),
'forskningsterminen': ('forskningstermin',),
'forskningsterminene': ('forskningstermin',),
'forskningsterminer': ('forskningstermin',),
'forskole': ('forskole',),
'forskolen': ('forskole',),
'forskolene': ('forskole',),
'forskoler': ('forskole',),
'forskott': ('forskott',),
'forskotten': ('forskott',),
'forskottene': ('forskott',),
'forskotter': ('forskott',),
'forskott': ('forskott',),
'forskotta': ('forskott',),
'forskottene': ('forskott',),
'forskottet': ('forskott',),
'forskottsrenta': ('forskottsrente',),
'forskottsrente': ('forskottsrente',),
'forskottsrenten': ('forskottsrente',),
'forskottsrentene': ('forskottsrente',),
'forskottsrenter': ('forskottsrente',),
'forskottsskatt': ('forskottsskatt',),
'forskottsskatten': ('forskottsskatt',),
'forskottsskattene': ('forskottsskatt',),
'forskottsskatter': ('forskottsskatt',),
'forskottstrekk': ('forskottstrekk',),
'forskottstrekka': ('forskottstrekk',),
'forskottstrekkene': ('forskottstrekk',),
'forskottstrekket': ('forskottstrekk',),
'forskrekkelse': ('forskrekkelse',),
'forskrekkelsen': ('forskrekkelse',),
'forskrekkelsene': ('forskrekkelse',),
'forskrekkelser': ('forskrekkelse',),
'forskrift': ('forskrift',),
'forskrifta': ('forskrift',),
'forskriften': ('forskrift',),
'forskriftene': ('forskrift',),
'forskrifter': ('forskrift',),
'forskrivning': ('forskrivning',),
'forskrivninga': ('forskrivning',),
'forskrivningen': ('forskrivning',),
'forskrivningene': ('forskrivning',),
'forskrivninger': ('forskrivning',),
'forskudd': ('forskudd',),
'forskudda': ('forskudd',),
'forskuddene': ('forskudd',),
'forskuddet': ('forskudd',),
'forskuddsrenta': ('forskuddsrente',),
'forskuddsrente': ('forskuddsrente',),
'forskuddsrenten': ('forskuddsrente',),
'forskuddsrentene': ('forskuddsrente',),
'forskuddsrenter': ('forskuddsrente',),
'forskuddsskatt': ('forskuddsskatt',),
'forskuddsskatten': ('forskuddsskatt',),
'forskuddsskattene': ('forskuddsskatt',),
'forskuddsskatter': ('forskuddsskatt',),
'forskuddstrekk': ('forskuddstrekk',),
'forskuddstrekka': ('forskuddstrekk',),
'forskuddstrekkene': ('forskuddstrekk',),
'forskuddstrekket': ('forskuddstrekk',),
'forskut': ('forskut',),
'forskuten': ('forskut',),
'forskutene': ('forskut',),
'forskuter': ('forskut',),
'forskyvning': ('forskyvning',),
'forskyvninga': ('forskyvning',),
'forskyvningen': ('forskyvning',),
'forskyvningene': ('forskyvning',),
'forskyvninger': ('forskyvning',),
'forslagenhet': ('forslagenhet',),
'forslagenheta': ('forslagenhet',),
'forslagenheten': ('forslagenhet',),
'forslagenhetene': ('forslagenhet',),
'forslagenheter': ('forslagenhet',),
'forsmak': ('forsmak',),
'forsmaken': ('forsmak',),
'forsmakene': ('forsmak',),
'forsmaker': ('forsmak',),
'forsmedelse': ('forsmedelse',),
'forsmedelsen': ('forsmedelse',),
'forsmedelsene': ('forsmedelse',),
'forsmedelser': ('forsmedelse',),
'forsnakkelse': ('forsnakkelse',),
'forsnakkelsen': ('forsnakkelse',),
'forsnakkelsene': ('forsnakkelse',),
'forsnakkelser': ('forsnakkelse',),
'forsnevring': ('forsnevring',),
'forsnevringen': ('forsnevring',),
'forsnevringene': ('forsnevring',),
'forsnevringer': ('forsnevring',),
'forsommer': ('forsommer',),
'forsommere': ('forsommer',),
'forsommeren': ('forsommer',),
'forsommerne': ('forsommer',),
'forsomre': ('forsommer',),
'forsomrene': ('forsommer',),
'forsomrer': ('forsommer',),
'forsommertid': ('forsommertid',),
'forsommertida': ('forsommertid',),
'forsommertiden': ('forsommertid',),
'forsommertidene': ('forsommertid',),
'forsommertider': ('forsommertid',),
'forsoner': ('forsoner',),
'forsonere': ('forsoner',),
'forsoneren': ('forsoner',),
'forsonerer': ('forsoner',),
'forsonerne': ('forsoner',),
'forsoning': ('forsoning',),
'forsoninga': ('forsoning',),
'forsoningen': ('forsoning',),
'forsoningene': ('forsoning',),
'forsoninger': ('forsoning',),
'forsoningslæra': ('forsoningslære',),
'forsoningslære': ('forsoningslære',),
'forsoningslæren': ('forsoningslære',),
'forsoningslærene': ('forsoningslære',),
'forsoningslærer': ('forsoningslære',),
'forsoningsscene': ('forsoningsscene',),
'forsoningsscenen': ('forsoningsscene',),
'forsoningsscenene': ('forsoningsscene',),
'forsoningsscener': ('forsoningsscene',),
'forsorg': ('forsorg',),
'forsorga': ('forsorg',),
'forsorgen': ('forsorg',),
'forsorgene': ('forsorg',),
'forsorger': ('forsorg',),
'forspann': ('forspann',),
'forspanna': ('forspann',),
'forspannene': ('forspann',),
'forspannet': ('forspann',),
'forspell': ('forspell',),
'forspella': ('forspell',),
'forspellene': ('forspell',),
'forspellet': ('forspell',),
'forspill': ('forspill',),
'forspilla': ('forspill',),
'forspillene': ('forspill',),
'forspillet': ('forspill',),
'forsprang': ('forsprang',),
'forspranga': ('forsprang',),
'forsprangene': ('forsprang',),
'forspranget': ('forsprang',),
'forstad': ('forstad',),
'forstaden': ('forstad',),
'forstedene': ('forstad',),
'forsteder': ('forstad',),
'forstadia': ('forstadium',),
'forstadiene': ('forstadium',),
'forstadier': ('forstadium',),
'forstadiet': ('forstadium',),
'forstadium': ('forstadium',),
'forstadsbane': ('forstadsbane',),
'forstadsbanen': ('forstadsbane',),
'forstadsbanene': ('forstadsbane',),
'forstadsbaner': ('forstadsbane',),
'forstadsbeboer': ('forstadsbeboer',),
'forstadsbeboere': ('forstadsbeboer',),
'forstadsbeboeren': ('forstadsbeboer',),
'forstadsbeboerer': ('forstadsbeboer',),
'forstadsbeboerne': ('forstadsbeboer',),
'forstadsboer': ('forstadsboer',),
'forstadsboere': ('forstadsboer',),
'forstadsboeren': ('forstadsboer',),
'forstadsboerer': ('forstadsboer',),
'forstadsboerne': ('forstadsboer',),
'forstadsbuer': ('forstadsbuer',),
'forstadsbuere': ('forstadsbuer',),
'forstadsbueren': ('forstadsbuer',),
'forstadsbuerer': ('forstadsbuer',),
'forstadsbuerne': ('forstadsbuer',),
'forstadskommune': ('forstadskommune',),
'forstadskommunen': ('forstadskommune',),
'forstadskommunene': ('forstadskommune',),
'forstadskommuner': ('forstadskommune',),
'forstadstog': ('forstadstog',),
'forstadstoga': ('forstadstog',),
'forstadstogene': ('forstadstog',),
'forstadstoget': ('forstadstog',),
'forstamn': ('forstamn',),
'forstamnen': ('forstamn',),
'forstamnene': ('forstamn',),
'forstamner': ('forstamn',),
'forstamn': ('forstamn',),
'forstamnen': ('forstamn',),
'forstamnene': ('forstamn',),
'forstamner': ('forstamn',),
'forstand': ('forstand',),
'forstanden': ('forstand',),
'forstandene': ('forstand',),
'forstander': ('forstand',),
'forstander': ('forstander',),
'forstandere': ('forstander',),
'forstanderen': ('forstander',),
'forstanderer': ('forstander',),
'forstanderne': ('forstander',),
'forstanderinna': ('forstanderinne',),
'forstanderinne': ('forstanderinne',),
'forstanderinnen': ('forstanderinne',),
'forstanderinnene': ('forstanderinne',),
'forstanderinner': ('forstanderinne',),
'forstanderskap': ('forstanderskap',),
'forstanderskapa': ('forstanderskap',),
'forstanderskapene': ('forstanderskap',),
'forstanderskapet': ('forstanderskap',),
'forstandstro': ('forstandstro',),
'forstandstroa': ('forstandstro',),
'forstandstroen': ('forstandstro',),
'forstandstroene': ('forstandstro',),
'forstandstroer': ('forstandstro',),
'forstandstru': ('forstandstru',),
'forstandstrua': ('forstandstru',),
'forstandstruen': ('forstandstru',),
'forstandstruene': ('forstandstru',),
'forstandstruer': ('forstandstru',),
'forstavelse': ('forstavelse',),
'forstavelsen': ('forstavelse',),
'forstavelsene': ('forstavelse',),
'forstavelser': ('forstavelse',),
'forstaving': ('forstaving',),
'forstavinga': ('forstaving',),
'forstavingen': ('forstaving',),
'forstavingene': ('forstaving',),
'forstavinger': ('forstaving',),
'forstavn': ('forstavn',),
'forstavnen': ('forstavn',),
'forstavnene': ('forstavn',),
'forstavner': ('forstavn',),
'forstavn': ('forstavn',),
'forstavnen': ('forstavn',),
'forstavnene': ('forstavn',),
'forstavner': ('forstavn',),
'forsteining': ('forsteining',),
'forsteininga': ('forsteining',),
'forsteiningen': ('forsteining',),
'forsteiningene': ('forsteining',),
'forsteininger': ('forsteining',),
'forsterker': ('forsterker',),
'forsterkere': ('forsterker',),
'forsterkeren': ('forsterker',),
'forsterkerer': ('forsterker',),
'forsterkerne': ('forsterker',),
'forsterkning': ('forsterkning',),
'forsterkninga': ('forsterkning',),
'forsterkningen': ('forsterkning',),
'forsterkningene': ('forsterkning',),
'forsterkninger': ('forsterkning',),
'forstillelse': ('forstillelse',),
'forstillelsen': ('forstillelse',),
'forstillelsene': ('forstillelse',),
'forstillelser': ('forstillelse',),
'forstillelsesevna': ('forstillelsesevne',),
'forstillelsesevne': ('forstillelsesevne',),
'forstillelsesevnen': ('forstillelsesevne',),
'forstillelsesevnene': ('forstillelsesevne',),
'forstillelsesevner': ('forstillelsesevne',),
'forstillelseskunst': ('forstillelseskunst',),
'forstillelseskunsten': ('forstillelseskunst',),
'forstillelseskunstene': ('forstillelseskunst',),
'forstillelseskunster': ('forstillelseskunst',),
'forstilling': ('forstilling',),
'forstillinga': ('forstilling',),
'forstillingen': ('forstilling',),
'forstillingene': ('forstilling',),
'forstillinger': ('forstilling',),
'forstillingskontroll': ('forstillingskontroll',),
'forstillingskontrollen': ('forstillingskontroll',),
'forstillingskontrollene': ('forstillingskontroll',),
'forstillingskontroller': ('forstillingskontroll',),
'forstkandidat': ('forstkandidat',),
'forstkandidaten': ('forstkandidat',),
'forstkandidatene': ('forstkandidat',),
'forstkandidater': ('forstkandidat',),
'forstoppelse': ('forstoppelse',),
'forstoppelsen': ('forstoppelse',),
'forstoppelsene': ('forstoppelse',),
'forstoppelser': ('forstoppelse',),
'forstova': ('forstove',),
'forstove': ('forstove',),
'forstoven': ('forstove',),
'forstovene': ('forstove',),
'forstover': ('forstove',),
'forstudie': ('forstudie',),
'forstudien': ('forstudie',),
'forstudiene': ('forstudie',),
'forstudier': ('forstudie',),
'forstudia': ('forstudium',),
'forstudiene': ('forstudium',),
'forstudier': ('forstudium',),
'forstudiet': ('forstudium',),
'forstudium': ('forstudium',),
'forstuing': ('forstuing',),
'forstuinga': ('forstuing',),
'forstuingen': ('forstuing',),
'forstuingene': ('forstuing',),
'forstuinger': ('forstuing',),
'forstuing': ('forstuing',),
'forstuinga': ('forstuing',),
'forstuingen': ('forstuing',),
'forstuingene': ('forstuing',),
'forstuinger': ('forstuing',),
'forstuving': ('forstuving',),
'forstuvinga': ('forstuving',),
'forstuvingen': ('forstuving',),
'forstuvingene': ('forstuving',),
'forstuvinger': ('forstuving',),
'forstuving': ('forstuving',),
'forstuvinga': ('forstuving',),
'forstuvingen': ('forstuving',),
'forstuvingene': ('forstuving',),
'forstuvinger': ('forstuving',),
'forstvesen': ('forstvesen',),
'forstvesena': ('forstvesen',),
'forstvesenene': ('forstvesen',),
'forstvesener': ('forstvesen',),
'forstvesenet': ('forstvesen',),
'forstykka': ('forstykke',),
'forstykke': ('forstykke',),
'forstykkene': ('forstykke',),
'forstykker': ('forstykke',),
'forstykket': ('forstykke',),
'forstyrrelse': ('forstyrrelse',),
'forstyrrelsen': ('forstyrrelse',),
'forstyrrelsene': ('forstyrrelse',),
'forstyrrelser': ('forstyrrelse',),
'forståelse': ('forståelse',),
'forståelsen': ('forståelse',),
'forståelsene': ('forståelse',),
'forståelser': ('forståelse',),
'forståsegpåer': ('forståsegpåer',),
'forståsegpåere': ('forståsegpåer',),
'forståsegpåeren': ('forståsegpåer',),
'forståsegpåerer': ('forståsegpåer',),
'forståsegpåerne': ('forståsegpåer',),
'forstørrelse': ('forstørrelse',),
'forstørrelsen': ('forstørrelse',),
'forstørrelsene': ('forstørrelse',),
'forstørrelser': ('forstørrelse',),
'forstørrelsesapparat': ('forstørrelsesapparat',),
'forstørrelsesapparata': ('forstørrelsesapparat',),
'forstørrelsesapparatene': ('forstørrelsesapparat',),
'forstørrelsesapparater': ('forstørrelsesapparat',),
'forstørrelsesapparatet': ('forstørrelsesapparat',),
'forstørrelsesglas': ('forstørrelsesglas',),
'forstørrelsesglasa': ('forstørrelsesglas',),
'forstørrelsesglasene': ('forstørrelsesglas',),
'forstørrelsesglaset': ('forstørrelsesglas',),
'forstørrelsesglass': ('forstørrelsesglass',),
'forstørrelsesglassa': ('forstørrelsesglass',),
'forstørrelsesglassene': ('forstørrelsesglass',),
'forstørrelsesglasset': ('forstørrelsesglass',),
'forstørring': ('forstørring',),
'forstørringa': ('forstørring',),
'forstørringen': ('forstørring',),
'forstørringene': ('forstørring',),
'forstørringer': ('forstørring',),
'forstøtning': ('forstøtning',),
'forstøtninga': ('forstøtning',),
'forstøtningen': ('forstøtning',),
'forstøtningene': ('forstøtning',),
'forstøtninger': ('forstøtning',),
'forstøtningsmur': ('forstøtningsmur',),
'forstøtningsmuren': ('forstøtningsmur',),
'forstøtningsmurene': ('forstøtningsmur',),
'forstøtningsmurer': ('forstøtningsmur',),
'forstøver': ('forstøver',),
'forstøvere': ('forstøver',),
'forstøveren': ('forstøver',),
'forstøverer': ('forstøver',),
'forstøverne': ('forstøver',),
'forstøving': ('forstøving',),
'forstøvinga': ('forstøving',),
'forstøvingen': ('forstøving',),
'forstøvingene': ('forstøving',),
'forstøvinger': ('forstøving',),
'forstøvingsapparat': ('forstøvingsapparat',),
'forstøvingsapparata': ('forstøvingsapparat',),
'forstøvingsapparatene': ('forstøvingsapparat',),
'forstøvingsapparater': ('forstøvingsapparat',),
'forstøvingsapparatet': ('forstøvingsapparat',),
'forstøvning': ('forstøvning',),
'forstøvninga': ('forstøvning',),
'forstøvningen': ('forstøvning',),
'forstøvningene': ('forstøvning',),
'forstøvninger': ('forstøvning',),
'forstøvningsapparat': ('forstøvningsapparat',),
'forstøvningsapparata': ('forstøvningsapparat',),
'forstøvningsapparatene': ('forstøvningsapparat',),
'forstøvningsapparater': ('forstøvningsapparat',),
'forstøvningsapparatet': ('forstøvningsapparat',),
'forsuring': ('forsuring',),
'forsuringa': ('forsuring',),
'forsuringen': ('forsuring',),
'forsuringene': ('forsuring',),
'forsuringer': ('forsuring',),
'forsvar': ('forsvar',),
'forsvara': ('forsvar',),
'forsvarene': ('forsvar',),
'forsvaret': ('forsvar',),
'forsvarer': ('forsvarer',),
'forsvarere': ('forsvarer',),
'forsvareren': ('forsvarer',),
'forsvarerer': ('forsvarer',),
'forsvarerne': ('forsvarer',),
'forsvarsadvokat': ('forsvarsadvokat',),
'forsvarsadvokaten': ('forsvarsadvokat',),
'forsvarsadvokatene': ('forsvarsadvokat',),
'forsvarsadvokater': ('forsvarsadvokat',),
'forsvarsbudsjett': ('forsvarsbudsjett',),
'forsvarsbudsjetta': ('forsvarsbudsjett',),
'forsvarsbudsjettene': ('forsvarsbudsjett',),
'forsvarsbudsjetter': ('forsvarsbudsjett',),
'forsvarsbudsjettet': ('forsvarsbudsjett',),
'forsvarsdepartement': ('forsvarsdepartement',),
'forsvarsdepartementa': ('forsvarsdepartement',),
'forsvarsdepartementene': ('forsvarsdepartement',),
'forsvarsdepartementer': ('forsvarsdepartement',),
'forsvarsdepartementet': ('forsvarsdepartement',),
'forsvarsgrein': ('forsvarsgrein',),
'forsvarsgreina': ('forsvarsgrein',),
'forsvarsgreinen': ('forsvarsgrein',),
'forsvarsgreinene': ('forsvarsgrein',),
'forsvarsgreiner': ('forsvarsgrein',),
'forsvarsgren': ('forsvarsgren',),
'forsvarsgrena': ('forsvarsgren',),
'forsvarsgrenen': ('forsvarsgren',),
'forsvarsgrenene': ('forsvarsgren',),
'forsvarsgrener': ('forsvarsgren',),
'forsvarshandling': ('forsvarshandling',),
'forsvarshandlinga': ('forsvarshandling',),
'forsvarshandlingen': ('forsvarshandling',),
'forsvarshandlingene': ('forsvarshandling',),
'forsvarshandlinger': ('forsvarshandling',),
'forsvarskommando': ('forsvarskommando',),
'forsvarskommandoen': ('forsvarskommando',),
'forsvarskommandoene': ('forsvarskommando',),
'forsvarskommandoer': ('forsvarskommando',),
'forsvarskrig': ('forsvarskrig',),
'forsvarskrigen': ('forsvarskrig',),
'forsvarskrigene': ('forsvarskrig',),
'forsvarskriger': ('forsvarskrig',),
'forsvarsmekanisme': ('forsvarsmekanisme',),
'forsvarsmekanismen': ('forsvarsmekanisme',),
'forsvarsmekanismene': ('forsvarsmekanisme',),
'forsvarsmekanismer': ('forsvarsmekanisme',),
'forsvarsminister': ('forsvarsminister',),
'forsvarsministere': ('forsvarsminister',),
'forsvarsministeren': ('forsvarsminister',),
'forsvarsministerer': ('forsvarsminister',),
'forsvarsministerne': ('forsvarsminister',),
'forsvarsministre': ('forsvarsminister',),
'forsvarsministrene': ('forsvarsminister',),
'forsvarsministrer': ('forsvarsminister',),
'forsvarspakt': ('forsvarspakt',),
'forsvarspakta': ('forsvarspakt',),
'forsvarspakten': ('forsvarspakt',),
'forsvarspaktene': ('forsvarspakt',),
'forsvarspakter': ('forsvarspakt',),
'forsvarsposisjon': ('forsvarsposisjon',),
'forsvarsposisjonen': ('forsvarsposisjon',),
'forsvarsposisjonene': ('forsvarsposisjon',),
'forsvarsposisjoner': ('forsvarsposisjon',),
'forsvarssjef': ('forsvarssjef',),
'forsvarssjefen': ('forsvarssjef',),
'forsvarssjefene': ('forsvarssjef',),
'forsvarssjefer': ('forsvarssjef',),
'forsvarsspeller': ('forsvarsspeller',),
'forsvarsspellere': ('forsvarsspeller',),
'forsvarsspelleren': ('forsvarsspeller',),
'forsvarsspellerer': ('forsvarsspeller',),
'forsvarsspellerne': ('forsvarsspeller',),
'forsvarsspiller': ('forsvarsspiller',),
'forsvarsspillere': ('forsvarsspiller',),
'forsvarsspilleren': ('forsvarsspiller',),
'forsvarsspillerer': ('forsvarsspiller',),
'forsvarsspillerne': ('forsvarsspiller',),
'forsvarsstab': ('forsvarsstab',),
'forsvarsstaben': ('forsvarsstab',),
'forsvarsstabene': ('forsvarsstab',),
'forsvarsstaber': ('forsvarsstab',),
'forsvarsverk': ('forsvarsverk',),
'forsvarsverka': ('forsvarsverk',),
'forsvarsverkene': ('forsvarsverk',),
'forsvarsverker': ('forsvarsverk',),
'forsvarsverket': ('forsvarsverk',),
'forsvinningsdrakt': ('forsvinningsdrakt',),
'forsvinningsdrakta': ('forsvinningsdrakt',),
'forsvinningsdrakten': ('forsvinningsdrakt',),
'forsvinningsdraktene': ('forsvinningsdrakt',),
'forsvinningsdrakter': ('forsvinningsdrakt',),
'forsvinningsnummer': ('forsvinningsnummer',),
'forsvinningsnummeret': ('forsvinningsnummer',),
'forsvinningsnumra': ('forsvinningsnummer',),
'forsvinningsnumre': ('forsvinningsnummer',),
'forsvinningsnumrene': ('forsvinningsnummer',),
'forsyning': ('forsyning',),
'forsyninga': ('forsyning',),
'forsyningen': ('forsyning',),
'forsyningene': ('forsyning',),
'forsyninger': ('forsyning',),
'forsyningsbase': ('forsyningsbase',),
'forsyningsbasen': ('forsyningsbase',),
'forsyningsbasene': ('forsyningsbase',),
'forsyningsbaser': ('forsyningsbase',),
'forsyningsfartøy': ('forsyningsfartøy',),
'forsyningsfartøya': ('forsyningsfartøy',),
'forsyningsfartøyene': ('forsyningsfartøy',),
'forsyningsfartøyer': ('forsyningsfartøy',),
'forsyningsfartøyet': ('forsyningsfartøy',),
'forsyningslinja': ('forsyningslinje',),
'forsyningslinje': ('forsyningslinje',),
'forsyningslinjen': ('forsyningslinje',),
'forsyningslinjene': ('forsyningslinje',),
'forsyningslinjer': ('forsyningslinje',),
'forsyningsskip': ('forsyningsskip',),
'forsyningsskipa': ('forsyningsskip',),
'forsyningsskipene': ('forsyningsskip',),
'forsyningsskipet': ('forsyningsskip',),
'forsytia': ('forsytia',),
'forsytiaen': ('forsytia',),
'forsytiaene': ('forsytia',),
'forsytiaer': ('forsytia',),
'forsøk': ('forsøk',),
'forsøka': ('forsøk',),
'forsøkene': ('forsøk',),
'forsøket': ('forsøk',),
'forsøksal': ('forsøksal',),
'forsøksala': ('forsøksal',),
'forsøksalene': ('forsøksal',),
'forsøksalet': ('forsøksal',),
'forsøksavl': ('forsøksavl',),
'forsøksavlen': ('forsøksavl',),
'forsøksavlene': ('forsøksavl',),
'forsøksavler': ('forsøksavl',),
'forsøksdrift': ('forsøksdrift',),
'forsøksdrifta': ('forsøksdrift',),
'forsøksdriften': ('forsøksdrift',),
'forsøksdriftene': ('forsøksdrift',),
'forsøksdrifter': ('forsøksdrift',),
'forsøksdyr': ('forsøksdyr',),
'forsøksdyra': ('forsøksdyr',),
'forsøksdyrene': ('forsøksdyr',),
'forsøksdyret': ('forsøksdyr',),
'forsøksgard': ('forsøksgard',),
'forsøksgarden': ('forsøksgard',),
'forsøksgardene': ('forsøksgard',),
'forsøksgarder': ('forsøksgard',),
'forsøksgymnas': ('forsøksgymnas',),
'forsøksgymnasa': ('forsøksgymnas',),
'forsøksgymnasene': ('forsøksgymnas',),
'forsøksgymnaser': ('forsøksgymnas',),
'forsøksgymnaset': ('forsøksgymnas',),
'forsøksgård': ('forsøksgård',),
'forsøksgården': ('forsøksgård',),
'forsøksgårdene': ('forsøksgård',),
'forsøksgårder': ('forsøksgård',),
'forsøksheat': ('forsøksheat',),
'forsøksheata': ('forsøksheat',),
'forsøksheatene': ('forsøksheat',),
'forsøksheatet': ('forsøksheat',),
'forsøkskanin': ('forsøkskanin',),
'forsøkskaninen': ('forsøkskanin',),
'forsøkskaninene': ('forsøkskanin',),
'forsøkskaniner': ('forsøkskanin',),
'forsøksordning': ('forsøksordning',),
'forsøksordninga': ('forsøksordning',),
'forsøksordningen': ('forsøksordning',),
'forsøksordningene': ('forsøksordning',),
'forsøksordninger': ('forsøksordning',),
'forsøksskole': ('forsøksskole',),
'forsøksskolen': ('forsøksskole',),
'forsøksskolene': ('forsøksskole',),
'forsøksskoler': ('forsøksskole',),
'forsøksstasjon': ('forsøksstasjon',),
'forsøksstasjonen': ('forsøksstasjon',),
'forsøksstasjonene': ('forsøksstasjon',),
'forsøksstasjoner': ('forsøksstasjon',),
'forsømmelse': ('forsømmelse',),
'forsømmelsen': ('forsømmelse',),
'forsømmelsene': ('forsømmelse',),
'forsømmelser': ('forsømmelse',),
'forsøpling': ('forsøpling',),
'forsøplinga': ('forsøpling',),
'forsøplingen': ('forsøpling',),
'forsøplingene': ('forsøpling',),
'forsøplinger': ('forsøpling',),
'forsørgelsesbyrde': ('forsørgelsesbyrde',),
'forsørgelsesbyrden': ('forsørgelsesbyrde',),
'forsørgelsesbyrdene': ('forsørgelsesbyrde',),
'forsørgelsesbyrder': ('forsørgelsesbyrde',),
'forsørgelsesplikt': ('forsørgelsesplikt',),
'forsørgelsesplikta': ('forsørgelsesplikt',),
'forsørgelsesplikten': ('forsørgelsesplikt',),
'forsørgelsespliktene': ('forsørgelsesplikt',),
'forsørgelsesplikter': ('forsørgelsesplikt',),
'forsørger': ('forsørger',),
'forsørgere': ('forsørger',),
'forsørgeren': ('forsørger',),
'forsørgerer': ('forsørger',),
'forsørgerne': ('forsørger',),
'forsørgerfradrag': ('forsørgerfradrag',),
'forsørgerfradraga': ('forsørgerfradrag',),
'forsørgerfradragene': ('forsørgerfradrag',),
'forsørgerfradraget': ('forsørgerfradrag',),
'forsørgertillegg': ('forsørgertillegg',),
'forsørgertillegga': ('forsørgertillegg',),
'forsørgertilleggene': ('forsørgertillegg',),
'forsørgertillegget': ('forsørgertillegg',),
'forsørgingsbyrde': ('forsørgingsbyrde',),
'forsørgingsbyrden': ('forsørgingsbyrde',),
'forsørgingsbyrdene': ('forsørgingsbyrde',),
'forsørgingsbyrder': ('forsørgingsbyrde',),
'forsørgingsplikt': ('forsørgingsplikt',),
'forsørgingsplikta': ('forsørgingsplikt',),
'forsørgingsplikten': ('forsørgingsplikt',),
'forsørgingspliktene': ('forsørgingsplikt',),
'forsørgingsplikter': ('forsørgingsplikt',),
'fort': ('fort',),
'forta': ('fort',),
'fortene': ('fort',),
'forter': ('fort',),
'fortet': ('fort',),
'fortale': ('fortale',),
'fortalen': ('fortale',),
'fortalene': ('fortale',),
'fortaler': ('fortale',),
'fortaler': ('fortaler',),
'fortalere': ('fortaler',),
'fortaleren': ('fortaler',),
'fortalerer': ('fortaler',),
'fortalerne': ('fortaler',),
'fortann': ('fortann',),
'fortanna': ('fortann',),
'fortannen': ('fortann',),
'fortennene': ('fortann',),
'fortenner': ('fortann',),
'fortapelse': ('fortapelse',),
'fortapelsen': ('fortapelse',),
'fortapelsene': ('fortapelse',),
'fortapelser': ('fortapelse',),
'fortau': ('fortau',),
'fortaua': ('fortau',),
'fortauene': ('fortau',),
'fortauer': ('fortau',),
'fortauet': ('fortau',),
'fortaurestaurant': ('fortaurestaurant',),
'fortaurestauranten': ('fortaurestaurant',),
'fortaurestaurantene': ('fortaurestaurant',),
'fortaurestauranter': ('fortaurestaurant',),
'fortausrestaurant': ('fortausrestaurant',),
'fortausrestauranten': ('fortausrestaurant',),
'fortausrestaurantene': ('fortausrestaurant',),
'fortausrestauranter': ('fortausrestaurant',),
'forta': ('forte',),
'forte': ('forte',),
'fortene': ('forte',),
'forter': ('forte',),
'fortet': ('forte',),
'fortegn': ('fortegn',),
'fortegna': ('fortegn',),
'fortegnene': ('fortegn',),
'fortegnet': ('fortegn',),
'fortegnelse': ('fortegnelse',),
'fortegnelsen': ('fortegnelse',),
'fortegnelsene': ('fortegnelse',),
'fortegnelser': ('fortegnelse',),
'fortegning': ('fortegning',),
'fortegninga': ('fortegning',),
'fortegningen': ('fortegning',),
'fortegningene': ('fortegning',),
'fortegninger': ('fortegning',),
'fortegning': ('fortegning',),
'fortegninga': ('fortegning',),
'fortegningen': ('fortegning',),
'fortegningene': ('fortegning',),
'fortegninger': ('fortegning',),
'fortegning': ('fortegning',),
'fortegninga': ('fortegning',),
'fortegningen': ('fortegning',),
'fortegningene': ('fortegning',),
'fortegninger': ('fortegning',),
'fortelleform': ('fortelleform',),
'fortelleforma': ('fortelleform',),
'fortelleformen': ('fortelleform',),
'fortelleformene': ('fortelleform',),
'fortelleformer': ('fortelleform',),
'fortellekunst': ('fortellekunst',),
'fortellekunsten': ('fortellekunst',),
'fortellekunstene': ('fortellekunst',),
'fortellekunster': ('fortellekunst',),
'fortellemåte': ('fortellemåte',),
'fortellemåten': ('fortellemåte',),
'fortellemåtene': ('fortellemåte',),
'fortellemåter': ('fortellemåte',),
'forteller': ('forteller',),
'fortellere': ('forteller',),
'fortelleren': ('forteller',),
'fortellerer': ('forteller',),
'fortellerne': ('forteller',),
'fortellerkunst': ('fortellerkunst',),
'fortellerkunsten': ('fortellerkunst',),
'fortellerkunstene': ('fortellerkunst',),
'fortellerkunster': ('fortellerkunst',),
'fortellerstil': ('fortellerstil',),
'fortellerstilen': ('fortellerstil',),
'fortellerstilene': ('fortellerstil',),
'fortellerstiler': ('fortellerstil',),
'fortellertalent': ('fortellertalent',),
'fortellertalenten': ('fortellertalent',),
'fortellertalentene': ('fortellertalent',),
'fortellertalenter': ('fortellertalent',),
'fortellertalent': ('fortellertalent',),
'fortellertalenta': ('fortellertalent',),
'fortellertalentene': ('fortellertalent',),
'fortellertalentet': ('fortellertalent',),
'fortellestil': ('fortellestil',),
'fortellestilen': ('fortellestil',),
'fortellestilene': ('fortellestil',),
'fortellestiler': ('fortellestil',),
'fortelleteknikk': ('fortelleteknikk',),
'fortelleteknikken': ('fortelleteknikk',),
'fortelleteknikkene': ('fortelleteknikk',),
'fortelleteknikker': ('fortelleteknikk',),
'fortelling': ('fortelling',),
'fortellinga': ('fortelling',),
'fortellingen': ('fortelling',),
'fortellingene': ('fortelling',),
'fortellinger': ('fortelling',),
'fortetning': ('fortetning',),
'fortetninga': ('fortetning',),
'fortetningen': ('fortetning',),
'fortetningene': ('fortetning',),
'fortetninger': ('fortetning',),
'fortetningsapparat': ('fortetningsapparat',),
'fortetningsapparata': ('fortetningsapparat',),
'fortetningsapparatene': ('fortetningsapparat',),
'fortetningsapparater': ('fortetningsapparat',),
'fortetningsapparatet': ('fortetningsapparat',),
'fortetningspunkt': ('fortetningspunkt',),
'fortetningspunkta': ('fortetningspunkt',),
'fortetningspunktene': ('fortetningspunkt',),
'fortetningspunkter': ('fortetningspunkt',),
'fortetningspunktet': ('fortetningspunkt',),
'fortgang': ('fortgang',),
'fortgangen': ('fortgang',),
'fortgangene': ('fortgang',),
'fortganger': ('fortgang',),
'fortid': ('fortid',),
'fortida': ('fortid',),
'fortiden': ('fortid',),
'fortidene': ('fortid',),
'fortider': ('fortid',),
'fortidshistoria': ('fortidshistorie',),
'fortidshistorie': ('fortidshistorie',),
'fortidshistorien': ('fortidshistorie',),
'fortidshistoriene': ('fortidshistorie',),
'fortidshistorier': ('fortidshistorie',),
'fortidslevning': ('fortidslevning',),
'fortidslevninga': ('fortidslevning',),
'fortidslevningen': ('fortidslevning',),
'fortidslevningene': ('fortidslevning',),
'fortidslevninger': ('fortidslevning',),
'fortidsminna': ('fortidsminne',),
'fortidsminne': ('fortidsminne',),
'fortidsminnene': ('fortidsminne',),
'fortidsminner': ('fortidsminne',),
'fortidsminnet': ('fortidsminne',),
'fortielse': ('fortielse',),
'fortielsen': ('fortielse',),
'fortielsene': ('fortielse',),
'fortielser': ('fortielse',),
'fortifikasjon': ('fortifikasjon',),
'fortifikasjonen': ('fortifikasjon',),
'fortifikasjonene': ('fortifikasjon',),
'fortifikasjoner': ('fortifikasjon',),
'fortissimo': ('fortissimo',),
'fortissimoa': ('fortissimo',),
'fortissimoene': ('fortissimo',),
'fortissimoer': ('fortissimo',),
'fortissimoet': ('fortissimo',),
'fortjenesta': ('fortjeneste',),
'fortjeneste': ('fortjeneste',),
'fortjenesten': ('fortjeneste',),
'fortjenestene': ('fortjeneste',),
'fortjenester': ('fortjeneste',),
'fortjenestemedalje': ('fortjenestemedalje',),
'fortjenestemedaljen': ('fortjenestemedalje',),
'fortjenestemedaljene': ('fortjenestemedalje',),
'fortjenestemedaljer': ('fortjenestemedalje',),
'fortjenstmedalje': ('fortjenstmedalje',),
'fortjenstmedaljen': ('fortjenstmedalje',),
'fortjenstmedaljene': ('fortjenstmedalje',),
'fortjenstmedaljer': ('fortjenstmedalje',),
'fortolker': ('fortolker',),
'fortolkere': ('fortolker',),
'fortolkeren': ('fortolker',),
'fortolkerer': ('fortolker',),
'fortolkerne': ('fortolker',),
'fortolking': ('fortolking',),
'fortolkinga': ('fortolking',),
'fortolkingen': ('fortolking',),
'fortolkingene': ('fortolking',),
'fortolkinger': ('fortolking',),
'fortolkning': ('fortolkning',),
'fortolkninga': ('fortolkning',),
'fortolkningen': ('fortolkning',),
'fortolkningene': ('fortolkning',),
'fortolkninger': ('fortolkning',),
'fortom': ('fortom',),
'fortommen': ('fortom',),
'fortommene': ('fortom',),
'fortommer': ('fortom',),
'fortopp': ('fortopp',),
'fortoppen': ('fortopp',),
'fortoppene': ('fortopp',),
'fortopper': ('fortopp',),
'fortred': ('fortred',),
'fortreden': ('fortred',),
'fortredene': ('fortred',),
'fortreder': ('fortred',),
'fortredelighet': ('fortredelighet',),
'fortredeligheta': ('fortredelighet',),
'fortredeligheten': ('fortredelighet',),
'fortredelighetene': ('fortredelighet',),
'fortredeligheter': ('fortredelighet',),
'fortrekksgardin': ('fortrekksgardin',),
'fortrekksgardina': ('fortrekksgardin',),
'fortrekksgardinen': ('fortrekksgardin',),
'fortrekksgardinene': ('fortrekksgardin',),
'fortrekksgardiner': ('fortrekksgardin',),
'fortrekksgardinet': ('fortrekksgardin',),
'fortrengning': ('fortrengning',),
'fortrengninga': ('fortrengning',),
'fortrengningen': ('fortrengning',),
'fortrengningene': ('fortrengning',),
'fortrengninger': ('fortrengning',),
'fortrengningsmekanisme': ('fortrengningsmekanisme',),
'fortrengningsmekanismen': ('fortrengningsmekanisme',),
'fortrengningsmekanismene': ('fortrengningsmekanisme',),
'fortrengningsmekanismer': ('fortrengningsmekanisme',),
'fortrengsel': ('fortrengsel',),
'fortrengselen': ('fortrengsel',),
'fortrengslene': ('fortrengsel',),
'fortrengsler': ('fortrengsel',),
'fortrinn': ('fortrinn',),
'fortrinna': ('fortrinn',),
'fortrinnene': ('fortrinn',),
'fortrinnet': ('fortrinn',),
'fortrinnsrett': ('fortrinnsrett',),
'fortrinnsretten': ('fortrinnsrett',),
'fortrinnsrettene': ('fortrinnsrett',),
'fortrinnsretter': ('fortrinnsrett',),
'fortrolighet': ('fortrolighet',),
'fortroligheta': ('fortrolighet',),
'fortroligheten': ('fortrolighet',),
'fortrolighetene': ('fortrolighet',),
'fortroligheter': ('fortrolighet',),
'fortropp': ('fortropp',),
'fortroppen': ('fortropp',),
'fortroppene': ('fortropp',),
'fortropper': ('fortropp',),
'fortrøstning': ('fortrøstning',),
'fortrøstninga': ('fortrøstning',),
'fortrøstningen': ('fortrøstning',),
'fortrøstningene': ('fortrøstning',),
'fortrøstninger': ('fortrøstning',),
'fortsettelse': ('fortsettelse',),
'fortsettelsen': ('fortsettelse',),
'fortsettelsene': ('fortsettelse',),
'fortsettelser': ('fortsettelse',),
'fortsettelsesfortelling': ('fortsettelsesfortelling',),
'fortsettelsesfortellinga': ('fortsettelsesfortelling',),
'fortsettelsesfortellingen': ('fortsettelsesfortelling',),
'fortsettelsesfortellingene': ('fortsettelsesfortelling',),
'fortsettelsesfortellinger': ('fortsettelsesfortelling',),
'fortuna': ('fortuna',),
'fortvilelse': ('fortvilelse',),
'fortvilelsen': ('fortvilelse',),
'fortvilelsene': ('fortvilelse',),
'fortvilelser': ('fortvilelse',),
'fortykning': ('fortykning',),
'fortykninga': ('fortykning',),
'fortykningen': ('fortykning',),
'fortykningene': ('fortykning',),
'fortykninger': ('fortykning',),
'fortynning': ('fortynning',),
'fortynninga': ('fortynning',),
'fortynningen': ('fortynning',),
'fortynningene': ('fortynning',),
'fortynninger': ('fortynning',),
'fortynningsmiddel': ('fortynningsmiddel',),
'fortynningsmiddelet': ('fortynningsmiddel',),
'fortynningsmidla': ('fortynningsmiddel',),
'fortynningsmidlene': ('fortynningsmiddel',),
'fortynningsmidler': ('fortynningsmiddel',),
'fortynningsmidlet': ('fortynningsmiddel',),
'fortynningsvæska': ('fortynningsvæske',),
'fortynningsvæske': ('fortynningsvæske',),
'fortynningsvæsken': ('fortynningsvæske',),
'fortynningsvæskene': ('fortynningsvæske',),
'fortynningsvæsker': ('fortynningsvæske',),
'fortøyning': ('fortøyning',),
'fortøyninga': ('fortøyning',),
'fortøyningen': ('fortøyning',),
'fortøyningene': ('fortøyning',),
'fortøyninger': ('fortøyning',),
'fora': ('forum',),
'foraene': ('forum',),
'forum': ('forum',),
'foruma': ('forum',),
'forumene': ('forum',),
'forumer': ('forum',),
'forumet': ('forum',),
'forundersøkelse': ('forundersøkelse',),
'forundersøkelsen': ('forundersøkelse',),
'forundersøkelsene': ('forundersøkelse',),
'forundersøkelser': ('forundersøkelse',),
'forundersøking': ('forundersøking',),
'forundersøkinga': ('forundersøking',),
'forundersøkingen': ('forundersøking',),
'forundersøkingene': ('forundersøking',),
'forundersøkinger': ('forundersøking',),
'forundring': ('forundring',),
'forundringa': ('forundring',),
'forundringen': ('forundring',),
'forundringene': ('forundring',),
'forundringer': ('forundring',),
'forundringspakka': ('forundringspakke',),
'forundringspakke': ('forundringspakke',),
'forundringspakken': ('forundringspakke',),
'forundringspakkene': ('forundringspakke',),
'forundringspakker': ('forundringspakke',),
'forurensning': ('forurensning',),
'forurensninga': ('forurensning',),
'forurensningen': ('forurensning',),
'forurensningene': ('forurensning',),
'forurensninger': ('forurensning',),
'forurensningskilde': ('forurensningskilde',),
'forurensningskilden': ('forurensningskilde',),
'forurensningskildene': ('forurensningskilde',),
'forurensningskilder': ('forurensningskilde',),
'forurensningskjelda': ('forurensningskjelde',),
'forurensningskjelde': ('forurensningskjelde',),
'forurensningskjelden': ('forurensningskjelde',),
'forurensningskjeldene': ('forurensningskjelde',),
'forurensningskjelder': ('forurensningskjelde',),
'forurensningsproblem': ('forurensningsproblem',),
'forurensningsproblema': ('forurensningsproblem',),
'forurensningsproblemene': ('forurensningsproblem',),
'forurensningsproblemer': ('forurensningsproblem',),
'forurensningsproblemet': ('forurensningsproblem',),
'forurensningstilsyn': ('forurensningstilsyn',),
'forurensningstilsyna': ('forurensningstilsyn',),
'forurensningstilsynene': ('forurensningstilsyn',),
'forurensningstilsynet': ('forurensningstilsyn',),
'forutanelse': ('forutanelse',),
'forutanelsen': ('forutanelse',),
'forutanelsene': ('forutanelse',),
'forutanelser': ('forutanelse',),
'forutaning': ('forutaning',),
'forutaninga': ('forutaning',),
'forutaningen': ('forutaning',),
'forutaningene': ('forutaning',),
'forutaninger': ('forutaning',),
'forutbestemmelse': ('forutbestemmelse',),
'forutbestemmelsen': ('forutbestemmelse',),
'forutbestemmelsene': ('forutbestemmelse',),
'forutbestemmelser': ('forutbestemmelse',),
'forutinntatthet': ('forutinntatthet',),
'forutinntattheta': ('forutinntatthet',),
'forutinntattheten': ('forutinntatthet',),
'forutinntatthetene': ('forutinntatthet',),
'forutinntattheter': ('forutinntatthet',),
'forutseenhet': ('forutseenhet',),
'forutseenheta': ('forutseenhet',),
'forutseenheten': ('forutseenhet',),
'forutseenhetene': ('forutseenhet',),
'forutseenheter': ('forutseenhet',),
'forutsetning': ('forutsetning',),
'forutsetninga': ('forutsetning',),
'forutsetningen': ('forutsetning',),
'forutsetningene': ('forutsetning',),
'forutsetninger': ('forutsetning',),
'forutsigelse': ('forutsigelse',),
'forutsigelsen': ('forutsigelse',),
'forutsigelsene': ('forutsigelse',),
'forutsigelser': ('forutsigelse',),
'forvalter': ('forvalter',),
'forvaltere': ('forvalter',),
'forvalteren': ('forvalter',),
'forvalterer': ('forvalter',),
'forvalterne': ('forvalter',),
'forvaltning': ('forvaltning',),
'forvaltninga': ('forvaltning',),
'forvaltningen': ('forvaltning',),
'forvaltningene': ('forvaltning',),
'forvaltninger': ('forvaltning',),
'forvaltningsbedrift': ('forvaltningsbedrift',),
'forvaltningsbedriften': ('forvaltningsbedrift',),
'forvaltningsbedriftene': ('forvaltningsbedrift',),
'forvaltningsbedrifter': ('forvaltningsbedrift',),
'forvaltningsdomstol': ('forvaltningsdomstol',),
'forvaltningsdomstolen': ('forvaltningsdomstol',),
'forvaltningsdomstolene': ('forvaltningsdomstol',),
'forvaltningsdomstoler': ('forvaltningsdomstol',),
'forvaltningskapital': ('forvaltningskapital',),
'forvaltningskapitalen': ('forvaltningskapital',),
'forvaltningskapitalene': ('forvaltningskapital',),
'forvaltningskapitaler': ('forvaltningskapital',),
'forvaltningsorgan': ('forvaltningsorgan',),
'forvaltningsorgana': ('forvaltningsorgan',),
'forvaltningsorganene': ('forvaltningsorgan',),
'forvaltningsorganer': ('forvaltningsorgan',),
'forvaltningsorganet': ('forvaltningsorgan',),
'forvaltningsrett': ('forvaltningsrett',),
'forvaltningsretten': ('forvaltningsrett',),
'forvaltningsrettene': ('forvaltningsrett',),
'forvaltningsretter': ('forvaltningsrett',),
'forvandling': ('forvandling',),
'forvandlinga': ('forvandling',),
'forvandlingen': ('forvandling',),
'forvandlingene': ('forvandling',),
'forvandlinger': ('forvandling',),
'forvandlingsprosess': ('forvandlingsprosess',),
'forvandlingsprosessen': ('forvandlingsprosess',),
'forvandlingsprosessene': ('forvandlingsprosess',),
'forvandlingsprosesser': ('forvandlingsprosess',),
'forvanskning': ('forvanskning',),
'forvanskninga': ('forvanskning',),
'forvanskningen': ('forvanskning',),
'forvanskningene': ('forvanskning',),
'forvanskninger': ('forvanskning',),
'forvar': ('forvar',),
'forvaring': ('forvaring',),
'forvaringa': ('forvaring',),
'forvaringen': ('forvaring',),
'forvaringene': ('forvaring',),
'forvaringer': ('forvaring',),
'forvarsel': ('forvarsel',),
'forvarselet': ('forvarsel',),
'forvarsla': ('forvarsel',),
'forvarslene': ('forvarsel',),
'forvarsler': ('forvarsel',),
'forvarslet': ('forvarsel',),
'forvask': ('forvask',),
'forvasken': ('forvask',),
'forvaskene': ('forvask',),
'forvasker': ('forvask',),
'forveg': ('forveg',),
'forvegen': ('forveg',),
'forvegene': ('forveg',),
'forveger': ('forveg',),
'forvei': ('forvei',),
'forveien': ('forvei',),
'forveiene': ('forvei',),
'forveier': ('forvei',),
'forveksling': ('forveksling',),
'forvekslinga': ('forveksling',),
'forvekslingen': ('forveksling',),
'forvekslingene': ('forveksling',),
'forvekslinger': ('forveksling',),
'forventning': ('forventning',),
'forventninga': ('forventning',),
'forventningen': ('forventning',),
'forventningene': ('forventning',),
'forventninger': ('forventning',),
'forvern': ('forvern',),
'forverna': ('forvern',),
'forvernene': ('forvern',),
'forvernet': ('forvern',),
'forvikling': ('forvikling',),
'forviklinga': ('forvikling',),
'forviklingen': ('forvikling',),
'forviklingene': ('forvikling',),
'forviklinger': ('forvikling',),
'forviklingskomedie': ('forviklingskomedie',),
'forviklingskomedien': ('forviklingskomedie',),
'forviklingskomediene': ('forviklingskomedie',),
'forviklingskomedier': ('forviklingskomedie',),
'forvinter': ('forvinter',),
'forvintere': ('forvinter',),
'forvinteren': ('forvinter',),
'forvinterne': ('forvinter',),
'forvintre': ('forvinter',),
'forvintrene': ('forvinter',),
'forvintrer': ('forvinter',),
'forvirring': ('forvirring',),
'forvirringa': ('forvirring',),
'forvirringen': ('forvirring',),
'forvirringene': ('forvirring',),
'forvirringer': ('forvirring',),
'forvisning': ('forvisning',),
'forvisninga': ('forvisning',),
'forvisningen': ('forvisning',),
'forvisningene': ('forvisning',),
'forvisninger': ('forvisning',),
'forvissning': ('forvissning',),
'forvissninga': ('forvissning',),
'forvissningen': ('forvissning',),
'forvissningene': ('forvissning',),
'forvissninger': ('forvissning',),
'forvitring': ('forvitring',),
'forvitringa': ('forvitring',),
'forvitringen': ('forvitring',),
'forvitringene': ('forvitring',),
'forvitringer': ('forvitring',),
'forvitringsskorpa': ('forvitringsskorpe',),
'forvitringsskorpe': ('forvitringsskorpe',),
'forvitringsskorpen': ('forvitringsskorpe',),
'forvitringsskorpene': ('forvitringsskorpe',),
'forvitringsskorper': ('forvitringsskorpe',),
'forværelsa': ('forværelse',),
'forværelse': ('forværelse',),
'forværelsene': ('forværelse',),
'forværelser': ('forværelse',),
'forværelset': ('forværelse',),
'forward': ('forward',),
'forwarden': ('forward',),
'forwardene': ('forward',),
'forwarder': ('forward',),
'foryngelseskur': ('foryngelseskur',),
'foryngelseskuren': ('foryngelseskur',),
'foryngelseskurene': ('foryngelseskur',),
'foryngelseskurer': ('foryngelseskur',),
'foryngelsesmiddel': ('foryngelsesmiddel',),
'foryngelsesmiddelet': ('foryngelsesmiddel',),
'foryngelsesmidla': ('foryngelsesmiddel',),
'foryngelsesmidlene': ('foryngelsesmiddel',),
'foryngelsesmidler': ('foryngelsesmiddel',),
'foryngelsesmidlet': ('foryngelsesmiddel',),
'forår': ('forår',),
'foråra': ('forår',),
'forårene': ('forår',),
'foråret': ('forår',),
'foræring': ('foræring',),
'foræringa': ('foræring',),
'foræringen': ('foræring',),
'foræringene': ('foræring',),
'foræringer': ('foræring',),
'forøkelse': ('forøkelse',),
'forøkelsen': ('forøkelse',),
'forøkelsene': ('forøkelse',),
'forøkelser': ('forøkelse',),
'forøkning': ('forøkning',),
'forøkninga': ('forøkning',),
'forøkningen': ('forøkning',),
'forøkningene': ('forøkning',),
'forøkninger': ('forøkning',),
'forørkning': ('forørkning',),
'forørkninga': ('forørkning',),
'forørkningen': ('forørkning',),
'forørkningene': ('forørkning',),
'forørkninger': ('forørkning',),
'fosfat': ('fosfat',),
'fosfata': ('fosfat',),
'fosfatene': ('fosfat',),
'fosfater': ('fosfat',),
'fosfatet': ('fosfat',),
'fosfatgjødsel': ('fosfatgjødsel',),
'fosfatgjødselen': ('fosfatgjødsel',),
'fosfatgjødsla': ('fosfatgjødsel',),
'fosfatgjødslene': ('fosfatgjødsel',),
'fosfatgjødsler': ('fosfatgjødsel',),
'fosfor': ('fosfor',),
'fosfora': ('fosfor',),
'fosforen': ('fosfor',),
'fosforene': ('fosfor',),
'fosforer': ('fosfor',),
'fosforet': ('fosfor',),
'fosforescens': ('fosforescens',),
'fosforescensen': ('fosforescens',),
'fosforescensene': ('fosforescens',),
'fosforescenser': ('fosforescens',),
'fosforgjødsel': ('fosforgjødsel',),
'fosforgjødselen': ('fosforgjødsel',),
'fosforgjødsla': ('fosforgjødsel',),
'fosforgjødslene': ('fosforgjødsel',),
'fosforgjødsler': ('fosforgjødsel',),
'fosforsyra': ('fosforsyre',),
'fosforsyre': ('fosforsyre',),
'fosforsyren': ('fosforsyre',),
'fosforsyrene': ('fosforsyre',),
'fosforsyrer': ('fosforsyre',),
'fosnakultur': ('fosnakultur',),
'fosnakulturen': ('fosnakultur',),
'fosnakulturene': ('fosnakultur',),
'fosnakulturer': ('fosnakultur',),
'foss': ('foss',),
'fossen': ('foss',),
'fossene': ('foss',),
'fosser': ('foss',),
'fossebrus': ('fossebrus',),
'fossebrusa': ('fossebrus',),
'fossebrusene': ('fossebrus',),
'fossebruset': ('fossebrus',),
'fossedur': ('fossedur',),
'fosseduren': ('fossedur',),
'fossedurene': ('fossedur',),
'fossedurer': ('fossedur',),
'fossefall': ('fossefall',),
'fossefalla': ('fossefall',),
'fossefallene': ('fossefall',),
'fossefallet': ('fossefall',),
'fossegrim': ('fossegrim',),
'fossegrimen': ('fossegrim',),
'fossegrimene': ('fossegrim',),
'fossegrimer': ('fossegrim',),
'fossekall': ('fossekall',),
'fossekallen': ('fossekall',),
'fossekallene': ('fossekall',),
'fossekaller': ('fossekall',),
'fossekraft': ('fossekraft',),
'fossekrafta': ('fossekraft',),
'fossekraften': ('fossekraft',),
'fossekreftene': ('fossekraft',),
'fossekrefter': ('fossekraft',),
'fossestryk': ('fossestryk',),
'fossestryka': ('fossestryk',),
'fossestrykene': ('fossestryk',),
'fossestryket': ('fossestryk',),
'fossil': ('fossil',),
'fossila': ('fossil',),
'fossilen': ('fossil',),
'fossilene': ('fossil',),
'fossiler': ('fossil',),
'fossilet': ('fossil',),
'fostbror': ('fostbror',),
'fostbroren': ('fostbror',),
'fostbrødre': ('fostbror',),
'fostbrødrene': ('fostbror',),
'fostbrorskap': ('fostbrorskap',),
'fostbrorskapa': ('fostbrorskap',),
'fostbrorskapen': ('fostbrorskap',),
'fostbrorskapene': ('fostbrorskap',),
'fostbrorskaper': ('fostbrorskap',),
'fostbrorskapet': ('fostbrorskap',),
'foster': ('foster',),
'fosteret': ('foster',),
'fostra': ('foster',),
'fostre': ('foster',),
'fostrene': ('foster',),
'fostret': ('foster',),
'fosterbarn': ('fosterbarn',),
'fosterbarna': ('fosterbarn',),
'fosterbarnene': ('fosterbarn',),
'fosterbarnet': ('fosterbarn',),
'fosterdatter': ('fosterdatter',),
'fosterdattera': ('fosterdatter',),
'fosterdatteren': ('fosterdatter',),
'fosterdøtre': ('fosterdatter',),
'fosterdøtrene': ('fosterdatter',),
'fosterdøtrer': ('fosterdatter',),
'fosterdrap': ('fosterdrap',),
'fosterdrapa': ('fosterdrap',),
'fosterdrapene': ('fosterdrap',),
'fosterdrapet': ('fosterdrap',),
'fosterhinna': ('fosterhinne',),
'fosterhinne': ('fosterhinne',),
'fosterhinnen': ('fosterhinne',),
'fosterhinnene': ('fosterhinne',),
'fosterhinner': ('fosterhinne',),
'fosterlyd': ('fosterlyd',),
'fosterlyden': ('fosterlyd',),
'fosterlydene': ('fosterlyd',),
'fosterlyder': ('fosterlyd',),
'fostersønn': ('fostersønn',),
'fostersønnen': ('fostersønn',),
'fostersønnene': ('fostersønn',),
'fostersønner': ('fostersønn',),
'fostervann': ('fostervann',),
'fostervanna': ('fostervann',),
'fostervannene': ('fostervann',),
'fostervannet': ('fostervann',),
'fostervannsprøva': ('fostervannsprøve',),
'fostervannsprøve': ('fostervannsprøve',),
'fostervannsprøven': ('fostervannsprøve',),
'fostervannsprøvene': ('fostervannsprøve',),
'fostervannsprøver': ('fostervannsprøve',),
'fostervassprøva': ('fostervassprøve',),
'fostervassprøve': ('fostervassprøve',),
'fostervassprøven': ('fostervassprøve',),
'fostervassprøvene': ('fostervassprøve',),
'fostervassprøver': ('fostervassprøve',),
'fostervatn': ('fostervatn',),
'fostervatna': ('fostervatn',),
'fostervatnene': ('fostervatn',),
'fostervatnet': ('fostervatn',),
'fostring': ('fostring',),
'fostringa': ('fostring',),
'fostringen': ('fostring',),
'fostringene': ('fostring',),
'fostringer': ('fostring',),
'fotarbeid': ('fotarbeid',),
'fotarbeida': ('fotarbeid',),
'fotarbeidene': ('fotarbeid',),
'fotarbeider': ('fotarbeid',),
'fotarbeidet': ('fotarbeid',),
'fotball': ('fotball',),
'fotballen': ('fotball',),
'fotballene': ('fotball',),
'fotballer': ('fotball',),
'fotballe': ('fotballe',),
'fotballen': ('fotballe',),
'fotballene': ('fotballe',),
'fotballer': ('fotballe',),
'fotballkamp': ('fotballkamp',),
'fotballkampen': ('fotballkamp',),
'fotballkampene': ('fotballkamp',),
'fotballkamper': ('fotballkamp',),
'fotballspeller': ('fotballspeller',),
'fotballspellere': ('fotballspeller',),
'fotballspelleren': ('fotballspeller',),
'fotballspellerer': ('fotballspeller',),
'fotballspellerne': ('fotballspeller',),
'fotballspiller': ('fotballspiller',),
'fotballspillere': ('fotballspiller',),
'fotballspilleren': ('fotballspiller',),
'fotballspillerer': ('fotballspiller',),
'fotballspillerne': ('fotballspiller',),
'fotblad': ('fotblad',),
'fotblada': ('fotblad',),
'fotbladene': ('fotblad',),
'fotblader': ('fotblad',),
'fotbladet': ('fotblad',),
'fotbrems': ('fotbrems',),
'fotbremsen': ('fotbrems',),
'fotbremsene': ('fotbrems',),
'fotbremser': ('fotbrems',),
'fotbremsa': ('fotbremse',),
'fotbremse': ('fotbremse',),
'fotbremsen': ('fotbremse',),
'fotbremsene': ('fotbremse',),
'fotbremser': ('fotbremse',),
'fotefar': ('fotefar',),
'fotefara': ('fotefar',),
'fotefarene': ('fotefar',),
'fotefaret': ('fotefar',),
'fotende': ('fotende',),
'fotenden': ('fotende',),
'fotendene': ('fotende',),
'fotender': ('fotende',),
'fotfesta': ('fotfeste',),
'fotfeste': ('fotfeste',),
'fotfestene': ('fotfeste',),
'fotfester': ('fotfeste',),
'fotfestet': ('fotfeste',),
'fotfolk': ('fotfolk',),
'fotfolka': ('fotfolk',),
'fotfolkene': ('fotfolk',),
'fotfolket': ('fotfolk',),
'fotfødsel': ('fotfødsel',),
'fotfødselen': ('fotfødsel',),
'fotfødslene': ('fotfødsel',),
'fotfødsler': ('fotfødsel',),
'fotgikt': ('fotgikt',),
'fotgikta': ('fotgikt',),
'fotgikten': ('fotgikt',),
'fotgiktene': ('fotgikt',),
'fotgikter': ('fotgikt',),
'fotgjenger': ('fotgjenger',),
'fotgjengere': ('fotgjenger',),
'fotgjengeren': ('fotgjenger',),
'fotgjengerer': ('fotgjenger',),
'fotgjengerne': ('fotgjenger',),
'fotgjengerbro': ('fotgjengerbro',),
'fotgjengerbroa': ('fotgjengerbro',),
'fotgjengerbroen': ('fotgjengerbro',),
'fotgjengerbroene': ('fotgjengerbro',),
'fotgjengerbroer': ('fotgjengerbro',),
'fotgjengerbru': ('fotgjengerbru',),
'fotgjengerbrua': ('fotgjengerbru',),
'fotgjengerbruen': ('fotgjengerbru',),
'fotgjengerbruene': ('fotgjengerbru',),
'fotgjengerbruer': ('fotgjengerbru',),
'fotgjengerfelt': ('fotgjengerfelt',),
'fotgjengerfelta': ('fotgjengerfelt',),
'fotgjengerfeltene': ('fotgjengerfelt',),
'fotgjengerfelter': ('fotgjengerfelt',),
'fotgjengerfeltet': ('fotgjengerfelt',),
'fotgjengerovergang': ('fotgjengerovergang',),
'fotgjengerovergangen': ('fotgjengerovergang',),
'fotgjengerovergangene': ('fotgjengerovergang',),
'fotgjengeroverganger': ('fotgjengerovergang',),
'fotnote': ('fotnote',),
'fotnoten': ('fotnote',),
'fotnotene': ('fotnote',),
'fotnoter': ('fotnote',),
'foto': ('foto',),
'fotoa': ('foto',),
'fotoene': ('foto',),
'fotoer': ('foto',),
'fotoet': ('foto',),
'fotoapparat': ('fotoapparat',),
'fotoapparata': ('fotoapparat',),
'fotoapparatene': ('fotoapparat',),
'fotoapparater': ('fotoapparat',),
'fotoapparatet': ('fotoapparat',),
'fotocella': ('fotocelle',),
'fotocelle': ('fotocelle',),
'fotocellen': ('fotocelle',),
'fotocellene': ('fotocelle',),
'fotoceller': ('fotocelle',),
'fotofinish': ('fotofinish',),
'fotofinishen': ('fotofinish',),
'fotofinishene': ('fotofinish',),
'fotofinisher': ('fotofinish',),
'fotograf': ('fotograf',),
'fotografen': ('fotograf',),
'fotografene': ('fotograf',),
'fotografer': ('fotograf',),
'fotografi': ('fotografi',),
'fotografien': ('fotografi',),
'fotografiene': ('fotografi',),
'fotografier': ('fotografi',),
'fotografi': ('fotografi',),
'fotografia': ('fotografi',),
'fotografiene': ('fotografi',),
'fotografier': ('fotografi',),
'fotografiet': ('fotografi',),
'fotografiapparat': ('fotografiapparat',),
'fotografiapparata': ('fotografiapparat',),
'fotografiapparatene': ('fotografiapparat',),
'fotografiapparater': ('fotografiapparat',),
'fotografiapparatet': ('fotografiapparat',),
'fotogravyr': ('fotogravyr',),
'fotogravyren': ('fotogravyr',),
'fotogravyrene': ('fotogravyr',),
'fotogravyrer': ('fotogravyr',),
'fotogravyr': ('fotogravyr',),
'fotogravyra': ('fotogravyr',),
'fotogravyrene': ('fotogravyr',),
'fotogravyrer': ('fotogravyr',),
'fotogravyret': ('fotogravyr',),
'fotokjemi': ('fotokjemi',),
'fotokjemien': ('fotokjemi',),
'fotokjemiene': ('fotokjemi',),
'fotokjemier': ('fotokjemi',),
'fotoklubb': ('fotoklubb',),
'fotoklubben': ('fotoklubb',),
'fotoklubbene': ('fotoklubb',),
'fotoklubber': ('fotoklubb',),
'fotokopi': ('fotokopi',),
'fotokopien': ('fotokopi',),
'fotokopiene': ('fotokopi',),
'fotokopier': ('fotokopi',),
'fotokunst': ('fotokunst',),
'fotokunsten': ('fotokunst',),
'fotokunstene': ('fotokunst',),
'fotokunster': ('fotokunst',),
'fotometer': ('fotometer',),
'fotometeret': ('fotometer',),
'fotometra': ('fotometer',),
'fotometre': ('fotometer',),
'fotometrene': ('fotometer',),
'fotometret': ('fotometer',),
'fotometri': ('fotometri',),
'fotometrien': ('fotometri',),
'fotometriene': ('fotometri',),
'fotometrier': ('fotometri',),
'fotomodell': ('fotomodell',),
'fotomodellen': ('fotomodell',),
'fotomodellene': ('fotomodell',),
'fotomodeller': ('fotomodell',),
'fotomontasje': ('fotomontasje',),
'fotomontasjen': ('fotomontasje',),
'fotomontasjene': ('fotomontasje',),
'fotomontasjer': ('fotomontasje',),
'foton': ('foton',),
'fotona': ('foton',),
'fotonene': ('foton',),
'fotoner': ('foton',),
'fotonet': ('foton',),
'fotoreportasje': ('fotoreportasje',),
'fotoreportasjen': ('fotoreportasje',),
'fotoreportasjene': ('fotoreportasje',),
'fotoreportasjer': ('fotoreportasje',),
'fotoreporter': ('fotoreporter',),
'fotoreportere': ('fotoreporter',),
'fotoreporteren': ('fotoreporter',),
'fotoreporterer': ('fotoreporter',),
'fotoreporterne': ('fotoreporter',),
'fotosats': ('fotosats',),
'fotosatsen': ('fotosats',),
'fotosatsene': ('fotosats',),
'fotosatser': ('fotosats',),
'fotostat': ('fotostat',),
'fotostaten': ('fotostat',),
'fotostatene': ('fotostat',),
'fotostater': ('fotostat',),
'fotostatkopi': ('fotostatkopi',),
'fotostatkopien': ('fotostatkopi',),
'fotostatkopiene': ('fotostatkopi',),
'fotostatkopier': ('fotostatkopi',),
'fotosyntese': ('fotosyntese',),
'fotosyntesen': ('fotosyntese',),
'fotosyntesene': ('fotosyntese',),
'fotosynteser': ('fotosyntese',),
'fototaksiene': ('fototaksis',),
'fototaksier': ('fototaksis',),
'fototaksis': ('fototaksis',),
'fototaksisen': ('fototaksis',),
'fototaksisene': ('fototaksis',),
'fototaksiser': ('fototaksis',),
'fototek': ('fototek',),
'fototeka': ('fototek',),
'fototekene': ('fototek',),
'fototeker': ('fototek',),
'fototeket': ('fototek',),
'fototropisme': ('fototropisme',),
'fototropismen': ('fototropisme',),
'fototropismene': ('fototropisme',),
'fototropismer': ('fototropisme',),
'fotoutstyr': ('fotoutstyr',),
'fotoutstyra': ('fotoutstyr',),
'fotoutstyrene': ('fotoutstyr',),
'fotoutstyret': ('fotoutstyr',),
'fotpleia': ('fotpleie',),
'fotpleie': ('fotpleie',),
'fotpleien': ('fotpleie',),
'fotpleiene': ('fotpleie',),
'fotpleier': ('fotpleie',),
'fotpleier': ('fotpleier',),
'fotpleiere': ('fotpleier',),
'fotpleieren': ('fotpleier',),
'fotpleierer': ('fotpleier',),
'fotpleierne': ('fotpleier',),
'fotpunkt': ('fotpunkt',),
'fotpunkta': ('fotpunkt',),
'fotpunktene': ('fotpunkt',),
'fotpunkter': ('fotpunkt',),
'fotpunktet': ('fotpunkt',),
'fotrot': ('fotrot',),
'fotrota': ('fotrot',),
'fotroten': ('fotrot',),
'fotrøttene': ('fotrot',),
'fotrøtter': ('fotrot',),
'fotrotsbein': ('fotrotsbein',),
'fotrotsbeina': ('fotrotsbein',),
'fotrotsbeinene': ('fotrotsbein',),
'fotrotsbeinet': ('fotrotsbein',),
'fotrotsben': ('fotrotsben',),
'fotrotsbena': ('fotrotsben',),
'fotrotsbenene': ('fotrotsben',),
'fotrotsbenet': ('fotrotsben',),
'fotsbredd': ('fotsbredd',),
'fotsbredden': ('fotsbredd',),
'fotsbreddene': ('fotsbredd',),
'fotsbredder': ('fotsbredd',),
'fotsopp': ('fotsopp',),
'fotsoppen': ('fotsopp',),
'fotsoppene': ('fotsopp',),
'fotsopper': ('fotsopp',),
'fotspor': ('fotspor',),
'fotspora': ('fotspor',),
'fotsporene': ('fotspor',),
'fotsporet': ('fotspor',),
'fotstykka': ('fotstykke',),
'fotstykke': ('fotstykke',),
'fotstykkene': ('fotstykke',),
'fotstykker': ('fotstykke',),
'fotstykket': ('fotstykke',),
'fotsvette': ('fotsvette',),
'fotsvetten': ('fotsvette',),
'fotsvettene': ('fotsvette',),
'fotsvetter': ('fotsvette',),
'fotsåle': ('fotsåle',),
'fotsålen': ('fotsåle',),
'fotsålene': ('fotsåle',),
'fotsåler': ('fotsåle',),
'fotterapeut': ('fotterapeut',),
'fotterapeuten': ('fotterapeut',),
'fotterapeutene': ('fotterapeut',),
'fotterapeuter': ('fotterapeut',),
'fottrinn': ('fottrinn',),
'fottrinna': ('fottrinn',),
'fottrinnene': ('fottrinn',),
'fottrinnet': ('fottrinn',),
'fottur': ('fottur',),
'fotturen': ('fottur',),
'fotturene': ('fottur',),
'fotturer': ('fottur',),
'fotturist': ('fotturist',),
'fotturisten': ('fotturist',),
'fotturistene': ('fotturist',),
'fotturister': ('fotturist',),
'fottøy': ('fottøy',),
'fottøya': ('fottøy',),
'fottøyene': ('fottøy',),
'fottøyet': ('fottøy',),
'foxterrier': ('foxterrier',),
'foxterriere': ('foxterrier',),
'foxterrieren': ('foxterrier',),
'foxterrierer': ('foxterrier',),
'foxterrierne': ('foxterrier',),
'foxtrot': ('foxtrot',),
'foxtroten': ('foxtrot',),
'foxtrotene': ('foxtrot',),
'foxtroter': ('foxtrot',),
'fradrag': ('fradrag',),
'fradraga': ('fradrag',),
'fradragene': ('fradrag',),
'fradraget': ('fradrag',),
'fradragsbeløp': ('fradragsbeløp',),
'fradragsbeløpa': ('fradragsbeløp',),
'fradragsbeløpene': ('fradragsbeløp',),
'fradragsbeløpet': ('fradragsbeløp',),
'frafall': ('frafall',),
'frafalla': ('frafall',),
'frafallene': ('frafall',),
'frafallet': ('frafall',),
'frafallsprosent': ('frafallsprosent',),
'frafallsprosenten': ('frafallsprosent',),
'frafallsprosentene': ('frafallsprosent',),
'frafallsprosenter': ('frafallsprosent',),
'fraflytning': ('fraflytning',),
'fraflytninga': ('fraflytning',),
'fraflytningen': ('fraflytning',),
'fraflytningene': ('fraflytning',),
'fraflytninger': ('fraflytning',),
'fraflytning': ('fraflytning',),
'fraflytninga': ('fraflytning',),
'fraflytningen': ('fraflytning',),
'fraflytningene': ('fraflytning',),
'fraflytninger': ('fraflytning',),
'fraflytning': ('fraflytning',),
'fraflytninga': ('fraflytning',),
'fraflytningen': ('fraflytning',),
'fraflytningene': ('fraflytning',),
'fraflytninger': ('fraflytning',),
'fraflytningsområda': ('fraflytningsområde',),
'fraflytningsområde': ('fraflytningsområde',),
'fraflytningsområdene': ('fraflytningsområde',),
'fraflytningsområder': ('fraflytningsområde',),
'fraflytningsområdet': ('fraflytningsområde',),
'fraflyttingsområda': ('fraflyttingsområde',),
'fraflyttingsområde': ('fraflyttingsområde',),
'fraflyttingsområdene': ('fraflyttingsområde',),
'fraflyttingsområder': ('fraflyttingsområde',),
'fraflyttingsområdet': ('fraflyttingsområde',),
'fragment': ('fragment',),
'fragmenta': ('fragment',),
'fragmentene': ('fragment',),
'fragmenter': ('fragment',),
'fragmentet': ('fragment',),
'frakk': ('frakk',),
'frakken': ('frakk',),
'frakkene': ('frakk',),
'frakker': ('frakk',),
'fraksjon': ('fraksjon',),
'fraksjonen': ('fraksjon',),
'fraksjonene': ('fraksjon',),
'fraksjoner': ('fraksjon',),
'fraksjonsleder': ('fraksjonsleder',),
'fraksjonsledere': ('fraksjonsleder',),
'fraksjonslederen': ('fraksjonsleder',),
'fraksjonslederer': ('fraksjonsleder',),
'fraksjonslederne': ('fraksjonsleder',),
'fraksjonsvirksomhet': ('fraksjonsvirksomhet',),
'fraksjonsvirksomheta': ('fraksjonsvirksomhet',),
'fraksjonsvirksomheten': ('fraksjonsvirksomhet',),
'fraksjonsvirksomhetene': ('fraksjonsvirksomhet',),
'fraksjonsvirksomheter': ('fraksjonsvirksomhet',),
'frakt': ('frakt',),
'frakta': ('frakt',),
'frakten': ('frakt',),
'fraktene': ('frakt',),
'frakter': ('frakt',),
'fraktal': ('fraktal',),
'fraktalen': ('fraktal',),
'fraktalene': ('fraktal',),
'fraktaler': ('fraktal',),
'fraktavtale': ('fraktavtale',),
'fraktavtalen': ('fraktavtale',),
'fraktavtalene': ('fraktavtale',),
'fraktavtaler': ('fraktavtale',),
'fraktbrev': ('fraktbrev',),
'fraktbreva': ('fraktbrev',),
'fraktbrevene': ('fraktbrev',),
'fraktbrever': ('fraktbrev',),
'fraktbrevet': ('fraktbrev',),
'fraktefartøy': ('fraktefartøy',),
'fraktefartøya': ('fraktefartøy',),
'fraktefartøyene': ('fraktefartøy',),
'fraktefartøyer': ('fraktefartøy',),
'fraktefartøyet': ('fraktefartøy',),
'frakteskuta': ('frakteskute',),
'frakteskute': ('frakteskute',),
'frakteskuten': ('frakteskute',),
'frakteskutene': ('frakteskute',),
'frakteskuter': ('frakteskute',),
'fraktfart': ('fraktfart',),
'fraktfarten': ('fraktfart',),
'fraktfartene': ('fraktfart',),
'fraktfarter': ('fraktfart',),
'fraktgods': ('fraktgods',),
'fraktgodsa': ('fraktgods',),
'fraktgodsene': ('fraktgods',),
'fraktgodset': ('fraktgods',),
'fraktrate': ('fraktrate',),
'fraktraten': ('fraktrate',),
'fraktratene': ('fraktrate',),
'fraktrater': ('fraktrate',),
'fraktur': ('fraktur',),
'frakturen': ('fraktur',),
'frakturene': ('fraktur',),
'frakturer': ('fraktur',),
'frakturskrift': ('frakturskrift',),
'frakturskrifta': ('frakturskrift',),
'frakturskriften': ('frakturskrift',),
'frakturskriftene': ('frakturskrift',),
'frakturskrifter': ('frakturskrift',),
'fralandsvind': ('fralandsvind',),
'fralandsvinden': ('fralandsvind',),
'fralandsvindene': ('fralandsvind',),
'fralandsvinder': ('fralandsvind',),
'frambrott': ('frambrott',),
'frambrotta': ('frambrott',),
'frambrottene': ('frambrott',),
'frambrottet': ('frambrott',),
'frambrudd': ('frambrudd',),
'frambrudda': ('frambrudd',),
'frambruddene': ('frambrudd',),
'frambruddet': ('frambrudd',),
'frambud': ('frambud',),
'frambuda': ('frambud',),
'frambudene': ('frambud',),
'frambudet': ('frambud',),
'framdel': ('framdel',),
'framdelen': ('framdel',),
'framdelene': ('framdel',),
'framdeler': ('framdel',),
'framdrift': ('framdrift',),
'framdrifta': ('framdrift',),
'framdriften': ('framdrift',),
'framdriftene': ('framdrift',),
'framdrifter': ('framdrift',),
'framdriftsplan': ('framdriftsplan',),
'framdriftsplanen': ('framdriftsplan',),
'framdriftsplanene': ('framdriftsplan',),
'framdriftsplaner': ('framdriftsplan',),
'framende': ('framende',),
'framenden': ('framende',),
'framendene': ('framende',),
'framender': ('framende',),
'framfall': ('framfall',),
'framfalla': ('framfall',),
'framfallene': ('framfall',),
'framfallet': ('framfall',),
'framferd': ('framferd',),
'framferda': ('framferd',),
'framferden': ('framferd',),
'framferdene': ('framferd',),
'framferder': ('framferd',),
'framførelse': ('framførelse',),
'framførelsen': ('framførelse',),
'framførelsene': ('framførelse',),
'framførelser': ('framførelse',),
'framføring': ('framføring',),
'framføringa': ('framføring',),
'framføringen': ('framføring',),
'framføringene': ('framføring',),
'framføringer': ('framføring',),
'framgang': ('framgang',),
'framgangen': ('framgang',),
'framgangene': ('framgang',),
'framganger': ('framgang',),
'framgangsmåte': ('framgangsmåte',),
'framgangsmåten': ('framgangsmåte',),
'framgangsmåtene': ('framgangsmåte',),
'framgangsmåter': ('framgangsmåte',),
'framgangstid': ('framgangstid',),
'framgangstida': ('framgangstid',),
'framgangstiden': ('framgangstid',),
'framgangstidene': ('framgangstid',),
'framgangstider': ('framgangstid',),
'framhald': ('framhald',),
'framhalda': ('framhald',),
'framhaldene': ('framhald',),
'framhaldet': ('framhald',),
'framhaldsskole': ('framhaldsskole',),
'framhaldsskolen': ('framhaldsskole',),
'framhaldsskolene': ('framhaldsskole',),
'framhaldsskoler': ('framhaldsskole',),
'framhjelp': ('framhjelp',),
'framhjelpa': ('framhjelp',),
'framhjelpen': ('framhjelp',),
'framhjelpene': ('framhjelp',),
'framhjelper': ('framhjelp',),
'framkallelse': ('framkallelse',),
'framkallelsen': ('framkallelse',),
'framkallelsene': ('framkallelse',),
'framkallelser': ('framkallelse',),
'framkaller': ('framkaller',),
'framkallere': ('framkaller',),
'framkalleren': ('framkaller',),
'framkallerer': ('framkaller',),
'framkallerne': ('framkaller',),
'framkallerrom': ('framkallerrom',),
'framkallerromma': ('framkallerrom',),
'framkallerrommene': ('framkallerrom',),
'framkallerrommet': ('framkallerrom',),
'framkallervæska': ('framkallervæske',),
'framkallervæske': ('framkallervæske',),
'framkallervæsken': ('framkallervæske',),
'framkallervæskene': ('framkallervæske',),
'framkallervæsker': ('framkallervæske',),
'framkalling': ('framkalling',),
'framkallinga': ('framkalling',),
'framkallingen': ('framkalling',),
'framkallingene': ('framkalling',),
'framkallinger': ('framkalling',),
'framkomst': ('framkomst',),
'framkomsten': ('framkomst',),
'framkomstene': ('framkomst',),
'framkomster': ('framkomst',),
'framkomstmiddel': ('framkomstmiddel',),
'framkomstmiddelet': ('framkomstmiddel',),
'framkomstmidla': ('framkomstmiddel',),
'framkomstmidlene': ('framkomstmiddel',),
'framkomstmidler': ('framkomstmiddel',),
'framkomstmidlet': ('framkomstmiddel',),
'framlegg': ('framlegg',),
'framlegga': ('framlegg',),
'framleggene': ('framlegg',),
'framlegget': ('framlegg',),
'framleia': ('framleie',),
'framleie': ('framleie',),
'framleien': ('framleie',),
'framleiene': ('framleie',),
'framleier': ('framleie',),
'framlyd': ('framlyd',),
'framlyden': ('framlyd',),
'framlydene': ('framlyd',),
'framlyder': ('framlyd',),
'framlån': ('framlån',),
'framlåna': ('framlån',),
'framlånene': ('framlån',),
'framlånet': ('framlån',),
'frammarsj': ('frammarsj',),
'frammarsjen': ('frammarsj',),
'frammarsjene': ('frammarsj',),
'frammarsjer': ('frammarsj',),
'frammast': ('frammast',),
'frammasta': ('frammast',),
'frammasten': ('frammast',),
'frammastene': ('frammast',),
'frammaster': ('frammast',),
'frammøta': ('frammøte',),
'frammøte': ('frammøte',),
'frammøtene': ('frammøte',),
'frammøter': ('frammøte',),
'frammøtet': ('frammøte',),
'frammøteprosent': ('frammøteprosent',),
'frammøteprosenten': ('frammøteprosent',),
'frammøteprosentene': ('frammøteprosent',),
'frammøteprosenter': ('frammøteprosent',),
'frampart': ('frampart',),
'framparten': ('frampart',),
'frampartene': ('frampart',),
'framparter': ('frampart',),
'framreisa': ('framreise',),
'framreise': ('framreise',),
'framreisen': ('framreise',),
'framreisene': ('framreise',),
'framreiser': ('framreise',),
'framrykking': ('framrykking',),
'framrykkinga': ('framrykking',),
'framrykkingen': ('framrykking',),
'framrykkingene': ('framrykking',),
'framrykkinger': ('framrykking',),
'framrykkingslinja': ('framrykkingslinje',),
'framrykkingslinje': ('framrykkingslinje',),
'framrykkingslinjen': ('framrykkingslinje',),
'framrykkingslinjene': ('framrykkingslinje',),
'framrykkingslinjer': ('framrykkingslinje',),
'framrykkingsplan': ('framrykkingsplan',),
'framrykkingsplanen': ('framrykkingsplan',),
'framrykkingsplanene': ('framrykkingsplan',),
'framrykkingsplaner': ('framrykkingsplan',),
'framrykning': ('framrykning',),
'framrykninga': ('framrykning',),
'framrykningen': ('framrykning',),
'framrykningene': ('framrykning',),
'framrykninger': ('framrykning',),
'framrykningslinja': ('framrykningslinje',),
'framrykningslinje': ('framrykningslinje',),
'framrykningslinjen': ('framrykningslinje',),
'framrykningslinjene': ('framrykningslinje',),
'framrykningslinjer': ('framrykningslinje',),
'framrykningsplan': ('framrykningsplan',),
'framrykningsplanen': ('framrykningsplan',),
'framrykningsplanene': ('framrykningsplan',),
'framrykningsplaner': ('framrykningsplan',),
'framseta': ('framsete',),
'framsete': ('framsete',),
'framsetene': ('framsete',),
'framseter': ('framsete',),
'framsetet': ('framsete',),
'framsida': ('framside',),
'framside': ('framside',),
'framsiden': ('framside',),
'framsidene': ('framside',),
'framsider': ('framside',),
'framskap': ('framskap',),
'framskapa': ('framskap',),
'framskapene': ('framskap',),
'framskapet': ('framskap',),
'framskott': ('framskott',),
'framskotten': ('framskott',),
'framskottene': ('framskott',),
'framskotter': ('framskott',),
'framskritt': ('framskritt',),
'framskritta': ('framskritt',),
'framskrittene': ('framskritt',),
'framskrittet': ('framskritt',),
'framskut': ('framskut',),
'framskuten': ('framskut',),
'framskutene': ('framskut',),
'framskuter': ('framskut',),
'framsleng': ('framsleng',),
'framslengen': ('framsleng',),
'framslengene': ('framsleng',),
'framslenger': ('framsleng',),
'framslenga': ('framslenge',),
'framslenge': ('framslenge',),
'framslengen': ('framslenge',),
'framslengene': ('framslenge',),
'framslenger': ('framslenge',),
'framslenging': ('framslenging',),
'framslengingen': ('framslenging',),
'framslengingene': ('framslenging',),
'framslenginger': ('framslenging',),
'framspill': ('framspill',),
'framspilla': ('framspill',),
'framspillene': ('framspill',),
'framspillet': ('framspill',),
'framsprang': ('framsprang',),
'framspranga': ('framsprang',),
'framsprangene': ('framsprang',),
'framspranget': ('framsprang',),
'framspring': ('framspring',),
'framspringa': ('framspring',),
'framspringene': ('framspring',),
'framspringet': ('framspring',),
'framstavn': ('framstavn',),
'framstavnen': ('framstavn',),
'framstavnene': ('framstavn',),
'framstavner': ('framstavn',),
'framsteg': ('framsteg',),
'framstega': ('framsteg',),
'framstegene': ('framsteg',),
'framsteget': ('framsteg',),
'framstilling': ('framstilling',),
'framstillinga': ('framstilling',),
'framstillingen': ('framstilling',),
'framstillingene': ('framstilling',),
'framstillinger': ('framstilling',),
'framstillingsevna': ('framstillingsevne',),
'framstillingsevne': ('framstillingsevne',),
'framstillingsevnen': ('framstillingsevne',),
'framstillingsevnene': ('framstillingsevne',),
'framstillingsevner': ('framstillingsevne',),
'framstillingsmåte': ('framstillingsmåte',),
'framstillingsmåten': ('framstillingsmåte',),
'framstillingsmåtene': ('framstillingsmåte',),
'framstillingsmåter': ('framstillingsmåte',),
'framstøt': ('framstøt',),
'framstøta': ('framstøt',),
'framstøtene': ('framstøt',),
'framstøtet': ('framstøt',),
'framstøyt': ('framstøyt',),
'framstøyten': ('framstøyt',),
'framstøytene': ('framstøyt',),
'framstøyter': ('framstøyt',),
'framsyn': ('framsyn',),
'framsyna': ('framsyn',),
'framsynene': ('framsyn',),
'framsynet': ('framsyn',),
'framsyning': ('framsyning',),
'framsyninga': ('framsyning',),
'framsyningen': ('framsyning',),
'framsyningene': ('framsyning',),
'framsyninger': ('framsyning',),
'framsynthet': ('framsynthet',),
'framsyntheta': ('framsynthet',),
'framsyntheten': ('framsynthet',),
'framsynthetene': ('framsynthet',),
'framsyntheter': ('framsynthet',),
'framtid': ('framtid',),
'framtida': ('framtid',),
'framtiden': ('framtid',),
'framtidene': ('framtid',),
'framtider': ('framtid',),
'framtidsforsker': ('framtidsforsker',),
'framtidsforskere': ('framtidsforsker',),
'framtidsforskeren': ('framtidsforsker',),
'framtidsforskerer': ('framtidsforsker',),
'framtidsforskerne': ('framtidsforsker',),
'framtidsforsking': ('framtidsforsking',),
'framtidsforskinga': ('framtidsforsking',),
'framtidsforskingen': ('framtidsforsking',),
'framtidsforskingene': ('framtidsforsking',),
'framtidsforskinger': ('framtidsforsking',),
'framtidsforskning': ('framtidsforskning',),
'framtidsforskninga': ('framtidsforskning',),
'framtidsforskningen': ('framtidsforskning',),
'framtidsforskningene': ('framtidsforskning',),
'framtidsforskninger': ('framtidsforskning',),
'framtidsmusikk': ('framtidsmusikk',),
'framtidsmusikken': ('framtidsmusikk',),
'framtidsmusikkene': ('framtidsmusikk',),
'framtidsmusikker': ('framtidsmusikk',),
'framtidsplan': ('framtidsplan',),
'framtidsplanen': ('framtidsplan',),
'framtidsplanene': ('framtidsplan',),
'framtidsplaner': ('framtidsplan',),
'framtidsroman': ('framtidsroman',),
'framtidsromanen': ('framtidsroman',),
'framtidsromanene': ('framtidsroman',),
'framtidsromaner': ('framtidsroman',),
'framtidssamfunn': ('framtidssamfunn',),
'framtidssamfunna': ('framtidssamfunn',),
'framtidssamfunnene': ('framtidssamfunn',),
'framtidssamfunnet': ('framtidssamfunn',),
'framtidsstilling': ('framtidsstilling',),
'framtidsstillinga': ('framtidsstilling',),
'framtidsstillingen': ('framtidsstilling',),
'framtidsstillingene': ('framtidsstilling',),
'framtidsstillinger': ('framtidsstilling',),
'framtidsutsikt': ('framtidsutsikt',),
'framtidsutsikta': ('framtidsutsikt',),
'framtidsutsikten': ('framtidsutsikt',),
'framtidsutsiktene': ('framtidsutsikt',),
'framtidsutsikter': ('framtidsutsikt',),
'framtidsvisjon': ('framtidsvisjon',),
'framtidsvisjonen': ('framtidsvisjon',),
'framtidsvisjonene': ('framtidsvisjon',),
'framtidsvisjoner': ('framtidsvisjon',),
'framtoning': ('framtoning',),
'framtoninga': ('framtoning',),
'framtoningen': ('framtoning',),
'framtoningene': ('framtoning',),
'framtoninger': ('framtoning',),
'framtoningspreg': ('framtoningspreg',),
'framtoningsprega': ('framtoningspreg',),
'framtoningspregene': ('framtoningspreg',),
'framtoningspreget': ('framtoningspreg',),
'framtreden': ('framtreden',),
'framtredenen': ('framtreden',),
'framtredenene': ('framtreden',),
'framtredener': ('framtreden',),
'framtrekk': ('framtrekk',),
'framtrekka': ('framtrekk',),
'framtrekkene': ('framtrekk',),
'framtrekket': ('framtrekk',),
'framvekst': ('framvekst',),
'framveksten': ('framvekst',),
'framvekstene': ('framvekst',),
'framvekster': ('framvekst',),
'framviser': ('framviser',),
'framvisere': ('framviser',),
'framviseren': ('framviser',),
'framviserer': ('framviser',),
'framviserne': ('framviser',),
'framviserapparat': ('framviserapparat',),
'framviserapparata': ('framviserapparat',),
'framviserapparatene': ('framviserapparat',),
'framviserapparater': ('framviserapparat',),
'framviserapparatet': ('framviserapparat',),
'framvisning': ('framvisning',),
'framvisninga': ('framvisning',),
'framvisningen': ('framvisning',),
'framvisningene': ('framvisning',),
'framvisninger': ('framvisning',),
'framvokster': ('framvokster',),
'framvokstere': ('framvokster',),
'framvoksteren': ('framvokster',),
'framvoksterer': ('framvokster',),
'framvoksterne': ('framvokster',),
'framvokstre': ('framvokster',),
'framvokstrene': ('framvokster',),
'framvokstrer': ('framvokster',),
'framvokstring': ('framvokstring',),
'framvokstringen': ('framvokstring',),
'framvokstringene': ('framvokstring',),
'framvokstringer': ('framvokstring',),
'franc': ('franc',),
'francen': ('franc',),
'francene': ('franc',),
'franchise': ('franchise',),
'franchisen': ('franchise',),
'franchisene': ('franchise',),
'franchiser': ('franchise',),
'franchising': ('franchising',),
'franchisingen': ('franchising',),
'franchisingene': ('franchising',),
'franchisinger': ('franchising',),
'francium': ('francium',),
'franciuma': ('francium',),
'franciumene': ('francium',),
'franciumet': ('francium',),
'franker': ('franker',),
'frankere': ('franker',),
'frankeren': ('franker',),
'frankerer': ('franker',),
'frankerne': ('franker',),
'frankeringsmaskin': ('frankeringsmaskin',),
'frankeringsmaskina': ('frankeringsmaskin',),
'frankeringsmaskinen': ('frankeringsmaskin',),
'frankeringsmaskinene': ('frankeringsmaskin',),
'frankeringsmaskiner': ('frankeringsmaskin',),
'franko': ('franko',),
'frankoen': ('franko',),
'frankoene': ('franko',),
'frankoer': ('franko',),
'franktirør': ('franktirør',),
'franktirøren': ('franktirør',),
'franktirørene': ('franktirør',),
'franktirører': ('franktirør',),
'fransese': ('fransese',),
'fransesen': ('fransese',),
'fransesene': ('fransese',),
'franseser': ('fransese',),
'fransiskaner': ('fransiskaner',),
'fransiskanere': ('fransiskaner',),
'fransiskaneren': ('fransiskaner',),
'fransiskanerer': ('fransiskaner',),
'fransiskanerne': ('fransiskaner',),
'fransiskanerkloster': ('fransiskanerkloster',),
'fransiskanerklosteret': ('fransiskanerkloster',),
'fransiskanerklostra': ('fransiskanerkloster',),
'fransiskanerklostre': ('fransiskanerkloster',),
'fransiskanerklostrene': ('fransiskanerkloster',),
'fransiskanerklostret': ('fransiskanerkloster',),
'fransiskanermunk': ('fransiskanermunk',),
'fransiskanermunken': ('fransiskanermunk',),
'fransiskanermunkene': ('fransiskanermunk',),
'fransiskanermunker': ('fransiskanermunk',),
'fransiskanerorden': ('fransiskanerorden',),
'fransiskanerordenen': ('fransiskanerorden',),
'fransiskanerordenene': ('fransiskanerorden',),
'fransiskanerordener': ('fransiskanerorden',),
'fransk': ('fransk',),
'fransken': ('fransk',),
'franskene': ('fransk',),
'fransker': ('fransk',),
'franskbind': ('franskbind',),
'franskbinda': ('franskbind',),
'franskbindene': ('franskbind',),
'franskbindet': ('franskbind',),
'franskbrød': ('franskbrød',),
'franskbrøda': ('franskbrød',),
'franskbrødene': ('franskbrød',),
'franskbrødet': ('franskbrød',),
'franskmann': ('franskmann',),
'franskmannen': ('franskmann',),
'franskmenn': ('franskmann',),
'franskmennene': ('franskmann',),
'frasagn': ('frasagn',),
'frasagna': ('frasagn',),
'frasagnene': ('frasagn',),
'frasagnet': ('frasagn',),
'frase': ('frase',),
'frasen': ('frase',),
'frasene': ('frase',),
'fraser': ('frase',),
'fraseflom': ('fraseflom',),
'fraseflommen': ('fraseflom',),
'fraseflommene': ('fraseflom',),
'fraseflommer': ('fraseflom',),
'frasemaker': ('frasemaker',),
'frasemakere': ('frasemaker',),
'frasemakeren': ('frasemaker',),
'frasemakerer': ('frasemaker',),
'frasemakerne': ('frasemaker',),
'fraseologi': ('fraseologi',),
'fraseologien': ('fraseologi',),
'fraseologiene': ('fraseologi',),
'fraseologier': ('fraseologi',),
'frasering': ('frasering',),
'fraseringa': ('frasering',),
'fraseringen': ('frasering',),
'fraseringene': ('frasering',),
'fraseringer': ('frasering',),
'fraspark': ('fraspark',),
'frasparka': ('fraspark',),
'frasparkene': ('fraspark',),
'frasparket': ('fraspark',),
'frater': ('frater',),
'fratere': ('frater',),
'frateren': ('frater',),
'fraterer': ('frater',),
'fraterne': ('frater',),
'fratres': ('frater',),
'fratredelse': ('fratredelse',),
'fratredelsen': ('fratredelse',),
'fratredelsene': ('fratredelse',),
'fratredelser': ('fratredelse',),
'frau': ('frau',),
'fraua': ('frau',),
'frauen': ('frau',),
'frauene': ('frau',),
'frauer': ('frau',),
'frauhus': ('frauhus',),
'frauhusa': ('frauhus',),
'frauhusene': ('frauhus',),
'frauhuset': ('frauhus',),
'fraukjeller': ('fraukjeller',),
'fraukjellere': ('fraukjeller',),
'fraukjelleren': ('fraukjeller',),
'fraukjellerer': ('fraukjeller',),
'fraukjellerne': ('fraukjeller',),
'frauport': ('frauport',),
'frauporten': ('frauport',),
'frauportene': ('frauport',),
'frauporter': ('frauport',),
'fravær': ('fravær',),
'fraværa': ('fravær',),
'fraværene': ('fravær',),
'fraværet': ('fravær',),
'fraværsdag': ('fraværsdag',),
'fraværsdagen': ('fraværsdag',),
'fraværsdagene': ('fraværsdag',),
'fraværsdager': ('fraværsdag',),
'fraværsprotokoll': ('fraværsprotokoll',),
'fraværsprotokollen': ('fraværsprotokoll',),
'fraværsprotokollene': ('fraværsprotokoll',),
'fraværsprotokoller': ('fraværsprotokoll',),
'fred': ('fred',),
'freden': ('fred',),
'fredene': ('fred',),
'freder': ('fred',),
'fredag': ('fredag',),
'fredagen': ('fredag',),
'fredagene': ('fredag',),
'fredager': ('fredag',),
'fredløs': ('fredløs',),
'fredløsen': ('fredløs',),
'fredløsene': ('fredløs',),
'fredløser': ('fredløs',),
'fredning': ('fredning',),
'fredninga': ('fredning',),
'fredningen': ('fredning',),
'fredningene': ('fredning',),
'fredninger': ('fredning',),
'fredningsbestemmelse': ('fredningsbestemmelse',),
'fredningsbestemmelsen': ('fredningsbestemmelse',),
'fredningsbestemmelsene': ('fredningsbestemmelse',),
'fredningsbestemmelser': ('fredningsbestemmelse',),
'fredningslov': ('fredningslov',),
'fredningsloven': ('fredningslov',),
'fredningslovene': ('fredningslov',),
'fredningslover': ('fredningslov',),
'fredningstid': ('fredningstid',),
'fredningstida': ('fredningstid',),
'fredningstiden': ('fredningstid',),
'fredningstidene': ('fredningstid',),
'fredningstider': ('fredningstid',),
'fredsapostel': ('fredsapostel',),
'fredsapostelen': ('fredsapostel',),
'fredsapostlene': ('fredsapostel',),
'fredsapostler': ('fredsapostel',),
'fredsarbeid': ('fredsarbeid',),
'fredsarbeida': ('fredsarbeid',),
'fredsarbeidene': ('fredsarbeid',),
'fredsarbeider': ('fredsarbeid',),
'fredsarbeidet': ('fredsarbeid',),
'fredsavtale': ('fredsavtale',),
'fredsavtalen': ('fredsavtale',),
'fredsavtalene': ('fredsavtale',),
'fredsavtaler': ('fredsavtale',),
'fredsbevegelse': ('fredsbevegelse',),
'fredsbevegelsen': ('fredsbevegelse',),
'fredsbevegelsene': ('fredsbevegelse',),
'fredsbevegelser': ('fredsbevegelse',),
'fredsdommer': ('fredsdommer',),
'fredsdommere': ('fredsdommer',),
'fredsdommeren': ('fredsdommer',),
'fredsdommerer': ('fredsdommer',),
'fredsdommerne': ('fredsdommer',),
'fredsdua': ('fredsdue',),
'fredsdue': ('fredsdue',),
'fredsduen': ('fredsdue',),
'fredsduene': ('fredsdue',),
'fredsduer': ('fredsdue',),
'fredsforhandling': ('fredsforhandling',),
'fredsforhandlinga': ('fredsforhandling',),
'fredsforhandlingen': ('fredsforhandling',),
'fredsforhandlingene': ('fredsforhandling',),
'fredsforhandlinger': ('fredsforhandling',),
'fredsforsking': ('fredsforsking',),
'fredsforskinga': ('fredsforsking',),
'fredsforskingen': ('fredsforsking',),
'fredsforskingene': ('fredsforsking',),
'fredsforskinger': ('fredsforsking',),
'fredsforskning': ('fredsforskning',),
'fredsforskninga': ('fredsforskning',),
'fredsforskningen': ('fredsforskning',),
'fredsforskningene': ('fredsforskning',),
'fredsforskninger': ('fredsforskning',),
'fredsfot': ('fredsfot',),
'fredsfoten': ('fredsfot',),
'fredsfotene': ('fredsfot',),
'fredsfoter': ('fredsfot',),
'fredsfyrste': ('fredsfyrste',),
'fredsfyrsten': ('fredsfyrste',),
'fredsfyrstene': ('fredsfyrste',),
'fredsfyrster': ('fredsfyrste',),
'fredskonferanse': ('fredskonferanse',),
'fredskonferansen': ('fredskonferanse',),
'fredskonferansene': ('fredskonferanse',),
'fredskonferanser': ('fredskonferanse',),
'fredskorps': ('fredskorps',),
'fredskorpsa': ('fredskorps',),
'fredskorpsene': ('fredskorps',),
'fredskorpset': ('fredskorps',),
'fredskorpsdeltaker': ('fredskorpsdeltaker',),
'fredskorpsdeltakere': ('fredskorpsdeltaker',),
'fredskorpsdeltakeren': ('fredskorpsdeltaker',),
'fredskorpsdeltakerer': ('fredskorpsdeltaker',),
'fredskorpsdeltakerne': ('fredskorpsdeltaker',),
'fredspipa': ('fredspipe',),
'fredspipe': ('fredspipe',),
'fredspipen': ('fredspipe',),
'fredspipene': ('fredspipe',),
'fredspiper': ('fredspipe',),
'fredspris': ('fredspris',),
'fredsprisen': ('fredspris',),
'fredsprisene': ('fredspris',),
'fredspriser': ('fredspris',),
'fredsprisvinner': ('fredsprisvinner',),
'fredsprisvinnere': ('fredsprisvinner',),
'fredsprisvinneren': ('fredsprisvinner',),
'fredsprisvinnerer': ('fredsprisvinner',),
'fredsprisvinnerne': ('fredsprisvinner',),
'fredsslutning': ('fredsslutning',),
'fredsslutninga': ('fredsslutning',),
'fredsslutningen': ('fredsslutning',),
'fredsslutningene': ('fredsslutning',),
'fredsslutninger': ('fredsslutning',),
'fredsstyrke': ('fredsstyrke',),
'fredsstyrken': ('fredsstyrke',),
'fredsstyrkene': ('fredsstyrke',),
'fredsstyrker': ('fredsstyrke',),
'fredstid': ('fredstid',),
'fredstida': ('fredstid',),
'fredstiden': ('fredstid',),
'fredstidene': ('fredstid',),
'fredstider': ('fredstid',),
'fredstraktat': ('fredstraktat',),
'fredstraktaten': ('fredstraktat',),
'fredstraktatene': ('fredstraktat',),
'fredstraktater': ('fredstraktat',),
'fredsår': ('fredsår',),
'fredsåra': ('fredsår',),
'fredsårene': ('fredsår',),
'fredsåret': ('fredsår',),
'freestyle': ('freestyle',),
'fregatt': ('fregatt',),
'fregatten': ('fregatt',),
'fregattene': ('fregatt',),
'fregatter': ('fregatt',),
'fregna': ('fregne',),
'fregne': ('fregne',),
'fregnen': ('fregne',),
'fregnene': ('fregne',),
'fregner': ('fregne',),
'frekkas': ('frekkas',),
'frekkasen': ('frekkas',),
'frekkasene': ('frekkas',),
'frekkaser': ('frekkas',),
'frekkhet': ('frekkhet',),
'frekkheta': ('frekkhet',),
'frekkheten': ('frekkhet',),
'frekkhetene': ('frekkhet',),
'frekkheter': ('frekkhet',),
'frekkis': ('frekkis',),
'frekkisen': ('frekkis',),
'frekkisene': ('frekkis',),
'frekkiser': ('frekkis',),
'frekvens': ('frekvens',),
'frekvensen': ('frekvens',),
'frekvensene': ('frekvens',),
'frekvenser': ('frekvens',),
'frekvensanalysa': ('frekvensanalyse',),
'frekvensanalyse': ('frekvensanalyse',),
'frekvensanalysen': ('frekvensanalyse',),
'frekvensanalysene': ('frekvensanalyse',),
'frekvensanalyser': ('frekvensanalyse',),
'frekvensmodulasjon': ('frekvensmodulasjon',),
'frekvensmodulasjonen': ('frekvensmodulasjon',),
'frekvensmodulasjonene': ('frekvensmodulasjon',),
'frekvensmodulasjoner': ('frekvensmodulasjon',),
'frekvensmodulering': ('frekvensmodulering',),
'frekvensmoduleringa': ('frekvensmodulering',),
'frekvensmoduleringen': ('frekvensmodulering',),
'frekvensmoduleringene': ('frekvensmodulering',),
'frekvensmoduleringer': ('frekvensmodulering',),
'frekvensmåler': ('frekvensmåler',),
'frekvensmålere': ('frekvensmåler',),
'frekvensmåleren': ('frekvensmåler',),
'frekvensmålerer': ('frekvensmåler',),
'frekvensmålerne': ('frekvensmåler',),
'frekvensomformer': ('frekvensomformer',),
'frekvensomformere': ('frekvensomformer',),
'frekvensomformeren': ('frekvensomformer',),
'frekvensomformerer': ('frekvensomformer',),
'frekvensomformerne': ('frekvensomformer',),
'frekvensordbok': ('frekvensordbok',),
'frekvensordboka': ('frekvensordbok',),
'frekvensordboken': ('frekvensordbok',),
'frekvensordbøkene': ('frekvensordbok',),
'frekvensordbøker': ('frekvensordbok',),
'frelsa': ('frelse',),
'frelse': ('frelse',),
'frelsen': ('frelse',),
'frelsene': ('frelse',),
'frelser': ('frelse',),
'frelser': ('frelser',),
'frelsere': ('frelser',),
'frelseren': ('frelser',),
'frelserer': ('frelser',),
'frelserne': ('frelser',),
'frelsermann': ('frelsermann',),
'frelsermannen': ('frelsermann',),
'frelsermenn': ('frelsermann',),
'frelsermennene': ('frelsermann',),
'frelserverk': ('frelserverk',),
'frelserverka': ('frelserverk',),
'frelserverkene': ('frelserverk',),
'frelserverker': ('frelserverk',),
'frelserverket': ('frelserverk',),
'frelsesarmémøta': ('frelsesarmémøte',),
'frelsesarmémøte': ('frelsesarmémøte',),
'frelsesarmémøtene': ('frelsesarmémøte',),
'frelsesarmémøter': ('frelsesarmémøte',),
'frelsesarmémøtet': ('frelsesarmémøte',),
'frelsesarméoffiser': ('frelsesarméoffiser',),
'frelsesarméoffiseren': ('frelsesarméoffiser',),
'frelsesarméoffiserene': ('frelsesarméoffiser',),
'frelsesarméoffiserer': ('frelsesarméoffiser',),
'frelsesarmésoldat': ('frelsesarmésoldat',),
'frelsesarmésoldaten': ('frelsesarmésoldat',),
'frelsesarmésoldatene': ('frelsesarmésoldat',),
'frelsesarmésoldater': ('frelsesarmésoldat',),
'frelsesreligion': ('frelsesreligion',),
'frelsesreligionen': ('frelsesreligion',),
'frelsesreligionene': ('frelsesreligion',),
'frelsesreligioner': ('frelsesreligion',),
'frelsessoldat': ('frelsessoldat',),
'frelsessoldaten': ('frelsessoldat',),
'frelsessoldatene': ('frelsessoldat',),
'frelsessoldater': ('frelsessoldat',),
'frelsesveg': ('frelsesveg',),
'frelsesvegen': ('frelsesveg',),
'frelsesvegene': ('frelsesveg',),
'frelsesveger': ('frelsesveg',),
'frelsesvei': ('frelsesvei',),
'frelsesveien': ('frelsesvei',),
'frelsesveiene': ('frelsesvei',),
'frelsesveier': ('frelsesvei',),
'frelsesverk': ('frelsesverk',),
'frelsesverka': ('frelsesverk',),
'frelsesverkene': ('frelsesverk',),
'frelsesverker': ('frelsesverk',),
'frelsesverket': ('frelsesverk',),
'frembrudd': ('frembrudd',),
'frembrudda': ('frembrudd',),
'frembruddene': ('frembrudd',),
'frembruddet': ('frembrudd',),
'frembud': ('frembud',),
'frembuda': ('frembud',),
'frembudene': ('frembud',),
'frembudet': ('frembud',),
'fremdel': ('fremdel',),
'fremdelen': ('fremdel',),
'fremdelene': ('fremdel',),
'fremdeler': ('fremdel',),
'fremdrift': ('fremdrift',),
'fremdrifta': ('fremdrift',),
'fremdriften': ('fremdrift',),
'fremdriftene': ('fremdrift',),
'fremdrifter': ('fremdrift',),
'fremdriftsplan': ('fremdriftsplan',),
'fremdriftsplanen': ('fremdriftsplan',),
'fremdriftsplanene': ('fremdriftsplan',),
'fremdriftsplaner': ('fremdriftsplan',),
'fremende': ('fremende',),
'fremenden': ('fremende',),
'fremendene': ('fremende',),
'fremender': ('fremende',),
'fremfall': ('fremfall',),
'fremfalla': ('fremfall',),
'fremfallene': ('fremfall',),
'fremfallet': ('fremfall',),
'fremferd': ('fremferd',),
'fremferda': ('fremferd',),
'fremferden': ('fremferd',),
'fremferdene': ('fremferd',),
'fremferder': ('fremferd',),
'fremførelse': ('fremførelse',),
'fremførelsen': ('fremførelse',),
'fremførelsene': ('fremførelse',),
'fremførelser': ('fremførelse',),
'fremføring': ('fremføring',),
'fremføringa': ('fremføring',),
'fremføringen': ('fremføring',),
'fremføringene': ('fremføring',),
'fremføringer': ('fremføring',),
'fremgang': ('fremgang',),
'fremgangen': ('fremgang',),
'fremgangene': ('fremgang',),
'fremganger': ('fremgang',),
'fremgangsmåte': ('fremgangsmåte',),
'fremgangsmåten': ('fremgangsmåte',),
'fremgangsmåtene': ('fremgangsmåte',),
'fremgangsmåter': ('fremgangsmåte',),
'fremgangstid': ('fremgangstid',),
'fremgangstida': ('fremgangstid',),
'fremgangstiden': ('fremgangstid',),
'fremgangstidene': ('fremgangstid',),
'fremgangstider': ('fremgangstid',),
'fremhjelp': ('fremhjelp',),
'fremhjelpa': ('fremhjelp',),
'fremhjelpen': ('fremhjelp',),
'fremhjelpene': ('fremhjelp',),
'fremhjelper': ('fremhjelp',),
'fremkallelse': ('fremkallelse',),
'fremkallelsen': ('fremkallelse',),
'fremkallelsene': ('fremkallelse',),
'fremkallelser': ('fremkallelse',),
'fremkaller': ('fremkaller',),
'fremkallere': ('fremkaller',),
'fremkalleren': ('fremkaller',),
'fremkallerer': ('fremkaller',),
'fremkallerne': ('fremkaller',),
'fremkallerrom': ('fremkallerrom',),
'fremkallerromma': ('fremkallerrom',),
'fremkallerrommene': ('fremkallerrom',),
'fremkallerrommet': ('fremkallerrom',),
'fremkallervæska': ('fremkallervæske',),
'fremkallervæske': ('fremkallervæske',),
'fremkallervæsken': ('fremkallervæske',),
'fremkallervæskene': ('fremkallervæske',),
'fremkallervæsker': ('fremkallervæske',),
'fremkalling': ('fremkalling',),
'fremkallinga': ('fremkalling',),
'fremkallingen': ('fremkalling',),
'fremkallingene': ('fremkalling',),
'fremkallinger': ('fremkalling',),
'fremkomst': ('fremkomst',),
'fremkomsten': ('fremkomst',),
'fremkomstene': ('fremkomst',),
'fremkomster': ('fremkomst',),
'fremkomstmiddel': ('fremkomstmiddel',),
'fremkomstmiddelet': ('fremkomstmiddel',),
'fremkomstmidla': ('fremkomstmiddel',),
'fremkomstmidlene': ('fremkomstmiddel',),
'fremkomstmidler': ('fremkomstmiddel',),
'fremkomstmidlet': ('fremkomstmiddel',),
'fremleia': ('fremleie',),
'fremleie': ('fremleie',),
'fremleien': ('fremleie',),
'fremleiene': ('fremleie',),
'fremleier': ('fremleie',),
'fremlyd': ('fremlyd',),
'fremlyden': ('fremlyd',),
'fremlydene': ('fremlyd',),
'fremlyder': ('fremlyd',),
'fremlån': ('fremlån',),
'fremlåna': ('fremlån',),
'fremlånene': ('fremlån',),
'fremlånet': ('fremlån',),
'fremmarsj': ('fremmarsj',),
'fremmarsjen': ('fremmarsj',),
'fremmarsjene': ('fremmarsj',),
'fremmarsjer': ('fremmarsj',),
'fremmast': ('fremmast',),
'fremmasta': ('fremmast',),
'fremmasten': ('fremmast',),
'fremmastene': ('fremmast',),
'fremmaster': ('fremmast',),
'fremmedarbeider': ('fremmedarbeider',),
'fremmedarbeidere': ('fremmedarbeider',),
'fremmedarbeideren': ('fremmedarbeider',),
'fremmedarbeiderer': ('fremmedarbeider',),
'fremmedarbeiderne': ('fremmedarbeider',),
'fremmedarbeider': ('fremmedarbeider',),
'fremmedarbeidere': ('fremmedarbeider',),
'fremmedarbeideren': ('fremmedarbeider',),
'fremmedarbeiderer': ('fremmedarbeider',),
'fremmedarbeiderne': ('fremmedarbeider',),
'fremmedbok': ('fremmedbok',),
'fremmedboka': ('fremmedbok',),
'fremmedboken': ('fremmedbok',),
'fremmedbøkene': ('fremmedbok',),
'fremmedbøker': ('fremmedbok',),
'fremmedbok': ('fremmedbok',),
'fremmedboka': ('fremmedbok',),
'fremmedboken': ('fremmedbok',),
'fremmedbøkene': ('fremmedbok',),
'fremmedbøker': ('fremmedbok',),
'fremmedelement': ('fremmedelement',),
'fremmedelementa': ('fremmedelement',),
'fremmedelementene': ('fremmedelement',),
'fremmedelementer': ('fremmedelement',),
'fremmedelementet': ('fremmedelement',),
'fremmedelement': ('fremmedelement',),
'fremmedelementa': ('fremmedelement',),
'fremmedelementene': ('fremmedelement',),
'fremmedelementer': ('fremmedelement',),
'fremmedelementet': ('fremmedelement',),
'fremmedfolk': ('fremmedfolk',),
'fremmedfolka': ('fremmedfolk',),
'fremmedfolkene': ('fremmedfolk',),
'fremmedfolket': ('fremmedfolk',),
'fremmedfolk': ('fremmedfolk',),
'fremmedfolka': ('fremmedfolk',),
'fremmedfolkene': ('fremmedfolk',),
'fremmedfolket': ('fremmedfolk',),
'fremmedfølelse': ('fremmedfølelse',),
'fremmedfølelsen': ('fremmedfølelse',),
'fremmedfølelsene': ('fremmedfølelse',),
'fremmedfølelser': ('fremmedfølelse',),
'fremmedfølelse': ('fremmedfølelse',),
'fremmedfølelsen': ('fremmedfølelse',),
'fremmedfølelsene': ('fremmedfølelse',),
'fremmedfølelser': ('fremmedfølelse',),
'fremmedgjorthet': ('fremmedgjorthet',),
'fremmedgjortheta': ('fremmedgjorthet',),
'fremmedgjortheten': ('fremmedgjorthet',),
'fremmedgjorthetene': ('fremmedgjorthet',),
'fremmedgjortheter': ('fremmedgjorthet',),
'fremmedgjorthet': ('fremmedgjorthet',),
'fremmedgjortheta': ('fremmedgjorthet',),
'fremmedgjortheten': ('fremmedgjorthet',),
'fremmedgjorthetene': ('fremmedgjorthet',),
'fremmedgjortheter': ('fremmedgjorthet',),
'fremmedgjørelse': ('fremmedgjørelse',),
'fremmedgjørelsen': ('fremmedgjørelse',),
'fremmedgjørelsene': ('fremmedgjørelse',),
'fremmedgjørelser': ('fremmedgjørelse',),
'fremmedgjørelse': ('fremmedgjørelse',),
'fremmedgjørelsen': ('fremmedgjørelse',),
'fremmedgjørelsene': ('fremmedgjørelse',),
'fremmedgjørelser': ('fremmedgjørelse',),
'fremmedgjøring': ('fremmedgjøring',),
'fremmedgjøringa': ('fremmedgjøring',),
'fremmedgjøringen': ('fremmedgjøring',),
'fremmedgjøringene': ('fremmedgjøring',),
'fremmedgjøringer': ('fremmedgjøring',),
'fremmedgjøring': ('fremmedgjøring',),
'fremmedgjøringa': ('fremmedgjøring',),
'fremmedgjøringen': ('fremmedgjøring',),
'fremmedgjøringene': ('fremmedgjøring',),
'fremmedgjøringer': ('fremmedgjøring',),
'fremmedhat': ('fremmedhat',),
'fremmedhata': ('fremmedhat',),
'fremmedhatene': ('fremmedhat',),
'fremmedhatet': ('fremmedhat',),
'fremmedhat': ('fremmedhat',),
'fremmedhata': ('fremmedhat',),
'fremmedhatene': ('fremmedhat',),
'fremmedhatet': ('fremmedhat',),
'fremmedkapital': ('fremmedkapital',),
'fremmedkapitalen': ('fremmedkapital',),
'fremmedkapitalene': ('fremmedkapital',),
'fremmedkapitaler': ('fremmedkapital',),
'fremmedkapital': ('fremmedkapital',),
'fremmedkapitalen': ('fremmedkapital',),
'fremmedkapitalene': ('fremmedkapital',),
'fremmedkapitaler': ('fremmedkapital',),
'fremmedlegema': ('fremmedlegeme',),
'fremmedlegeme': ('fremmedlegeme',),
'fremmedlegemene': ('fremmedlegeme',),
'fremmedlegemer': ('fremmedlegeme',),
'fremmedlegemet': ('fremmedlegeme',),
'fremmedlegema': ('fremmedlegeme',),
'fremmedlegeme': ('fremmedlegeme',),
'fremmedlegemene': ('fremmedlegeme',),
'fremmedlegemer': ('fremmedlegeme',),
'fremmedlegemet': ('fremmedlegeme',),
'fremmedlegion': ('fremmedlegion',),
'fremmedlegionen': ('fremmedlegion',),
'fremmedlegionene': ('fremmedlegion',),
'fremmedlegioner': ('fremmedlegion',),
'fremmedlegion': ('fremmedlegion',),
'fremmedlegionen': ('fremmedlegion',),
'fremmedlegionene': ('fremmedlegion',),
'fremmedlegioner': ('fremmedlegion',),
'fremmedlovgiing': ('fremmedlovgiing',),
'fremmedlovgiinga': ('fremmedlovgiing',),
'fremmedlovgiingen': ('fremmedlovgiing',),
'fremmedlovgiingene': ('fremmedlovgiing',),
'fremmedlovgiinger': ('fremmedlovgiing',),
'fremmedlovgiving': ('fremmedlovgiving',),
'fremmedlovgivinga': ('fremmedlovgiving',),
'fremmedlovgivingen': ('fremmedlovgiving',),
'fremmedlovgivingene': ('fremmedlovgiving',),
'fremmedlovgivinger': ('fremmedlovgiving',),
'fremmedlovgiving': ('fremmedlovgiving',),
'fremmedlovgivinga': ('fremmedlovgiving',),
'fremmedlovgivingen': ('fremmedlovgiving',),
'fremmedlovgivingene': ('fremmedlovgiving',),
'fremmedlovgivinger': ('fremmedlovgiving',),
'fremmedlovgivning': ('fremmedlovgivning',),
'fremmedlovgivninga': ('fremmedlovgivning',),
'fremmedlovgivningen': ('fremmedlovgivning',),
'fremmedlovgivningene': ('fremmedlovgivning',),
'fremmedlovgivninger': ('fremmedlovgivning',),
'fremmedlovgivning': ('fremmedlovgivning',),
'fremmedlovgivninga': ('fremmedlovgivning',),
'fremmedlovgivningen': ('fremmedlovgivning',),
'fremmedlovgivningene': ('fremmedlovgivning',),
'fremmedlovgivninger': ('fremmedlovgivning',),
'fremmedord': ('fremmedord',),
'fremmedorda': ('fremmedord',),
'fremmedordene': ('fremmedord',),
'fremmedordet': ('fremmedord',),
'fremmedord': ('fremmedord',),
'fremmedorda': ('fremmedord',),
'fremmedordene': ('fremmedord',),
'fremmedordet': ('fremmedord',),
'fremmedordbok': ('fremmedordbok',),
'fremmedordboka': ('fremmedordbok',),
'fremmedordboken': ('fremmedordbok',),
'fremmedordbøkene': ('fremmedordbok',),
'fremmedordbøker': ('fremmedordbok',),
'fremmedordbok': ('fremmedordbok',),
'fremmedordboka': ('fremmedordbok',),
'fremmedordboken': ('fremmedordbok',),
'fremmedordbøkene': ('fremmedordbok',),
'fremmedordbøker': ('fremmedordbok',),
'fremmedprotein': ('fremmedprotein',),
'fremmedproteina': ('fremmedprotein',),
'fremmedproteinene': ('fremmedprotein',),
'fremmedproteiner': ('fremmedprotein',),
'fremmedproteinet': ('fremmedprotein',),
'fremmedprotein': ('fremmedprotein',),
'fremmedproteina': ('fremmedprotein',),
'fremmedproteinene': ('fremmedprotein',),
'fremmedproteiner': ('fremmedprotein',),
'fremmedproteinet': ('fremmedprotein',),
'fremmedspråk': ('fremmedspråk',),
'fremmedspråka': ('fremmedspråk',),
'fremmedspråkene': ('fremmedspråk',),
'fremmedspråket': ('fremmedspråk',),
'fremmedspråk': ('fremmedspråk',),
'fremmedspråka': ('fremmedspråk',),
'fremmedspråkene': ('fremmedspråk',),
'fremmedspråket': ('fremmedspråk',),
'fremmedstyra': ('fremmedstyre',),
'fremmedstyre': ('fremmedstyre',),
'fremmedstyrene': ('fremmedstyre',),
'fremmedstyrer': ('fremmedstyre',),
'fremmedstyret': ('fremmedstyre',),
'fremmedstyra': ('fremmedstyre',),
'fremmedstyre': ('fremmedstyre',),
'fremmedstyrene': ('fremmedstyre',),
'fremmedstyrer': ('fremmedstyre',),
'fremmedstyret': ('fremmedstyre',),
'fremmendarbeider': ('fremmendarbeider',),
'fremmendarbeidere': ('fremmendarbeider',),
'fremmendarbeideren': ('fremmendarbeider',),
'fremmendarbeiderer': ('fremmendarbeider',),
'fremmendarbeiderne': ('fremmendarbeider',),
'fremmendarbeider': ('fremmendarbeider',),
'fremmendarbeidere': ('fremmendarbeider',),
'fremmendarbeideren': ('fremmendarbeider',),
'fremmendarbeiderer': ('fremmendarbeider',),
'fremmendarbeiderne': ('fremmendarbeider',),
'fremmendbok': ('fremmendbok',),
'fremmendboka': ('fremmendbok',),
'fremmendboken': ('fremmendbok',),
'fremmendbøkene': ('fremmendbok',),
'fremmendbøker': ('fremmendbok',),
'fremmendbok': ('fremmendbok',),
'fremmendboka': ('fremmendbok',),
'fremmendboken': ('fremmendbok',),
'fremmendbøkene': ('fremmendbok',),
'fremmendbøker': ('fremmendbok',),
'fremmendelement': ('fremmendelement',),
'fremmendelementa': ('fremmendelement',),
'fremmendelementene': ('fremmendelement',),
'fremmendelementer': ('fremmendelement',),
'fremmendelementet': ('fremmendelement',),
'fremmendelement': ('fremmendelement',),
'fremmendelementa': ('fremmendelement',),
'fremmendelementene': ('fremmendelement',),
'fremmendelementer': ('fremmendelement',),
'fremmendelementet': ('fremmendelement',),
'fremmendfolk': ('fremmendfolk',),
'fremmendfolka': ('fremmendfolk',),
'fremmendfolkene': ('fremmendfolk',),
'fremmendfolket': ('fremmendfolk',),
'fremmendfolk': ('fremmendfolk',),
'fremmendfolka': ('fremmendfolk',),
'fremmendfolkene': ('fremmendfolk',),
'fremmendfolket': ('fremmendfolk',),
'fremmendfølelse': ('fremmendfølelse',),
'fremmendfølelsen': ('fremmendfølelse',),
'fremmendfølelsene': ('fremmendfølelse',),
'fremmendfølelser': ('fremmendfølelse',),
'fremmendfølelse': ('fremmendfølelse',),
'fremmendfølelsen': ('fremmendfølelse',),
'fremmendfølelsene': ('fremmendfølelse',),
'fremmendfølelser': ('fremmendfølelse',),
'fremmendgjorthet': ('fremmendgjorthet',),
'fremmendgjortheta': ('fremmendgjorthet',),
'fremmendgjortheten': ('fremmendgjorthet',),
'fremmendgjorthetene': ('fremmendgjorthet',),
'fremmendgjortheter': ('fremmendgjorthet',),
'fremmendgjorthet': ('fremmendgjorthet',),
'fremmendgjortheta': ('fremmendgjorthet',),
'fremmendgjortheten': ('fremmendgjorthet',),
'fremmendgjorthetene': ('fremmendgjorthet',),
'fremmendgjortheter': ('fremmendgjorthet',),
'fremmendgjørelse': ('fremmendgjørelse',),
'fremmendgjørelsen': ('fremmendgjørelse',),
'fremmendgjørelsene': ('fremmendgjørelse',),
'fremmendgjørelser': ('fremmendgjørelse',),
'fremmendgjørelse': ('fremmendgjørelse',),
'fremmendgjørelsen': ('fremmendgjørelse',),
'fremmendgjørelsene': ('fremmendgjørelse',),
'fremmendgjørelser': ('fremmendgjørelse',),
'fremmendgjøring': ('fremmendgjøring',),
'fremmendgjøringa': ('fremmendgjøring',),
'fremmendgjøringen': ('fremmendgjøring',),
'fremmendgjøringene': ('fremmendgjøring',),
'fremmendgjøringer': ('fremmendgjøring',),
'fremmendgjøring': ('fremmendgjøring',),
'fremmendgjøringa': ('fremmendgjøring',),
'fremmendgjøringen': ('fremmendgjøring',),
'fremmendgjøringene': ('fremmendgjøring',),
'fremmendgjøringer': ('fremmendgjøring',),
'fremmendhat': ('fremmendhat',),
'fremmendhata': ('fremmendhat',),
'fremmendhatene': ('fremmendhat',),
'fremmendhatet': ('fremmendhat',),
'fremmendhat': ('fremmendhat',),
'fremmendhata': ('fremmendhat',),
'fremmendhatene': ('fremmendhat',),
'fremmendhatet': ('fremmendhat',),
'fremmendkapital': ('fremmendkapital',),
'fremmendkapitalen': ('fremmendkapital',),
'fremmendkapitalene': ('fremmendkapital',),
'fremmendkapitaler': ('fremmendkapital',),
'fremmendkapital': ('fremmendkapital',),
'fremmendkapitalen': ('fremmendkapital',),
'fremmendkapitalene': ('fremmendkapital',),
'fremmendkapitaler': ('fremmendkapital',),
'fremmendlegema': ('fremmendlegeme',),
'fremmendlegeme': ('fremmendlegeme',),
'fremmendlegemene': ('fremmendlegeme',),
'fremmendlegemer': ('fremmendlegeme',),
'fremmendlegemet': ('fremmendlegeme',),
'fremmendlegema': ('fremmendlegeme',),
'fremmendlegeme': ('fremmendlegeme',),
'fremmendlegemene': ('fremmendlegeme',),
'fremmendlegemer': ('fremmendlegeme',),
'fremmendlegemet': ('fremmendlegeme',),
'fremmendlegion': ('fremmendlegion',),
'fremmendlegionen': ('fremmendlegion',),
'fremmendlegionene': ('fremmendlegion',),
'fremmendlegioner': ('fremmendlegion',),
'fremmendlegion': ('fremmendlegion',),
'fremmendlegionen': ('fremmendlegion',),
'fremmendlegionene': ('fremmendlegion',),
'fremmendlegioner': ('fremmendlegion',),
'fremmendlovgiing': ('fremmendlovgiing',),
'fremmendlovgiinga': ('fremmendlovgiing',),
'fremmendlovgiingen': ('fremmendlovgiing',),
'fremmendlovgiingene': ('fremmendlovgiing',),
'fremmendlovgiinger': ('fremmendlovgiing',),
'fremmendlovgiving': ('fremmendlovgiving',),
'fremmendlovgivinga': ('fremmendlovgiving',),
'fremmendlovgivingen': ('fremmendlovgiving',),
'fremmendlovgivingene': ('fremmendlovgiving',),
'fremmendlovgivinger': ('fremmendlovgiving',),
'fremmendlovgiving': ('fremmendlovgiving',),
'fremmendlovgivinga': ('fremmendlovgiving',),
'fremmendlovgivingen': ('fremmendlovgiving',),
'fremmendlovgivingene': ('fremmendlovgiving',),
'fremmendlovgivinger': ('fremmendlovgiving',),
'fremmendlovgivning': ('fremmendlovgivning',),
'fremmendlovgivninga': ('fremmendlovgivning',),
'fremmendlovgivningen': ('fremmendlovgivning',),
'fremmendlovgivningene': ('fremmendlovgivning',),
'fremmendlovgivninger': ('fremmendlovgivning',),
'fremmendlovgivning': ('fremmendlovgivning',),
'fremmendlovgivninga': ('fremmendlovgivning',),
'fremmendlovgivningen': ('fremmendlovgivning',),
'fremmendlovgivningene': ('fremmendlovgivning',),
'fremmendlovgivninger': ('fremmendlovgivning',),
'fremmendord': ('fremmendord',),
'fremmendorda': ('fremmendord',),
'fremmendordene': ('fremmendord',),
'fremmendordet': ('fremmendord',),
'fremmendord': ('fremmendord',),
'fremmendorda': ('fremmendord',),
'fremmendordene': ('fremmendord',),
'fremmendordet': ('fremmendord',),
'fremmendordbok': ('fremmendordbok',),
'fremmendordboka': ('fremmendordbok',),
'fremmendordboken': ('fremmendordbok',),
'fremmendordbøkene': ('fremmendordbok',),
'fremmendordbøker': ('fremmendordbok',),
'fremmendordbok': ('fremmendordbok',),
'fremmendordboka': ('fremmendordbok',),
'fremmendordboken': ('fremmendordbok',),
'fremmendordbøkene': ('fremmendordbok',),
'fremmendordbøker': ('fremmendordbok',),
'fremmendprotein': ('fremmendprotein',),
'fremmendproteina': ('fremmendprotein',),
'fremmendproteinene': ('fremmendprotein',),
'fremmendproteiner': ('fremmendprotein',),
'fremmendproteinet': ('fremmendprotein',),
'fremmendprotein': ('fremmendprotein',),
'fremmendproteina': ('fremmendprotein',),
'fremmendproteinene': ('fremmendprotein',),
'fremmendproteiner': ('fremmendprotein',),
'fremmendproteinet': ('fremmendprotein',),
'fremmendspråk': ('fremmendspråk',),
'fremmendspråka': ('fremmendspråk',),
'fremmendspråkene': ('fremmendspråk',),
'fremmendspråket': ('fremmendspråk',),
'fremmendspråk': ('fremmendspråk',),
'fremmendspråka': ('fremmendspråk',),
'fremmendspråkene': ('fremmendspråk',),
'fremmendspråket': ('fremmendspråk',),
'fremmendstyra': ('fremmendstyre',),
'fremmendstyre': ('fremmendstyre',),
'fremmendstyrene': ('fremmendstyre',),
'fremmendstyrer': ('fremmendstyre',),
'fremmendstyret': ('fremmendstyre',),
'fremmendstyra': ('fremmendstyre',),
'fremmendstyre': ('fremmendstyre',),
'fremmendstyrene': ('fremmendstyre',),
'fremmendstyrer': ('fremmendstyre',),
'fremmendstyret': ('fremmendstyre',),
'fremmer': ('fremmer',),
'fremmere': ('fremmer',),
'fremmeren': ('fremmer',),
'fremmerer': ('fremmer',),
'fremmerne': ('fremmer',),
'fremmøta': ('fremmøte',),
'fremmøte': ('fremmøte',),
'fremmøtene': ('fremmøte',),
'fremmøter': ('fremmøte',),
'fremmøtet': ('fremmøte',),
'fremmøteprosent': ('fremmøteprosent',),
'fremmøteprosenten': ('fremmøteprosent',),
'fremmøteprosentene': ('fremmøteprosent',),
'fremmøteprosenter': ('fremmøteprosent',),
'frempart': ('frempart',),
'fremparten': ('frempart',),
'frempartene': ('frempart',),
'fremparter': ('frempart',),
'fremreisa': ('fremreise',),
'fremreise': ('fremreise',),
'fremreisen': ('fremreise',),
'fremreisene': ('fremreise',),
'fremreiser': ('fremreise',),
'fremrykking': ('fremrykking',),
'fremrykkinga': ('fremrykking',),
'fremrykkingen': ('fremrykking',),
'fremrykkingene': ('fremrykking',),
'fremrykkinger': ('fremrykking',),
'fremrykkingslinja': ('fremrykkingslinje',),
'fremrykkingslinje': ('fremrykkingslinje',),
'fremrykkingslinjen': ('fremrykkingslinje',),
'fremrykkingslinjene': ('fremrykkingslinje',),
'fremrykkingslinjer': ('fremrykkingslinje',),
'fremrykkingsplan': ('fremrykkingsplan',),
'fremrykkingsplanen': ('fremrykkingsplan',),
'fremrykkingsplanene': ('fremrykkingsplan',),
'fremrykkingsplaner': ('fremrykkingsplan',),
'fremrykning': ('fremrykning',),
'fremrykninga': ('fremrykning',),
'fremrykningen': ('fremrykning',),
'fremrykningene': ('fremrykning',),
'fremrykninger': ('fremrykning',),
'fremrykningslinja': ('fremrykningslinje',),
'fremrykningslinje': ('fremrykningslinje',),
'fremrykningslinjen': ('fremrykningslinje',),
'fremrykningslinjene': ('fremrykningslinje',),
'fremrykningslinjer': ('fremrykningslinje',),
'fremrykningsplan': ('fremrykningsplan',),
'fremrykningsplanen': ('fremrykningsplan',),
'fremrykningsplanene': ('fremrykningsplan',),
'fremrykningsplaner': ('fremrykningsplan',),
'fremseta': ('fremsete',),
'fremsete': ('fremsete',),
'fremsetene': ('fremsete',),
'fremseter': ('fremsete',),
'fremsetet': ('fremsete',),
'fremsida': ('fremside',),
'fremside': ('fremside',),
'fremsiden': ('fremside',),
'fremsidene': ('fremside',),
'fremsider': ('fremside',),
'fremskritt': ('fremskritt',),
'fremskritta': ('fremskritt',),
'fremskrittene': ('fremskritt',),
'fremskrittet': ('fremskritt',),
'fremspill': ('fremspill',),
'fremspilla': ('fremspill',),
'fremspillene': ('fremspill',),
'fremspillet': ('fremspill',),
'fremsprang': ('fremsprang',),
'fremspranga': ('fremsprang',),
'fremsprangene': ('fremsprang',),
'fremspranget': ('fremsprang',),
'fremspring': ('fremspring',),
'fremspringa': ('fremspring',),
'fremspringene': ('fremspring',),
'fremspringet': ('fremspring',),
'fremstavn': ('fremstavn',),
'fremstavnen': ('fremstavn',),
'fremstavnene': ('fremstavn',),
'fremstavner': ('fremstavn',),
'fremstilling': ('fremstilling',),
'fremstillinga': ('fremstilling',),
'fremstillingen': ('fremstilling',),
'fremstillingene': ('fremstilling',),
'fremstillinger': ('fremstilling',),
'fremstillingsevna': ('fremstillingsevne',),
'fremstillingsevne': ('fremstillingsevne',),
'fremstillingsevnen': ('fremstillingsevne',),
'fremstillingsevnene': ('fremstillingsevne',),
'fremstillingsevner': ('fremstillingsevne',),
'fremstillingsmåte': ('fremstillingsmåte',),
'fremstillingsmåten': ('fremstillingsmåte',),
'fremstillingsmåtene': ('fremstillingsmåte',),
'fremstillingsmåter': ('fremstillingsmåte',),
'fremstøt': ('fremstøt',),
'fremstøta': ('fremstøt',),
'fremstøtene': ('fremstøt',),
'fremstøtet': ('fremstøt',),
'fremsyn': ('fremsyn',),
'fremsyna': ('fremsyn',),
'fremsynene': ('fremsyn',),
'fremsynet': ('fremsyn',),
'fremsyning': ('fremsyning',),
'fremsyninga': ('fremsyning',),
'fremsyningen': ('fremsyning',),
'fremsyningene': ('fremsyning',),
'fremsyninger': ('fremsyning',),
'fremsynthet': ('fremsynthet',),
'fremsyntheta': ('fremsynthet',),
'fremsyntheten': ('fremsynthet',),
'fremsynthetene': ('fremsynthet',),
'fremsyntheter': ('fremsynthet',),
'fremtid': ('fremtid',),
'fremtida': ('fremtid',),
'fremtiden': ('fremtid',),
'fremtidene': ('fremtid',),
'fremtider': ('fremtid',),
'fremtidsforsker': ('fremtidsforsker',),
'fremtidsforskere': ('fremtidsforsker',),
'fremtidsforskeren': ('fremtidsforsker',),
'fremtidsforskerer': ('fremtidsforsker',),
'fremtidsforskerne': ('fremtidsforsker',),
'fremtidsforsking': ('fremtidsforsking',),
'fremtidsforskinga': ('fremtidsforsking',),
'fremtidsforskingen': ('fremtidsforsking',),
'fremtidsforskingene': ('fremtidsforsking',),
'fremtidsforskinger': ('fremtidsforsking',),
'fremtidsforskning': ('fremtidsforskning',),
'fremtidsforskninga': ('fremtidsforskning',),
'fremtidsforskningen': ('fremtidsforskning',),
'fremtidsforskningene': ('fremtidsforskning',),
'fremtidsforskninger': ('fremtidsforskning',),
'fremtidsmusikk': ('fremtidsmusikk',),
'fremtidsmusikken': ('fremtidsmusikk',),
'fremtidsmusikkene': ('fremtidsmusikk',),
'fremtidsmusikker': ('fremtidsmusikk',),
'fremtidsplan': ('fremtidsplan',),
'fremtidsplanen': ('fremtidsplan',),
'fremtidsplanene': ('fremtidsplan',),
'fremtidsplaner': ('fremtidsplan',),
'fremtidsroman': ('fremtidsroman',),
'fremtidsromanen': ('fremtidsroman',),
'fremtidsromanene': ('fremtidsroman',),
'fremtidsromaner': ('fremtidsroman',),
'fremtidssamfunn': ('fremtidssamfunn',),
'fremtidssamfunna': ('fremtidssamfunn',),
'fremtidssamfunnene': ('fremtidssamfunn',),
'fremtidssamfunnet': ('fremtidssamfunn',),
'fremtidsstilling': ('fremtidsstilling',),
'fremtidsstillinga': ('fremtidsstilling',),
'fremtidsstillingen': ('fremtidsstilling',),
'fremtidsstillingene': ('fremtidsstilling',),
'fremtidsstillinger': ('fremtidsstilling',),
'fremtidsutsikt': ('fremtidsutsikt',),
'fremtidsutsikta': ('fremtidsutsikt',),
'fremtidsutsikten': ('fremtidsutsikt',),
'fremtidsutsiktene': ('fremtidsutsikt',),
'fremtidsutsikter': ('fremtidsutsikt',),
'fremtidsvisjon': ('fremtidsvisjon',),
'fremtidsvisjonen': ('fremtidsvisjon',),
'fremtidsvisjonene': ('fremtidsvisjon',),
'fremtidsvisjoner': ('fremtidsvisjon',),
'fremtoning': ('fremtoning',),
'fremtoninga': ('fremtoning',),
'fremtoningen': ('fremtoning',),
'fremtoningene': ('fremtoning',),
'fremtoninger': ('fremtoning',),
'fremtoningspreg': ('fremtoningspreg',),
'fremtoningsprega': ('fremtoningspreg',),
'fremtoningspregene': ('fremtoningspreg',),
'fremtoningspreget': ('fremtoningspreg',),
'fremtreden': ('fremtreden',),
'fremtredenen': ('fremtreden',),
'fremtredenene': ('fremtreden',),
'fremtredener': ('fremtreden',),
'fremtrekk': ('fremtrekk',),
'fremtrekka': ('fremtrekk',),
'fremtrekkene': ('fremtrekk',),
'fremtrekket': ('fremtrekk',),
'fremvekst': ('fremvekst',),
'fremveksten': ('fremvekst',),
'fremvekstene': ('fremvekst',),
'fremvekster': ('fremvekst',),
'fremviser': ('fremviser',),
'fremvisere': ('fremviser',),
'fremviseren': ('fremviser',),
'fremviserer': ('fremviser',),
'fremviserne': ('fremviser',),
'fremviserapparat': ('fremviserapparat',),
'fremviserapparata': ('fremviserapparat',),
'fremviserapparatene': ('fremviserapparat',),
'fremviserapparater': ('fremviserapparat',),
'fremviserapparatet': ('fremviserapparat',),
'fremvisning': ('fremvisning',),
'fremvisninga': ('fremvisning',),
'fremvisningen': ('fremvisning',),
'fremvisningene': ('fremvisning',),
'fremvisninger': ('fremvisning',),
'fremvokster': ('fremvokster',),
'fremvokstere': ('fremvokster',),
'fremvoksteren': ('fremvokster',),
'fremvoksterer': ('fremvokster',),
'fremvoksterne': ('fremvokster',),
'fremvokstre': ('fremvokster',),
'fremvokstrene': ('fremvokster',),
'fremvokstrer': ('fremvokster',),
'fremvokstring': ('fremvokstring',),
'fremvokstringen': ('fremvokstring',),
'fremvokstringene': ('fremvokstring',),
'fremvokstringer': ('fremvokstring',),
'frende': ('frende',),
'frenden': ('frende',),
'frendene': ('frende',),
'frender': ('frende',),
'frenesi': ('frenesi',),
'frenesien': ('frenesi',),
'frenesiene': ('frenesi',),
'frenesier': ('frenesi',),
'frenka': ('frenke',),
'frenke': ('frenke',),
'frenken': ('frenke',),
'frenkene': ('frenke',),
'frenker': ('frenke',),
'freon': ('freon',),
'freona': ('freon',),
'freonene': ('freon',),
'freoner': ('freon',),
'freonet': ('freon',),
'freongass': ('freongass',),
'freongassen': ('freongass',),
'freongassene': ('freongass',),
'freongasser': ('freongass',),
'fres': ('fres',),
'fresen': ('fres',),
'fresene': ('fres',),
'freser': ('fres',),
'fres': ('fres',),
'fresa': ('fres',),
'fresen': ('fres',),
'fresene': ('fres',),
'freser': ('fres',),
'freset': ('fres',),
'fresemaskin': ('fresemaskin',),
'fresemaskina': ('fresemaskin',),
'fresemaskinen': ('fresemaskin',),
'fresemaskinene': ('fresemaskin',),
'fresemaskiner': ('fresemaskin',),
'freser': ('freser',),
'fresere': ('freser',),
'freseren': ('freser',),
'freserer': ('freser',),
'freserne': ('freser',),
'fresia': ('fresia',),
'fresiaen': ('fresia',),
'fresiaene': ('fresia',),
'fresiaer': ('fresia',),
'freske': ('freske',),
'fresken': ('freske',),
'freskene': ('freske',),
'fresker': ('freske',),
'fresko': ('fresko',),
'freskoen': ('fresko',),
'freskoene': ('fresko',),
'freskoer': ('fresko',),
'freskomaler': ('freskomaler',),
'freskomalere': ('freskomaler',),
'freskomaleren': ('freskomaler',),
'freskomalerer': ('freskomaler',),
'freskomalerne': ('freskomaler',),
'freskomaleri': ('freskomaleri',),
'freskomaleria': ('freskomaleri',),
'freskomaleriene': ('freskomaleri',),
'freskomalerier': ('freskomaleri',),
'freskomaleriet': ('freskomaleri',),
'freudianer': ('freudianer',),
'freudianere': ('freudianer',),
'freudianeren': ('freudianer',),
'freudianerer': ('freudianer',),
'freudianerne': ('freudianer',),
'friareal': ('friareal',),
'friareala': ('friareal',),
'friarealene': ('friareal',),
'friarealer': ('friareal',),
'friarealet': ('friareal',),
'fribadestrand': ('fribadestrand',),
'fribadestranda': ('fribadestrand',),
'fribadestranden': ('fribadestrand',),
'fribadestrendene': ('fribadestrand',),
'fribadestrender': ('fribadestrand',),
'fribagasje': ('fribagasje',),
'fribagasjen': ('fribagasje',),
'fribagasjene': ('fribagasje',),
'fribagasjer': ('fribagasje',),
'fribillett': ('fribillett',),
'fribilletten': ('fribillett',),
'fribillettene': ('fribillett',),
'fribilletter': ('fribillett',),
'fribord': ('fribord',),
'friborda': ('fribord',),
'fribordene': ('fribord',),
'fribordet': ('fribord',),
'fribrev': ('fribrev',),
'fribreva': ('fribrev',),
'fribrevene': ('fribrev',),
'fribrever': ('fribrev',),
'fribrevet': ('fribrev',),
'fribryter': ('fribryter',),
'fribrytere': ('fribryter',),
'fribryteren': ('fribryter',),
'fribryterer': ('fribryter',),
'fribryterne': ('fribryter',),
'fribryting': ('fribryting',),
'fribrytinga': ('fribryting',),
'fribrytingen': ('fribryting',),
'fribrytingene': ('fribryting',),
'fribrytinger': ('fribryting',),
'fribytter': ('fribytter',),
'fribyttere': ('fribytter',),
'fribytteren': ('fribytter',),
'fribytterer': ('fribytter',),
'fribytterne': ('fribytter',),
'fribytteri': ('fribytteri',),
'fribytteria': ('fribytteri',),
'fribytteriene': ('fribytteri',),
'fribytterier': ('fribytteri',),
'fribytteriet': ('fribytteri',),
'fridag': ('fridag',),
'fridagen': ('fridag',),
'fridagene': ('fridag',),
'fridager': ('fridag',),
'fridom': ('fridom',),
'fridommen': ('fridom',),
'fridommene': ('fridom',),
'fridommer': ('fridom',),
'fridykking': ('fridykking',),
'fridykkinga': ('fridykking',),
'fridykkingen': ('fridykking',),
'fridykkingene': ('fridykking',),
'fridykkinger': ('fridykking',),
'frieksemplar': ('frieksemplar',),
'frieksemplara': ('frieksemplar',),
'frieksemplarene': ('frieksemplar',),
'frieksemplarer': ('frieksemplar',),
'frieksemplaret': ('frieksemplar',),
'frier': ('frier',),
'friere': ('frier',),
'frieren': ('frier',),
'frierer': ('frier',),
'frierne': ('frier',),
'frierbrev': ('frierbrev',),
'frierbreva': ('frierbrev',),
'frierbrevene': ('frierbrev',),
'frierbrever': ('frierbrev',),
'frierbrevet': ('frierbrev',),
'frierferd': ('frierferd',),
'frierferda': ('frierferd',),
'frierferden': ('frierferd',),
'frierferdene': ('frierferd',),
'frierferder': ('frierferd',),
'frieri': ('frieri',),
'frieria': ('frieri',),
'frieriene': ('frieri',),
'frierier': ('frieri',),
'frieriet': ('frieri',),
'frifant': ('frifant',),
'frifanten': ('frifant',),
'frifantene': ('frifant',),
'frifanter': ('frifant',),
'frifinnelse': ('frifinnelse',),
'frifinnelsen': ('frifinnelse',),
'frifinnelsene': ('frifinnelse',),
'frifinnelser': ('frifinnelse',),
'frifinning': ('frifinning',),
'frifinninga': ('frifinning',),
'frifinningen': ('frifinning',),
'frifinningene': ('frifinning',),
'frifinninger': ('frifinning',),
'frigang': ('frigang',),
'frigangen': ('frigang',),
'frigangene': ('frigang',),
'friganger': ('frigang',),
'frigangsheim': ('frigangsheim',),
'frigangsheimen': ('frigangsheim',),
'frigangsheimene': ('frigangsheim',),
'frigangsheimer': ('frigangsheim',),
'frigangshjem': ('frigangshjem',),
'frigangshjemma': ('frigangshjem',),
'frigangshjemmene': ('frigangshjem',),
'frigangshjemmet': ('frigangshjem',),
'frigevær': ('frigevær',),
'frigeværa': ('frigevær',),
'frigeværene': ('frigevær',),
'frigeværer': ('frigevær',),
'frigeværet': ('frigevær',),
'frigiditet': ('frigiditet',),
'frigiditeten': ('frigiditet',),
'frigiditetene': ('frigiditet',),
'frigiditeter': ('frigiditet',),
'frigjører': ('frigjører',),
'frigjørere': ('frigjører',),
'frigjøreren': ('frigjører',),
'frigjørerer': ('frigjører',),
'frigjørerne': ('frigjører',),
'frigjøring': ('frigjøring',),
'frigjøringa': ('frigjøring',),
'frigjøringen': ('frigjøring',),
'frigjøringene': ('frigjøring',),
'frigjøringer': ('frigjøring',),
'frigjøringsbevegelse': ('frigjøringsbevegelse',),
'frigjøringsbevegelsen': ('frigjøringsbevegelse',),
'frigjøringsbevegelsene': ('frigjøringsbevegelse',),
'frigjøringsbevegelser': ('frigjøringsbevegelse',),
'frigjøringskamp': ('frigjøringskamp',),
'frigjøringskampen': ('frigjøringskamp',),
'frigjøringskampene': ('frigjøringskamp',),
'frigjøringskamper': ('frigjøringskamp',),
'frigjøringsteologi': ('frigjøringsteologi',),
'frigjøringsteologien': ('frigjøringsteologi',),
'frigjøringsteologiene': ('frigjøringsteologi',),
'frigjøringsteologier': ('frigjøringsteologi',),
'frihamn': ('frihamn',),
'frihamna': ('frihamn',),
'frihamnen': ('frihamn',),
'frihamnene': ('frihamn',),
'frihamner': ('frihamn',),
'frihamn': ('frihamn',),
'frihamna': ('frihamn',),
'frihamnen': ('frihamn',),
'frihamnene': ('frihamn',),
'frihamner': ('frihamn',),
'frihandel': ('frihandel',),
'frihandelen': ('frihandel',),
'frihandlene': ('frihandel',),
'frihandler': ('frihandel',),
'frihandelsforbund': ('frihandelsforbund',),
'frihandelsforbunda': ('frihandelsforbund',),
'frihandelsforbundene': ('frihandelsforbund',),
'frihandelsforbundet': ('frihandelsforbund',),
'frihandelsområda': ('frihandelsområde',),
'frihandelsområde': ('frihandelsområde',),
'frihandelsområdene': ('frihandelsområde',),
'frihandelsområder': ('frihandelsområde',),
'frihandelsområdet': ('frihandelsområde',),
'frihavn': ('frihavn',),
'frihavna': ('frihavn',),
'frihavnen': ('frihavn',),
'frihavnene': ('frihavn',),
'frihavner': ('frihavn',),
'frihavn': ('frihavn',),
'frihavna': ('frihavn',),
'frihavnen': ('frihavn',),
'frihavnene': ('frihavn',),
'frihavner': ('frihavn',),
'friherre': ('friherre',),
'friherren': ('friherre',),
'friherrene': ('friherre',),
'friherrer': ('friherre',),
'frihet': ('frihet',),
'friheta': ('frihet',),
'friheten': ('frihet',),
'frihetene': ('frihet',),
'friheter': ('frihet',),
'frihetsberøvelse': ('frihetsberøvelse',),
'frihetsberøvelsen': ('frihetsberøvelse',),
'frihetsberøvelsene': ('frihetsberøvelse',),
'frihetsberøvelser': ('frihetsberøvelse',),
'frihetsbrev': ('frihetsbrev',),
'frihetsbreva': ('frihetsbrev',),
'frihetsbrevene': ('frihetsbrev',),
'frihetsbrever': ('frihetsbrev',),
'frihetsbrevet': ('frihetsbrev',),
'frihetsdag': ('frihetsdag',),
'frihetsdagen': ('frihetsdag',),
'frihetsdagene': ('frihetsdag',),
'frihetsdager': ('frihetsdag',),
'frihetshelt': ('frihetshelt',),
'frihetshelten': ('frihetshelt',),
'frihetsheltene': ('frihetshelt',),
'frihetshelter': ('frihetshelt',),
'frihetskjemper': ('frihetskjemper',),
'frihetskjempere': ('frihetskjemper',),
'frihetskjemperen': ('frihetskjemper',),
'frihetskjemperer': ('frihetskjemper',),
'frihetskjemperne': ('frihetskjemper',),
'frihetskrig': ('frihetskrig',),
'frihetskrigen': ('frihetskrig',),
'frihetskrigene': ('frihetskrig',),
'frihetskriger': ('frihetskrig',),
'frihetssymbol': ('frihetssymbol',),
'frihetssymbola': ('frihetssymbol',),
'frihetssymbolene': ('frihetssymbol',),
'frihetssymboler': ('frihetssymbol',),
'frihetssymbolet': ('frihetssymbol',),
'frihetstap': ('frihetstap',),
'frihetstapa': ('frihetstap',),
'frihetstapene': ('frihetstap',),
'frihetstapet': ('frihetstap',),
'frihjul': ('frihjul',),
'frihjula': ('frihjul',),
'frihjulene': ('frihjul',),
'frihjulet': ('frihjul',),
'frihjulsnav': ('frihjulsnav',),
'frihjulsnava': ('frihjulsnav',),
'frihjulsnavene': ('frihjulsnav',),
'frihjulsnavet': ('frihjulsnav',),
'friholt': ('friholt',),
'friholta': ('friholt',),
'friholten': ('friholt',),
'friholtene': ('friholt',),
'friholter': ('friholt',),
'friholtet': ('friholt',),
'friidrett': ('friidrett',),
'friidretten': ('friidrett',),
'friidrettene': ('friidrett',),
'friidretter': ('friidrett',),
'friing': ('friing',),
'friinga': ('friing',),
'friingen': ('friing',),
'friingene': ('friing',),
'friinger': ('friing',),
'frik': ('frik',),
'friken': ('frik',),
'frikene': ('frik',),
'friker': ('frik',),
'frikadelle': ('frikadelle',),
'frikadellen': ('frikadelle',),
'frikadellene': ('frikadelle',),
'frikadeller': ('frikadelle',),
'frikar': ('frikar',),
'frikara': ('frikar',),
'frikarene': ('frikar',),
'frikaret': ('frikar',),
'frikasseen': ('frikassé',),
'frikasseene': ('frikassé',),
'frikasseer': ('frikassé',),
'frikassé': ('frikassé',),
'frikasséen': ('frikassé',),
'frikasséene': ('frikassé',),
'frikasséer': ('frikassé',),
'frikast': ('frikast',),
'frikasta': ('frikast',),
'frikastene': ('frikast',),
'frikastet': ('frikast',),
'frikativ': ('frikativ',),
'frikativen': ('frikativ',),
'frikativene': ('frikativ',),
'frikativer': ('frikativ',),
'friker': ('friker',),
'frikere': ('friker',),
'frikeren': ('friker',),
'frikerer': ('friker',),
'frikerne': ('friker',),
'frikirka': ('frikirke',),
'frikirke': ('frikirke',),
'frikirken': ('frikirke',),
'frikirkene': ('frikirke',),
'frikirker': ('frikirke',),
'frikjennelse': ('frikjennelse',),
'frikjennelsen': ('frikjennelse',),
'frikjennelsene': ('frikjennelse',),
'frikjennelser': ('frikjennelse',),
'frikjerka': ('frikjerke',),
'frikjerke': ('frikjerke',),
'frikjerken': ('frikjerke',),
'frikjerkene': ('frikjerke',),
'frikjerker': ('frikjerke',),
'frikorps': ('frikorps',),
'frikorpsa': ('frikorps',),
'frikorpsene': ('frikorps',),
'frikorpset': ('frikorps',),
'frikort': ('frikort',),
'frikorta': ('frikort',),
'frikortene': ('frikort',),
'frikortet': ('frikort',),
'friksjon': ('friksjon',),
'friksjonen': ('friksjon',),
'friksjonene': ('friksjon',),
'friksjoner': ('friksjon',),
'friksjonselektrisitet': ('friksjonselektrisitet',),
'friksjonselektrisiteten': ('friksjonselektrisitet',),
'friksjonselektrisitetene': ('friksjonselektrisitet',),
'friksjonselektrisiteter': ('friksjonselektrisitet',),
'friksjonshjul': ('friksjonshjul',),
'friksjonshjula': ('friksjonshjul',),
'friksjonshjulene': ('friksjonshjul',),
'friksjonshjulet': ('friksjonshjul',),
'friksjonskobling': ('friksjonskobling',),
'friksjonskoblinga': ('friksjonskobling',),
'friksjonskoblingen': ('friksjonskobling',),
'friksjonskoblingene': ('friksjonskobling',),
'friksjonskoblinger': ('friksjonskobling',),
'friksjonskopling': ('friksjonskopling',),
'friksjonskoplinga': ('friksjonskopling',),
'friksjonskoplingen': ('friksjonskopling',),
'friksjonskoplingene': ('friksjonskopling',),
'friksjonskoplinger': ('friksjonskopling',),
'friksjonsmotstand': ('friksjonsmotstand',),
'friksjonsmotstanden': ('friksjonsmotstand',),
'friksjonsmotstandene': ('friksjonsmotstand',),
'friksjonsmotstander': ('friksjonsmotstand',),
'frikvarter': ('frikvarter',),
'frikvartera': ('frikvarter',),
'frikvarterene': ('frikvarter',),
'frikvarterer': ('frikvarter',),
'frikvarteret': ('frikvarter',),
'frilager': ('frilager',),
'frilageret': ('frilager',),
'frilagra': ('frilager',),
'frilagre': ('frilager',),
'frilagrene': ('frilager',),
'friland': ('friland',),
'frilanda': ('friland',),
'frilandene': ('friland',),
'frilandet': ('friland',),
'frilandstomat': ('frilandstomat',),
'frilandstomaten': ('frilandstomat',),
'frilandstomatene': ('frilandstomat',),
'frilandstomater': ('frilandstomat',),
'frilans': ('frilans',),
'frilansen': ('frilans',),
'frilansene': ('frilans',),
'frilanser': ('frilans',),
'frilanser': ('frilanser',),
'frilansere': ('frilanser',),
'frilanseren': ('frilanser',),
'frilanserer': ('frilanser',),
'frilanserne': ('frilanser',),
'frilansfotograf': ('frilansfotograf',),
'frilansfotografen': ('frilansfotograf',),
'frilansfotografene': ('frilansfotograf',),
'frilansfotografer': ('frilansfotograf',),
'frilansjournalist': ('frilansjournalist',),
'frilansjournalisten': ('frilansjournalist',),
'frilansjournalistene': ('frilansjournalist',),
'frilansjournalister': ('frilansjournalist',),
'frilansmedarbeider': ('frilansmedarbeider',),
'frilansmedarbeidere': ('frilansmedarbeider',),
'frilansmedarbeideren': ('frilansmedarbeider',),
'frilansmedarbeiderer': ('frilansmedarbeider',),
'frilansmedarbeiderne': ('frilansmedarbeider',),
'frilla': ('frille',),
'frille': ('frille',),
'frillen': ('frille',),
'frillene': ('frille',),
'friller': ('frille',),
'friluft': ('friluft',),
'frilufta': ('friluft',),
'friluften': ('friluft',),
'friluftene': ('friluft',),
'frilufter': ('friluft',),
'friluftsgudstjeneste': ('friluftsgudstjeneste',),
'friluftsgudstjenesten': ('friluftsgudstjeneste',),
'friluftsgudstjenestene': ('friluftsgudstjeneste',),
'friluftsgudstjenester': ('friluftsgudstjeneste',),
'friluftskonsert': ('friluftskonsert',),
'friluftskonserten': ('friluftskonsert',),
'friluftskonsertene': ('friluftskonsert',),
'friluftskonserter': ('friluftskonsert',),
'friluftsliv': ('friluftsliv',),
'friluftsliva': ('friluftsliv',),
'friluftslivene': ('friluftsliv',),
'friluftslivet': ('friluftsliv',),
'friluftsmenneska': ('friluftsmenneske',),
'friluftsmenneske': ('friluftsmenneske',),
'friluftsmenneskene': ('friluftsmenneske',),
'friluftsmennesker': ('friluftsmenneske',),
'friluftsmennesket': ('friluftsmenneske',),
'friluftsmøta': ('friluftsmøte',),
'friluftsmøte': ('friluftsmøte',),
'friluftsmøtene': ('friluftsmøte',),
'friluftsmøter': ('friluftsmøte',),
'friluftsmøtet': ('friluftsmøte',),
'friluftsområda': ('friluftsområde',),
'friluftsområde': ('friluftsområde',),
'friluftsområdene': ('friluftsområde',),
'friluftsområder': ('friluftsområde',),
'friluftsområdet': ('friluftsområde',),
'friluftsteater': ('friluftsteater',),
'friluftsteateret': ('friluftsteater',),
'friluftsteatra': ('friluftsteater',),
'friluftsteatre': ('friluftsteater',),
'friluftsteatrene': ('friluftsteater',),
'friluftsteatret': ('friluftsteater',),
'frilynna': ('frilynne',),
'frilynne': ('frilynne',),
'frilynnene': ('frilynne',),
'frilynner': ('frilynne',),
'frilynnet': ('frilynne',),
'frilørdag': ('frilørdag',),
'frilørdagen': ('frilørdag',),
'frilørdagene': ('frilørdag',),
'frilørdager': ('frilørdag',),
'frimenighet': ('frimenighet',),
'frimenigheta': ('frimenighet',),
'frimenigheten': ('frimenighet',),
'frimenighetene': ('frimenighet',),
'frimenigheter': ('frimenighet',),
'frimerka': ('frimerke',),
'frimerke': ('frimerke',),
'frimerkene': ('frimerke',),
'frimerker': ('frimerke',),
'frimerket': ('frimerke',),
'frimerkealbum': ('frimerkealbum',),
'frimerkealbuma': ('frimerkealbum',),
'frimerkealbumene': ('frimerkealbum',),
'frimerkealbumer': ('frimerkealbum',),
'frimerkealbumet': ('frimerkealbum',),
'frimerkesamler': ('frimerkesamler',),
'frimerkesamlere': ('frimerkesamler',),
'frimerkesamleren': ('frimerkesamler',),
'frimerkesamlerer': ('frimerkesamler',),
'frimerkesamlerne': ('frimerkesamler',),
'frimerkesamling': ('frimerkesamling',),
'frimerkesamlinga': ('frimerkesamling',),
'frimerkesamlingen': ('frimerkesamling',),
'frimerkesamlingene': ('frimerkesamling',),
'frimerkesamlinger': ('frimerkesamling',),
'friminutt': ('friminutt',),
'friminutta': ('friminutt',),
'friminuttene': ('friminutt',),
'friminutter': ('friminutt',),
'friminuttet': ('friminutt',),
'frimodighet': ('frimodighet',),
'frimodigheta': ('frimodighet',),
'frimodigheten': ('frimodighet',),
'frimodighetene': ('frimodighet',),
'frimodigheter': ('frimodighet',),
'frimurer': ('frimurer',),
'frimurere': ('frimurer',),
'frimureren': ('frimurer',),
'frimurerer': ('frimurer',),
'frimurerne': ('frimurer',),
'frimureri': ('frimureri',),
'frimureria': ('frimureri',),
'frimureriene': ('frimureri',),
'frimurerier': ('frimureri',),
'frimureriet': ('frimureri',),
'frimurerlosje': ('frimurerlosje',),
'frimurerlosjen': ('frimurerlosje',),
'frimurerlosjene': ('frimurerlosje',),
'frimurerlosjer': ('frimurerlosje',),
'frimurerorden': ('frimurerorden',),
'frimurerordenen': ('frimurerorden',),
'frimurerordenene': ('frimurerorden',),
'frimurerordener': ('frimurerorden',),
'friområda': ('friområde',),
'friområde': ('friområde',),
'friområdene': ('friområde',),
'friområder': ('friområde',),
'friområdet': ('friområde',),
'fripass': ('fripass',),
'fripassa': ('fripass',),
'fripassene': ('fripass',),
'fripasset': ('fripass',),
'friplass': ('friplass',),
'friplassen': ('friplass',),
'friplassene': ('friplass',),
'friplasser': ('friplass',),
'friprismarked': ('friprismarked',),
'friprismarkeda': ('friprismarked',),
'friprismarkedene': ('friprismarked',),
'friprismarkeder': ('friprismarked',),
'friprismarkedet': ('friprismarked',),
'friprismarknad': ('friprismarknad',),
'friprismarknaden': ('friprismarknad',),
'friprismarknadene': ('friprismarknad',),
'friprismarknader': ('friprismarknad',),
'frisbee': ('frisbee',),
'frisbeen': ('frisbee',),
'frisbeene': ('frisbee',),
'frisbeer': ('frisbee',),
'frise': ('frise',),
'frisen': ('frise',),
'frisene': ('frise',),
'friser': ('frise',),
'friser': ('friser',),
'frisere': ('friser',),
'friseren': ('friser',),
'friserer': ('friser',),
'friserne': ('friser',),
'friserdama': ('friserdame',),
'friserdame': ('friserdame',),
'friserdamen': ('friserdame',),
'friserdamene': ('friserdame',),
'friserdamer': ('friserdame',),
'frisersalong': ('frisersalong',),
'frisersalongen': ('frisersalong',),
'frisersalongene': ('frisersalong',),
'frisersalonger': ('frisersalong',),
'frisinn': ('frisinn',),
'frisinna': ('frisinn',),
'frisinnene': ('frisinn',),
'frisinnet': ('frisinn',),
'frisisk': ('frisisk',),
'frisisken': ('frisisk',),
'frisiskene': ('frisisk',),
'frisisker': ('frisisk',),
'frisk': ('frisk',),
'friskare': ('friskare',),
'friskaren': ('friskare',),
'friskarene': ('friskare',),
'friskarer': ('friskare',),
'friskfyr': ('friskfyr',),
'friskfyren': ('friskfyr',),
'friskfyrene': ('friskfyr',),
'friskfyrer': ('friskfyr',),
'friskluft': ('friskluft',),
'frisklufta': ('friskluft',),
'friskluften': ('friskluft',),
'friskluftene': ('friskluft',),
'frisklufter': ('friskluft',),
'friskluftanlegg': ('friskluftanlegg',),
'friskluftanlegga': ('friskluftanlegg',),
'friskluftanleggene': ('friskluftanlegg',),
'friskluftanlegget': ('friskluftanlegg',),
'friskmelding': ('friskmelding',),
'friskmeldinga': ('friskmelding',),
'friskmeldingen': ('friskmelding',),
'friskmeldingene': ('friskmelding',),
'friskmeldinger': ('friskmelding',),
'friskus': ('friskus',),
'friskusen': ('friskus',),
'friskusene': ('friskus',),
'friskuser': ('friskus',),
'friskytter': ('friskytter',),
'friskyttere': ('friskytter',),
'friskytteren': ('friskytter',),
'friskytterer': ('friskytter',),
'friskytterne': ('friskytter',),
'frislag': ('frislag',),
'frislaga': ('frislag',),
'frislagene': ('frislag',),
'frislaget': ('frislag',),
'frispark': ('frispark',),
'frisparka': ('frispark',),
'frisparkene': ('frispark',),
'frisparket': ('frispark',),
'frispeller': ('frispeller',),
'frispellere': ('frispeller',),
'frispelleren': ('frispeller',),
'frispellerer': ('frispeller',),
'frispellerne': ('frispeller',),
'frispiller': ('frispiller',),
'frispillere': ('frispiller',),
'frispilleren': ('frispiller',),
'frispillerer': ('frispiller',),
'frispillerne': ('frispiller',),
'frispråk': ('frispråk',),
'frispråka': ('frispråk',),
'frispråkene': ('frispråk',),
'frispråket': ('frispråk',),
'frist': ('frist',),
'fristen': ('frist',),
'fristene': ('frist',),
'frister': ('frist',),
'fristat': ('fristat',),
'fristaten': ('fristat',),
'fristatene': ('fristat',),
'fristater': ('fristat',),
'fristed': ('fristed',),
'fristedene': ('fristed',),
'fristeder': ('fristed',),
'fristedet': ('fristed',),
'fristelse': ('fristelse',),
'fristelsen': ('fristelse',),
'fristelsene': ('fristelse',),
'fristelser': ('fristelse',),
'frister': ('frister',),
'fristere': ('frister',),
'fristeren': ('frister',),
'fristerer': ('frister',),
'fristerne': ('frister',),
'fristil': ('fristil',),
'fristilen': ('fristil',),
'fristilene': ('fristil',),
'fristiler': ('fristil',),
'fristopper': ('fristopper',),
'fristoppere': ('fristopper',),
'fristopperen': ('fristopper',),
'fristopperer': ('fristopper',),
'fristopperne': ('fristopper',),
'fristund': ('fristund',),
'fristunda': ('fristund',),
'fristunden': ('fristund',),
'fristundene': ('fristund',),
'fristunder': ('fristund',),
'frisvømming': ('frisvømming',),
'frisvømminga': ('frisvømming',),
'frisvømmingen': ('frisvømming',),
'frisvømmingene': ('frisvømming',),
'frisvømminger': ('frisvømming',),
'frisyre': ('frisyre',),
'frisyren': ('frisyre',),
'frisyrene': ('frisyre',),
'frisyrer': ('frisyre',),
'frisør': ('frisør',),
'frisøren': ('frisør',),
'frisørene': ('frisør',),
'frisører': ('frisør',),
'frisørsalong': ('frisørsalong',),
'frisørsalongen': ('frisørsalong',),
'frisørsalongene': ('frisørsalong',),
'frisørsalonger': ('frisørsalong',),
'fritaing': ('fritaing',),
'fritainga': ('fritaing',),
'fritaingen': ('fritaing',),
'fritaingene': ('fritaing',),
'fritainger': ('fritaing',),
'fritak': ('fritak',),
'fritaka': ('fritak',),
'fritakene': ('fritak',),
'fritaket': ('fritak',),
'fritakelse': ('fritakelse',),
'fritakelsen': ('fritakelse',),
'fritakelsene': ('fritakelse',),
'fritakelser': ('fritakelse',),
'fritaking': ('fritaking',),
'fritakinga': ('fritaking',),
'fritakingen': ('fritaking',),
'fritakingene': ('fritaking',),
'fritakinger': ('fritaking',),
'fritalenhet': ('fritalenhet',),
'fritalenheta': ('fritalenhet',),
'fritalenheten': ('fritalenhet',),
'fritalenhetene': ('fritalenhet',),
'fritalenheter': ('fritalenhet',),
'fritenker': ('fritenker',),
'fritenkere': ('fritenker',),
'fritenkeren': ('fritenker',),
'fritenkerer': ('fritenker',),
'fritenkerne': ('fritenker',),
'fritenkeri': ('fritenkeri',),
'fritenkeria': ('fritenkeri',),
'fritenkeriene': ('fritenkeri',),
'fritenkerier': ('fritenkeri',),
'fritenkeriet': ('fritenkeri',),
'fritid': ('fritid',),
'fritida': ('fritid',),
'fritiden': ('fritid',),
'fritidene': ('fritid',),
'fritider': ('fritid',),
'fritidsaktivitet': ('fritidsaktivitet',),
'fritidsaktiviteten': ('fritidsaktivitet',),
'fritidsaktivitetene': ('fritidsaktivitet',),
'fritidsaktiviteter': ('fritidsaktivitet',),
'fritidsantrekk': ('fritidsantrekk',),
'fritidsantrekka': ('fritidsantrekk',),
'fritidsantrekkene': ('fritidsantrekk',),
'fritidsantrekket': ('fritidsantrekk',),
'fritidsheim': ('fritidsheim',),
'fritidsheimen': ('fritidsheim',),
'fritidsheimene': ('fritidsheim',),
'fritidsheimer': ('fritidsheim',),
'fritidshjem': ('fritidshjem',),
'fritidshjemma': ('fritidshjem',),
'fritidshjemmene': ('fritidshjem',),
'fritidshjemmet': ('fritidshjem',),
'fritidshus': ('fritidshus',),
'fritidshusa': ('fritidshus',),
'fritidshusene': ('fritidshus',),
'fritidshuset': ('fritidshus',),
'fritidsklubb': ('fritidsklubb',),
'fritidsklubben': ('fritidsklubb',),
'fritidsklubbene': ('fritidsklubb',),
'fritidsklubber': ('fritidsklubb',),
'fritidsleder': ('fritidsleder',),
'fritidsledere': ('fritidsleder',),
'fritidslederen': ('fritidsleder',),
'fritidslederer': ('fritidsleder',),
'fritidslederne': ('fritidsleder',),
'fritidsområda': ('fritidsområde',),
'fritidsområde': ('fritidsområde',),
'fritidsområdene': ('fritidsområde',),
'fritidsområder': ('fritidsområde',),
'fritidsområdet': ('fritidsområde',),
'fritidsproblem': ('fritidsproblem',),
'fritidsproblema': ('fritidsproblem',),
'fritidsproblemene': ('fritidsproblem',),
'fritidsproblemer': ('fritidsproblem',),
'fritidsproblemet': ('fritidsproblem',),
'fritidssyslene': ('fritidssyssel',),
'fritidssysler': ('fritidssyssel',),
'fritidssyssel': ('fritidssyssel',),
'fritidssysselen': ('fritidssyssel',),
'fritidstilbud': ('fritidstilbud',),
'fritidstilbuda': ('fritidstilbud',),
'fritidstilbudene': ('fritidstilbud',),
'fritidstilbudet': ('fritidstilbud',),
'fritime': ('fritime',),
'fritimen': ('fritime',),
'fritimene': ('fritime',),
'fritimer': ('fritime',),
'fritte': ('fritte',),
'fritten': ('fritte',),
'frittene': ('fritte',),
'fritter': ('fritte',),
'fritteporselen': ('fritteporselen',),
'fritteporselena': ('fritteporselen',),
'fritteporselenene': ('fritteporselen',),
'fritteporselener': ('fritteporselen',),
'fritteporselenet': ('fritteporselen',),
'frityr': ('frityr',),
'frityren': ('frityr',),
'frityrene': ('frityr',),
'frityrer': ('frityr',),
'frityrtorsk': ('frityrtorsk',),
'frityrtorsken': ('frityrtorsk',),
'frityrtorskene': ('frityrtorsk',),
'frityrtorsker': ('frityrtorsk',),
'frivakt': ('frivakt',),
'frivakta': ('frivakt',),
'frivakten': ('frivakt',),
'frivaktene': ('frivakt',),
'frivakter': ('frivakt',),
'frivolitet': ('frivolitet',),
'frivoliteten': ('frivolitet',),
'frivolitetene': ('frivolitet',),
'frivoliteter': ('frivolitet',),
'frokost': ('frokost',),
'frokosten': ('frokost',),
'frokostene': ('frokost',),
'frokoster': ('frokost',),
'frokostblanding': ('frokostblanding',),
'frokostblandinga': ('frokostblanding',),
'frokostblandingen': ('frokostblanding',),
'frokostblandingene': ('frokostblanding',),
'frokostblandinger': ('frokostblanding',),
'frokostbord': ('frokostbord',),
'frokostborda': ('frokostbord',),
'frokostbordene': ('frokostbord',),
'frokostborder': ('frokostbord',),
'frokostbordet': ('frokostbord',),
'frokostpause': ('frokostpause',),
'frokostpausen': ('frokostpause',),
'frokostpausene': ('frokostpause',),
'frokostpauser': ('frokostpause',),
'fromasj': ('fromasj',),
'fromasjen': ('fromasj',),
'fromasjene': ('fromasj',),
'fromasjer': ('fromasj',),
'fromessa': ('fromesse',),
'fromesse': ('fromesse',),
'fromessen': ('fromesse',),
'fromessene': ('fromesse',),
'fromesser': ('fromesse',),
'fromhet': ('fromhet',),
'fromheta': ('fromhet',),
'fromheten': ('fromhet',),
'fromhetene': ('fromhet',),
'fromheter': ('fromhet',),
'fromhetsliv': ('fromhetsliv',),
'fromhetsliva': ('fromhetsliv',),
'fromhetslivene': ('fromhetsliv',),
'fromhetslivet': ('fromhetsliv',),
'fromme': ('fromme',),
'frondør': ('frondør',),
'frondøren': ('frondør',),
'frondørene': ('frondør',),
'frondører': ('frondør',),
'front': ('front',),
'fronten': ('front',),
'frontene': ('front',),
'fronter': ('front',),
'front-mot-front-kollisjon': ('front-mot-front-kollisjon',),
'front-mot-front-kollisjonen': ('front-mot-front-kollisjon',),
'front-mot-front-kollisjonene': ('front-mot-front-kollisjon',),
'front-mot-front-kollisjoner': ('front-mot-front-kollisjon',),
'frontalangrep': ('frontalangrep',),
'frontalangrepa': ('frontalangrep',),
'frontalangrepene': ('frontalangrep',),
'frontalangrepet': ('frontalangrep',),
'frontalitet': ('frontalitet',),
'frontaliteten': ('frontalitet',),
'frontalitetene': ('frontalitet',),
'frontaliteter': ('frontalitet',),
'frontangrep': ('frontangrep',),
'frontangrepa': ('frontangrep',),
'frontangrepene': ('frontangrep',),
'frontangrepet': ('frontangrep',),
'frontavsnitt': ('frontavsnitt',),
'frontavsnitta': ('frontavsnitt',),
'frontavsnittene': ('frontavsnitt',),
'frontavsnittet': ('frontavsnitt',),
'frontbalkong': ('frontbalkong',),
'frontbalkongen': ('frontbalkong',),
'frontbalkongene': ('frontbalkong',),
'frontbalkonger': ('frontbalkong',),
'frontispis': ('frontispis',),
'frontispisen': ('frontispis',),
'frontispisene': ('frontispis',),
'frontispiser': ('frontispis',),
'frontispise': ('frontispise',),
'frontispisen': ('frontispise',),
'frontispisene': ('frontispise',),
'frontispiser': ('frontispise',),
'frontkjemper': ('frontkjemper',),
'frontkjempere': ('frontkjemper',),
'frontkjemperen': ('frontkjemper',),
'frontkjemperer': ('frontkjemper',),
'frontkjemperne': ('frontkjemper',),
'frontkollisjon': ('frontkollisjon',),
'frontkollisjonen': ('frontkollisjon',),
'frontkollisjonene': ('frontkollisjon',),
'frontkollisjoner': ('frontkollisjon',),
'frontlinja': ('frontlinje',),
'frontlinje': ('frontlinje',),
'frontlinjen': ('frontlinje',),
'frontlinjene': ('frontlinje',),
'frontlinjer': ('frontlinje',),
'frontlinjestat': ('frontlinjestat',),
'frontlinjestaten': ('frontlinjestat',),
'frontlinjestatene': ('frontlinjestat',),
'frontlinjestater': ('frontlinjestat',),
'frontlosje': ('frontlosje',),
'frontlosjen': ('frontlosje',),
'frontlosjene': ('frontlosje',),
'frontlosjer': ('frontlosje',),
'fronton': ('fronton',),
'frontonen': ('fronton',),
'frontonene': ('fronton',),
'frontoner': ('fronton',),
'frontruta': ('frontrute',),
'frontrute': ('frontrute',),
'frontruten': ('frontrute',),
'frontrutene': ('frontrute',),
'frontruter': ('frontrute',),
'frontsoldat': ('frontsoldat',),
'frontsoldaten': ('frontsoldat',),
'frontsoldatene': ('frontsoldat',),
'frontsoldater': ('frontsoldat',),
'fronttjeneste': ('fronttjeneste',),
'fronttjenesten': ('fronttjeneste',),
'fronttjenestene': ('fronttjeneste',),
'fronttjenester': ('fronttjeneste',),
'fropreken': ('fropreken',),
'froprekenen': ('fropreken',),
'froprekenene': ('fropreken',),
'froprekener': ('fropreken',),
'frosk': ('frosk',),
'frosken': ('frosk',),
'froskene': ('frosk',),
'frosker': ('frosk',),
'froskedam': ('froskedam',),
'froskedammen': ('froskedam',),
'froskedammene': ('froskedam',),
'froskedammer': ('froskedam',),
'froskeegg': ('froskeegg',),
'froskeegga': ('froskeegg',),
'froskeeggene': ('froskeegg',),
'froskeegget': ('froskeegg',),
'froskelår': ('froskelår',),
'froskelåra': ('froskelår',),
'froskelårene': ('froskelår',),
'froskelåret': ('froskelår',),
'froskemann': ('froskemann',),
'froskemannen': ('froskemann',),
'froskemenn': ('froskemann',),
'froskemennene': ('froskemann',),
'froskemannsutstyr': ('froskemannsutstyr',),
'froskemannsutstyra': ('froskemannsutstyr',),
'froskemannsutstyrene': ('froskemannsutstyr',),
'froskemannsutstyret': ('froskemannsutstyr',),
'froskeperspektiv': ('froskeperspektiv',),
'froskeperspektiva': ('froskeperspektiv',),
'froskeperspektivene': ('froskeperspektiv',),
'froskeperspektiver': ('froskeperspektiv',),
'froskeperspektivet': ('froskeperspektiv',),
'froskeskott': ('froskeskott',),
'froskeskotta': ('froskeskott',),
'froskeskottene': ('froskeskott',),
'froskeskottet': ('froskeskott',),
'froskeskudd': ('froskeskudd',),
'froskeskudda': ('froskeskudd',),
'froskeskuddene': ('froskeskudd',),
'froskeskuddet': ('froskeskudd',),
'froskeyngel': ('froskeyngel',),
'froskeyngelen': ('froskeyngel',),
'froskeynglene': ('froskeyngel',),
'frossenfilet': ('frossenfilet',),
'frossenfileten': ('frossenfilet',),
'frossenfiletene': ('frossenfilet',),
'frossenfileter': ('frossenfilet',),
'frossenfisk': ('frossenfisk',),
'frossenfisken': ('frossenfisk',),
'frossenfiskene': ('frossenfisk',),
'frossenfisker': ('frossenfisk',),
'frossenpinn': ('frossenpinn',),
'frossenpinnen': ('frossenpinn',),
'frossenpinnene': ('frossenpinn',),
'frossenpinner': ('frossenpinn',),
'frost': ('frost',),
'frosten': ('frost',),
'frostene': ('frost',),
'froster': ('frost',),
'frostfare': ('frostfare',),
'frostfaren': ('frostfare',),
'frostfarene': ('frostfare',),
'frostfarer': ('frostfare',),
'frostknute': ('frostknute',),
'frostknuten': ('frostknute',),
'frostknutene': ('frostknute',),
'frostknuter': ('frostknute',),
'frostluft': ('frostluft',),
'frostlufta': ('frostluft',),
'frostluften': ('frostluft',),
'frostluftene': ('frostluft',),
'frostlufter': ('frostluft',),
'frostmåler': ('frostmåler',),
'frostmålere': ('frostmåler',),
'frostmåleren': ('frostmåler',),
'frostmålerer': ('frostmåler',),
'frostmålerne': ('frostmåler',),
'frostnatt': ('frostnatt',),
'frostnatta': ('frostnatt',),
'frostnatten': ('frostnatt',),
'frostnettene': ('frostnatt',),
'frostnetter': ('frostnatt',),
'frostrosa': ('frostrose',),
'frostrose': ('frostrose',),
'frostrosen': ('frostrose',),
'frostrosene': ('frostrose',),
'frostroser': ('frostrose',),
'frostrøyk': ('frostrøyk',),
'frostrøyken': ('frostrøyk',),
'frostrøykene': ('frostrøyk',),
'frostrøyker': ('frostrøyk',),
'frostskade': ('frostskade',),
'frostskaden': ('frostskade',),
'frostskadene': ('frostskade',),
'frostskader': ('frostskade',),
'frostvæska': ('frostvæske',),
'frostvæske': ('frostvæske',),
'frostvæsken': ('frostvæske',),
'frostvæskene': ('frostvæske',),
'frostvæsker': ('frostvæske',),
'frotteen': ('frotté',),
'frotteene': ('frotté',),
'frotteer': ('frotté',),
'frotté': ('frotté',),
'frottéen': ('frotté',),
'frottéene': ('frotté',),
'frottéer': ('frotté',),
'frottéhandkle': ('frottéhandkle',),
'frottéhandkleet': ('frottéhandkle',),
'frottéhandklær': ('frottéhandkle',),
'frottéhandklærne': ('frottéhandkle',),
'frottéhåndkle': ('frottéhåndkle',),
'frottéhåndkleet': ('frottéhåndkle',),
'frottéhåndklær': ('frottéhåndkle',),
'frottéhåndklærne': ('frottéhåndkle',),
'frottérhandkle': ('frottérhandkle',),
'frottérhandkleet': ('frottérhandkle',),
'frottérhandklær': ('frottérhandkle',),
'frottérhandklærne': ('frottérhandkle',),
'frottérhåndkle': ('frottérhåndkle',),
'frottérhåndkleet': ('frottérhåndkle',),
'frottérhåndklær': ('frottérhåndkle',),
'frottérhåndklærne': ('frottérhåndkle',),
'frottérstoff': ('frottérstoff',),
'frottérstoffa': ('frottérstoff',),
'frottérstoffene': ('frottérstoff',),
'frottérstoffer': ('frottérstoff',),
'frottérstoffet': ('frottérstoff',),
'frottértøy': ('frottértøy',),
'frottértøya': ('frottértøy',),
'frottértøyene': ('frottértøy',),
'frottértøyer': ('frottértøy',),
'frottértøyet': ('frottértøy',),
'frottéstoff': ('frottéstoff',),
'frottéstoffa': ('frottéstoff',),
'frottéstoffene': ('frottéstoff',),
'frottéstoffer': ('frottéstoff',),
'frottéstoffet': ('frottéstoff',),
'frottétøy': ('frottétøy',),
'frottétøya': ('frottétøy',),
'frottétøyene': ('frottétøy',),
'frottétøyer': ('frottétøy',),
'frottétøyet': ('frottétøy',),
'fru': ('fru',),
'frua': ('frue',),
'frue': ('frue',),
'fruen': ('frue',),
'fruene': ('frue',),
'fruer': ('frue',),
'fruentimmer': ('fruentimmer',),
'fruentimmeret': ('fruentimmer',),
'fruentimra': ('fruentimmer',),
'fruentimre': ('fruentimmer',),
'fruentimrene': ('fruentimmer',),
'fruestørrelse': ('fruestørrelse',),
'fruestørrelsen': ('fruestørrelse',),
'fruestørrelsene': ('fruestørrelse',),
'fruestørrelser': ('fruestørrelse',),
'fruetitlene': ('fruetittel',),
'fruetitler': ('fruetittel',),
'fruetittel': ('fruetittel',),
'fruetittelen': ('fruetittel',),
'frukt': ('frukt',),
'frukta': ('frukt',),
'frukten': ('frukt',),
'fruktene': ('frukt',),
'frukter': ('frukt',),
'fruktbarhet': ('fruktbarhet',),
'fruktbarheta': ('fruktbarhet',),
'fruktbarheten': ('fruktbarhet',),
'fruktbarhetene': ('fruktbarhet',),
'fruktbarheter': ('fruktbarhet',),
'fruktbarhetsgud': ('fruktbarhetsgud',),
'fruktbarhetsguden': ('fruktbarhetsgud',),
'fruktbarhetsgudene': ('fruktbarhetsgud',),
'fruktbarhetsguder': ('fruktbarhetsgud',),
'fruktbarhetsgudinna': ('fruktbarhetsgudinne',),
'fruktbarhetsgudinne': ('fruktbarhetsgudinne',),
'fruktbarhetsgudinnen': ('fruktbarhetsgudinne',),
'fruktbarhetsgudinnene': ('fruktbarhetsgudinne',),
'fruktbarhetsgudinner': ('fruktbarhetsgudinne',),
'fruktbarhetskult': ('fruktbarhetskult',),
'fruktbarhetskulten': ('fruktbarhetskult',),
'fruktbarhetskultene': ('fruktbarhetskult',),
'fruktbarhetskulter': ('fruktbarhetskult',),
'fruktbarhetskultus': ('fruktbarhetskultus',),
'fruktbarhetskultusen': ('fruktbarhetskultus',),
'fruktbarhetskultusene': ('fruktbarhetskultus',),
'fruktbarhetskultuser': ('fruktbarhetskultus',),
'fruktblad': ('fruktblad',),
'fruktblada': ('fruktblad',),
'fruktbladene': ('fruktblad',),
'fruktblader': ('fruktblad',),
'fruktbladet': ('fruktblad',),
'fruktbåt': ('fruktbåt',),
'fruktbåten': ('fruktbåt',),
'fruktbåtene': ('fruktbåt',),
'fruktbåter': ('fruktbåt',),
'fruktdistrikt': ('fruktdistrikt',),
'fruktdistrikta': ('fruktdistrikt',),
'fruktdistriktene': ('fruktdistrikt',),
'fruktdistrikter': ('fruktdistrikt',),
'fruktdistriktet': ('fruktdistrikt',),
'fruktdyrker': ('fruktdyrker',),
'fruktdyrkere': ('fruktdyrker',),
'fruktdyrkeren': ('fruktdyrker',),
'fruktdyrkerer': ('fruktdyrker',),
'fruktdyrkerne': ('fruktdyrker',),
'fruktdyrking': ('fruktdyrking',),
'fruktdyrkinga': ('fruktdyrking',),
'fruktdyrkingen': ('fruktdyrking',),
'fruktdyrkingene': ('fruktdyrking',),
'fruktdyrkinger': ('fruktdyrking',),
'fruktdyrkning': ('fruktdyrkning',),
'fruktdyrkninga': ('fruktdyrkning',),
'fruktdyrkningen': ('fruktdyrkning',),
'fruktdyrkningene': ('fruktdyrkning',),
'fruktdyrkninger': ('fruktdyrkning',),
'fruktemna': ('fruktemne',),
'fruktemne': ('fruktemne',),
'fruktemnene': ('fruktemne',),
'fruktemner': ('fruktemne',),
'fruktemnet': ('fruktemne',),
'fruktknute': ('fruktknute',),
'fruktknuten': ('fruktknute',),
'fruktknutene': ('fruktknute',),
'fruktknuter': ('fruktknute',),
'fruktkompott': ('fruktkompott',),
'fruktkompotten': ('fruktkompott',),
'fruktkompottene': ('fruktkompott',),
'fruktkompotter': ('fruktkompott',),
'fruktose': ('fruktose',),
'fruktosen': ('fruktose',),
'fruktosene': ('fruktose',),
'fruktoser': ('fruktose',),
'fruktsalat': ('fruktsalat',),
'fruktsalaten': ('fruktsalat',),
'fruktsalatene': ('fruktsalat',),
'fruktsalater': ('fruktsalat',),
'fruktskip': ('fruktskip',),
'fruktskipa': ('fruktskip',),
'fruktskipene': ('fruktskip',),
'fruktskipet': ('fruktskip',),
'fruktsukker': ('fruktsukker',),
'fruktsukkera': ('fruktsukker',),
'fruktsukkere': ('fruktsukker',),
'fruktsukkerene': ('fruktsukker',),
'fruktsukkeret': ('fruktsukker',),
'fruktsukkerne': ('fruktsukker',),
'fruktsuppa': ('fruktsuppe',),
'fruktsuppe': ('fruktsuppe',),
'fruktsuppen': ('fruktsuppe',),
'fruktsuppene': ('fruktsuppe',),
'fruktsupper': ('fruktsuppe',),
'frustrasjon': ('frustrasjon',),
'frustrasjonen': ('frustrasjon',),
'frustrasjonene': ('frustrasjon',),
'frustrasjoner': ('frustrasjon',),
'fryd': ('fryd',),
'fryden': ('fryd',),
'frydene': ('fryd',),
'fryder': ('fryd',),
'fryderop': ('fryderop',),
'fryderopa': ('fryderop',),
'fryderopene': ('fryderop',),
'fryderopet': ('fryderop',),
'frykt': ('frykt',),
'frykten': ('frykt',),
'fryktene': ('frykt',),
'frykter': ('frykt',),
'frynsa': ('frynse',),
'frynse': ('frynse',),
'frynsen': ('frynse',),
'frynsene': ('frynse',),
'frynser': ('frynse',),
'frynsegoda': ('frynsegode',),
'frynsegode': ('frynsegode',),
'frynsegodene': ('frynsegode',),
'frynsegoder': ('frynsegode',),
'frynsegodet': ('frynsegode',),
'fryseanlegg': ('fryseanlegg',),
'fryseanlegga': ('fryseanlegg',),
'fryseanleggene': ('fryseanlegg',),
'fryseanlegget': ('fryseanlegg',),
'frysebil': ('frysebil',),
'frysebilen': ('frysebil',),
'frysebilene': ('frysebil',),
'frysebiler': ('frysebil',),
'fryseboks': ('fryseboks',),
'fryseboksen': ('fryseboks',),
'fryseboksene': ('fryseboks',),
'frysebokser': ('fryseboks',),
'frysedisk': ('frysedisk',),
'frysedisken': ('frysedisk',),
'frysediskene': ('frysedisk',),
'frysedisker': ('frysedisk',),
'frysepunkt': ('frysepunkt',),
'frysepunkta': ('frysepunkt',),
'frysepunktene': ('frysepunkt',),
'frysepunkter': ('frysepunkt',),
'frysepunktet': ('frysepunkt',),
'fryser': ('fryser',),
'frysere': ('fryser',),
'fryseren': ('fryser',),
'fryserer': ('fryser',),
'fryserne': ('fryser',),
'fryseri': ('fryseri',),
'fryseria': ('fryseri',),
'fryseriene': ('fryseri',),
'fryserier': ('fryseri',),
'fryseriet': ('fryseri',),
'fryserom': ('fryserom',),
'fryseromma': ('fryserom',),
'fryserommene': ('fryserom',),
'fryserommet': ('fryserom',),
'fryseskap': ('fryseskap',),
'fryseskapa': ('fryseskap',),
'fryseskapene': ('fryseskap',),
'fryseskapet': ('fryseskap',),
'frysetøy': ('frysetøy',),
'frysetøya': ('frysetøy',),
'frysetøyene': ('frysetøy',),
'frysetøyer': ('frysetøy',),
'frysetøyet': ('frysetøy',),
'frysevæska': ('frysevæske',),
'frysevæske': ('frysevæske',),
'frysevæsken': ('frysevæske',),
'frysevæskene': ('frysevæske',),
'frysevæsker': ('frysevæske',),
'frysing': ('frysing',),
'frysinga': ('frysing',),
'frysingen': ('frysing',),
'frysingene': ('frysing',),
'frysinger': ('frysing',),
'frysning': ('frysning',),
'frysninga': ('frysning',),
'frysningen': ('frysning',),
'frysningene': ('frysning',),
'frysninger': ('frysning',),
'fråde': ('fråde',),
'fråden': ('fråde',),
'frådene': ('fråde',),
'fråder': ('fråde',),
'fråsegn': ('fråsegn',),
'fråsegna': ('fråsegn',),
'fråsegnen': ('fråsegn',),
'fråsegnene': ('fråsegn',),
'fråsegner': ('fråsegn',),
'fråsser': ('fråsser',),
'fråssere': ('fråsser',),
'fråsseren': ('fråsser',),
'fråsserer': ('fråsser',),
'fråsserne': ('fråsser',),
'fråsseri': ('fråsseri',),
'fråsseria': ('fråsseri',),
'fråsseriene': ('fråsseri',),
'fråsserier': ('fråsseri',),
'fråsseriet': ('fråsseri',),
'fråtser': ('fråtser',),
'fråtsere': ('fråtser',),
'fråtseren': ('fråtser',),
'fråtserer': ('fråtser',),
'fråtserne': ('fråtser',),
'fråtseri': ('fråtseri',),
'fråtseria': ('fråtseri',),
'fråtseriene': ('fråtseri',),
'fråtserier': ('fråtseri',),
'fråtseriet': ('fråtseri',),
'frø': ('frø',),
'frøa': ('frø',),
'frøene': ('frø',),
'frøet': ('frø',),
'frøanalysa': ('frøanalyse',),
'frøanalyse': ('frøanalyse',),
'frøanalysen': ('frøanalyse',),
'frøanalysene': ('frøanalyse',),
'frøanalyser': ('frøanalyse',),
'frøavl': ('frøavl',),
'frøavlen': ('frøavl',),
'frøavlene': ('frøavl',),
'frøavler': ('frøavl',),
'frøblad': ('frøblad',),
'frøblada': ('frøblad',),
'frøbladene': ('frøblad',),
'frøblader': ('frøblad',),
'frøbladet': ('frøblad',),
'frøbrød': ('frøbrød',),
'frøbrøda': ('frøbrød',),
'frøbrødene': ('frøbrød',),
'frøbrødet': ('frøbrød',),
'frøemna': ('frøemne',),
'frøemne': ('frøemne',),
'frøemnene': ('frøemne',),
'frøemner': ('frøemne',),
'frøemnet': ('frøemne',),
'frøhus': ('frøhus',),
'frøhusa': ('frøhus',),
'frøhusene': ('frøhus',),
'frøhuset': ('frøhus',),
'frøkapsel': ('frøkapsel',),
'frøkapselen': ('frøkapsel',),
'frøkapslene': ('frøkapsel',),
'frøkapsler': ('frøkapsel',),
'frøken': ('frøken',),
'frøkenen': ('frøken',),
'frøkna': ('frøken',),
'frøknene': ('frøken',),
'frøkner': ('frøken',),
'frøkenfotball': ('frøkenfotball',),
'frøkenfotballen': ('frøkenfotball',),
'frøkenfotballene': ('frøkenfotball',),
'frøkenfotballer': ('frøkenfotball',),
'frøkontroll': ('frøkontroll',),
'frøkontrollen': ('frøkontroll',),
'frøkontrollene': ('frøkontroll',),
'frøkontroller': ('frøkontroll',),
'frøplanta': ('frøplante',),
'frøplante': ('frøplante',),
'frøplanten': ('frøplante',),
'frøplantene': ('frøplante',),
'frøplanter': ('frøplante',),
'frørensing': ('frørensing',),
'frørensinga': ('frørensing',),
'frørensingen': ('frørensing',),
'frørensingene': ('frørensing',),
'frørensinger': ('frørensing',),
'frøsetting': ('frøsetting',),
'frøsettinga': ('frøsetting',),
'frøsettingen': ('frøsetting',),
'frøsettingene': ('frøsetting',),
'frøsettinger': ('frøsetting',),
'frøskal': ('frøskal',),
'frøskala': ('frøskal',),
'frøskalene': ('frøskal',),
'frøskalet': ('frøskal',),
'frøskall': ('frøskall',),
'frøskalla': ('frøskall',),
'frøskallene': ('frøskall',),
'frøskallet': ('frøskall',),
'frøtre': ('frøtre',),
'frøtrea': ('frøtre',),
'frøtreet': ('frøtre',),
'frøtrær': ('frøtre',),
'frøtrærne': ('frøtre',),
'frøvara': ('frøvare',),
'frøvare': ('frøvare',),
'frøvaren': ('frøvare',),
'frøvarene': ('frøvare',),
'frøvarer': ('frøvare',),
'fuga': ('fuga',),
'fugaen': ('fuga',),
'fugaene': ('fuga',),
'fugaer': ('fuga',),
'fuge': ('fuge',),
'fugen': ('fuge',),
'fugene': ('fuge',),
'fuger': ('fuge',),
'fuge': ('fuge',),
'fugen': ('fuge',),
'fugene': ('fuge',),
'fuger': ('fuge',),
'fugearbeid': ('fugearbeid',),
'fugearbeida': ('fugearbeid',),
'fugearbeidene': ('fugearbeid',),
'fugearbeider': ('fugearbeid',),
'fugearbeidet': ('fugearbeid',),
'fugemasse': ('fugemasse',),
'fugemassen': ('fugemasse',),
'fugemassene': ('fugemasse',),
'fugemasser': ('fugemasse',),
'fugeskei': ('fugeskei',),
'fugeskeia': ('fugeskei',),
'fugeskeien': ('fugeskei',),
'fugeskeiene': ('fugeskei',),
'fugeskeier': ('fugeskei',),
'fugeskje': ('fugeskje',),
'fugeskjea': ('fugeskje',),
'fugeskjeen': ('fugeskje',),
'fugeskjeene': ('fugeskje',),
'fugeskjeer': ('fugeskje',),
'fugl': ('fugl',),
'fuglen': ('fugl',),
'fuglene': ('fugl',),
'fugler': ('fugl',),
'fugleart': ('fugleart',),
'fuglearta': ('fugleart',),
'fuglearten': ('fugleart',),
'fugleartene': ('fugleart',),
'fuglearter': ('fugleart',),
'fugleberg': ('fugleberg',),
'fugleberga': ('fugleberg',),
'fuglebergene': ('fugleberg',),
'fugleberget': ('fugleberg',),
'fuglebrett': ('fuglebrett',),
'fuglebretta': ('fuglebrett',),
'fuglebrettene': ('fuglebrett',),
'fuglebretter': ('fuglebrett',),
'fuglebrettet': ('fuglebrett',),
'fuglebryst': ('fuglebryst',),
'fuglebrysta': ('fuglebryst',),
'fuglebrystene': ('fuglebryst',),
'fuglebrystet': ('fuglebryst',),
'fuglefjell': ('fuglefjell',),
'fuglefjella': ('fuglefjell',),
'fuglefjellene': ('fuglefjell',),
'fuglefjellet': ('fuglefjell',),
'fuglehund': ('fuglehund',),
'fuglehunden': ('fuglehund',),
'fuglehundene': ('fuglehund',),
'fuglehunder': ('fuglehund',),
'fuglekonge': ('fuglekonge',),
'fuglekongen': ('fuglekonge',),
'fuglekongene': ('fuglekonge',),
'fuglekonger': ('fuglekonge',),
'fuglekvitra': ('fuglekvitter',),
'fuglekvitre': ('fuglekvitter',),
'fuglekvitrene': ('fuglekvitter',),
'fuglekvitret': ('fuglekvitter',),
'fuglekvitter': ('fuglekvitter',),
'fuglekvitteret': ('fuglekvitter',),
'fugleperspektiv': ('fugleperspektiv',),
'fugleperspektiva': ('fugleperspektiv',),
'fugleperspektivene': ('fugleperspektiv',),
'fugleperspektiver': ('fugleperspektiv',),
'fugleperspektivet': ('fugleperspektiv',),
'fuglereda': ('fuglerede',),
'fuglerede': ('fuglerede',),
'fugleredene': ('fuglerede',),
'fuglereder': ('fuglerede',),
'fugleredet': ('fuglerede',),
'fuglereir': ('fuglereir',),
'fuglereira': ('fuglereir',),
'fuglereirene': ('fuglereir',),
'fuglereiret': ('fuglereir',),
'fuglesang': ('fuglesang',),
'fuglesangen': ('fuglesang',),
'fuglesangene': ('fuglesang',),
'fuglesanger': ('fuglesang',),
'fugleskremsel': ('fugleskremsel',),
'fugleskremselet': ('fugleskremsel',),
'fugleskremsla': ('fugleskremsel',),
'fugleskremslene': ('fugleskremsel',),
'fugleskremsler': ('fugleskremsel',),
'fugleskremslet': ('fugleskremsel',),
'fugletrekk': ('fugletrekk',),
'fugletrekka': ('fugletrekk',),
'fugletrekkene': ('fugletrekk',),
'fugletrekket': ('fugletrekk',),
'fuglevikka': ('fuglevikke',),
'fuglevikke': ('fuglevikke',),
'fuglevikken': ('fuglevikke',),
'fuglevikkene': ('fuglevikke',),
'fuglevikker': ('fuglevikke',),
'fuglevær': ('fuglevær',),
'fugleværa': ('fuglevær',),
'fugleværene': ('fuglevær',),
'fugleværet': ('fuglevær',),
'fuks': ('fuks',),
'fuksen': ('fuks',),
'fuksene': ('fuks',),
'fukser': ('fuks',),
'fuksia': ('fuksia',),
'fuksiaen': ('fuksia',),
'fuksiaene': ('fuksia',),
'fuksiaer': ('fuksia',),
'fukt': ('fukt',),
'fukta': ('fukt',),
'fukten': ('fukt',),
'fuktene': ('fukt',),
'fukter': ('fukt',),
'fuktighet': ('fuktighet',),
'fuktigheta': ('fuktighet',),
'fuktigheten': ('fuktighet',),
'fuktighetene': ('fuktighet',),
'fuktigheter': ('fuktighet',),
'fuktighetsmåler': ('fuktighetsmåler',),
'fuktighetsmålere': ('fuktighetsmåler',),
'fuktighetsmåleren': ('fuktighetsmåler',),
'fuktighetsmålerer': ('fuktighetsmåler',),
'fuktighetsmålerne': ('fuktighetsmåler',),
'fuling': ('fuling',),
'fulingen': ('fuling',),
'fulingene': ('fuling',),
'fulinger': ('fuling',),
'fullblodshest': ('fullblodshest',),
'fullblodshesten': ('fullblodshest',),
'fullblodshestene': ('fullblodshest',),
'fullblodshester': ('fullblodshest',),
'fullgjødsel': ('fullgjødsel',),
'fullgjødselen': ('fullgjødsel',),
'fullgjødsla': ('fullgjødsel',),
'fullgjødslene': ('fullgjødsel',),
'fullgjødsler': ('fullgjødsel',),
'fullkommenhet': ('fullkommenhet',),
'fullkommenheta': ('fullkommenhet',),
'fullkommenheten': ('fullkommenhet',),
'fullkommenhetene': ('fullkommenhet',),
'fullkommenheter': ('fullkommenhet',),
'fullmakt': ('fullmakt',),
'fullmakta': ('fullmakt',),
'fullmakten': ('fullmakt',),
'fullmaktene': ('fullmakt',),
'fullmakter': ('fullmakt',),
'fullmaktsbrev': ('fullmaktsbrev',),
'fullmaktsbreva': ('fullmaktsbrev',),
'fullmaktsbrevene': ('fullmaktsbrev',),
'fullmaktsbrever': ('fullmaktsbrev',),
'fullmaktsbrevet': ('fullmaktsbrev',),
'fullmektig': ('fullmektig',),
'fullmektigen': ('fullmektig',),
'fullmektigene': ('fullmektig',),
'fullmektiger': ('fullmektig',),
'fullmåne': ('fullmåne',),
'fullmånen': ('fullmåne',),
'fullmånene': ('fullmåne',),
'fullmåner': ('fullmåne',),
'fullrigger': ('fullrigger',),
'fullriggere': ('fullrigger',),
'fullriggeren': ('fullrigger',),
'fullriggerer': ('fullrigger',),
'fullriggerne': ('fullrigger',),
'fulltreff': ('fulltreff',),
'fulltreffa': ('fulltreff',),
'fulltreffene': ('fulltreff',),
'fulltreffet': ('fulltreff',),
'fulltreffer': ('fulltreffer',),
'fulltreffere': ('fulltreffer',),
'fulltrefferen': ('fulltreffer',),
'fulltrefferer': ('fulltreffer',),
'fulltrefferne': ('fulltreffer',),
'fullverdiforsikring': ('fullverdiforsikring',),
'fullverdiforsikringa': ('fullverdiforsikring',),
'fullverdiforsikringen': ('fullverdiforsikring',),
'fullverdiforsikringene': ('fullverdiforsikring',),
'fullverdiforsikringer': ('fullverdiforsikring',),
'fullvokal': ('fullvokal',),
'fullvokalen': ('fullvokal',),
'fullvokalene': ('fullvokal',),
'fullvokaler': ('fullvokal',),
'fund': ('fund',),
'fundament': ('fundament',),
'fundamenta': ('fundament',),
'fundamentene': ('fundament',),
'fundamenter': ('fundament',),
'fundamentet': ('fundament',),
'fundamentalisme': ('fundamentalisme',),
'fundamentalismen': ('fundamentalisme',),
'fundamentalismene': ('fundamentalisme',),
'fundamentalismer': ('fundamentalisme',),
'fundamentalist': ('fundamentalist',),
'fundamentalisten': ('fundamentalist',),
'fundamentalistene': ('fundamentalist',),
'fundamentalister': ('fundamentalist',),
'fundas': ('fundas',),
'fundasen': ('fundas',),
'fundasene': ('fundas',),
'fundaser': ('fundas',),
'fungicid': ('fungicid',),
'fungicida': ('fungicid',),
'fungicidene': ('fungicid',),
'fungicider': ('fungicid',),
'fungicidet': ('fungicid',),
'funkis': ('funkis',),
'funkisen': ('funkis',),
'funkisene': ('funkis',),
'funkiser': ('funkis',),
'funkishus': ('funkishus',),
'funkishusa': ('funkishus',),
'funkishusene': ('funkishus',),
'funkishuset': ('funkishus',),
'funkisstil': ('funkisstil',),
'funkisstilen': ('funkisstil',),
'funkisstilene': ('funkisstil',),
'funkisstiler': ('funkisstil',),
'funksjon': ('funksjon',),
'funksjonen': ('funksjon',),
'funksjonene': ('funksjon',),
'funksjoner': ('funksjon',),
'funksjonalisme': ('funksjonalisme',),
'funksjonalismen': ('funksjonalisme',),
'funksjonalismene': ('funksjonalisme',),
'funksjonalismer': ('funksjonalisme',),
'funksjonshemning': ('funksjonshemning',),
'funksjonshemninga': ('funksjonshemning',),
'funksjonshemningen': ('funksjonshemning',),
'funksjonshemningene': ('funksjonshemning',),
'funksjonshemninger': ('funksjonshemning',),
'funksjonslæra': ('funksjonslære',),
'funksjonslære': ('funksjonslære',),
'funksjonslæren': ('funksjonslære',),
'funksjonslærene': ('funksjonslære',),
'funksjonslærer': ('funksjonslære',),
'funksjonstid': ('funksjonstid',),
'funksjonstida': ('funksjonstid',),
'funksjonstiden': ('funksjonstid',),
'funksjonstidene': ('funksjonstid',),
'funksjonstider': ('funksjonstid',),
'funksjonær': ('funksjonær',),
'funksjonæren': ('funksjonær',),
'funksjonærene': ('funksjonær',),
'funksjonærer': ('funksjonær',),
'funksjonærbolig': ('funksjonærbolig',),
'funksjonærboligen': ('funksjonærbolig',),
'funksjonærboligene': ('funksjonærbolig',),
'funksjonærboliger': ('funksjonærbolig',),
'funn': ('funn',),
'funna': ('funn',),
'funnene': ('funn',),
'funnet': ('funn',),
'funnsted': ('funnsted',),
'funnstedene': ('funnsted',),
'funnsteder': ('funnsted',),
'funnstedet': ('funnsted',),
'furasje': ('furasje',),
'furasjen': ('furasje',),
'furasjene': ('furasje',),
'furasjer': ('furasje',),
'fure': ('fure',),
'furen': ('fure',),
'furene': ('fure',),
'furer': ('fure',),
'furer': ('furer',),
'fureren': ('furer',),
'furerene': ('furer',),
'furerer': ('furer',),
'furia': ('furie',),
'furie': ('furie',),
'furien': ('furie',),
'furiene': ('furie',),
'furier': ('furie',),
'furore': ('furore',),
'furoren': ('furore',),
'furorene': ('furore',),
'furorer': ('furore',),
'furt': ('furt',),
'furten': ('furt',),
'furtene': ('furt',),
'furter': ('furt',),
'furu': ('furu',),
'furua': ('furu',),
'furuen': ('furu',),
'furuene': ('furu',),
'furuer': ('furu',),
'furubord': ('furubord',),
'furuborda': ('furubord',),
'furubordene': ('furubord',),
'furuborder': ('furubord',),
'furubordet': ('furubord',),
'furubukk': ('furubukk',),
'furubukken': ('furubukk',),
'furubukkene': ('furubukk',),
'furubukker': ('furubukk',),
'furufamilie': ('furufamilie',),
'furufamilien': ('furufamilie',),
'furufamiliene': ('furufamilie',),
'furufamilier': ('furufamilie',),
'furukongla': ('furukongle',),
'furukongle': ('furukongle',),
'furukonglen': ('furukongle',),
'furukonglene': ('furukongle',),
'furukongler': ('furukongle',),
'furukrona': ('furukrone',),
'furukrone': ('furukrone',),
'furukronen': ('furukrone',),
'furukronene': ('furukrone',),
'furukroner': ('furukrone',),
'furulegg': ('furulegg',),
'furuleggen': ('furulegg',),
'furuleggene': ('furulegg',),
'furulegger': ('furulegg',),
'furumo': ('furumo',),
'furumoen': ('furumo',),
'furumoene': ('furumo',),
'furumoer': ('furumo',),
'furunkel': ('furunkel',),
'furunkelen': ('furunkel',),
'furunklene': ('furunkel',),
'furunkler': ('furunkel',),
'furunkulose': ('furunkulose',),
'furunkulosen': ('furunkulose',),
'furunkulosene': ('furunkulose',),
'furunkuloser': ('furunkulose',),
'furunål': ('furunål',),
'furunåla': ('furunål',),
'furunålen': ('furunål',),
'furunålene': ('furunål',),
'furunåler': ('furunål',),
'furunålsbad': ('furunålsbad',),
'furunålsbada': ('furunålsbad',),
'furunålsbadene': ('furunålsbad',),
'furunålsbadet': ('furunålsbad',),
'furuskog': ('furuskog',),
'furuskogen': ('furuskog',),
'furuskogene': ('furuskog',),
'furuskoger': ('furuskog',),
'furustamme': ('furustamme',),
'furustammen': ('furustamme',),
'furustammene': ('furustamme',),
'furustammer': ('furustamme',),
'furuved': ('furuved',),
'furuveden': ('furuved',),
'furuvedene': ('furuved',),
'furuveder': ('furuved',),
'fus': ('fus',),
'fusen': ('fus',),
'fusene': ('fus',),
'fuser': ('fus',),
'fusel': ('fusel',),
'fuselen': ('fusel',),
'fuslene': ('fusel',),
'fusler': ('fusel',),
'fuselbrennevin': ('fuselbrennevin',),
'fuselbrennevinene': ('fuselbrennevin',),
'fuselbrenneviner': ('fuselbrennevin',),
'fuselbrennevinet': ('fuselbrennevin',),
'fuselolja': ('fuselolje',),
'fuselolje': ('fuselolje',),
'fuseloljen': ('fuselolje',),
'fuseloljene': ('fuselolje',),
'fuseloljer': ('fuselolje',),
'fusentast': ('fusentast',),
'fusentasten': ('fusentast',),
'fusentastene': ('fusentast',),
'fusentaster': ('fusentast',),
'fusjon': ('fusjon',),
'fusjonen': ('fusjon',),
'fusjonene': ('fusjon',),
'fusjoner': ('fusjon',),
'fusk': ('fusk',),
'fuska': ('fusk',),
'fuskene': ('fusk',),
'fusket': ('fusk',),
'fuskearbeid': ('fuskearbeid',),
'fuskearbeida': ('fuskearbeid',),
'fuskearbeidene': ('fuskearbeid',),
'fuskearbeider': ('fuskearbeid',),
'fuskearbeidet': ('fuskearbeid',),
'fuskelapp': ('fuskelapp',),
'fuskelappen': ('fuskelapp',),
'fuskelappene': ('fuskelapp',),
'fuskelapper': ('fuskelapp',),
'fusker': ('fusker',),
'fuskere': ('fusker',),
'fuskeren': ('fusker',),
'fuskerer': ('fusker',),
'fuskerne': ('fusker',),
'fuskerarbeid': ('fuskerarbeid',),
'fuskerarbeida': ('fuskerarbeid',),
'fuskerarbeidene': ('fuskerarbeid',),
'fuskerarbeider': ('fuskerarbeid',),
'fuskerarbeidet': ('fuskerarbeid',),
'fuskeri': ('fuskeri',),
'fuskeria': ('fuskeri',),
'fuskeriene': ('fuskeri',),
'fuskerier': ('fuskeri',),
'fuskeriet': ('fuskeri',),
'fuskesikring': ('fuskesikring',),
'fuskesikringa': ('fuskesikring',),
'fuskesikringen': ('fuskesikring',),
'fuskesikringene': ('fuskesikring',),
'fuskesikringer': ('fuskesikring',),
'fusse': ('fusse',),
'fussen': ('fusse',),
'fussene': ('fusse',),
'fusser': ('fusse',),
'fusselukt': ('fusselukt',),
'fusselukta': ('fusselukt',),
'fusselukten': ('fusselukt',),
'fusseluktene': ('fusselukt',),
'fusselukter': ('fusselukt',),
'fustasje': ('fustasje',),
'fustasjen': ('fustasje',),
'fustasjene': ('fustasje',),
'fustasjer': ('fustasje',),
'fut': ('fut',),
'futen': ('fut',),
'futene': ('fut',),
'futer': ('fut',),
'futedømma': ('futedømme',),
'futedømme': ('futedømme',),
'futedømmene': ('futedømme',),
'futedømmer': ('futedømme',),
'futedømmet': ('futedømme',),
'futegard': ('futegard',),
'futegarden': ('futegard',),
'futegardene': ('futegard',),
'futegarder': ('futegard',),
'futegård': ('futegård',),
'futegården': ('futegård',),
'futegårdene': ('futegård',),
'futegårder': ('futegård',),
'futhark': ('futhark',),
'futharken': ('futhark',),
'futharkene': ('futhark',),
'futharker': ('futhark',),
'futilitet': ('futilitet',),
'futiliteten': ('futilitet',),
'futilitetene': ('futilitet',),
'futiliteter': ('futilitet',),
'futt': ('futt',),
'futten': ('futt',),
'futtene': ('futt',),
'futter': ('futt',),
'futteral': ('futteral',),
'futterala': ('futteral',),
'futteralene': ('futteral',),
'futteraler': ('futteral',),
'futteralet': ('futteral',),
'futurisme': ('futurisme',),
'futurismen': ('futurisme',),
'futurismene': ('futurisme',),
'futurismer': ('futurisme',),
'futurist': ('futurist',),
'futuristen': ('futurist',),
'futuristene': ('futurist',),
'futurister': ('futurist',),
'futurolog': ('futurolog',),
'futurologen': ('futurolog',),
'futurologene': ('futurolog',),
'futurologer': ('futurolog',),
'futurologi': ('futurologi',),
'futurologien': ('futurologi',),
'futurologiene': ('futurologi',),
'futurologier': ('futurologi',),
'futura': ('futurum',),
'futuraene': ('futurum',),
'futurum': ('futurum',),
'futuruma': ('futurum',),
'futurumene': ('futurum',),
'futurumer': ('futurum',),
'futurumet': ('futurum',),
'futurum exactum': ('futurum exactum',),
'fyk': ('fyk',),
'fyka': ('fyk',),
'fyken': ('fyk',),
'fykene': ('fyk',),
'fyker': ('fyk',),
'fyket': ('fyk',),
'fylde': ('fylde',),
'fylden': ('fylde',),
'fyldene': ('fylde',),
'fylder': ('fylde',),
'fylde': ('fylde',),
'fylden': ('fylde',),
'fyldene': ('fylde',),
'fylder': ('fylde',),
'fylgja': ('fylgje',),
'fylgje': ('fylgje',),
'fylgjen': ('fylgje',),
'fylgjene': ('fylgje',),
'fylgjer': ('fylgje',),
'fylka': ('fylke',),
'fylke': ('fylke',),
'fylkene': ('fylke',),
'fylker': ('fylke',),
'fylket': ('fylke',),
'fylkesagronom': ('fylkesagronom',),
'fylkesagronomen': ('fylkesagronom',),
'fylkesagronomene': ('fylkesagronom',),
'fylkesagronomer': ('fylkesagronom',),
'fylkeskommune': ('fylkeskommune',),
'fylkeskommunen': ('fylkeskommune',),
'fylkeskommunene': ('fylkeskommune',),
'fylkeskommuner': ('fylkeskommune',),
'fylkeslege': ('fylkeslege',),
'fylkeslegen': ('fylkeslege',),
'fylkeslegene': ('fylkeslege',),
'fylkesleger': ('fylkeslege',),
'fylkesmann': ('fylkesmann',),
'fylkesmannen': ('fylkesmann',),
'fylkesmenn': ('fylkesmann',),
'fylkesmennene': ('fylkesmann',),
'fylkesordfører': ('fylkesordfører',),
'fylkesordførere': ('fylkesordfører',),
'fylkesordføreren': ('fylkesordfører',),
'fylkesordførerer': ('fylkesordfører',),
'fylkesordførerne': ('fylkesordfører',),
'fylkesplan': ('fylkesplan',),
'fylkesplana': ('fylkesplan',),
'fylkesplanene': ('fylkesplan',),
'fylkesplanet': ('fylkesplan',),
'fylkesrådmann': ('fylkesrådmann',),
'fylkesrådmannen': ('fylkesrådmann',),
'fylkesrådmenn': ('fylkesrådmann',),
'fylkesrådmennene': ('fylkesrådmann',),
'fylkessjukehus': ('fylkessjukehus',),
'fylkessjukehusa': ('fylkessjukehus',),
'fylkessjukehusene': ('fylkessjukehus',),
'fylkessjukehuset': ('fylkessjukehus',),
'fylkesskatt': ('fylkesskatt',),
'fylkesskatten': ('fylkesskatt',),
'fylkesskattene': ('fylkesskatt',),
'fylkesskatter': ('fylkesskatt',),
'fylkesskattestyra': ('fylkesskattestyre',),
'fylkesskattestyre': ('fylkesskattestyre',),
'fylkesskattestyrene': ('fylkesskattestyre',),
'fylkesskattestyrer': ('fylkesskattestyre',),
'fylkesskattestyret': ('fylkesskattestyre',),
'fylkesskogsjef': ('fylkesskogsjef',),
'fylkesskogsjefen': ('fylkesskogsjef',),
'fylkesskogsjefene': ('fylkesskogsjef',),
'fylkesskogsjefer': ('fylkesskogsjef',),
'fylkessykehus': ('fylkessykehus',),
'fylkessykehusa': ('fylkessykehus',),
'fylkessykehusene': ('fylkessykehus',),
'fylkessykehuset': ('fylkessykehus',),
'fylkesting': ('fylkesting',),
'fylkestinga': ('fylkesting',),
'fylkestingene': ('fylkesting',),
'fylkestinget': ('fylkesting',),
'fylkesveg': ('fylkesveg',),
'fylkesvegen': ('fylkesveg',),
'fylkesvegene': ('fylkesveg',),
'fylkesveger': ('fylkesveg',),
'fylkesvei': ('fylkesvei',),
'fylkesveien': ('fylkesvei',),
'fylkesveiene': ('fylkesvei',),
'fylkesveier': ('fylkesvei',),
'fylking': ('fylking',),
'fylkinga': ('fylking',),
'fylkingen': ('fylking',),
'fylkingene': ('fylking',),
'fylkinger': ('fylking',),
'fylle': ('fylle',),
'fyllen': ('fylle',),
'fyllene': ('fylle',),
'fyller': ('fylle',),
'fylle': ('fylle',),
'fyllen': ('fylle',),
'fyllene': ('fylle',),
'fyller': ('fylle',),
'fyllearrest': ('fyllearrest',),
'fyllearresten': ('fyllearrest',),
'fyllearrestene': ('fyllearrest',),
'fyllearrester': ('fyllearrest',),
'fyllebråk': ('fyllebråk',),
'fyllebråka': ('fyllebråk',),
'fyllebråkene': ('fyllebråk',),
'fyllebråket': ('fyllebråk',),
'fyllebøtta': ('fyllebøtte',),
'fyllebøtte': ('fyllebøtte',),
'fyllebøtten': ('fyllebøtte',),
'fyllebøttene': ('fyllebøtte',),
'fyllebøtter': ('fyllebøtte',),
'fyllekalas': ('fyllekalas',),
'fyllekalasa': ('fyllekalas',),
'fyllekalasene': ('fyllekalas',),
'fyllekalaser': ('fyllekalas',),
'fyllekalaset': ('fyllekalas',),
'fyllekalk': ('fyllekalk',),
'fyllekalken': ('fyllekalk',),
'fyllekalkene': ('fyllekalk',),
'fyllekalker': ('fyllekalk',),
'fyllepenn': ('fyllepenn',),
'fyllepennen': ('fyllepenn',),
'fyllepennene': ('fyllepenn',),
'fyllepenner': ('fyllepenn',),
'fylleprat': ('fylleprat',),
'fylleprata': ('fylleprat',),
'fyllepraten': ('fylleprat',),
'fyllepratene': ('fylleprat',),
'fylleprater': ('fylleprat',),
'fyllepratet': ('fylleprat',),
'fylleri': ('fylleri',),
'fylleria': ('fylleri',),
'fylleriene': ('fylleri',),
'fylleriet': ('fylleri',),
'fylleslagsmål': ('fylleslagsmål',),
'fylleslagsmåla': ('fylleslagsmål',),
'fylleslagsmålene': ('fylleslagsmål',),
'fylleslagsmålet': ('fylleslagsmål',),
'fyllest': ('fyllest',),
'fyllesten': ('fyllest',),
'fyllestene': ('fyllest',),
'fyllester': ('fyllest',),
'fyllik': ('fyllik',),
'fylliken': ('fyllik',),
'fyllikene': ('fyllik',),
'fylliker': ('fyllik',),
'fylling': ('fylling',),
'fyllinga': ('fylling',),
'fyllingen': ('fylling',),
'fyllingene': ('fylling',),
'fyllinger': ('fylling',),
'fyllingsdam': ('fyllingsdam',),
'fyllingsdammen': ('fyllingsdam',),
'fyllingsdammene': ('fyllingsdam',),
'fyllingsdammer': ('fyllingsdam',),
'fyllmasse': ('fyllmasse',),
'fyllmassen': ('fyllmasse',),
'fyllmassene': ('fyllmasse',),
'fyllmasser': ('fyllmasse',),
'fyllord': ('fyllord',),
'fyllorda': ('fyllord',),
'fyllordene': ('fyllord',),
'fyllordet': ('fyllord',),
'fylogenese': ('fylogenese',),
'fylogenesen': ('fylogenese',),
'fylogenesene': ('fylogenese',),
'fylogeneser': ('fylogenese',),
'fylogeni': ('fylogeni',),
'fylogenien': ('fylogeni',),
'fylogeniene': ('fylogeni',),
'fylogenier': ('fylogeni',),
'fynd': ('fynd',),
'fynda': ('fynd',),
'fynden': ('fynd',),
'fyndene': ('fynd',),
'fynder': ('fynd',),
'fyndet': ('fynd',),
'fyndord': ('fyndord',),
'fyndorda': ('fyndord',),
'fyndordene': ('fyndord',),
'fyndordet': ('fyndord',),
'fyndspråk': ('fyndspråk',),
'fyndspråka': ('fyndspråk',),
'fyndspråkene': ('fyndspråk',),
'fyndspråket': ('fyndspråk',),
'fyord': ('fyord',),
'fyorda': ('fyord',),
'fyordene': ('fyord',),
'fyordet': ('fyord',),
'fyr': ('fyr',),
'fyren': ('fyr',),
'fyrene': ('fyr',),
'fyrer': ('fyr',),
'fyr': ('fyr',),
'fyren': ('fyr',),
'fyrene': ('fyr',),
'fyrer': ('fyr',),
'fyr': ('fyr',),
'fyra': ('fyr',),
'fyrene': ('fyr',),
'fyret': ('fyr',),
'fyraben': ('fyraben',),
'fyrabenen': ('fyraben',),
'fyrabenene': ('fyraben',),
'fyrabener': ('fyraben',),
'fyrabend': ('fyrabend',),
'fyrabenden': ('fyrabend',),
'fyrabendene': ('fyrabend',),
'fyrabender': ('fyrabend',),
'fyrabendsarbeid': ('fyrabendsarbeid',),
'fyrabendsarbeida': ('fyrabendsarbeid',),
'fyrabendsarbeidene': ('fyrabendsarbeid',),
'fyrabendsarbeider': ('fyrabendsarbeid',),
'fyrabendsarbeidet': ('fyrabendsarbeid',),
'fyrabensarbeid': ('fyrabensarbeid',),
'fyrabensarbeida': ('fyrabensarbeid',),
'fyrabensarbeidene': ('fyrabensarbeid',),
'fyrabensarbeider': ('fyrabensarbeid',),
'fyrabensarbeidet': ('fyrabensarbeid',),
'fyrapparat': ('fyrapparat',),
'fyrapparata': ('fyrapparat',),
'fyrapparatene': ('fyrapparat',),
'fyrapparater': ('fyrapparat',),
'fyrapparatet': ('fyrapparat',),
'fyrblink': ('fyrblink',),
'fyrblinka': ('fyrblink',),
'fyrblinkene': ('fyrblink',),
'fyrblinket': ('fyrblink',),
'fyrbøter': ('fyrbøter',),
'fyrbøtere': ('fyrbøter',),
'fyrbøteren': ('fyrbøter',),
'fyrbøterer': ('fyrbøter',),
'fyrbøterne': ('fyrbøter',),
'fyring': ('fyring',),
'fyringa': ('fyring',),
'fyringen': ('fyring',),
'fyringene': ('fyring',),
'fyringer': ('fyring',),
'fyringsanlegg': ('fyringsanlegg',),
'fyringsanlegga': ('fyringsanlegg',),
'fyringsanleggene': ('fyringsanlegg',),
'fyringsanlegget': ('fyringsanlegg',),
'fyringsolja': ('fyringsolje',),
'fyringsolje': ('fyringsolje',),
'fyringsoljen': ('fyringsolje',),
'fyringsoljene': ('fyringsolje',),
'fyringsoljer': ('fyringsolje',),
'fyrlykt': ('fyrlykt',),
'fyrlykta': ('fyrlykt',),
'fyrlykten': ('fyrlykt',),
'fyrlyktene': ('fyrlykt',),
'fyrlykter': ('fyrlykt',),
'fyrlys': ('fyrlys',),
'fyrlysa': ('fyrlys',),
'fyrlysene': ('fyrlys',),
'fyrlyset': ('fyrlys',),
'fyrop': ('fyrop',),
'fyropa': ('fyrop',),
'fyropene': ('fyrop',),
'fyropet': ('fyrop',),
'fyrspett': ('fyrspett',),
'fyrspetta': ('fyrspett',),
'fyrspettene': ('fyrspett',),
'fyrspettet': ('fyrspett',),
'fyrst': ('fyrst',),
'fyrsten': ('fyrst',),
'fyrstene': ('fyrst',),
'fyrster': ('fyrst',),
'fyrste': ('fyrste',),
'fyrsten': ('fyrste',),
'fyrstene': ('fyrste',),
'fyrster': ('fyrste',),
'fyrstedømma': ('fyrstedømme',),
'fyrstedømme': ('fyrstedømme',),
'fyrstedømmene': ('fyrstedømme',),
'fyrstedømmer': ('fyrstedømme',),
'fyrstedømmet': ('fyrstedømme',),
'fyrstehus': ('fyrstehus',),
'fyrstehusa': ('fyrstehus',),
'fyrstehusene': ('fyrstehus',),
'fyrstehuset': ('fyrstehus',),
'fyrstekaka': ('fyrstekake',),
'fyrstekake': ('fyrstekake',),
'fyrstekaken': ('fyrstekake',),
'fyrstekakene': ('fyrstekake',),
'fyrstekaker': ('fyrstekake',),
'fyrstikk': ('fyrstikk',),
'fyrstikka': ('fyrstikk',),
'fyrstikken': ('fyrstikk',),
'fyrstikkene': ('fyrstikk',),
'fyrstikker': ('fyrstikk',),
'fyrstikka': ('fyrstikke',),
'fyrstikke': ('fyrstikke',),
'fyrstikken': ('fyrstikke',),
'fyrstikkene': ('fyrstikke',),
'fyrstikker': ('fyrstikke',),
'fyrstikkeska': ('fyrstikkeske',),
'fyrstikkeske': ('fyrstikkeske',),
'fyrstikkesken': ('fyrstikkeske',),
'fyrstikkeskene': ('fyrstikkeske',),
'fyrstikkesker': ('fyrstikkeske',),
'fyrstikkfabrikk': ('fyrstikkfabrikk',),
'fyrstikkfabrikken': ('fyrstikkfabrikk',),
'fyrstikkfabrikkene': ('fyrstikkfabrikk',),
'fyrstikkfabrikker': ('fyrstikkfabrikk',),
'fyrstinna': ('fyrstinne',),
'fyrstinne': ('fyrstinne',),
'fyrstinnen': ('fyrstinne',),
'fyrstinnene': ('fyrstinne',),
'fyrstinner': ('fyrstinne',),
'fyrstål': ('fyrstål',),
'fyrståla': ('fyrstål',),
'fyrstålene': ('fyrstål',),
'fyrstålet': ('fyrstål',),
'fyrtårn': ('fyrtårn',),
'fyrtårna': ('fyrtårn',),
'fyrtårnene': ('fyrtårn',),
'fyrtårnet': ('fyrtårn',),
'fyrtøy': ('fyrtøy',),
'fyrtøya': ('fyrtøy',),
'fyrtøyene': ('fyrtøy',),
'fyrtøyer': ('fyrtøy',),
'fyrtøyet': ('fyrtøy',),
'fyrverker': ('fyrverker',),
'fyrverkere': ('fyrverker',),
'fyrverkeren': ('fyrverker',),
'fyrverkerer': ('fyrverker',),
'fyrverkerne': ('fyrverker',),
'fyrverkeri': ('fyrverkeri',),
'fyrverkeria': ('fyrverkeri',),
'fyrverkeriene': ('fyrverkeri',),
'fyrverkerier': ('fyrverkeri',),
'fyrverkeriet': ('fyrverkeri',),
'fyrvesen': ('fyrvesen',),
'fyrvesena': ('fyrvesen',),
'fyrvesenene': ('fyrvesen',),
'fyrvesener': ('fyrvesen',),
'fyrvesenet': ('fyrvesen',),
'fyrvokter': ('fyrvokter',),
'fyrvoktere': ('fyrvokter',),
'fyrvokteren': ('fyrvokter',),
'fyrvokterer': ('fyrvokter',),
'fyrvokterne': ('fyrvokter',),
'fysak': ('fysak',),
'fysaken': ('fysak',),
'fysakene': ('fysak',),
'fysaker': ('fysak',),
'fysiker': ('fysiker',),
'fysikere': ('fysiker',),
'fysikeren': ('fysiker',),
'fysikerer': ('fysiker',),
'fysikerne': ('fysiker',),
'fysikk': ('fysikk',),
'fysikken': ('fysikk',),
'fysikkene': ('fysikk',),
'fysikker': ('fysikk',),
'fysikus': ('fysikus',),
'fysikusen': ('fysikus',),
'fysikusene': ('fysikus',),
'fysikuser': ('fysikus',),
'fysiognomi': ('fysiognomi',),
'fysiognomia': ('fysiognomi',),
'fysiognomien': ('fysiognomi',),
'fysiognomiene': ('fysiognomi',),
'fysiognomier': ('fysiognomi',),
'fysiognomiet': ('fysiognomi',),
'fysiokjemiker': ('fysiokjemiker',),
'fysiokjemikere': ('fysiokjemiker',),
'fysiokjemikeren': ('fysiokjemiker',),
'fysiokjemikerer': ('fysiokjemiker',),
'fysiokjemikerne': ('fysiokjemiker',),
'fysiokrati': ('fysiokrati',),
'fysiokratia': ('fysiokrati',),
'fysiokratiene': ('fysiokrati',),
'fysiokratiet': ('fysiokrati',),
'fysiolog': ('fysiolog',),
'fysiologen': ('fysiolog',),
'fysiologene': ('fysiolog',),
'fysiologer': ('fysiolog',),
'fysiologi': ('fysiologi',),
'fysiologien': ('fysiologi',),
'fysiologiene': ('fysiologi',),
'fysiologier': ('fysiologi',),
'fysioterapeut': ('fysioterapeut',),
'fysioterapeuten': ('fysioterapeut',),
'fysioterapeutene': ('fysioterapeut',),
'fysioterapeuter': ('fysioterapeut',),
'fysioterapi': ('fysioterapi',),
'fysioterapien': ('fysioterapi',),
'fysioterapiene': ('fysioterapi',),
'fysioterapier': ('fysioterapi',),
'fytotron': ('fytotron',),
'fytotronen': ('fytotron',),
'fytotronene': ('fytotron',),
'fytotroner': ('fytotron',),
'fåmannsstyra': ('fåmannsstyre',),
'fåmannsstyre': ('fåmannsstyre',),
'fåmannsstyrene': ('fåmannsstyre',),
'fåmannsstyrer': ('fåmannsstyre',),
'fåmannsstyret': ('fåmannsstyre',),
'fåmannsvelda': ('fåmannsvelde',),
'fåmannsvelde': ('fåmannsvelde',),
'fåmannsveldene': ('fåmannsvelde',),
'fåmannsvelder': ('fåmannsvelde',),
'fåmannsveldet': ('fåmannsvelde',),
'fånytta': ('fånytte',),
'fånytte': ('fånytte',),
'fånytten': ('fånytte',),
'fånyttene': ('fånytte',),
'fånytter': ('fånytte',),
'får': ('får',),
'fåra': ('får',),
'fårene': ('får',),
'fåret': ('får',),
'får': ('får',),
'fåra': ('får',),
'fåren': ('får',),
'fårene': ('får',),
'fårer': ('får',),
'fårehund': ('fårehund',),
'fårehunden': ('fårehund',),
'fårehundene': ('fårehund',),
'fårehunder': ('fårehund',),
'fåreklær': ('fåreklær',),
'fåreklærne': ('fåreklær',),
'fårekotelett': ('fårekotelett',),
'fårekoteletten': ('fårekotelett',),
'fårekotelettene': ('fårekotelett',),
'fårekoteletter': ('fårekotelett',),
'fårepølsa': ('fårepølse',),
'fårepølse': ('fårepølse',),
'fårepølsen': ('fårepølse',),
'fårepølsene': ('fårepølse',),
'fårepølser': ('fårepølse',),
'fåresteik': ('fåresteik',),
'fåresteika': ('fåresteik',),
'fåresteiken': ('fåresteik',),
'fåresteikene': ('fåresteik',),
'fåresteiker': ('fåresteik',),
'fårestek': ('fårestek',),
'fåresteka': ('fårestek',),
'fåresteken': ('fårestek',),
'fårestekene': ('fårestek',),
'fåresteker': ('fårestek',),
'fårikål': ('fårikål',),
'fårikålen': ('fårikål',),
'fårikålene': ('fårikål',),
'fårikåler': ('fårikål',),
'fåtal': ('fåtal',),
'fåtala': ('fåtal',),
'fåtalene': ('fåtal',),
'fåtalet': ('fåtal',),
'fåtall': ('fåtall',),
'fåtalla': ('fåtall',),
'fåtallene': ('fåtall',),
'fåtallet': ('fåtall',),
'fæla': ('fæle',),
'fæle': ('fæle',),
'fælen': ('fæle',),
'fælene': ('fæle',),
'fæler': ('fæle',),
'færing': ('færing',),
'færingen': ('færing',),
'færingene': ('færing',),
'færinger': ('færing',),
'færing': ('færing',),
'færingen': ('færing',),
'færingene': ('færing',),
'færinger': ('færing',),
'færøying': ('færøying',),
'færøyingen': ('færøying',),
'færøyingene': ('færøying',),
'færøyinger': ('færøying',),
'færøysk': ('færøysk',),
'færøysken': ('færøysk',),
'færøyskene': ('færøysk',),
'færøysker': ('færøysk',),
'føda': ('føde',),
'føde': ('føde',),
'føden': ('føde',),
'fødene': ('føde',),
'føder': ('føde',),
'fødeavdeling': ('fødeavdeling',),
'fødeavdelinga': ('fødeavdeling',),
'fødeavdelingen': ('fødeavdeling',),
'fødeavdelingene': ('fødeavdeling',),
'fødeavdelinger': ('fødeavdeling',),
'fødeby': ('fødeby',),
'fødebyen': ('fødeby',),
'fødebyene': ('fødeby',),
'fødebyer': ('fødeby',),
'fødebygd': ('fødebygd',),
'fødebygda': ('fødebygd',),
'fødebygden': ('fødebygd',),
'fødebygdene': ('fødebygd',),
'fødebygder': ('fødebygd',),
'fødeheim': ('fødeheim',),
'fødeheimen': ('fødeheim',),
'fødeheimene': ('fødeheim',),
'fødeheimer': ('fødeheim',),
'fødehjem': ('fødehjem',),
'fødehjemma': ('fødehjem',),
'fødehjemmene': ('fødehjem',),
'fødehjemmet': ('fødehjem',),
'fødeland': ('fødeland',),
'fødelanda': ('fødeland',),
'fødelandene': ('fødeland',),
'fødelandet': ('fødeland',),
'fødeledning': ('fødeledning',),
'fødeledninga': ('fødeledning',),
'fødeledningen': ('fødeledning',),
'fødeledningene': ('fødeledning',),
'fødeledninger': ('fødeledning',),
'fødemiddel': ('fødemiddel',),
'fødemiddelet': ('fødemiddel',),
'fødemidla': ('fødemiddel',),
'fødemidlene': ('fødemiddel',),
'fødemidler': ('fødemiddel',),
'fødemidlet': ('fødemiddel',),
'føderalisme': ('føderalisme',),
'føderalismen': ('føderalisme',),
'føderalismene': ('føderalisme',),
'føderalismer': ('føderalisme',),
'føderasjon': ('føderasjon',),
'føderasjonen': ('føderasjon',),
'føderasjonene': ('føderasjon',),
'føderasjoner': ('føderasjon',),
'føderåd': ('føderåd',),
'føderåda': ('føderåd',),
'føderådene': ('føderåd',),
'føderådet': ('føderåd',),
'føderådsbrev': ('føderådsbrev',),
'føderådsbreva': ('føderådsbrev',),
'føderådsbrevene': ('føderådsbrev',),
'føderådsbrever': ('føderådsbrev',),
'føderådsbrevet': ('føderådsbrev',),
'føderådsfolk': ('føderådsfolk',),
'føderådsfolka': ('føderådsfolk',),
'føderådsfolkene': ('føderådsfolk',),
'føderådsfolket': ('føderådsfolk',),
'fødested': ('fødested',),
'fødestedene': ('fødested',),
'fødesteder': ('fødested',),
'fødestedet': ('fødested',),
'fødestua': ('fødestue',),
'fødestue': ('fødestue',),
'fødestuen': ('fødestue',),
'fødestuene': ('fødestue',),
'fødestuer': ('fødestue',),
'fødsel': ('fødsel',),
'fødselen': ('fødsel',),
'fødslene': ('fødsel',),
'fødsler': ('fødsel',),
'fødselsattest': ('fødselsattest',),
'fødselsattesten': ('fødselsattest',),
'fødselsattestene': ('fødselsattest',),
'fødselsattester': ('fødselsattest',),
'fødselsdag': ('fødselsdag',),
'fødselsdagen': ('fødselsdag',),
'fødselsdagene': ('fødselsdag',),
'fødselsdager': ('fødselsdag',),
'fødselsdagsselskap': ('fødselsdagsselskap',),
'fødselsdagsselskapa': ('fødselsdagsselskap',),
'fødselsdagsselskapene': ('fødselsdagsselskap',),
'fødselsdagsselskaper': ('fødselsdagsselskap',),
'fødselsdagsselskapet': ('fødselsdagsselskap',),
'fødselshjelp': ('fødselshjelp',),
'fødselshjelpa': ('fødselshjelp',),
'fødselshjelpen': ('fødselshjelp',),
'fødselshjelpene': ('fødselshjelp',),
'fødselshjelper': ('fødselshjelp',),
'fødselshjelper': ('fødselshjelper',),
'fødselshjelpere': ('fødselshjelper',),
'fødselshjelperen': ('fødselshjelper',),
'fødselshjelperer': ('fødselshjelper',),
'fødselshjelperne': ('fødselshjelper',),
'fødselshyppighet': ('fødselshyppighet',),
'fødselshyppigheta': ('fødselshyppighet',),
'fødselshyppigheten': ('fødselshyppighet',),
'fødselshyppighetene': ('fødselshyppighet',),
'fødselshyppigheter': ('fødselshyppighet',),
'fødselsklinikk': ('fødselsklinikk',),
'fødselsklinikken': ('fødselsklinikk',),
'fødselsklinikkene': ('fødselsklinikk',),
'fødselsklinikker': ('fødselsklinikk',),
'fødselskontroll': ('fødselskontroll',),
'fødselskontrollen': ('fødselskontroll',),
'fødselskontrollene': ('fødselskontroll',),
'fødselskontroller': ('fødselskontroll',),
'fødselsnummer': ('fødselsnummer',),
'fødselsnummeret': ('fødselsnummer',),
'fødselsnumra': ('fødselsnummer',),
'fødselsnumre': ('fødselsnummer',),
'fødselsnumrene': ('fødselsnummer',),
'fødselsoverskott': ('fødselsoverskott',),
'fødselsoverskotta': ('fødselsoverskott',),
'fødselsoverskottene': ('fødselsoverskott',),
'fødselsoverskottet': ('fødselsoverskott',),
'fødselsoverskudd': ('fødselsoverskudd',),
'fødselsoverskudda': ('fødselsoverskudd',),
'fødselsoverskuddene': ('fødselsoverskudd',),
'fødselsoverskuddet': ('fødselsoverskudd',),
'fødselspengene': ('fødselspenger',),
'fødselspenger': ('fødselspenger',),
'fødselsregister': ('fødselsregister',),
'fødselsregisteret': ('fødselsregister',),
'fødselsregistra': ('fødselsregister',),
'fødselsregistre': ('fødselsregister',),
'fødselsregistrene': ('fødselsregister',),
'fødselsregistret': ('fødselsregister',),
'fødselsri': ('fødselsri',),
'fødselsria': ('fødselsri',),
'fødselsrien': ('fødselsri',),
'fødselsriene': ('fødselsri',),
'fødselsrier': ('fødselsri',),
'fødselstal': ('fødselstal',),
'fødselstala': ('fødselstal',),
'fødselstalene': ('fødselstal',),
'fødselstalet': ('fødselstal',),
'fødselstall': ('fødselstall',),
'fødselstalla': ('fødselstall',),
'fødselstallene': ('fødselstall',),
'fødselstallet': ('fødselstall',),
'fødselsve': ('fødselsve',),
'fødselsveen': ('fødselsve',),
'fødselsveene': ('fødselsve',),
'fødselsveer': ('fødselsve',),
'fødselsår': ('fødselsår',),
'fødselsåra': ('fødselsår',),
'fødselsårene': ('fødselsår',),
'fødselsåret': ('fødselsår',),
'føflekk': ('føflekk',),
'føflekken': ('føflekk',),
'føflekkene': ('føflekk',),
'føflekker': ('føflekk',),
'føl': ('føl',),
'føla': ('føl',),
'følene': ('føl',),
'følet': ('føl',),
'føl': ('føl',),
'føla': ('føl',),
'følene': ('føl',),
'følet': ('føl',),
'følehorn': ('følehorn',),
'følehorna': ('følehorn',),
'følehornene': ('følehorn',),
'følehornet': ('følehorn',),
'følelse': ('følelse',),
'følelsen': ('følelse',),
'følelsene': ('følelse',),
'følelser': ('følelse',),
'følelsesinntrykk': ('følelsesinntrykk',),
'følelsesinntrykka': ('følelsesinntrykk',),
'følelsesinntrykkene': ('følelsesinntrykk',),
'følelsesinntrykket': ('følelsesinntrykk',),
'følelseskulda': ('følelseskulde',),
'følelseskulde': ('følelseskulde',),
'følelseskulden': ('følelseskulde',),
'følelseskuldene': ('følelseskulde',),
'følelseskulder': ('følelseskulde',),
'følelsesliv': ('følelsesliv',),
'følelsesliva': ('følelsesliv',),
'følelseslivene': ('følelsesliv',),
'følelseslivet': ('følelsesliv',),
'følelsesmenneska': ('følelsesmenneske',),
'følelsesmenneske': ('følelsesmenneske',),
'følelsesmenneskene': ('følelsesmenneske',),
'følelsesmennesker': ('følelsesmenneske',),
'følelsesmennesket': ('følelsesmenneske',),
'følelsessak': ('følelsessak',),
'følelsessaka': ('følelsessak',),
'følelsessaken': ('følelsessak',),
'følelsessakene': ('følelsessak',),
'følelsessaker': ('følelsessak',),
'følelsesutbrott': ('følelsesutbrott',),
'følelsesutbrotta': ('følelsesutbrott',),
'følelsesutbrottene': ('følelsesutbrott',),
'følelsesutbrottet': ('følelsesutbrott',),
'følelsesutbrudd': ('følelsesutbrudd',),
'følelsesutbrudda': ('følelsesutbrudd',),
'følelsesutbruddene': ('følelsesutbrudd',),
'følelsesutbruddet': ('følelsesutbrudd',),
'følelsesuttrykk': ('følelsesuttrykk',),
'følelsesuttrykka': ('følelsesuttrykk',),
'følelsesuttrykkene': ('følelsesuttrykk',),
'følelsesuttrykket': ('følelsesuttrykk',),
'føler': ('føler',),
'følere': ('føler',),
'føleren': ('føler',),
'følerer': ('føler',),
'følerne': ('føler',),
'føleri': ('føleri',),
'føleria': ('føleri',),
'føleriene': ('føleri',),
'følerier': ('føleri',),
'føleriet': ('føleri',),
'følesans': ('følesans',),
'følesansen': ('følesans',),
'følesansene': ('følesans',),
'følesanser': ('følesans',),
'følesentra': ('følesentrum',),
'følesentraene': ('følesentrum',),
'følesentre': ('følesentrum',),
'følesentrene': ('følesentrum',),
'følesentret': ('følesentrum',),
'følesentrum': ('følesentrum',),
'følesentrumet': ('følesentrum',),
'følga': ('følge',),
'følge': ('følge',),
'følgen': ('følge',),
'følgene': ('følge',),
'følger': ('følge',),
'følga': ('følge',),
'følge': ('følge',),
'følgene': ('følge',),
'følger': ('følge',),
'følget': ('følge',),
'følga': ('følge',),
'følge': ('følge',),
'følgene': ('følge',),
'følger': ('følge',),
'følget': ('følge',),
'følgebrev': ('følgebrev',),
'følgebreva': ('følgebrev',),
'følgebrevene': ('følgebrev',),
'følgebrever': ('følgebrev',),
'følgebrevet': ('følgebrev',),
'følgekonjunksjon': ('følgekonjunksjon',),
'følgekonjunksjonen': ('følgekonjunksjon',),
'følgekonjunksjonene': ('følgekonjunksjon',),
'følgekonjunksjoner': ('følgekonjunksjon',),
'følgeseddel': ('følgeseddel',),
'følgeseddelen': ('følgeseddel',),
'følgesedlene': ('følgeseddel',),
'følgesedler': ('følgeseddel',),
'følgeseddel': ('følgeseddel',),
'følgeseddelen': ('følgeseddel',),
'følgesedlene': ('følgeseddel',),
'følgesedler': ('følgeseddel',),
'følgesetning': ('følgesetning',),
'følgesetninga': ('følgesetning',),
'følgesetningen': ('følgesetning',),
'følgesetningene': ('følgesetning',),
'følgesetninger': ('følgesetning',),
'følgeskriv': ('følgeskriv',),
'følgeskriva': ('følgeskriv',),
'følgeskrivene': ('følgeskriv',),
'følgeskrivet': ('følgeskriv',),
'følgeskriv': ('følgeskriv',),
'følgeskriva': ('følgeskriv',),
'følgeskrivene': ('følgeskriv',),
'følgeskrivet': ('følgeskriv',),
'følgestreng': ('følgestreng',),
'følgestrengen': ('følgestreng',),
'følgestrengene': ('følgestreng',),
'følgestrenger': ('følgestreng',),
'følgesvenn': ('følgesvenn',),
'følgesvennen': ('følgesvenn',),
'følgesvennene': ('følgesvenn',),
'følgesvenner': ('følgesvenn',),
'følgesvenn': ('følgesvenn',),
'følgesvennen': ('følgesvenn',),
'følgesvennene': ('følgesvenn',),
'følgesvenner': ('følgesvenn',),
'følgeånd': ('følgeånd',),
'følgeånden': ('følgeånd',),
'følgeåndene': ('følgeånd',),
'følgeånder': ('følgeånd',),
'følgesånd': ('følgesånd',),
'følgesånden': ('følgesånd',),
'følgesåndene': ('følgesånd',),
'følgesånder': ('følgesånd',),
'følging': ('følging',),
'følginga': ('følging',),
'følgingen': ('følging',),
'følgingene': ('følging',),
'følginger': ('følging',),
'følgja': ('følgje',),
'følgje': ('følgje',),
'følgjene': ('følgje',),
'følgjer': ('følgje',),
'følgjet': ('følgje',),
'følgja': ('følgje',),
'følgje': ('følgje',),
'følgjene': ('følgje',),
'følgjer': ('følgje',),
'følgjet': ('følgje',),
'følgja': ('følgje',),
'følgje': ('følgje',),
'følgjen': ('følgje',),
'følgjene': ('følgje',),
'følgjer': ('følgje',),
'følgjebrev': ('følgjebrev',),
'følgjebreva': ('følgjebrev',),
'følgjebrevene': ('følgjebrev',),
'følgjebrever': ('følgjebrev',),
'følgjebrevet': ('følgjebrev',),
'følgjeseddel': ('følgjeseddel',),
'følgjeseddelen': ('følgjeseddel',),
'følgjesedlene': ('følgjeseddel',),
'følgjesedler': ('følgjeseddel',),
'følgjeseddel': ('følgjeseddel',),
'følgjeseddelen': ('følgjeseddel',),
'følgjesedlene': ('følgjeseddel',),
'følgjesedler': ('følgjeseddel',),
'følgjeskriv': ('følgjeskriv',),
'følgjeskriva': ('følgjeskriv',),
'følgjeskrivene': ('følgjeskriv',),
'følgjeskrivet': ('følgjeskriv',),
'følgjeskriv': ('følgjeskriv',),
'følgjeskriva': ('følgjeskriv',),
'følgjeskrivene': ('følgjeskriv',),
'følgjeskrivet': ('følgjeskriv',),
'følgjesvenn': ('følgjesvenn',),
'følgjesvennen': ('følgjesvenn',),
'følgjesvennene': ('følgjesvenn',),
'følgjesvenner': ('følgjesvenn',),
'følgjesvenn': ('følgjesvenn',),
'følgjesvennen': ('følgjesvenn',),
'følgjesvennene': ('følgjesvenn',),
'følgjesvenner': ('følgjesvenn',),
'følgjeånd': ('følgjeånd',),
'følgjeånden': ('følgjeånd',),
'følgjeåndene': ('følgjeånd',),
'følgjeånder': ('følgjeånd',),
'følgjesånd': ('følgjesånd',),
'følgjesånden': ('følgjesånd',),
'følgjesåndene': ('følgjesånd',),
'følgjesånder': ('følgjesånd',),
'føling': ('føling',),
'følinga': ('føling',),
'følingen': ('føling',),
'følingene': ('føling',),
'følinger': ('føling',),
'føljetong': ('føljetong',),
'føljetongen': ('føljetong',),
'føljetongene': ('føljetong',),
'føljetonger': ('føljetong',),
'føljetongforfatter': ('føljetongforfatter',),
'føljetongforfattere': ('føljetongforfatter',),
'føljetongforfatteren': ('føljetongforfatter',),
'føljetongforfatterer': ('føljetongforfatter',),
'føljetongforfatterne': ('føljetongforfatter',),
'føljetongroman': ('føljetongroman',),
'føljetongromanen': ('føljetongroman',),
'føljetongromanene': ('føljetongroman',),
'føljetongromaner': ('føljetongroman',),
'føll': ('føll',),
'følla': ('føll',),
'føllene': ('føll',),
'føllet': ('føll',),
'føll': ('føll',),
'følla': ('føll',),
'føllene': ('føll',),
'føllet': ('føll',),
'følsomhet': ('følsomhet',),
'følsomheta': ('følsomhet',),
'følsomheten': ('følsomhet',),
'følsomhetene': ('følsomhet',),
'følsomheter': ('følsomhet',),
'føn': ('føn',),
'fønen': ('føn',),
'fønene': ('føn',),
'føner': ('føn',),
'føneapparat': ('føneapparat',),
'føneapparata': ('føneapparat',),
'føneapparatene': ('føneapparat',),
'føneapparater': ('føneapparat',),
'føneapparatet': ('føneapparat',),
'føner': ('føner',),
'fønere': ('føner',),
'føneren': ('føner',),
'fønerer': ('føner',),
'fønerne': ('føner',),
'føniks': ('føniks',),
'føniksen': ('føniks',),
'føniksene': ('føniks',),
'fønikser': ('føniks',),
'fønvind': ('fønvind',),
'fønvinden': ('fønvind',),
'fønvindene': ('fønvind',),
'fønvinder': ('fønvind',),
'føra': ('føre',),
'føre': ('føre',),
'førene': ('føre',),
'fører': ('føre',),
'føret': ('føre',),
'føredøma': ('føredøme',),
'føredøme': ('føredøme',),
'føredømene': ('føredøme',),
'føredømer': ('føredøme',),
'føredømet': ('føredøme',),
'førefall': ('førefall',),
'førefalla': ('førefall',),
'førefallene': ('førefall',),
'førefallet': ('førefall',),
'føreforhold': ('føreforhold',),
'føreforholda': ('føreforhold',),
'føreforholdene': ('føreforhold',),
'føreforholdet': ('føreforhold',),
'førehand': ('førehand',),
'førejulsvinter': ('førejulsvinter',),
'førejulsvintere': ('førejulsvinter',),
'førejulsvinteren': ('førejulsvinter',),
'førejulsvinterne': ('førejulsvinter',),
'førejulsvintre': ('førejulsvinter',),
'førejulsvintrene': ('førejulsvinter',),
'førejulsvintrer': ('førejulsvinter',),
'førejulsvinter': ('førejulsvinter',),
'førejulsvintere': ('førejulsvinter',),
'førejulsvinteren': ('førejulsvinter',),
'førejulsvinterne': ('førejulsvinter',),
'førejulsvintre': ('førejulsvinter',),
'førejulsvintrene': ('førejulsvinter',),
'førejulsvintrer': ('førejulsvinter',),
'fører': ('fører',),
'førere': ('fører',),
'føreren': ('fører',),
'førerer': ('fører',),
'førerne': ('fører',),
'førerhund': ('førerhund',),
'førerhunden': ('førerhund',),
'førerhundene': ('førerhund',),
'førerhunder': ('førerhund',),
'førerhus': ('førerhus',),
'førerhusa': ('førerhus',),
'førerhusene': ('førerhus',),
'førerhuset': ('førerhus',),
'førerkort': ('førerkort',),
'førerkorta': ('førerkort',),
'førerkortene': ('førerkort',),
'førerkortet': ('førerkort',),
'førerprøva': ('førerprøve',),
'førerprøve': ('førerprøve',),
'førerprøven': ('førerprøve',),
'førerprøvene': ('førerprøve',),
'førerprøver': ('førerprøve',),
'førerskikkelse': ('førerskikkelse',),
'førerskikkelsen': ('førerskikkelse',),
'førerskikkelsene': ('førerskikkelse',),
'førerskikkelser': ('førerskikkelse',),
'førerstilling': ('førerstilling',),
'førerstillinga': ('førerstilling',),
'førerstillingen': ('førerstilling',),
'førerstillingene': ('førerstilling',),
'førerstillinger': ('førerstilling',),
'føresegn': ('føresegn',),
'føresegna': ('føresegn',),
'føresegnen': ('føresegn',),
'føresegnene': ('føresegn',),
'føresegner': ('føresegn',),
'førfortid': ('førfortid',),
'førfortida': ('førfortid',),
'førfortiden': ('førfortid',),
'førfortidene': ('førfortid',),
'førfortider': ('førfortid',),
'førframtid': ('førframtid',),
'førframtida': ('førframtid',),
'førframtiden': ('førframtid',),
'førframtidene': ('førframtid',),
'førframtider': ('førframtid',),
'førfremtid': ('førfremtid',),
'førfremtida': ('førfremtid',),
'førfremtiden': ('førfremtid',),
'førfremtidene': ('førfremtid',),
'førfremtider': ('førfremtid',),
'førhistoria': ('førhistorie',),
'førhistorie': ('førhistorie',),
'førhistorien': ('førhistorie',),
'førhistoriene': ('førhistorie',),
'førhistorier': ('førhistorie',),
'føring': ('føring',),
'føringa': ('føring',),
'føringen': ('føring',),
'føringene': ('føring',),
'føringer': ('føring',),
'førjulsvinter': ('førjulsvinter',),
'førjulsvintere': ('førjulsvinter',),
'førjulsvinteren': ('førjulsvinter',),
'førjulsvinterne': ('førjulsvinter',),
'førjulsvintre': ('førjulsvinter',),
'førjulsvintrene': ('førjulsvinter',),
'førjulsvintrer': ('førjulsvinter',),
'førkja': ('førkje',),
'førkje': ('førkje',),
'førkjen': ('førkje',),
'førkjene': ('førkje',),
'førkjer': ('førkje',),
'førkjeunge': ('førkjeunge',),
'førkjeungen': ('førkjeunge',),
'førkjeungene': ('førkjeunge',),
'førkjeunger': ('førkjeunge',),
'førkrigstid': ('førkrigstid',),
'førkrigstida': ('førkrigstid',),
'førkrigstiden': ('førkrigstid',),
'førkrigstidene': ('førkrigstid',),
'førkrigstider': ('førkrigstid',),
'førlighet': ('førlighet',),
'førligheta': ('førlighet',),
'førligheten': ('førlighet',),
'førlighetene': ('førlighet',),
'førligheter': ('førlighet',),
'førnåtid': ('førnåtid',),
'førnåtida': ('førnåtid',),
'førnåtiden': ('førnåtid',),
'førnåtidene': ('førnåtid',),
'førnåtider': ('førnåtid',),
'førpremiere': ('førpremiere',),
'førpremieren': ('førpremiere',),
'førpremierene': ('førpremiere',),
'førpremierer': ('førpremiere',),
'førsel': ('førsel',),
'førselen': ('førsel',),
'førslene': ('førsel',),
'førsler': ('førsel',),
'førselsskip': ('førselsskip',),
'førselsskipa': ('førselsskip',),
'førselsskipene': ('førselsskip',),
'førselsskipet': ('førselsskip',),
'førselsveg': ('førselsveg',),
'førselsvegen': ('førselsveg',),
'førselsvegene': ('førselsveg',),
'førselsveger': ('førselsveg',),
'førselsvei': ('førselsvei',),
'førselsveien': ('førselsvei',),
'førselsveiene': ('førselsvei',),
'førselsveier': ('førselsvei',),
'førskole': ('førskole',),
'førskolen': ('førskole',),
'førskolene': ('førskole',),
'førskoler': ('førskole',),
'førskolealder': ('førskolealder',),
'førskolealdere': ('førskolealder',),
'førskolealderen': ('førskolealder',),
'førskolealderer': ('førskolealder',),
'førskolealderne': ('førskolealder',),
'førskolealdre': ('førskolealder',),
'førskolealdrene': ('førskolealder',),
'førskolealdrer': ('førskolealder',),
'førskolelærer': ('førskolelærer',),
'førskolelærere': ('førskolelærer',),
'førskolelæreren': ('førskolelærer',),
'førskolelærerer': ('førskolelærer',),
'førskolelærerne': ('førskolelærer',),
'førsteamanuens': ('førsteamanuens',),
'førsteamanuensen': ('førsteamanuens',),
'førsteamanuensene': ('førsteamanuens',),
'førsteamanuenser': ('førsteamanuens',),
'førsteamanuensen': ('førsteamanuensis',),
'førsteamanuensene': ('førsteamanuensis',),
'førsteamanuenser': ('førsteamanuensis',),
'førsteamanuensis': ('førsteamanuensis',),
'førstebetjent': ('førstebetjent',),
'førstebetjenten': ('førstebetjent',),
'førstebetjentene': ('førstebetjent',),
'førstebetjenter': ('førstebetjent',),
'førstedag': ('førstedag',),
'førstedagen': ('førstedag',),
'førstedagene': ('førstedag',),
'førstedager': ('førstedag',),
'førstedagsbrev': ('førstedagsbrev',),
'førstedagsbreva': ('førstedagsbrev',),
'førstedagsbrevene': ('førstedagsbrev',),
'førstedagsbrever': ('førstedagsbrev',),
'førstedagsbrevet': ('førstedagsbrev',),
'førstedagsstempel': ('førstedagsstempel',),
'førstedagsstempelet': ('førstedagsstempel',),
'førstedagsstempla': ('førstedagsstempel',),
'førstedagsstemplene': ('førstedagsstempel',),
'førstedagsstempler': ('førstedagsstempel',),
'førstedagsstemplet': ('førstedagsstempel',),
'førsteelsker': ('førsteelsker',),
'førsteelskere': ('førsteelsker',),
'førsteelskeren': ('førsteelsker',),
'førsteelskerer': ('førsteelsker',),
'førsteelskerne': ('førsteelsker',),
'førstefiolin': ('førstefiolin',),
'førstefiolinen': ('førstefiolin',),
'førstefiolinene': ('førstefiolin',),
'førstefioliner': ('førstefiolin',),
'førstefødselsrett': ('førstefødselsrett',),
'førstefødselsretten': ('førstefødselsrett',),
'førstefødselsrettene': ('førstefødselsrett',),
'førstefødselsretter': ('førstefødselsrett',),
'førstegangstjeneste': ('førstegangstjeneste',),
'førstegangstjenesten': ('førstegangstjeneste',),
'førstegangstjenestene': ('førstegangstjeneste',),
'førstegangstjenester': ('førstegangstjeneste',),
'førstegangsvelger': ('førstegangsvelger',),
'førstegangsvelgere': ('førstegangsvelger',),
'førstegangsvelgeren': ('førstegangsvelger',),
'førstegangsvelgerer': ('førstegangsvelger',),
'førstegangsvelgerne': ('førstegangsvelger',),
'førstegir': ('førstegir',),
'førstegira': ('førstegir',),
'førstegirene': ('førstegir',),
'førstegiret': ('førstegir',),
'førstegradsligning': ('førstegradsligning',),
'førstegradsligninga': ('førstegradsligning',),
'førstegradsligningen': ('førstegradsligning',),
'førstegradsligningene': ('førstegradsligning',),
'førstegradsligninger': ('førstegradsligning',),
'førstegradslikning': ('førstegradslikning',),
'førstegradslikninga': ('førstegradslikning',),
'førstegradslikningen': ('førstegradslikning',),
'førstegradslikningene': ('førstegradslikning',),
'førstegradslikninger': ('førstegradslikning',),
'førstegrøda': ('førstegrøde',),
'førstegrøde': ('førstegrøde',),
'førstegrøden': ('førstegrøde',),
'førstegrødene': ('førstegrøde',),
'førstegrøder': ('førstegrøde',),
'førstehandsverdi': ('førstehandsverdi',),
'førstehandsverdien': ('førstehandsverdi',),
'førstehandsverdiene': ('førstehandsverdi',),
'førstehandsverdier': ('førstehandsverdi',),
'førstehjelp': ('førstehjelp',),
'førstehjelpa': ('førstehjelp',),
'førstehjelpen': ('førstehjelp',),
'førstehjelpene': ('førstehjelp',),
'førstehjelper': ('førstehjelp',),
'førstehjelpskurs': ('førstehjelpskurs',),
'førstehjelpskursa': ('førstehjelpskurs',),
'førstehjelpskursene': ('førstehjelpskurs',),
'førstehjelpskurser': ('førstehjelpskurs',),
'førstehjelpskurset': ('førstehjelpskurs',),
'førstehjelpskursene': ('førstehjelpskursus',),
'førstehjelpskurser': ('førstehjelpskursus',),
'førstehjelpskursus': ('førstehjelpskursus',),
'førstehjelpskursuset': ('førstehjelpskursus',),
'førstehjelpsutstyr': ('førstehjelpsutstyr',),
'førstehjelpsutstyra': ('førstehjelpsutstyr',),
'førstehjelpsutstyrene': ('førstehjelpsutstyr',),
'førstehjelpsutstyret': ('førstehjelpsutstyr',),
'førstehåndsverdi': ('førstehåndsverdi',),
'førstehåndsverdien': ('førstehåndsverdi',),
'førstehåndsverdiene': ('førstehåndsverdi',),
'førstehåndsverdier': ('førstehåndsverdi',),
'førsteinntrykk': ('førsteinntrykk',),
'førsteinntrykka': ('førsteinntrykk',),
'førsteinntrykkene': ('førsteinntrykk',),
'førsteinntrykket': ('førsteinntrykk',),
'førstekonsulent': ('førstekonsulent',),
'førstekonsulenten': ('førstekonsulent',),
'førstekonsulentene': ('førstekonsulent',),
'førstekonsulenter': ('førstekonsulent',),
'førstelærer': ('førstelærer',),
'førstelærere': ('førstelærer',),
'førstelæreren': ('førstelærer',),
'førstelærerer': ('førstelærer',),
'førstelærerne': ('førstelærer',),
'førstemaidemonstrasjon': ('førstemaidemonstrasjon',),
'førstemaidemonstrasjonen': ('førstemaidemonstrasjon',),
'førstemaidemonstrasjonene': ('førstemaidemonstrasjon',),
'førstemaidemonstrasjoner': ('førstemaidemonstrasjon',),
'førstemaitog': ('førstemaitog',),
'førstemaitoga': ('førstemaitog',),
'førstemaitogene': ('førstemaitog',),
'førstemaitoget': ('førstemaitog',),
'førstemann': ('førstemann',),
'førstemannen': ('førstemann',),
'førstemannene': ('førstemann',),
'førstemanner': ('førstemann',),
'førsten': ('førsten',),
'førsteoppførelse': ('førsteoppførelse',),
'førsteoppførelsen': ('førsteoppførelse',),
'førsteoppførelsene': ('førsteoppførelse',),
'førsteoppførelser': ('førsteoppførelse',),
'førsteplass': ('førsteplass',),
'førsteplassen': ('førsteplass',),
'førsteplassene': ('førsteplass',),
'førsteplasser': ('førsteplass',),
'førstepremie': ('førstepremie',),
'førstepremien': ('førstepremie',),
'førstepremiene': ('førstepremie',),
'førstepremier': ('førstepremie',),
'førsteprioritet': ('førsteprioritet',),
'førsteprioriteten': ('førsteprioritet',),
'førsteprioritetene': ('førsteprioritet',),
'førsteprioriteter': ('førsteprioritet',),
'førsteprioritetslån': ('førsteprioritetslån',),
'førsteprioritetslåna': ('førsteprioritetslån',),
'førsteprioritetslånene': ('førsteprioritetslån',),
'førsteprioritetslånet': ('førsteprioritetslån',),
'førstereis': ('førstereis',),
'førstereisa': ('førstereis',),
'førstereisen': ('førstereis',),
'førstereisene': ('førstereis',),
'førstereiser': ('førstereis',),
'førstereisgutt': ('førstereisgutt',),
'førstereisgutten': ('førstereisgutt',),
'førstereisguttene': ('førstereisgutt',),
'førstereisgutter': ('førstereisgutt',),
'førstesida': ('førsteside',),
'førsteside': ('førsteside',),
'førstesiden': ('førsteside',),
'førstesidene': ('førsteside',),
'førstesider': ('førsteside',),
'førstesideoppslag': ('førstesideoppslag',),
'førstesideoppslaga': ('førstesideoppslag',),
'førstesideoppslagene': ('førstesideoppslag',),
'førstesideoppslaget': ('førstesideoppslag',),
'førstesidestoff': ('førstesidestoff',),
'førstesidestoffa': ('førstesidestoff',),
'førstesidestoffene': ('førstesidestoff',),
'førstesidestoffet': ('førstesidestoff',),
'førstestyrmann': ('førstestyrmann',),
'førstestyrmannen': ('førstestyrmann',),
'førstestyrmenn': ('førstestyrmann',),
'førstestyrmennene': ('førstestyrmann',),
'førsteutgava': ('førsteutgave',),
'førsteutgave': ('førsteutgave',),
'førsteutgaven': ('førsteutgave',),
'førsteutgavene': ('førsteutgave',),
'førsteutgaver': ('førsteutgave',),
'førstning': ('førstning',),
'førstninga': ('førstning',),
'førstningen': ('førstning',),
'førstningene': ('førstning',),
'førstninger': ('førstning',),
'førstvoterende': ('førstvoterende',),
'førtidel': ('førtidel',),
'førtidelen': ('førtidel',),
'førtidelene': ('førtidel',),
'førtideler': ('førtidel',),
'førtidspensjon': ('førtidspensjon',),
'førtidspensjonen': ('førtidspensjon',),
'førtidspensjonene': ('førtidspensjon',),
'førtidspensjoner': ('førtidspensjon',),
'førtiår': ('førtiår',),
'førtiåra': ('førtiår',),
'førtiårene': ('førtiår',),
'førtiåret': ('førtiår',),
'føydalisme': ('føydalisme',),
'føydalismen': ('føydalisme',),
'føydalismene': ('føydalisme',),
'føydalismer': ('føydalisme',),
'føye': ('føye',),
'føyk': ('føyk',),
'føyken': ('føyk',),
'føykene': ('føyk',),
'føyker': ('føyk',),
'føyka': ('føyke',),
'føyke': ('føyke',),
'føyken': ('føyke',),
'føykene': ('føyke',),
'føyker': ('føyke',),
'g': ('g',),
'g\'en': ('g',),
'g-en': ('g',),
'g-ene': ('g',),
'g-er': ('g',),
'gêne': ('gêne',),
'gênen': ('gêne',),
'gênene': ('gêne',),
'gêner': ('gêne',),
'g-moll': ('g-moll',),
'g-mollen': ('g-moll',),
'g-mollene': ('g-moll',),
'g-moller': ('g-moll',),
'g-nøkkel': ('g-nøkkel',),
'g-nøkkelen': ('g-nøkkel',),
'g-nøklene': ('g-nøkkel',),
'g-nøkler': ('g-nøkkel',),
'gabardin': ('gabardin',),
'gabardinen': ('gabardin',),
'gabardinene': ('gabardin',),
'gabardiner': ('gabardin',),
'gabbro': ('gabbro',),
'gabbroen': ('gabbro',),
'gabbroene': ('gabbro',),
'gabbroer': ('gabbro',),
'gaboner': ('gaboner',),
'gabonere': ('gaboner',),
'gaboneren': ('gaboner',),
'gabonerer': ('gaboner',),
'gabonerne': ('gaboner',),
'gadd': ('gadd',),
'gadden': ('gadd',),
'gaddene': ('gadd',),
'gadder': ('gadd',),
'gaddfuru': ('gaddfuru',),
'gaddfurua': ('gaddfuru',),
'gaddfuruen': ('gaddfuru',),
'gaddfuruene': ('gaddfuru',),
'gaddfuruer': ('gaddfuru',),
'gadolinium': ('gadolinium',),
'gadoliniuma': ('gadolinium',),
'gadoliniumene': ('gadolinium',),
'gadoliniumet': ('gadolinium',),
'gaffel': ('gaffel',),
'gaffelen': ('gaffel',),
'gaflene': ('gaffel',),
'gafler': ('gaffel',),
'gaffelbitene': ('gaffelbiter',),
'gaffelbiter': ('gaffelbiter',),
'gaffelgreining': ('gaffelgreining',),
'gaffelgreininga': ('gaffelgreining',),
'gaffelgreiningen': ('gaffelgreining',),
'gaffelgreiningene': ('gaffelgreining',),
'gaffelgreininger': ('gaffelgreining',),
'gaffelgrening': ('gaffelgrening',),
'gaffelgreninga': ('gaffelgrening',),
'gaffelgreningen': ('gaffelgrening',),
'gaffelgreningene': ('gaffelgrening',),
'gaffelgreninger': ('gaffelgrening',),
'gaffelsegl': ('gaffelsegl',),
'gaffelsegla': ('gaffelsegl',),
'gaffelseglene': ('gaffelsegl',),
'gaffelseglet': ('gaffelsegl',),
'gaffelseil': ('gaffelseil',),
'gaffelseila': ('gaffelseil',),
'gaffelseilene': ('gaffelseil',),
'gaffelseilet': ('gaffelseil',),
'gaffeltruck': ('gaffeltruck',),
'gaffeltrucken': ('gaffeltruck',),
'gaffeltruckene': ('gaffeltruck',),
'gaffeltrucker': ('gaffeltruck',),
'gafling': ('gafling',),
'gaflinga': ('gafling',),
'gaflingen': ('gafling',),
'gaflingene': ('gafling',),
'gaflinger': ('gafling',),
'gag': ('gag',),
'gagen': ('gag',),
'gagene': ('gag',),
'gager': ('gag',),
'gagn': ('gagn',),
'gagna': ('gagn',),
'gagnene': ('gagn',),
'gagnet': ('gagn',),
'gakkgakk': ('gakkgakk',),
'gakkgakken': ('gakkgakk',),
'gakkgakkene': ('gakkgakk',),
'gakkgakker': ('gakkgakk',),
'gal': ('gal',),
'gala': ('gal',),
'galene': ('gal',),
'galet': ('gal',),
'galakse': ('galakse',),
'galaksen': ('galakse',),
'galaksene': ('galakse',),
'galakser': ('galakse',),
'galanteri': ('galanteri',),
'galanteria': ('galanteri',),
'galanteriene': ('galanteri',),
'galanterier': ('galanteri',),
'galanteriet': ('galanteri',),
'galanterivara': ('galanterivare',),
'galanterivare': ('galanterivare',),
'galanterivaren': ('galanterivare',),
'galanterivarene': ('galanterivare',),
'galanterivarer': ('galanterivare',),
'galater': ('galater',),
'galatere': ('galater',),
'galateren': ('galater',),
'galaterer': ('galater',),
'galaterne': ('galater',),
'galaterbrev': ('galaterbrev',),
'galaterbreva': ('galaterbrev',),
'galaterbrevene': ('galaterbrev',),
'galaterbrever': ('galaterbrev',),
'galaterbrevet': ('galaterbrev',),
'galder': ('galder',),
'galderen': ('galder',),
'galdre': ('galder',),
'galdrene': ('galder',),
'galdrer': ('galder',),
'galder': ('galder',),
'galderet': ('galder',),
'galdra': ('galder',),
'galdre': ('galder',),
'galdrene': ('galder',),
'galdret': ('galder',),
'galdrekunst': ('galdrekunst',),
'galdrekunsten': ('galdrekunst',),
'galdrekunstene': ('galdrekunst',),
'galdrekunster': ('galdrekunst',),
'galdresang': ('galdresang',),
'galdresangen': ('galdresang',),
'galdresangene': ('galdresang',),
'galdresanger': ('galdresang',),
'galeas': ('galeas',),
'galeasen': ('galeas',),
'galeasene': ('galeas',),
'galeaser': ('galeas',),
'galehus': ('galehus',),
'galehusa': ('galehus',),
'galehusene': ('galehus',),
'galehuset': ('galehus',),
'galei': ('galei',),
'galeien': ('galei',),
'galeiene': ('galei',),
'galeier': ('galei',),
'galeislave': ('galeislave',),
'galeislaven': ('galeislave',),
'galeislavene': ('galeislave',),
'galeislaver': ('galeislave',),
'galenskap': ('galenskap',),
'galenskapen': ('galenskap',),
'galenskapene': ('galenskap',),
'galenskaper': ('galenskap',),
'galfrans': ('galfrans',),
'galfransen': ('galfrans',),
'galfransene': ('galfrans',),
'galfranser': ('galfrans',),
'galge': ('galge',),
'galgen': ('galge',),
'galgene': ('galge',),
'galger': ('galge',),
'galgebakke': ('galgebakke',),
'galgebakken': ('galgebakke',),
'galgebakkene': ('galgebakke',),
'galgebakker': ('galgebakke',),
'galgenfrist': ('galgenfrist',),
'galgenfristen': ('galgenfrist',),
'galgenfristene': ('galgenfrist',),
'galgenfrister': ('galgenfrist',),
'galgenfugl': ('galgenfugl',),
'galgenfuglen': ('galgenfugl',),
'galgenfuglene': ('galgenfugl',),
'galgenfugler': ('galgenfugl',),
'galgenhumor': ('galgenhumor',),
'galgenhumoren': ('galgenhumor',),
'galgenhumorene': ('galgenhumor',),
'galgenhumorer': ('galgenhumor',),
'galileer': ('galileer',),
'galileere': ('galileer',),
'galileeren': ('galileer',),
'galileerer': ('galileer',),
'galileerne': ('galileer',),
'galimatias': ('galimatias',),
'galimatiasa': ('galimatias',),
'galimatiasene': ('galimatias',),
'galimatiaset': ('galimatias',),
'gall': ('gall',),
'galla': ('gall',),
'gallene': ('gall',),
'gallet': ('gall',),
'galla': ('galla',),
'gallaen': ('galla',),
'gallaene': ('galla',),
'gallaer': ('galla',),
'galla': ('galla',),
'gallaen': ('galla',),
'gallaene': ('galla',),
'gallaer': ('galla',),
'gallaantrekk': ('gallaantrekk',),
'gallaantrekka': ('gallaantrekk',),
'gallaantrekkene': ('gallaantrekk',),
'gallaantrekket': ('gallaantrekk',),
'gallafest': ('gallafest',),
'gallafesten': ('gallafest',),
'gallafestene': ('gallafest',),
'gallafester': ('gallafest',),
'gallaforestilling': ('gallaforestilling',),
'gallaforestillinga': ('gallaforestilling',),
'gallaforestillingen': ('gallaforestilling',),
'gallaforestillingene': ('gallaforestilling',),
'gallaforestillinger': ('gallaforestilling',),
'gallamiddag': ('gallamiddag',),
'gallamiddagen': ('gallamiddag',),
'gallamiddagene': ('gallamiddag',),
'gallamiddager': ('gallamiddag',),
'gallauniform': ('gallauniform',),
'gallauniforma': ('gallauniform',),
'gallauniformen': ('gallauniform',),
'gallauniformene': ('gallauniform',),
'gallauniformer': ('gallauniform',),
'gallbær': ('gallbær',),
'gallbæra': ('gallbær',),
'gallbærene': ('gallbær',),
'gallbæret': ('gallbær',),
'galle': ('galle',),
'gallen': ('galle',),
'gallene': ('galle',),
'galler': ('galle',),
'galle': ('galle',),
'gallen': ('galle',),
'gallene': ('galle',),
'galler': ('galle',),
'galleblærebetennelse': ('galleblærebetennelse',),
'galleblærebetennelsen': ('galleblærebetennelse',),
'galleblærebetennelsene': ('galleblærebetennelse',),
'galleblærebetennelser': ('galleblærebetennelse',),
'gallebær': ('gallebær',),
'gallebæra': ('gallebær',),
'gallebærene': ('gallebær',),
'gallebæret': ('gallebær',),
'galleepla': ('galleeple',),
'galleeple': ('galleeple',),
'galleeplene': ('galleeple',),
'galleepler': ('galleeple',),
'galleeplet': ('galleeple',),
'gallegang': ('gallegang',),
'gallegangen': ('gallegang',),
'gallegangene': ('gallegang',),
'galleganger': ('gallegang',),
'gallepla': ('galleple',),
'galleple': ('galleple',),
'galleplene': ('galleple',),
'gallepler': ('galleple',),
'galleplet': ('galleple',),
'galler': ('galler',),
'gallere': ('galler',),
'galleren': ('galler',),
'gallerer': ('galler',),
'gallerne': ('galler',),
'galleri': ('galleri',),
'galleria': ('galleri',),
'galleriene': ('galleri',),
'gallerier': ('galleri',),
'galleriet': ('galleri',),
'gallestein': ('gallestein',),
'gallesteinen': ('gallestein',),
'gallesteinene': ('gallestein',),
'gallesteiner': ('gallestein',),
'gallesyra': ('gallesyre',),
'gallesyre': ('gallesyre',),
'gallesyren': ('gallesyre',),
'gallesyrene': ('gallesyre',),
'gallesyrer': ('gallesyre',),
'gallion': ('gallion',),
'gallionen': ('gallion',),
'gallionene': ('gallion',),
'gallioner': ('gallion',),
'gallionsfigur': ('gallionsfigur',),
'gallionsfiguren': ('gallionsfigur',),
'gallionsfigurene': ('gallionsfigur',),
'gallionsfigurer': ('gallionsfigur',),
'gallium': ('gallium',),
'galliuma': ('gallium',),
'galliumene': ('gallium',),
'galliumet': ('gallium',),
'gallon': ('gallon',),
'gallonen': ('gallon',),
'gallonene': ('gallon',),
'gallons': ('gallon',),
'gallup': ('gallup',),
'gallupen': ('gallup',),
'gallupene': ('gallup',),
'galluper': ('gallup',),
'gallupdemokrati': ('gallupdemokrati',),
'gallupdemokratia': ('gallupdemokrati',),
'gallupdemokratiene': ('gallupdemokrati',),
'gallupdemokratier': ('gallupdemokrati',),
'gallupdemokratiet': ('gallupdemokrati',),
'gallupinstitutt': ('gallupinstitutt',),
'gallupinstitutta': ('gallupinstitutt',),
'gallupinstituttene': ('gallupinstitutt',),
'gallupinstitutter': ('gallupinstitutt',),
'gallupinstituttet': ('gallupinstitutt',),
'gallupundersøkelse': ('gallupundersøkelse',),
'gallupundersøkelsen': ('gallupundersøkelse',),
'gallupundersøkelsene': ('gallupundersøkelse',),
'gallupundersøkelser': ('gallupundersøkelse',),
'galmannsferd': ('galmannsferd',),
'galmannsferda': ('galmannsferd',),
'galmannsferden': ('galmannsferd',),
'galmannsferdene': ('galmannsferd',),
'galmannsferder': ('galmannsferd',),
'galmannsverk': ('galmannsverk',),
'galmannsverka': ('galmannsverk',),
'galmannsverkene': ('galmannsverk',),
'galmannsverker': ('galmannsverk',),
'galmannsverket': ('galmannsverk',),
'galning': ('galning',),
'galningen': ('galning',),
'galningene': ('galning',),
'galninger': ('galning',),
'galon': ('galon',),
'galonen': ('galon',),
'galonene': ('galon',),
'galoner': ('galon',),
'galopp': ('galopp',),
'galoppen': ('galopp',),
'galoppene': ('galopp',),
'galopper': ('galopp',),
'galoppade': ('galoppade',),
'galoppaden': ('galoppade',),
'galoppadene': ('galoppade',),
'galoppader': ('galoppade',),
'galoppbane': ('galoppbane',),
'galoppbanen': ('galoppbane',),
'galoppbanene': ('galoppbane',),
'galoppbaner': ('galoppbane',),
'galopphest': ('galopphest',),
'galopphesten': ('galopphest',),
'galopphestene': ('galopphest',),
'galopphester': ('galopphest',),
'galskap': ('galskap',),
'galskapen': ('galskap',),
'galskapene': ('galskap',),
'galskaper': ('galskap',),
'galt': ('galt',),
'galten': ('galt',),
'galtene': ('galt',),
'galter': ('galt',),
'galte': ('galte',),
'galten': ('galte',),
'galtene': ('galte',),
'galter': ('galte',),
'galvanisme': ('galvanisme',),
'galvanismen': ('galvanisme',),
'galvanismene': ('galvanisme',),
'galvanismer': ('galvanisme',),
'galvanisør': ('galvanisør',),
'galvanisøren': ('galvanisør',),
'galvanisørene': ('galvanisør',),
'galvanisører': ('galvanisør',),
'galvanometer': ('galvanometer',),
'galvanometeret': ('galvanometer',),
'galvanometra': ('galvanometer',),
'galvanometre': ('galvanometer',),
'galvanometrene': ('galvanometer',),
'galvanometret': ('galvanometer',),
'galvanoskop': ('galvanoskop',),
'galvanoskopa': ('galvanoskop',),
'galvanoskopene': ('galvanoskop',),
'galvanoskoper': ('galvanoskop',),
'galvanoskopet': ('galvanoskop',),
'gaman': ('gaman',),
'gamasje': ('gamasje',),
'gamasjen': ('gamasje',),
'gamasjene': ('gamasje',),
'gamasjer': ('gamasje',),
'gambe': ('gambe',),
'gamben': ('gambe',),
'gambene': ('gambe',),
'gamber': ('gambe',),
'gambier': ('gambier',),
'gambiere': ('gambier',),
'gambieren': ('gambier',),
'gambierer': ('gambier',),
'gambierne': ('gambier',),
'gambit': ('gambit',),
'gambiten': ('gambit',),
'gambitene': ('gambit',),
'gambiter': ('gambit',),
'gambler': ('gambler',),
'gamblere': ('gambler',),
'gambleren': ('gambler',),
'gamblerer': ('gambler',),
'gamblerne': ('gambler',),
'gama': ('game',),
'game': ('game',),
'gamene': ('game',),
'gamet': ('game',),
'gamet': ('gamet',),
'gameten': ('gamet',),
'gametene': ('gamet',),
'gameter': ('gamet',),
'gametofytt': ('gametofytt',),
'gametofytten': ('gametofytt',),
'gametofyttene': ('gametofytt',),
'gametofytter': ('gametofytt',),
'gamla': ('gamla',),
'gamleby': ('gamleby',),
'gamlebyen': ('gamleby',),
'gamlebyene': ('gamleby',),
'gamlebyer': ('gamleby',),
'gamleheim': ('gamleheim',),
'gamleheimen': ('gamleheim',),
'gamleheimene': ('gamleheim',),
'gamleheimer': ('gamleheim',),
'gamlehjem': ('gamlehjem',),
'gamlehjemma': ('gamlehjem',),
'gamlehjemmene': ('gamlehjem',),
'gamlehjemmet': ('gamlehjem',),
'gamlekjæreste': ('gamlekjæreste',),
'gamlekjæresten': ('gamlekjæreste',),
'gamlekjærestene': ('gamlekjæreste',),
'gamlekjærester': ('gamlekjæreste',),
'gamlemor': ('gamlemor',),
'gamlemora': ('gamlemor',),
'gamlemoren': ('gamlemor',),
'gamlemødre': ('gamlemor',),
'gamlemødrene': ('gamlemor',),
'gamlemødrer': ('gamlemor',),
'gamlen': ('gamlen',),
'gamlestev': ('gamlestev',),
'gamlesteva': ('gamlestev',),
'gamlestevene': ('gamlestev',),
'gamlestevet': ('gamlestev',),
'gamletid': ('gamletid',),
'gamletida': ('gamletid',),
'gamletiden': ('gamletid',),
'gamletidene': ('gamletid',),
'gamletider': ('gamletid',),
'gamleår': ('gamleår',),
'gamleåra': ('gamleår',),
'gamleårene': ('gamleår',),
'gamleåret': ('gamleår',),
'gamling': ('gamling',),
'gamlingen': ('gamling',),
'gamlingene': ('gamling',),
'gamlinger': ('gamling',),
'gamma': ('gamma',),
'gammaen': ('gamma',),
'gammaene': ('gamma',),
'gammaer': ('gamma',),
'gammaglobulin': ('gammaglobulin',),
'gammaglobulina': ('gammaglobulin',),
'gammaglobulinene': ('gammaglobulin',),
'gammaglobuliner': ('gammaglobulin',),
'gammaglobulinet': ('gammaglobulin',),
'gammaldans': ('gammaldans',),
'gammaldansen': ('gammaldans',),
'gammaldansene': ('gammaldans',),
'gammaldanser': ('gammaldans',),
'gammaldansk': ('gammaldansk',),
'gammaldansken': ('gammaldansk',),
'gammaldanskene': ('gammaldansk',),
'gammaldansker': ('gammaldansk',),
'gammalengelsk': ('gammalengelsk',),
'gammalengelsken': ('gammalengelsk',),
'gammalengelskene': ('gammalengelsk',),
'gammalengelsker': ('gammalengelsk',),
'gammalgresk': ('gammalgresk',),
'gammalgresken': ('gammalgresk',),
'gammalgreskene': ('gammalgresk',),
'gammalgresker': ('gammalgresk',),
'gammalkjæreste': ('gammalkjæreste',),
'gammalkjæresten': ('gammalkjæreste',),
'gammalkjærestene': ('gammalkjæreste',),
'gammalkjærester': ('gammalkjæreste',),
'gammalkommunist': ('gammalkommunist',),
'gammalkommunisten': ('gammalkommunist',),
'gammalkommunistene': ('gammalkommunist',),
'gammalkommunister': ('gammalkommunist',),
'gammalnorsk': ('gammalnorsk',),
'gammalnorsken': ('gammalnorsk',),
'gammalnorskene': ('gammalnorsk',),
'gammalnorsker': ('gammalnorsk',),
'gammalost': ('gammalost',),
'gammalosten': ('gammalost',),
'gammalostene': ('gammalost',),
'gammaloster': ('gammalost',),
'gammalstev': ('gammalstev',),
'gammalsteva': ('gammalstev',),
'gammalstevene': ('gammalstev',),
'gammalstevet': ('gammalstev',),
'gammaltid': ('gammaltid',),
'gammaltida': ('gammaltid',),
'gammaltiden': ('gammaltid',),
'gammaltidene': ('gammaltid',),
'gammaltider': ('gammaltid',),
'gammastråle': ('gammastråle',),
'gammastrålen': ('gammastråle',),
'gammastrålene': ('gammastråle',),
'gammastråler': ('gammastråle',),
'gammastråling': ('gammastråling',),
'gammastrålinga': ('gammastråling',),
'gammastrålingen': ('gammastråling',),
'gammastrålingene': ('gammastråling',),
'gammastrålinger': ('gammastråling',),
'gamma': ('gamme',),
'gamme': ('gamme',),
'gammen': ('gamme',),
'gammene': ('gamme',),
'gammer': ('gamme',),
'gammeldans': ('gammeldans',),
'gammeldansen': ('gammeldans',),
'gammeldansene': ('gammeldans',),
'gammeldanser': ('gammeldans',),
'gammeldansk': ('gammeldansk',),
'gammeldansken': ('gammeldansk',),
'gammeldanskene': ('gammeldansk',),
'gammeldansker': ('gammeldansk',),
'gammelengelsk': ('gammelengelsk',),
'gammelengelsken': ('gammelengelsk',),
'gammelengelskene': ('gammelengelsk',),
'gammelengelsker': ('gammelengelsk',),
'gammelgresk': ('gammelgresk',),
'gammelgresken': ('gammelgresk',),
'gammelgreskene': ('gammelgresk',),
'gammelgresker': ('gammelgresk',),
'gammelkjæreste': ('gammelkjæreste',),
'gammelkjæresten': ('gammelkjæreste',),
'gammelkjærestene': ('gammelkjæreste',),
'gammelkjærester': ('gammelkjæreste',),
'gammelkommunist': ('gammelkommunist',),
'gammelkommunisten': ('gammelkommunist',),
'gammelkommunistene': ('gammelkommunist',),
'gammelkommunister': ('gammelkommunist',),
'gammelnorsk': ('gammelnorsk',),
'gammelnorsken': ('gammelnorsk',),
'gammelnorskene': ('gammelnorsk',),
'gammelnorsker': ('gammelnorsk',),
'gammelost': ('gammelost',),
'gammelosten': ('gammelost',),
'gammelostene': ('gammelost',),
'gammeloster': ('gammelost',),
'gammelstev': ('gammelstev',),
'gammelsteva': ('gammelstev',),
'gammelstevene': ('gammelstev',),
'gammelstevet': ('gammelstev',),
'gammeltid': ('gammeltid',),
'gammeltida': ('gammeltid',),
'gammeltiden': ('gammeltid',),
'gammeltidene': ('gammeltid',),
'gammeltider': ('gammeltid',),
'gammen': ('gammen',),
'gamp': ('gamp',),
'gampen': ('gamp',),
'gampene': ('gamp',),
'gamper': ('gamp',),
'gan': ('gan',),
'gana': ('gan',),
'ganene': ('gan',),
'ganet': ('gan',),
'gand': ('gand',),
'ganden': ('gand',),
'gandene': ('gand',),
'gander': ('gand',),
'gandfinn': ('gandfinn',),
'gandfinnen': ('gandfinn',),
'gandfinnene': ('gandfinn',),
'gandfinner': ('gandfinn',),
'gandflua': ('gandflue',),
'gandflue': ('gandflue',),
'gandfluen': ('gandflue',),
'gandfluene': ('gandflue',),
'gandfluer': ('gandflue',),
'gane': ('gane',),
'ganen': ('gane',),
'ganene': ('gane',),
'ganer': ('gane',),
'ganelyd': ('ganelyd',),
'ganelyden': ('ganelyd',),
'ganelydene': ('ganelyd',),
'ganelyder': ('ganelyd',),
'ganesegl': ('ganesegl',),
'ganesegla': ('ganesegl',),
'ganeseglene': ('ganesegl',),
'ganeseglet': ('ganesegl',),
'ganeseil': ('ganeseil',),
'ganeseila': ('ganeseil',),
'ganeseilene': ('ganeseil',),
'ganeseilet': ('ganeseil',),
'ganespalta': ('ganespalte',),
'ganespalte': ('ganespalte',),
'ganespalten': ('ganespalte',),
'ganespaltene': ('ganespalte',),
'ganespalter': ('ganespalte',),
'gang': ('gang',),
'gangen': ('gang',),
'gangene': ('gang',),
'ganger': ('gang',),
'gangar': ('gangar',),
'gangaren': ('gangar',),
'gangarene': ('gangar',),
'gangarer': ('gangar',),
'gangbro': ('gangbro',),
'gangbroa': ('gangbro',),
'gangbroen': ('gangbro',),
'gangbroene': ('gangbro',),
'gangbroer': ('gangbro',),
'gangbru': ('gangbru',),
'gangbrua': ('gangbru',),
'gangbruen': ('gangbru',),
'gangbruene': ('gangbru',),
'gangbruer': ('gangbru',),
'gangdag': ('gangdag',),
'gangdagen': ('gangdag',),
'gangdagene': ('gangdag',),
'gangdager': ('gangdag',),
'gangdør': ('gangdør',),
'gangdøra': ('gangdør',),
'gangdøren': ('gangdør',),
'gangdørene': ('gangdør',),
'gangdører': ('gangdør',),
'ganga': ('gange',),
'gange': ('gange',),
'gangen': ('gange',),
'gangene': ('gange',),
'ganger': ('gange',),
'ganger': ('ganger',),
'gangere': ('ganger',),
'gangeren': ('ganger',),
'gangerer': ('ganger',),
'gangerne': ('ganger',),
'gangfelt': ('gangfelt',),
'gangfelta': ('gangfelt',),
'gangfeltene': ('gangfelt',),
'gangfelter': ('gangfelt',),
'gangfeltet': ('gangfelt',),
'gangjern': ('gangjern',),
'gangjerna': ('gangjern',),
'gangjernene': ('gangjern',),
'gangjernet': ('gangjern',),
'gangklær': ('gangklær',),
'gangklærne': ('gangklær',),
'ganglag': ('ganglag',),
'ganglaga': ('ganglag',),
'ganglagene': ('ganglag',),
'ganglaget': ('ganglag',),
'ganglem': ('ganglem',),
'ganglemma': ('ganglem',),
'ganglemmene': ('ganglem',),
'ganglemmer': ('ganglem',),
'ganglemmet': ('ganglem',),
'ganglia': ('ganglie',),
'ganglie': ('ganglie',),
'ganglien': ('ganglie',),
'gangliene': ('ganglie',),
'ganglier': ('ganglie',),
'gangliet': ('ganglie',),
'ganglia': ('ganglion',),
'gangliene': ('ganglion',),
'ganglier': ('ganglion',),
'ganglion': ('ganglion',),
'ganglionet': ('ganglion',),
'gangren': ('gangren',),
'gangrena': ('gangren',),
'gangrenen': ('gangren',),
'gangrenene': ('gangren',),
'gangrener': ('gangren',),
'gangrenet': ('gangren',),
'gangsperr': ('gangsperr',),
'gangsperren': ('gangsperr',),
'gangsperrene': ('gangsperr',),
'gangsperrer': ('gangsperr',),
'gangsperra': ('gangsperre',),
'gangsperre': ('gangsperre',),
'gangsperren': ('gangsperre',),
'gangsperrene': ('gangsperre',),
'gangsperrer': ('gangsperre',),
'gangspill': ('gangspill',),
'gangspilla': ('gangspill',),
'gangspillene': ('gangspill',),
'gangspillet': ('gangspill',),
'gangsport': ('gangsport',),
'gangsporten': ('gangsport',),
'gangsportene': ('gangsport',),
'gangsporter': ('gangsport',),
'gangster': ('gangster',),
'gangstere': ('gangster',),
'gangsteren': ('gangster',),
'gangsterer': ('gangster',),
'gangsterne': ('gangster',),
'gangsterfilm': ('gangsterfilm',),
'gangsterfilmen': ('gangsterfilm',),
'gangsterfilmene': ('gangsterfilm',),
'gangsterfilmer': ('gangsterfilm',),
'gangsti': ('gangsti',),
'gangstien': ('gangsti',),
'gangstiene': ('gangsti',),
'gangstier': ('gangsti',),
'gangstol': ('gangstol',),
'gangstolen': ('gangstol',),
'gangstolene': ('gangstol',),
'gangstoler': ('gangstol',),
'gangsyn': ('gangsyn',),
'gangsyna': ('gangsyn',),
'gangsynene': ('gangsyn',),
'gangsynet': ('gangsyn',),
'gangtid': ('gangtid',),
'gangtida': ('gangtid',),
'gangtiden': ('gangtid',),
'gangtidene': ('gangtid',),
'gangtider': ('gangtid',),
'gangvad': ('gangvad',),
'gangvada': ('gangvad',),
'gangvaden': ('gangvad',),
'gangvadene': ('gangvad',),
'gangvader': ('gangvad',),
'gangvadet': ('gangvad',),
'gangveg': ('gangveg',),
'gangvegen': ('gangveg',),
'gangvegene': ('gangveg',),
'gangveger': ('gangveg',),
'gangvei': ('gangvei',),
'gangveien': ('gangvei',),
'gangveiene': ('gangvei',),
'gangveier': ('gangvei',),
'gangverk': ('gangverk',),
'gangverka': ('gangverk',),
'gangverkene': ('gangverk',),
'gangverker': ('gangverk',),
'gangverket': ('gangverk',),
'gant': ('gant',),
'ganta': ('gant',),
'ganten': ('gant',),
'gantene': ('gant',),
'ganter': ('gant',),
'gantet': ('gant',),
'gap': ('gap',),
'gapen': ('gap',),
'gapene': ('gap',),
'gaper': ('gap',),
'gap': ('gap',),
'gapa': ('gap',),
'gapene': ('gap',),
'gapet': ('gap',),
'gapahuk': ('gapahuk',),
'gapahuken': ('gapahuk',),
'gapahukene': ('gapahuk',),
'gapahuker': ('gapahuk',),
'gaperi': ('gaperi',),
'gaperia': ('gaperi',),
'gaperiene': ('gaperi',),
'gaperier': ('gaperi',),
'gaperiet': ('gaperi',),
'gapestokk': ('gapestokk',),
'gapestokken': ('gapestokk',),
'gapestokkene': ('gapestokk',),
'gapestokker': ('gapestokk',),
'gapestrek': ('gapestrek',),
'gapestreken': ('gapestrek',),
'gapestrekene': ('gapestrek',),
'gapestreker': ('gapestrek',),
'gapestykka': ('gapestykke',),
'gapestykke': ('gapestykke',),
'gapestykkene': ('gapestykke',),
'gapestykker': ('gapestykke',),
'gapestykket': ('gapestykke',),
'gapskratt': ('gapskratt',),
'gapskratta': ('gapskratt',),
'gapskratten': ('gapskratt',),
'gapskrattene': ('gapskratt',),
'gapskrattet': ('gapskratt',),
'garant': ('garant',),
'garanten': ('garant',),
'garantene': ('garant',),
'garanter': ('garant',),
'garanti': ('garanti',),
'garantien': ('garanti',),
'garantiene': ('garanti',),
'garantier': ('garanti',),
'garantiansvar': ('garantiansvar',),
'garantiansvara': ('garantiansvar',),
'garantiansvarene': ('garantiansvar',),
'garantiansvaret': ('garantiansvar',),
'garantiforsikring': ('garantiforsikring',),
'garantiforsikringa': ('garantiforsikring',),
'garantiforsikringen': ('garantiforsikring',),
'garantiforsikringene': ('garantiforsikring',),
'garantiforsikringer': ('garantiforsikring',),
'garantiinstitutt': ('garantiinstitutt',),
'garantiinstitutta': ('garantiinstitutt',),
'garantiinstituttene': ('garantiinstitutt',),
'garantiinstitutter': ('garantiinstitutt',),
'garantiinstituttet': ('garantiinstitutt',),
'garantikort': ('garantikort',),
'garantikorta': ('garantikort',),
'garantikortene': ('garantikort',),
'garantikortet': ('garantikort',),
'garantist': ('garantist',),
'garantisten': ('garantist',),
'garantistene': ('garantist',),
'garantister': ('garantist',),
'garantitid': ('garantitid',),
'garantitida': ('garantitid',),
'garantitiden': ('garantitid',),
'garantitidene': ('garantitid',),
'garantitider': ('garantitid',),
'garantitraktat': ('garantitraktat',),
'garantitraktaten': ('garantitraktat',),
'garantitraktatene': ('garantitraktat',),
'garantitraktater': ('garantitraktat',),
'garasje': ('garasje',),
'garasjen': ('garasje',),
'garasjene': ('garasje',),
'garasjer': ('garasje',),
'garasjehus': ('garasjehus',),
'garasjehusa': ('garasjehus',),
'garasjehusene': ('garasjehus',),
'garasjehuset': ('garasjehus',),
'garasjeport': ('garasjeport',),
'garasjeporten': ('garasjeport',),
'garasjeportene': ('garasjeport',),
'garasjeporter': ('garasjeport',),
'gard': ('gard',),
'garden': ('gard',),
'gardene': ('gard',),
'garder': ('gard',),
'gard': ('gard',),
'garden': ('gard',),
'gardene': ('gard',),
'garder': ('gard',),
'gardbruker': ('gardbruker',),
'gardbrukere': ('gardbruker',),
'gardbrukeren': ('gardbruker',),
'gardbrukerer': ('gardbruker',),
'gardbrukerne': ('gardbruker',),
'gardeier': ('gardeier',),
'gardeiere': ('gardeier',),
'gardeieren': ('gardeier',),
'gardeierer': ('gardeier',),
'gardeierne': ('gardeier',),
'gardekompani': ('gardekompani',),
'gardekompania': ('gardekompani',),
'gardekompaniene': ('gardekompani',),
'gardekompanier': ('gardekompani',),
'gardekompaniet': ('gardekompani',),
'gardenia': ('gardenia',),
'gardeniaen': ('gardenia',),
'gardeniaene': ('gardenia',),
'gardeniaer': ('gardenia',),
'gardeniene': ('gardenia',),
'gardenier': ('gardenia',),
'garderobe': ('garderobe',),
'garderoben': ('garderobe',),
'garderobene': ('garderobe',),
'garderober': ('garderobe',),
'garderobeavgift': ('garderobeavgift',),
'garderobeavgifta': ('garderobeavgift',),
'garderobeavgiften': ('garderobeavgift',),
'garderobeavgiftene': ('garderobeavgift',),
'garderobeavgifter': ('garderobeavgift',),
'garderobeplikt': ('garderobeplikt',),
'garderobeplikta': ('garderobeplikt',),
'garderobeplikten': ('garderobeplikt',),
'garderobepliktene': ('garderobeplikt',),
'garderobeplikter': ('garderobeplikt',),
'garderobeskap': ('garderobeskap',),
'garderobeskapa': ('garderobeskap',),
'garderobeskapene': ('garderobeskap',),
'garderobeskapet': ('garderobeskap',),
'gardesoldat': ('gardesoldat',),
'gardesoldaten': ('gardesoldat',),
'gardesoldatene': ('gardesoldat',),
'gardesoldater': ('gardesoldat',),
'gardestilling': ('gardestilling',),
'gardestillinga': ('gardestilling',),
'gardestillingen': ('gardestilling',),
'gardestillingene': ('gardestilling',),
'gardestillinger': ('gardestilling',),
'gardfang': ('gardfang',),
'gardfanga': ('gardfang',),
'gardfangene': ('gardfang',),
'gardfanget': ('gardfang',),
'gardfolk': ('gardfolk',),
'gardfolka': ('gardfolk',),
'gardfolkene': ('gardfolk',),
'gardfolket': ('gardfolk',),
'gardgutt': ('gardgutt',),
'gardgutten': ('gardgutt',),
'gardguttene': ('gardgutt',),
'gardgutter': ('gardgutt',),
'gardin': ('gardin',),
'gardina': ('gardin',),
'gardinen': ('gardin',),
'gardinene': ('gardin',),
'gardiner': ('gardin',),
'gardinet': ('gardin',),
'gardinbrett': ('gardinbrett',),
'gardinbretta': ('gardinbrett',),
'gardinbrettene': ('gardinbrett',),
'gardinbretter': ('gardinbrett',),
'gardinbrettet': ('gardinbrett',),
'gardinpreken': ('gardinpreken',),
'gardinprekenen': ('gardinpreken',),
'gardinprekenene': ('gardinpreken',),
'gardinprekener': ('gardinpreken',),
'gardinstang': ('gardinstang',),
'gardinstanga': ('gardinstang',),
'gardinstangen': ('gardinstang',),
'gardinstengene': ('gardinstang',),
'gardinstenger': ('gardinstang',),
'gardintrapp': ('gardintrapp',),
'gardintrappa': ('gardintrapp',),
'gardintrappen': ('gardintrapp',),
'gardintrappene': ('gardintrapp',),
'gardintrapper': ('gardintrapp',),
'gardist': ('gardist',),
'gardisten': ('gardist',),
'gardistene': ('gardist',),
'gardister': ('gardist',),
'gardjenta': ('gardjente',),
'gardjente': ('gardjente',),
'gardjenten': ('gardjente',),
'gardjentene': ('gardjente',),
'gardjenter': ('gardjente',),
'gardkjerring': ('gardkjerring',),
'gardkjerringa': ('gardkjerring',),
'gardkjerringen': ('gardkjerring',),
'gardkjerringene': ('gardkjerring',),
'gardkjerringer': ('gardkjerring',),
'gardkona': ('gardkone',),
'gardkone': ('gardkone',),
'gardkonen': ('gardkone',),
'gardkonene': ('gardkone',),
'gardkoner': ('gardkone',),
'gardkonge': ('gardkonge',),
'gardkongen': ('gardkonge',),
'gardkongene': ('gardkonge',),
'gardkonger': ('gardkonge',),
'gardmann': ('gardmann',),
'gardmannen': ('gardmann',),
'gardmenn': ('gardmann',),
'gardmennene': ('gardmann',),
'gardpart': ('gardpart',),
'gardparten': ('gardpart',),
'gardpartene': ('gardpart',),
'gardparter': ('gardpart',),
'gardsarbeid': ('gardsarbeid',),
'gardsarbeida': ('gardsarbeid',),
'gardsarbeidene': ('gardsarbeid',),
'gardsarbeider': ('gardsarbeid',),
'gardsarbeidet': ('gardsarbeid',),
'gardsarbeider': ('gardsarbeider',),
'gardsarbeidere': ('gardsarbeider',),
'gardsarbeideren': ('gardsarbeider',),
'gardsarbeiderer': ('gardsarbeider',),
'gardsarbeiderne': ('gardsarbeider',),
'gardsbruk': ('gardsbruk',),
'gardsbruka': ('gardsbruk',),
'gardsbrukene': ('gardsbruk',),
'gardsbruket': ('gardsbruk',),
'gardsdreng': ('gardsdreng',),
'gardsdrengen': ('gardsdreng',),
'gardsdrengene': ('gardsdreng',),
'gardsdrenger': ('gardsdreng',),
'gardsdrift': ('gardsdrift',),
'gardsdrifta': ('gardsdrift',),
'gardsdriften': ('gardsdrift',),
'gardsdriftene': ('gardsdrift',),
'gardsdrifter': ('gardsdrift',),
'gardsfolk': ('gardsfolk',),
'gardsfolka': ('gardsfolk',),
'gardsfolkene': ('gardsfolk',),
'gardsfolket': ('gardsfolk',),
'gardsgutt': ('gardsgutt',),
'gardsgutten': ('gardsgutt',),
'gardsguttene': ('gardsgutt',),
'gardsgutter': ('gardsgutt',),
'gardshund': ('gardshund',),
'gardshunden': ('gardshund',),
'gardshundene': ('gardshund',),
'gardshunder': ('gardshund',),
'gardsled': ('gardsled',),
'gardsleda': ('gardsled',),
'gardsledene': ('gardsled',),
'gardsledet': ('gardsled',),
'gardsnavn': ('gardsnavn',),
'gardsnavna': ('gardsnavn',),
'gardsnavnene': ('gardsnavn',),
'gardsnavnet': ('gardsnavn',),
'gardsnummer': ('gardsnummer',),
'gardsnummeret': ('gardsnummer',),
'gardsnumra': ('gardsnummer',),
'gardsnumre': ('gardsnummer',),
'gardsnumrene': ('gardsnummer',),
'gardsplass': ('gardsplass',),
'gardsplassen': ('gardsplass',),
'gardsplassene': ('gardsplass',),
'gardsplasser': ('gardsplass',),
'gardsrom': ('gardsrom',),
'gardsromma': ('gardsrom',),
'gardsrommene': ('gardsrom',),
'gardsrommet': ('gardsrom',),
'gardssmør': ('gardssmør',),
'gardssmøra': ('gardssmør',),
'gardssmørene': ('gardssmør',),
'gardssmøret': ('gardssmør',),
'gardsstell': ('gardsstell',),
'gardsstella': ('gardsstell',),
'gardsstellene': ('gardsstell',),
'gardsstellet': ('gardsstell',),
'gardstank': ('gardstank',),
'gardstanken': ('gardstank',),
'gardstankene': ('gardstank',),
'gardstanker': ('gardstank',),
'gardstanksystem': ('gardstanksystem',),
'gardstanksystema': ('gardstanksystem',),
'gardstanksystemene': ('gardstanksystem',),
'gardstanksystemer': ('gardstanksystem',),
'gardstanksystemet': ('gardstanksystem',),
'gardstaur': ('gardstaur',),
'gardstauren': ('gardstaur',),
'gardstaurene': ('gardstaur',),
'gardstaurer': ('gardstaur',),
'gardsteig': ('gardsteig',),
'gardsteigen': ('gardsteig',),
'gardsteigene': ('gardsteig',),
'gardsteiger': ('gardsteig',),
'gardstilling': ('gardstilling',),
'gardstillinga': ('gardstilling',),
'gardstillingen': ('gardstilling',),
'gardstillingene': ('gardstilling',),
'gardstillinger': ('gardstilling',),
'gardstun': ('gardstun',),
'gardstuna': ('gardstun',),
'gardstunene': ('gardstun',),
'gardstunet': ('gardstun',),
'gardsveg': ('gardsveg',),
'gardsvegen': ('gardsveg',),
'gardsvegene': ('gardsveg',),
'gardsveger': ('gardsveg',),
'gardsvei': ('gardsvei',),
'gardsveien': ('gardsvei',),
'gardsveiene': ('gardsvei',),
'gardsveier': ('gardsvei',),
'gardvord': ('gardvord',),
'gardvorden': ('gardvord',),
'gardvordene': ('gardvord',),
'gardvorder': ('gardvord',),
'garn': ('garn',),
'garna': ('garn',),
'garnene': ('garn',),
'garnet': ('garn',),
'garnbinder': ('garnbinder',),
'garnbindere': ('garnbinder',),
'garnbinderen': ('garnbinder',),
'garnbinderer': ('garnbinder',),
'garnbinderne': ('garnbinder',),
'garnbom': ('garnbom',),
'garnbommen': ('garnbom',),
'garnbommene': ('garnbom',),
'garnbommer': ('garnbom',),
'garnbruk': ('garnbruk',),
'garnbruka': ('garnbruk',),
'garnbrukene': ('garnbruk',),
'garnbruket': ('garnbruk',),
'garnbunt': ('garnbunt',),
'garnbunten': ('garnbunt',),
'garnbuntene': ('garnbunt',),
'garnbunter': ('garnbunt',),
'garnbåt': ('garnbåt',),
'garnbåten': ('garnbåt',),
'garnbåtene': ('garnbåt',),
'garnbåter': ('garnbåt',),
'garndokka': ('garndokke',),
'garndokke': ('garndokke',),
'garndokken': ('garndokke',),
'garndokkene': ('garndokke',),
'garndokker': ('garndokke',),
'garndukka': ('garndukke',),
'garndukke': ('garndukke',),
'garndukken': ('garndukke',),
'garndukkene': ('garndukke',),
'garndukker': ('garndukke',),
'garnering': ('garnering',),
'garneringa': ('garnering',),
'garneringen': ('garnering',),
'garneringene': ('garnering',),
'garneringer': ('garnering',),
'garnfangst': ('garnfangst',),
'garnfangsten': ('garnfangst',),
'garnfangstene': ('garnfangst',),
'garnfangster': ('garnfangst',),
'garnfiska': ('garnfiske',),
'garnfiske': ('garnfiske',),
'garnfiskene': ('garnfiske',),
'garnfisker': ('garnfiske',),
'garnfisket': ('garnfiske',),
'garnhespa': ('garnhespe',),
'garnhespe': ('garnhespe',),
'garnhespen': ('garnhespe',),
'garnhespene': ('garnhespe',),
'garnhesper': ('garnhespe',),
'garnhespel': ('garnhespel',),
'garnhespelen': ('garnhespel',),
'garnhesplene': ('garnhespel',),
'garnhespler': ('garnhespel',),
'garnison': ('garnison',),
'garnisonen': ('garnison',),
'garnisonene': ('garnison',),
'garnisoner': ('garnison',),
'garnisonsby': ('garnisonsby',),
'garnisonsbyen': ('garnisonsby',),
'garnisonsbyene': ('garnisonsby',),
'garnisonsbyer': ('garnisonsby',),
'garnisonskirka': ('garnisonskirke',),
'garnisonskirke': ('garnisonskirke',),
'garnisonskirken': ('garnisonskirke',),
'garnisonskirkene': ('garnisonskirke',),
'garnisonskirker': ('garnisonskirke',),
'garnisonskjerka': ('garnisonskjerke',),
'garnisonskjerke': ('garnisonskjerke',),
'garnisonskjerken': ('garnisonskjerke',),
'garnisonskjerkene': ('garnisonskjerke',),
'garnisonskjerker': ('garnisonskjerke',),
'garnityr': ('garnityr',),
'garnityra': ('garnityr',),
'garnityrene': ('garnityr',),
'garnityrer': ('garnityr',),
'garnityret': ('garnityr',),
'garnlenk': ('garnlenk',),
'garnlenken': ('garnlenk',),
'garnlenkene': ('garnlenk',),
'garnlenker': ('garnlenk',),
'garnlenka': ('garnlenke',),
'garnlenke': ('garnlenke',),
'garnlenken': ('garnlenke',),
'garnlenkene': ('garnlenke',),
'garnlenker': ('garnlenke',),
'garnnøsta': ('garnnøste',),
'garnnøste': ('garnnøste',),
'garnnøstene': ('garnnøste',),
'garnnøster': ('garnnøste',),
'garnnøstet': ('garnnøste',),
'garnsetning': ('garnsetning',),
'garnsetninga': ('garnsetning',),
'garnsetningen': ('garnsetning',),
'garnsetningene': ('garnsetning',),
'garnsetninger': ('garnsetning',),
'garnsett': ('garnsett',),
'garnsetta': ('garnsett',),
'garnsettene': ('garnsett',),
'garnsettet': ('garnsett',),
'garnskott': ('garnskott',),
'garnskotta': ('garnskott',),
'garnskottene': ('garnskott',),
'garnskottet': ('garnskott',),
'garnvinda': ('garnvinde',),
'garnvinde': ('garnvinde',),
'garnvinden': ('garnvinde',),
'garnvindene': ('garnvinde',),
'garnvinder': ('garnvinde',),
'garp': ('garp',),
'garpen': ('garp',),
'garpene': ('garp',),
'garper': ('garp',),
'garpegenitiv': ('garpegenitiv',),
'garpegenitiven': ('garpegenitiv',),
'garpegenitivene': ('garpegenitiv',),
'garpegenitiver': ('garpegenitiv',),
'garrotte': ('garrotte',),
'garrotten': ('garrotte',),
'garrottene': ('garrotte',),
'garrotter': ('garrotte',),
'gartner': ('gartner',),
'gartnere': ('gartner',),
'gartneren': ('gartner',),
'gartnerer': ('gartner',),
'gartnerne': ('gartner',),
'gartnerarbeid': ('gartnerarbeid',),
'gartnerarbeida': ('gartnerarbeid',),
'gartnerarbeidene': ('gartnerarbeid',),
'gartnerarbeider': ('gartnerarbeid',),
'gartnerarbeidet': ('gartnerarbeid',),
'gartnerbolig': ('gartnerbolig',),
'gartnerboligen': ('gartnerbolig',),
'gartnerboligene': ('gartnerbolig',),
'gartnerboliger': ('gartnerbolig',),
'gartneri': ('gartneri',),
'gartneria': ('gartneri',),
'gartneriene': ('gartneri',),
'gartnerier': ('gartneri',),
'gartneriet': ('gartneri',),
'gartnerlæra': ('gartnerlære',),
'gartnerlære': ('gartnerlære',),
'gartnerlæren': ('gartnerlære',),
'gartnerlærene': ('gartnerlære',),
'gartnerlærer': ('gartnerlære',),
'gartnerskole': ('gartnerskole',),
'gartnerskolen': ('gartnerskole',),
'gartnerskolene': ('gartnerskole',),
'gartnerskoler': ('gartnerskole',),
'garver': ('garver',),
'garvere': ('garver',),
'garveren': ('garver',),
'garverer': ('garver',),
'garverne': ('garver',),
'garverfag': ('garverfag',),
'garverfaga': ('garverfag',),
'garverfagene': ('garverfag',),
'garverfaget': ('garverfag',),
'garveri': ('garveri',),
'garveria': ('garveri',),
'garveriene': ('garveri',),
'garverier': ('garveri',),
'garveriet': ('garveri',),
'garvestoff': ('garvestoff',),
'garvestoffa': ('garvestoff',),
'garvestoffene': ('garvestoff',),
'garvestoffer': ('garvestoff',),
'garvestoffet': ('garvestoff',),
'garvesyra': ('garvesyre',),
'garvesyre': ('garvesyre',),
'garvesyren': ('garvesyre',),
'garvesyrene': ('garvesyre',),
'garvesyrer': ('garvesyre',),
'garveverk': ('garveverk',),
'garveverka': ('garveverk',),
'garveverkene': ('garveverk',),
'garveverker': ('garveverk',),
'garveverket': ('garveverk',),
'gas': ('gas',),
'gasen': ('gas',),
'gasene': ('gas',),
'gaser': ('gas',),
'gasbind': ('gasbind',),
'gasbinda': ('gasbind',),
'gasbindene': ('gasbind',),
'gasbindet': ('gasbind',),
'gasell': ('gasell',),
'gasellen': ('gasell',),
'gasellene': ('gasell',),
'gaseller': ('gasell',),
'gasellblikk': ('gasellblikk',),
'gasellblikka': ('gasellblikk',),
'gasellblikkene': ('gasellblikk',),
'gasellblikket': ('gasellblikk',),
'gaselleblikk': ('gaselleblikk',),
'gaselleblikka': ('gaselleblikk',),
'gaselleblikkene': ('gaselleblikk',),
'gaselleblikket': ('gaselleblikk',),
'gaselleøya': ('gaselleøyne',),
'gaselleøyene': ('gaselleøyne',),
'gaselleøyer': ('gaselleøyne',),
'gaselleøyne': ('gaselleøyne',),
'gaselleøynene': ('gaselleøyne',),
'gaselløya': ('gaselløyne',),
'gaselløyene': ('gaselløyne',),
'gaselløyer': ('gaselløyne',),
'gaselløyne': ('gaselløyne',),
'gaselløynene': ('gaselløyne',),
'gasje': ('gasje',),
'gasjen': ('gasje',),
'gasjene': ('gasje',),
'gasjer': ('gasje',),
'gasjepålegg': ('gasjepålegg',),
'gasjepålegga': ('gasjepålegg',),
'gasjepåleggene': ('gasjepålegg',),
'gasjepålegget': ('gasjepålegg',),
'gass': ('gass',),
'gassen': ('gass',),
'gassene': ('gass',),
'gasser': ('gass',),
'gass-sveising': ('gass-sveising',),
'gass-sveisinga': ('gass-sveising',),
'gass-sveisingen': ('gass-sveising',),
'gass-sveisingene': ('gass-sveising',),
'gass-sveisinger': ('gass-sveising',),
'gassangrep': ('gassangrep',),
'gassangrepa': ('gassangrep',),
'gassangrepene': ('gassangrep',),
'gassangrepet': ('gassangrep',),
'gassart': ('gassart',),
'gassarta': ('gassart',),
'gassarten': ('gassart',),
'gassartene': ('gassart',),
'gassarter': ('gassart',),
'gassballong': ('gassballong',),
'gassballongen': ('gassballong',),
'gassballongene': ('gassballong',),
'gassballonger': ('gassballong',),
'gassbeholder': ('gassbeholder',),
'gassbeholdere': ('gassbeholder',),
'gassbeholderen': ('gassbeholder',),
'gassbeholderer': ('gassbeholder',),
'gassbeholderne': ('gassbeholder',),
'gassbetong': ('gassbetong',),
'gassbetongen': ('gassbetong',),
'gassbetongene': ('gassbetong',),
'gassbetonger': ('gassbetong',),
'gassbluss': ('gassbluss',),
'gassblussa': ('gassbluss',),
'gassblussene': ('gassbluss',),
'gassblusset': ('gassbluss',),
'gassbomba': ('gassbombe',),
'gassbombe': ('gassbombe',),
'gassbomben': ('gassbombe',),
'gassbombene': ('gassbombe',),
'gassbomber': ('gassbombe',),
'gassbrenner': ('gassbrenner',),
'gassbrennere': ('gassbrenner',),
'gassbrenneren': ('gassbrenner',),
'gassbrennerer': ('gassbrenner',),
'gassbrennerne': ('gassbrenner',),
'gasse': ('gasse',),
'gassen': ('gasse',),
'gassene': ('gasse',),
'gasser': ('gasse',),
'gasseksplosjon': ('gasseksplosjon',),
'gasseksplosjonen': ('gasseksplosjon',),
'gasseksplosjonene': ('gasseksplosjon',),
'gasseksplosjoner': ('gasseksplosjon',),
'gasser': ('gasser',),
'gassere': ('gasser',),
'gasseren': ('gasser',),
'gasserer': ('gasser',),
'gasserne': ('gasser',),
'gassfare': ('gassfare',),
'gassfaren': ('gassfare',),
'gassfarene': ('gassfare',),
'gassfarer': ('gassfare',),
'gassforgiftning': ('gassforgiftning',),
'gassforgiftninga': ('gassforgiftning',),
'gassforgiftningen': ('gassforgiftning',),
'gassforgiftningene': ('gassforgiftning',),
'gassforgiftninger': ('gassforgiftning',),
'gassform': ('gassform',),
'gassforma': ('gassform',),
'gassformen': ('gassform',),
'gassformene': ('gassform',),
'gassformer': ('gassform',),
'gassfunn': ('gassfunn',),
'gassfunna': ('gassfunn',),
'gassfunnene': ('gassfunn',),
'gassfunnet': ('gassfunn',),
'gassfyring': ('gassfyring',),
'gassfyringa': ('gassfyring',),
'gassfyringen': ('gassfyring',),
'gassfyringene': ('gassfyring',),
'gassfyringer': ('gassfyring',),
'gasskammer': ('gasskammer',),
'gasskammeret': ('gasskammer',),
'gasskamra': ('gasskammer',),
'gasskamre': ('gasskammer',),
'gasskamrene': ('gasskammer',),
'gassklokka': ('gassklokke',),
'gassklokke': ('gassklokke',),
'gassklokken': ('gassklokke',),
'gassklokkene': ('gassklokke',),
'gassklokker': ('gassklokke',),
'gasskomfyr': ('gasskomfyr',),
'gasskomfyren': ('gasskomfyr',),
'gasskomfyrene': ('gasskomfyr',),
'gasskomfyrer': ('gasskomfyr',),
'gassledning': ('gassledning',),
'gassledninga': ('gassledning',),
'gassledningen': ('gassledning',),
'gassledningene': ('gassledning',),
'gassledninger': ('gassledning',),
'gasslykt': ('gasslykt',),
'gasslykta': ('gasslykt',),
'gasslykten': ('gasslykt',),
'gasslyktene': ('gasslykt',),
'gasslykter': ('gasslykt',),
'gasslys': ('gasslys',),
'gasslysa': ('gasslys',),
'gasslysene': ('gasslys',),
'gasslyset': ('gasslys',),
'gassmaska': ('gassmaske',),
'gassmaske': ('gassmaske',),
'gassmasken': ('gassmaske',),
'gassmaskene': ('gassmaske',),
'gassmasker': ('gassmaske',),
'gasspedal': ('gasspedal',),
'gasspedalen': ('gasspedal',),
'gasspedalene': ('gasspedal',),
'gasspedaler': ('gasspedal',),
'gasspistol': ('gasspistol',),
'gasspistolen': ('gasspistol',),
'gasspistolene': ('gasspistol',),
'gasspistoler': ('gasspistol',),
'gassrør': ('gassrør',),
'gassrøra': ('gassrør',),
'gassrørene': ('gassrør',),
'gassrøret': ('gassrør',),
'gassveising': ('gassveising',),
'gassveisinga': ('gassveising',),
'gassveisingen': ('gassveising',),
'gassveisingene': ('gassveising',),
'gassveisinger': ('gassveising',),
'gassverk': ('gassverk',),
'gassverka': ('gassverk',),
'gassverkene': ('gassverk',),
'gassverker': ('gassverk',),
'gassverket': ('gassverk',),
'gassvern': ('gassvern',),
'gassverna': ('gassvern',),
'gassvernene': ('gassvern',),
'gassvernet': ('gassvern',),
'gast': ('gast',),
'gasten': ('gast',),
'gastene': ('gast',),
'gaster': ('gast',),
'gast': ('gast',),
'gasten': ('gast',),
'gastene': ('gast',),
'gaster': ('gast',),
'gastronom': ('gastronom',),
'gastronomen': ('gastronom',),
'gastronomene': ('gastronom',),
'gastronomer': ('gastronom',),
'gastronomi': ('gastronomi',),
'gastronomien': ('gastronomi',),
'gastronomiene': ('gastronomi',),
'gastronomier': ('gastronomi',),
'gata': ('gate',),
'gate': ('gate',),
'gaten': ('gate',),
'gatene': ('gate',),
'gater': ('gate',),
'gatebilda': ('gatebilde',),
'gatebilde': ('gatebilde',),
'gatebildene': ('gatebilde',),
'gatebilder': ('gatebilde',),
'gatebildet': ('gatebilde',),
'gatebruksplan': ('gatebruksplan',),
'gatebruksplanen': ('gatebruksplan',),
'gatebruksplanene': ('gatebruksplan',),
'gatebruksplaner': ('gatebruksplan',),
'gatedør': ('gatedør',),
'gatedøra': ('gatedør',),
'gatedøren': ('gatedør',),
'gatedørene': ('gatedør',),
'gatedører': ('gatedør',),
'gatefeier': ('gatefeier',),
'gatefeiere': ('gatefeier',),
'gatefeieren': ('gatefeier',),
'gatefeierer': ('gatefeier',),
'gatefeierne': ('gatefeier',),
'gategutt': ('gategutt',),
'gategutten': ('gategutt',),
'gateguttene': ('gategutt',),
'gategutter': ('gategutt',),
'gatehandel': ('gatehandel',),
'gatehandelen': ('gatehandel',),
'gatehandlene': ('gatehandel',),
'gatehandler': ('gatehandel',),
'gatehjørna': ('gatehjørne',),
'gatehjørne': ('gatehjørne',),
'gatehjørnene': ('gatehjørne',),
'gatehjørner': ('gatehjørne',),
'gatehjørnet': ('gatehjørne',),
'gatejenta': ('gatejente',),
'gatejente': ('gatejente',),
'gatejenten': ('gatejente',),
'gatejentene': ('gatejente',),
'gatejenter': ('gatejente',),
'gatejustis': ('gatejustis',),
'gatejustisen': ('gatejustis',),
'gatejustisene': ('gatejustis',),
'gatejustiser': ('gatejustis',),
'gatekamp': ('gatekamp',),
'gatekampen': ('gatekamp',),
'gatekampene': ('gatekamp',),
'gatekamper': ('gatekamp',),
'gatekjøkken': ('gatekjøkken',),
'gatekjøkkena': ('gatekjøkken',),
'gatekjøkkenene': ('gatekjøkken',),
'gatekjøkkener': ('gatekjøkken',),
'gatekjøkkenet': ('gatekjøkken',),
'gatekryss': ('gatekryss',),
'gatekryssa': ('gatekryss',),
'gatekryssene': ('gatekryss',),
'gatekrysset': ('gatekryss',),
'gatekultur': ('gatekultur',),
'gatekulturen': ('gatekultur',),
'gatekulturene': ('gatekultur',),
'gatekulturer': ('gatekultur',),
'gatelegema': ('gatelegeme',),
'gatelegeme': ('gatelegeme',),
'gatelegemene': ('gatelegeme',),
'gatelegemer': ('gatelegeme',),
'gatelegemet': ('gatelegeme',),
'gatelys': ('gatelys',),
'gatelysa': ('gatelys',),
'gatelysene': ('gatelys',),
'gatelyset': ('gatelys',),
'gateløp': ('gateløp',),
'gateløpa': ('gateløp',),
'gateløpene': ('gateløp',),
'gateløpet': ('gateløp',),
'gatemusikant': ('gatemusikant',),
'gatemusikanten': ('gatemusikant',),
'gatemusikantene': ('gatemusikant',),
'gatemusikanter': ('gatemusikant',),
'gatenett': ('gatenett',),
'gatenetta': ('gatenett',),
'gatenettene': ('gatenett',),
'gatenettet': ('gatenett',),
'gatenummer': ('gatenummer',),
'gatenummeret': ('gatenummer',),
'gatenumra': ('gatenummer',),
'gatenumre': ('gatenummer',),
'gatenumrene': ('gatenummer',),
'gateoppløp': ('gateoppløp',),
'gateoppløpa': ('gateoppløp',),
'gateoppløpene': ('gateoppløp',),
'gateoppløpet': ('gateoppløp',),
'gateopptøyene': ('gateopptøyer',),
'gateopptøyer': ('gateopptøyer',),
'gatepika': ('gatepike',),
'gatepike': ('gatepike',),
'gatepiken': ('gatepike',),
'gatepikene': ('gatepike',),
'gatepiker': ('gatepike',),
'gatesalg': ('gatesalg',),
'gatesalga': ('gatesalg',),
'gatesalgene': ('gatesalg',),
'gatesalget': ('gatesalg',),
'gatesanger': ('gatesanger',),
'gatesangere': ('gatesanger',),
'gatesangeren': ('gatesanger',),
'gatesangerer': ('gatesanger',),
'gatesangerne': ('gatesanger',),
'gateselger': ('gateselger',),
'gateselgere': ('gateselger',),
'gateselgeren': ('gateselger',),
'gateselgerer': ('gateselger',),
'gateselgerne': ('gateselger',),
'gatespråk': ('gatespråk',),
'gatespråka': ('gatespråk',),
'gatespråkene': ('gatespråk',),
'gatespråket': ('gatespråk',),
'gatestein': ('gatestein',),
'gatesteinen': ('gatestein',),
'gatesteinene': ('gatestein',),
'gatesteiner': ('gatestein',),
'gateteater': ('gateteater',),
'gateteateret': ('gateteater',),
'gateteatra': ('gateteater',),
'gateteatre': ('gateteater',),
'gateteatrene': ('gateteater',),
'gateteatret': ('gateteater',),
'gatetrafikk': ('gatetrafikk',),
'gatetrafikken': ('gatetrafikk',),
'gatetrafikkene': ('gatetrafikk',),
'gatetrafikker': ('gatetrafikk',),
'gatetun': ('gatetun',),
'gatetuna': ('gatetun',),
'gatetunene': ('gatetun',),
'gatetunet': ('gatetun',),
'gateuorden': ('gateuorden',),
'gateuordenen': ('gateuorden',),
'gateuordenene': ('gateuorden',),
'gateuordener': ('gateuorden',),
'gatevisa': ('gatevise',),
'gatevise': ('gatevise',),
'gatevisen': ('gatevise',),
'gatevisene': ('gatevise',),
'gateviser': ('gatevise',),
'gatt': ('gatt',),
'gatta': ('gatt',),
'gattene': ('gatt',),
'gattet': ('gatt',),
'gattfinna': ('gattfinne',),
'gattfinne': ('gattfinne',),
'gattfinnen': ('gattfinne',),
'gattfinnene': ('gattfinne',),
'gattfinner': ('gattfinne',),
'gaucho': ('gaucho',),
'gauchoen': ('gaucho',),
'gauchoene': ('gaucho',),
'gauchoer': ('gaucho',),
'gauda': ('gauda',),
'gaudaen': ('gauda',),
'gaudaene': ('gauda',),
'gaudaer': ('gauda',),
'gaudaost': ('gaudaost',),
'gaudaosten': ('gaudaost',),
'gaudaostene': ('gaudaost',),
'gaudaoster': ('gaudaost',),
'gauge': ('gauge',),
'gaugen': ('gauge',),
'gaugene': ('gauge',),
'gauk': ('gauk',),
'gauken': ('gauk',),
'gaukene': ('gauk',),
'gauker': ('gauk',),
'gauk': ('gauk',),
'gauken': ('gauk',),
'gaukene': ('gauk',),
'gauker': ('gauk',),
'gaukedag': ('gaukedag',),
'gaukedagen': ('gaukedag',),
'gaukedagene': ('gaukedag',),
'gaukedager': ('gaukedag',),
'gaukefamilie': ('gaukefamilie',),
'gaukefamilien': ('gaukefamilie',),
'gaukefamiliene': ('gaukefamilie',),
'gaukefamilier': ('gaukefamilie',),
'gaukegal': ('gaukegal',),
'gaukegala': ('gaukegal',),
'gaukegalene': ('gaukegal',),
'gaukegalet': ('gaukegal',),
'gaukemess': ('gaukemess',),
'gaukemor': ('gaukemor',),
'gaukemora': ('gaukemor',),
'gaukemoren': ('gaukemor',),
'gaukemødre': ('gaukemor',),
'gaukemødrene': ('gaukemor',),
'gaukemødrer': ('gaukemor',),
'gaukeri': ('gaukeri',),
'gaukeria': ('gaukeri',),
'gaukeriene': ('gaukeri',),
'gaukeriet': ('gaukeri',),
'gaukesprit': ('gaukesprit',),
'gaukespriten': ('gaukesprit',),
'gaukespritene': ('gaukesprit',),
'gaukespriter': ('gaukesprit',),
'gaukesyra': ('gaukesyre',),
'gaukesyre': ('gaukesyre',),
'gaukesyren': ('gaukesyre',),
'gaukesyrene': ('gaukesyre',),
'gaukesyrer': ('gaukesyre',),
'gauksmess': ('gauksmess',),
'gauksyra': ('gauksyre',),
'gauksyre': ('gauksyre',),
'gauksyren': ('gauksyre',),
'gauksyrene': ('gauksyre',),
'gauksyrer': ('gauksyre',),
'gaukunge': ('gaukunge',),
'gaukungen': ('gaukunge',),
'gaukungene': ('gaukunge',),
'gaukunger': ('gaukunge',),
'gaukur': ('gaukur',),
'gaukura': ('gaukur',),
'gaukurene': ('gaukur',),
'gaukuret': ('gaukur',),
'gaul': ('gaul',),
'gaula': ('gaul',),
'gaulene': ('gaul',),
'gaulet': ('gaul',),
'gaullisme': ('gaullisme',),
'gaullismen': ('gaullisme',),
'gaullismene': ('gaullisme',),
'gaullismer': ('gaullisme',),
'gaullist': ('gaullist',),
'gaullisten': ('gaullist',),
'gaullistene': ('gaullist',),
'gaullister': ('gaullist',),
'gaum': ('gaum',),
'gaumen': ('gaum',),
'gaumene': ('gaum',),
'gaumer': ('gaum',),
'gaupa': ('gaupe',),
'gaupe': ('gaupe',),
'gaupen': ('gaupe',),
'gaupene': ('gaupe',),
'gauper': ('gaupe',),
'gaupa': ('gaupe',),
'gaupe': ('gaupe',),
'gaupen': ('gaupe',),
'gaupene': ('gaupe',),
'gauper': ('gaupe',),
'gaus': ('gaus',),
'gausen': ('gaus',),
'gausene': ('gaus',),
'gauser': ('gaus',),
'gausskurve': ('gausskurve',),
'gausskurven': ('gausskurve',),
'gausskurvene': ('gausskurve',),
'gausskurver': ('gausskurve',),
'gauv': ('gauv',),
'gauven': ('gauv',),
'gauvene': ('gauv',),
'gauver': ('gauv',),
'gava': ('gave',),
'gave': ('gave',),
'gaven': ('gave',),
'gavene': ('gave',),
'gaver': ('gave',),
'gavebok': ('gavebok',),
'gaveboka': ('gavebok',),
'gaveboken': ('gavebok',),
'gavebøkene': ('gavebok',),
'gavebøker': ('gavebok',),
'gavebord': ('gavebord',),
'gaveborda': ('gavebord',),
'gavebordene': ('gavebord',),
'gaveborder': ('gavebord',),
'gavebordet': ('gavebord',),
'gavebrev': ('gavebrev',),
'gavebreva': ('gavebrev',),
'gavebrevene': ('gavebrev',),
'gavebrever': ('gavebrev',),
'gavebrevet': ('gavebrev',),
'gavekort': ('gavekort',),
'gavekorta': ('gavekort',),
'gavekortene': ('gavekort',),
'gavekortet': ('gavekort',),
'gavepakka': ('gavepakke',),
'gavepakke': ('gavepakke',),
'gavepakken': ('gavepakke',),
'gavepakkene': ('gavepakke',),
'gavepakker': ('gavepakke',),
'gavepremie': ('gavepremie',),
'gavepremien': ('gavepremie',),
'gavepremiene': ('gavepremie',),
'gavepremier': ('gavepremie',),
'gavitasjonskraft': ('gavitasjonskraft',),
'gavitasjonskrafta': ('gavitasjonskraft',),
'gavitasjonskraften': ('gavitasjonskraft',),
'gavitasjonskreftene': ('gavitasjonskraft',),
'gavitasjonskrefter': ('gavitasjonskraft',),
'gavl': ('gavl',),
'gavlen': ('gavl',),
'gavlene': ('gavl',),
'gavler': ('gavl',),
'gavlsida': ('gavlside',),
'gavlside': ('gavlside',),
'gavlsiden': ('gavlside',),
'gavlsidene': ('gavlside',),
'gavlsider': ('gavlside',),
'gavlvegg': ('gavlvegg',),
'gavlveggen': ('gavlvegg',),
'gavlveggene': ('gavlvegg',),
'gavlvegger': ('gavlvegg',),
'gavott': ('gavott',),
'gavotten': ('gavott',),
'gavottene': ('gavott',),
'gavotter': ('gavott',),
'geberde': ('geberde',),
'geberden': ('geberde',),
'geberdene': ('geberde',),
'geberder': ('geberde',),
'gebet': ('gebet',),
'gebeta': ('gebet',),
'gebetene': ('gebet',),
'gebeter': ('gebet',),
'gebetet': ('gebet',),
'gebiss': ('gebiss',),
'gebissa': ('gebiss',),
'gebissene': ('gebiss',),
'gebisser': ('gebiss',),
'gebisset': ('gebiss',),
'geburtsdag': ('geburtsdag',),
'geburtsdagen': ('geburtsdag',),
'geburtsdagene': ('geburtsdag',),
'geburtsdager': ('geburtsdag',),
'geburtsdagsbarn': ('geburtsdagsbarn',),
'geburtsdagsbarna': ('geburtsdagsbarn',),
'geburtsdagsbarnene': ('geburtsdagsbarn',),
'geburtsdagsbarnet': ('geburtsdagsbarn',),
'geburtsdagsgava': ('geburtsdagsgave',),
'geburtsdagsgave': ('geburtsdagsgave',),
'geburtsdagsgaven': ('geburtsdagsgave',),
'geburtsdagsgavene': ('geburtsdagsgave',),
'geburtsdagsgaver': ('geburtsdagsgave',),
'gebyr': ('gebyr',),
'gebyra': ('gebyr',),
'gebyrene': ('gebyr',),
'gebyrer': ('gebyr',),
'gebyret': ('gebyr',),
'gefundenes fressen': ('gefundenes fressen',),
'gehalt': ('gehalt',),
'gehalten': ('gehalt',),
'gehaltene': ('gehalt',),
'gehalter': ('gehalt',),
'geheimeråd': ('geheimeråd',),
'geheimeråden': ('geheimeråd',),
'geheimerådene': ('geheimeråd',),
'geheimeråder': ('geheimeråd',),
'geheng': ('geheng',),
'gehenga': ('geheng',),
'gehengene': ('geheng',),
'gehenget': ('geheng',),
'gehør': ('gehør',),
'gehøra': ('gehør',),
'gehørene': ('gehør',),
'gehøret': ('gehør',),
'geigerteller': ('geigerteller',),
'geigertellere': ('geigerteller',),
'geigertelleren': ('geigerteller',),
'geigertellerer': ('geigerteller',),
'geigertellerne': ('geigerteller',),
'geil': ('geil',),
'geila': ('geil',),
'geilen': ('geil',),
'geilene': ('geil',),
'geiler': ('geil',),
'geip': ('geip',),
'geipen': ('geip',),
'geipene': ('geip',),
'geiper': ('geip',),
'geip': ('geip',),
'geipa': ('geip',),
'geipen': ('geip',),
'geipene': ('geip',),
'geiper': ('geip',),
'geipet': ('geip',),
'geirfugl': ('geirfugl',),
'geirfuglen': ('geirfugl',),
'geirfuglene': ('geirfugl',),
'geirfugler': ('geirfugl',),
'geisha': ('geisha',),
'geishaen': ('geisha',),
'geishaene': ('geisha',),
'geishaer': ('geisha',),
'geist': ('geist',),
'geisten': ('geist',),
'geistene': ('geist',),
'geister': ('geist',),
'geistlighet': ('geistlighet',),
'geistligheta': ('geistlighet',),
'geistligheten': ('geistlighet',),
'geistlighetene': ('geistlighet',),
'geistligheter': ('geistlighet',),
'geit': ('geit',),
'geita': ('geit',),
'geiten': ('geit',),
'geitene': ('geit',),
'geiter': ('geit',),
'geitdoning': ('geitdoning',),
'geitdoninga': ('geitdoning',),
'geitdoningen': ('geitdoning',),
'geitdoningene': ('geitdoning',),
'geitdoninger': ('geitdoning',),
'geita': ('geite',),
'geite': ('geite',),
'geiten': ('geite',),
'geitene': ('geite',),
'geiter': ('geite',),
'geitebukk': ('geitebukk',),
'geitebukken': ('geitebukk',),
'geitebukkene': ('geitebukk',),
'geitebukker': ('geitebukk',),
'geitehams': ('geitehams',),
'geitehamsen': ('geitehams',),
'geitehamsene': ('geitehams',),
'geitehamser': ('geitehams',),
'geitehold': ('geitehold',),
'geiteholda': ('geitehold',),
'geiteholdene': ('geitehold',),
'geiteholdet': ('geitehold',),
'geitehår': ('geitehår',),
'geitehåra': ('geitehår',),
'geitehårene': ('geitehår',),
'geitehåret': ('geitehår',),
'geitekilling': ('geitekilling',),
'geitekillingen': ('geitekilling',),
'geitekillingene': ('geitekilling',),
'geitekillinger': ('geitekilling',),
'geitemelk': ('geitemelk',),
'geitemelka': ('geitemelk',),
'geitemelken': ('geitemelk',),
'geitemelkene': ('geitemelk',),
'geitemelker': ('geitemelk',),
'geitemjølk': ('geitemjølk',),
'geitemjølka': ('geitemjølk',),
'geitemjølken': ('geitemjølk',),
'geitemjølkene': ('geitemjølk',),
'geitemjølker': ('geitemjølk',),
'geiteragg': ('geiteragg',),
'geiteragga': ('geiteragg',),
'geiteraggene': ('geiteragg',),
'geiteragget': ('geiteragg',),
'geiterams': ('geiterams',),
'geiteramsen': ('geiterams',),
'geiteramsene': ('geiterams',),
'geiteramser': ('geiterams',),
'geithams': ('geithams',),
'geithamsen': ('geithams',),
'geithamsene': ('geithams',),
'geithamser': ('geithams',),
'geithår': ('geithår',),
'geithåra': ('geithår',),
'geithårene': ('geithår',),
'geithåret': ('geithår',),
'geitost': ('geitost',),
'geitosten': ('geitost',),
'geitostene': ('geitost',),
'geitoster': ('geitost',),
'geitrams': ('geitrams',),
'geitramsen': ('geitrams',),
'geitramsene': ('geitrams',),
'geitramser': ('geitrams',),
'geitrygg': ('geitrygg',),
'geitryggen': ('geitrygg',),
'geitryggene': ('geitrygg',),
'geitrygger': ('geitrygg',),
'geleen': ('gelé',),
'geleene': ('gelé',),
'geleer': ('gelé',),
'gelé': ('gelé',),
'geléen': ('gelé',),
'geléene': ('gelé',),
'geléer': ('gelé',),
'gelatin': ('gelatin',),
'gelatina': ('gelatin',),
'gelatinen': ('gelatin',),
'gelatinene': ('gelatin',),
'gelatiner': ('gelatin',),
'gelatinet': ('gelatin',),
'geledd': ('geledd',),
'geledda': ('geledd',),
'geleddene': ('geledd',),
'geledder': ('geledd',),
'geleddet': ('geledd',),
'gelender': ('gelender',),
'gelenderet': ('gelender',),
'gelendra': ('gelender',),
'gelendre': ('gelender',),
'gelendrene': ('gelender',),
'gelendret': ('gelender',),
'gelenk': ('gelenk',),
'gelenken': ('gelenk',),
'gelenkene': ('gelenk',),
'gelenker': ('gelenk',),
'gemakk': ('gemakk',),
'gemakka': ('gemakk',),
'gemakkene': ('gemakk',),
'gemakker': ('gemakk',),
'gemakket': ('gemakk',),
'gemal': ('gemal',),
'gemalen': ('gemal',),
'gemalene': ('gemal',),
'gemaler': ('gemal',),
'gemalinna': ('gemalinne',),
'gemalinne': ('gemalinne',),
'gemalinnen': ('gemalinne',),
'gemalinnene': ('gemalinne',),
'gemalinner': ('gemalinne',),
'gemeng': ('gemeng',),
'gemenga': ('gemeng',),
'gemengene': ('gemeng',),
'gemenger': ('gemeng',),
'gemenget': ('gemeng',),
'gemenhet': ('gemenhet',),
'gemenheta': ('gemenhet',),
'gemenheten': ('gemenhet',),
'gemenhetene': ('gemenhet',),
'gemenheter': ('gemenhet',),
'geminasjon': ('geminasjon',),
'geminasjonen': ('geminasjon',),
'geminasjonene': ('geminasjon',),
'geminasjoner': ('geminasjon',),
'geminat': ('geminat',),
'geminaten': ('geminat',),
'geminatene': ('geminat',),
'geminater': ('geminat',),
'gemme': ('gemme',),
'gemmen': ('gemme',),
'gemmene': ('gemme',),
'gemmer': ('gemme',),
'gemmolog': ('gemmolog',),
'gemmologen': ('gemmolog',),
'gemmologene': ('gemmolog',),
'gemmologer': ('gemmolog',),
'gemmologi': ('gemmologi',),
'gemmologien': ('gemmologi',),
'gemmologiene': ('gemmologi',),
'gemmologier': ('gemmologi',),
'gemse': ('gemse',),
'gemsen': ('gemse',),
'gemsene': ('gemse',),
'gemser': ('gemse',),
'gemytt': ('gemytt',),
'gemytta': ('gemytt',),
'gemyttene': ('gemytt',),
'gemytter': ('gemytt',),
'gemyttet': ('gemytt',),
'gemyttlighet': ('gemyttlighet',),
'gemyttligheta': ('gemyttlighet',),
'gemyttligheten': ('gemyttlighet',),
'gemyttlighetene': ('gemyttlighet',),
'gemyttligheter': ('gemyttlighet',),
'gen': ('gen',),
'gena': ('gen',),
'genen': ('gen',),
'genene': ('gen',),
'gener': ('gen',),
'genet': ('gen',),
'genbank': ('genbank',),
'genbanken': ('genbank',),
'genbankene': ('genbank',),
'genbanker': ('genbank',),
'gendarm': ('gendarm',),
'gendarmen': ('gendarm',),
'gendarmene': ('gendarm',),
'gendarmer': ('gendarm',),
'gendarmeri': ('gendarmeri',),
'gendarmeria': ('gendarmeri',),
'gendarmeriene': ('gendarmeri',),
'gendarmerier': ('gendarmeri',),
'gendarmeriet': ('gendarmeri',),
'genealog': ('genealog',),
'genealogen': ('genealog',),
'genealogene': ('genealog',),
'genealoger': ('genealog',),
'genealogi': ('genealogi',),
'genealogien': ('genealogi',),
'genealogiene': ('genealogi',),
'genealogier': ('genealogi',),
'general': ('general',),
'generalen': ('general',),
'generalene': ('general',),
'generaler': ('general',),
'generalagent': ('generalagent',),
'generalagenten': ('generalagent',),
'generalagentene': ('generalagent',),
'generalagenter': ('generalagent',),
'generaldebatt': ('generaldebatt',),
'generaldebatten': ('generaldebatt',),
'generaldebattene': ('generaldebatt',),
'generaldebatter': ('generaldebatt',),
'generaldirektør': ('generaldirektør',),
'generaldirektøren': ('generaldirektør',),
'generaldirektørene': ('generaldirektør',),
'generaldirektører': ('generaldirektør',),
'generalforsamling': ('generalforsamling',),
'generalforsamlinga': ('generalforsamling',),
'generalforsamlingen': ('generalforsamling',),
'generalforsamlingene': ('generalforsamling',),
'generalforsamlinger': ('generalforsamling',),
'generalguvernør': ('generalguvernør',),
'generalguvernøren': ('generalguvernør',),
'generalguvernørene': ('generalguvernør',),
'generalguvernører': ('generalguvernør',),
'generalinspektør': ('generalinspektør',),
'generalinspektøren': ('generalinspektør',),
'generalinspektørene': ('generalinspektør',),
'generalinspektører': ('generalinspektør',),
'generalisasjon': ('generalisasjon',),
'generalisasjonen': ('generalisasjon',),
'generalisasjonene': ('generalisasjon',),
'generalisasjoner': ('generalisasjon',),
'generalisering': ('generalisering',),
'generaliseringa': ('generalisering',),
'generaliseringen': ('generalisering',),
'generaliseringene': ('generalisering',),
'generaliseringer': ('generalisering',),
'generalissimus': ('generalissimus',),
'generalissimusen': ('generalissimus',),
'generalissimusene': ('generalissimus',),
'generalissimuser': ('generalissimus',),
'generalist': ('generalist',),
'generalisten': ('generalist',),
'generalistene': ('generalist',),
'generalister': ('generalist',),
'generalitet': ('generalitet',),
'generaliteten': ('generalitet',),
'generalitetene': ('generalitet',),
'generaliteter': ('generalitet',),
'generalitet': ('generalitet',),
'generaliteta': ('generalitet',),
'generalitetene': ('generalitet',),
'generaliteter': ('generalitet',),
'generalitetet': ('generalitet',),
'generalkonsul': ('generalkonsul',),
'generalkonsulen': ('generalkonsul',),
'generalkonsulene': ('generalkonsul',),
'generalkonsuler': ('generalkonsul',),
'generalkrigskommissær': ('generalkrigskommissær',),
'generalkrigskommissæren': ('generalkrigskommissær',),
'generalkrigskommissærene': ('generalkrigskommissær',),
'generalkrigskommissærer': ('generalkrigskommissær',),
'generalløytnant': ('generalløytnant',),
'generalløytnanten': ('generalløytnant',),
'generalløytnantene': ('generalløytnant',),
'generalløytnanter': ('generalløytnant',),
'generalmajor': ('generalmajor',),
'generalmajoren': ('generalmajor',),
'generalmajorene': ('generalmajor',),
'generalmajorer': ('generalmajor',),
'generalnevner': ('generalnevner',),
'generalnevnere': ('generalnevner',),
'generalnevneren': ('generalnevner',),
'generalnevnerer': ('generalnevner',),
'generalnevnerne': ('generalnevner',),
'generalnøkkel': ('generalnøkkel',),
'generalnøkkelen': ('generalnøkkel',),
'generalnøklene': ('generalnøkkel',),
'generalnøkler': ('generalnøkkel',),
'generalnøkkelsystem': ('generalnøkkelsystem',),
'generalnøkkelsystema': ('generalnøkkelsystem',),
'generalnøkkelsystemene': ('generalnøkkelsystem',),
'generalnøkkelsystemer': ('generalnøkkelsystem',),
'generalnøkkelsystemet': ('generalnøkkelsystem',),
'generalplan': ('generalplan',),
'generalplanen': ('generalplan',),
'generalplanene': ('generalplan',),
'generalplaner': ('generalplan',),
'generalprevensjon': ('generalprevensjon',),
'generalprevensjonen': ('generalprevensjon',),
'generalprevensjonene': ('generalprevensjon',),
'generalprevensjoner': ('generalprevensjon',),
'generalprøva': ('generalprøve',),
'generalprøve': ('generalprøve',),
'generalprøven': ('generalprøve',),
'generalprøvene': ('generalprøve',),
'generalprøver': ('generalprøve',),
'generalsekretær': ('generalsekretær',),
'generalsekretæren': ('generalsekretær',),
'generalsekretærene': ('generalsekretær',),
'generalsekretærer': ('generalsekretær',),
'generalstab': ('generalstab',),
'generalstaben': ('generalstab',),
'generalstabene': ('generalstab',),
'generalstaber': ('generalstab',),
'generalstreik': ('generalstreik',),
'generalstreiken': ('generalstreik',),
'generalstreikene': ('generalstreik',),
'generalstreiker': ('generalstreik',),
'generalsuniform': ('generalsuniform',),
'generalsuniforma': ('generalsuniform',),
'generalsuniformen': ('generalsuniform',),
'generalsuniformene': ('generalsuniform',),
'generalsuniformer': ('generalsuniform',),
'generaltabbe': ('generaltabbe',),
'generaltabben': ('generaltabbe',),
'generaltabbene': ('generaltabbe',),
'generaltabber': ('generaltabbe',),
'generaltabbe': ('generaltabbe',),
'generaltabben': ('generaltabbe',),
'generaltabbene': ('generaltabbe',),
'generaltabber': ('generaltabbe',),
'generasjon': ('generasjon',),
'generasjonen': ('generasjon',),
'generasjonene': ('generasjon',),
'generasjoner': ('generasjon',),
'generasjonsbolig': ('generasjonsbolig',),
'generasjonsboligen': ('generasjonsbolig',),
'generasjonsboligene': ('generasjonsbolig',),
'generasjonsboliger': ('generasjonsbolig',),
'generasjonsintervall': ('generasjonsintervall',),
'generasjonsintervalla': ('generasjonsintervall',),
'generasjonsintervallene': ('generasjonsintervall',),
'generasjonsintervaller': ('generasjonsintervall',),
'generasjonsintervallet': ('generasjonsintervall',),
'generasjonskløft': ('generasjonskløft',),
'generasjonskløfta': ('generasjonskløft',),
'generasjonskløften': ('generasjonskløft',),
'generasjonskløftene': ('generasjonskløft',),
'generasjonskløfter': ('generasjonskløft',),
'generasjonsmotsetning': ('generasjonsmotsetning',),
'generasjonsmotsetninga': ('generasjonsmotsetning',),
'generasjonsmotsetningen': ('generasjonsmotsetning',),
'generasjonsmotsetningene': ('generasjonsmotsetning',),
'generasjonsmotsetninger': ('generasjonsmotsetning',),
'generasjonsskifta': ('generasjonsskifte',),
'generasjonsskifte': ('generasjonsskifte',),
'generasjonsskiftene': ('generasjonsskifte',),
'generasjonsskifter': ('generasjonsskifte',),
'generasjonsskiftet': ('generasjonsskifte',),
'generasjonsveksel': ('generasjonsveksel',),
'generasjonsvekselen': ('generasjonsveksel',),
'generasjonsvekslene': ('generasjonsveksel',),
'generasjonsveksler': ('generasjonsveksel',),
'generator': ('generator',),
'generatoren': ('generator',),
'generatorene': ('generator',),
'generatorer': ('generator',),
'generatorgass': ('generatorgass',),
'generatorgassen': ('generatorgass',),
'generatorgassene': ('generatorgass',),
'generatorgasser': ('generatorgass',),
'genese': ('genese',),
'genesen': ('genese',),
'genesene': ('genese',),
'geneser': ('genese',),
'genesis': ('genesis',),
'genesisen': ('genesis',),
'genesisene': ('genesis',),
'genesiser': ('genesis',),
'genetiker': ('genetiker',),
'genetikere': ('genetiker',),
'genetikeren': ('genetiker',),
'genetikerer': ('genetiker',),
'genetikerne': ('genetiker',),
'genetikk': ('genetikk',),
'genetikken': ('genetikk',),
'genetikkene': ('genetikk',),
'genetikker': ('genetikk',),
'genfer': ('genfer',),
'genfere': ('genfer',),
'genferen': ('genfer',),
'genferer': ('genfer',),
'genferne': ('genfer',),
'genferkors': ('genferkors',),
'genferkorsa': ('genferkors',),
'genferkorsene': ('genferkors',),
'genferkorset': ('genferkors',),
'genfkors': ('genfkors',),
'genfkorsa': ('genfkors',),
'genfkorsene': ('genfkors',),
'genfkorset': ('genfkors',),
'geni': ('geni',),
'genia': ('geni',),
'geniene': ('geni',),
'genier': ('geni',),
'geniet': ('geni',),
'genialitet': ('genialitet',),
'genialiteten': ('genialitet',),
'genialitetene': ('genialitet',),
'genialiteter': ('genialitet',),
'genistrek': ('genistrek',),
'genistreken': ('genistrek',),
'genistrekene': ('genistrek',),
'genistreker': ('genistrek',),
'genitalia': ('genitalia',),
'genitaliene': ('genitalia',),
'genitaliene': ('genitalier',),
'genitalier': ('genitalier',),
'genitiv': ('genitiv',),
'genitiven': ('genitiv',),
'genitivene': ('genitiv',),
'genitiver': ('genitiv',),
'genitivs-s': ('genitivs-s',),
'genitivs-s-en': ('genitivs-s',),
'genitivs-s-ene': ('genitivs-s',),
'genitivs-s-er': ('genitivs-s',),
'geniene': ('genius',),
'genier': ('genius',),
'genius': ('genius',),
'geniusen': ('genius',),
'genmanipulering': ('genmanipulering',),
'genmanipuleringa': ('genmanipulering',),
'genmanipuleringen': ('genmanipulering',),
'genmanipuleringene': ('genmanipulering',),
'genmanipuleringer': ('genmanipulering',),
'genocid': ('genocid',),
'genocida': ('genocid',),
'genocidene': ('genocid',),
'genocider': ('genocid',),
'genocidet': ('genocid',),
'genotype': ('genotype',),
'genotypen': ('genotype',),
'genotypene': ('genotype',),
'genotyper': ('genotype',),
'genoveser': ('genoveser',),
'genovesere': ('genoveser',),
'genoveseren': ('genoveser',),
'genoveserer': ('genoveser',),
'genoveserne': ('genoveser',),
'genre': ('genre',),
'genren': ('genre',),
'genrene': ('genre',),
'genrer': ('genre',),
'genrebilda': ('genrebilde',),
'genrebilde': ('genrebilde',),
'genrebildene': ('genrebilde',),
'genrebilder': ('genrebilde',),
'genrebildet': ('genrebilde',),
'genser': ('genser',),
'gensere': ('genser',),
'genseren': ('genser',),
'genserer': ('genser',),
'genserne': ('genser',),
'genteknologi': ('genteknologi',),
'genteknologien': ('genteknologi',),
'genteknologiene': ('genteknologi',),
'genteknologier': ('genteknologi',),
'gentleman': ('gentleman',),
'gentlemen': ('gentleman',),
'gentlemen\'s agreement': ('gentlemen\'s agreement',),
'genuafokk': ('genuafokk',),
'genuafokka': ('genuafokk',),
'genuafokken': ('genuafokk',),
'genuafokkene': ('genuafokk',),
'genuafokker': ('genuafokk',),
'genueser': ('genueser',),
'genuesere': ('genueser',),
'genueseren': ('genueser',),
'genueserer': ('genueser',),
'genueserne': ('genueser',),
'genera': ('genus',),
'generaene': ('genus',),
'genus': ('genus',),
'genusa': ('genus',),
'genusen': ('genus',),
'genusene': ('genus',),
'genuset': ('genus',),
'geodesi': ('geodesi',),
'geodesien': ('geodesi',),
'geodesiene': ('geodesi',),
'geodesier': ('geodesi',),
'geodet': ('geodet',),
'geodeten': ('geodet',),
'geodetene': ('geodet',),
'geodeter': ('geodet',),
'geofysiker': ('geofysiker',),
'geofysikere': ('geofysiker',),
'geofysikeren': ('geofysiker',),
'geofysikerer': ('geofysiker',),
'geofysikerne': ('geofysiker',),
'geofysikk': ('geofysikk',),
'geofysikken': ('geofysikk',),
'geofysikkene': ('geofysikk',),
'geofysikker': ('geofysikk',),
'geograf': ('geograf',),
'geografen': ('geograf',),
'geografene': ('geograf',),
'geografer': ('geograf',),
'geografi': ('geografi',),
'geografien': ('geografi',),
'geografiene': ('geografi',),
'geografier': ('geografi',),
'geokjemi': ('geokjemi',),
'geokjemien': ('geokjemi',),
'geokjemiene': ('geokjemi',),
'geokjemier': ('geokjemi',),
'geolog': ('geolog',),
'geologen': ('geolog',),
'geologene': ('geolog',),
'geologer': ('geolog',),
'geologi': ('geologi',),
'geologien': ('geologi',),
'geologiene': ('geologi',),
'geologier': ('geologi',),
'geometer': ('geometer',),
'geometere': ('geometer',),
'geometeren': ('geometer',),
'geometerer': ('geometer',),
'geometerne': ('geometer',),
'geometri': ('geometri',),
'geometrien': ('geometri',),
'geometriene': ('geometri',),
'geometrier': ('geometri',),
'geopolitikk': ('geopolitikk',),
'geopolitikken': ('geopolitikk',),
'geopolitikkene': ('geopolitikk',),
'geopolitikker': ('geopolitikk',),
'georgette': ('georgette',),
'georgetten': ('georgette',),
'georgettene': ('georgette',),
'georgetter': ('georgette',),
'georgier': ('georgier',),
'georgiere': ('georgier',),
'georgieren': ('georgier',),
'georgierer': ('georgier',),
'georgierne': ('georgier',),
'georgina': ('georgine',),
'georgine': ('georgine',),
'georginen': ('georgine',),
'georginene': ('georgine',),
'georginer': ('georgine',),
'georgisme': ('georgisme',),
'georgismen': ('georgisme',),
'georgismene': ('georgisme',),
'georgismer': ('georgisme',),
'geoteknikk': ('geoteknikk',),
'geoteknikken': ('geoteknikk',),
'geoteknikkene': ('geoteknikk',),
'geoteknikker': ('geoteknikk',),
'geotropisme': ('geotropisme',),
'geotropismen': ('geotropisme',),
'geotropismene': ('geotropisme',),
'geotropismer': ('geotropisme',),
'gepard': ('gepard',),
'geparden': ('gepard',),
'gepardene': ('gepard',),
'geparder': ('gepard',),
'geranien': ('geranium',),
'geraniene': ('geranium',),
'geranier': ('geranium',),
'geranium': ('geranium',),
'geraniumen': ('geranium',),
'geraniumolja': ('geraniumolje',),
'geraniumolje': ('geraniumolje',),
'geraniumoljen': ('geraniumolje',),
'geraniumoljene': ('geraniumolje',),
'geraniumoljer': ('geraniumolje',),
'geriatri': ('geriatri',),
'geriatrien': ('geriatri',),
'geriatriene': ('geriatri',),
'geriatrier': ('geriatri',),
'gerikt': ('gerikt',),
'gerikten': ('gerikt',),
'geriktene': ('gerikt',),
'gerikter': ('gerikt',),
'gerilja': ('gerilja',),
'geriljaen': ('gerilja',),
'geriljaene': ('gerilja',),
'geriljaer': ('gerilja',),
'geriljaangrep': ('geriljaangrep',),
'geriljaangrepa': ('geriljaangrep',),
'geriljaangrepene': ('geriljaangrep',),
'geriljaangrepet': ('geriljaangrep',),
'geriljakrig': ('geriljakrig',),
'geriljakrigen': ('geriljakrig',),
'geriljakrigene': ('geriljakrig',),
'geriljakriger': ('geriljakrig',),
'geriljataktikk': ('geriljataktikk',),
'geriljataktikken': ('geriljataktikk',),
'geriljataktikkene': ('geriljataktikk',),
'geriljataktikker': ('geriljataktikk',),
'geriljavirksomhet': ('geriljavirksomhet',),
'geriljavirksomheta': ('geriljavirksomhet',),
'geriljavirksomheten': ('geriljavirksomhet',),
'geriljavirksomhetene': ('geriljavirksomhet',),
'geriljavirksomheter': ('geriljavirksomhet',),
'germaner': ('germaner',),
'germanere': ('germaner',),
'germaneren': ('germaner',),
'germanerer': ('germaner',),
'germanerne': ('germaner',),
'germanisme': ('germanisme',),
'germanismen': ('germanisme',),
'germanismene': ('germanisme',),
'germanismer': ('germanisme',),
'germanist': ('germanist',),
'germanisten': ('germanist',),
'germanistene': ('germanist',),
'germanister': ('germanist',),
'germanistikk': ('germanistikk',),
'germanistikken': ('germanistikk',),
'germanistikkene': ('germanistikk',),
'germanistikker': ('germanistikk',),
'germanium': ('germanium',),
'germaniuma': ('germanium',),
'germaniumene': ('germanium',),
'germaniumet': ('germanium',),
'gerontolog': ('gerontolog',),
'gerontologen': ('gerontolog',),
'gerontologene': ('gerontolog',),
'gerontologer': ('gerontolog',),
'gerontologi': ('gerontologi',),
'gerontologien': ('gerontologi',),
'gerontologiene': ('gerontologi',),
'gerontologier': ('gerontologi',),
'gesandt': ('gesandt',),
'gesandten': ('gesandt',),
'gesandtene': ('gesandt',),
'gesandter': ('gesandt',),
'gesandtskap': ('gesandtskap',),
'gesandtskapa': ('gesandtskap',),
'gesandtskapene': ('gesandtskap',),
'gesandtskaper': ('gesandtskap',),
'gesandtskapet': ('gesandtskap',),
'gesell': ('gesell',),
'gesellen': ('gesell',),
'gesellene': ('gesell',),
'geseller': ('gesell',),
'gesims': ('gesims',),
'gesimsen': ('gesims',),
'gesimsene': ('gesims',),
'gesimser': ('gesims',),
'gesimshøgd': ('gesimshøgd',),
'gesimshøgda': ('gesimshøgd',),
'gesimshøgdene': ('gesimshøgd',),
'gesimshøgder': ('gesimshøgd',),
'gesimshøyde': ('gesimshøyde',),
'gesimshøyden': ('gesimshøyde',),
'gesimshøydene': ('gesimshøyde',),
'gesimshøyder': ('gesimshøyde',),
'geskjeft': ('geskjeft',),
'geskjeften': ('geskjeft',),
'geskjeftene': ('geskjeft',),
'geskjefter': ('geskjeft',),
'gess': ('gess',),
'gessen': ('gess',),
'gessene': ('gess',),
'gesser': ('gess',),
'gest': ('gest',),
'gesten': ('gest',),
'gestene': ('gest',),
'gester': ('gest',),
'gestalt': ('gestalt',),
'gestalten': ('gestalt',),
'gestaltene': ('gestalt',),
'gestalter': ('gestalt',),
'gestaltpsykologi': ('gestaltpsykologi',),
'gestaltpsykologien': ('gestaltpsykologi',),
'gestaltpsykologiene': ('gestaltpsykologi',),
'gestaltpsykologier': ('gestaltpsykologi',),
'gestapist': ('gestapist',),
'gestapisten': ('gestapist',),
'gestapistene': ('gestapist',),
'gestapister': ('gestapist',),
'gestikulasjon': ('gestikulasjon',),
'gestikulasjonen': ('gestikulasjon',),
'gestikulasjonene': ('gestikulasjon',),
'gestikulasjoner': ('gestikulasjon',),
'gestene': ('gestus',),
'gester': ('gestus',),
'gestus': ('gestus',),
'gestusen': ('gestus',),
'gestusene': ('gestus',),
'gestuser': ('gestus',),
'getto': ('getto',),
'gettoen': ('getto',),
'gettoene': ('getto',),
'gettoer': ('getto',),
'gevant': ('gevant',),
'gevanta': ('gevant',),
'gevantene': ('gevant',),
'gevanter': ('gevant',),
'gevantet': ('gevant',),
'gevinst': ('gevinst',),
'gevinsten': ('gevinst',),
'gevinstene': ('gevinst',),
'gevinster': ('gevinst',),
'gevir': ('gevir',),
'gevira': ('gevir',),
'gevirene': ('gevir',),
'gevirer': ('gevir',),
'geviret': ('gevir',),
'gevær': ('gevær',),
'geværa': ('gevær',),
'geværene': ('gevær',),
'geværer': ('gevær',),
'geværet': ('gevær',),
'geværgranat': ('geværgranat',),
'geværgranaten': ('geværgranat',),
'geværgranatene': ('geværgranat',),
'geværgranater': ('geværgranat',),
'geværhane': ('geværhane',),
'geværhanen': ('geværhane',),
'geværhanene': ('geværhane',),
'geværhaner': ('geværhane',),
'geværkolbe': ('geværkolbe',),
'geværkolben': ('geværkolbe',),
'geværkolbene': ('geværkolbe',),
'geværkolber': ('geværkolbe',),
'geværmunning': ('geværmunning',),
'geværmunninga': ('geværmunning',),
'geværmunningen': ('geværmunning',),
'geværmunningene': ('geværmunning',),
'geværmunninger': ('geværmunning',),
'geværskjefta': ('geværskjefte',),
'geværskjefte': ('geværskjefte',),
'geværskjeftene': ('geværskjefte',),
'geværskjefter': ('geværskjefte',),
'geværskjeftet': ('geværskjefte',),
'geværskott': ('geværskott',),
'geværskotta': ('geværskott',),
'geværskottene': ('geværskott',),
'geværskottet': ('geværskott',),
'geværskudd': ('geværskudd',),
'geværskudda': ('geværskudd',),
'geværskuddene': ('geværskudd',),
'geværskuddet': ('geværskudd',),
'geysir': ('geysir',),
'geysiren': ('geysir',),
'geysirene': ('geysir',),
'geysirer': ('geysir',),
'ghaneser': ('ghaneser',),
'ghanesere': ('ghaneser',),
'ghaneseren': ('ghaneser',),
'ghaneserer': ('ghaneser',),
'ghaneserne': ('ghaneser',),
'ghostwriter': ('ghostwriter',),
'ghostwritere': ('ghostwriter',),
'ghostwriteren': ('ghostwriter',),
'ghostwriterer': ('ghostwriter',),
'ghostwriterne': ('ghostwriter',),
'gibbon': ('gibbon',),
'gibbonen': ('gibbon',),
'gibbonene': ('gibbon',),
'gibboner': ('gibbon',),
'gift': ('gift',),
'gifta': ('gift',),
'giften': ('gift',),
'giftene': ('gift',),
'gifter': ('gift',),
'giftampulle': ('giftampulle',),
'giftampullen': ('giftampulle',),
'giftampullene': ('giftampulle',),
'giftampuller': ('giftampulle',),
'giftbeger': ('giftbeger',),
'giftbegeret': ('giftbeger',),
'giftbegra': ('giftbeger',),
'giftbegre': ('giftbeger',),
'giftbegrene': ('giftbeger',),
'giftblanding': ('giftblanding',),
'giftblandinga': ('giftblanding',),
'giftblandingen': ('giftblanding',),
'giftblandingene': ('giftblanding',),
'giftblandinger': ('giftblanding',),
'giftbrodd': ('giftbrodd',),
'giftbrodden': ('giftbrodd',),
'giftbroddene': ('giftbrodd',),
'giftbrodder': ('giftbrodd',),
'gifta': ('gifte',),
'gifte': ('gifte',),
'giftene': ('gifte',),
'gifter': ('gifte',),
'giftet': ('gifte',),
'gifta': ('gifte',),
'gifte': ('gifte',),
'giften': ('gifte',),
'giftene': ('gifte',),
'gifter': ('gifte',),
'giftealder': ('giftealder',),
'giftealdere': ('giftealder',),
'giftealderen': ('giftealder',),
'giftealderer': ('giftealder',),
'giftealderne': ('giftealder',),
'giftealdre': ('giftealder',),
'giftealdrene': ('giftealder',),
'giftealdrer': ('giftealder',),
'giftekniv': ('giftekniv',),
'giftekniven': ('giftekniv',),
'gifteknivene': ('giftekniv',),
'giftekniver': ('giftekniv',),
'giftelyst': ('giftelyst',),
'giftelysta': ('giftelyst',),
'giftelysten': ('giftelyst',),
'giftelystene': ('giftelyst',),
'giftelyster': ('giftelyst',),
'giftering': ('giftering',),
'gifteringen': ('giftering',),
'gifteringene': ('giftering',),
'gifteringer': ('giftering',),
'giftermål': ('giftermål',),
'giftermåla': ('giftermål',),
'giftermålene': ('giftermål',),
'giftermålet': ('giftermål',),
'giftetankene': ('giftetanker',),
'giftetanker': ('giftetanker',),
'giftflua': ('giftflue',),
'giftflue': ('giftflue',),
'giftfluen': ('giftflue',),
'giftfluene': ('giftflue',),
'giftfluer': ('giftflue',),
'giftgass': ('giftgass',),
'giftgassen': ('giftgass',),
'giftgassene': ('giftgass',),
'giftgasser': ('giftgass',),
'giftighet': ('giftighet',),
'giftigheta': ('giftighet',),
'giftigheten': ('giftighet',),
'giftighetene': ('giftighet',),
'giftigheter': ('giftighet',),
'giftkartotek': ('giftkartotek',),
'giftkartoteka': ('giftkartotek',),
'giftkartotekene': ('giftkartotek',),
'giftkartoteker': ('giftkartotek',),
'giftkartoteket': ('giftkartotek',),
'giftkjertel': ('giftkjertel',),
'giftkjertelen': ('giftkjertel',),
'giftkjertlene': ('giftkjertel',),
'giftkjertler': ('giftkjertel',),
'giftmerka': ('giftmerke',),
'giftmerke': ('giftmerke',),
'giftmerkene': ('giftmerke',),
'giftmerker': ('giftmerke',),
'giftmerket': ('giftmerke',),
'giftmord': ('giftmord',),
'giftmorda': ('giftmord',),
'giftmordene': ('giftmord',),
'giftmordet': ('giftmord',),
'giftslange': ('giftslange',),
'giftslangen': ('giftslange',),
'giftslangene': ('giftslange',),
'giftslanger': ('giftslange',),
'giftstoff': ('giftstoff',),
'giftstoffa': ('giftstoff',),
'giftstoffene': ('giftstoff',),
'giftstoffer': ('giftstoff',),
'giftstoffet': ('giftstoff',),
'gifttann': ('gifttann',),
'gifttanna': ('gifttann',),
'gifttannen': ('gifttann',),
'gifttennene': ('gifttann',),
'gifttenner': ('gifttann',),
'giftutslepp': ('giftutslepp',),
'giftutsleppa': ('giftutslepp',),
'giftutsleppene': ('giftutslepp',),
'giftutsleppet': ('giftutslepp',),
'giftutslipp': ('giftutslipp',),
'giftutslippa': ('giftutslipp',),
'giftutslippene': ('giftutslipp',),
'giftutslippet': ('giftutslipp',),
'gigabyte': ('gigabyte',),
'gigabyten': ('gigabyte',),
'gigabytene': ('gigabyte',),
'gigahertz': ('gigahertz',),
'gigahertzen': ('gigahertz',),
'gigahertzene': ('gigahertz',),
'gigant': ('gigant',),
'giganten': ('gigant',),
'gigantene': ('gigant',),
'giganter': ('gigant',),
'gigantisme': ('gigantisme',),
'gigantismen': ('gigantisme',),
'gigantismene': ('gigantisme',),
'gigantismer': ('gigantisme',),
'gigantomani': ('gigantomani',),
'gigantomanien': ('gigantomani',),
'gigantomaniene': ('gigantomani',),
'gigantomanier': ('gigantomani',),
'gigawatt': ('gigawatt',),
'gigawatten': ('gigawatt',),
'gigawattene': ('gigawatt',),
'gigg': ('gigg',),
'giggen': ('gigg',),
'giggene': ('gigg',),
'gigger': ('gigg',),
'gigg': ('gigg',),
'giggen': ('gigg',),
'giggene': ('gigg',),
'gigger': ('gigg',),
'gigolo': ('gigolo',),
'gigoloen': ('gigolo',),
'gigoloene': ('gigolo',),
'gigoloer': ('gigolo',),
'gikt': ('gikt',),
'gikta': ('gikt',),
'gikten': ('gikt',),
'giktene': ('gikt',),
'gikter': ('gikt',),
'giktfeber': ('giktfeber',),
'giktfebere': ('giktfeber',),
'giktfeberen': ('giktfeber',),
'giktfeberne': ('giktfeber',),
'giktfebre': ('giktfeber',),
'giktfebrene': ('giktfeber',),
'giktfebrer': ('giktfeber',),
'giktiker': ('giktiker',),
'giktikere': ('giktiker',),
'giktikeren': ('giktiker',),
'giktikerer': ('giktiker',),
'giktikerne': ('giktiker',),
'gilda': ('gilde',),
'gilde': ('gilde',),
'gildene': ('gilde',),
'gilder': ('gilde',),
'gildet': ('gilde',),
'gildehall': ('gildehall',),
'gildehallen': ('gildehall',),
'gildehallene': ('gildehall',),
'gildehaller': ('gildehall',),
'gildeskrå': ('gildeskrå',),
'gildeskråa': ('gildeskrå',),
'gildeskråen': ('gildeskrå',),
'gildeskråene': ('gildeskrå',),
'gildeskråer': ('gildeskrå',),
'gildra': ('gildre',),
'gildre': ('gildre',),
'gildren': ('gildre',),
'gildrene': ('gildre',),
'gildrer': ('gildre',),
'giljotin': ('giljotin',),
'giljotinen': ('giljotin',),
'giljotinene': ('giljotin',),
'giljotiner': ('giljotin',),
'gimmer': ('gimmer',),
'gimra': ('gimmer',),
'gimren': ('gimmer',),
'gimrene': ('gimmer',),
'gimrer': ('gimmer',),
'gimmick': ('gimmick',),
'gimmicken': ('gimmick',),
'gimmickene': ('gimmick',),
'gimmicker': ('gimmick',),
'gin': ('gin',),
'ginen': ('gin',),
'ginene': ('gin',),
'giner': ('gin',),
'gingiva': ('gingiva',),
'gingivitt': ('gingivitt',),
'gingivitten': ('gingivitt',),
'gingivittene': ('gingivitt',),
'gingivitter': ('gingivitt',),
'ginseng': ('ginseng',),
'ginsengen': ('ginseng',),
'ginsengene': ('ginseng',),
'ginsenger': ('ginseng',),
'gips': ('gips',),
'gipsen': ('gips',),
'gipsene': ('gips',),
'gipser': ('gips',),
'gipsarbeid': ('gipsarbeid',),
'gipsarbeida': ('gipsarbeid',),
'gipsarbeidene': ('gipsarbeid',),
'gipsarbeider': ('gipsarbeid',),
'gipsarbeidet': ('gipsarbeid',),
'gipsavtrykk': ('gipsavtrykk',),
'gipsavtrykka': ('gipsavtrykk',),
'gipsavtrykkene': ('gipsavtrykk',),
'gipsavtrykket': ('gipsavtrykk',),
'gipsbandasje': ('gipsbandasje',),
'gipsbandasjen': ('gipsbandasje',),
'gipsbandasjene': ('gipsbandasje',),
'gipsbandasjer': ('gipsbandasje',),
'gipsfigur': ('gipsfigur',),
'gipsfiguren': ('gipsfigur',),
'gipsfigurene': ('gipsfigur',),
'gipsfigurer': ('gipsfigur',),
'gipsmaska': ('gipsmaske',),
'gipsmaske': ('gipsmaske',),
'gipsmasken': ('gipsmaske',),
'gipsmaskene': ('gipsmaske',),
'gipsmasker': ('gipsmaske',),
'gipsornament': ('gipsornament',),
'gipsornamenta': ('gipsornament',),
'gipsornamentene': ('gipsornament',),
'gipsornamenter': ('gipsornament',),
'gipsornamentet': ('gipsornament',),
'gipsrosett': ('gipsrosett',),
'gipsrosetten': ('gipsrosett',),
'gipsrosettene': ('gipsrosett',),
'gipsrosetter': ('gipsrosett',),
'gipstak': ('gipstak',),
'gipstaka': ('gipstak',),
'gipstakene': ('gipstak',),
'gipstaket': ('gipstak',),
'gir': ('gir',),
'giren': ('gir',),
'girene': ('gir',),
'girer': ('gir',),
'gir': ('gir',),
'giren': ('gir',),
'girene': ('gir',),
'girer': ('gir',),
'gir': ('gir',),
'gira': ('gir',),
'girene': ('gir',),
'giret': ('gir',),
'girant': ('girant',),
'giranten': ('girant',),
'girantene': ('girant',),
'giranter': ('girant',),
'girat': ('girat',),
'giraten': ('girat',),
'giratene': ('girat',),
'girater': ('girat',),
'giratar': ('giratar',),
'girataren': ('giratar',),
'giratarene': ('giratar',),
'giratarer': ('giratar',),
'girering': ('girering',),
'gireringa': ('girering',),
'gireringen': ('girering',),
'gireringene': ('girering',),
'gireringer': ('girering',),
'gireringsgebyr': ('gireringsgebyr',),
'gireringsgebyra': ('gireringsgebyr',),
'gireringsgebyrene': ('gireringsgebyr',),
'gireringsgebyrer': ('gireringsgebyr',),
'gireringsgebyret': ('gireringsgebyr',),
'girkassa': ('girkasse',),
'girkasse': ('girkasse',),
'girkassen': ('girkasse',),
'girkassene': ('girkasse',),
'girkasser': ('girkasse',),
'girlander': ('girlander',),
'girlandere': ('girlander',),
'girlanderen': ('girlander',),
'girlanderer': ('girlander',),
'girlanderne': ('girlander',),
'giro': ('giro',),
'giroen': ('giro',),
'giroene': ('giro',),
'giroer': ('giro',),
'giroblankett': ('giroblankett',),
'giroblanketten': ('giroblankett',),
'giroblankettene': ('giroblankett',),
'giroblanketter': ('giroblankett',),
'girokonti': ('girokonto',),
'girokontiene': ('girokonto',),
'girokonto': ('girokonto',),
'girokontoen': ('girokonto',),
'girokontoene': ('girokonto',),
'girokontoer': ('girokonto',),
'girokort': ('girokort',),
'girokorta': ('girokort',),
'girokortene': ('girokort',),
'girokortet': ('girokort',),
'girolja': ('girolje',),
'girolje': ('girolje',),
'giroljen': ('girolje',),
'giroljene': ('girolje',),
'giroljer': ('girolje',),
'girondiner': ('girondiner',),
'girondinere': ('girondiner',),
'girondineren': ('girondiner',),
'girondinerer': ('girondiner',),
'girondinerne': ('girondiner',),
'gironummer': ('gironummer',),
'gironummeret': ('gironummer',),
'gironumra': ('gironummer',),
'gironumre': ('gironummer',),
'gironumrene': ('gironummer',),
'girooverføring': ('girooverføring',),
'girooverføringa': ('girooverføring',),
'girooverføringen': ('girooverføring',),
'girooverføringene': ('girooverføring',),
'girooverføringer': ('girooverføring',),
'girstang': ('girstang',),
'girstanga': ('girstang',),
'girstangen': ('girstang',),
'girstengene': ('girstang',),
'girstenger': ('girstang',),
'gisp': ('gisp',),
'gispa': ('gisp',),
'gispene': ('gisp',),
'gispet': ('gisp',),
'giss': ('giss',),
'gissen': ('giss',),
'gissene': ('giss',),
'gisser': ('giss',),
'giss-moll': ('giss-moll',),
'giss-mollen': ('giss-moll',),
'giss-mollene': ('giss-moll',),
'giss-moller': ('giss-moll',),
'gisla': ('gissel',),
'gislene': ('gissel',),
'gisler': ('gissel',),
'gislet': ('gissel',),
'gissel': ('gissel',),
'gisselen': ('gissel',),
'gisselet': ('gissel',),
'gisseldrama': ('gisseldrama',),
'gisseldramaene': ('gisseldrama',),
'gisseldramaer': ('gisseldrama',),
'gisseldramaet': ('gisseldrama',),
'gitar': ('gitar',),
'gitaren': ('gitar',),
'gitarene': ('gitar',),
'gitarer': ('gitar',),
'gitarist': ('gitarist',),
'gitaristen': ('gitarist',),
'gitaristene': ('gitarist',),
'gitarister': ('gitarist',),
'gitarmusikk': ('gitarmusikk',),
'gitarmusikken': ('gitarmusikk',),
'gitarmusikkene': ('gitarmusikk',),
'gitarmusikker': ('gitarmusikk',),
'gitarstreng': ('gitarstreng',),
'gitarstrengen': ('gitarstreng',),
'gitarstrengene': ('gitarstreng',),
'gitarstrenger': ('gitarstreng',),
'gitra': ('gitter',),
'gitre': ('gitter',),
'gitrene': ('gitter',),
'gitret': ('gitter',),
'gitter': ('gitter',),
'gitteret': ('gitter',),
'gitterport': ('gitterport',),
'gitterporten': ('gitterport',),
'gitterportene': ('gitterport',),
'gitterporter': ('gitterport',),
'gitterverk': ('gitterverk',),
'gitterverka': ('gitterverk',),
'gitterverkene': ('gitterverk',),
'gitterverker': ('gitterverk',),
'gitterverket': ('gitterverk',),
'gittervindu': ('gittervindu',),
'gittervindua': ('gittervindu',),
'gittervinduene': ('gittervindu',),
'gittervinduer': ('gittervindu',),
'gittervinduet': ('gittervindu',),
'giv': ('giv',),
'given': ('giv',),
'givene': ('giv',),
'giver': ('giv',),
'givakt': ('givakt',),
'givakten': ('givakt',),
'givaktene': ('givakt',),
'givakter': ('givakt',),
'givaktstilling': ('givaktstilling',),
'givaktstillinga': ('givaktstilling',),
'givaktstillingen': ('givaktstilling',),
'givaktstillingene': ('givaktstilling',),
'givaktstillinger': ('givaktstilling',),
'giver': ('giver',),
'givere': ('giver',),
'giveren': ('giver',),
'giverer': ('giver',),
'giverne': ('giver',),
'givergleda': ('giverglede',),
'giverglede': ('giverglede',),
'givergleden': ('giverglede',),
'givergledene': ('giverglede',),
'givergleder': ('giverglede',),
'giverland': ('giverland',),
'giverlanda': ('giverland',),
'giverlandene': ('giverland',),
'giverlandet': ('giverland',),
'givnad': ('givnad',),
'givnaden': ('givnad',),
'givnadene': ('givnad',),
'givnader': ('givnad',),
'gjall': ('gjall',),
'gjalla': ('gjall',),
'gjallene': ('gjall',),
'gjallet': ('gjall',),
'gjedda': ('gjedde',),
'gjedde': ('gjedde',),
'gjedden': ('gjedde',),
'gjeddene': ('gjedde',),
'gjedder': ('gjedde',),
'gjeddefiska': ('gjeddefiske',),
'gjeddefiske': ('gjeddefiske',),
'gjeddefiskene': ('gjeddefiske',),
'gjeddefisker': ('gjeddefiske',),
'gjeddefisket': ('gjeddefiske',),
'gjekk': ('gjekk',),
'gjekken': ('gjekk',),
'gjekkene': ('gjekk',),
'gjekker': ('gjekk',),
'gjel': ('gjel',),
'gjela': ('gjel',),
'gjelene': ('gjel',),
'gjelet': ('gjel',),
'gjel': ('gjel',),
'gjela': ('gjel',),
'gjelen': ('gjel',),
'gjelene': ('gjel',),
'gjeler': ('gjel',),
'gjelet': ('gjel',),
'gjeld': ('gjeld',),
'gjelda': ('gjeld',),
'gjeldene': ('gjeld',),
'gjeldet': ('gjeld',),
'gjeld': ('gjeld',),
'gjelda': ('gjeld',),
'gjelden': ('gjeld',),
'gjeldene': ('gjeld',),
'gjelder': ('gjeld',),
'gjeldbukk': ('gjeldbukk',),
'gjeldbukken': ('gjeldbukk',),
'gjeldbukkene': ('gjeldbukk',),
'gjeldbukker': ('gjeldbukk',),
'gjelding': ('gjelding',),
'gjeldingen': ('gjelding',),
'gjeldingene': ('gjelding',),
'gjeldinger': ('gjelding',),
'gjeldkarve': ('gjeldkarve',),
'gjeldkarven': ('gjeldkarve',),
'gjeldkarvene': ('gjeldkarve',),
'gjeldkarver': ('gjeldkarve',),
'gjeldku': ('gjeldku',),
'gjeldkua': ('gjeldku',),
'gjeldkuen': ('gjeldku',),
'gjeldkuene': ('gjeldku',),
'gjeldkuer': ('gjeldku',),
'gjeldkyr': ('gjeldku',),
'gjeldkyrne': ('gjeldku',),
'gjeldokse': ('gjeldokse',),
'gjeldoksen': ('gjeldokse',),
'gjeldoksene': ('gjeldokse',),
'gjeldokser': ('gjeldokse',),
'gjeldsbrev': ('gjeldsbrev',),
'gjeldsbreva': ('gjeldsbrev',),
'gjeldsbrevene': ('gjeldsbrev',),
'gjeldsbrever': ('gjeldsbrev',),
'gjeldsbrevet': ('gjeldsbrev',),
'gjeldsfengsel': ('gjeldsfengsel',),
'gjeldsfengselet': ('gjeldsfengsel',),
'gjeldsfengsla': ('gjeldsfengsel',),
'gjeldsfengslene': ('gjeldsfengsel',),
'gjeldsfengsler': ('gjeldsfengsel',),
'gjeldsfengslet': ('gjeldsfengsel',),
'gjeldsoffer': ('gjeldsoffer',),
'gjeldsofferet': ('gjeldsoffer',),
'gjeldsofra': ('gjeldsoffer',),
'gjeldsofre': ('gjeldsoffer',),
'gjeldsofrene': ('gjeldsoffer',),
'gjeldspost': ('gjeldspost',),
'gjeldsposten': ('gjeldspost',),
'gjeldspostene': ('gjeldspost',),
'gjeldsposter': ('gjeldspost',),
'gjeldsrenta': ('gjeldsrente',),
'gjeldsrente': ('gjeldsrente',),
'gjeldsrenten': ('gjeldsrente',),
'gjeldsrentene': ('gjeldsrente',),
'gjeldsrenter': ('gjeldsrente',),
'gjeldstut': ('gjeldstut',),
'gjeldstuten': ('gjeldstut',),
'gjeldstutene': ('gjeldstut',),
'gjeldstuter': ('gjeldstut',),
'gjeldvær': ('gjeldvær',),
'gjeldværen': ('gjeldvær',),
'gjeldværene': ('gjeldvær',),
'gjeldværer': ('gjeldvær',),
'gjella': ('gjelle',),
'gjelle': ('gjelle',),
'gjellen': ('gjelle',),
'gjellene': ('gjelle',),
'gjeller': ('gjelle',),
'gjelleblad': ('gjelleblad',),
'gjelleblada': ('gjelleblad',),
'gjellebladene': ('gjelleblad',),
'gjelleblader': ('gjelleblad',),
'gjellebladet': ('gjelleblad',),
'gjellelokk': ('gjellelokk',),
'gjellelokka': ('gjellelokk',),
'gjellelokkene': ('gjellelokk',),
'gjellelokket': ('gjellelokk',),
'gjellespalta': ('gjellespalte',),
'gjellespalte': ('gjellespalte',),
'gjellespalten': ('gjellespalte',),
'gjellespaltene': ('gjellespalte',),
'gjellespalter': ('gjellespalte',),
'gjelleåpning': ('gjelleåpning',),
'gjelleåpninga': ('gjelleåpning',),
'gjelleåpningen': ('gjelleåpning',),
'gjelleåpningene': ('gjelleåpning',),
'gjelleåpninger': ('gjelleåpning',),
'gjemma': ('gjemme',),
'gjemme': ('gjemme',),
'gjemmene': ('gjemme',),
'gjemmer': ('gjemme',),
'gjemmet': ('gjemme',),
'gjemmested': ('gjemmested',),
'gjemmestedene': ('gjemmested',),
'gjemmesteder': ('gjemmested',),
'gjemmestedet': ('gjemmested',),
'gjemsel': ('gjemsel',),
'gjemselet': ('gjemsel',),
'gjemsla': ('gjemsel',),
'gjemslene': ('gjemsel',),
'gjemsler': ('gjemsel',),
'gjemslet': ('gjemsel',),
'gjenboer': ('gjenboer',),
'gjenboere': ('gjenboer',),
'gjenboeren': ('gjenboer',),
'gjenboerer': ('gjenboer',),
'gjenboerne': ('gjenboer',),
'gjenbruk': ('gjenbruk',),
'gjenbruka': ('gjenbruk',),
'gjenbruken': ('gjenbruk',),
'gjenbrukene': ('gjenbruk',),
'gjenbruker': ('gjenbruk',),
'gjenbruket': ('gjenbruk',),
'gjenbuer': ('gjenbuer',),
'gjenbuere': ('gjenbuer',),
'gjenbueren': ('gjenbuer',),
'gjenbuerer': ('gjenbuer',),
'gjenbuerne': ('gjenbuer',),
'gjendikting': ('gjendikting',),
'gjendiktinga': ('gjendikting',),
'gjendiktingen': ('gjendikting',),
'gjendiktingene': ('gjendikting',),
'gjendiktinger': ('gjendikting',),
'gjendiktning': ('gjendiktning',),
'gjendiktninga': ('gjendiktning',),
'gjendiktningen': ('gjendiktning',),
'gjendiktningene': ('gjendiktning',),
'gjendiktninger': ('gjendiktning',),
'gjendåp': ('gjendåp',),
'gjendåpen': ('gjendåp',),
'gjendåpene': ('gjendåp',),
'gjendåper': ('gjendåp',),
'gjendøper': ('gjendøper',),
'gjendøpere': ('gjendøper',),
'gjendøperen': ('gjendøper',),
'gjendøperer': ('gjendøper',),
'gjendøperne': ('gjendøper',),
'gjenferd': ('gjenferd',),
'gjenferda': ('gjenferd',),
'gjenferdene': ('gjenferd',),
'gjenferdet': ('gjenferd',),
'gjenfinning': ('gjenfinning',),
'gjenfinninga': ('gjenfinning',),
'gjenfinningen': ('gjenfinning',),
'gjenfinningene': ('gjenfinning',),
'gjenfinninger': ('gjenfinning',),
'gjenfortelling': ('gjenfortelling',),
'gjenfortellinga': ('gjenfortelling',),
'gjenfortellingen': ('gjenfortelling',),
'gjenfortellingene': ('gjenfortelling',),
'gjenfortellinger': ('gjenfortelling',),
'gjenfunn': ('gjenfunn',),
'gjenfunna': ('gjenfunn',),
'gjenfunnene': ('gjenfunn',),
'gjenfunnet': ('gjenfunn',),
'gjeng': ('gjeng',),
'gjengen': ('gjeng',),
'gjengene': ('gjeng',),
'gjenger': ('gjeng',),
'gjenganger': ('gjenganger',),
'gjengangere': ('gjenganger',),
'gjengangeren': ('gjenganger',),
'gjengangerer': ('gjenganger',),
'gjengangerne': ('gjenganger',),
'gjenga': ('gjenge',),
'gjenge': ('gjenge',),
'gjengen': ('gjenge',),
'gjengene': ('gjenge',),
'gjenger': ('gjenge',),
'gjenget': ('gjenge',),
'gjengelæra': ('gjengelære',),
'gjengelære': ('gjengelære',),
'gjengelæren': ('gjengelære',),
'gjengelærene': ('gjengelære',),
'gjengelærer': ('gjengelære',),
'gjengelæret': ('gjengelære',),
'gjengesnitt': ('gjengesnitt',),
'gjengesnitta': ('gjengesnitt',),
'gjengesnittene': ('gjengesnitt',),
'gjengesnittet': ('gjengesnitt',),
'gjengetapp': ('gjengetapp',),
'gjengetappen': ('gjengetapp',),
'gjengetappene': ('gjengetapp',),
'gjengetapper': ('gjengetapp',),
'gjengifta': ('gjengifte',),
'gjengifte': ('gjengifte',),
'gjengiftene': ('gjengifte',),
'gjengifter': ('gjengifte',),
'gjengiftet': ('gjengifte',),
'gjengivelse': ('gjengivelse',),
'gjengivelsen': ('gjengivelse',),
'gjengivelsene': ('gjengivelse',),
'gjengivelser': ('gjengivelse',),
'gjengjeldelse': ('gjengjeldelse',),
'gjengjeldelsen': ('gjengjeldelse',),
'gjengjeldelsene': ('gjengjeldelse',),
'gjengjeldelser': ('gjengjeldelse',),
'gjengjeldelsesaksjon': ('gjengjeldelsesaksjon',),
'gjengjeldelsesaksjonen': ('gjengjeldelsesaksjon',),
'gjengjeldelsesaksjonene': ('gjengjeldelsesaksjon',),
'gjengjeldelsesaksjoner': ('gjengjeldelsesaksjon',),
'gjenglans': ('gjenglans',),
'gjenglansen': ('gjenglans',),
'gjenglansene': ('gjenglans',),
'gjenglanser': ('gjenglans',),
'gjenhør': ('gjenhør',),
'gjenhøra': ('gjenhør',),
'gjenhørene': ('gjenhør',),
'gjenhøret': ('gjenhør',),
'gjenkjøp': ('gjenkjøp',),
'gjenkjøpa': ('gjenkjøp',),
'gjenkjøpene': ('gjenkjøp',),
'gjenkjøpet': ('gjenkjøp',),
'gjenkjøpsrett': ('gjenkjøpsrett',),
'gjenkjøpsretten': ('gjenkjøpsrett',),
'gjenkjøpsrettene': ('gjenkjøpsrett',),
'gjenkjøpsretter': ('gjenkjøpsrett',),
'gjenkjøpsverdi': ('gjenkjøpsverdi',),
'gjenkjøpsverdien': ('gjenkjøpsverdi',),
'gjenkjøpsverdiene': ('gjenkjøpsverdi',),
'gjenkjøpsverdier': ('gjenkjøpsverdi',),
'gjenklang': ('gjenklang',),
'gjenklangen': ('gjenklang',),
'gjenklangene': ('gjenklang',),
'gjenklanger': ('gjenklang',),
'gjenkomst': ('gjenkomst',),
'gjenkomsten': ('gjenkomst',),
'gjenkomstene': ('gjenkomst',),
'gjenkomster': ('gjenkomst',),
'gjenlegg': ('gjenlegg',),
'gjenlegga': ('gjenlegg',),
'gjenleggene': ('gjenlegg',),
'gjenlegget': ('gjenlegg',),
'gjenlyd': ('gjenlyd',),
'gjenlyden': ('gjenlyd',),
'gjenlydene': ('gjenlyd',),
'gjenlyder': ('gjenlyd',),
'gjenløser': ('gjenløser',),
'gjenløsere': ('gjenløser',),
'gjenløseren': ('gjenløser',),
'gjenløserer': ('gjenløser',),
'gjenløserne': ('gjenløser',),
'gjenmæla': ('gjenmæle',),
'gjenmæle': ('gjenmæle',),
'gjenmælene': ('gjenmæle',),
'gjenmæler': ('gjenmæle',),
'gjenmælet': ('gjenmæle',),
'gjennombrott': ('gjennombrott',),
'gjennombrotta': ('gjennombrott',),
'gjennombrottene': ('gjennombrott',),
'gjennombrottet': ('gjennombrott',),
'gjennombrudd': ('gjennombrudd',),
'gjennombrudda': ('gjennombrudd',),
'gjennombruddene': ('gjennombrudd',),
'gjennombruddet': ('gjennombrudd',),
'gjennomfart': ('gjennomfart',),
'gjennomfarten': ('gjennomfart',),
'gjennomfartene': ('gjennomfart',),
'gjennomfarter': ('gjennomfart',),
'gjennomfartsåra': ('gjennomfartsåre',),
'gjennomfartsåre': ('gjennomfartsåre',),
'gjennomfartsåren': ('gjennomfartsåre',),
'gjennomfartsårene': ('gjennomfartsåre',),
'gjennomfartsårer': ('gjennomfartsåre',),
'gjennomgang': ('gjennomgang',),
'gjennomgangen': ('gjennomgang',),
'gjennomgangene': ('gjennomgang',),
'gjennomganger': ('gjennomgang',),
'gjennomgangsbillett': ('gjennomgangsbillett',),
'gjennomgangsbilletten': ('gjennomgangsbillett',),
'gjennomgangsbillettene': ('gjennomgangsbillett',),
'gjennomgangsbilletter': ('gjennomgangsbillett',),
'gjennomgangsbolig': ('gjennomgangsbolig',),
'gjennomgangsboligen': ('gjennomgangsbolig',),
'gjennomgangsboligene': ('gjennomgangsbolig',),
'gjennomgangsboliger': ('gjennomgangsbolig',),
'gjennomgangsfigur': ('gjennomgangsfigur',),
'gjennomgangsfiguren': ('gjennomgangsfigur',),
'gjennomgangsfigurene': ('gjennomgangsfigur',),
'gjennomgangsfigurer': ('gjennomgangsfigur',),
'gjennomgangsleilighet': ('gjennomgangsleilighet',),
'gjennomgangsleiligheta': ('gjennomgangsleilighet',),
'gjennomgangsleiligheten': ('gjennomgangsleilighet',),
'gjennomgangsleilighetene': ('gjennomgangsleilighet',),
'gjennomgangsleiligheter': ('gjennomgangsleilighet',),
'gjennomgangsmelodi': ('gjennomgangsmelodi',),
'gjennomgangsmelodien': ('gjennomgangsmelodi',),
'gjennomgangsmelodiene': ('gjennomgangsmelodi',),
'gjennomgangsmelodier': ('gjennomgangsmelodi',),
'gjennomgangstema': ('gjennomgangstema',),
'gjennomgangstemaene': ('gjennomgangstema',),
'gjennomgangstemaer': ('gjennomgangstema',),
'gjennomgangstemaet': ('gjennomgangstema',),
'gjennomgangstrafikk': ('gjennomgangstrafikk',),
'gjennomgangstrafikken': ('gjennomgangstrafikk',),
'gjennomgangstrafikkene': ('gjennomgangstrafikk',),
'gjennomgangstrafikker': ('gjennomgangstrafikk',),
'gjennomgangsveg': ('gjennomgangsveg',),
'gjennomgangsvegen': ('gjennomgangsveg',),
'gjennomgangsvegene': ('gjennomgangsveg',),
'gjennomgangsveger': ('gjennomgangsveg',),
'gjennomgangsvei': ('gjennomgangsvei',),
'gjennomgangsveien': ('gjennomgangsvei',),
'gjennomgangsveiene': ('gjennomgangsvei',),
'gjennomgangsveier': ('gjennomgangsvei',),
'gjennomgåelse': ('gjennomgåelse',),
'gjennomgåelsen': ('gjennomgåelse',),
'gjennomgåelsene': ('gjennomgåelse',),
'gjennomgåelser': ('gjennomgåelse',),
'gjennomgåing': ('gjennomgåing',),
'gjennomgåinga': ('gjennomgåing',),
'gjennomgåingen': ('gjennomgåing',),
'gjennomgåingene': ('gjennomgåing',),
'gjennomgåinger': ('gjennomgåing',),
'gjennomkjøring': ('gjennomkjøring',),
'gjennomkjøringa': ('gjennomkjøring',),
'gjennomkjøringen': ('gjennomkjøring',),
'gjennomkjøringene': ('gjennomkjøring',),
'gjennomkjøringer': ('gjennomkjøring',),
'gjennomkjørsel': ('gjennomkjørsel',),
'gjennomkjørselen': ('gjennomkjørsel',),
'gjennomkjørsla': ('gjennomkjørsel',),
'gjennomkjørslene': ('gjennomkjørsel',),
'gjennomkjørsler': ('gjennomkjørsel',),
'gjennommarsj': ('gjennommarsj',),
'gjennommarsjen': ('gjennommarsj',),
'gjennommarsjene': ('gjennommarsj',),
'gjennommarsjer': ('gjennommarsj',),
'gjennomreisa': ('gjennomreise',),
'gjennomreise': ('gjennomreise',),
'gjennomreisen': ('gjennomreise',),
'gjennomreisene': ('gjennomreise',),
'gjennomreiser': ('gjennomreise',),
'gjennomslag': ('gjennomslag',),
'gjennomslaga': ('gjennomslag',),
'gjennomslagene': ('gjennomslag',),
'gjennomslaget': ('gjennomslag',),
'gjennomslagskraft': ('gjennomslagskraft',),
'gjennomslagskrafta': ('gjennomslagskraft',),
'gjennomslagskraften': ('gjennomslagskraft',),
'gjennomslagskreftene': ('gjennomslagskraft',),
'gjennomslagskrefter': ('gjennomslagskraft',),
'gjennomslagspapir': ('gjennomslagspapir',),
'gjennomslagspapira': ('gjennomslagspapir',),
'gjennomslagspapirene': ('gjennomslagspapir',),
'gjennomslagspapirer': ('gjennomslagspapir',),
'gjennomslagspapiret': ('gjennomslagspapir',),
'gjennomsnitt': ('gjennomsnitt',),
'gjennomsnitta': ('gjennomsnitt',),
'gjennomsnittene': ('gjennomsnitt',),
'gjennomsnittet': ('gjennomsnitt',),
'gjennomsnittsalder': ('gjennomsnittsalder',),
'gjennomsnittsaldere': ('gjennomsnittsalder',),
'gjennomsnittsalderen': ('gjennomsnittsalder',),
'gjennomsnittsalderer': ('gjennomsnittsalder',),
'gjennomsnittsalderne': ('gjennomsnittsalder',),
'gjennomsnittsaldre': ('gjennomsnittsalder',),
'gjennomsnittsaldrene': ('gjennomsnittsalder',),
'gjennomsnittsaldrer': ('gjennomsnittsalder',),
'gjennomsnittsinntekt': ('gjennomsnittsinntekt',),
'gjennomsnittsinntekta': ('gjennomsnittsinntekt',),
'gjennomsnittsinntekten': ('gjennomsnittsinntekt',),
'gjennomsnittsinntektene': ('gjennomsnittsinntekt',),
'gjennomsnittsinntekter': ('gjennomsnittsinntekt',),
'gjennomsnittsmenneska': ('gjennomsnittsmenneske',),
'gjennomsnittsmenneske': ('gjennomsnittsmenneske',),
'gjennomsnittsmenneskene': ('gjennomsnittsmenneske',),
'gjennomsnittsmennesker': ('gjennomsnittsmenneske',),
'gjennomsnittsmennesket': ('gjennomsnittsmenneske',),
'gjennomsnittstal': ('gjennomsnittstal',),
'gjennomsnittstala': ('gjennomsnittstal',),
'gjennomsnittstalene': ('gjennomsnittstal',),
'gjennomsnittstalet': ('gjennomsnittstal',),
'gjennomsnittstall': ('gjennomsnittstall',),
'gjennomsnittstalla': ('gjennomsnittstall',),
'gjennomsnittstallene': ('gjennomsnittstall',),
'gjennomsnittstallet': ('gjennomsnittstall',),
'gjennomsnittsverdi': ('gjennomsnittsverdi',),
'gjennomsnittsverdien': ('gjennomsnittsverdi',),
'gjennomsnittsverdiene': ('gjennomsnittsverdi',),
'gjennomsnittsverdier': ('gjennomsnittsverdi',),
'gjennomspell': ('gjennomspell',),
'gjennomspella': ('gjennomspell',),
'gjennomspellene': ('gjennomspell',),
'gjennomspellet': ('gjennomspell',),
'gjennomspill': ('gjennomspill',),
'gjennomspilla': ('gjennomspill',),
'gjennomspillene': ('gjennomspill',),
'gjennomspillet': ('gjennomspill',),
'gjennomsyn': ('gjennomsyn',),
'gjennomsyna': ('gjennomsyn',),
'gjennomsynene': ('gjennomsyn',),
'gjennomsynet': ('gjennomsyn',),
'gjennomtrekk': ('gjennomtrekk',),
'gjennomtrekka': ('gjennomtrekk',),
'gjennomtrekken': ('gjennomtrekk',),
'gjennomtrekkene': ('gjennomtrekk',),
'gjennomtrekker': ('gjennomtrekk',),
'gjennomtrekket': ('gjennomtrekk',),
'gjenoppdagelse': ('gjenoppdagelse',),
'gjenoppdagelsen': ('gjenoppdagelse',),
'gjenoppdagelsene': ('gjenoppdagelse',),
'gjenoppdagelser': ('gjenoppdagelse',),
'gjenoppdaging': ('gjenoppdaging',),
'gjenoppdaginga': ('gjenoppdaging',),
'gjenoppdagingen': ('gjenoppdaging',),
'gjenoppdagingene': ('gjenoppdaging',),
'gjenoppdaginger': ('gjenoppdaging',),
'gjenoppliving': ('gjenoppliving',),
'gjenopplivinga': ('gjenoppliving',),
'gjenopplivingen': ('gjenoppliving',),
'gjenopplivingene': ('gjenoppliving',),
'gjenopplivinger': ('gjenoppliving',),
'gjenopplivingsforsøk': ('gjenopplivingsforsøk',),
'gjenopplivingsforsøka': ('gjenopplivingsforsøk',),
'gjenopplivingsforsøkene': ('gjenopplivingsforsøk',),
'gjenopplivingsforsøket': ('gjenopplivingsforsøk',),
'gjenopplivning': ('gjenopplivning',),
'gjenopplivninga': ('gjenopplivning',),
'gjenopplivningen': ('gjenopplivning',),
'gjenopplivningene': ('gjenopplivning',),
'gjenopplivninger': ('gjenopplivning',),
'gjenopplivningsforsøk': ('gjenopplivningsforsøk',),
'gjenopplivningsforsøka': ('gjenopplivningsforsøk',),
'gjenopplivningsforsøkene': ('gjenopplivningsforsøk',),
'gjenopplivningsforsøket': ('gjenopplivningsforsøk',),
'gjenpart': ('gjenpart',),
'gjenparten': ('gjenpart',),
'gjenpartene': ('gjenpart',),
'gjenparter': ('gjenpart',),
'gjenskinn': ('gjenskinn',),
'gjenskinna': ('gjenskinn',),
'gjenskinnene': ('gjenskinn',),
'gjenskinnet': ('gjenskinn',),
'gjenstand': ('gjenstand',),
'gjenstanden': ('gjenstand',),
'gjenstandene': ('gjenstand',),
'gjenstander': ('gjenstand',),
'gjensvar': ('gjensvar',),
'gjensvara': ('gjensvar',),
'gjensvarene': ('gjensvar',),
'gjensvaret': ('gjensvar',),
'gjensyn': ('gjensyn',),
'gjensyna': ('gjensyn',),
'gjensynene': ('gjensyn',),
'gjensynet': ('gjensyn',),
'gjensynsgleda': ('gjensynsglede',),
'gjensynsglede': ('gjensynsglede',),
'gjensynsgleden': ('gjensynsglede',),
'gjensynsgledene': ('gjensynsglede',),
'gjensynsgleder': ('gjensynsglede',),
'gjensynshåp': ('gjensynshåp',),
'gjensynshåpa': ('gjensynshåp',),
'gjensynshåpene': ('gjensynshåp',),
'gjensynshåpet': ('gjensynshåp',),
'gjentaing': ('gjentaing',),
'gjentainga': ('gjentaing',),
'gjentaingen': ('gjentaing',),
'gjentaingene': ('gjentaing',),
'gjentainger': ('gjentaing',),
'gjentaingsstraff': ('gjentaingsstraff',),
'gjentaingsstraffen': ('gjentaingsstraff',),
'gjentaingsstraffene': ('gjentaingsstraff',),
'gjentaingsstraffer': ('gjentaingsstraff',),
'gjentaingstegn': ('gjentaingstegn',),
'gjentaingstegna': ('gjentaingstegn',),
'gjentaingstegnene': ('gjentaingstegn',),
'gjentaingstegnet': ('gjentaingstegn',),
'gjentaingstilfella': ('gjentaingstilfelle',),
'gjentaingstilfelle': ('gjentaingstilfelle',),
'gjentaingstilfellene': ('gjentaingstilfelle',),
'gjentaingstilfeller': ('gjentaingstilfelle',),
'gjentaingstilfellet': ('gjentaingstilfelle',),
'gjentakelse': ('gjentakelse',),
'gjentakelsen': ('gjentakelse',),
'gjentakelsene': ('gjentakelse',),
'gjentakelser': ('gjentakelse',),
'gjentakelsesstraff': ('gjentakelsesstraff',),
'gjentakelsesstraffen': ('gjentakelsesstraff',),
'gjentakelsesstraffene': ('gjentakelsesstraff',),
'gjentakelsesstraffer': ('gjentakelsesstraff',),
'gjentakelsestegn': ('gjentakelsestegn',),
'gjentakelsestegna': ('gjentakelsestegn',),
'gjentakelsestegnene': ('gjentakelsestegn',),
'gjentakelsestegnet': ('gjentakelsestegn',),
'gjentakelsestilfella': ('gjentakelsestilfelle',),
'gjentakelsestilfelle': ('gjentakelsestilfelle',),
'gjentakelsestilfellene': ('gjentakelsestilfelle',),
'gjentakelsestilfeller': ('gjentakelsestilfelle',),
'gjentakelsestilfellet': ('gjentakelsestilfelle',),
'gjentaking': ('gjentaking',),
'gjentakinga': ('gjentaking',),
'gjentakingen': ('gjentaking',),
'gjentakingene': ('gjentaking',),
'gjentakinger': ('gjentaking',),
'gjentakingsstraff': ('gjentakingsstraff',),
'gjentakingsstraffen': ('gjentakingsstraff',),
'gjentakingsstraffene': ('gjentakingsstraff',),
'gjentakingsstraffer': ('gjentakingsstraff',),
'gjentakingstegn': ('gjentakingstegn',),
'gjentakingstegna': ('gjentakingstegn',),
'gjentakingstegnene': ('gjentakingstegn',),
'gjentakingstegnet': ('gjentakingstegn',),
'gjentakingstilfella': ('gjentakingstilfelle',),
'gjentakingstilfelle': ('gjentakingstilfelle',),
'gjentakingstilfellene': ('gjentakingstilfelle',),
'gjentakingstilfeller': ('gjentakingstilfelle',),
'gjentakingstilfellet': ('gjentakingstilfelle',),
'gjenvalg': ('gjenvalg',),
'gjenvalga': ('gjenvalg',),
'gjenvalgene': ('gjenvalg',),
'gjenvalget': ('gjenvalg',),
'gjenveg': ('gjenveg',),
'gjenvegen': ('gjenveg',),
'gjenvegene': ('gjenveg',),
'gjenveger': ('gjenveg',),
'gjenvei': ('gjenvei',),
'gjenveien': ('gjenvei',),
'gjenveiene': ('gjenvei',),
'gjenveier': ('gjenvei',),
'gjenvekst': ('gjenvekst',),
'gjenveksten': ('gjenvekst',),
'gjenvekstene': ('gjenvekst',),
'gjenvekster': ('gjenvekst',),
'gjenvinning': ('gjenvinning',),
'gjenvinninga': ('gjenvinning',),
'gjenvinningen': ('gjenvinning',),
'gjenvinningene': ('gjenvinning',),
'gjenvinninger': ('gjenvinning',),
'gjenvisitt': ('gjenvisitt',),
'gjenvisitten': ('gjenvisitt',),
'gjenvisittene': ('gjenvisitt',),
'gjenvisitter': ('gjenvisitt',),
'gjenvordighet': ('gjenvordighet',),
'gjenvordigheta': ('gjenvordighet',),
'gjenvordigheten': ('gjenvordighet',),
'gjenvordighetene': ('gjenvordighet',),
'gjenvordigheter': ('gjenvordighet',),
'gjerd': ('gjerd',),
'gjerda': ('gjerd',),
'gjerden': ('gjerd',),
'gjerdene': ('gjerd',),
'gjerder': ('gjerd',),
'gjerda': ('gjerde',),
'gjerde': ('gjerde',),
'gjerdene': ('gjerde',),
'gjerder': ('gjerde',),
'gjerdet': ('gjerde',),
'gjerde': ('gjerde',),
'gjerdefang': ('gjerdefang',),
'gjerdefanga': ('gjerdefang',),
'gjerdefangene': ('gjerdefang',),
'gjerdefanget': ('gjerdefang',),
'gjerdehold': ('gjerdehold',),
'gjerdeholda': ('gjerdehold',),
'gjerdeholdene': ('gjerdehold',),
'gjerdeholdet': ('gjerdehold',),
'gjerdenetting': ('gjerdenetting',),
'gjerdenettingen': ('gjerdenetting',),
'gjerdenettingene': ('gjerdenetting',),
'gjerdenettinger': ('gjerdenetting',),
'gjerdeplikt': ('gjerdeplikt',),
'gjerdeplikta': ('gjerdeplikt',),
'gjerdeplikten': ('gjerdeplikt',),
'gjerdepliktene': ('gjerdeplikt',),
'gjerdeplikter': ('gjerdeplikt',),
'gjerdesitting': ('gjerdesitting',),
'gjerdesittinga': ('gjerdesitting',),
'gjerdesittingen': ('gjerdesitting',),
'gjerdesittingene': ('gjerdesitting',),
'gjerdesittinger': ('gjerdesitting',),
'gjerdesmett': ('gjerdesmett',),
'gjerdesmetten': ('gjerdesmett',),
'gjerdesmettene': ('gjerdesmett',),
'gjerdesmetter': ('gjerdesmett',),
'gjerdestaur': ('gjerdestaur',),
'gjerdestauren': ('gjerdestaur',),
'gjerdestaurene': ('gjerdestaur',),
'gjerdestaurer': ('gjerdestaur',),
'gjerdestolpe': ('gjerdestolpe',),
'gjerdestolpen': ('gjerdestolpe',),
'gjerdestolpene': ('gjerdestolpe',),
'gjerdestolper': ('gjerdestolpe',),
'gjerning': ('gjerning',),
'gjerninga': ('gjerning',),
'gjerningen': ('gjerning',),
'gjerningene': ('gjerning',),
'gjerninger': ('gjerning',),
'gjerningskristendom': ('gjerningskristendom',),
'gjerningskristendommen': ('gjerningskristendom',),
'gjerningskristendommene': ('gjerningskristendom',),
'gjerningskristendommer': ('gjerningskristendom',),
'gjerningsmann': ('gjerningsmann',),
'gjerningsmannen': ('gjerningsmann',),
'gjerningsmenn': ('gjerningsmann',),
'gjerningsmennene': ('gjerningsmann',),
'gjerningsord': ('gjerningsord',),
'gjerningsorda': ('gjerningsord',),
'gjerningsordene': ('gjerningsord',),
'gjerningsordet': ('gjerningsord',),
'gjerningssted': ('gjerningssted',),
'gjerningsstedene': ('gjerningssted',),
'gjerningssteder': ('gjerningssted',),
'gjerningsstedet': ('gjerningssted',),
'gjerningsøyeblikk': ('gjerningsøyeblikk',),
'gjerningsøyeblikka': ('gjerningsøyeblikk',),
'gjerningsøyeblikkene': ('gjerningsøyeblikk',),
'gjerningsøyeblikket': ('gjerningsøyeblikk',),
'gjerrigknark': ('gjerrigknark',),
'gjerrigknarken': ('gjerrigknark',),
'gjerrigknarkene': ('gjerrigknark',),
'gjerrigknarker': ('gjerrigknark',),
'gjertrudsdag': ('gjertrudsdag',),
'gjertrudsdagen': ('gjertrudsdag',),
'gjertrudsdagene': ('gjertrudsdag',),
'gjertrudsdager': ('gjertrudsdag',),
'gjertrudsfugl': ('gjertrudsfugl',),
'gjertrudsfuglen': ('gjertrudsfugl',),
'gjertrudsfuglene': ('gjertrudsfugl',),
'gjertrudsfugler': ('gjertrudsfugl',),
'gjertrudsmess': ('gjertrudsmess',),
'gjertrudsmesse': ('gjertrudsmesse',),
'gjesp': ('gjesp',),
'gjespa': ('gjesp',),
'gjespen': ('gjesp',),
'gjespene': ('gjesp',),
'gjesper': ('gjesp',),
'gjespet': ('gjesp',),
'gjest': ('gjest',),
'gjesten': ('gjest',),
'gjestene': ('gjest',),
'gjester': ('gjest',),
'gjestearbeider': ('gjestearbeider',),
'gjestearbeidere': ('gjestearbeider',),
'gjestearbeideren': ('gjestearbeider',),
'gjestearbeiderer': ('gjestearbeider',),
'gjestearbeiderne': ('gjestearbeider',),
'gjestebud': ('gjestebud',),
'gjestebuda': ('gjestebud',),
'gjestebudene': ('gjestebud',),
'gjestebudet': ('gjestebud',),
'gjestedirigent': ('gjestedirigent',),
'gjestedirigenten': ('gjestedirigent',),
'gjestedirigentene': ('gjestedirigent',),
'gjestedirigenter': ('gjestedirigent',),
'gjestedøger': ('gjestedøger',),
'gjestedøgeret': ('gjestedøger',),
'gjestedøgerne': ('gjestedøger',),
'gjestedøgn': ('gjestedøgn',),
'gjestedøgna': ('gjestedøgn',),
'gjestedøgnene': ('gjestedøgn',),
'gjestedøgnet': ('gjestedøgn',),
'gjesteforeleser': ('gjesteforeleser',),
'gjesteforelesere': ('gjesteforeleser',),
'gjesteforeleseren': ('gjesteforeleser',),
'gjesteforeleserer': ('gjesteforeleser',),
'gjesteforeleserne': ('gjesteforeleser',),
'gjesteforelesning': ('gjesteforelesning',),
'gjesteforelesninga': ('gjesteforelesning',),
'gjesteforelesningen': ('gjesteforelesning',),
'gjesteforelesningene': ('gjesteforelesning',),
'gjesteforelesninger': ('gjesteforelesning',),
'gjesteopptreden': ('gjesteopptreden',),
'gjesteopptredenen': ('gjesteopptreden',),
'gjesteopptredenene': ('gjesteopptreden',),
'gjesteopptredener': ('gjesteopptreden',),
'gjesteprofessor': ('gjesteprofessor',),
'gjesteprofessoren': ('gjesteprofessor',),
'gjesteprofessorene': ('gjesteprofessor',),
'gjesteprofessorer': ('gjesteprofessor',),
'gjesterolla': ('gjesterolle',),
'gjesterolle': ('gjesterolle',),
'gjesterollen': ('gjesterolle',),
'gjesterollene': ('gjesterolle',),
'gjesteroller': ('gjesterolle',),
'gjesterom': ('gjesterom',),
'gjesteromma': ('gjesterom',),
'gjesterommene': ('gjesterom',),
'gjesterommet': ('gjesterom',),
'gjestespell': ('gjestespell',),
'gjestespella': ('gjestespell',),
'gjestespellene': ('gjestespell',),
'gjestespellet': ('gjestespell',),
'gjestespill': ('gjestespill',),
'gjestespilla': ('gjestespill',),
'gjestespillene': ('gjestespill',),
'gjestespillet': ('gjestespill',),
'gjesteværelsa': ('gjesteværelse',),
'gjesteværelse': ('gjesteværelse',),
'gjesteværelsene': ('gjesteværelse',),
'gjesteværelser': ('gjesteværelse',),
'gjesteværelset': ('gjesteværelse',),
'gjestfrihet': ('gjestfrihet',),
'gjestfriheta': ('gjestfrihet',),
'gjestfriheten': ('gjestfrihet',),
'gjestfrihetene': ('gjestfrihet',),
'gjestfriheter': ('gjestfrihet',),
'gjestgiver': ('gjestgiver',),
'gjestgivere': ('gjestgiver',),
'gjestgiveren': ('gjestgiver',),
'gjestgiverer': ('gjestgiver',),
'gjestgiverne': ('gjestgiver',),
'gjestgiveri': ('gjestgiveri',),
'gjestgiveria': ('gjestgiveri',),
'gjestgiveriene': ('gjestgiveri',),
'gjestgiverier': ('gjestgiveri',),
'gjestgiveriet': ('gjestgiveri',),
'gjeter': ('gjeter',),
'gjetere': ('gjeter',),
'gjeteren': ('gjeter',),
'gjeterer': ('gjeter',),
'gjeterne': ('gjeter',),
'gjetergutt': ('gjetergutt',),
'gjetergutten': ('gjetergutt',),
'gjeterguttene': ('gjetergutt',),
'gjetergutter': ('gjetergutt',),
'gjeterjenta': ('gjeterjente',),
'gjeterjente': ('gjeterjente',),
'gjeterjenten': ('gjeterjente',),
'gjeterjentene': ('gjeterjente',),
'gjeterjenter': ('gjeterjente',),
'gjetertaska': ('gjetertaske',),
'gjetertaske': ('gjetertaske',),
'gjetertasken': ('gjetertaske',),
'gjetertaskene': ('gjetertaske',),
'gjetertasker': ('gjetertaske',),
'gjetning': ('gjetning',),
'gjetninga': ('gjetning',),
'gjetningen': ('gjetning',),
'gjetningene': ('gjetning',),
'gjetninger': ('gjetning',),
'gjetord': ('gjetord',),
'gjetorda': ('gjetord',),
'gjetordene': ('gjetord',),
'gjetordet': ('gjetord',),
'gjettekonkurranse': ('gjettekonkurranse',),
'gjettekonkurransen': ('gjettekonkurranse',),
'gjettekonkurransene': ('gjettekonkurranse',),
'gjettekonkurranser': ('gjettekonkurranse',),
'gjetteleik': ('gjetteleik',),
'gjetteleiken': ('gjetteleik',),
'gjetteleikene': ('gjetteleik',),
'gjetteleiker': ('gjetteleik',),
'gjettelek': ('gjettelek',),
'gjetteleken': ('gjettelek',),
'gjettelekene': ('gjettelek',),
'gjetteleker': ('gjettelek',),
'gjeving': ('gjeving',),
'gjevingen': ('gjeving',),
'gjevingene': ('gjeving',),
'gjevinger': ('gjeving',),
'gjeving': ('gjeving',),
'gjevingen': ('gjeving',),
'gjevingene': ('gjeving',),
'gjevinger': ('gjeving',),
'gjord': ('gjord',),
'gjorda': ('gjord',),
'gjorden': ('gjord',),
'gjordene': ('gjord',),
'gjorder': ('gjord',),
'gjura': ('gjure',),
'gjure': ('gjure',),
'gjuren': ('gjure',),
'gjurene': ('gjure',),
'gjurer': ('gjure',),
'gjær': ('gjær',),
'gjæren': ('gjær',),
'gjærene': ('gjær',),
'gjærer': ('gjær',),
'gjærbakst': ('gjærbakst',),
'gjærbaksten': ('gjærbakst',),
'gjærbakstene': ('gjærbakst',),
'gjærbakster': ('gjærbakst',),
'gjære': ('gjære',),
'gjærekassa': ('gjærekasse',),
'gjærekasse': ('gjærekasse',),
'gjærekassen': ('gjærekasse',),
'gjærekassene': ('gjærekasse',),
'gjærekasser': ('gjærekasse',),
'gjæresag': ('gjæresag',),
'gjæresaga': ('gjæresag',),
'gjæresagen': ('gjæresag',),
'gjæresagene': ('gjæresag',),
'gjæresager': ('gjæresag',),
'gjærfabrikk': ('gjærfabrikk',),
'gjærfabrikken': ('gjærfabrikk',),
'gjærfabrikkene': ('gjærfabrikk',),
'gjærfabrikker': ('gjærfabrikk',),
'gjæring': ('gjæring',),
'gjæringa': ('gjæring',),
'gjæringen': ('gjæring',),
'gjæringene': ('gjæring',),
'gjæringer': ('gjæring',),
'gjæringskar': ('gjæringskar',),
'gjæringskara': ('gjæringskar',),
'gjæringskarene': ('gjæringskar',),
'gjæringskaret': ('gjæringskar',),
'gjæringskum': ('gjæringskum',),
'gjæringskummen': ('gjæringskum',),
'gjæringskummene': ('gjæringskum',),
'gjæringskummer': ('gjæringskum',),
'gjæringsmiddel': ('gjæringsmiddel',),
'gjæringsmiddelet': ('gjæringsmiddel',),
'gjæringsmidla': ('gjæringsmiddel',),
'gjæringsmidlene': ('gjæringsmiddel',),
'gjæringsmidler': ('gjæringsmiddel',),
'gjæringsmidlet': ('gjæringsmiddel',),
'gjæringsprosess': ('gjæringsprosess',),
'gjæringsprosessen': ('gjæringsprosess',),
'gjæringsprosessene': ('gjæringsprosess',),
'gjæringsprosesser': ('gjæringsprosess',),
'gjæringstid': ('gjæringstid',),
'gjæringstida': ('gjæringstid',),
'gjæringstiden': ('gjæringstid',),
'gjæringstidene': ('gjæringstid',),
'gjæringstider': ('gjæringstid',),
'gjæringsvinkel': ('gjæringsvinkel',),
'gjæringsvinkelen': ('gjæringsvinkel',),
'gjæringsvinklene': ('gjæringsvinkel',),
'gjæringsvinkler': ('gjæringsvinkel',),
'gjærkassa': ('gjærkasse',),
'gjærkasse': ('gjærkasse',),
'gjærkassen': ('gjærkasse',),
'gjærkassene': ('gjærkasse',),
'gjærkasser': ('gjærkasse',),
'gjærlås': ('gjærlås',),
'gjærlåsa': ('gjærlås',),
'gjærlåsen': ('gjærlås',),
'gjærlåsene': ('gjærlås',),
'gjærlåser': ('gjærlås',),
'gjærlåset': ('gjærlås',),
'gjærpulver': ('gjærpulver',),
'gjærpulvera': ('gjærpulver',),
'gjærpulvere': ('gjærpulver',),
'gjærpulveret': ('gjærpulver',),
'gjærpulverne': ('gjærpulver',),
'gjærsag': ('gjærsag',),
'gjærsaga': ('gjærsag',),
'gjærsagen': ('gjærsag',),
'gjærsagene': ('gjærsag',),
'gjærsager': ('gjærsag',),
'gjærsopp': ('gjærsopp',),
'gjærsoppen': ('gjærsopp',),
'gjærsoppene': ('gjærsopp',),
'gjærsopper': ('gjærsopp',),
'gjærstoff': ('gjærstoff',),
'gjærstoffa': ('gjærstoff',),
'gjærstoffene': ('gjærstoff',),
'gjærstoffer': ('gjærstoff',),
'gjærstoffet': ('gjærstoff',),
'gjæving': ('gjæving',),
'gjævingen': ('gjæving',),
'gjævingene': ('gjæving',),
'gjævinger': ('gjæving',),
'gjæving': ('gjæving',),
'gjævingen': ('gjæving',),
'gjævingene': ('gjæving',),
'gjævinger': ('gjæving',),
'gjø': ('gjø',),
'gjøa': ('gjø',),
'gjøene': ('gjø',),
'gjøet': ('gjø',),
'gjødning': ('gjødning',),
'gjødninga': ('gjødning',),
'gjødningen': ('gjødning',),
'gjødningene': ('gjødning',),
'gjødninger': ('gjødning',),
'gjødsel': ('gjødsel',),
'gjødselen': ('gjødsel',),
'gjødsla': ('gjødsel',),
'gjødslene': ('gjødsel',),
'gjødsler': ('gjødsel',),
'gjødselbille': ('gjødselbille',),
'gjødselbillen': ('gjødselbille',),
'gjødselbillene': ('gjødselbille',),
'gjødselbiller': ('gjødselbille',),
'gjødselbing': ('gjødselbing',),
'gjødselbingen': ('gjødselbing',),
'gjødselbingene': ('gjødselbing',),
'gjødselbinger': ('gjødselbing',),
'gjødselbinge': ('gjødselbinge',),
'gjødselbingen': ('gjødselbinge',),
'gjødselbingene': ('gjødselbinge',),
'gjødselbinger': ('gjødselbinge',),
'gjødseldunge': ('gjødseldunge',),
'gjødseldungen': ('gjødseldunge',),
'gjødseldungene': ('gjødseldunge',),
'gjødseldunger': ('gjødseldunge',),
'gjødseldynga': ('gjødseldynge',),
'gjødseldynge': ('gjødseldynge',),
'gjødseldyngen': ('gjødseldynge',),
'gjødseldyngene': ('gjødseldynge',),
'gjødseldynger': ('gjødseldynge',),
'gjødselflua': ('gjødselflue',),
'gjødselflue': ('gjødselflue',),
'gjødselfluen': ('gjødselflue',),
'gjødselfluene': ('gjødselflue',),
'gjødselfluer': ('gjødselflue',),
'gjødselgass': ('gjødselgass',),
'gjødselgassen': ('gjødselgass',),
'gjødselgassene': ('gjødselgass',),
'gjødselgasser': ('gjødselgass',),
'gjødselgreip': ('gjødselgreip',),
'gjødselgreipa': ('gjødselgreip',),
'gjødselgreipen': ('gjødselgreip',),
'gjødselgreipene': ('gjødselgreip',),
'gjødselgreiper': ('gjødselgreip',),
'gjødselgreipet': ('gjødselgreip',),
'gjødselkjeller': ('gjødselkjeller',),
'gjødselkjellere': ('gjødselkjeller',),
'gjødselkjelleren': ('gjødselkjeller',),
'gjødselkjellerer': ('gjødselkjeller',),
'gjødselkjellerne': ('gjødselkjeller',),
'gjødselrenna': ('gjødselrenne',),
'gjødselrenne': ('gjødselrenne',),
'gjødselrennen': ('gjødselrenne',),
'gjødselrennene': ('gjødselrenne',),
'gjødselrenner': ('gjødselrenne',),
'gjødselspreder': ('gjødselspreder',),
'gjødselspredere': ('gjødselspreder',),
'gjødselsprederen': ('gjødselspreder',),
'gjødselsprederer': ('gjødselspreder',),
'gjødselsprederne': ('gjødselspreder',),
'gjødselspreier': ('gjødselspreier',),
'gjødselspreiere': ('gjødselspreier',),
'gjødselspreieren': ('gjødselspreier',),
'gjødselspreierer': ('gjødselspreier',),
'gjødselspreierne': ('gjødselspreier',),
'gjødselvann': ('gjødselvann',),
'gjødselvanna': ('gjødselvann',),
'gjødselvannene': ('gjødselvann',),
'gjødselvannet': ('gjødselvann',),
'gjødselvatn': ('gjødselvatn',),
'gjødselvatna': ('gjødselvatn',),
'gjødselvatnene': ('gjødselvatn',),
'gjødselvatnet': ('gjødselvatn',),
'gjødsling': ('gjødsling',),
'gjødslinga': ('gjødsling',),
'gjødslingen': ('gjødsling',),
'gjødslingene': ('gjødsling',),
'gjødslinger': ('gjødsling',),
'gjødslingsforsøk': ('gjødslingsforsøk',),
'gjødslingsforsøka': ('gjødslingsforsøk',),
'gjødslingsforsøkene': ('gjødslingsforsøk',),
'gjødslingsforsøket': ('gjødslingsforsøk',),
'gjødslingsvanning': ('gjødslingsvanning',),
'gjødslingsvanninga': ('gjødslingsvanning',),
'gjødslingsvanningen': ('gjødslingsvanning',),
'gjødslingsvanningene': ('gjødslingsvanning',),
'gjødslingsvanninger': ('gjødslingsvanning',),
'gjødslingsvatning': ('gjødslingsvatning',),
'gjødslingsvatninga': ('gjødslingsvatning',),
'gjødslingsvatningen': ('gjødslingsvatning',),
'gjødslingsvatningene': ('gjødslingsvatning',),
'gjødslingsvatninger': ('gjødslingsvatning',),
'gjøgl': ('gjøgl',),
'gjøgla': ('gjøgl',),
'gjøglene': ('gjøgl',),
'gjøglet': ('gjøgl',),
'gjøglebilda': ('gjøglebilde',),
'gjøglebilde': ('gjøglebilde',),
'gjøglebildene': ('gjøglebilde',),
'gjøglebilder': ('gjøglebilde',),
'gjøglebildet': ('gjøglebilde',),
'gjøgler': ('gjøgler',),
'gjøglere': ('gjøgler',),
'gjøgleren': ('gjøgler',),
'gjøglerer': ('gjøgler',),
'gjøglerne': ('gjøgler',),
'gjøglergleda': ('gjøglerglede',),
'gjøglerglede': ('gjøglerglede',),
'gjøglergleden': ('gjøglerglede',),
'gjøglergledene': ('gjøglerglede',),
'gjøglergleder': ('gjøglerglede',),
'gjøgleri': ('gjøgleri',),
'gjøgleria': ('gjøgleri',),
'gjøgleriene': ('gjøgleri',),
'gjøglerier': ('gjøgleri',),
'gjøgleriet': ('gjøgleri',),
'gjøglerkunst': ('gjøglerkunst',),
'gjøglerkunsten': ('gjøglerkunst',),
'gjøglerkunstene': ('gjøglerkunst',),
'gjøglerkunster': ('gjøglerkunst',),
'gjøglerspell': ('gjøglerspell',),
'gjøglerspella': ('gjøglerspell',),
'gjøglerspellene': ('gjøglerspell',),
'gjøglerspellet': ('gjøglerspell',),
'gjøglerspill': ('gjøglerspill',),
'gjøglerspilla': ('gjøglerspill',),
'gjøglerspillene': ('gjøglerspill',),
'gjøglerspillet': ('gjøglerspill',),
'gjøglertrupp': ('gjøglertrupp',),
'gjøglertruppen': ('gjøglertrupp',),
'gjøglertruppene': ('gjøglertrupp',),
'gjøglertrupper': ('gjøglertrupp',),
'gjøglerverk': ('gjøglerverk',),
'gjøglerverka': ('gjøglerverk',),
'gjøglerverkene': ('gjøglerverk',),
'gjøglerverker': ('gjøglerverk',),
'gjøglerverket': ('gjøglerverk',),
'gjøk': ('gjøk',),
'gjøken': ('gjøk',),
'gjøkene': ('gjøk',),
'gjøker': ('gjøk',),
'gjøkalv': ('gjøkalv',),
'gjøkalven': ('gjøkalv',),
'gjøkalvene': ('gjøkalv',),
'gjøkalver': ('gjøkalv',),
'gjøkefamilie': ('gjøkefamilie',),
'gjøkefamilien': ('gjøkefamilie',),
'gjøkefamiliene': ('gjøkefamilie',),
'gjøkefamilier': ('gjøkefamilie',),
'gjøkegal': ('gjøkegal',),
'gjøkegala': ('gjøkegal',),
'gjøkegalene': ('gjøkegal',),
'gjøkegalet': ('gjøkegal',),
'gjøkemor': ('gjøkemor',),
'gjøkemora': ('gjøkemor',),
'gjøkemoren': ('gjøkemor',),
'gjøkemødre': ('gjøkemor',),
'gjøkemødrene': ('gjøkemor',),
'gjøkemødrer': ('gjøkemor',),
'gjøkunge': ('gjøkunge',),
'gjøkungen': ('gjøkunge',),
'gjøkungene': ('gjøkunge',),
'gjøkunger': ('gjøkunge',),
'gjøkur': ('gjøkur',),
'gjøkura': ('gjøkur',),
'gjøkurene': ('gjøkur',),
'gjøkuret': ('gjøkur',),
'gjøler': ('gjøler',),
'gjølere': ('gjøler',),
'gjøleren': ('gjøler',),
'gjølerer': ('gjøler',),
'gjølerne': ('gjøler',),
'gjømmested': ('gjømmested',),
'gjømmestedene': ('gjømmested',),
'gjømmesteder': ('gjømmested',),
'gjømmestedet': ('gjømmested',),
'gjømsel': ('gjømsel',),
'gjømselet': ('gjømsel',),
'gjømsla': ('gjømsel',),
'gjømslene': ('gjømsel',),
'gjømsler': ('gjømsel',),
'gjømslet': ('gjømsel',),
'gjømsla': ('gjømsle',),
'gjømsle': ('gjømsle',),
'gjømslen': ('gjømsle',),
'gjømslene': ('gjømsle',),
'gjømsler': ('gjømsle',),
'gjømslet': ('gjømsle',),
'gjøn': ('gjøn',),
'gjøna': ('gjøn',),
'gjønene': ('gjøn',),
'gjønet': ('gjøn',),
'gjøremål': ('gjøremål',),
'gjøremåla': ('gjøremål',),
'gjøremålene': ('gjøremål',),
'gjøremålet': ('gjøremål',),
'gjøremåte': ('gjøremåte',),
'gjøremåten': ('gjøremåte',),
'gjøremåtene': ('gjøremåte',),
'gjøremåter': ('gjøremåte',),
'gjørma': ('gjørme',),
'gjørme': ('gjørme',),
'gjørmen': ('gjørme',),
'gjørmene': ('gjørme',),
'gjørmer': ('gjørme',),
'gjørmehol': ('gjørmehol',),
'gjørmehola': ('gjørmehol',),
'gjørmeholene': ('gjørmehol',),
'gjørmeholet': ('gjørmehol',),
'gjørmehull': ('gjørmehull',),
'gjørmehulla': ('gjørmehull',),
'gjørmehullene': ('gjørmehull',),
'gjørmehuller': ('gjørmehull',),
'gjørmehullet': ('gjørmehull',),
'gjørs': ('gjørs',),
'gjørsen': ('gjørs',),
'gjørsene': ('gjørs',),
'gjørser': ('gjørs',),
'gjørs': ('gjørs',),
'gjørtler': ('gjørtler',),
'gjørtlere': ('gjørtler',),
'gjørtleren': ('gjørtler',),
'gjørtlerer': ('gjørtler',),
'gjørtlerne': ('gjørtler',),
'gjøs': ('gjøs',),
'gjøsen': ('gjøs',),
'gjøsene': ('gjøs',),
'gjøser': ('gjøs',),
'glaceen': ('glacé',),
'glaceene': ('glacé',),
'glaceer': ('glacé',),
'glacé': ('glacé',),
'glacéen': ('glacé',),
'glacéene': ('glacé',),
'glacéer': ('glacé',),
'glacéhanske': ('glacéhanske',),
'glacéhansken': ('glacéhanske',),
'glacéhanskene': ('glacéhanske',),
'glacéhansker': ('glacéhanske',),
'glacélær': ('glacélær',),
'glacélæra': ('glacélær',),
'glacélærene': ('glacélær',),
'glacélæret': ('glacélær',),
'glad': ('glad',),
'glada': ('glad',),
'gladene': ('glad',),
'gladet': ('glad',),
'gladiator': ('gladiator',),
'gladiatoren': ('gladiator',),
'gladiatorene': ('gladiator',),
'gladiatorer': ('gladiator',),
'gladiatorkamp': ('gladiatorkamp',),
'gladiatorkampen': ('gladiatorkamp',),
'gladiatorkampene': ('gladiatorkamp',),
'gladiatorkamper': ('gladiatorkamp',),
'gladiatorspell': ('gladiatorspell',),
'gladiatorspella': ('gladiatorspell',),
'gladiatorspellene': ('gladiatorspell',),
'gladiatorspellet': ('gladiatorspell',),
'gladiatorspill': ('gladiatorspill',),
'gladiatorspilla': ('gladiatorspill',),
'gladiatorspillene': ('gladiatorspill',),
'gladiatorspillet': ('gladiatorspill',),
'gladiolene': ('gladiolus',),
'gladioler': ('gladiolus',),
'gladiolus': ('gladiolus',),
'gladiolusen': ('gladiolus',),
'gladiolusene': ('gladiolus',),
'gladioluser': ('gladiolus',),
'gladlynna': ('gladlynne',),
'gladlynne': ('gladlynne',),
'gladlynnene': ('gladlynne',),
'gladlynner': ('gladlynne',),
'gladlynnet': ('gladlynne',),
'glafs': ('glafs',),
'glafsen': ('glafs',),
'glafsene': ('glafs',),
'glafser': ('glafs',),
'glam': ('glam',),
'glamma': ('glam',),
'glammene': ('glam',),
'glammet': ('glam',),
'glamour': ('glamour',),
'glamouren': ('glamour',),
'glamourene': ('glamour',),
'glamourer': ('glamour',),
'glaning': ('glaning',),
'glaninga': ('glaning',),
'glaningen': ('glaning',),
'glaningene': ('glaning',),
'glaninger': ('glaning',),
'glans': ('glans',),
'glansen': ('glans',),
'glansene': ('glans',),
'glanser': ('glans',),
'glansbilda': ('glansbilde',),
'glansbilde': ('glansbilde',),
'glansbildene': ('glansbilde',),
'glansbilder': ('glansbilde',),
'glansbildet': ('glansbilde',),
'glansnummer': ('glansnummer',),
'glansnummeret': ('glansnummer',),
'glansnumra': ('glansnummer',),
'glansnumre': ('glansnummer',),
'glansnumrene': ('glansnummer',),
'glanspapir': ('glanspapir',),
'glanspapira': ('glanspapir',),
'glanspapirene': ('glanspapir',),
'glanspapirer': ('glanspapir',),
'glanspapiret': ('glanspapir',),
'glansperiode': ('glansperiode',),
'glansperioden': ('glansperiode',),
'glansperiodene': ('glansperiode',),
'glansperioder': ('glansperiode',),
'glansrolla': ('glansrolle',),
'glansrolle': ('glansrolle',),
'glansrollen': ('glansrolle',),
'glansrollene': ('glansrolle',),
'glansroller': ('glansrolle',),
'glanstid': ('glanstid',),
'glanstida': ('glanstid',),
'glanstiden': ('glanstid',),
'glanstidene': ('glanstid',),
'glanstider': ('glanstid',),
'glas': ('glas',),
'glasa': ('glas',),
'glasene': ('glas',),
'glaset': ('glas',),
'glas': ('glas',),
'glasa': ('glas',),
'glasene': ('glas',),
'glaset': ('glas',),
'glas': ('glas',),
'glasa': ('glas',),
'glasene': ('glas',),
'glaset': ('glas',),
'glasarbeid': ('glasarbeid',),
'glasarbeida': ('glasarbeid',),
'glasarbeidene': ('glasarbeid',),
'glasarbeider': ('glasarbeid',),
'glasarbeidet': ('glasarbeid',),
'glasarbeid': ('glasarbeid',),
'glasarbeida': ('glasarbeid',),
'glasarbeidene': ('glasarbeid',),
'glasarbeider': ('glasarbeid',),
'glasarbeidet': ('glasarbeid',),
'glasarbeider': ('glasarbeider',),
'glasarbeidere': ('glasarbeider',),
'glasarbeideren': ('glasarbeider',),
'glasarbeiderer': ('glasarbeider',),
'glasarbeiderne': ('glasarbeider',),
'glasarbeider': ('glasarbeider',),
'glasarbeidere': ('glasarbeider',),
'glasarbeideren': ('glasarbeider',),
'glasarbeiderer': ('glasarbeider',),
'glasarbeiderne': ('glasarbeider',),
'glasbenk': ('glasbenk',),
'glasbenken': ('glasbenk',),
'glasbenkene': ('glasbenk',),
'glasbenker': ('glasbenk',),
'glasbenk': ('glasbenk',),
'glasbenken': ('glasbenk',),
'glasbenkene': ('glasbenk',),
'glasbenker': ('glasbenk',),
'glasberg': ('glasberg',),
'glasberga': ('glasberg',),
'glasbergene': ('glasberg',),
'glasberget': ('glasberg',),
'glasberg': ('glasberg',),
'glasberga': ('glasberg',),
'glasbergene': ('glasberg',),
'glasberget': ('glasberg',),
'glasblåser': ('glasblåser',),
'glasblåsere': ('glasblåser',),
'glasblåseren': ('glasblåser',),
'glasblåserer': ('glasblåser',),
'glasblåserne': ('glasblåser',),
'glasblåser': ('glasblåser',),
'glasblåsere': ('glasblåser',),
'glasblåseren': ('glasblåser',),
'glasblåserer': ('glasblåser',),
'glasblåserne': ('glasblåser',),
'glasbrott': ('glasbrott',),
'glasbrotta': ('glasbrott',),
'glasbrottene': ('glasbrott',),
'glasbrottet': ('glasbrott',),
'glasbrott': ('glasbrott',),
'glasbrotta': ('glasbrott',),
'glasbrottene': ('glasbrott',),
'glasbrottet': ('glasbrott',),
'glasdør': ('glasdør',),
'glasdøra': ('glasdør',),
'glasdøren': ('glasdør',),
'glasdørene': ('glasdør',),
'glasdører': ('glasdør',),
'glasdør': ('glasdør',),
'glasdøra': ('glasdør',),
'glasdøren': ('glasdør',),
'glasdørene': ('glasdør',),
'glasdører': ('glasdør',),
'glasepla': ('glaseple',),
'glaseple': ('glaseple',),
'glaseplene': ('glaseple',),
'glasepler': ('glaseple',),
'glaseplet': ('glaseple',),
'glasepla': ('glaseple',),
'glaseple': ('glaseple',),
'glaseplene': ('glaseple',),
'glasepler': ('glaseple',),
'glaseplet': ('glaseple',),
'glasfiber': ('glasfiber',),
'glasfibere': ('glasfiber',),
'glasfiberen': ('glasfiber',),
'glasfiberne': ('glasfiber',),
'glasfibre': ('glasfiber',),
'glasfibrene': ('glasfiber',),
'glasfibrer': ('glasfiber',),
'glasfiber': ('glasfiber',),
'glasfibere': ('glasfiber',),
'glasfiberen': ('glasfiber',),
'glasfiberne': ('glasfiber',),
'glasfibre': ('glasfiber',),
'glasfibrene': ('glasfiber',),
'glasfibrer': ('glasfiber',),
'glasfiberplast': ('glasfiberplast',),
'glasfiberplasten': ('glasfiberplast',),
'glasfiberplastene': ('glasfiberplast',),
'glasfiberplaster': ('glasfiberplast',),
'glasfiberplast': ('glasfiberplast',),
'glasfiberplasten': ('glasfiberplast',),
'glasfiberplastene': ('glasfiberplast',),
'glasfiberplaster': ('glasfiberplast',),
'glasfiberplata': ('glasfiberplate',),
'glasfiberplate': ('glasfiberplate',),
'glasfiberplaten': ('glasfiberplate',),
'glasfiberplatene': ('glasfiberplate',),
'glasfiberplater': ('glasfiberplate',),
'glasfiberplata': ('glasfiberplate',),
'glasfiberplate': ('glasfiberplate',),
'glasfiberplaten': ('glasfiberplate',),
'glasfiberplatene': ('glasfiberplate',),
'glasfiberplater': ('glasfiberplate',),
'glasfiberstrie': ('glasfiberstrie',),
'glasfiberstrien': ('glasfiberstrie',),
'glasfiberstriene': ('glasfiberstrie',),
'glasfiberstrier': ('glasfiberstrie',),
'glashus': ('glashus',),
'glashusa': ('glashus',),
'glashusene': ('glashus',),
'glashuset': ('glashus',),
'glashus': ('glashus',),
'glashusa': ('glashus',),
'glashusene': ('glashus',),
'glashuset': ('glashus',),
'glashytta': ('glashytte',),
'glashytte': ('glashytte',),
'glashytten': ('glashytte',),
'glashyttene': ('glashytte',),
'glashytter': ('glashytte',),
'glashytta': ('glashytte',),
'glashytte': ('glashytte',),
'glashytten': ('glashytte',),
'glashyttene': ('glashytte',),
'glashytter': ('glashytte',),
'glasindustri': ('glasindustri',),
'glasindustrien': ('glasindustri',),
'glasindustriene': ('glasindustri',),
'glasindustrier': ('glasindustri',),
'glasindustri': ('glasindustri',),
'glasindustrien': ('glasindustri',),
'glasindustriene': ('glasindustri',),
'glasindustrier': ('glasindustri',),
'glasiolog': ('glasiolog',),
'glasiologen': ('glasiolog',),
'glasiologene': ('glasiolog',),
'glasiologer': ('glasiolog',),
'glasiologi': ('glasiologi',),
'glasiologien': ('glasiologi',),
'glasiologiene': ('glasiologi',),
'glasiologier': ('glasiologi',),
'glaslegema': ('glaslegeme',),
'glaslegeme': ('glaslegeme',),
'glaslegemene': ('glaslegeme',),
'glaslegemer': ('glaslegeme',),
'glaslegemet': ('glaslegeme',),
'glaslegema': ('glaslegeme',),
'glaslegeme': ('glaslegeme',),
'glaslegemene': ('glaslegeme',),
'glaslegemer': ('glaslegeme',),
'glaslegemet': ('glaslegeme',),
'glasmagasin': ('glasmagasin',),
'glasmagasina': ('glasmagasin',),
'glasmagasinene': ('glasmagasin',),
'glasmagasiner': ('glasmagasin',),
'glasmagasinet': ('glasmagasin',),
'glasmagasin': ('glasmagasin',),
'glasmagasina': ('glasmagasin',),
'glasmagasinene': ('glasmagasin',),
'glasmagasiner': ('glasmagasin',),
'glasmagasinet': ('glasmagasin',),
'glasmaleri': ('glasmaleri',),
'glasmaleria': ('glasmaleri',),
'glasmaleriene': ('glasmaleri',),
'glasmalerier': ('glasmaleri',),
'glasmaleriet': ('glasmaleri',),
'glasmaleri': ('glasmaleri',),
'glasmaleria': ('glasmaleri',),
'glasmaleriene': ('glasmaleri',),
'glasmalerier': ('glasmaleri',),
'glasmaleriet': ('glasmaleri',),
'glasmanet': ('glasmanet',),
'glasmaneta': ('glasmanet',),
'glasmaneten': ('glasmanet',),
'glasmanetene': ('glasmanet',),
'glasmaneter': ('glasmanet',),
'glasmester': ('glasmester',),
'glasmestere': ('glasmester',),
'glasmesteren': ('glasmester',),
'glasmesterer': ('glasmester',),
'glasmesterne': ('glasmester',),
'glasmestre': ('glasmester',),
'glasmestrene': ('glasmester',),
'glasmestrer': ('glasmester',),
'glasmester': ('glasmester',),
'glasmestere': ('glasmester',),
'glasmesteren': ('glasmester',),
'glasmesterer': ('glasmester',),
'glasmesterne': ('glasmester',),
'glasmestre': ('glasmester',),
'glasmestrene': ('glasmester',),
'glasmestrer': ('glasmester',),
'glasmesterdiamant': ('glasmesterdiamant',),
'glasmesterdiamanten': ('glasmesterdiamant',),
'glasmesterdiamantene': ('glasmesterdiamant',),
'glasmesterdiamanter': ('glasmesterdiamant',),
'glasmesterdiamant': ('glasmesterdiamant',),
'glasmesterdiamanten': ('glasmesterdiamant',),
'glasmesterdiamantene': ('glasmesterdiamant',),
'glasmesterdiamanter': ('glasmesterdiamant',),
'glasmosaikk': ('glasmosaikk',),
'glasmosaikken': ('glasmosaikk',),
'glasmosaikkene': ('glasmosaikk',),
'glasmosaikker': ('glasmosaikk',),
'glasmosaikk': ('glasmosaikk',),
'glasmosaikken': ('glasmosaikk',),
'glasmosaikkene': ('glasmosaikk',),
'glasmosaikker': ('glasmosaikk',),
'glasnost': ('glasnost',),
'glasnosten': ('glasnost',),
'glasnostene': ('glasnost',),
'glasnoster': ('glasnost',),
'glasprisma': ('glasprisme',),
'glasprisme': ('glasprisme',),
'glasprismene': ('glasprisme',),
'glasprismer': ('glasprisme',),
'glasprismet': ('glasprisme',),
'glasprisma': ('glasprisme',),
'glasprisme': ('glasprisme',),
'glasprismene': ('glasprisme',),
'glasprismer': ('glasprisme',),
'glasprismet': ('glasprisme',),
'glasruta': ('glasrute',),
'glasrute': ('glasrute',),
'glasruten': ('glasrute',),
'glasrutene': ('glasrute',),
'glasruter': ('glasrute',),
'glasruta': ('glasrute',),
'glasrute': ('glasrute',),
'glasruten': ('glasrute',),
'glasrutene': ('glasrute',),
'glasruter': ('glasrute',),
'glass': ('glass',),
'glassa': ('glass',),
'glassene': ('glass',),
'glasset': ('glass',),
'glass': ('glass',),
'glassa': ('glass',),
'glassene': ('glass',),
'glasset': ('glass',),
'glass-skjærer': ('glass-skjærer',),
'glass-skjærere': ('glass-skjærer',),
'glass-skjæreren': ('glass-skjærer',),
'glass-skjærerer': ('glass-skjærer',),
'glass-skjærerne': ('glass-skjærer',),
'glass-skår': ('glass-skår',),
'glass-skåra': ('glass-skår',),
'glass-skårene': ('glass-skår',),
'glass-skåret': ('glass-skår',),
'glass-sliper': ('glass-sliper',),
'glass-slipere': ('glass-sliper',),
'glass-sliperen': ('glass-sliper',),
'glass-sliperer': ('glass-sliper',),
'glass-sliperne': ('glass-sliper',),
'glass-sliperi': ('glass-sliperi',),
'glass-sliperia': ('glass-sliperi',),
'glass-sliperiene': ('glass-sliperi',),
'glass-sliperier': ('glass-sliperi',),
'glass-sliperiet': ('glass-sliperi',),
'glass-splint': ('glass-splint',),
'glass-splinten': ('glass-splint',),
'glass-splintene': ('glass-splint',),
'glass-splinter': ('glass-splint',),
'glassarbeid': ('glassarbeid',),
'glassarbeida': ('glassarbeid',),
'glassarbeidene': ('glassarbeid',),
'glassarbeider': ('glassarbeid',),
'glassarbeidet': ('glassarbeid',),
'glassarbeid': ('glassarbeid',),
'glassarbeida': ('glassarbeid',),
'glassarbeidene': ('glassarbeid',),
'glassarbeider': ('glassarbeid',),
'glassarbeidet': ('glassarbeid',),
'glassarbeider': ('glassarbeider',),
'glassarbeidere': ('glassarbeider',),
'glassarbeideren': ('glassarbeider',),
'glassarbeiderer': ('glassarbeider',),
'glassarbeiderne': ('glassarbeider',),
'glassarbeider': ('glassarbeider',),
'glassarbeidere': ('glassarbeider',),
'glassarbeideren': ('glassarbeider',),
'glassarbeiderer': ('glassarbeider',),
'glassarbeiderne': ('glassarbeider',),
'glassbenk': ('glassbenk',),
'glassbenken': ('glassbenk',),
'glassbenkene': ('glassbenk',),
'glassbenker': ('glassbenk',),
'glassbenk': ('glassbenk',),
'glassbenken': ('glassbenk',),
'glassbenkene': ('glassbenk',),
'glassbenker': ('glassbenk',),
'glassberg': ('glassberg',),
'glassberga': ('glassberg',),
'glassbergene': ('glassberg',),
'glassberget': ('glassberg',),
'glassberg': ('glassberg',),
'glassberga': ('glassberg',),
'glassbergene': ('glassberg',),
'glassberget': ('glassberg',),
'glassblåser': ('glassblåser',),
'glassblåsere': ('glassblåser',),
'glassblåseren': ('glassblåser',),
'glassblåserer': ('glassblåser',),
'glassblåserne': ('glassblåser',),
'glassblåser': ('glassblåser',),
'glassblåsere': ('glassblåser',),
'glassblåseren': ('glassblåser',),
'glassblåserer': ('glassblåser',),
'glassblåserne': ('glassblåser',),
'glassbrott': ('glassbrott',),
'glassbrotta': ('glassbrott',),
'glassbrottene': ('glassbrott',),
'glassbrottet': ('glassbrott',),
'glassbrott': ('glassbrott',),
'glassbrotta': ('glassbrott',),
'glassbrottene': ('glassbrott',),
'glassbrottet': ('glassbrott',),
'glassdør': ('glassdør',),
'glassdøra': ('glassdør',),
'glassdøren': ('glassdør',),
'glassdørene': ('glassdør',),
'glassdører': ('glassdør',),
'glassdør': ('glassdør',),
'glassdøra': ('glassdør',),
'glassdøren': ('glassdør',),
'glassdørene': ('glassdør',),
'glassdører': ('glassdør',),
'glassepla': ('glasseple',),
'glasseple': ('glasseple',),
'glasseplene': ('glasseple',),
'glassepler': ('glasseple',),
'glasseplet': ('glasseple',),
'glassepla': ('glasseple',),
'glasseple': ('glasseple',),
'glasseplene': ('glasseple',),
'glassepler': ('glasseple',),
'glasseplet': ('glasseple',),
'glassfiber': ('glassfiber',),
'glassfibere': ('glassfiber',),
'glassfiberen': ('glassfiber',),
'glassfiberne': ('glassfiber',),
'glassfibre': ('glassfiber',),
'glassfibrene': ('glassfiber',),
'glassfibrer': ('glassfiber',),
'glassfiber': ('glassfiber',),
'glassfibere': ('glassfiber',),
'glassfiberen': ('glassfiber',),
'glassfiberne': ('glassfiber',),
'glassfibre': ('glassfiber',),
'glassfibrene': ('glassfiber',),
'glassfibrer': ('glassfiber',),
'glassfiberplast': ('glassfiberplast',),
'glassfiberplasten': ('glassfiberplast',),
'glassfiberplastene': ('glassfiberplast',),
'glassfiberplaster': ('glassfiberplast',),
'glassfiberplast': ('glassfiberplast',),
'glassfiberplasten': ('glassfiberplast',),
'glassfiberplastene': ('glassfiberplast',),
'glassfiberplaster': ('glassfiberplast',),
'glassfiberplata': ('glassfiberplate',),
'glassfiberplate': ('glassfiberplate',),
'glassfiberplaten': ('glassfiberplate',),
'glassfiberplatene': ('glassfiberplate',),
'glassfiberplater': ('glassfiberplate',),
'glassfiberplata': ('glassfiberplate',),
'glassfiberplate': ('glassfiberplate',),
'glassfiberplaten': ('glassfiberplate',),
'glassfiberplatene': ('glassfiberplate',),
'glassfiberplater': ('glassfiberplate',),
'glassfiberstrie': ('glassfiberstrie',),
'glassfiberstrien': ('glassfiberstrie',),
'glassfiberstriene': ('glassfiberstrie',),
'glassfiberstrier': ('glassfiberstrie',),
'glasshus': ('glasshus',),
'glasshusa': ('glasshus',),
'glasshusene': ('glasshus',),
'glasshuset': ('glasshus',),
'glasshus': ('glasshus',),
'glasshusa': ('glasshus',),
'glasshusene': ('glasshus',),
'glasshuset': ('glasshus',),
'glasshytta': ('glasshytte',),
'glasshytte': ('glasshytte',),
'glasshytten': ('glasshytte',),
'glasshyttene': ('glasshytte',),
'glasshytter': ('glasshytte',),
'glasshytta': ('glasshytte',),
'glasshytte': ('glasshytte',),
'glasshytten': ('glasshytte',),
'glasshyttene': ('glasshytte',),
'glasshytter': ('glasshytte',),
'glassindustri': ('glassindustri',),
'glassindustrien': ('glassindustri',),
'glassindustriene': ('glassindustri',),
'glassindustrier': ('glassindustri',),
'glassindustri': ('glassindustri',),
'glassindustrien': ('glassindustri',),
'glassindustriene': ('glassindustri',),
'glassindustrier': ('glassindustri',),
'glasskjærer': ('glasskjærer',),
'glasskjærere': ('glasskjærer',),
'glasskjæreren': ('glasskjærer',),
'glasskjærerer': ('glasskjærer',),
'glasskjærerne': ('glasskjærer',),
'glasskår': ('glasskår',),
'glasskåra': ('glasskår',),
'glasskårene': ('glasskår',),
'glasskåret': ('glasskår',),
'glasslegema': ('glasslegeme',),
'glasslegeme': ('glasslegeme',),
'glasslegemene': ('glasslegeme',),
'glasslegemer': ('glasslegeme',),
'glasslegemet': ('glasslegeme',),
'glasslegema': ('glasslegeme',),
'glasslegeme': ('glasslegeme',),
'glasslegemene': ('glasslegeme',),
'glasslegemer': ('glasslegeme',),
'glasslegemet': ('glasslegeme',),
'glassliper': ('glassliper',),
'glasslipere': ('glassliper',),
'glassliperen': ('glassliper',),
'glassliperer': ('glassliper',),
'glassliperne': ('glassliper',),
'glassliperi': ('glassliperi',),
'glassliperia': ('glassliperi',),
'glassliperiene': ('glassliperi',),
'glassliperier': ('glassliperi',),
'glassliperiet': ('glassliperi',),
'glassmagasin': ('glassmagasin',),
'glassmagasina': ('glassmagasin',),
'glassmagasinene': ('glassmagasin',),
'glassmagasiner': ('glassmagasin',),
'glassmagasinet': ('glassmagasin',),
'glassmagasin': ('glassmagasin',),
'glassmagasina': ('glassmagasin',),
'glassmagasinene': ('glassmagasin',),
'glassmagasiner': ('glassmagasin',),
'glassmagasinet': ('glassmagasin',),
'glassmaleri': ('glassmaleri',),
'glassmaleria': ('glassmaleri',),
'glassmaleriene': ('glassmaleri',),
'glassmalerier': ('glassmaleri',),
'glassmaleriet': ('glassmaleri',),
'glassmaleri': ('glassmaleri',),
'glassmaleria': ('glassmaleri',),
'glassmaleriene': ('glassmaleri',),
'glassmalerier': ('glassmaleri',),
'glassmaleriet': ('glassmaleri',),
'glassmanet': ('glassmanet',),
'glassmaneta': ('glassmanet',),
'glassmaneten': ('glassmanet',),
'glassmanetene': ('glassmanet',),
'glassmaneter': ('glassmanet',),
'glassmester': ('glassmester',),
'glassmestere': ('glassmester',),
'glassmesteren': ('glassmester',),
'glassmesterer': ('glassmester',),
'glassmesterne': ('glassmester',),
'glassmestre': ('glassmester',),
'glassmestrene': ('glassmester',),
'glassmestrer': ('glassmester',),
'glassmester': ('glassmester',),
'glassmestere': ('glassmester',),
'glassmesteren': ('glassmester',),
'glassmesterer': ('glassmester',),
'glassmesterne': ('glassmester',),
'glassmestre': ('glassmester',),
'glassmestrene': ('glassmester',),
'glassmestrer': ('glassmester',),
'glassmesterdiamant': ('glassmesterdiamant',),
'glassmesterdiamanten': ('glassmesterdiamant',),
'glassmesterdiamantene': ('glassmesterdiamant',),
'glassmesterdiamanter': ('glassmesterdiamant',),
'glassmesterdiamant': ('glassmesterdiamant',),
'glassmesterdiamanten': ('glassmesterdiamant',),
'glassmesterdiamantene': ('glassmesterdiamant',),
'glassmesterdiamanter': ('glassmesterdiamant',),
'glassmosaikk': ('glassmosaikk',),
'glassmosaikken': ('glassmosaikk',),
'glassmosaikkene': ('glassmosaikk',),
'glassmosaikker': ('glassmosaikk',),
'glassmosaikk': ('glassmosaikk',),
'glassmosaikken': ('glassmosaikk',),
'glassmosaikkene': ('glassmosaikk',),
'glassmosaikker': ('glassmosaikk',),
'glassplint': ('glassplint',),
'glassplinten': ('glassplint',),
'glassplintene': ('glassplint',),
'glassplinter': ('glassplint',),
'glassprisma': ('glassprisme',),
'glassprisme': ('glassprisme',),
'glassprismene': ('glassprisme',),
'glassprismer': ('glassprisme',),
'glassprismet': ('glassprisme',),
'glassprisma': ('glassprisme',),
'glassprisme': ('glassprisme',),
'glassprismene': ('glassprisme',),
'glassprismer': ('glassprisme',),
'glassprismet': ('glassprisme',),
'glassruta': ('glassrute',),
'glassrute': ('glassrute',),
'glassruten': ('glassrute',),
'glassrutene': ('glassrute',),
'glassruter': ('glassrute',),
'glassruta': ('glassrute',),
'glassrute': ('glassrute',),
'glassruten': ('glassrute',),
'glassrutene': ('glassrute',),
'glassruter': ('glassrute',),
'glassull': ('glassull',),
'glassulla': ('glassull',),
'glassullen': ('glassull',),
'glassullene': ('glassull',),
'glassuller': ('glassull',),
'glassvatt': ('glassvatt',),
'glassvatta': ('glassvatt',),
'glassvatten': ('glassvatt',),
'glassvattene': ('glassvatt',),
'glassvatter': ('glassvatt',),
'glassvattet': ('glassvatt',),
'glassvatt': ('glassvatt',),
'glassvatta': ('glassvatt',),
'glassvatten': ('glassvatt',),
'glassvattene': ('glassvatt',),
'glassvatter': ('glassvatt',),
'glassvattet': ('glassvatt',),
'glassvegg': ('glassvegg',),
'glassveggen': ('glassvegg',),
'glassveggene': ('glassvegg',),
'glassvegger': ('glassvegg',),
'glassvegg': ('glassvegg',),
'glassveggen': ('glassvegg',),
'glassveggene': ('glassvegg',),
'glassvegger': ('glassvegg',),
'glassveranda': ('glassveranda',),
'glassverandaen': ('glassveranda',),
'glassverandaene': ('glassveranda',),
'glassverandaer': ('glassveranda',),
'glassveranda': ('glassveranda',),
'glassverandaen': ('glassveranda',),
'glassverandaene': ('glassveranda',),
'glassverandaer': ('glassveranda',),
'glassverk': ('glassverk',),
'glassverka': ('glassverk',),
'glassverkene': ('glassverk',),
'glassverker': ('glassverk',),
'glassverket': ('glassverk',),
'glassverk': ('glassverk',),
'glassverka': ('glassverk',),
'glassverkene': ('glassverk',),
'glassverker': ('glassverk',),
'glassverket': ('glassverk',),
'glasull': ('glasull',),
'glasulla': ('glasull',),
'glasullen': ('glasull',),
'glasullene': ('glasull',),
'glasuller': ('glasull',),
'glasur': ('glasur',),
'glasuren': ('glasur',),
'glasurene': ('glasur',),
'glasurer': ('glasur',),
'glasvatt': ('glasvatt',),
'glasvatta': ('glasvatt',),
'glasvatten': ('glasvatt',),
'glasvattene': ('glasvatt',),
'glasvatter': ('glasvatt',),
'glasvattet': ('glasvatt',),
'glasvatt': ('glasvatt',),
'glasvatta': ('glasvatt',),
'glasvatten': ('glasvatt',),
'glasvattene': ('glasvatt',),
'glasvatter': ('glasvatt',),
'glasvattet': ('glasvatt',),
'glasvegg': ('glasvegg',),
'glasveggen': ('glasvegg',),
'glasveggene': ('glasvegg',),
'glasvegger': ('glasvegg',),
'glasvegg': ('glasvegg',),
'glasveggen': ('glasvegg',),
'glasveggene': ('glasvegg',),
'glasvegger': ('glasvegg',),
'glasveranda': ('glasveranda',),
'glasverandaen': ('glasveranda',),
'glasverandaene': ('glasveranda',),
'glasverandaer': ('glasveranda',),
'glasveranda': ('glasveranda',),
'glasverandaen': ('glasveranda',),
'glasverandaene': ('glasveranda',),
'glasverandaer': ('glasveranda',),
'glasverk': ('glasverk',),
'glasverka': ('glasverk',),
'glasverkene': ('glasverk',),
'glasverker': ('glasverk',),
'glasverket': ('glasverk',),
'glasverk': ('glasverk',),
'glasverka': ('glasverk',),
'glasverkene': ('glasverk',),
'glasverker': ('glasverk',),
'glasverket': ('glasverk',),
'glatta': ('glatte',),
'glatte': ('glatte',),
'glatten': ('glatte',),
'glattene': ('glatte',),
'glatter': ('glatte',),
'glattis': ('glattis',),
'glattisen': ('glattis',),
'glattisene': ('glattis',),
'glattiser': ('glattis',),
'glattkant': ('glattkant',),
'glattkanten': ('glattkant',),
'glattkantene': ('glattkant',),
'glattkanter': ('glattkant',),
'glattkjøring': ('glattkjøring',),
'glattkjøringa': ('glattkjøring',),
'glattkjøringen': ('glattkjøring',),
'glattkjøringene': ('glattkjøring',),
'glattkjøringer': ('glattkjøring',),
'glattkjøringsbane': ('glattkjøringsbane',),
'glattkjøringsbanen': ('glattkjøringsbane',),
'glattkjøringsbanene': ('glattkjøringsbane',),
'glattkjøringsbaner': ('glattkjøringsbane',),
'glattkjøringskurs': ('glattkjøringskurs',),
'glattkjøringskursa': ('glattkjøringskurs',),
'glattkjøringskursene': ('glattkjøringskurs',),
'glattkjøringskurser': ('glattkjøringskurs',),
'glattkjøringskurset': ('glattkjøringskurs',),
'glattkjøringskursene': ('glattkjøringskursus',),
'glattkjøringskurser': ('glattkjøringskursus',),
'glattkjøringskursus': ('glattkjøringskursus',),
'glattkjøringskursuset': ('glattkjøringskursus',),
'glattstrikking': ('glattstrikking',),
'glattstrikkinga': ('glattstrikking',),
'glattstrikkingen': ('glattstrikking',),
'glattstrikkingene': ('glattstrikking',),
'glattstrikkinger': ('glattstrikking',),
'glavin': ('glavin',),
'glavina': ('glavin',),
'glavinene': ('glavin',),
'glavinet': ('glavin',),
'gleda': ('glede',),
'glede': ('glede',),
'gleden': ('glede',),
'gledene': ('glede',),
'gleder': ('glede',),
'gledesbudskap': ('gledesbudskap',),
'gledesbudskapa': ('gledesbudskap',),
'gledesbudskapene': ('gledesbudskap',),
'gledesbudskaper': ('gledesbudskap',),
'gledesbudskapet': ('gledesbudskap',),
'gledesdag': ('gledesdag',),
'gledesdagen': ('gledesdag',),
'gledesdagene': ('gledesdag',),
'gledesdager': ('gledesdag',),
'gledesdreper': ('gledesdreper',),
'gledesdrepere': ('gledesdreper',),
'gledesdreperen': ('gledesdreper',),
'gledesdreperer': ('gledesdreper',),
'gledesdreperne': ('gledesdreper',),
'gledeshus': ('gledeshus',),
'gledeshusa': ('gledeshus',),
'gledeshusene': ('gledeshus',),
'gledeshuset': ('gledeshus',),
'gledespika': ('gledespike',),
'gledespike': ('gledespike',),
'gledespiken': ('gledespike',),
'gledespikene': ('gledespike',),
'gledespiker': ('gledespike',),
'gledesrop': ('gledesrop',),
'gledesropa': ('gledesrop',),
'gledesropene': ('gledesrop',),
'gledesropet': ('gledesrop',),
'gledesrus': ('gledesrus',),
'gledesrusa': ('gledesrus',),
'gledesrusen': ('gledesrus',),
'gledesrusene': ('gledesrus',),
'gledesruser': ('gledesrus',),
'gledesruset': ('gledesrus',),
'gledesspreder': ('gledesspreder',),
'gledesspredere': ('gledesspreder',),
'gledessprederen': ('gledesspreder',),
'gledessprederer': ('gledesspreder',),
'gledessprederne': ('gledesspreder',),
'gledeståra': ('gledeståre',),
'gledeståre': ('gledeståre',),
'gledeståren': ('gledeståre',),
'gledestårene': ('gledeståre',),
'gledestårer': ('gledeståre',),
'gledesutbrott': ('gledesutbrott',),
'gledesutbrotta': ('gledesutbrott',),
'gledesutbrottene': ('gledesutbrott',),
'gledesutbrottet': ('gledesutbrott',),
'gledesutbrudd': ('gledesutbrudd',),
'gledesutbrudda': ('gledesutbrudd',),
'gledesutbruddene': ('gledesutbrudd',),
'gledesutbruddet': ('gledesutbrudd',),
'gledesytring': ('gledesytring',),
'gledesytringa': ('gledesytring',),
'gledesytringen': ('gledesytring',),
'gledesytringene': ('gledesytring',),
'gledesytringer': ('gledesytring',),
'glefs': ('glefs',),
'glefsa': ('glefs',),
'glefsen': ('glefs',),
'glefsene': ('glefs',),
'glefset': ('glefs',),
'glefsa': ('glefse',),
'glefse': ('glefse',),
'glefsen': ('glefse',),
'glefsene': ('glefse',),
'glefser': ('glefse',),
'gleksa': ('glekse',),
'glekse': ('glekse',),
'gleksen': ('glekse',),
'gleksene': ('glekse',),
'glekser': ('glekse',),
'glemme': ('glemme',),
'glemmebok': ('glemmebok',),
'glemmeboka': ('glemmebok',),
'glemmeboken': ('glemmebok',),
'glemmebøkene': ('glemmebok',),
'glemmebøker': ('glemmebok',),
'glemsel': ('glemsel',),
'glemselen': ('glemsel',),
'glemslene': ('glemsel',),
'glemsler': ('glemsel',),
'glemselsdrikk': ('glemselsdrikk',),
'glemselsdrikken': ('glemselsdrikk',),
'glemselsdrikkene': ('glemselsdrikk',),
'glemselsdrikker': ('glemselsdrikk',),
'glemsomhet': ('glemsomhet',),
'glemsomheta': ('glemsomhet',),
'glemsomheten': ('glemsomhet',),
'glemsomhetene': ('glemsomhet',),
'glemsomheter': ('glemsomhet',),
'glenna': ('glenne',),
'glenne': ('glenne',),
'glennen': ('glenne',),
'glennene': ('glenne',),
'glenner': ('glenne',),
'glente': ('glente',),
'glenten': ('glente',),
'glentene': ('glente',),
'glenter': ('glente',),
'glepp': ('glepp',),
'gleppa': ('glepp',),
'gleppen': ('glepp',),
'gleppene': ('glepp',),
'gleppet': ('glepp',),
'gletsjer': ('gletsjer',),
'gletsjere': ('gletsjer',),
'gletsjeren': ('gletsjer',),
'gletsjerer': ('gletsjer',),
'gletsjerne': ('gletsjer',),
'glett': ('glett',),
'gletten': ('glett',),
'glettene': ('glett',),
'gletter': ('glett',),
'gletta': ('glette',),
'glette': ('glette',),
'gletten': ('glette',),
'glettene': ('glette',),
'gletter': ('glette',),
'glettet': ('glette',),
'glid': ('glid',),
'glida': ('glid',),
'gliden': ('glid',),
'glidene': ('glid',),
'glider': ('glid',),
'glidet': ('glid',),
'glideflata': ('glideflate',),
'glideflate': ('glideflate',),
'glideflaten': ('glideflate',),
'glideflatene': ('glideflate',),
'glideflater': ('glideflate',),
'glideflukt': ('glideflukt',),
'glideflukta': ('glideflukt',),
'glideflukten': ('glideflukt',),
'glidefluktene': ('glideflukt',),
'glideflukter': ('glideflukt',),
'glidefly': ('glidefly',),
'glideflya': ('glidefly',),
'glideflyene': ('glidefly',),
'glideflyet': ('glidefly',),
'glideforskaling': ('glideforskaling',),
'glideforskalinga': ('glideforskaling',),
'glideforskalingen': ('glideforskaling',),
'glideforskalingene': ('glideforskaling',),
'glideforskalinger': ('glideforskaling',),
'glidehylsa': ('glidehylse',),
'glidehylse': ('glidehylse',),
'glidehylsen': ('glidehylse',),
'glidehylsene': ('glidehylse',),
'glidehylser': ('glidehylse',),
'glidelager': ('glidelager',),
'glidelageret': ('glidelager',),
'glidelagra': ('glidelager',),
'glidelagre': ('glidelager',),
'glidelagrene': ('glidelager',),
'glideledd': ('glideledd',),
'glideledda': ('glideledd',),
'glideleddene': ('glideledd',),
'glideleddet': ('glideledd',),
'glidelyd': ('glidelyd',),
'glidelyden': ('glidelyd',),
'glidelydene': ('glidelyd',),
'glidelyder': ('glidelyd',),
'glidelås': ('glidelås',),
'glidelåsa': ('glidelås',),
'glidelåsen': ('glidelås',),
'glidelåsene': ('glidelås',),
'glidelåser': ('glidelås',),
'glidelåset': ('glidelås',),
'glider': ('glider',),
'glidere': ('glider',),
'glideren': ('glider',),
'gliderer': ('glider',),
'gliderne': ('glider',),
'glideskala': ('glideskala',),
'glideskalaen': ('glideskala',),
'glideskalaene': ('glideskala',),
'glideskalaer': ('glideskala',),
'glidetakling': ('glidetakling',),
'glidetaklinga': ('glidetakling',),
'glidetaklingen': ('glidetakling',),
'glidetaklingene': ('glidetakling',),
'glidetaklinger': ('glidetakling',),
'glidetoll': ('glidetoll',),
'glidetollen': ('glidetoll',),
'glidetollene': ('glidetoll',),
'glidetoller': ('glidetoll',),
'gliding': ('gliding',),
'glidinga': ('gliding',),
'glidingen': ('gliding',),
'glidingene': ('gliding',),
'glidinger': ('gliding',),
'glidsmurning': ('glidsmurning',),
'glidsmurninga': ('glidsmurning',),
'glidsmurningen': ('glidsmurning',),
'glidsmurningene': ('glidsmurning',),
'glidsmurninger': ('glidsmurning',),
'glidsmøring': ('glidsmøring',),
'glidsmøringa': ('glidsmøring',),
'glidsmøringen': ('glidsmøring',),
'glidsmøringene': ('glidsmøring',),
'glidsmøringer': ('glidsmøring',),
'gliing': ('gliing',),
'gliinga': ('gliing',),
'gliingen': ('gliing',),
'gliingene': ('gliing',),
'gliinger': ('gliing',),
'glima': ('glima',),
'glimaen': ('glima',),
'glimaene': ('glima',),
'glimaer': ('glima',),
'glima': ('glime',),
'glime': ('glime',),
'glimen': ('glime',),
'glimene': ('glime',),
'glimer': ('glime',),
'glimlampa': ('glimlampe',),
'glimlampe': ('glimlampe',),
'glimlampen': ('glimlampe',),
'glimlampene': ('glimlampe',),
'glimlamper': ('glimlampe',),
'glimmer': ('glimmer',),
'glimmere': ('glimmer',),
'glimmeren': ('glimmer',),
'glimmerer': ('glimmer',),
'glimmerne': ('glimmer',),
'glimrene': ('glimmer',),
'glimrer': ('glimmer',),
'glimmerskifer': ('glimmerskifer',),
'glimmerskifere': ('glimmerskifer',),
'glimmerskiferen': ('glimmerskifer',),
'glimmerskiferer': ('glimmerskifer',),
'glimmerskiferne': ('glimmerskifer',),
'glimmerskifre': ('glimmerskifer',),
'glimmerskifrene': ('glimmerskifer',),
'glimmerskifrer': ('glimmerskifer',),
'glimmerstein': ('glimmerstein',),
'glimmersteinen': ('glimmerstein',),
'glimmersteinene': ('glimmerstein',),
'glimmersteiner': ('glimmerstein',),
'glimt': ('glimt',),
'glimta': ('glimt',),
'glimten': ('glimt',),
'glimtene': ('glimt',),
'glimtet': ('glimt',),
'glip': ('glip',),
'glipa': ('glip',),
'glipen': ('glip',),
'glipene': ('glip',),
'glipet': ('glip',),
'glipa': ('glipe',),
'glipe': ('glipe',),
'glipen': ('glipe',),
'glipene': ('glipe',),
'gliper': ('glipe',),
'glipp': ('glipp',),
'glippa': ('glipp',),
'glippen': ('glipp',),
'glippene': ('glipp',),
'glippet': ('glipp',),
'glipp': ('glipp',),
'glis': ('glis',),
'glisa': ('glis',),
'glisen': ('glis',),
'glisene': ('glis',),
'gliset': ('glis',),
'glissando': ('glissando',),
'glissandoa': ('glissando',),
'glissandoen': ('glissando',),
'glissandoene': ('glissando',),
'glissandoer': ('glissando',),
'glissandoet': ('glissando',),
'glittemaskin': ('glittemaskin',),
'glittemaskina': ('glittemaskin',),
'glittemaskinen': ('glittemaskin',),
'glittemaskinene': ('glittemaskin',),
'glittemaskiner': ('glittemaskin',),
'glitra': ('glitter',),
'glitre': ('glitter',),
'glitrene': ('glitter',),
'glitret': ('glitter',),
'glitter': ('glitter',),
'glitteret': ('glitter',),
'glo': ('glo',),
'gloa': ('glo',),
'gloen': ('glo',),
'glør': ('glo',),
'glørne': ('glo',),
'globalstråling': ('globalstråling',),
'globalstrålinga': ('globalstråling',),
'globalstrålingen': ('globalstråling',),
'globalstrålingene': ('globalstråling',),
'globalstrålinger': ('globalstråling',),
'globetrotter': ('globetrotter',),
'globetrottere': ('globetrotter',),
'globetrotteren': ('globetrotter',),
'globetrotterer': ('globetrotter',),
'globetrotterne': ('globetrotter',),
'globulin': ('globulin',),
'globulina': ('globulin',),
'globulinene': ('globulin',),
'globuliner': ('globulin',),
'globulinet': ('globulin',),
'globus': ('globus',),
'globusen': ('globus',),
'globusene': ('globus',),
'globuser': ('globus',),
'glohane': ('glohane',),
'glohanen': ('glohane',),
'glohanene': ('glohane',),
'glohaner': ('glohane',),
'gloire': ('gloire',),
'gloiren': ('gloire',),
'gloirene': ('gloire',),
'gloirer': ('gloire',),
'gloksinia': ('gloksinia',),
'gloksiniaen': ('gloksinia',),
'gloksiniaene': ('gloksinia',),
'gloksiniaer': ('gloksinia',),
'glomørja': ('glomørje',),
'glomørje': ('glomørje',),
'glomørjen': ('glomørje',),
'glomørjene': ('glomørje',),
'glomørjer': ('glomørje',),
'gloppa': ('gloppe',),
'gloppe': ('gloppe',),
'gloppen': ('gloppe',),
'gloppene': ('gloppe',),
'glopper': ('gloppe',),
'glor': ('glor',),
'glora': ('glor',),
'glorene': ('glor',),
'gloret': ('glor',),
'gloria': ('gloria',),
'gloriaene': ('gloria',),
'gloriaet': ('gloria',),
'gloriene': ('gloria',),
'glorier': ('gloria',),
'glorie': ('glorie',),
'glorien': ('glorie',),
'gloriene': ('glorie',),
'glorier': ('glorie',),
'glosa': ('glose',),
'glose': ('glose',),
'glosen': ('glose',),
'glosene': ('glose',),
'gloser': ('glose',),
'glosepugg': ('glosepugg',),
'glosepugga': ('glosepugg',),
'glosepuggene': ('glosepugg',),
'glosepugget': ('glosepugg',),
'glossar': ('glossar',),
'glossara': ('glossar',),
'glossarene': ('glossar',),
'glossarer': ('glossar',),
'glossaret': ('glossar',),
'glossaria': ('glossarium',),
'glossariene': ('glossarium',),
'glossarier': ('glossarium',),
'glossariet': ('glossarium',),
'glossarium': ('glossarium',),
'glosse': ('glosse',),
'glossen': ('glosse',),
'glossene': ('glosse',),
'glosser': ('glosse',),
'glossematikk': ('glossematikk',),
'glossematikken': ('glossematikk',),
'glossematikkene': ('glossematikk',),
'glossematikker': ('glossematikk',),
'glottis': ('glottis',),
'glottisen': ('glottis',),
'glottisene': ('glottis',),
'glottiser': ('glottis',),
'glugg': ('glugg',),
'gluggen': ('glugg',),
'gluggene': ('glugg',),
'glugger': ('glugg',),
'glugge': ('glugge',),
'gluggen': ('glugge',),
'gluggene': ('glugge',),
'glugger': ('glugge',),
'gluggehol': ('gluggehol',),
'gluggehola': ('gluggehol',),
'gluggeholene': ('gluggehol',),
'gluggeholet': ('gluggehol',),
'gluggehull': ('gluggehull',),
'gluggehulla': ('gluggehull',),
'gluggehullene': ('gluggehull',),
'gluggehuller': ('gluggehull',),
'gluggehullet': ('gluggehull',),
'gluggevindu': ('gluggevindu',),
'gluggevindua': ('gluggevindu',),
'gluggevinduene': ('gluggevindu',),
'gluggevinduer': ('gluggevindu',),
'gluggevinduet': ('gluggevindu',),
'glugghol': ('glugghol',),
'glugghola': ('glugghol',),
'gluggholene': ('glugghol',),
'gluggholet': ('glugghol',),
'glugghull': ('glugghull',),
'glugghulla': ('glugghull',),
'glugghullene': ('glugghull',),
'glugghuller': ('glugghull',),
'glugghullet': ('glugghull',),
'gluggvindu': ('gluggvindu',),
'gluggvindua': ('gluggvindu',),
'gluggvinduene': ('gluggvindu',),
'gluggvinduer': ('gluggvindu',),
'gluggvinduet': ('gluggvindu',),
'glukose': ('glukose',),
'glukosen': ('glukose',),
'glukosene': ('glukose',),
'glukoser': ('glukose',),
'gluten': ('gluten',),
'glutena': ('gluten',),
'glutenene': ('gluten',),
'glutenet': ('gluten',),
'glykogen': ('glykogen',),
'glykogena': ('glykogen',),
'glykogenene': ('glykogen',),
'glykogener': ('glykogen',),
'glykogenet': ('glykogen',),
'glykol': ('glykol',),
'glykolen': ('glykol',),
'glykolene': ('glykol',),
'glykoler': ('glykol',),
'glykolyse': ('glykolyse',),
'glykolysen': ('glykolyse',),
'glykolysene': ('glykolyse',),
'glykolyser': ('glykolyse',),
'glyptotek': ('glyptotek',),
'glyptoteka': ('glyptotek',),
'glyptotekene': ('glyptotek',),
'glyptoteker': ('glyptotek',),
'glyptoteket': ('glyptotek',),
'glyserid': ('glyserid',),
'glyserida': ('glyserid',),
'glyseridene': ('glyserid',),
'glyserider': ('glyserid',),
'glyseridet': ('glyserid',),
'glyserin': ('glyserin',),
'glyserinen': ('glyserin',),
'glyserinene': ('glyserin',),
'glyseriner': ('glyserin',),
'glyserol': ('glyserol',),
'glyserolen': ('glyserol',),
'glyserolene': ('glyserol',),
'glyseroler': ('glyserol',),
'glød': ('glød',),
'gløden': ('glød',),
'glødene': ('glød',),
'gløder': ('glød',),
'glødelampa': ('glødelampe',),
'glødelampe': ('glødelampe',),
'glødelampen': ('glødelampe',),
'glødelampene': ('glødelampe',),
'glødelamper': ('glødelampe',),
'gløgg': ('gløgg',),
'gløggen': ('gløgg',),
'gløggene': ('gløgg',),
'gløgger': ('gløgg',),
'glømme': ('glømme',),
'glømmebok': ('glømmebok',),
'glømmeboka': ('glømmebok',),
'glømmeboken': ('glømmebok',),
'glømmebøkene': ('glømmebok',),
'glømmebøker': ('glømmebok',),
'glømsel': ('glømsel',),
'glømselen': ('glømsel',),
'glømslene': ('glømsel',),
'glømsler': ('glømsel',),
'glømselsdrikk': ('glømselsdrikk',),
'glømselsdrikken': ('glømselsdrikk',),
'glømselsdrikkene': ('glømselsdrikk',),
'glømselsdrikker': ('glømselsdrikk',),
'glømsomhet': ('glømsomhet',),
'glømsomheta': ('glømsomhet',),
'glømsomheten': ('glømsomhet',),
'glømsomhetene': ('glømsomhet',),
'glømsomheter': ('glømsomhet',),
'gløtt': ('gløtt',),
'gløtta': ('gløtt',),
'gløtten': ('gløtt',),
'gløttene': ('gløtt',),
'gløtter': ('gløtt',),
'gløttet': ('gløtt',),
'gnag': ('gnag',),
'gnaga': ('gnag',),
'gnagene': ('gnag',),
'gnaget': ('gnag',),
'gnager': ('gnager',),
'gnagere': ('gnager',),
'gnageren': ('gnager',),
'gnagerer': ('gnager',),
'gnagerne': ('gnager',),
'gnagsår': ('gnagsår',),
'gnagsåra': ('gnagsår',),
'gnagsårene': ('gnagsår',),
'gnagsåret': ('gnagsår',),
'gnav': ('gnav',),
'gnava': ('gnav',),
'gnaven': ('gnav',),
'gnavene': ('gnav',),
'gnaver': ('gnav',),
'gnavet': ('gnav',),
'gneis': ('gneis',),
'gneisen': ('gneis',),
'gneisene': ('gneis',),
'gneiser': ('gneis',),
'gneisfjell': ('gneisfjell',),
'gneisfjella': ('gneisfjell',),
'gneisfjellene': ('gneisfjell',),
'gneisfjellet': ('gneisfjell',),
'gnelder': ('gnelder',),
'gnelderet': ('gnelder',),
'gneldra': ('gnelder',),
'gneldre': ('gnelder',),
'gneldrene': ('gnelder',),
'gneldret': ('gnelder',),
'gneldrebikkja': ('gneldrebikkje',),
'gneldrebikkje': ('gneldrebikkje',),
'gneldrebikkjen': ('gneldrebikkje',),
'gneldrebikkjene': ('gneldrebikkje',),
'gneldrebikkjer': ('gneldrebikkje',),
'gnell': ('gnell',),
'gnella': ('gnell',),
'gnellene': ('gnell',),
'gnellet': ('gnell',),
'gnidder': ('gnidder',),
'gniddera': ('gnidder',),
'gniddere': ('gnidder',),
'gnidderene': ('gnidder',),
'gnidderet': ('gnidder',),
'gnidderne': ('gnidder',),
'gnidning': ('gnidning',),
'gnidninga': ('gnidning',),
'gnidningen': ('gnidning',),
'gnidningene': ('gnidning',),
'gnidninger': ('gnidning',),
'gnidningselektrisitet': ('gnidningselektrisitet',),
'gnidningselektrisiteten': ('gnidningselektrisitet',),
'gnidningselektrisitetene': ('gnidningselektrisitet',),
'gnidningselektrisiteter': ('gnidningselektrisitet',),
'gnidningsmotstand': ('gnidningsmotstand',),
'gnidningsmotstanden': ('gnidningsmotstand',),
'gnidningsmotstandene': ('gnidningsmotstand',),
'gnidningsmotstander': ('gnidningsmotstand',),
'gnier': ('gnier',),
'gniere': ('gnier',),
'gnieren': ('gnier',),
'gnierer': ('gnier',),
'gnierne': ('gnier',),
'gnirk': ('gnirk',),
'gnirka': ('gnirk',),
'gnirken': ('gnirk',),
'gnirkene': ('gnirk',),
'gnirket': ('gnirk',),
'gnisning': ('gnisning',),
'gnisninga': ('gnisning',),
'gnisningen': ('gnisning',),
'gnisningene': ('gnisning',),
'gnisninger': ('gnisning',),
'gniss': ('gniss',),
'gnissa': ('gniss',),
'gnissene': ('gniss',),
'gnisset': ('gniss',),
'gnislene': ('gnissel',),
'gnisler': ('gnissel',),
'gnissel': ('gnissel',),
'gnisselen': ('gnissel',),
'gnisselyd': ('gnisselyd',),
'gnisselyden': ('gnisselyd',),
'gnisselydene': ('gnisselyd',),
'gnisselyder': ('gnisselyd',),
'gnist': ('gnist',),
'gnisten': ('gnist',),
'gnistene': ('gnist',),
'gnister': ('gnist',),
'gnistfanger': ('gnistfanger',),
'gnistfangere': ('gnistfanger',),
'gnistfangeren': ('gnistfanger',),
'gnistfangerer': ('gnistfanger',),
'gnistfangerne': ('gnistfanger',),
'gnistregn': ('gnistregn',),
'gnistregna': ('gnistregn',),
'gnistregnene': ('gnistregn',),
'gnistregnet': ('gnistregn',),
'gnom': ('gnom',),
'gnomen': ('gnom',),
'gnomene': ('gnom',),
'gnomer': ('gnom',),
'gnome': ('gnome',),
'gnomen': ('gnome',),
'gnomene': ('gnome',),
'gnomer': ('gnome',),
'gnostiker': ('gnostiker',),
'gnostikere': ('gnostiker',),
'gnostikeren': ('gnostiker',),
'gnostikerer': ('gnostiker',),
'gnostikerne': ('gnostiker',),
'gnostisisme': ('gnostisisme',),
'gnostisismen': ('gnostisisme',),
'gnostisismene': ('gnostisisme',),
'gnostisismer': ('gnostisisme',),
'gnu': ('gnu',),
'gnuen': ('gnu',),
'gnuene': ('gnu',),
'gnuer': ('gnu',),
'gny': ('gny',),
'gnya': ('gny',),
'gnyene': ('gny',),
'gnyet': ('gny',),
'gnål': ('gnål',),
'gnåla': ('gnål',),
'gnålene': ('gnål',),
'gnålet': ('gnål',),
'goal': ('goal',),
'goalen': ('goal',),
'goalene': ('goal',),
'goaler': ('goal',),
'goalgetter': ('goalgetter',),
'goalgettere': ('goalgetter',),
'goalgetteren': ('goalgetter',),
'goalgetterer': ('goalgetter',),
'goalgetterne': ('goalgetter',),
'goaneser': ('goaneser',),
'goanesere': ('goaneser',),
'goaneseren': ('goaneser',),
'goaneserer': ('goaneser',),
'goaneserne': ('goaneser',),
'gobeleng': ('gobeleng',),
'gobelenga': ('gobeleng',),
'gobelengene': ('gobeleng',),
'gobelenger': ('gobeleng',),
'gobelenget': ('gobeleng',),
'gobelinbroderi': ('gobelinbroderi',),
'gobelinbroderia': ('gobelinbroderi',),
'gobelinbroderiene': ('gobelinbroderi',),
'gobelinbroderier': ('gobelinbroderi',),
'gobelinbroderiet': ('gobelinbroderi',),
'gobelintapet': ('gobelintapet',),
'gobelintapeta': ('gobelintapet',),
'gobelintapetene': ('gobelintapet',),
'gobelintapeter': ('gobelintapet',),
'gobelintapetet': ('gobelintapet',),
'gobelintrekk': ('gobelintrekk',),
'gobelintrekka': ('gobelintrekk',),
'gobelintrekkene': ('gobelintrekk',),
'gobelintrekket': ('gobelintrekk',),
'gobelinvev': ('gobelinvev',),
'gobelinveven': ('gobelinvev',),
'gobelinvevene': ('gobelinvev',),
'gobelinvever': ('gobelinvev',),
'godbit': ('godbit',),
'godbiten': ('godbit',),
'godbitene': ('godbit',),
'godbiter': ('godbit',),
'gode': ('gode',),
'goden': ('gode',),
'godene': ('gode',),
'goder': ('gode',),
'goda': ('gode',),
'gode': ('gode',),
'godene': ('gode',),
'goder': ('gode',),
'godet': ('gode',),
'godfjott': ('godfjott',),
'godfjotten': ('godfjott',),
'godfjottene': ('godfjott',),
'godfjotter': ('godfjott',),
'godhet': ('godhet',),
'godheta': ('godhet',),
'godheten': ('godhet',),
'godhetene': ('godhet',),
'godheter': ('godhet',),
'godhug': ('godhug',),
'godhugen': ('godhug',),
'godhugene': ('godhug',),
'godhuger': ('godhug',),
'godkjennelse': ('godkjennelse',),
'godkjennelsen': ('godkjennelse',),
'godkjennelsene': ('godkjennelse',),
'godkjennelser': ('godkjennelse',),
'godkjenning': ('godkjenning',),
'godkjenninga': ('godkjenning',),
'godkjenningen': ('godkjenning',),
'godkjenningene': ('godkjenning',),
'godkjenninger': ('godkjenning',),
'godkjøp': ('godkjøp',),
'godkjøpa': ('godkjøp',),
'godkjøpene': ('godkjøp',),
'godkjøpet': ('godkjøp',),
'godlag': ('godlag',),
'godlaga': ('godlag',),
'godlagene': ('godlag',),
'godlaget': ('godlag',),
'godluna': ('godlune',),
'godlune': ('godlune',),
'godlunene': ('godlune',),
'godluner': ('godlune',),
'godlunet': ('godlune',),
'godlynna': ('godlynne',),
'godlynne': ('godlynne',),
'godlynnene': ('godlynne',),
'godlynner': ('godlynne',),
'godlynnet': ('godlynne',),
'godlåt': ('godlåt',),
'godlåten': ('godlåt',),
'godlåtene': ('godlåt',),
'godlåter': ('godlåt',),
'godnattklem': ('godnattklem',),
'godnattklemmen': ('godnattklem',),
'godnattklemmene': ('godnattklem',),
'godnattklemmer': ('godnattklem',),
'godnattkyss': ('godnattkyss',),
'godnattkyssa': ('godnattkyss',),
'godnattkyssen': ('godnattkyss',),
'godnattkyssene': ('godnattkyss',),
'godnattkysset': ('godnattkyss',),
'godord': ('godord',),
'godorda': ('godord',),
'godordene': ('godord',),
'godordet': ('godord',),
'godord': ('godord',),
'godorda': ('godord',),
'godordene': ('godord',),
'godordet': ('godord',),
'gods': ('gods',),
'godsa': ('gods',),
'godsene': ('gods',),
'godser': ('gods',),
'godset': ('gods',),
'godsbåt': ('godsbåt',),
'godsbåten': ('godsbåt',),
'godsbåtene': ('godsbåt',),
'godsbåter': ('godsbåt',),
'godseier': ('godseier',),
'godseiere': ('godseier',),
'godseieren': ('godseier',),
'godseierer': ('godseier',),
'godseierne': ('godseier',),
'godsekspedisjon': ('godsekspedisjon',),
'godsekspedisjonen': ('godsekspedisjon',),
'godsekspedisjonene': ('godsekspedisjon',),
'godsekspedisjoner': ('godsekspedisjon',),
'godsforvalter': ('godsforvalter',),
'godsforvaltere': ('godsforvalter',),
'godsforvalteren': ('godsforvalter',),
'godsforvalterer': ('godsforvalter',),
'godsforvalterne': ('godsforvalter',),
'godsida': ('godside',),
'godside': ('godside',),
'godsiden': ('godside',),
'godsidene': ('godside',),
'godsider': ('godside',),
'godsruta': ('godsrute',),
'godsrute': ('godsrute',),
'godsruten': ('godsrute',),
'godsrutene': ('godsrute',),
'godsruter': ('godsrute',),
'godsterminal': ('godsterminal',),
'godsterminalen': ('godsterminal',),
'godsterminalene': ('godsterminal',),
'godsterminaler': ('godsterminal',),
'godstog': ('godstog',),
'godstoga': ('godstog',),
'godstogene': ('godstog',),
'godstoget': ('godstog',),
'godstrafikk': ('godstrafikk',),
'godstrafikken': ('godstrafikk',),
'godstrafikkene': ('godstrafikk',),
'godstrafikker': ('godstrafikk',),
'godsvogn': ('godsvogn',),
'godsvogna': ('godsvogn',),
'godsvognen': ('godsvogn',),
'godsvognene': ('godsvogn',),
'godsvogner': ('godsvogn',),
'godt': ('godt',),
'godten': ('godt',),
'godtene': ('godt',),
'godter': ('godt',),
'godtebutikk': ('godtebutikk',),
'godtebutikken': ('godtebutikk',),
'godtebutikkene': ('godtebutikk',),
'godtebutikker': ('godtebutikk',),
'godtemplar': ('godtemplar',),
'godtemplaren': ('godtemplar',),
'godtemplarene': ('godtemplar',),
'godtemplarer': ('godtemplar',),
'godtemplarlosje': ('godtemplarlosje',),
'godtemplarlosjen': ('godtemplarlosje',),
'godtemplarlosjene': ('godtemplarlosje',),
'godtemplarlosjer': ('godtemplarlosje',),
'godtemplarorden': ('godtemplarorden',),
'godtemplarordenen': ('godtemplarorden',),
'godtemplarordenene': ('godtemplarorden',),
'godtemplarordener': ('godtemplarorden',),
'godtepose': ('godtepose',),
'godteposen': ('godtepose',),
'godteposene': ('godtepose',),
'godteposer': ('godtepose',),
'godtene': ('godter',),
'godter': ('godter',),
'godteri': ('godteri',),
'godteria': ('godteri',),
'godteriene': ('godteri',),
'godterier': ('godteri',),
'godteriet': ('godteri',),
'godtfolk': ('godtfolk',),
'godtfolka': ('godtfolk',),
'godtfolkene': ('godtfolk',),
'godtfolket': ('godtfolk',),
'godtgjørelse': ('godtgjørelse',),
'godtgjørelsen': ('godtgjørelse',),
'godtgjørelsene': ('godtgjørelse',),
'godtgjørelser': ('godtgjørelse',),
'godtgjøring': ('godtgjøring',),
'godtgjøringa': ('godtgjøring',),
'godtgjøringen': ('godtgjøring',),
'godtgjøringene': ('godtgjøring',),
'godtgjøringer': ('godtgjøring',),
'godtkjøpsvara': ('godtkjøpsvare',),
'godtkjøpsvare': ('godtkjøpsvare',),
'godtkjøpsvaren': ('godtkjøpsvare',),
'godtkjøpsvarene': ('godtkjøpsvare',),
'godtkjøpsvarer': ('godtkjøpsvare',),
'godtroenhet': ('godtroenhet',),
'godtroenheta': ('godtroenhet',),
'godtroenheten': ('godtroenhet',),
'godtroenhetene': ('godtroenhet',),
'godtroenheter': ('godtroenhet',),
'godtruenhet': ('godtruenhet',),
'godtruenheta': ('godtruenhet',),
'godtruenheten': ('godtruenhet',),
'godtruenhetene': ('godtruenhet',),
'godtruenheter': ('godtruenhet',),
'godtykka': ('godtykke',),
'godtykke': ('godtykke',),
'godtykkene': ('godtykke',),
'godtykker': ('godtykke',),
'godtykket': ('godtykke',),
'godvennene': ('godvenner',),
'godvenner': ('godvenner',),
'godvilje': ('godvilje',),
'godviljen': ('godvilje',),
'godviljene': ('godvilje',),
'godviljer': ('godvilje',),
'godvær': ('godvær',),
'godværa': ('godvær',),
'godværene': ('godvær',),
'godværet': ('godvær',),
'godværsdag': ('godværsdag',),
'godværsdagen': ('godværsdag',),
'godværsdagene': ('godværsdag',),
'godværsdager': ('godværsdag',),
'godværsperiode': ('godværsperiode',),
'godværsperioden': ('godværsperiode',),
'godværsperiodene': ('godværsperiode',),
'godværsperioder': ('godværsperiode',),
'godværssky': ('godværssky',),
'godværsskya': ('godværssky',),
'godværsskyen': ('godværssky',),
'godværsskyene': ('godværssky',),
'godværsskyer': ('godværssky',),
'gogn': ('gogn',),
'gogna': ('gogn',),
'gognen': ('gogn',),
'gognene': ('gogn',),
'gogner': ('gogn',),
'gojim': ('gojim',),
'gokart': ('gokart',),
'gokarten': ('gokart',),
'gokartene': ('gokart',),
'gokarter': ('gokart',),
'golden retriever': ('golden retriever',),
'golden retrievere': ('golden retriever',),
'golden retrieveren': ('golden retriever',),
'golden retrieverer': ('golden retriever',),
'golden retrieverne': ('golden retriever',),
'golfbane': ('golfbane',),
'golfbanen': ('golfbane',),
'golfbanene': ('golfbane',),
'golfbaner': ('golfbane',),
'golfjakka': ('golfjakke',),
'golfjakke': ('golfjakke',),
'golfjakken': ('golfjakke',),
'golfjakkene': ('golfjakke',),
'golfjakker': ('golfjakke',),
'golfkølla': ('golfkølle',),
'golfkølle': ('golfkølle',),
'golfkøllen': ('golfkølle',),
'golfkøllene': ('golfkølle',),
'golfkøller': ('golfkølle',),
'golv': ('golv',),
'golva': ('golv',),
'golvene': ('golv',),
'golvet': ('golv',),
'golvfilla': ('golvfille',),
'golvfille': ('golvfille',),
'golvfillen': ('golvfille',),
'golvfillene': ('golvfille',),
'golvfiller': ('golvfille',),
'golvflata': ('golvflate',),
'golvflate': ('golvflate',),
'golvflaten': ('golvflate',),
'golvflatene': ('golvflate',),
'golvflater': ('golvflate',),
'golvflis': ('golvflis',),
'golvflisa': ('golvflis',),
'golvflisen': ('golvflis',),
'golvflisene': ('golvflis',),
'golvfliser': ('golvflis',),
'golvflise': ('golvflise',),
'golvflisen': ('golvflise',),
'golvflisene': ('golvflise',),
'golvfliser': ('golvflise',),
'golvgir': ('golvgir',),
'golvgira': ('golvgir',),
'golvgirene': ('golvgir',),
'golvgiret': ('golvgir',),
'golvklut': ('golvklut',),
'golvkluten': ('golvklut',),
'golvklutene': ('golvklut',),
'golvkluter': ('golvklut',),
'golvlampa': ('golvlampe',),
'golvlampe': ('golvlampe',),
'golvlampen': ('golvlampe',),
'golvlampene': ('golvlampe',),
'golvlamper': ('golvlampe',),
'golvløper': ('golvløper',),
'golvløpere': ('golvløper',),
'golvløperen': ('golvløper',),
'golvløperer': ('golvløper',),
'golvløperne': ('golvløper',),
'golvmatta': ('golvmatte',),
'golvmatte': ('golvmatte',),
'golvmatten': ('golvmatte',),
'golvmattene': ('golvmatte',),
'golvmatter': ('golvmatte',),
'golvplass': ('golvplass',),
'golvplassen': ('golvplass',),
'golvplassene': ('golvplass',),
'golvplasser': ('golvplass',),
'golvteppa': ('golvteppe',),
'golvteppe': ('golvteppe',),
'golvteppene': ('golvteppe',),
'golvtepper': ('golvteppe',),
'golvteppet': ('golvteppe',),
'gom': ('gom',),
'gommen': ('gom',),
'gommene': ('gom',),
'gommer': ('gom',),
'gomler': ('gomler',),
'gomlere': ('gomler',),
'gomleren': ('gomler',),
'gomlerer': ('gomler',),
'gomlerne': ('gomler',),
'gomme': ('gomme',),
'gommen': ('gomme',),
'gommene': ('gomme',),
'gommer': ('gomme',),
'gondol': ('gondol',),
'gondolen': ('gondol',),
'gondolene': ('gondol',),
'gondoler': ('gondol',),
'gondolbane': ('gondolbane',),
'gondolbanen': ('gondolbane',),
'gondolbanene': ('gondolbane',),
'gondolbaner': ('gondolbane',),
'gondolfart': ('gondolfart',),
'gondolfarten': ('gondolfart',),
'gondolfartene': ('gondolfart',),
'gondolfarter': ('gondolfart',),
'gondolfører': ('gondolfører',),
'gondolførere': ('gondolfører',),
'gondolføreren': ('gondolfører',),
'gondolførerer': ('gondolfører',),
'gondolførerne': ('gondolfører',),
'gondolier': ('gondolier',),
'gondolieren': ('gondolier',),
'gondolierene': ('gondolier',),
'gondolierer': ('gondolier',),
'gondoliera': ('gondoliera',),
'gondolieraen': ('gondoliera',),
'gondolieraene': ('gondoliera',),
'gondolieraer': ('gondoliera',),
'gong': ('gong',),
'gongen': ('gong',),
'gongene': ('gong',),
'gonger': ('gong',),
'gongong': ('gongong',),
'gongongen': ('gongong',),
'gongongene': ('gongong',),
'gongonger': ('gongong',),
'gonokokk': ('gonokokk',),
'gonokokken': ('gonokokk',),
'gonokokkene': ('gonokokk',),
'gonokokker': ('gonokokk',),
'gonoreen': ('gonoré',),
'gonoreene': ('gonoré',),
'gonoreer': ('gonoré',),
'gonoré': ('gonoré',),
'gonoréen': ('gonoré',),
'gonoréene': ('gonoré',),
'gonoréer': ('gonoré',),
'goodwill': ('goodwill',),
'goodwillen': ('goodwill',),
'goodwillene': ('goodwill',),
'goodwiller': ('goodwill',),
'goodwillreisa': ('goodwillreise',),
'goodwillreise': ('goodwillreise',),
'goodwillreisen': ('goodwillreise',),
'goodwillreisene': ('goodwillreise',),
'goodwillreiser': ('goodwillreise',),
'gopla': ('gople',),
'gople': ('gople',),
'goplen': ('gople',),
'goplene': ('gople',),
'gopler': ('gople',),
'gordonsetter': ('gordonsetter',),
'gordonsettere': ('gordonsetter',),
'gordonsetteren': ('gordonsetter',),
'gordonsetterer': ('gordonsetter',),
'gordonsetterne': ('gordonsetter',),
'gorgonzola': ('gorgonzola',),
'gorgonzolaen': ('gorgonzola',),
'gorgonzolaene': ('gorgonzola',),
'gorgonzolaer': ('gorgonzola',),
'gorilla': ('gorilla',),
'gorillaen': ('gorilla',),
'gorillaene': ('gorilla',),
'gorillaer': ('gorilla',),
'goro': ('goro',),
'goroa': ('goro',),
'goroen': ('goro',),
'goroene': ('goro',),
'goroer': ('goro',),
'gorojern': ('gorojern',),
'gorojerna': ('gorojern',),
'gorojernene': ('gorojern',),
'gorojernet': ('gorojern',),
'gorr': ('gorr',),
'gorra': ('gorr',),
'gorrene': ('gorr',),
'gorret': ('gorr',),
'gospel': ('gospel',),
'gospelen': ('gospel',),
'gosplene': ('gospel',),
'gospler': ('gospel',),
'gospelkor': ('gospelkor',),
'gospelkora': ('gospelkor',),
'gospelkorene': ('gospelkor',),
'gospelkoret': ('gospelkor',),
'gospelsang': ('gospelsang',),
'gospelsangen': ('gospelsang',),
'gospelsangene': ('gospelsang',),
'gospelsanger': ('gospelsang',),
'goter': ('goter',),
'gotere': ('goter',),
'goteren': ('goter',),
'goterer': ('goter',),
'goterne': ('goter',),
'gotikk': ('gotikk',),
'gotikken': ('gotikk',),
'gotikkene': ('gotikk',),
'gotikker': ('gotikk',),
'gotisk': ('gotisk',),
'gotisken': ('gotisk',),
'gotiskene': ('gotisk',),
'gotisker': ('gotisk',),
'gotlending': ('gotlending',),
'gotlendingen': ('gotlending',),
'gotlendingene': ('gotlending',),
'gotlendinger': ('gotlending',),
'gouache': ('gouache',),
'gouachen': ('gouache',),
'gouachene': ('gouache',),
'gouacher': ('gouache',),
'gouachemaleri': ('gouachemaleri',),
'gouachemaleria': ('gouachemaleri',),
'gouachemaleriene': ('gouachemaleri',),
'gouachemalerier': ('gouachemaleri',),
'gouachemaleriet': ('gouachemaleri',),
'gouda': ('gouda',),
'goudaen': ('gouda',),
'goudaene': ('gouda',),
'goudaer': ('gouda',),
'goudaost': ('goudaost',),
'goudaosten': ('goudaost',),
'goudaostene': ('goudaost',),
'goudaoster': ('goudaost',),
'gourmand': ('gourmand',),
'gourmanden': ('gourmand',),
'gourmandene': ('gourmand',),
'gourmander': ('gourmand',),
'gourmet': ('gourmet',),
'gourmeten': ('gourmet',),
'gourmetene': ('gourmet',),
'gourmeter': ('gourmet',),
'gout': ('gout',),
'gouten': ('gout',),
'goutene': ('gout',),
'gouter': ('gout',),
'gov': ('gov',),
'gova': ('gov',),
'govene': ('gov',),
'govet': ('gov',),
'gova': ('gove',),
'gove': ('gove',),
'goven': ('gove',),
'govene': ('gove',),
'gover': ('gove',),
'gründer': ('gründer',),
'gründere': ('gründer',),
'gründeren': ('gründer',),
'gründerer': ('gründer',),
'gründerne': ('gründer',),
'gründerfortjenesta': ('gründerfortjeneste',),
'gründerfortjeneste': ('gründerfortjeneste',),
'gründerfortjenesten': ('gründerfortjeneste',),
'gründerfortjenestene': ('gründerfortjeneste',),
'gründerfortjenester': ('gründerfortjeneste',),
'grabb': ('grabb',),
'grabben': ('grabb',),
'grabbene': ('grabb',),
'grabber': ('grabb',),
'grabukk': ('grabukk',),
'grabukken': ('grabukk',),
'grabukkene': ('grabukk',),
'grabukker': ('grabukk',),
'grace': ('grace',),
'gracen': ('grace',),
'gracene': ('grace',),
'gracer': ('grace',),
'grad': ('grad',),
'graden': ('grad',),
'gradene': ('grad',),
'grader': ('grad',),
'gradasjon': ('gradasjon',),
'gradasjonen': ('gradasjon',),
'gradasjonene': ('gradasjon',),
'gradasjoner': ('gradasjon',),
'gradboge': ('gradboge',),
'gradbogen': ('gradboge',),
'gradbogene': ('gradboge',),
'gradboger': ('gradboge',),
'gradbue': ('gradbue',),
'gradbuen': ('gradbue',),
'gradbuene': ('gradbue',),
'gradbuer': ('gradbue',),
'gradbøying': ('gradbøying',),
'gradbøyinga': ('gradbøying',),
'gradbøyingen': ('gradbøying',),
'gradbøyingene': ('gradbøying',),
'gradbøyinger': ('gradbøying',),
'gradbøyning': ('gradbøyning',),
'gradbøyninga': ('gradbøyning',),
'gradbøyningen': ('gradbøyning',),
'gradbøyningene': ('gradbøyning',),
'gradbøyninger': ('gradbøyning',),
'gradestokk': ('gradestokk',),
'gradestokken': ('gradestokk',),
'gradestokkene': ('gradestokk',),
'gradestokker': ('gradestokk',),
'gradhøvel': ('gradhøvel',),
'gradhøvelen': ('gradhøvel',),
'gradhøvlene': ('gradhøvel',),
'gradhøvler': ('gradhøvel',),
'gradient': ('gradient',),
'gradienten': ('gradient',),
'gradientene': ('gradient',),
'gradienter': ('gradient',),
'gradinndeling': ('gradinndeling',),
'gradinndelinga': ('gradinndeling',),
'gradinndelingen': ('gradinndeling',),
'gradinndelingene': ('gradinndeling',),
'gradinndelinger': ('gradinndeling',),
'gradmål': ('gradmål',),
'gradmåla': ('gradmål',),
'gradmålene': ('gradmål',),
'gradmålet': ('gradmål',),
'gradmåling': ('gradmåling',),
'gradmålinga': ('gradmåling',),
'gradmålingen': ('gradmåling',),
'gradmålingene': ('gradmåling',),
'gradmålinger': ('gradmåling',),
'gradnett': ('gradnett',),
'gradnetta': ('gradnett',),
'gradnettene': ('gradnett',),
'gradnettet': ('gradnett',),
'gradsadverb': ('gradsadverb',),
'gradsadverba': ('gradsadverb',),
'gradsadverbene': ('gradsadverb',),
'gradsadverber': ('gradsadverb',),
'gradsadverbet': ('gradsadverb',),
'gradsadverbia': ('gradsadverbium',),
'gradsadverbiene': ('gradsadverbium',),
'gradsadverbier': ('gradsadverbium',),
'gradsadverbiet': ('gradsadverbium',),
'gradsadverbium': ('gradsadverbium',),
'gradsforskjell': ('gradsforskjell',),
'gradsforskjellen': ('gradsforskjell',),
'gradsforskjellene': ('gradsforskjell',),
'gradsforskjeller': ('gradsforskjell',),
'gradstrek': ('gradstrek',),
'gradstreken': ('gradstrek',),
'gradstrekene': ('gradstrek',),
'gradstreker': ('gradstrek',),
'gradtal': ('gradtal',),
'gradtala': ('gradtal',),
'gradtalene': ('gradtal',),
'gradtalet': ('gradtal',),
'gradtall': ('gradtall',),
'gradtalla': ('gradtall',),
'gradtallene': ('gradtall',),
'gradtallet': ('gradtall',),
'gradteigkart': ('gradteigkart',),
'gradteigkarta': ('gradteigkart',),
'gradteigkartene': ('gradteigkart',),
'gradteigkarter': ('gradteigkart',),
'gradteigkartet': ('gradteigkart',),
'gradteigskart': ('gradteigskart',),
'gradteigskarta': ('gradteigskart',),
'gradteigskartene': ('gradteigskart',),
'gradteigskarter': ('gradteigskart',),
'gradteigskartet': ('gradteigskart',),
'graduala': ('graduale',),
'graduale': ('graduale',),
'gradualene': ('graduale',),
'gradualer': ('graduale',),
'gradualet': ('graduale',),
'graf': ('graf',),
'grafen': ('graf',),
'grafene': ('graf',),
'grafer': ('graf',),
'grafem': ('grafem',),
'grafema': ('grafem',),
'grafemene': ('grafem',),
'grafemer': ('grafem',),
'grafemet': ('grafem',),
'graffiti': ('graffiti',),
'graffitien': ('graffiti',),
'graffitiene': ('graffiti',),
'graffitier': ('graffiti',),
'grafiker': ('grafiker',),
'grafikere': ('grafiker',),
'grafikeren': ('grafiker',),
'grafikerer': ('grafiker',),
'grafikerne': ('grafiker',),
'grafikk': ('grafikk',),
'grafikken': ('grafikk',),
'grafikkene': ('grafikk',),
'grafikker': ('grafikk',),
'grafitt': ('grafitt',),
'grafitten': ('grafitt',),
'grafittene': ('grafitt',),
'grafitter': ('grafitt',),
'grafolog': ('grafolog',),
'grafologen': ('grafolog',),
'grafologene': ('grafolog',),
'grafologer': ('grafolog',),
'grafologi': ('grafologi',),
'grafologien': ('grafologi',),
'grafologiene': ('grafologi',),
'grafologier': ('grafologi',),
'gragalt': ('gragalt',),
'gragalten': ('gragalt',),
'gragaltene': ('gragalt',),
'gragalter': ('gragalt',),
'gragalte': ('gragalte',),
'gragalten': ('gragalte',),
'gragaltene': ('gragalte',),
'gragalter': ('gragalte',),
'grahambrød': ('grahambrød',),
'grahambrøda': ('grahambrød',),
'grahambrødene': ('grahambrød',),
'grahambrødet': ('grahambrød',),
'grahest': ('grahest',),
'grahesten': ('grahest',),
'grahestene': ('grahest',),
'grahester': ('grahest',),
'gral': ('gral',),
'gralen': ('gral',),
'gralene': ('gral',),
'graler': ('gral',),
'gram': ('gram',),
'gramma': ('gram',),
'grammene': ('gram',),
'grammet': ('gram',),
'grammatiker': ('grammatiker',),
'grammatikere': ('grammatiker',),
'grammatikeren': ('grammatiker',),
'grammatikerer': ('grammatiker',),
'grammatikerne': ('grammatiker',),
'grammatikk': ('grammatikk',),
'grammatikken': ('grammatikk',),
'grammatikkene': ('grammatikk',),
'grammatikker': ('grammatikk',),
'grammofon': ('grammofon',),
'grammofonen': ('grammofon',),
'grammofonene': ('grammofon',),
'grammofoner': ('grammofon',),
'grammofonmusikk': ('grammofonmusikk',),
'grammofonmusikken': ('grammofonmusikk',),
'grammofonmusikkene': ('grammofonmusikk',),
'grammofonmusikker': ('grammofonmusikk',),
'grammofonplata': ('grammofonplate',),
'grammofonplate': ('grammofonplate',),
'grammofonplaten': ('grammofonplate',),
'grammofonplatene': ('grammofonplate',),
'grammofonplater': ('grammofonplate',),
'grammofonselskap': ('grammofonselskap',),
'grammofonselskapa': ('grammofonselskap',),
'grammofonselskapene': ('grammofonselskap',),
'grammofonselskaper': ('grammofonselskap',),
'grammofonselskapet': ('grammofonselskap',),
'gran': ('gran',),
'grana': ('gran',),
'granen': ('gran',),
'granene': ('gran',),
'graner': ('gran',),
'granat': ('granat',),
'granaten': ('granat',),
'granatene': ('granat',),
'granater': ('granat',),
'granateld': ('granateld',),
'granatelden': ('granateld',),
'granateldene': ('granateld',),
'granatelder': ('granateld',),
'granateld': ('granateld',),
'granatelden': ('granateld',),
'granateldene': ('granateld',),
'granatelder': ('granateld',),
'granatepla': ('granateple',),
'granateple': ('granateple',),
'granateplene': ('granateple',),
'granatepler': ('granateple',),
'granateplet': ('granateple',),
'granatild': ('granatild',),
'granatilden': ('granatild',),
'granatildene': ('granatild',),
'granatilder': ('granatild',),
'granatild': ('granatild',),
'granatilden': ('granatild',),
'granatildene': ('granatild',),
'granatilder': ('granatild',),
'granatmineral': ('granatmineral',),
'granatminerala': ('granatmineral',),
'granatmineralene': ('granatmineral',),
'granatmineraler': ('granatmineral',),
'granatmineralet': ('granatmineral',),
'granatregn': ('granatregn',),
'granatregna': ('granatregn',),
'granatregnene': ('granatregn',),
'granatregnet': ('granatregn',),
'granatsplint': ('granatsplint',),
'granatsplinten': ('granatsplint',),
'granatsplintene': ('granatsplint',),
'granatsplinter': ('granatsplint',),
'granattre': ('granattre',),
'granattrea': ('granattre',),
'granattreet': ('granattre',),
'granattrær': ('granattre',),
'granattrærne': ('granattre',),
'granbar': ('granbar',),
'granbara': ('granbar',),
'granbarene': ('granbar',),
'granbaret': ('granbar',),
'granbarkbille': ('granbarkbille',),
'granbarkbillen': ('granbarkbille',),
'granbarkbillene': ('granbarkbille',),
'granbarkbiller': ('granbarkbille',),
'granbarlus': ('granbarlus',),
'granbarlusa': ('granbarlus',),
'granbarlusen': ('granbarlus',),
'granbarlusene': ('granbarlus',),
'grand': ('grand',),
'granden': ('grand',),
'grandene': ('grand',),
'grander': ('grand',),
'grand danois': ('grand danois',),
'grand danoisen': ('grand danois',),
'grand danoisene': ('grand danois',),
'grand danoiser': ('grand danois',),
'grand mal': ('grand mal',),
'grand old man': ('grand old man',),
'grand prix': ('grand prix',),
'grand prixen': ('grand prix',),
'grand prixene': ('grand prix',),
'grand prixer': ('grand prix',),
'grand prix-melodi': ('grand prix-melodi',),
'grand prix-melodien': ('grand prix-melodi',),
'grand prix-melodiene': ('grand prix-melodi',),
'grand prix-melodier': ('grand prix-melodi',),
'grand prix-vinner': ('grand prix-vinner',),
'grand prix-vinnere': ('grand prix-vinner',),
'grand prix-vinneren': ('grand prix-vinner',),
'grand prix-vinnerer': ('grand prix-vinner',),
'grand prix-vinnerne': ('grand prix-vinner',),
'grand-seigneur': ('grand-seigneur',),
'grand-seigneuren': ('grand-seigneur',),
'grand-seigneurene': ('grand-seigneur',),
'grand-seigneurer': ('grand-seigneur',),
'grande': ('grande',),
'granden': ('grande',),
'grandene': ('grande',),
'grander': ('grande',),
'grandezza': ('grandezza',),
'grandezzaen': ('grandezza',),
'grandezzaene': ('grandezza',),
'grandezzaer': ('grandezza',),
'grandonkel': ('grandonkel',),
'grandonkelen': ('grandonkel',),
'grandonklene': ('grandonkel',),
'grandonkler': ('grandonkel',),
'grandtanta': ('grandtante',),
'grandtante': ('grandtante',),
'grandtanten': ('grandtante',),
'grandtantene': ('grandtante',),
'grandtanter': ('grandtante',),
'granitol': ('granitol',),
'granitolen': ('granitol',),
'granitolene': ('granitol',),
'granitoler': ('granitol',),
'granitt': ('granitt',),
'granitten': ('granitt',),
'granittene': ('granitt',),
'granitter': ('granitt',),
'grankongla': ('grankongle',),
'grankongle': ('grankongle',),
'grankonglen': ('grankongle',),
'grankonglene': ('grankongle',),
'grankongler': ('grankongle',),
'grankvist': ('grankvist',),
'grankvisten': ('grankvist',),
'grankvistene': ('grankvist',),
'grankvister': ('grankvist',),
'granlav': ('granlav',),
'granlava': ('granlav',),
'granlavene': ('granlav',),
'granlavet': ('granlav',),
'granmeis': ('granmeis',),
'granmeisa': ('granmeis',),
'granmeisen': ('granmeis',),
'granmeisene': ('granmeis',),
'granmeiser': ('granmeis',),
'grann': ('grann',),
'granna': ('grann',),
'grannene': ('grann',),
'grannet': ('grann',),
'granne': ('granne',),
'grannen': ('granne',),
'grannene': ('granne',),
'granner': ('granne',),
'grannebygd': ('grannebygd',),
'grannebygda': ('grannebygd',),
'grannebygden': ('grannebygd',),
'grannebygdene': ('grannebygd',),
'grannebygder': ('grannebygd',),
'grannegard': ('grannegard',),
'grannegarden': ('grannegard',),
'grannegardene': ('grannegard',),
'grannegarder': ('grannegard',),
'grannegård': ('grannegård',),
'grannegården': ('grannegård',),
'grannegårdene': ('grannegård',),
'grannegårder': ('grannegård',),
'grannelag': ('grannelag',),
'grannelaga': ('grannelag',),
'grannelagene': ('grannelag',),
'grannelaget': ('grannelag',),
'granneskap': ('granneskap',),
'granneskapa': ('granneskap',),
'granneskapen': ('granneskap',),
'granneskapene': ('granneskap',),
'granneskaper': ('granneskap',),
'granneskapet': ('granneskap',),
'gransanger': ('gransanger',),
'gransangere': ('gransanger',),
'gransangeren': ('gransanger',),
'gransangerer': ('gransanger',),
'gransangerne': ('gransanger',),
'gransker': ('gransker',),
'granskere': ('gransker',),
'granskeren': ('gransker',),
'granskerer': ('gransker',),
'granskerne': ('gransker',),
'gransking': ('gransking',),
'granskinga': ('gransking',),
'granskingen': ('gransking',),
'granskingene': ('gransking',),
'granskinger': ('gransking',),
'granskingsarbeid': ('granskingsarbeid',),
'granskingsarbeida': ('granskingsarbeid',),
'granskingsarbeidene': ('granskingsarbeid',),
'granskingsarbeider': ('granskingsarbeid',),
'granskingsarbeidet': ('granskingsarbeid',),
'granskingsferd': ('granskingsferd',),
'granskingsferda': ('granskingsferd',),
'granskingsferden': ('granskingsferd',),
'granskingsferdene': ('granskingsferd',),
'granskingsferder': ('granskingsferd',),
'granskingskommisjon': ('granskingskommisjon',),
'granskingskommisjonen': ('granskingskommisjon',),
'granskingskommisjonene': ('granskingskommisjon',),
'granskingskommisjoner': ('granskingskommisjon',),
'granskingsnemnd': ('granskingsnemnd',),
'granskingsnemnda': ('granskingsnemnd',),
'granskingsnemnden': ('granskingsnemnd',),
'granskingsnemndene': ('granskingsnemnd',),
'granskingsnemnder': ('granskingsnemnd',),
'granskingsoppgava': ('granskingsoppgave',),
'granskingsoppgave': ('granskingsoppgave',),
'granskingsoppgaven': ('granskingsoppgave',),
'granskingsoppgavene': ('granskingsoppgave',),
'granskingsoppgaver': ('granskingsoppgave',),
'granskjegg': ('granskjegg',),
'granskjegga': ('granskjegg',),
'granskjeggene': ('granskjegg',),
'granskjegget': ('granskjegg',),
'granskog': ('granskog',),
'granskogen': ('granskog',),
'granskogene': ('granskog',),
'granskoger': ('granskog',),
'granulasjon': ('granulasjon',),
'granulasjonen': ('granulasjon',),
'granulasjonene': ('granulasjon',),
'granulasjoner': ('granulasjon',),
'granulasjonsvev': ('granulasjonsvev',),
'granulasjonsveva': ('granulasjonsvev',),
'granulasjonsvevene': ('granulasjonsvev',),
'granulasjonsvevet': ('granulasjonsvev',),
'granulat': ('granulat',),
'granulata': ('granulat',),
'granulatene': ('granulat',),
'granulater': ('granulat',),
'granulatet': ('granulat',),
'granulitt': ('granulitt',),
'granulitten': ('granulitt',),
'granulittene': ('granulitt',),
'granulitter': ('granulitt',),
'granved': ('granved',),
'granveden': ('granved',),
'granvedene': ('granved',),
'granveder': ('granved',),
'granås': ('granås',),
'granåsen': ('granås',),
'granåsene': ('granås',),
'granåser': ('granås',),
'graokse': ('graokse',),
'graoksen': ('graokse',),
'graoksene': ('graokse',),
'graokser': ('graokse',),
'grapefrukt': ('grapefrukt',),
'grapefrukta': ('grapefrukt',),
'grapefrukten': ('grapefrukt',),
'grapefruktene': ('grapefrukt',),
'grapefrukter': ('grapefrukt',),
'gras': ('gras',),
'grasa': ('gras',),
'grasene': ('gras',),
'graset': ('gras',),
'grasand': ('grasand',),
'grasanda': ('grasand',),
'grasanden': ('grasand',),
'grasendene': ('grasand',),
'grasender': ('grasand',),
'grasbakke': ('grasbakke',),
'grasbakken': ('grasbakke',),
'grasbakkene': ('grasbakke',),
'grasbakker': ('grasbakke',),
'grasbane': ('grasbane',),
'grasbanen': ('grasbane',),
'grasbanene': ('grasbane',),
'grasbaner': ('grasbane',),
'grasbjørn': ('grasbjørn',),
'grasbjørnen': ('grasbjørn',),
'grasbjørnene': ('grasbjørn',),
'grasbjørner': ('grasbjørn',),
'grasbrann': ('grasbrann',),
'grasbrannen': ('grasbrann',),
'grasbrannene': ('grasbrann',),
'grasbranner': ('grasbrann',),
'grasdekka': ('grasdekke',),
'grasdekke': ('grasdekke',),
'grasdekkene': ('grasdekke',),
'grasdekker': ('grasdekke',),
'grasdekket': ('grasdekke',),
'grasfamilie': ('grasfamilie',),
'grasfamilien': ('grasfamilie',),
'grasfamiliene': ('grasfamilie',),
'grasfamilier': ('grasfamilie',),
'grasfrø': ('grasfrø',),
'grasfrøa': ('grasfrø',),
'grasfrøene': ('grasfrø',),
'grasfrøet': ('grasfrø',),
'grashoppa': ('grashoppe',),
'grashoppe': ('grashoppe',),
'grashoppen': ('grashoppe',),
'grashoppene': ('grashoppe',),
'grashopper': ('grashoppe',),
'grasing': ('grasing',),
'grasingen': ('grasing',),
'grasingene': ('grasing',),
'grasinger': ('grasing',),
'graskar': ('graskar',),
'graskara': ('graskar',),
'graskarene': ('graskar',),
'graskaret': ('graskar',),
'grasklipper': ('grasklipper',),
'grasklippere': ('grasklipper',),
'grasklipperen': ('grasklipper',),
'grasklipperer': ('grasklipper',),
'grasklipperne': ('grasklipper',),
'grasklypper': ('grasklypper',),
'grasklyppere': ('grasklypper',),
'grasklypperen': ('grasklypper',),
'grasklypperer': ('grasklypper',),
'grasklypperne': ('grasklypper',),
'grasløk': ('grasløk',),
'grasløken': ('grasløk',),
'grasløkene': ('grasløk',),
'grasløker': ('grasløk',),
'grasmatta': ('grasmatte',),
'grasmatte': ('grasmatte',),
'grasmatten': ('grasmatte',),
'grasmattene': ('grasmatte',),
'grasmatter': ('grasmatte',),
'grasnaut': ('grasnaut',),
'grasnauta': ('grasnaut',),
'grasnautene': ('grasnaut',),
'grasnautet': ('grasnaut',),
'grasplen': ('grasplen',),
'grasplenen': ('grasplen',),
'grasplenene': ('grasplen',),
'grasplener': ('grasplen',),
'grasrot': ('grasrot',),
'grasrota': ('grasrot',),
'grasroten': ('grasrot',),
'grasrøttene': ('grasrot',),
'grasrøtter': ('grasrot',),
'grasrotbevegelse': ('grasrotbevegelse',),
'grasrotbevegelsen': ('grasrotbevegelse',),
'grasrotbevegelsene': ('grasrotbevegelse',),
'grasrotbevegelser': ('grasrotbevegelse',),
'grasrotkontakt': ('grasrotkontakt',),
'grasrotkontakten': ('grasrotkontakt',),
'grasrotkontaktene': ('grasrotkontakt',),
'grasrotkontakter': ('grasrotkontakt',),
'grasrotnivå': ('grasrotnivå',),
'grasrotnivåa': ('grasrotnivå',),
'grasrotnivåene': ('grasrotnivå',),
'grasrotnivåer': ('grasrotnivå',),
'grasrotnivået': ('grasrotnivå',),
'grassletta': ('grasslette',),
'grasslette': ('grasslette',),
'grassletten': ('grasslette',),
'grasslettene': ('grasslette',),
'grassletter': ('grasslette',),
'grasstrå': ('grasstrå',),
'grasstråa': ('grasstrå',),
'grasstråene': ('grasstrå',),
'grasstrået': ('grasstrå',),
'grastorv': ('grastorv',),
'grastorva': ('grastorv',),
'grastorven': ('grastorv',),
'grastorvene': ('grastorv',),
'grastorver': ('grastorv',),
'grastorvet': ('grastorv',),
'grasvoll': ('grasvoll',),
'grasvollen': ('grasvoll',),
'grasvollene': ('grasvoll',),
'grasvoller': ('grasvoll',),
'grateng': ('grateng',),
'gratengen': ('grateng',),
'gratengene': ('grateng',),
'gratenger': ('grateng',),
'gratengform': ('gratengform',),
'gratengforma': ('gratengform',),
'gratengformen': ('gratengform',),
'gratengformene': ('gratengform',),
'gratengformer': ('gratengform',),
'gratiala': ('gratiale',),
'gratiale': ('gratiale',),
'gratialene': ('gratiale',),
'gratialer': ('gratiale',),
'gratialet': ('gratiale',),
'gratie': ('gratie',),
'gratien': ('gratie',),
'gratiene': ('gratie',),
'gratier': ('gratie',),
'gratifikasjon': ('gratifikasjon',),
'gratifikasjonen': ('gratifikasjon',),
'gratifikasjonene': ('gratifikasjon',),
'gratifikasjoner': ('gratifikasjon',),
'gratisarbeid': ('gratisarbeid',),
'gratisarbeida': ('gratisarbeid',),
'gratisarbeidene': ('gratisarbeid',),
'gratisarbeider': ('gratisarbeid',),
'gratisarbeidet': ('gratisarbeid',),
'gratisforestilling': ('gratisforestilling',),
'gratisforestillinga': ('gratisforestilling',),
'gratisforestillingen': ('gratisforestilling',),
'gratisforestillingene': ('gratisforestilling',),
'gratisforestillinger': ('gratisforestilling',),
'gratispassasjer': ('gratispassasjer',),
'gratispassasjeren': ('gratispassasjer',),
'gratispassasjerene': ('gratispassasjer',),
'gratispassasjerer': ('gratispassasjer',),
'gratist': ('gratist',),
'gratisten': ('gratist',),
'gratistene': ('gratist',),
'gratister': ('gratist',),
'gratisteri': ('gratisteri',),
'gratisteria': ('gratisteri',),
'gratisteriene': ('gratisteri',),
'gratisteriet': ('gratisteri',),
'gratistur': ('gratistur',),
'gratisturen': ('gratistur',),
'gratisturene': ('gratistur',),
'gratisturer': ('gratistur',),
'gratulant': ('gratulant',),
'gratulanten': ('gratulant',),
'gratulantene': ('gratulant',),
'gratulanter': ('gratulant',),
'gratulasjon': ('gratulasjon',),
'gratulasjonen': ('gratulasjon',),
'gratulasjonene': ('gratulasjon',),
'gratulasjoner': ('gratulasjon',),
'graut': ('graut',),
'grauten': ('graut',),
'grautene': ('graut',),
'grauter': ('graut',),
'grautdag': ('grautdag',),
'grautdagen': ('grautdag',),
'grautdagene': ('grautdag',),
'grautdager': ('grautdag',),
'grautfat': ('grautfat',),
'grautfata': ('grautfat',),
'grautfatene': ('grautfat',),
'grautfater': ('grautfat',),
'grautfatet': ('grautfat',),
'grauthoda': ('grauthode',),
'grauthode': ('grauthode',),
'grauthodene': ('grauthode',),
'grauthoder': ('grauthode',),
'grauthodet': ('grauthode',),
'grauthoda': ('grauthode',),
'grauthode': ('grauthode',),
'grauthodene': ('grauthode',),
'grauthoder': ('grauthode',),
'grauthodet': ('grauthode',),
'grautklepp': ('grautklepp',),
'grautkleppen': ('grautklepp',),
'grautkleppene': ('grautklepp',),
'grautklepper': ('grautklepp',),
'grautomslag': ('grautomslag',),
'grautomslaga': ('grautomslag',),
'grautomslagene': ('grautomslag',),
'grautomslaget': ('grautomslag',),
'grautpinne': ('grautpinne',),
'grautpinnen': ('grautpinne',),
'grautpinnene': ('grautpinne',),
'grautpinner': ('grautpinne',),
'grautsleiv': ('grautsleiv',),
'grautsleiva': ('grautsleiv',),
'grautsleiven': ('grautsleiv',),
'grautsleivene': ('grautsleiv',),
'grautsleiver': ('grautsleiv',),
'grav': ('grav',),
'graven': ('grav',),
'gravene': ('grav',),
'graver': ('grav',),
'grav': ('grav',),
'grava': ('grav',),
'gravene': ('grav',),
'gravet': ('grav',),
'grav': ('grav',),
'grava': ('grav',),
'graven': ('grav',),
'gravene': ('grav',),
'graver': ('grav',),
'gravalvor': ('gravalvor',),
'gravalvora': ('gravalvor',),
'gravalvorene': ('gravalvor',),
'gravalvoret': ('gravalvor',),
'gravand': ('gravand',),
'gravanda': ('gravand',),
'gravanden': ('gravand',),
'gravendene': ('gravand',),
'gravender': ('gravand',),
'gravearbeid': ('gravearbeid',),
'gravearbeida': ('gravearbeid',),
'gravearbeidene': ('gravearbeid',),
'gravearbeider': ('gravearbeid',),
'gravearbeidet': ('gravearbeid',),
'gravefartøy': ('gravefartøy',),
'gravefartøya': ('gravefartøy',),
'gravefartøyene': ('gravefartøy',),
'gravefartøyer': ('gravefartøy',),
'gravefartøyet': ('gravefartøy',),
'gravemaskin': ('gravemaskin',),
'gravemaskina': ('gravemaskin',),
'gravemaskinen': ('gravemaskin',),
'gravemaskinene': ('gravemaskin',),
'gravemaskiner': ('gravemaskin',),
'gravenstein': ('gravenstein',),
'gravensteinen': ('gravenstein',),
'gravensteinene': ('gravenstein',),
'gravensteiner': ('gravenstein',),
'gravensteinepla': ('gravensteineple',),
'gravensteineple': ('gravensteineple',),
'gravensteineplene': ('gravensteineple',),
'gravensteinepler': ('gravensteineple',),
'gravensteineplet': ('gravensteineple',),
'gravensteinsepla': ('gravensteinseple',),
'gravensteinseple': ('gravensteinseple',),
'gravensteinseplene': ('gravensteinseple',),
'gravensteinsepler': ('gravensteinseple',),
'gravensteinseplet': ('gravensteinseple',),
'gravensten': ('gravensten',),
'gravenstenen': ('gravensten',),
'gravenstenene': ('gravensten',),
'gravenstener': ('gravensten',),
'gravenstenepla': ('gravensteneple',),
'gravensteneple': ('gravensteneple',),
'gravensteneplene': ('gravensteneple',),
'gravenstenepler': ('gravensteneple',),
'gravensteneplet': ('gravensteneple',),
'gravenstensepla': ('gravenstenseple',),
'gravenstenseple': ('gravenstenseple',),
'gravenstenseplene': ('gravenstenseple',),
'gravenstensepler': ('gravenstenseple',),
'gravenstenseplet': ('gravenstenseple',),
'graver': ('graver',),
'gravere': ('graver',),
'graveren': ('graver',),
'graverer': ('graver',),
'graverne': ('graver',),
'gravering': ('gravering',),
'graveringa': ('gravering',),
'graveringen': ('gravering',),
'graveringene': ('gravering',),
'graveringer': ('gravering',),
'graveslede': ('graveslede',),
'gravesleden': ('graveslede',),
'gravesledene': ('graveslede',),
'gravesleder': ('graveslede',),
'gravfelt': ('gravfelt',),
'gravfelta': ('gravfelt',),
'gravfeltene': ('gravfelt',),
'gravfelter': ('gravfelt',),
'gravfeltet': ('gravfelt',),
'gravferd': ('gravferd',),
'gravferda': ('gravferd',),
'gravferden': ('gravferd',),
'gravferdene': ('gravferd',),
'gravferder': ('gravferd',),
'gravfred': ('gravfred',),
'gravfreden': ('gravfred',),
'gravfredene': ('gravfred',),
'gravfreder': ('gravfred',),
'gravfunn': ('gravfunn',),
'gravfunna': ('gravfunn',),
'gravfunnene': ('gravfunn',),
'gravfunnet': ('gravfunn',),
'gravhaug': ('gravhaug',),
'gravhaugen': ('gravhaug',),
'gravhaugene': ('gravhaug',),
'gravhauger': ('gravhaug',),
'gravhola': ('gravhole',),
'gravhole': ('gravhole',),
'gravholen': ('gravhole',),
'gravholene': ('gravhole',),
'gravholer': ('gravhole',),
'gravhula': ('gravhule',),
'gravhule': ('gravhule',),
'gravhulen': ('gravhule',),
'gravhulene': ('gravhule',),
'gravhuler': ('gravhule',),
'graviditet': ('graviditet',),
'graviditeten': ('graviditet',),
'graviditetene': ('graviditet',),
'graviditeter': ('graviditet',),
'graviditetsprøva': ('graviditetsprøve',),
'graviditetsprøve': ('graviditetsprøve',),
'graviditetsprøven': ('graviditetsprøve',),
'graviditetsprøvene': ('graviditetsprøve',),
'graviditetsprøver': ('graviditetsprøve',),
'gravis': ('gravis',),
'gravisen': ('gravis',),
'gravisene': ('gravis',),
'graviser': ('gravis',),
'gravistegn': ('gravistegn',),
'gravistegna': ('gravistegn',),
'gravistegnene': ('gravistegn',),
'gravistegnet': ('gravistegn',),
'gravitasjon': ('gravitasjon',),
'gravitasjonen': ('gravitasjon',),
'gravitasjonene': ('gravitasjon',),
'gravitasjoner': ('gravitasjon',),
'gravitasjonsfelt': ('gravitasjonsfelt',),
'gravitasjonsfelta': ('gravitasjonsfelt',),
'gravitasjonsfeltene': ('gravitasjonsfelt',),
'gravitasjonsfelter': ('gravitasjonsfelt',),
'gravitasjonsfeltet': ('gravitasjonsfelt',),
'gravitet': ('gravitet',),
'graviteten': ('gravitet',),
'gravitetene': ('gravitet',),
'graviteter': ('gravitet',),
'gravlaks': ('gravlaks',),
'gravlaksen': ('gravlaks',),
'gravlaksene': ('gravlaks',),
'gravlakser': ('gravlaks',),
'gravlund': ('gravlund',),
'gravlunden': ('gravlund',),
'gravlundene': ('gravlund',),
'gravlunder': ('gravlund',),
'gravminna': ('gravminne',),
'gravminne': ('gravminne',),
'gravminnene': ('gravminne',),
'gravminner': ('gravminne',),
'gravminnet': ('gravminne',),
'gravmæla': ('gravmæle',),
'gravmæle': ('gravmæle',),
'gravmælene': ('gravmæle',),
'gravmæler': ('gravmæle',),
'gravmælet': ('gravmæle',),
'gravplass': ('gravplass',),
'gravplassen': ('gravplass',),
'gravplassene': ('gravplass',),
'gravplasser': ('gravplass',),
'gravrust': ('gravrust',),
'gravrusta': ('gravrust',),
'gravrusten': ('gravrust',),
'gravrustene': ('gravrust',),
'gravruster': ('gravrust',),
'gravrøst': ('gravrøst',),
'gravrøsta': ('gravrøst',),
'gravrøsten': ('gravrøst',),
'gravrøstene': ('gravrøst',),
'gravrøster': ('gravrøst',),
'gravrøys': ('gravrøys',),
'gravrøysa': ('gravrøys',),
'gravrøysen': ('gravrøys',),
'gravrøysene': ('gravrøys',),
'gravrøyser': ('gravrøys',),
'gravskjending': ('gravskjending',),
'gravskjendinga': ('gravskjending',),
'gravskjendingen': ('gravskjending',),
'gravskjendingene': ('gravskjending',),
'gravskjendinger': ('gravskjending',),
'gravskrift': ('gravskrift',),
'gravskrifta': ('gravskrift',),
'gravskriften': ('gravskrift',),
'gravskriftene': ('gravskrift',),
'gravskrifter': ('gravskrift',),
'gravsted': ('gravsted',),
'gravstedene': ('gravsted',),
'gravsteder': ('gravsted',),
'gravstedet': ('gravsted',),
'gravstein': ('gravstein',),
'gravsteinen': ('gravstein',),
'gravsteinene': ('gravstein',),
'gravsteiner': ('gravstein',),
'gravstikka': ('gravstikke',),
'gravstikke': ('gravstikke',),
'gravstikken': ('gravstikke',),
'gravstikkene': ('gravstikke',),
'gravstikker': ('gravstikke',),
'gravstikkel': ('gravstikkel',),
'gravstikkelen': ('gravstikkel',),
'gravstiklene': ('gravstikkel',),
'gravstikler': ('gravstikkel',),
'gravstøtta': ('gravstøtte',),
'gravstøtte': ('gravstøtte',),
'gravstøtten': ('gravstøtte',),
'gravstøttene': ('gravstøtte',),
'gravstøtter': ('gravstøtte',),
'gravtale': ('gravtale',),
'gravtalen': ('gravtale',),
'gravtalene': ('gravtale',),
'gravtaler': ('gravtale',),
'gravtegn': ('gravtegn',),
'gravtegna': ('gravtegn',),
'gravtegnene': ('gravtegn',),
'gravtegnet': ('gravtegn',),
'gravurna': ('gravurne',),
'gravurne': ('gravurne',),
'gravurnen': ('gravurne',),
'gravurnene': ('gravurne',),
'gravurner': ('gravurne',),
'gravyr': ('gravyr',),
'gravyren': ('gravyr',),
'gravyrene': ('gravyr',),
'gravyrer': ('gravyr',),
'gravøl': ('gravøl',),
'gravøla': ('gravøl',),
'gravølene': ('gravøl',),
'gravølet': ('gravøl',),
'gravør': ('gravør',),
'gravøren': ('gravør',),
'gravørene': ('gravør',),
'gravører': ('gravør',),
'gravørkunst': ('gravørkunst',),
'gravørkunsten': ('gravørkunst',),
'gravørkunstene': ('gravørkunst',),
'gravørkunster': ('gravørkunst',),
'gray': ('gray',),
'grayen': ('gray',),
'grayene': ('gray',),
'gregorsmess': ('gregorsmess',),
'gregorsmess': ('gregorsmess',),
'gregorsmesse': ('gregorsmesse',),
'greia': ('greie',),
'greie': ('greie',),
'greiene': ('greie',),
'greier': ('greie',),
'greiet': ('greie',),
'greia': ('greie',),
'greie': ('greie',),
'greien': ('greie',),
'greiene': ('greie',),
'greier': ('greie',),
'greietråd': ('greietråd',),
'greietråden': ('greietråd',),
'greietrådene': ('greietråd',),
'greietråder': ('greietråd',),
'grein': ('grein',),
'greina': ('grein',),
'greinen': ('grein',),
'greinene': ('grein',),
'greiner': ('grein',),
'grein': ('grein',),
'greinrør': ('greinrør',),
'greinrøra': ('greinrør',),
'greinrørene': ('greinrør',),
'greinrøret': ('greinrør',),
'greip': ('greip',),
'greipa': ('greip',),
'greipen': ('greip',),
'greipene': ('greip',),
'greiper': ('greip',),
'greipet': ('greip',),
'greker': ('greker',),
'grekere': ('greker',),
'grekeren': ('greker',),
'grekerer': ('greker',),
'grekerne': ('greker',),
'gremmelse': ('gremmelse',),
'gremmelsen': ('gremmelse',),
'gremmelsene': ('gremmelse',),
'gremmelser': ('gremmelse',),
'gren': ('gren',),
'grena': ('gren',),
'grenene': ('gren',),
'grenet': ('gren',),
'gren': ('gren',),
'grena': ('gren',),
'grenen': ('gren',),
'grenene': ('gren',),
'grener': ('gren',),
'grenader': ('grenader',),
'grenaderen': ('grenader',),
'grenaderene': ('grenader',),
'grenaderer': ('grenader',),
'grenadier': ('grenadier',),
'grenadiere': ('grenadier',),
'grenadieren': ('grenadier',),
'grenadierer': ('grenadier',),
'grenadierne': ('grenadier',),
'grend': ('grend',),
'grenda': ('grend',),
'grenden': ('grend',),
'grendene': ('grend',),
'grender': ('grend',),
'grendefolk': ('grendefolk',),
'grendefolka': ('grendefolk',),
'grendefolkene': ('grendefolk',),
'grendefolket': ('grendefolk',),
'grendehus': ('grendehus',),
'grendehusa': ('grendehus',),
'grendehusene': ('grendehus',),
'grendehuset': ('grendehus',),
'grendelag': ('grendelag',),
'grendelaga': ('grendelag',),
'grendelagene': ('grendelag',),
'grendelaget': ('grendelag',),
'grendesenter': ('grendesenter',),
'grendesenteret': ('grendesenter',),
'grendesentra': ('grendesenter',),
'grendesentre': ('grendesenter',),
'grendesentrene': ('grendesenter',),
'grendesentret': ('grendesenter',),
'grendeskole': ('grendeskole',),
'grendeskolen': ('grendeskole',),
'grendeskolene': ('grendeskole',),
'grendeskoler': ('grendeskole',),
'grendeutvalg': ('grendeutvalg',),
'grendeutvalga': ('grendeutvalg',),
'grendeutvalgene': ('grendeutvalg',),
'grendeutvalget': ('grendeutvalg',),
'grena': ('grene',),
'grene': ('grene',),
'grenen': ('grene',),
'grenene': ('grene',),
'grener': ('grene',),
'grenrør': ('grenrør',),
'grenrøra': ('grenrør',),
'grenrørene': ('grenrør',),
'grenrøret': ('grenrør',),
'grensa': ('grense',),
'grense': ('grense',),
'grensen': ('grense',),
'grensene': ('grense',),
'grenser': ('grense',),
'grensebelta': ('grensebelte',),
'grensebelte': ('grensebelte',),
'grensebeltene': ('grensebelte',),
'grensebelter': ('grensebelte',),
'grensebeltet': ('grensebelte',),
'grenseboer': ('grenseboer',),
'grenseboere': ('grenseboer',),
'grenseboeren': ('grenseboer',),
'grenseboerer': ('grenseboer',),
'grenseboerne': ('grenseboer',),
'grensebuer': ('grensebuer',),
'grensebuere': ('grensebuer',),
'grensebueren': ('grensebuer',),
'grensebuerer': ('grensebuer',),
'grensebuerne': ('grensebuer',),
'grenseby': ('grenseby',),
'grensebyen': ('grenseby',),
'grensebyene': ('grenseby',),
'grensebyer': ('grenseby',),
'grensebygd': ('grensebygd',),
'grensebygda': ('grensebygd',),
'grensebygden': ('grensebygd',),
'grensebygdene': ('grensebygd',),
'grensebygder': ('grensebygd',),
'grenseelv': ('grenseelv',),
'grenseelva': ('grenseelv',),
'grenseelven': ('grenseelv',),
'grenseelvene': ('grenseelv',),
'grenseelver': ('grenseelv',),
'grensegang': ('grensegang',),
'grensegangen': ('grensegang',),
'grensegangene': ('grensegang',),
'grenseganger': ('grensegang',),
'grensegata': ('grensegate',),
'grensegate': ('grensegate',),
'grensegaten': ('grensegate',),
'grensegatene': ('grensegate',),
'grensegater': ('grensegate',),
'grensehandel': ('grensehandel',),
'grensehandelen': ('grensehandel',),
'grensehandlene': ('grensehandel',),
'grensehandler': ('grensehandel',),
'grensekommissær': ('grensekommissær',),
'grensekommissæren': ('grensekommissær',),
'grensekommissærene': ('grensekommissær',),
'grensekommissærer': ('grensekommissær',),
'grensekrig': ('grensekrig',),
'grensekrigen': ('grensekrig',),
'grensekrigene': ('grensekrig',),
'grensekriger': ('grensekrig',),
'grenseland': ('grenseland',),
'grenselanda': ('grenseland',),
'grenselandene': ('grenseland',),
'grenselandet': ('grenseland',),
'grenselinja': ('grenselinje',),
'grenselinje': ('grenselinje',),
'grenselinjen': ('grenselinje',),
'grenselinjene': ('grenselinje',),
'grenselinjer': ('grenselinje',),
'grensemerka': ('grensemerke',),
'grensemerke': ('grensemerke',),
'grensemerkene': ('grensemerke',),
'grensemerker': ('grensemerke',),
'grensemerket': ('grensemerke',),
'grenseområda': ('grenseområde',),
'grenseområde': ('grenseområde',),
'grenseområdene': ('grenseområde',),
'grenseområder': ('grenseområde',),
'grenseområdet': ('grenseområde',),
'grenseoppsyn': ('grenseoppsyn',),
'grenseoppsyna': ('grenseoppsyn',),
'grenseoppsynene': ('grenseoppsyn',),
'grenseoppsynet': ('grenseoppsyn',),
'grenseovergang': ('grenseovergang',),
'grenseovergangen': ('grenseovergang',),
'grenseovergangene': ('grenseovergang',),
'grenseoverganger': ('grenseovergang',),
'grensepost': ('grensepost',),
'grenseposten': ('grensepost',),
'grensepostene': ('grensepost',),
'grenseposter': ('grensepost',),
'grenseskjell': ('grenseskjell',),
'grenseskjella': ('grenseskjell',),
'grenseskjellene': ('grenseskjell',),
'grenseskjellet': ('grenseskjell',),
'grensestasjon': ('grensestasjon',),
'grensestasjonen': ('grensestasjon',),
'grensestasjonene': ('grensestasjon',),
'grensestasjoner': ('grensestasjon',),
'grensestein': ('grensestein',),
'grensesteinen': ('grensestein',),
'grensesteinene': ('grensestein',),
'grensesteiner': ('grensestein',),
'grensestrid': ('grensestrid',),
'grensestriden': ('grensestrid',),
'grensestridene': ('grensestrid',),
'grensestrider': ('grensestrid',),
'grensetilfella': ('grensetilfelle',),
'grensetilfelle': ('grensetilfelle',),
'grensetilfellene': ('grensetilfelle',),
'grensetilfeller': ('grensetilfelle',),
'grensetilfellet': ('grensetilfelle',),
'grensetoll': ('grensetoll',),
'grensetollen': ('grensetoll',),
'grensetollene': ('grensetoll',),
'grensetoller': ('grensetoll',),
'grensetrafikk': ('grensetrafikk',),
'grensetrafikken': ('grensetrafikk',),
'grensetrafikkene': ('grensetrafikk',),
'grensetrafikker': ('grensetrafikk',),
'grensetvist': ('grensetvist',),
'grensetvisten': ('grensetvist',),
'grensetvistene': ('grensetvist',),
'grensetvister': ('grensetvist',),
'grensevakt': ('grensevakt',),
'grensevakta': ('grensevakt',),
'grensevakten': ('grensevakt',),
'grensevaktene': ('grensevakt',),
'grensevakter': ('grensevakt',),
'grenseverdi': ('grenseverdi',),
'grenseverdien': ('grenseverdi',),
'grenseverdiene': ('grenseverdi',),
'grenseverdier': ('grenseverdi',),
'grep': ('grep',),
'grepa': ('grep',),
'grepene': ('grep',),
'grepet': ('grep',),
'grepp': ('grepp',),
'greppa': ('grepp',),
'greppene': ('grepp',),
'greppet': ('grepp',),
'grepplyng': ('grepplyng',),
'grepplynga': ('grepplyng',),
'grepplyngen': ('grepplyng',),
'grepplyngene': ('grepplyng',),
'grepplynger': ('grepplyng',),
'grepplynget': ('grepplyng',),
'gresk': ('gresk',),
'gresken': ('gresk',),
'greskene': ('gresk',),
'gresker': ('gresk',),
'gress': ('gress',),
'gressa': ('gress',),
'gressene': ('gress',),
'gresset': ('gress',),
'gress-sletta': ('gress-slette',),
'gress-slette': ('gress-slette',),
'gress-sletten': ('gress-slette',),
'gress-slettene': ('gress-slette',),
'gress-sletter': ('gress-slette',),
'gress-strå': ('gress-strå',),
'gress-stråa': ('gress-strå',),
'gress-stråene': ('gress-strå',),
'gress-strået': ('gress-strå',),
'gressand': ('gressand',),
'gressanda': ('gressand',),
'gressanden': ('gressand',),
'gressendene': ('gressand',),
'gressender': ('gressand',),
'gressbakke': ('gressbakke',),
'gressbakken': ('gressbakke',),
'gressbakkene': ('gressbakke',),
'gressbakker': ('gressbakke',),
'gressbane': ('gressbane',),
'gressbanen': ('gressbane',),
'gressbanene': ('gressbane',),
'gressbaner': ('gressbane',),
'gressbrann': ('gressbrann',),
'gressbrannen': ('gressbrann',),
'gressbrannene': ('gressbrann',),
'gressbranner': ('gressbrann',),
'gressdekka': ('gressdekke',),
'gressdekke': ('gressdekke',),
'gressdekkene': ('gressdekke',),
'gressdekker': ('gressdekke',),
'gressdekket': ('gressdekke',),
'gressenka': ('gressenke',),
'gressenke': ('gressenke',),
'gressenken': ('gressenke',),
'gressenkene': ('gressenke',),
'gressenker': ('gressenke',),
'gressenkemann': ('gressenkemann',),
'gressenkemannen': ('gressenkemann',),
'gressenkemenn': ('gressenkemann',),
'gressenkemennene': ('gressenkemann',),
'gressfamilie': ('gressfamilie',),
'gressfamilien': ('gressfamilie',),
'gressfamiliene': ('gressfamilie',),
'gressfamilier': ('gressfamilie',),
'gressfrø': ('gressfrø',),
'gressfrøa': ('gressfrø',),
'gressfrøene': ('gressfrø',),
'gressfrøet': ('gressfrø',),
'gresshoppa': ('gresshoppe',),
'gresshoppe': ('gresshoppe',),
'gresshoppen': ('gresshoppe',),
'gresshoppene': ('gresshoppe',),
'gresshopper': ('gresshoppe',),
'gresskar': ('gresskar',),
'gresskara': ('gresskar',),
'gresskarene': ('gresskar',),
'gresskaret': ('gresskar',),
'gressklipper': ('gressklipper',),
'gressklippere': ('gressklipper',),
'gressklipperen': ('gressklipper',),
'gressklipperer': ('gressklipper',),
'gressklipperne': ('gressklipper',),
'gressklypper': ('gressklypper',),
'gressklyppere': ('gressklypper',),
'gressklypperen': ('gressklypper',),
'gressklypperer': ('gressklypper',),
'gressklypperne': ('gressklypper',),
'gressletta': ('gresslette',),
'gresslette': ('gresslette',),
'gressletten': ('gresslette',),
'gresslettene': ('gresslette',),
'gressletter': ('gresslette',),
'gressløk': ('gressløk',),
'gressløken': ('gressløk',),
'gressløkene': ('gressløk',),
'gressløker': ('gressløk',),
'gressmatta': ('gressmatte',),
'gressmatte': ('gressmatte',),
'gressmatten': ('gressmatte',),
'gressmattene': ('gressmatte',),
'gressmatter': ('gressmatte',),
'gressplen': ('gressplen',),
'gressplenen': ('gressplen',),
'gressplenene': ('gressplen',),
'gressplener': ('gressplen',),
'gresstorv': ('gresstorv',),
'gresstorva': ('gresstorv',),
'gresstorven': ('gresstorv',),
'gresstorvene': ('gresstorv',),
'gresstorver': ('gresstorv',),
'gresstorvet': ('gresstorv',),
'gresstrå': ('gresstrå',),
'gresstråa': ('gresstrå',),
'gresstråene': ('gresstrå',),
'gresstrået': ('gresstrå',),
'gressvoll': ('gressvoll',),
'gressvollen': ('gressvoll',),
'gressvollene': ('gressvoll',),
'gressvoller': ('gressvoll',),
'grev': ('grev',),
'greva': ('grev',),
'grevene': ('grev',),
'grevet': ('grev',),
'greve': ('greve',),
'greven': ('greve',),
'grevene': ('greve',),
'grever': ('greve',),
'grevetitlene': ('grevetittel',),
'grevetitler': ('grevetittel',),
'grevetittel': ('grevetittel',),
'grevetittelen': ('grevetittel',),
'grevinna': ('grevinne',),
'grevinne': ('grevinne',),
'grevinnen': ('grevinne',),
'grevinnene': ('grevinne',),
'grevinner': ('grevinne',),
'grevling': ('grevling',),
'grevlingen': ('grevling',),
'grevlingene': ('grevling',),
'grevlinger': ('grevling',),
'grevlinghund': ('grevlinghund',),
'grevlinghunden': ('grevlinghund',),
'grevlinghundene': ('grevlinghund',),
'grevlinghunder': ('grevlinghund',),
'grevskaft': ('grevskaft',),
'grevskafta': ('grevskaft',),
'grevskaftene': ('grevskaft',),
'grevskafter': ('grevskaft',),
'grevskaftet': ('grevskaft',),
'grevskap': ('grevskap',),
'grevskapa': ('grevskap',),
'grevskapene': ('grevskap',),
'grevskaper': ('grevskap',),
'grevskapet': ('grevskap',),
'greyhound': ('greyhound',),
'greyhounden': ('greyhound',),
'greyhoundene': ('greyhound',),
'greyhounder': ('greyhound',),
'gribb': ('gribb',),
'gribben': ('gribb',),
'gribbene': ('gribb',),
'gribber': ('gribb',),
'grid': ('grid',),
'grida': ('grid',),
'gridene': ('grid',),
'gridet': ('grid',),
'griff': ('griff',),
'griffen': ('griff',),
'griffene': ('griff',),
'griffer': ('griff',),
'griffel': ('griffel',),
'griffelen': ('griffel',),
'griflene': ('griffel',),
'grifler': ('griffel',),
'griffelfot': ('griffelfot',),
'griffelfoten': ('griffelfot',),
'griffelføttene': ('griffelfot',),
'griffelføtter': ('griffelfot',),
'griljermel': ('griljermel',),
'griljermela': ('griljermel',),
'griljermelene': ('griljermel',),
'griljermelet': ('griljermel',),
'griljermjøl': ('griljermjøl',),
'griljermjøla': ('griljermjøl',),
'griljermjølene': ('griljermjøl',),
'griljermjølet': ('griljermjøl',),
'grill': ('grill',),
'grillen': ('grill',),
'grillene': ('grill',),
'griller': ('grill',),
'grillbar': ('grillbar',),
'grillbaren': ('grillbar',),
'grillbarene': ('grillbar',),
'grillbarer': ('grillbar',),
'grilla': ('grille',),
'grille': ('grille',),
'grillen': ('grille',),
'grillene': ('grille',),
'griller': ('grille',),
'grillett': ('grillett',),
'grilletten': ('grillett',),
'grillettene': ('grillett',),
'grilletter': ('grillett',),
'grillpølsa': ('grillpølse',),
'grillpølse': ('grillpølse',),
'grillpølsen': ('grillpølse',),
'grillpølsene': ('grillpølse',),
'grillpølser': ('grillpølse',),
'grillrom': ('grillrom',),
'grillromma': ('grillrom',),
'grillrommene': ('grillrom',),
'grillrommet': ('grillrom',),
'grillspyd': ('grillspyd',),
'grillspyda': ('grillspyd',),
'grillspydene': ('grillspyd',),
'grillspydet': ('grillspyd',),
'grim': ('grim',),
'grimen': ('grim',),
'grimene': ('grim',),
'grimer': ('grim',),
'grimase': ('grimase',),
'grimasen': ('grimase',),
'grimasene': ('grimase',),
'grimaser': ('grimase',),
'grima': ('grime',),
'grime': ('grime',),
'grimen': ('grime',),
'grimene': ('grime',),
'grimer': ('grime',),
'grin': ('grin',),
'grina': ('grin',),
'grinene': ('grin',),
'grinet': ('grin',),
'grind': ('grind',),
'grinda': ('grind',),
'grinden': ('grind',),
'grindene': ('grind',),
'grinder': ('grind',),
'grindhval': ('grindhval',),
'grindhvalen': ('grindhval',),
'grindhvalene': ('grindhval',),
'grindhvaler': ('grindhval',),
'grindkval': ('grindkval',),
'grindkvalen': ('grindkval',),
'grindkvalene': ('grindkval',),
'grindkvaler': ('grindkval',),
'grindlås': ('grindlås',),
'grindlåsa': ('grindlås',),
'grindlåsen': ('grindlås',),
'grindlåsene': ('grindlås',),
'grindlåser': ('grindlås',),
'grindlåset': ('grindlås',),
'grindpengene': ('grindpenger',),
'grindpenger': ('grindpenger',),
'grindsag': ('grindsag',),
'grindsaga': ('grindsag',),
'grindsagen': ('grindsag',),
'grindsagene': ('grindsag',),
'grindsager': ('grindsag',),
'grindstolpe': ('grindstolpe',),
'grindstolpen': ('grindstolpe',),
'grindstolpene': ('grindstolpe',),
'grindstolper': ('grindstolpe',),
'grinebiter': ('grinebiter',),
'grinebitere': ('grinebiter',),
'grinebiteren': ('grinebiter',),
'grinebiterer': ('grinebiter',),
'grinebiterne': ('grinebiter',),
'gringo': ('gringo',),
'gringoen': ('gringo',),
'gringoene': ('gringo',),
'gringoer': ('gringo',),
'gripbrett': ('gripbrett',),
'gripbretta': ('gripbrett',),
'gripbrettene': ('gripbrett',),
'gripbretter': ('gripbrett',),
'gripbrettet': ('gripbrett',),
'gripebrett': ('gripebrett',),
'gripebretta': ('gripebrett',),
'gripebrettene': ('gripebrett',),
'gripebretter': ('gripebrett',),
'gripebrettet': ('gripebrett',),
'gripeevna': ('gripeevne',),
'gripeevne': ('gripeevne',),
'gripeevnen': ('gripeevne',),
'gripeevnene': ('gripeevne',),
'gripeevner': ('gripeevne',),
'gripeklo': ('gripeklo',),
'gripekloa': ('gripeklo',),
'gripekloen': ('gripeklo',),
'gripeklør': ('gripeklo',),
'gripeklørne': ('gripeklo',),
'gripeorgan': ('gripeorgan',),
'gripeorgana': ('gripeorgan',),
'gripeorganene': ('gripeorgan',),
'gripeorganer': ('gripeorgan',),
'gripeorganet': ('gripeorgan',),
'griper': ('griper',),
'gripere': ('griper',),
'griperen': ('griper',),
'griperer': ('griper',),
'griperne': ('griper',),
'griperedskap': ('griperedskap',),
'griperedskapa': ('griperedskap',),
'griperedskapen': ('griperedskap',),
'griperedskapene': ('griperedskap',),
'griperedskaper': ('griperedskap',),
'griperedskapet': ('griperedskap',),
'griperefleks': ('griperefleks',),
'griperefleksen': ('griperefleks',),
'griperefleksene': ('griperefleks',),
'gripereflekser': ('griperefleks',),
'grisailla': ('grisaille',),
'grisaille': ('grisaille',),
'grisaillene': ('grisaille',),
'grisailler': ('grisaille',),
'grisaillet': ('grisaille',),
'griseal': ('griseal',),
'griseala': ('griseal',),
'grisealene': ('griseal',),
'grisealet': ('griseal',),
'grisearbeid': ('grisearbeid',),
'grisearbeida': ('grisearbeid',),
'grisearbeidene': ('grisearbeid',),
'grisearbeider': ('grisearbeid',),
'grisearbeidet': ('grisearbeid',),
'griseavl': ('griseavl',),
'griseavlen': ('griseavl',),
'griseavlene': ('griseavl',),
'griseavler': ('griseavl',),
'grisebing': ('grisebing',),
'grisebingen': ('grisebing',),
'grisebingene': ('grisebing',),
'grisebinger': ('grisebing',),
'grisebinge': ('grisebinge',),
'grisebingen': ('grisebinge',),
'grisebingene': ('grisebinge',),
'grisebinger': ('grisebinge',),
'grisebust': ('grisebust',),
'grisebusta': ('grisebust',),
'grisebusten': ('grisebust',),
'grisebustene': ('grisebust',),
'grisebuster': ('grisebust',),
'grisefest': ('grisefest',),
'grisefesten': ('grisefest',),
'grisefestene': ('grisefest',),
'grisefester': ('grisefest',),
'griseflaks': ('griseflaks',),
'griseflaksen': ('griseflaks',),
'griseflaksene': ('griseflaks',),
'griseflakser': ('griseflaks',),
'grisehold': ('grisehold',),
'griseholda': ('grisehold',),
'griseholdene': ('grisehold',),
'griseholdet': ('grisehold',),
'grisehus': ('grisehus',),
'grisehusa': ('grisehus',),
'grisehusene': ('grisehus',),
'grisehuset': ('grisehus',),
'griselabb': ('griselabb',),
'griselabben': ('griselabb',),
'griselabbene': ('griselabb',),
'griselabber': ('griselabb',),
'griselitteratur': ('griselitteratur',),
'griselitteraturen': ('griselitteratur',),
'griselitteraturene': ('griselitteratur',),
'griselitteraturer': ('griselitteratur',),
'griseprat': ('griseprat',),
'griseprata': ('griseprat',),
'grisepraten': ('griseprat',),
'grisepratene': ('griseprat',),
'griseprater': ('griseprat',),
'grisepratet': ('griseprat',),
'grisepurka': ('grisepurke',),
'grisepurke': ('grisepurke',),
'grisepurken': ('grisepurke',),
'grisepurkene': ('grisepurke',),
'grisepurker': ('grisepurke',),
'griseri': ('griseri',),
'griseria': ('griseri',),
'griseriene': ('griseri',),
'griserier': ('griseri',),
'griseriet': ('griseri',),
'grisesteik': ('grisesteik',),
'grisesteika': ('grisesteik',),
'grisesteiken': ('grisesteik',),
'grisesteikene': ('grisesteik',),
'grisesteiker': ('grisesteik',),
'grisestek': ('grisestek',),
'grisesteka': ('grisestek',),
'grisesteken': ('grisestek',),
'grisestekene': ('grisestek',),
'grisesteker': ('grisestek',),
'grisesti': ('grisesti',),
'grisestien': ('grisesti',),
'grisestiene': ('grisesti',),
'grisestier': ('grisesti',),
'grisesylta': ('grisesylte',),
'grisesylte': ('grisesylte',),
'grisesylten': ('grisesylte',),
'grisesyltene': ('grisesylte',),
'grisesylter': ('grisesylte',),
'grisetang': ('grisetang',),
'grisetanga': ('grisetang',),
'grisetangen': ('grisetang',),
'grisetangene': ('grisetang',),
'grisetanger': ('grisetang',),
'grisetanget': ('grisetang',),
'grisetrau': ('grisetrau',),
'grisetraua': ('grisetrau',),
'grisetrauene': ('grisetrau',),
'grisetrauet': ('grisetrau',),
'grisetro': ('grisetro',),
'grisetroa': ('grisetro',),
'grisetroen': ('grisetro',),
'grisetroene': ('grisetro',),
'grisetroer': ('grisetro',),
'grisetta': ('grisette',),
'grisette': ('grisette',),
'grisetten': ('grisette',),
'grisettene': ('grisette',),
'grisetter': ('grisette',),
'grisevær': ('grisevær',),
'griseværa': ('grisevær',),
'griseværene': ('grisevær',),
'griseværet': ('grisevær',),
'grisevær': ('grisevær',),
'griseværa': ('grisevær',),
'griseværene': ('grisevær',),
'griseværet': ('grisevær',),
'griskhet': ('griskhet',),
'griskheta': ('griskhet',),
'griskheten': ('griskhet',),
'griskhetene': ('griskhet',),
'griskheter': ('griskhet',),
'grislebrød': ('grislebrød',),
'grislebrøda': ('grislebrød',),
'grislebrødene': ('grislebrød',),
'grislebrødet': ('grislebrød',),
'grisotta': ('grisotte',),
'grisotte': ('grisotte',),
'grisotten': ('grisotte',),
'grisottene': ('grisotte',),
'grisotter': ('grisotte',),
'grisunge': ('grisunge',),
'grisungen': ('grisunge',),
'grisungene': ('grisunge',),
'grisunger': ('grisunge',),
'grizzlybjørn': ('grizzlybjørn',),
'grizzlybjørnen': ('grizzlybjørn',),
'grizzlybjørnene': ('grizzlybjørn',),
'grizzlybjørner': ('grizzlybjørn',),
'grobian': ('grobian',),
'grobianen': ('grobian',),
'grobianene': ('grobian',),
'grobianer': ('grobian',),
'groblad': ('groblad',),
'groblada': ('groblad',),
'grobladene': ('groblad',),
'groblader': ('groblad',),
'grobladet': ('groblad',),
'grobotn': ('grobotn',),
'grobotnen': ('grobotn',),
'grobotnene': ('grobotn',),
'grobotner': ('grobotn',),
'grobunn': ('grobunn',),
'grobunnen': ('grobunn',),
'grobunnene': ('grobunn',),
'grobunner': ('grobunn',),
'grodag': ('grodag',),
'grodagen': ('grodag',),
'grodagene': ('grodag',),
'grodager': ('grodag',),
'groe': ('groe',),
'groen': ('groe',),
'groene': ('groe',),
'groer': ('groe',),
'groevna': ('groevne',),
'groevne': ('groevne',),
'groevnen': ('groevne',),
'groevnene': ('groevne',),
'groevner': ('groevne',),
'grogg': ('grogg',),
'groggen': ('grogg',),
'groggene': ('grogg',),
'grogger': ('grogg',),
'grohold': ('grohold',),
'groholda': ('grohold',),
'groholdene': ('grohold',),
'groholdet': ('grohold',),
'groing': ('groing',),
'groinga': ('groing',),
'groingen': ('groing',),
'groingene': ('groing',),
'groinger': ('groing',),
'grojord': ('grojord',),
'grojorda': ('grojord',),
'grojorden': ('grojord',),
'grojordene': ('grojord',),
'grojorder': ('grojord',),
'grokjøtt': ('grokjøtt',),
'grokjøtta': ('grokjøtt',),
'grokjøttene': ('grokjøtt',),
'grokjøttet': ('grokjøtt',),
'grombarn': ('grombarn',),
'grombarna': ('grombarn',),
'grombarnene': ('grombarn',),
'grombarnet': ('grombarn',),
'gromgutt': ('gromgutt',),
'gromgutten': ('gromgutt',),
'gromguttene': ('gromgutt',),
'gromgutter': ('gromgutt',),
'gromjenta': ('gromjente',),
'gromjente': ('gromjente',),
'gromjenten': ('gromjente',),
'gromjentene': ('gromjente',),
'gromjenter': ('gromjente',),
'groningerfe': ('groningerfe',),
'groningerfea': ('groningerfe',),
'groningerfeene': ('groningerfe',),
'groningerfeet': ('groningerfe',),
'grop': ('grop',),
'gropa': ('grop',),
'gropen': ('grop',),
'gropene': ('grop',),
'groper': ('grop',),
'gropa': ('grope',),
'grope': ('grope',),
'gropen': ('grope',),
'gropene': ('grope',),
'groper': ('grope',),
'gropigg': ('gropigg',),
'gropiggen': ('gropigg',),
'gropiggene': ('gropigg',),
'gropigger': ('gropigg',),
'gror': ('gror',),
'groren': ('gror',),
'grorene': ('gror',),
'grorer': ('gror',),
'grosserer': ('grosserer',),
'grosserere': ('grosserer',),
'grossereren': ('grosserer',),
'grossererer': ('grosserer',),
'grossererne': ('grosserer',),
'grosshavari': ('grosshavari',),
'grosshavaria': ('grosshavari',),
'grosshavariene': ('grosshavari',),
'grosshavarier': ('grosshavari',),
'grosshavariet': ('grosshavari',),
'grossist': ('grossist',),
'grossisten': ('grossist',),
'grossistene': ('grossist',),
'grossister': ('grossist',),
'grossistfirma': ('grossistfirma',),
'grossistfirmaene': ('grossistfirma',),
'grossistfirmaer': ('grossistfirma',),
'grossistfirmaet': ('grossistfirma',),
'grossistkjede': ('grossistkjede',),
'grossistkjeden': ('grossistkjede',),
'grossistkjedene': ('grossistkjede',),
'grossistkjeder': ('grossistkjede',),
'grotesk': ('grotesk',),
'grotesken': ('grotesk',),
'groteskene': ('grotesk',),
'grotesker': ('grotesk',),
'grotid': ('grotid',),
'grotida': ('grotid',),
'grotiden': ('grotid',),
'grotidene': ('grotid',),
'grotider': ('grotid',),
'grotta': ('grotte',),
'grotte': ('grotte',),
'grotten': ('grotte',),
'grottene': ('grotte',),
'grotter': ('grotte',),
'grovarbeid': ('grovarbeid',),
'grovarbeida': ('grovarbeid',),
'grovarbeidene': ('grovarbeid',),
'grovarbeider': ('grovarbeid',),
'grovarbeidet': ('grovarbeid',),
'grovbrød': ('grovbrød',),
'grovbrøda': ('grovbrød',),
'grovbrødene': ('grovbrød',),
'grovbrødet': ('grovbrød',),
'grovhet': ('grovhet',),
'grovheta': ('grovhet',),
'grovheten': ('grovhet',),
'grovhetene': ('grovhet',),
'grovheter': ('grovhet',),
'grovis': ('grovis',),
'grovisen': ('grovis',),
'grovisene': ('grovis',),
'groviser': ('grovis',),
'grovkjøkken': ('grovkjøkken',),
'grovkjøkkena': ('grovkjøkken',),
'grovkjøkkenene': ('grovkjøkken',),
'grovkjøkkener': ('grovkjøkken',),
'grovkjøkkenet': ('grovkjøkken',),
'grovkomikk': ('grovkomikk',),
'grovkomikken': ('grovkomikk',),
'grovkomikkene': ('grovkomikk',),
'grovkomikker': ('grovkomikk',),
'grovleir': ('grovleir',),
'grovleira': ('grovleir',),
'grovleirene': ('grovleir',),
'grovleiret': ('grovleir',),
'grovleira': ('grovleire',),
'grovleire': ('grovleire',),
'grovleiren': ('grovleire',),
'grovleirene': ('grovleire',),
'grovleirer': ('grovleire',),
'grovmel': ('grovmel',),
'grovmela': ('grovmel',),
'grovmelene': ('grovmel',),
'grovmelet': ('grovmel',),
'grovmjøl': ('grovmjøl',),
'grovmjøla': ('grovmjøl',),
'grovmjølene': ('grovmjøl',),
'grovmjølet': ('grovmjøl',),
'grovriss': ('grovriss',),
'grovrissa': ('grovriss',),
'grovrissene': ('grovriss',),
'grovrisset': ('grovriss',),
'grovsalt': ('grovsalt',),
'grovsalta': ('grovsalt',),
'grovsaltene': ('grovsalt',),
'grovsalter': ('grovsalt',),
'grovsaltet': ('grovsalt',),
'grovsand': ('grovsand',),
'grovsanden': ('grovsand',),
'grovsandene': ('grovsand',),
'grovsander': ('grovsand',),
'grovsmed': ('grovsmed',),
'grovsmeden': ('grovsmed',),
'grovsmedene': ('grovsmed',),
'grovsmeder': ('grovsmed',),
'grovsmia': ('grovsmie',),
'grovsmie': ('grovsmie',),
'grovsmien': ('grovsmie',),
'grovsmiene': ('grovsmie',),
'grovsmier': ('grovsmie',),
'grovsåld': ('grovsåld',),
'grovsålda': ('grovsåld',),
'grovsåldene': ('grovsåld',),
'grovsåldet': ('grovsåld',),
'gru': ('gru',),
'grua': ('gru',),
'gruen': ('gru',),
'gruene': ('gru',),
'gruer': ('gru',),
'grubler': ('grubler',),
'grublere': ('grubler',),
'grubleren': ('grubler',),
'grublerer': ('grubler',),
'grublerne': ('grubler',),
'grubleri': ('grubleri',),
'grubleria': ('grubleri',),
'grubleriene': ('grubleri',),
'grublerier': ('grubleri',),
'grubleriet': ('grubleri',),
'grua': ('grue',),
'grue': ('grue',),
'gruen': ('grue',),
'gruene': ('grue',),
'gruer': ('grue',),
'grugg': ('grugg',),
'grugga': ('grugg',),
'gruggene': ('grugg',),
'grugget': ('grugg',),
'grugge': ('grugge',),
'gruggen': ('grugge',),
'gruggene': ('grugge',),
'grugger': ('grugge',),
'grukk': ('grukk',),
'grukka': ('grukk',),
'grukkene': ('grukk',),
'grukket': ('grukk',),
'grums': ('grums',),
'grumsa': ('grums',),
'grumsene': ('grums',),
'grumset': ('grums',),
'grundtvigianer': ('grundtvigianer',),
'grundtvigianere': ('grundtvigianer',),
'grundtvigianeren': ('grundtvigianer',),
'grundtvigianerer': ('grundtvigianer',),
'grundtvigianerne': ('grundtvigianer',),
'grundtvigianisme': ('grundtvigianisme',),
'grundtvigianismen': ('grundtvigianisme',),
'grundtvigianismene': ('grundtvigianisme',),
'grundtvigianismer': ('grundtvigianisme',),
'grunkene': ('grunker',),
'grunker': ('grunker',),
'grunn': ('grunn',),
'grunnen': ('grunn',),
'grunnene': ('grunn',),
'grunner': ('grunn',),
'grunnarbeid': ('grunnarbeid',),
'grunnarbeida': ('grunnarbeid',),
'grunnarbeidene': ('grunnarbeid',),
'grunnarbeider': ('grunnarbeid',),
'grunnarbeidet': ('grunnarbeid',),
'grunnavgift': ('grunnavgift',),
'grunnavgifta': ('grunnavgift',),
'grunnavgiften': ('grunnavgift',),
'grunnavgiftene': ('grunnavgift',),
'grunnavgifter': ('grunnavgift',),
'grunnbegrep': ('grunnbegrep',),
'grunnbegrepa': ('grunnbegrep',),
'grunnbegrepene': ('grunnbegrep',),
'grunnbegreper': ('grunnbegrep',),
'grunnbegrepet': ('grunnbegrep',),
'grunnbeløp': ('grunnbeløp',),
'grunnbeløpa': ('grunnbeløp',),
'grunnbeløpene': ('grunnbeløp',),
'grunnbeløpet': ('grunnbeløp',),
'grunnbetingelse': ('grunnbetingelse',),
'grunnbetingelsen': ('grunnbetingelse',),
'grunnbetingelsene': ('grunnbetingelse',),
'grunnbetingelser': ('grunnbetingelse',),
'grunnbetydning': ('grunnbetydning',),
'grunnbetydninga': ('grunnbetydning',),
'grunnbetydningen': ('grunnbetydning',),
'grunnbetydningene': ('grunnbetydning',),
'grunnbetydninger': ('grunnbetydning',),
'grunnboring': ('grunnboring',),
'grunnboringa': ('grunnboring',),
'grunnboringen': ('grunnboring',),
'grunnboringene': ('grunnboring',),
'grunnboringer': ('grunnboring',),
'grunnbrott': ('grunnbrott',),
'grunnbrotta': ('grunnbrott',),
'grunnbrottene': ('grunnbrott',),
'grunnbrottet': ('grunnbrott',),
'grunndrag': ('grunndrag',),
'grunndraga': ('grunndrag',),
'grunndragene': ('grunndrag',),
'grunndraget': ('grunndrag',),
'grunna': ('grunne',),
'grunne': ('grunne',),
'grunnen': ('grunne',),
'grunnene': ('grunne',),
'grunner': ('grunne',),
'grunnegenskap': ('grunnegenskap',),
'grunnegenskapen': ('grunnegenskap',),
'grunnegenskapene': ('grunnegenskap',),
'grunnegenskaper': ('grunnegenskap',),
'grunneiendom': ('grunneiendom',),
'grunneiendommen': ('grunneiendom',),
'grunneiendommene': ('grunneiendom',),
'grunneiendommer': ('grunneiendom',),
'grunneier': ('grunneier',),
'grunneiere': ('grunneier',),
'grunneieren': ('grunneier',),
'grunneierer': ('grunneier',),
'grunneierne': ('grunneier',),
'grunneierlag': ('grunneierlag',),
'grunneierlaga': ('grunneierlag',),
'grunneierlagene': ('grunneierlag',),
'grunneierlaget': ('grunneierlag',),
'grunnelement': ('grunnelement',),
'grunnelementa': ('grunnelement',),
'grunnelementene': ('grunnelement',),
'grunnelementer': ('grunnelement',),
'grunnelementet': ('grunnelement',),
'grunnemna': ('grunnemne',),
'grunnemne': ('grunnemne',),
'grunnemnene': ('grunnemne',),
'grunnemner': ('grunnemne',),
'grunnemnet': ('grunnemne',),
'grunnenhet': ('grunnenhet',),
'grunnenheten': ('grunnenhet',),
'grunnenhetene': ('grunnenhet',),
'grunnenheter': ('grunnenhet',),
'grunnfag': ('grunnfag',),
'grunnfaga': ('grunnfag',),
'grunnfagene': ('grunnfag',),
'grunnfaget': ('grunnfag',),
'grunnfagseksamen': ('grunnfagseksamen',),
'grunnfagseksamenen': ('grunnfagseksamen',),
'grunnfagseksamenene': ('grunnfagseksamen',),
'grunnfagseksamener': ('grunnfagseksamen',),
'grunnfagsundervisning': ('grunnfagsundervisning',),
'grunnfagsundervisninga': ('grunnfagsundervisning',),
'grunnfagsundervisningen': ('grunnfagsundervisning',),
'grunnfagsundervisningene': ('grunnfagsundervisning',),
'grunnfagsundervisninger': ('grunnfagsundervisning',),
'grunnfarge': ('grunnfarge',),
'grunnfargen': ('grunnfarge',),
'grunnfargene': ('grunnfarge',),
'grunnfarger': ('grunnfarge',),
'grunnfjell': ('grunnfjell',),
'grunnfjella': ('grunnfjell',),
'grunnfjellene': ('grunnfjell',),
'grunnfjellet': ('grunnfjell',),
'grunnflata': ('grunnflate',),
'grunnflate': ('grunnflate',),
'grunnflaten': ('grunnflate',),
'grunnflatene': ('grunnflate',),
'grunnflater': ('grunnflate',),
'grunnfond': ('grunnfond',),
'grunnfonda': ('grunnfond',),
'grunnfondene': ('grunnfond',),
'grunnfondet': ('grunnfond',),
'grunnform': ('grunnform',),
'grunnforma': ('grunnform',),
'grunnformen': ('grunnform',),
'grunnformene': ('grunnform',),
'grunnformer': ('grunnform',),
'grunnforsking': ('grunnforsking',),
'grunnforskinga': ('grunnforsking',),
'grunnforskingen': ('grunnforsking',),
'grunnforskingene': ('grunnforsking',),
'grunnforskinger': ('grunnforsking',),
'grunnforskning': ('grunnforskning',),
'grunnforskninga': ('grunnforskning',),
'grunnforskningen': ('grunnforskning',),
'grunnforskningene': ('grunnforskning',),
'grunnforskninger': ('grunnforskning',),
'grunnfrekvens': ('grunnfrekvens',),
'grunnfrekvensen': ('grunnfrekvens',),
'grunnfrekvensene': ('grunnfrekvens',),
'grunnfrekvenser': ('grunnfrekvens',),
'grunngiing': ('grunngiing',),
'grunngiinga': ('grunngiing',),
'grunngiingen': ('grunngiing',),
'grunngiingene': ('grunngiing',),
'grunngiinger': ('grunngiing',),
'grunngiving': ('grunngiving',),
'grunngivinga': ('grunngiving',),
'grunngivingen': ('grunngiving',),
'grunngivingene': ('grunngiving',),
'grunngivinger': ('grunngiving',),
'grunngivning': ('grunngivning',),
'grunngivninga': ('grunngivning',),
'grunngivningen': ('grunngivning',),
'grunngivningene': ('grunngivning',),
'grunngivninger': ('grunngivning',),
'grunnhav': ('grunnhav',),
'grunnhava': ('grunnhav',),
'grunnhavene': ('grunnhav',),
'grunnhavet': ('grunnhav',),
'grunnholdning': ('grunnholdning',),
'grunnholdninga': ('grunnholdning',),
'grunnholdningen': ('grunnholdning',),
'grunnholdningene': ('grunnholdning',),
'grunnholdninger': ('grunnholdning',),
'grunning': ('grunning',),
'grunninga': ('grunning',),
'grunningen': ('grunning',),
'grunningene': ('grunning',),
'grunninger': ('grunning',),
'grunning': ('grunning',),
'grunninga': ('grunning',),
'grunningen': ('grunning',),
'grunningene': ('grunning',),
'grunninger': ('grunning',),
'grunninnstilling': ('grunninnstilling',),
'grunninnstillinga': ('grunninnstilling',),
'grunninnstillingen': ('grunninnstilling',),
'grunninnstillingene': ('grunninnstilling',),
'grunninnstillinger': ('grunninnstilling',),
'grunnkart': ('grunnkart',),
'grunnkarta': ('grunnkart',),
'grunnkartene': ('grunnkart',),
'grunnkarter': ('grunnkart',),
'grunnkartet': ('grunnkart',),
'grunnkurs': ('grunnkurs',),
'grunnkursa': ('grunnkurs',),
'grunnkursene': ('grunnkurs',),
'grunnkurser': ('grunnkurs',),
'grunnkurset': ('grunnkurs',),
'grunnkursene': ('grunnkursus',),
'grunnkurser': ('grunnkursus',),
'grunnkursus': ('grunnkursus',),
'grunnkursuset': ('grunnkursus',),
'grunnlag': ('grunnlag',),
'grunnlaga': ('grunnlag',),
'grunnlagene': ('grunnlag',),
'grunnlaget': ('grunnlag',),
'grunnlagsinvestering': ('grunnlagsinvestering',),
'grunnlagsinvesteringa': ('grunnlagsinvestering',),
'grunnlagsinvesteringen': ('grunnlagsinvestering',),
'grunnlagsinvesteringene': ('grunnlagsinvestering',),
'grunnlagsinvesteringer': ('grunnlagsinvestering',),
'grunnlagsmateriala': ('grunnlagsmateriale',),
'grunnlagsmateriale': ('grunnlagsmateriale',),
'grunnlagsmaterialene': ('grunnlagsmateriale',),
'grunnlagsmaterialer': ('grunnlagsmateriale',),
'grunnlagsmaterialet': ('grunnlagsmateriale',),
'grunnlegger': ('grunnlegger',),
'grunnleggere': ('grunnlegger',),
'grunnleggeren': ('grunnlegger',),
'grunnleggerer': ('grunnlegger',),
'grunnleggerne': ('grunnlegger',),
'grunnleia': ('grunnleie',),
'grunnleie': ('grunnleie',),
'grunnleien': ('grunnleie',),
'grunnleiene': ('grunnleie',),
'grunnleier': ('grunnleie',),
'grunnlinja': ('grunnlinje',),
'grunnlinje': ('grunnlinje',),
'grunnlinjen': ('grunnlinje',),
'grunnlinjene': ('grunnlinje',),
'grunnlinjer': ('grunnlinje',),
'grunnlov': ('grunnlov',),
'grunnloven': ('grunnlov',),
'grunnlovene': ('grunnlov',),
'grunnlover': ('grunnlov',),
'grunnlovsdag': ('grunnlovsdag',),
'grunnlovsdagen': ('grunnlovsdag',),
'grunnlovsdagene': ('grunnlovsdag',),
'grunnlovsdager': ('grunnlovsdag',),
'grunnlovsendring': ('grunnlovsendring',),
'grunnlovsendringa': ('grunnlovsendring',),
'grunnlovsendringen': ('grunnlovsendring',),
'grunnlovsendringene': ('grunnlovsendring',),
'grunnlovsendringer': ('grunnlovsendring',),
'grunnlovsforsamling': ('grunnlovsforsamling',),
'grunnlovsforsamlinga': ('grunnlovsforsamling',),
'grunnlovsforsamlingen': ('grunnlovsforsamling',),
'grunnlovsforsamlingene': ('grunnlovsforsamling',),
'grunnlovsforsamlinger': ('grunnlovsforsamling',),
'grunnlønn': ('grunnlønn',),
'grunnlønna': ('grunnlønn',),
'grunnlønnen': ('grunnlønn',),
'grunnlønnene': ('grunnlønn',),
'grunnlønner': ('grunnlønn',),
'grunnmaling': ('grunnmaling',),
'grunnmalinga': ('grunnmaling',),
'grunnmalingen': ('grunnmaling',),
'grunnmalingene': ('grunnmaling',),
'grunnmalinger': ('grunnmaling',),
'grunnmotiv': ('grunnmotiv',),
'grunnmotiva': ('grunnmotiv',),
'grunnmotivene': ('grunnmotiv',),
'grunnmotiver': ('grunnmotiv',),
'grunnmotivet': ('grunnmotiv',),
'grunnmur': ('grunnmur',),
'grunnmuren': ('grunnmur',),
'grunnmurene': ('grunnmur',),
'grunnmurer': ('grunnmur',),
'grunnord': ('grunnord',),
'grunnorda': ('grunnord',),
'grunnordene': ('grunnord',),
'grunnordet': ('grunnord',),
'grunnpensjon': ('grunnpensjon',),
'grunnpensjonen': ('grunnpensjon',),
'grunnpensjonene': ('grunnpensjon',),
'grunnpensjoner': ('grunnpensjon',),
'grunnpilar': ('grunnpilar',),
'grunnpilaren': ('grunnpilar',),
'grunnpilarene': ('grunnpilar',),
'grunnpilarer': ('grunnpilar',),
'grunnplan': ('grunnplan',),
'grunnplana': ('grunnplan',),
'grunnplanene': ('grunnplan',),
'grunnplanet': ('grunnplan',),
'grunnpreg': ('grunnpreg',),
'grunnprega': ('grunnpreg',),
'grunnpregene': ('grunnpreg',),
'grunnpreget': ('grunnpreg',),
'grunnprinsipp': ('grunnprinsipp',),
'grunnprinsippa': ('grunnprinsipp',),
'grunnprinsippene': ('grunnprinsipp',),
'grunnprinsipper': ('grunnprinsipp',),
'grunnprinsippet': ('grunnprinsipp',),
'grunnregel': ('grunnregel',),
'grunnregelen': ('grunnregel',),
'grunnreglene': ('grunnregel',),
'grunnregler': ('grunnregel',),
'grunnrenta': ('grunnrente',),
'grunnrente': ('grunnrente',),
'grunnrenten': ('grunnrente',),
'grunnrentene': ('grunnrente',),
'grunnrenter': ('grunnrente',),
'grunnriss': ('grunnriss',),
'grunnrissa': ('grunnriss',),
'grunnrissene': ('grunnriss',),
'grunnrisset': ('grunnriss',),
'grunnsannhet': ('grunnsannhet',),
'grunnsannheta': ('grunnsannhet',),
'grunnsannheten': ('grunnsannhet',),
'grunnsannhetene': ('grunnsannhet',),
'grunnsannheter': ('grunnsannhet',),
'grunnsetning': ('grunnsetning',),
'grunnsetninga': ('grunnsetning',),
'grunnsetningen': ('grunnsetning',),
'grunnsetningene': ('grunnsetning',),
'grunnsetninger': ('grunnsetning',),
'grunnskole': ('grunnskole',),
'grunnskolen': ('grunnskole',),
'grunnskolene': ('grunnskole',),
'grunnskoler': ('grunnskole',),
'grunnskott': ('grunnskott',),
'grunnskotta': ('grunnskott',),
'grunnskottene': ('grunnskott',),
'grunnskottet': ('grunnskott',),
'grunnskudd': ('grunnskudd',),
'grunnskudda': ('grunnskudd',),
'grunnskuddene': ('grunnskudd',),
'grunnskuddet': ('grunnskudd',),
'grunnspell': ('grunnspell',),
'grunnspella': ('grunnspell',),
'grunnspellene': ('grunnspell',),
'grunnspellet': ('grunnspell',),
'grunnspill': ('grunnspill',),
'grunnspilla': ('grunnspill',),
'grunnspillene': ('grunnspill',),
'grunnspillet': ('grunnspill',),
'grunnspråk': ('grunnspråk',),
'grunnspråka': ('grunnspråk',),
'grunnspråkene': ('grunnspråk',),
'grunnspråket': ('grunnspråk',),
'grunnstamme': ('grunnstamme',),
'grunnstammen': ('grunnstamme',),
'grunnstammene': ('grunnstamme',),
'grunnstammer': ('grunnstamme',),
'grunnstein': ('grunnstein',),
'grunnsteinen': ('grunnstein',),
'grunnsteinene': ('grunnstein',),
'grunnsteiner': ('grunnstein',),
'grunnstilling': ('grunnstilling',),
'grunnstillinga': ('grunnstilling',),
'grunnstillingen': ('grunnstilling',),
'grunnstillingene': ('grunnstilling',),
'grunnstillinger': ('grunnstilling',),
'grunnstoff': ('grunnstoff',),
'grunnstoffa': ('grunnstoff',),
'grunnstoffene': ('grunnstoff',),
'grunnstoffer': ('grunnstoff',),
'grunnstoffet': ('grunnstoff',),
'grunnsum': ('grunnsum',),
'grunnsummen': ('grunnsum',),
'grunnsummene': ('grunnsum',),
'grunnsummer': ('grunnsum',),
'grunnsyn': ('grunnsyn',),
'grunnsyna': ('grunnsyn',),
'grunnsynene': ('grunnsyn',),
'grunnsynet': ('grunnsyn',),
'grunntal': ('grunntal',),
'grunntala': ('grunntal',),
'grunntalene': ('grunntal',),
'grunntalet': ('grunntal',),
'grunntall': ('grunntall',),
'grunntalla': ('grunntall',),
'grunntallene': ('grunntall',),
'grunntallet': ('grunntall',),
'grunntanke': ('grunntanke',),
'grunntanken': ('grunntanke',),
'grunntankene': ('grunntanke',),
'grunntanker': ('grunntanke',),
'grunntekst': ('grunntekst',),
'grunnteksta': ('grunntekst',),
'grunnteksten': ('grunntekst',),
'grunntekstene': ('grunntekst',),
'grunntekster': ('grunntekst',),
'grunntone': ('grunntone',),
'grunntonen': ('grunntone',),
'grunntonene': ('grunntone',),
'grunntoner': ('grunntone',),
'grunntrekk': ('grunntrekk',),
'grunntrekka': ('grunntrekk',),
'grunntrekkene': ('grunntrekk',),
'grunntrekket': ('grunntrekk',),
'grunnvann': ('grunnvann',),
'grunnvanna': ('grunnvann',),
'grunnvannene': ('grunnvann',),
'grunnvannet': ('grunnvann',),
'grunnvatn': ('grunnvatn',),
'grunnvatna': ('grunnvatn',),
'grunnvatnene': ('grunnvatn',),
'grunnvatnet': ('grunnvatn',),
'grunnverdi': ('grunnverdi',),
'grunnverdien': ('grunnverdi',),
'grunnverdiene': ('grunnverdi',),
'grunnverdier': ('grunnverdi',),
'grunnvev': ('grunnvev',),
'grunnveva': ('grunnvev',),
'grunnvevene': ('grunnvev',),
'grunnvevet': ('grunnvev',),
'grunnvoll': ('grunnvoll',),
'grunnvollen': ('grunnvoll',),
'grunnvollene': ('grunnvoll',),
'grunnvoller': ('grunnvoll',),
'gruntvannssona': ('gruntvannssone',),
'gruntvannssone': ('gruntvannssone',),
'gruntvannssonen': ('gruntvannssone',),
'gruntvannssonene': ('gruntvannssone',),
'gruntvannssoner': ('gruntvannssone',),
'gruntvass-sona': ('gruntvass-sone',),
'gruntvass-sone': ('gruntvass-sone',),
'gruntvass-sonen': ('gruntvass-sone',),
'gruntvass-sonene': ('gruntvass-sone',),
'gruntvass-soner': ('gruntvass-sone',),
'gruntvassona': ('gruntvassone',),
'gruntvassone': ('gruntvassone',),
'gruntvassonen': ('gruntvassone',),
'gruntvassonene': ('gruntvassone',),
'gruntvassoner': ('gruntvassone',),
'gruppa': ('gruppe',),
'gruppe': ('gruppe',),
'gruppen': ('gruppe',),
'gruppene': ('gruppe',),
'grupper': ('gruppe',),
'gruppearbeid': ('gruppearbeid',),
'gruppearbeida': ('gruppearbeid',),
'gruppearbeidene': ('gruppearbeid',),
'gruppearbeider': ('gruppearbeid',),
'gruppearbeidet': ('gruppearbeid',),
'gruppebilda': ('gruppebilde',),
'gruppebilde': ('gruppebilde',),
'gruppebildene': ('gruppebilde',),
'gruppebilder': ('gruppebilde',),
'gruppebildet': ('gruppebilde',),
'gruppedynamikk': ('gruppedynamikk',),
'gruppedynamikken': ('gruppedynamikk',),
'gruppedynamikkene': ('gruppedynamikk',),
'gruppedynamikker': ('gruppedynamikk',),
'gruppeeksamen': ('gruppeeksamen',),
'gruppeeksamenen': ('gruppeeksamen',),
'gruppeeksamenene': ('gruppeeksamen',),
'gruppeeksamener': ('gruppeeksamen',),
'gruppeformann': ('gruppeformann',),
'gruppeformannen': ('gruppeformann',),
'gruppeformenn': ('gruppeformann',),
'gruppeformennene': ('gruppeformann',),
'gruppefører': ('gruppefører',),
'gruppeførere': ('gruppefører',),
'gruppeføreren': ('gruppefører',),
'gruppeførerer': ('gruppefører',),
'gruppeførerne': ('gruppefører',),
'gruppekorsband': ('gruppekorsband',),
'gruppekorsbanda': ('gruppekorsband',),
'gruppekorsbandene': ('gruppekorsband',),
'gruppekorsbandet': ('gruppekorsband',),
'gruppekorsbånd': ('gruppekorsbånd',),
'gruppekorsbånda': ('gruppekorsbånd',),
'gruppekorsbåndene': ('gruppekorsbånd',),
'gruppekorsbåndet': ('gruppekorsbånd',),
'gruppeleder': ('gruppeleder',),
'gruppeledere': ('gruppeleder',),
'gruppelederen': ('gruppeleder',),
'gruppelederer': ('gruppeleder',),
'gruppelederne': ('gruppeleder',),
'gruppelivsforsikring': ('gruppelivsforsikring',),
'gruppelivsforsikringa': ('gruppelivsforsikring',),
'gruppelivsforsikringen': ('gruppelivsforsikring',),
'gruppelivsforsikringene': ('gruppelivsforsikring',),
'gruppelivsforsikringer': ('gruppelivsforsikring',),
'gruppenorm': ('gruppenorm',),
'gruppenormen': ('gruppenorm',),
'gruppenormene': ('gruppenorm',),
'gruppenormer': ('gruppenorm',),
'gruppepress': ('gruppepress',),
'gruppepressa': ('gruppepress',),
'gruppepressene': ('gruppepress',),
'gruppepresset': ('gruppepress',),
'gruppepsykologi': ('gruppepsykologi',),
'gruppepsykologien': ('gruppepsykologi',),
'gruppepsykologiene': ('gruppepsykologi',),
'gruppepsykologier': ('gruppepsykologi',),
'grupperabatt': ('grupperabatt',),
'grupperabatten': ('grupperabatt',),
'grupperabattene': ('grupperabatt',),
'grupperabatter': ('grupperabatt',),
'gruppereisa': ('gruppereise',),
'gruppereise': ('gruppereise',),
'gruppereisen': ('gruppereise',),
'gruppereisene': ('gruppereise',),
'gruppereiser': ('gruppereise',),
'gruppering': ('gruppering',),
'grupperinga': ('gruppering',),
'grupperingen': ('gruppering',),
'grupperingene': ('gruppering',),
'grupperinger': ('gruppering',),
'gruppesex': ('gruppesex',),
'gruppesexen': ('gruppesex',),
'gruppesexene': ('gruppesex',),
'gruppesexer': ('gruppesex',),
'gruppeteater': ('gruppeteater',),
'gruppeteateret': ('gruppeteater',),
'gruppeteatra': ('gruppeteater',),
'gruppeteatre': ('gruppeteater',),
'gruppeteatrene': ('gruppeteater',),
'gruppeteatret': ('gruppeteater',),
'gruppeterapi': ('gruppeterapi',),
'gruppeterapien': ('gruppeterapi',),
'gruppeterapiene': ('gruppeterapi',),
'gruppeterapier': ('gruppeterapi',),
'gruppetest': ('gruppetest',),
'gruppetesten': ('gruppetest',),
'gruppetestene': ('gruppetest',),
'gruppetester': ('gruppetest',),
'gruppetilhørighet': ('gruppetilhørighet',),
'gruppetilhørigheta': ('gruppetilhørighet',),
'gruppetilhørigheten': ('gruppetilhørighet',),
'gruppetilhørighetene': ('gruppetilhørighet',),
'gruppetilhørigheter': ('gruppetilhørighet',),
'gruppeundervisning': ('gruppeundervisning',),
'gruppeundervisninga': ('gruppeundervisning',),
'gruppeundervisningen': ('gruppeundervisning',),
'gruppeundervisningene': ('gruppeundervisning',),
'gruppeundervisninger': ('gruppeundervisning',),
'gruppevold': ('gruppevold',),
'gruppevolden': ('gruppevold',),
'gruppevoldene': ('gruppevold',),
'gruppevolder': ('gruppevold',),
'grus': ('grus',),
'grusa': ('grus',),
'grusen': ('grus',),
'grusene': ('grus',),
'gruser': ('grus',),
'gruset': ('grus',),
'grusbakke': ('grusbakke',),
'grusbakken': ('grusbakke',),
'grusbakkene': ('grusbakke',),
'grusbakker': ('grusbakke',),
'grusbane': ('grusbane',),
'grusbanen': ('grusbane',),
'grusbanene': ('grusbane',),
'grusbaner': ('grusbane',),
'grusdekka': ('grusdekke',),
'grusdekke': ('grusdekke',),
'grusdekkene': ('grusdekke',),
'grusdekker': ('grusdekke',),
'grusdekket': ('grusdekke',),
'grusgang': ('grusgang',),
'grusgangen': ('grusgang',),
'grusgangene': ('grusgang',),
'grusganger': ('grusgang',),
'grushaug': ('grushaug',),
'grushaugen': ('grushaug',),
'grushaugene': ('grushaug',),
'grushauger': ('grushaug',),
'grusier': ('grusier',),
'grusiere': ('grusier',),
'grusieren': ('grusier',),
'grusierer': ('grusier',),
'grusierne': ('grusier',),
'gruslag': ('gruslag',),
'gruslaga': ('gruslag',),
'gruslagene': ('gruslag',),
'gruslaget': ('gruslag',),
'grusomhet': ('grusomhet',),
'grusomheta': ('grusomhet',),
'grusomheten': ('grusomhet',),
'grusomhetene': ('grusomhet',),
'grusomheter': ('grusomhet',),
'grusrygg': ('grusrygg',),
'grusryggen': ('grusrygg',),
'grusryggene': ('grusrygg',),
'grusrygger': ('grusrygg',),
'grustak': ('grustak',),
'grustaka': ('grustak',),
'grustakene': ('grustak',),
'grustaket': ('grustak',),
'grusveg': ('grusveg',),
'grusvegen': ('grusveg',),
'grusvegene': ('grusveg',),
'grusveger': ('grusveg',),
'grusvei': ('grusvei',),
'grusveien': ('grusvei',),
'grusveiene': ('grusvei',),
'grusveier': ('grusvei',),
'grut': ('grut',),
'gruta': ('grut',),
'gruten': ('grut',),
'grutene': ('grut',),
'gruter': ('grut',),
'grutet': ('grut',),
'gruva': ('gruve',),
'gruve': ('gruve',),
'gruven': ('gruve',),
'gruvene': ('gruve',),
'gruver': ('gruve',),
'gruvearbeid': ('gruvearbeid',),
'gruvearbeida': ('gruvearbeid',),
'gruvearbeidene': ('gruvearbeid',),
'gruvearbeider': ('gruvearbeid',),
'gruvearbeidet': ('gruvearbeid',),
'gruvearbeider': ('gruvearbeider',),
'gruvearbeidere': ('gruvearbeider',),
'gruvearbeideren': ('gruvearbeider',),
'gruvearbeiderer': ('gruvearbeider',),
'gruvearbeiderne': ('gruvearbeider',),
'gruveby': ('gruveby',),
'gruvebyen': ('gruveby',),
'gruvebyene': ('gruveby',),
'gruvebyer': ('gruveby',),
'gruvedistrikt': ('gruvedistrikt',),
'gruvedistrikta': ('gruvedistrikt',),
'gruvedistriktene': ('gruvedistrikt',),
'gruvedistrikter': ('gruvedistrikt',),
'gruvedistriktet': ('gruvedistrikt',),
'gruvedrift': ('gruvedrift',),
'gruvedrifta': ('gruvedrift',),
'gruvedriften': ('gruvedrift',),
'gruvedriftene': ('gruvedrift',),
'gruvedrifter': ('gruvedrift',),
'gruveeksplosjon': ('gruveeksplosjon',),
'gruveeksplosjonen': ('gruveeksplosjon',),
'gruveeksplosjonene': ('gruveeksplosjon',),
'gruveeksplosjoner': ('gruveeksplosjon',),
'gruvefelt': ('gruvefelt',),
'gruvefelta': ('gruvefelt',),
'gruvefeltene': ('gruvefelt',),
'gruvefelter': ('gruvefelt',),
'gruvefeltet': ('gruvefelt',),
'gruvegang': ('gruvegang',),
'gruvegangen': ('gruvegang',),
'gruvegangene': ('gruvegang',),
'gruveganger': ('gruvegang',),
'gruvelampa': ('gruvelampe',),
'gruvelampe': ('gruvelampe',),
'gruvelampen': ('gruvelampe',),
'gruvelampene': ('gruvelampe',),
'gruvelamper': ('gruvelampe',),
'gruvesjakt': ('gruvesjakt',),
'gruvesjakta': ('gruvesjakt',),
'gruvesjakten': ('gruvesjakt',),
'gruvesjaktene': ('gruvesjakt',),
'gruvesjakter': ('gruvesjakt',),
'gruveulykka': ('gruveulykke',),
'gruveulykke': ('gruveulykke',),
'gruveulykken': ('gruveulykke',),
'gruveulykkene': ('gruveulykke',),
'gruveulykker': ('gruveulykke',),
'gry': ('gry',),
'grya': ('gry',),
'gryene': ('gry',),
'gryet': ('gry',),
'gryn': ('gryn',),
'gryna': ('gryn',),
'grynene': ('gryn',),
'grynet': ('gryn',),
'gryngraut': ('gryngraut',),
'gryngrauten': ('gryngraut',),
'gryngrautene': ('gryngraut',),
'gryngrauter': ('gryngraut',),
'gryngrøt': ('gryngrøt',),
'gryngrøten': ('gryngrøt',),
'gryngrøtene': ('gryngrøt',),
'gryngrøter': ('gryngrøt',),
'gryning': ('gryning',),
'gryninga': ('gryning',),
'gryningen': ('gryning',),
'gryningene': ('gryning',),
'gryninger': ('gryning',),
'grynmel': ('grynmel',),
'grynmela': ('grynmel',),
'grynmelene': ('grynmel',),
'grynmelet': ('grynmel',),
'grynmjøl': ('grynmjøl',),
'grynmjøla': ('grynmjøl',),
'grynmjølene': ('grynmjøl',),
'grynmjølet': ('grynmjøl',),
'grynsodd': ('grynsodd',),
'grynsodda': ('grynsodd',),
'grynsoddene': ('grynsodd',),
'grynsoddet': ('grynsodd',),
'grynsuppa': ('grynsuppe',),
'grynsuppe': ('grynsuppe',),
'grynsuppen': ('grynsuppe',),
'grynsuppene': ('grynsuppe',),
'grynsupper': ('grynsuppe',),
'grynt': ('grynt',),
'grynta': ('grynt',),
'gryntene': ('grynt',),
'gryntet': ('grynt',),
'grynteokse': ('grynteokse',),
'grynteoksen': ('grynteokse',),
'grynteoksene': ('grynteokse',),
'grynteokser': ('grynteokse',),
'gryta': ('gryte',),
'gryte': ('gryte',),
'gryten': ('gryte',),
'grytene': ('gryte',),
'gryter': ('gryte',),
'grytebiff': ('grytebiff',),
'grytebiffen': ('grytebiff',),
'grytebiffene': ('grytebiff',),
'grytebiffer': ('grytebiff',),
'gryteklut': ('gryteklut',),
'grytekluten': ('gryteklut',),
'gryteklutene': ('gryteklut',),
'grytekluter': ('gryteklut',),
'grytelokk': ('grytelokk',),
'grytelokka': ('grytelokk',),
'grytelokkene': ('grytelokk',),
'grytelokket': ('grytelokk',),
'gryterett': ('gryterett',),
'gryteretten': ('gryterett',),
'gryterettene': ('gryterett',),
'gryteretter': ('gryterett',),
'gryteskap': ('gryteskap',),
'gryteskapa': ('gryteskap',),
'gryteskapene': ('gryteskap',),
'gryteskapet': ('gryteskap',),
'gryteskrubb': ('gryteskrubb',),
'gryteskrubben': ('gryteskrubb',),
'gryteskrubbene': ('gryteskrubb',),
'gryteskrubber': ('gryteskrubb',),
'gråbein': ('gråbein',),
'gråbeinen': ('gråbein',),
'gråbeinene': ('gråbein',),
'gråbeiner': ('gråbein',),
'gråbeingård': ('gråbeingård',),
'gråbeingården': ('gråbeingård',),
'gråbeingårdene': ('gråbeingård',),
'gråbeingårder': ('gråbeingård',),
'gråbeinsild': ('gråbeinsild',),
'gråbeinsilda': ('gråbeinsild',),
'gråbeinsilden': ('gråbeinsild',),
'gråbeinsildene': ('gråbeinsild',),
'gråbeinsilder': ('gråbeinsild',),
'gråbjørn': ('gråbjørn',),
'gråbjørnen': ('gråbjørn',),
'gråbjørnene': ('gråbjørn',),
'gråbjørner': ('gråbjørn',),
'gråbror': ('gråbror',),
'gråbroren': ('gråbror',),
'gråbrødre': ('gråbror',),
'gråbrødrene': ('gråbror',),
'grågjess': ('grågås',),
'grågjessene': ('grågås',),
'grågjæsene': ('grågås',),
'grågjæser': ('grågås',),
'grågås': ('grågås',),
'grågåsa': ('grågås',),
'grågåsen': ('grågås',),
'grågåstrekk': ('grågåstrekk',),
'grågåstrekka': ('grågåstrekk',),
'grågåstrekkene': ('grågåstrekk',),
'grågåstrekket': ('grågåstrekk',),
'gråhval': ('gråhval',),
'gråhvalen': ('gråhval',),
'gråhvalene': ('gråhval',),
'gråhvaler': ('gråhval',),
'gråkval': ('gråkval',),
'gråkvalen': ('gråkval',),
'gråkvalene': ('gråkval',),
'gråkvaler': ('gråkval',),
'grål': ('grål',),
'grålen': ('grål',),
'grålene': ('grål',),
'gråler': ('grål',),
'grålysing': ('grålysing',),
'grålysinga': ('grålysing',),
'grålysingen': ('grålysing',),
'grålysingene': ('grålysing',),
'grålysinger': ('grålysing',),
'grålysning': ('grålysning',),
'grålysninga': ('grålysning',),
'grålysningen': ('grålysning',),
'grålysningene': ('grålysning',),
'grålysninger': ('grålysning',),
'gråmåka': ('gråmåke',),
'gråmåke': ('gråmåke',),
'gråmåken': ('gråmåke',),
'gråmåkene': ('gråmåke',),
'gråmåker': ('gråmåke',),
'gråmåse': ('gråmåse',),
'gråmåsen': ('gråmåse',),
'gråmåsene': ('gråmåse',),
'gråmåser': ('gråmåse',),
'gråolder': ('gråolder',),
'gråoldere': ('gråolder',),
'gråolderen': ('gråolder',),
'gråolderne': ('gråolder',),
'gråoldra': ('gråolder',),
'gråoldre': ('gråolder',),
'gråoldrene': ('gråolder',),
'gråoldrer': ('gråolder',),
'gråor': ('gråor',),
'gråora': ('gråor',),
'gråoren': ('gråor',),
'gråorene': ('gråor',),
'gråorer': ('gråor',),
'gråpæra': ('gråpære',),
'gråpære': ('gråpære',),
'gråpæren': ('gråpære',),
'gråpærene': ('gråpære',),
'gråpærer': ('gråpære',),
'gråsei': ('gråsei',),
'gråseien': ('gråsei',),
'gråseiene': ('gråsei',),
'gråseier': ('gråsei',),
'gråsel': ('gråsel',),
'gråselen': ('gråsel',),
'gråselene': ('gråsel',),
'gråseler': ('gråsel',),
'gråselja': ('gråselje',),
'gråselje': ('gråselje',),
'gråseljen': ('gråselje',),
'gråseljene': ('gråselje',),
'gråseljer': ('gråselje',),
'gråskala': ('gråskala',),
'gråskalaen': ('gråskala',),
'gråskalaene': ('gråskala',),
'gråskalaer': ('gråskala',),
'gråsnegl': ('gråsnegl',),
'gråsneglen': ('gråsnegl',),
'gråsneglene': ('gråsnegl',),
'gråsnegler': ('gråsnegl',),
'gråsnile': ('gråsnile',),
'gråsnilen': ('gråsnile',),
'gråsnilene': ('gråsnile',),
'gråsniler': ('gråsnile',),
'gråsona': ('gråsone',),
'gråsone': ('gråsone',),
'gråsonen': ('gråsone',),
'gråsonene': ('gråsone',),
'gråsoner': ('gråsone',),
'gråspett': ('gråspett',),
'gråspetten': ('gråspett',),
'gråspettene': ('gråspett',),
'gråspetter': ('gråspett',),
'gråspetta': ('gråspette',),
'gråspette': ('gråspette',),
'gråspetten': ('gråspette',),
'gråspettene': ('gråspette',),
'gråspetter': ('gråspette',),
'gråspurv': ('gråspurv',),
'gråspurven': ('gråspurv',),
'gråspurvene': ('gråspurv',),
'gråspurver': ('gråspurv',),
'gråstein': ('gråstein',),
'gråsteinen': ('gråstein',),
'gråsteinene': ('gråstein',),
'gråsteiner': ('gråstein',),
'gråsteinsmur': ('gråsteinsmur',),
'gråsteinsmuren': ('gråsteinsmur',),
'gråsteinsmurene': ('gråsteinsmur',),
'gråsteinsmurer': ('gråsteinsmur',),
'gråt': ('gråt',),
'gråten': ('gråt',),
'gråtene': ('gråt',),
'gråter': ('gråt',),
'gråtekona': ('gråtekone',),
'gråtekone': ('gråtekone',),
'gråtekonen': ('gråtekone',),
'gråtekonene': ('gråtekone',),
'gråtekoner': ('gråtekone',),
'gråtekor': ('gråtekor',),
'gråtekora': ('gråtekor',),
'gråtekorene': ('gråtekor',),
'gråtekoret': ('gråtekor',),
'gråtekvinna': ('gråtekvinne',),
'gråtekvinne': ('gråtekvinne',),
'gråtekvinnen': ('gråtekvinne',),
'gråtekvinnene': ('gråtekvinne',),
'gråtekvinner': ('gråtekvinne',),
'gråteri': ('gråteri',),
'gråteria': ('gråteri',),
'gråterien': ('gråteri',),
'gråteriene': ('gråteri',),
'gråterier': ('gråteri',),
'gråtetokt': ('gråtetokt',),
'gråtetokta': ('gråtetokt',),
'gråtetokten': ('gråtetokt',),
'gråtetoktene': ('gråtetokt',),
'gråtetokter': ('gråtetokt',),
'gråtrast': ('gråtrast',),
'gråtrasten': ('gråtrast',),
'gråtrastene': ('gråtrast',),
'gråtraster': ('gråtrast',),
'gråtrost': ('gråtrost',),
'gråtrosten': ('gråtrost',),
'gråtrostene': ('gråtrost',),
'gråtroster': ('gråtrost',),
'grått': ('grått',),
'gråurt': ('gråurt',),
'gråurta': ('gråurt',),
'gråurten': ('gråurt',),
'gråurtene': ('gråurt',),
'gråurter': ('gråurt',),
'gråverk': ('gråverk',),
'gråverka': ('gråverk',),
'gråverkene': ('gråverk',),
'gråverker': ('gråverk',),
'gråverket': ('gråverk',),
'gråverkskinn': ('gråverkskinn',),
'gråverkskinna': ('gråverkskinn',),
'gråverkskinnene': ('gråverkskinn',),
'gråverkskinnet': ('gråverkskinn',),
'gråverkskåpa': ('gråverkskåpe',),
'gråverkskåpe': ('gråverkskåpe',),
'gråverkskåpen': ('gråverkskåpe',),
'gråverkskåpene': ('gråverkskåpe',),
'gråverkskåper': ('gråverkskåpe',),
'gråvær': ('gråvær',),
'gråværa': ('gråvær',),
'gråværene': ('gråvær',),
'gråværet': ('gråvær',),
'gråværsdag': ('gråværsdag',),
'gråværsdagen': ('gråværsdag',),
'gråværsdagene': ('gråværsdag',),
'gråværsdager': ('gråværsdag',),
'grøda': ('grøde',),
'grøde': ('grøde',),
'grøden': ('grøde',),
'grødene': ('grøde',),
'grøder': ('grøde',),
'grøft': ('grøft',),
'grøfta': ('grøft',),
'grøften': ('grøft',),
'grøftene': ('grøft',),
'grøfter': ('grøft',),
'grøftegraver': ('grøftegraver',),
'grøftegravere': ('grøftegraver',),
'grøftegraveren': ('grøftegraver',),
'grøftegraverer': ('grøftegraver',),
'grøftegraverne': ('grøftegraver',),
'grøftekant': ('grøftekant',),
'grøftekanten': ('grøftekant',),
'grøftekantene': ('grøftekant',),
'grøftekanter': ('grøftekant',),
'grøftelys': ('grøftelys',),
'grøftelysa': ('grøftelys',),
'grøftelysene': ('grøftelys',),
'grøftelyset': ('grøftelys',),
'grøftemaskin': ('grøftemaskin',),
'grøftemaskina': ('grøftemaskin',),
'grøftemaskinen': ('grøftemaskin',),
'grøftemaskinene': ('grøftemaskin',),
'grøftemaskiner': ('grøftemaskin',),
'grøfterør': ('grøfterør',),
'grøfterøra': ('grøfterør',),
'grøfterørene': ('grøfterør',),
'grøfterøret': ('grøfterør',),
'grøftespade': ('grøftespade',),
'grøftespaden': ('grøftespade',),
'grøftespadene': ('grøftespade',),
'grøftespader': ('grøftespade',),
'grøfting': ('grøfting',),
'grøftinga': ('grøfting',),
'grøftingen': ('grøfting',),
'grøftingene': ('grøfting',),
'grøftinger': ('grøfting',),
'grøftingsanlegg': ('grøftingsanlegg',),
'grøftingsanlegga': ('grøftingsanlegg',),
'grøftingsanleggene': ('grøftingsanlegg',),
'grøftingsanlegget': ('grøftingsanlegg',),
'grønalge': ('grønalge',),
'grønalgen': ('grønalge',),
'grønalgene': ('grønalge',),
'grønalger': ('grønalge',),
'grønalge': ('grønalge',),
'grønalgen': ('grønalge',),
'grønalgene': ('grønalge',),
'grønalger': ('grønalge',),
'grønfink': ('grønfink',),
'grønfinken': ('grønfink',),
'grønfinkene': ('grønfink',),
'grønfinker': ('grønfink',),
'grønfink': ('grønfink',),
'grønfinken': ('grønfink',),
'grønfinkene': ('grønfink',),
'grønfinker': ('grønfink',),
'grønkål': ('grønkål',),
'grønkålen': ('grønkål',),
'grønkålene': ('grønkål',),
'grønkåler': ('grønkål',),
'grønkål': ('grønkål',),
'grønkålen': ('grønkål',),
'grønkålene': ('grønkål',),
'grønkåler': ('grønkål',),
'grønlandshund': ('grønlandshund',),
'grønlandshunden': ('grønlandshund',),
'grønlandshundene': ('grønlandshund',),
'grønlandshunder': ('grønlandshund',),
'grønlandshval': ('grønlandshval',),
'grønlandshvalen': ('grønlandshval',),
'grønlandshvalene': ('grønlandshval',),
'grønlandshvaler': ('grønlandshval',),
'grønlandsk': ('grønlandsk',),
'grønlandsken': ('grønlandsk',),
'grønlandskene': ('grønlandsk',),
'grønlandsker': ('grønlandsk',),
'grønlandskval': ('grønlandskval',),
'grønlandskvalen': ('grønlandskval',),
'grønlandskvalene': ('grønlandskval',),
'grønlandskvaler': ('grønlandskval',),
'grønlandsmåka': ('grønlandsmåke',),
'grønlandsmåke': ('grønlandsmåke',),
'grønlandsmåken': ('grønlandsmåke',),
'grønlandsmåkene': ('grønlandsmåke',),
'grønlandsmåker': ('grønlandsmåke',),
'grønlandsmåse': ('grønlandsmåse',),
'grønlandsmåsen': ('grønlandsmåse',),
'grønlandsmåsene': ('grønlandsmåse',),
'grønlandsmåser': ('grønlandsmåse',),
'grønlandssel': ('grønlandssel',),
'grønlandsselen': ('grønlandssel',),
'grønlandsselene': ('grønlandssel',),
'grønlandsseler': ('grønlandssel',),
'grønlender': ('grønlender',),
'grønlendere': ('grønlender',),
'grønlenderen': ('grønlender',),
'grønlenderer': ('grønlender',),
'grønlenderne': ('grønlender',),
'grønlending': ('grønlending',),
'grønlendingen': ('grønlending',),
'grønlendingene': ('grønlending',),
'grønlendinger': ('grønlending',),
'grønmalm': ('grønmalm',),
'grønmalmen': ('grønmalm',),
'grønmalmene': ('grønmalm',),
'grønmalmer': ('grønmalm',),
'grønmalm': ('grønmalm',),
'grønmalmen': ('grønmalm',),
'grønmalmene': ('grønmalm',),
'grønmalmer': ('grønmalm',),
'grønnalge': ('grønnalge',),
'grønnalgen': ('grønnalge',),
'grønnalgene': ('grønnalge',),
'grønnalger': ('grønnalge',),
'grønnalge': ('grønnalge',),
'grønnalgen': ('grønnalge',),
'grønnalgene': ('grønnalge',),
'grønnalger': ('grønnalge',),
'grønnfink': ('grønnfink',),
'grønnfinken': ('grønnfink',),
'grønnfinkene': ('grønnfink',),
'grønnfinker': ('grønnfink',),
'grønnfink': ('grønnfink',),
'grønnfinken': ('grønnfink',),
'grønnfinkene': ('grønnfink',),
'grønnfinker': ('grønnfink',),
'grønnkål': ('grønnkål',),
'grønnkålen': ('grønnkål',),
'grønnkålene': ('grønnkål',),
'grønnkåler': ('grønnkål',),
'grønnkål': ('grønnkål',),
'grønnkålen': ('grønnkål',),
'grønnkålene': ('grønnkål',),
'grønnkåler': ('grønnkål',),
'grønnmalm': ('grønnmalm',),
'grønnmalmen': ('grønnmalm',),
'grønnmalmene': ('grønnmalm',),
'grønnmalmer': ('grønnmalm',),
'grønnmalm': ('grønnmalm',),
'grønnmalmen': ('grønnmalm',),
'grønnmalmene': ('grønnmalm',),
'grønnmalmer': ('grønnmalm',),
'grønnsak': ('grønnsak',),
'grønnsaka': ('grønnsak',),
'grønnsaken': ('grønnsak',),
'grønnsakene': ('grønnsak',),
'grønnsaker': ('grønnsak',),
'grønnsaksuppa': ('grønnsaksuppe',),
'grønnsaksuppe': ('grønnsaksuppe',),
'grønnsaksuppen': ('grønnsaksuppe',),
'grønnsaksuppene': ('grønnsaksuppe',),
'grønnsaksupper': ('grønnsaksuppe',),
'grønnsaktorg': ('grønnsaktorg',),
'grønnsaktorga': ('grønnsaktorg',),
'grønnsaktorgene': ('grønnsaktorg',),
'grønnsaktorget': ('grønnsaktorg',),
'grønnsisik': ('grønnsisik',),
'grønnsisiken': ('grønnsisik',),
'grønnsisikene': ('grønnsisik',),
'grønnsisiker': ('grønnsisik',),
'grønnskolling': ('grønnskolling',),
'grønnskollingen': ('grønnskolling',),
'grønnskollingene': ('grønnskolling',),
'grønnskollinger': ('grønnskolling',),
'grønnskolling': ('grønnskolling',),
'grønnskollingen': ('grønnskolling',),
'grønnskollingene': ('grønnskolling',),
'grønnskollinger': ('grønnskolling',),
'grønnspett': ('grønnspett',),
'grønnspetten': ('grønnspett',),
'grønnspettene': ('grønnspett',),
'grønnspetter': ('grønnspett',),
'grønnspett': ('grønnspett',),
'grønnspetten': ('grønnspett',),
'grønnspettene': ('grønnspett',),
'grønnspetter': ('grønnspett',),
'grønnspetta': ('grønnspette',),
'grønnspette': ('grønnspette',),
'grønnspetten': ('grønnspette',),
'grønnspettene': ('grønnspette',),
'grønnspetter': ('grønnspette',),
'grønnspetta': ('grønnspette',),
'grønnspette': ('grønnspette',),
'grønnspetten': ('grønnspette',),
'grønnspettene': ('grønnspette',),
'grønnspetter': ('grønnspette',),
'grønnsvær': ('grønnsvær',),
'grønnsværa': ('grønnsvær',),
'grønnsværene': ('grønnsvær',),
'grønnsværet': ('grønnsvær',),
'grønnsåpa': ('grønnsåpe',),
'grønnsåpe': ('grønnsåpe',),
'grønnsåpen': ('grønnsåpe',),
'grønnsåpene': ('grønnsåpe',),
'grønnsåper': ('grønnsåpe',),
'grønnsåpa': ('grønnsåpe',),
'grønnsåpe': ('grønnsåpe',),
'grønnsåpen': ('grønnsåpe',),
'grønnsåpene': ('grønnsåpe',),
'grønnsåper': ('grønnsåpe',),
'grønsak': ('grønsak',),
'grønsaka': ('grønsak',),
'grønsaken': ('grønsak',),
'grønsakene': ('grønsak',),
'grønsaker': ('grønsak',),
'grønsaksuppa': ('grønsaksuppe',),
'grønsaksuppe': ('grønsaksuppe',),
'grønsaksuppen': ('grønsaksuppe',),
'grønsaksuppene': ('grønsaksuppe',),
'grønsaksupper': ('grønsaksuppe',),
'grønsaktorg': ('grønsaktorg',),
'grønsaktorga': ('grønsaktorg',),
'grønsaktorgene': ('grønsaktorg',),
'grønsaktorget': ('grønsaktorg',),
'grønsisik': ('grønsisik',),
'grønsisiken': ('grønsisik',),
'grønsisikene': ('grønsisik',),
'grønsisiker': ('grønsisik',),
'grønska': ('grønske',),
'grønske': ('grønske',),
'grønsken': ('grønske',),
'grønskene': ('grønske',),
'grønsker': ('grønske',),
'grønskolling': ('grønskolling',),
'grønskollingen': ('grønskolling',),
'grønskollingene': ('grønskolling',),
'grønskollinger': ('grønskolling',),
'grønskolling': ('grønskolling',),
'grønskollingen': ('grønskolling',),
'grønskollingene': ('grønskolling',),
'grønskollinger': ('grønskolling',),
'grønspett': ('grønspett',),
'grønspetten': ('grønspett',),
'grønspettene': ('grønspett',),
'grønspetter': ('grønspett',),
'grønspett': ('grønspett',),
'grønspetten': ('grønspett',),
'grønspettene': ('grønspett',),
'grønspetter': ('grønspett',),
'grønspetta': ('grønspette',),
'grønspette': ('grønspette',),
'grønspetten': ('grønspette',),
'grønspettene': ('grønspette',),
'grønspetter': ('grønspette',),
'grønspetta': ('grønspette',),
'grønspette': ('grønspette',),
'grønspetten': ('grønspette',),
'grønspettene': ('grønspette',),
'grønspetter': ('grønspette',),
'grønsvær': ('grønsvær',),
'grønsværa': ('grønsvær',),
'grønsværene': ('grønsvær',),
'grønsværet': ('grønsvær',),
'grønsåpa': ('grønsåpe',),
'grønsåpe': ('grønsåpe',),
'grønsåpen': ('grønsåpe',),
'grønsåpene': ('grønsåpe',),
'grønsåper': ('grønsåpe',),
'grønsåpa': ('grønsåpe',),
'grønsåpe': ('grønsåpe',),
'grønsåpen': ('grønsåpe',),
'grønsåpene': ('grønsåpe',),
'grønsåper': ('grønsåpe',),
'grønt': ('grønt',),
'grøntanlegg': ('grøntanlegg',),
'grøntanlegga': ('grøntanlegg',),
'grøntanleggene': ('grøntanlegg',),
'grøntanlegget': ('grøntanlegg',),
'grøntareal': ('grøntareal',),
'grøntareala': ('grøntareal',),
'grøntarealene': ('grøntareal',),
'grøntarealer': ('grøntareal',),
'grøntarealet': ('grøntareal',),
'grøntområda': ('grøntområde',),
'grøntområde': ('grøntområde',),
'grøntområdene': ('grøntområde',),
'grøntområder': ('grøntområde',),
'grøntområdet': ('grøntområde',),
'grøpp': ('grøpp',),
'grøppa': ('grøpp',),
'grøppene': ('grøpp',),
'grøppet': ('grøpp',),
'grøss': ('grøss',),
'grøssa': ('grøss',),
'grøssene': ('grøss',),
'grøsset': ('grøss',),
'grøsser': ('grøsser',),
'grøssere': ('grøsser',),
'grøsseren': ('grøsser',),
'grøsserer': ('grøsser',),
'grøsserne': ('grøsser',),
'grøt': ('grøt',),
'grøten': ('grøt',),
'grøtene': ('grøt',),
'grøter': ('grøt',),
'grøtdag': ('grøtdag',),
'grøtdagen': ('grøtdag',),
'grøtdagene': ('grøtdag',),
'grøtdager': ('grøtdag',),
'grøtfat': ('grøtfat',),
'grøtfata': ('grøtfat',),
'grøtfatene': ('grøtfat',),
'grøtfater': ('grøtfat',),
'grøtfatet': ('grøtfat',),
'grøthoda': ('grøthode',),
'grøthode': ('grøthode',),
'grøthodene': ('grøthode',),
'grøthoder': ('grøthode',),
'grøthodet': ('grøthode',),
'grøthoda': ('grøthode',),
'grøthode': ('grøthode',),
'grøthodene': ('grøthode',),
'grøthoder': ('grøthode',),
'grøthodet': ('grøthode',),
'grøtklepp': ('grøtklepp',),
'grøtkleppen': ('grøtklepp',),
'grøtkleppene': ('grøtklepp',),
'grøtklepper': ('grøtklepp',),
'grøtomslag': ('grøtomslag',),
'grøtomslaga': ('grøtomslag',),
'grøtomslagene': ('grøtomslag',),
'grøtomslaget': ('grøtomslag',),
'grøtpinne': ('grøtpinne',),
'grøtpinnen': ('grøtpinne',),
'grøtpinnene': ('grøtpinne',),
'grøtpinner': ('grøtpinne',),
'grøtsleiv': ('grøtsleiv',),
'grøtsleiva': ('grøtsleiv',),
'grøtsleiven': ('grøtsleiv',),
'grøtsleivene': ('grøtsleiv',),
'grøtsleiver': ('grøtsleiv',),
'guano': ('guano',),
'guanoen': ('guano',),
'guanoene': ('guano',),
'guanoer': ('guano',),
'guatemalaner': ('guatemalaner',),
'guatemalanere': ('guatemalaner',),
'guatemalaneren': ('guatemalaner',),
'guatemalanerer': ('guatemalaner',),
'guatemalanerne': ('guatemalaner',),
'gubbe': ('gubbe',),
'gubben': ('gubbe',),
'gubbene': ('gubbe',),
'gubber': ('gubbe',),
'gubbevelda': ('gubbevelde',),
'gubbevelde': ('gubbevelde',),
'gubbeveldene': ('gubbevelde',),
'gubbevelder': ('gubbevelde',),
'gubbeveldet': ('gubbevelde',),
'gud': ('gud',),
'guden': ('gud',),
'gudene': ('gud',),
'guder': ('gud',),
'gudbarn': ('gudbarn',),
'gudbarna': ('gudbarn',),
'gudbarnene': ('gudbarn',),
'gudbarnet': ('gudbarn',),
'gudbrandsdalsost': ('gudbrandsdalsost',),
'gudbrandsdalsosten': ('gudbrandsdalsost',),
'gudbrandsdalsostene': ('gudbrandsdalsost',),
'gudbrandsdalsoster': ('gudbrandsdalsost',),
'gudbrandsdøl': ('gudbrandsdøl',),
'gudbrandsdølen': ('gudbrandsdøl',),
'gudbrandsdølene': ('gudbrandsdøl',),
'gudbrandsdøler': ('gudbrandsdøl',),
'guddatter': ('guddatter',),
'guddattera': ('guddatter',),
'guddatteren': ('guddatter',),
'guddøtre': ('guddatter',),
'guddøtrene': ('guddatter',),
'guddøtrer': ('guddatter',),
'guddom': ('guddom',),
'guddommen': ('guddom',),
'guddommene': ('guddom',),
'guddommer': ('guddom',),
'guddomskraft': ('guddomskraft',),
'guddomskrafta': ('guddomskraft',),
'guddomskraften': ('guddomskraft',),
'guddomskreftene': ('guddomskraft',),
'guddomskrefter': ('guddomskraft',),
'guddomsmakt': ('guddomsmakt',),
'guddomsmakta': ('guddomsmakt',),
'guddomsmakten': ('guddomsmakt',),
'guddomsmaktene': ('guddomsmakt',),
'guddomsmakter': ('guddomsmakt',),
'gudebilda': ('gudebilde',),
'gudebilde': ('gudebilde',),
'gudebildene': ('gudebilde',),
'gudebilder': ('gudebilde',),
'gudebildet': ('gudebilde',),
'gudebolig': ('gudebolig',),
'gudeboligen': ('gudebolig',),
'gudeboligene': ('gudebolig',),
'gudeboliger': ('gudebolig',),
'gudedrikk': ('gudedrikk',),
'gudedrikken': ('gudedrikk',),
'gudedrikkene': ('gudedrikk',),
'gudedrikker': ('gudedrikk',),
'gudedyrkelse': ('gudedyrkelse',),
'gudedyrkelsen': ('gudedyrkelse',),
'gudedyrkelsene': ('gudedyrkelse',),
'gudedyrkelser': ('gudedyrkelse',),
'gudedyrking': ('gudedyrking',),
'gudedyrkinga': ('gudedyrking',),
'gudedyrkingen': ('gudedyrking',),
'gudedyrkingene': ('gudedyrking',),
'gudedyrkinger': ('gudedyrking',),
'gudegava': ('gudegave',),
'gudegave': ('gudegave',),
'gudegaven': ('gudegave',),
'gudegavene': ('gudegave',),
'gudegaver': ('gudegave',),
'gudelæra': ('gudelære',),
'gudelære': ('gudelære',),
'gudelæren': ('gudelære',),
'gudelærene': ('gudelære',),
'gudelærer': ('gudelære',),
'gudesagn': ('gudesagn',),
'gudesagna': ('gudesagn',),
'gudesagnene': ('gudesagn',),
'gudesagnet': ('gudesagn',),
'gudesønn': ('gudesønn',),
'gudesønnen': ('gudesønn',),
'gudesønnene': ('gudesønn',),
'gudesønner': ('gudesønn',),
'gudeverden': ('gudeverden',),
'gudeverdenen': ('gudeverden',),
'gudeverdenene': ('gudeverden',),
'gudeverdener': ('gudeverden',),
'gudeætt': ('gudeætt',),
'gudeætta': ('gudeætt',),
'gudeætten': ('gudeætt',),
'gudeættene': ('gudeætt',),
'gudeætter': ('gudeætt',),
'gudfar': ('gudfar',),
'gudfaren': ('gudfar',),
'gudfedre': ('gudfar',),
'gudfedrene': ('gudfar',),
'gudinna': ('gudinne',),
'gudinne': ('gudinne',),
'gudinnen': ('gudinne',),
'gudinnene': ('gudinne',),
'gudinner': ('gudinne',),
'gudsbegrep': ('gudsbegrep',),
'gudsbegrepa': ('gudsbegrep',),
'gudsbegrepene': ('gudsbegrep',),
'gudsbegreper': ('gudsbegrep',),
'gudsbegrepet': ('gudsbegrep',),
'gudsbespottelse': ('gudsbespottelse',),
'gudsbespottelsen': ('gudsbespottelse',),
'gudsbespottelsene': ('gudsbespottelse',),
'gudsbespottelser': ('gudsbespottelse',),
'gudsbevis': ('gudsbevis',),
'gudsbevisa': ('gudsbevis',),
'gudsbevisene': ('gudsbevis',),
'gudsbeviser': ('gudsbevis',),
'gudsbeviset': ('gudsbevis',),
'gudsdom': ('gudsdom',),
'gudsdommen': ('gudsdom',),
'gudsdommene': ('gudsdom',),
'gudsdommer': ('gudsdom',),
'gudsdyrkelse': ('gudsdyrkelse',),
'gudsdyrkelsen': ('gudsdyrkelse',),
'gudsdyrkelsene': ('gudsdyrkelse',),
'gudsdyrkelser': ('gudsdyrkelse',),
'gudsdyrking': ('gudsdyrking',),
'gudsdyrkinga': ('gudsdyrking',),
'gudsdyrkingen': ('gudsdyrking',),
'gudsdyrkingene': ('gudsdyrking',),
'gudsdyrkinger': ('gudsdyrking',),
'gudsengel': ('gudsengel',),
'gudsengelen': ('gudsengel',),
'gudsenglene': ('gudsengel',),
'gudsengler': ('gudsengel',),
'gudsforestilling': ('gudsforestilling',),
'gudsforestillinga': ('gudsforestilling',),
'gudsforestillingen': ('gudsforestilling',),
'gudsforestillingene': ('gudsforestilling',),
'gudsforestillinger': ('gudsforestilling',),
'gudsfornekter': ('gudsfornekter',),
'gudsfornektere': ('gudsfornekter',),
'gudsfornekteren': ('gudsfornekter',),
'gudsfornekterer': ('gudsfornekter',),
'gudsfornekterne': ('gudsfornekter',),
'gudsfred': ('gudsfred',),
'gudsfreden': ('gudsfred',),
'gudsfredene': ('gudsfred',),
'gudsfreder': ('gudsfred',),
'gudsfrykt': ('gudsfrykt',),
'gudsfrykten': ('gudsfrykt',),
'gudsfryktene': ('gudsfrykt',),
'gudsfrykter': ('gudsfrykt',),
'gudshus': ('gudshus',),
'gudshusa': ('gudshus',),
'gudshusene': ('gudshus',),
'gudshuset': ('gudshus',),
'gudskjelovkveld': ('gudskjelovkveld',),
'gudskjelovkvelden': ('gudskjelovkveld',),
'gudskjelovkveldene': ('gudskjelovkveld',),
'gudskjelovkvelder': ('gudskjelovkveld',),
'gudsliv': ('gudsliv',),
'gudsliva': ('gudsliv',),
'gudslivene': ('gudsliv',),
'gudslivet': ('gudsliv',),
'gudslån': ('gudslån',),
'gudslåna': ('gudslån',),
'gudslånene': ('gudslån',),
'gudslånet': ('gudslån',),
'gudsord': ('gudsord',),
'gudsorda': ('gudsord',),
'gudsordene': ('gudsord',),
'gudsordet': ('gudsord',),
'gudsrika': ('gudsrike',),
'gudsrike': ('gudsrike',),
'gudsrikene': ('gudsrike',),
'gudsriker': ('gudsrike',),
'gudsriket': ('gudsrike',),
'gudstjeneste': ('gudstjeneste',),
'gudstjenesten': ('gudstjeneste',),
'gudstjenestene': ('gudstjeneste',),
'gudstjenester': ('gudstjeneste',),
'gudstjenesteordning': ('gudstjenesteordning',),
'gudstjenesteordninga': ('gudstjenesteordning',),
'gudstjenesteordningen': ('gudstjenesteordning',),
'gudstjenesteordningene': ('gudstjenesteordning',),
'gudstjenesteordninger': ('gudstjenesteordning',),
'gudstro': ('gudstro',),
'gudstroa': ('gudstro',),
'gudstroen': ('gudstro',),
'gudstroene': ('gudstro',),
'gudstroer': ('gudstro',),
'gudsønn': ('gudsønn',),
'gudsønnen': ('gudsønn',),
'gudsønnene': ('gudsønn',),
'gudsønner': ('gudsønn',),
'guernseyfe': ('guernseyfe',),
'guernseyfea': ('guernseyfe',),
'guernseyfeene': ('guernseyfe',),
'guernseyfeet': ('guernseyfe',),
'guffa': ('guffe',),
'guffe': ('guffe',),
'guffen': ('guffe',),
'guffene': ('guffe',),
'guffer': ('guffe',),
'gufs': ('gufs',),
'gufsa': ('gufs',),
'gufsen': ('gufs',),
'gufsene': ('gufs',),
'gufser': ('gufs',),
'gufset': ('gufs',),
'guide': ('guide',),
'guiden': ('guide',),
'guidene': ('guide',),
'guider': ('guide',),
'guinea': ('guinea',),
'guineaen': ('guinea',),
'guineaene': ('guinea',),
'guineas': ('guinea',),
'guineaner': ('guineaner',),
'guineanere': ('guineaner',),
'guineaneren': ('guineaner',),
'guineanerer': ('guineaner',),
'guineanerne': ('guineaner',),
'gul': ('gul',),
'gula': ('gul',),
'gulen': ('gul',),
'gulene': ('gul',),
'guler': ('gul',),
'gul': ('gul',),
'gula': ('gul',),
'gulen': ('gul',),
'gulene': ('gul',),
'guler': ('gul',),
'gulasj': ('gulasj',),
'gulasjen': ('gulasj',),
'gulasjene': ('gulasj',),
'gulasjer': ('gulasj',),
'gulasjbaron': ('gulasjbaron',),
'gulasjbaronen': ('gulasjbaron',),
'gulasjbaronene': ('gulasjbaron',),
'gulasjbaroner': ('gulasjbaron',),
'gulasjgrosserer': ('gulasjgrosserer',),
'gulasjgrosserere': ('gulasjgrosserer',),
'gulasjgrossereren': ('gulasjgrosserer',),
'gulasjgrossererer': ('gulasjgrosserer',),
'gulasjgrossererne': ('gulasjgrosserer',),
'gula': ('gule',),
'gule': ('gule',),
'gulen': ('gule',),
'gulene': ('gule',),
'guler': ('gule',),
'gula': ('gule',),
'gule': ('gule',),
'gulen': ('gule',),
'gulene': ('gule',),
'guler': ('gule',),
'gula': ('gule',),
'gule': ('gule',),
'gulen': ('gule',),
'gulene': ('gule',),
'guler': ('gule',),
'gulerla': ('gulerle',),
'gulerle': ('gulerle',),
'gulerlen': ('gulerle',),
'gulerlene': ('gulerle',),
'gulerler': ('gulerle',),
'gulfeber': ('gulfeber',),
'gulfebere': ('gulfeber',),
'gulfeberen': ('gulfeber',),
'gulfeberne': ('gulfeber',),
'gulfebre': ('gulfeber',),
'gulfebrene': ('gulfeber',),
'gulfebrer': ('gulfeber',),
'gull': ('gull',),
'gulla': ('gull',),
'gullene': ('gull',),
'gullet': ('gull',),
'gull-land': ('gull-land',),
'gull-landa': ('gull-land',),
'gull-landene': ('gull-land',),
'gull-landet': ('gull-land',),
'gullalder': ('gullalder',),
'gullaldere': ('gullalder',),
'gullalderen': ('gullalder',),
'gullalderer': ('gullalder',),
'gullalderne': ('gullalder',),
'gullaldre': ('gullalder',),
'gullaldrene': ('gullalder',),
'gullaldrer': ('gullalder',),
'gulland': ('gulland',),
'gullanda': ('gulland',),
'gullandene': ('gulland',),
'gullandet': ('gulland',),
'gullarbeid': ('gullarbeid',),
'gullarbeida': ('gullarbeid',),
'gullarbeidene': ('gullarbeid',),
'gullarbeider': ('gullarbeid',),
'gullarbeidet': ('gullarbeid',),
'gullarmband': ('gullarmband',),
'gullarmbanda': ('gullarmband',),
'gullarmbandene': ('gullarmband',),
'gullarmbandet': ('gullarmband',),
'gullarmbånd': ('gullarmbånd',),
'gullarmbånda': ('gullarmbånd',),
'gullarmbåndene': ('gullarmbånd',),
'gullarmbåndet': ('gullarmbånd',),
'gullbarn': ('gullbarn',),
'gullbarna': ('gullbarn',),
'gullbarnene': ('gullbarn',),
'gullbarnet': ('gullbarn',),
'gullbarre': ('gullbarre',),
'gullbarren': ('gullbarre',),
'gullbarrene': ('gullbarre',),
'gullbarrer': ('gullbarre',),
'gullbeholdning': ('gullbeholdning',),
'gullbeholdninga': ('gullbeholdning',),
'gullbeholdningen': ('gullbeholdning',),
'gullbeholdningene': ('gullbeholdning',),
'gullbeholdninger': ('gullbeholdning',),
'gullbrand': ('gullbrand',),
'gullbranden': ('gullbrand',),
'gullbrandene': ('gullbrand',),
'gullbrander': ('gullbrand',),
'gullbrud': ('gullbrud',),
'gullbruda': ('gullbrud',),
'gullbruden': ('gullbrud',),
'gullbrudene': ('gullbrud',),
'gullbruder': ('gullbrud',),
'gullbrudepar': ('gullbrudepar',),
'gullbrudepara': ('gullbrudepar',),
'gullbrudeparene': ('gullbrudepar',),
'gullbrudeparet': ('gullbrudepar',),
'gullbrudgom': ('gullbrudgom',),
'gullbrudgommen': ('gullbrudgom',),
'gullbrudgommene': ('gullbrudgom',),
'gullbrudgommer': ('gullbrudgom',),
'gullbrur': ('gullbrur',),
'gullbrura': ('gullbrur',),
'gullbrurene': ('gullbrur',),
'gullbrurer': ('gullbrur',),
'gullbryllup': ('gullbryllup',),
'gullbryllupa': ('gullbryllup',),
'gullbryllupene': ('gullbryllup',),
'gullbrylluper': ('gullbryllup',),
'gullbryllupet': ('gullbryllup',),
'gullbust': ('gullbust',),
'gullbusten': ('gullbust',),
'gullbustene': ('gullbust',),
'gullbuster': ('gullbust',),
'gullegg': ('gullegg',),
'gullegga': ('gullegg',),
'gulleggene': ('gullegg',),
'gullegget': ('gullegg',),
'gullfeber': ('gullfeber',),
'gullfebere': ('gullfeber',),
'gullfeberen': ('gullfeber',),
'gullfeberer': ('gullfeber',),
'gullfeberne': ('gullfeber',),
'gullfebre': ('gullfeber',),
'gullfebrene': ('gullfeber',),
'gullfebrer': ('gullfeber',),
'gullfisk': ('gullfisk',),
'gullfisken': ('gullfisk',),
'gullfiskene': ('gullfisk',),
'gullfisker': ('gullfisk',),
'gullflyndra': ('gullflyndre',),
'gullflyndre': ('gullflyndre',),
'gullflyndren': ('gullflyndre',),
'gullflyndrene': ('gullflyndre',),
'gullflyndrer': ('gullflyndre',),
'gullfugl': ('gullfugl',),
'gullfuglen': ('gullfugl',),
'gullfuglene': ('gullfugl',),
'gullfugler': ('gullfugl',),
'gullfunn': ('gullfunn',),
'gullfunna': ('gullfunn',),
'gullfunnene': ('gullfunn',),
'gullfunnet': ('gullfunn',),
'gullgraver': ('gullgraver',),
'gullgravere': ('gullgraver',),
'gullgraveren': ('gullgraver',),
'gullgraverer': ('gullgraver',),
'gullgraverne': ('gullgraver',),
'gullgruva': ('gullgruve',),
'gullgruve': ('gullgruve',),
'gullgruven': ('gullgruve',),
'gullgruvene': ('gullgruve',),
'gullgruver': ('gullgruve',),
'gullhamster': ('gullhamster',),
'gullhamstere': ('gullhamster',),
'gullhamsteren': ('gullhamster',),
'gullhamsterer': ('gullhamster',),
'gullhamsterne': ('gullhamster',),
'gullhamstre': ('gullhamster',),
'gullhamstrene': ('gullhamster',),
'gullhamstrer': ('gullhamster',),
'gullkalv': ('gullkalv',),
'gullkalven': ('gullkalv',),
'gullkalvene': ('gullkalv',),
'gullkalver': ('gullkalv',),
'gullkant': ('gullkant',),
'gullkanten': ('gullkant',),
'gullkantene': ('gullkant',),
'gullkanter': ('gullkant',),
'gullkjeda': ('gullkjede',),
'gullkjede': ('gullkjede',),
'gullkjeden': ('gullkjede',),
'gullkjedene': ('gullkjede',),
'gullkjeder': ('gullkjede',),
'gullkjedet': ('gullkjede',),
'gullklausul': ('gullklausul',),
'gullklausulen': ('gullklausul',),
'gullklausulene': ('gullklausul',),
'gullklausuler': ('gullklausul',),
'gullklokka': ('gullklokke',),
'gullklokke': ('gullklokke',),
'gullklokken': ('gullklokke',),
'gullklokkene': ('gullklokke',),
'gullklokker': ('gullklokke',),
'gullklump': ('gullklump',),
'gullklumpen': ('gullklump',),
'gullklumpene': ('gullklump',),
'gullklumper': ('gullklump',),
'gullkorn': ('gullkorn',),
'gullkorna': ('gullkorn',),
'gullkornene': ('gullkorn',),
'gullkornet': ('gullkorn',),
'gullkrage': ('gullkrage',),
'gullkragen': ('gullkrage',),
'gullkragene': ('gullkrage',),
'gullkrager': ('gullkrage',),
'gullmaker': ('gullmaker',),
'gullmakere': ('gullmaker',),
'gullmakeren': ('gullmaker',),
'gullmakerer': ('gullmaker',),
'gullmakerne': ('gullmaker',),
'gullmakeri': ('gullmakeri',),
'gullmakeria': ('gullmakeri',),
'gullmakeriene': ('gullmakeri',),
'gullmakeriet': ('gullmakeri',),
'gullmakrell': ('gullmakrell',),
'gullmakrellen': ('gullmakrell',),
'gullmakrellene': ('gullmakrell',),
'gullmakreller': ('gullmakrell',),
'gullmedalje': ('gullmedalje',),
'gullmedaljen': ('gullmedalje',),
'gullmedaljene': ('gullmedalje',),
'gullmedaljer': ('gullmedalje',),
'gullmedaljevinner': ('gullmedaljevinner',),
'gullmedaljevinnere': ('gullmedaljevinner',),
'gullmedaljevinneren': ('gullmedaljevinner',),
'gullmedaljevinnerer': ('gullmedaljevinner',),
'gullmedaljevinnerne': ('gullmedaljevinner',),
'gullmynt': ('gullmynt',),
'gullmynten': ('gullmynt',),
'gullmyntene': ('gullmynt',),
'gullmynter': ('gullmynt',),
'gullnål': ('gullnål',),
'gullnåla': ('gullnål',),
'gullnålen': ('gullnål',),
'gullnålene': ('gullnål',),
'gullnåler': ('gullnål',),
'gullplata': ('gullplate',),
'gullplate': ('gullplate',),
'gullplaten': ('gullplate',),
'gullplatene': ('gullplate',),
'gullplater': ('gullplate',),
'gullregn': ('gullregn',),
'gullregnen': ('gullregn',),
'gullregnene': ('gullregn',),
'gullregner': ('gullregn',),
'gullregnforgiftning': ('gullregnforgiftning',),
'gullregnforgiftninga': ('gullregnforgiftning',),
'gullregnforgiftningen': ('gullregnforgiftning',),
'gullregnforgiftningene': ('gullregnforgiftning',),
'gullregnforgiftninger': ('gullregnforgiftning',),
'gullring': ('gullring',),
'gullringen': ('gullring',),
'gullringene': ('gullring',),
'gullringer': ('gullring',),
'gullrips': ('gullrips',),
'gullripsen': ('gullrips',),
'gullripsene': ('gullrips',),
'gullripser': ('gullrips',),
'gullskrift': ('gullskrift',),
'gullskrifta': ('gullskrift',),
'gullskriften': ('gullskrift',),
'gullskriftene': ('gullskrift',),
'gullskrifter': ('gullskrift',),
'gullsmed': ('gullsmed',),
'gullsmeden': ('gullsmed',),
'gullsmedene': ('gullsmed',),
'gullsmeder': ('gullsmed',),
'gullsmedforretning': ('gullsmedforretning',),
'gullsmedforretninga': ('gullsmedforretning',),
'gullsmedforretningen': ('gullsmedforretning',),
'gullsmedforretningene': ('gullsmedforretning',),
'gullsmedforretninger': ('gullsmedforretning',),
'gullsmedkunst': ('gullsmedkunst',),
'gullsmedkunsten': ('gullsmedkunst',),
'gullsmedkunstene': ('gullsmedkunst',),
'gullsmedkunster': ('gullsmedkunst',),
'gullsnitt': ('gullsnitt',),
'gullsnitta': ('gullsnitt',),
'gullsnittene': ('gullsnitt',),
'gullsnittet': ('gullsnitt',),
'gullsnor': ('gullsnor',),
'gullsnora': ('gullsnor',),
'gullsnoren': ('gullsnor',),
'gullsnorene': ('gullsnor',),
'gullsnorer': ('gullsnor',),
'gullstandard': ('gullstandard',),
'gullstandarden': ('gullstandard',),
'gullstandardene': ('gullstandard',),
'gullstandarder': ('gullstandard',),
'gullstjerna': ('gullstjerne',),
'gullstjerne': ('gullstjerne',),
'gullstjernen': ('gullstjerne',),
'gullstjernene': ('gullstjerne',),
'gullstjerner': ('gullstjerne',),
'gullstol': ('gullstol',),
'gullstolen': ('gullstol',),
'gullstolene': ('gullstol',),
'gullstoler': ('gullstol',),
'gullstøv': ('gullstøv',),
'gullstøva': ('gullstøv',),
'gullstøvene': ('gullstøv',),
'gullstøvet': ('gullstøv',),
'gulltann': ('gulltann',),
'gulltanna': ('gulltann',),
'gulltannen': ('gulltann',),
'gulltennene': ('gulltann',),
'gulltenner': ('gulltann',),
'gullunge': ('gullunge',),
'gullungen': ('gullunge',),
'gullungene': ('gullunge',),
'gullunger': ('gullunge',),
'gullur': ('gullur',),
'gullura': ('gullur',),
'gullurene': ('gullur',),
'gulluret': ('gullur',),
'gullvasking': ('gullvasking',),
'gullvaskinga': ('gullvasking',),
'gullvaskingen': ('gullvasking',),
'gullvaskingene': ('gullvasking',),
'gullvaskinger': ('gullvasking',),
'gullvekt': ('gullvekt',),
'gullvekta': ('gullvekt',),
'gullvekten': ('gullvekt',),
'gullvektene': ('gullvekt',),
'gullvekter': ('gullvekt',),
'gullverdi': ('gullverdi',),
'gullverdien': ('gullverdi',),
'gullverdiene': ('gullverdi',),
'gullverdier': ('gullverdi',),
'gulost': ('gulost',),
'gulosten': ('gulost',),
'gulostene': ('gulost',),
'guloster': ('gulost',),
'gulp': ('gulp',),
'gulpa': ('gulp',),
'gulpen': ('gulp',),
'gulpene': ('gulp',),
'gulper': ('gulp',),
'gulpet': ('gulp',),
'gulrot': ('gulrot',),
'gulrota': ('gulrot',),
'gulroten': ('gulrot',),
'gulrøttene': ('gulrot',),
'gulrøtter': ('gulrot',),
'gulrotstuing': ('gulrotstuing',),
'gulrotstuinga': ('gulrotstuing',),
'gulrotstuingen': ('gulrotstuing',),
'gulrotstuingene': ('gulrotstuing',),
'gulrotstuinger': ('gulrotstuing',),
'gulsott': ('gulsott',),
'gulsotta': ('gulsott',),
'gulsotten': ('gulsott',),
'gulsottene': ('gulsott',),
'gulsotter': ('gulsott',),
'gulspurv': ('gulspurv',),
'gulspurven': ('gulspurv',),
'gulspurvene': ('gulspurv',),
'gulspurver': ('gulspurv',),
'gult': ('gult',),
'gulv': ('gulv',),
'gulva': ('gulv',),
'gulvene': ('gulv',),
'gulvet': ('gulv',),
'gulvfilla': ('gulvfille',),
'gulvfille': ('gulvfille',),
'gulvfillen': ('gulvfille',),
'gulvfillene': ('gulvfille',),
'gulvfiller': ('gulvfille',),
'gulvflata': ('gulvflate',),
'gulvflate': ('gulvflate',),
'gulvflaten': ('gulvflate',),
'gulvflatene': ('gulvflate',),
'gulvflater': ('gulvflate',),
'gulvflis': ('gulvflis',),
'gulvflisa': ('gulvflis',),
'gulvflisen': ('gulvflis',),
'gulvflisene': ('gulvflis',),
'gulvfliser': ('gulvflis',),
'gulvflise': ('gulvflise',),
'gulvflisen': ('gulvflise',),
'gulvflisene': ('gulvflise',),
'gulvfliser': ('gulvflise',),
'gulvgir': ('gulvgir',),
'gulvgira': ('gulvgir',),
'gulvgirene': ('gulvgir',),
'gulvgiret': ('gulvgir',),
'gulvklut': ('gulvklut',),
'gulvkluten': ('gulvklut',),
'gulvklutene': ('gulvklut',),
'gulvkluter': ('gulvklut',),
'gulvlampa': ('gulvlampe',),
'gulvlampe': ('gulvlampe',),
'gulvlampen': ('gulvlampe',),
'gulvlampene': ('gulvlampe',),
'gulvlamper': ('gulvlampe',),
'gulvløper': ('gulvløper',),
'gulvløpere': ('gulvløper',),
'gulvløperen': ('gulvløper',),
'gulvløperer': ('gulvløper',),
'gulvløperne': ('gulvløper',),
'gulvmatta': ('gulvmatte',),
'gulvmatte': ('gulvmatte',),
'gulvmatten': ('gulvmatte',),
'gulvmattene': ('gulvmatte',),
'gulvmatter': ('gulvmatte',),
'gulvplass': ('gulvplass',),
'gulvplassen': ('gulvplass',),
'gulvplassene': ('gulvplass',),
'gulvplasser': ('gulvplass',),
'gulvteppa': ('gulvteppe',),
'gulvteppe': ('gulvteppe',),
'gulvteppene': ('gulvteppe',),
'gulvtepper': ('gulvteppe',),
'gulvteppet': ('gulvteppe',),
'gumme': ('gumme',),
'gummen': ('gumme',),
'gummene': ('gumme',),
'gummer': ('gumme',),
'gummi': ('gummi',),
'gummien': ('gummi',),
'gummiene': ('gummi',),
'gummier': ('gummi',),
'gummiartikkel': ('gummiartikkel',),
'gummiartikkelen': ('gummiartikkel',),
'gummiartiklene': ('gummiartikkel',),
'gummiartikler': ('gummiartikkel',),
'gummiasfalt': ('gummiasfalt',),
'gummiasfalten': ('gummiasfalt',),
'gummiasfaltene': ('gummiasfalt',),
'gummiasfalter': ('gummiasfalt',),
'gummiball': ('gummiball',),
'gummiballen': ('gummiball',),
'gummiballene': ('gummiball',),
'gummiballer': ('gummiball',),
'gummibåt': ('gummibåt',),
'gummibåten': ('gummibåt',),
'gummibåtene': ('gummibåt',),
'gummibåter': ('gummibåt',),
'gummihanske': ('gummihanske',),
'gummihansken': ('gummihanske',),
'gummihanskene': ('gummihanske',),
'gummihansker': ('gummihanske',),
'gummiplanta': ('gummiplante',),
'gummiplante': ('gummiplante',),
'gummiplanten': ('gummiplante',),
'gummiplantene': ('gummiplante',),
'gummiplanter': ('gummiplante',),
'gummislange': ('gummislange',),
'gummislangen': ('gummislange',),
'gummislangene': ('gummislange',),
'gummislanger': ('gummislange',),
'gummistrikk': ('gummistrikk',),
'gummistrikken': ('gummistrikk',),
'gummistrikkene': ('gummistrikk',),
'gummistrikker': ('gummistrikk',),
'gummistrømpa': ('gummistrømpe',),
'gummistrømpe': ('gummistrømpe',),
'gummistrømpen': ('gummistrømpe',),
'gummistrømpene': ('gummistrømpe',),
'gummistrømper': ('gummistrømpe',),
'gummistøvel': ('gummistøvel',),
'gummistøvelen': ('gummistøvel',),
'gummistøvlene': ('gummistøvel',),
'gummistøvler': ('gummistøvel',),
'gummivara': ('gummivare',),
'gummivare': ('gummivare',),
'gummivaren': ('gummivare',),
'gummivarene': ('gummivare',),
'gummivarer': ('gummivare',),
'gump': ('gump',),
'gumpen': ('gump',),
'gumpene': ('gump',),
'gumper': ('gump',),
'gunst': ('gunst',),
'gunsten': ('gunst',),
'gunstene': ('gunst',),
'gunster': ('gunst',),
'gunstbevisning': ('gunstbevisning',),
'gunstbevisninga': ('gunstbevisning',),
'gunstbevisningen': ('gunstbevisning',),
'gunstbevisningene': ('gunstbevisning',),
'gunstbevisninger': ('gunstbevisning',),
'gurglevann': ('gurglevann',),
'gurglevanna': ('gurglevann',),
'gurglevannene': ('gurglevann',),
'gurglevannet': ('gurglevann',),
'gurglevatn': ('gurglevatn',),
'gurglevatna': ('gurglevatn',),
'gurglevatnene': ('gurglevatn',),
'gurglevatnet': ('gurglevatn',),
'gurkemeie': ('gurkemeie',),
'gurkemeien': ('gurkemeie',),
'gurkemeiene': ('gurkemeie',),
'gurkemeier': ('gurkemeie',),
'gurp': ('gurp',),
'gurpen': ('gurp',),
'gurpene': ('gurp',),
'gurper': ('gurp',),
'guru': ('guru',),
'guruen': ('guru',),
'guruene': ('guru',),
'guruer': ('guru',),
'gurubevegelse': ('gurubevegelse',),
'gurubevegelsen': ('gurubevegelse',),
'gurubevegelsene': ('gurubevegelse',),
'gurubevegelser': ('gurubevegelse',),
'gust': ('gust',),
'gusta': ('gust',),
'gusten': ('gust',),
'gustene': ('gust',),
'guster': ('gust',),
'gustet': ('gust',),
'gut': ('gut',),
'guten': ('gut',),
'gutene': ('gut',),
'guter': ('gut',),
'gutt': ('gutt',),
'gutta': ('gutt',),
'gutten': ('gutt',),
'guttene': ('gutt',),
'gutter': ('gutt',),
'guttaperka': ('guttaperka',),
'guttaperkaen': ('guttaperka',),
'guttaperkaene': ('guttaperka',),
'guttaperkaer': ('guttaperka',),
'guttebande': ('guttebande',),
'guttebanden': ('guttebande',),
'guttebandene': ('guttebande',),
'guttebander': ('guttebande',),
'guttebarn': ('guttebarn',),
'guttebarna': ('guttebarn',),
'guttebarnene': ('guttebarn',),
'guttebarnet': ('guttebarn',),
'guttedag': ('guttedag',),
'guttedagen': ('guttedag',),
'guttedagene': ('guttedag',),
'guttedager': ('guttedag',),
'gutteflokk': ('gutteflokk',),
'gutteflokken': ('gutteflokk',),
'gutteflokkene': ('gutteflokk',),
'gutteflokker': ('gutteflokk',),
'guttemusikk': ('guttemusikk',),
'guttemusikken': ('guttemusikk',),
'guttemusikkene': ('guttemusikk',),
'guttemusikker': ('guttemusikk',),
'guttenavn': ('guttenavn',),
'guttenavna': ('guttenavn',),
'guttenavnene': ('guttenavn',),
'guttenavnet': ('guttenavn',),
'guttepjokk': ('guttepjokk',),
'guttepjokken': ('guttepjokk',),
'guttepjokkene': ('guttepjokk',),
'guttepjokker': ('guttepjokk',),
'guttestrek': ('guttestrek',),
'guttestreken': ('guttestrek',),
'guttestrekene': ('guttestrek',),
'guttestreker': ('guttestrek',),
'guttesveis': ('guttesveis',),
'guttesveisen': ('guttesveis',),
'guttesveisene': ('guttesveis',),
'guttesveiser': ('guttesveis',),
'guttevalp': ('guttevalp',),
'guttevalpen': ('guttevalp',),
'guttevalpene': ('guttevalp',),
'guttevalper': ('guttevalp',),
'gutteår': ('gutteår',),
'gutteåra': ('gutteår',),
'gutteårene': ('gutteår',),
'gutteåret': ('gutteår',),
'guttunge': ('guttunge',),
'guttungen': ('guttunge',),
'guttungene': ('guttunge',),
'guttunger': ('guttunge',),
'guttural': ('guttural',),
'gutturalen': ('guttural',),
'gutturalene': ('guttural',),
'gutturaler': ('guttural',),
'gutu': ('gutu',),
'gutua': ('gutu',),
'gutuen': ('gutu',),
'gutuene': ('gutu',),
'gutuer': ('gutu',),
'guvernanta': ('guvernante',),
'guvernante': ('guvernante',),
'guvernanten': ('guvernante',),
'guvernantene': ('guvernante',),
'guvernanter': ('guvernante',),
'guvernement': ('guvernement',),
'guvernementa': ('guvernement',),
'guvernementene': ('guvernement',),
'guvernementer': ('guvernement',),
'guvernementet': ('guvernement',),
'guvernør': ('guvernør',),
'guvernøren': ('guvernør',),
'guvernørene': ('guvernør',),
'guvernører': ('guvernør',),
'guyaner': ('guyaner',),
'guyanere': ('guyaner',),
'guyaneren': ('guyaner',),
'guyanerer': ('guyaner',),
'guyanerne': ('guyaner',),
'gydja': ('gydje',),
'gydje': ('gydje',),
'gydjen': ('gydje',),
'gydjene': ('gydje',),
'gydjer': ('gydje',),
'gyger': ('gyger',),
'gygere': ('gyger',),
'gygeren': ('gyger',),
'gygerne': ('gyger',),
'gygra': ('gyger',),
'gygre': ('gyger',),
'gygrene': ('gyger',),
'gygrer': ('gyger',),
'gylden': ('gylden',),
'gyldenen': ('gylden',),
'gyldenene': ('gylden',),
'gyldighet': ('gyldighet',),
'gyldigheta': ('gyldighet',),
'gyldigheten': ('gyldighet',),
'gyldighetene': ('gyldighet',),
'gyldigheter': ('gyldighet',),
'gylf': ('gylf',),
'gylfen': ('gylf',),
'gylfene': ('gylf',),
'gylfer': ('gylf',),
'gyllenlakk': ('gyllenlakk',),
'gyllenlakken': ('gyllenlakk',),
'gyllenlakkene': ('gyllenlakk',),
'gyllenlakker': ('gyllenlakk',),
'gyllenlær': ('gyllenlær',),
'gyllenlæra': ('gyllenlær',),
'gyllenlærene': ('gyllenlær',),
'gyllenlæret': ('gyllenlær',),
'gylta': ('gylte',),
'gylte': ('gylte',),
'gylten': ('gylte',),
'gyltene': ('gylte',),
'gylter': ('gylte',),
'gym': ('gym',),
'gymmen': ('gym',),
'gymmene': ('gym',),
'gymmer': ('gym',),
'gymkhana': ('gymkhana',),
'gymkhanaen': ('gymkhana',),
'gymkhanaene': ('gymkhana',),
'gymkhanaer': ('gymkhana',),
'gymnas': ('gymnas',),
'gymnasa': ('gymnas',),
'gymnasene': ('gymnas',),
'gymnaser': ('gymnas',),
'gymnaset': ('gymnas',),
'gymnaselev': ('gymnaselev',),
'gymnaseleven': ('gymnaselev',),
'gymnaselevene': ('gymnaselev',),
'gymnaselever': ('gymnaselev',),
'gymnaselev': ('gymnaselev',),
'gymnaseleven': ('gymnaselev',),
'gymnaselevene': ('gymnaselev',),
'gymnaselever': ('gymnaselev',),
'gymnasiast': ('gymnasiast',),
'gymnasiasten': ('gymnasiast',),
'gymnasiastene': ('gymnasiast',),
'gymnasiaster': ('gymnasiast',),
'gymnasieelev': ('gymnasieelev',),
'gymnasieeleven': ('gymnasieelev',),
'gymnasieelevene': ('gymnasieelev',),
'gymnasieelever': ('gymnasieelev',),
'gymnasieelev': ('gymnasieelev',),
'gymnasieeleven': ('gymnasieelev',),
'gymnasieelevene': ('gymnasieelev',),
'gymnasieelever': ('gymnasieelev',),
'gymnasia': ('gymnasium',),
'gymnasiene': ('gymnasium',),
'gymnasier': ('gymnasium',),
'gymnasiet': ('gymnasium',),
'gymnasium': ('gymnasium',),
'gymnast': ('gymnast',),
'gymnasten': ('gymnast',),
'gymnastene': ('gymnast',),
'gymnaster': ('gymnast',),
'gymnastikk': ('gymnastikk',),
'gymnastikken': ('gymnastikk',),
'gymnastikkene': ('gymnastikk',),
'gymnastikker': ('gymnastikk',),
'gymnastikkapparat': ('gymnastikkapparat',),
'gymnastikkapparata': ('gymnastikkapparat',),
'gymnastikkapparatene': ('gymnastikkapparat',),
'gymnastikkapparater': ('gymnastikkapparat',),
'gymnastikkapparatet': ('gymnastikkapparat',),
'gymnastikklærer': ('gymnastikklærer',),
'gymnastikklærere': ('gymnastikklærer',),
'gymnastikklæreren': ('gymnastikklærer',),
'gymnastikklærerer': ('gymnastikklærer',),
'gymnastikklærerne': ('gymnastikklærer',),
'gymnastikksal': ('gymnastikksal',),
'gymnastikksalen': ('gymnastikksal',),
'gymnastikksalene': ('gymnastikksal',),
'gymnastikksaler': ('gymnastikksal',),
'gymnastikkøvelse': ('gymnastikkøvelse',),
'gymnastikkøvelsen': ('gymnastikkøvelse',),
'gymnastikkøvelsene': ('gymnastikkøvelse',),
'gymnastikkøvelser': ('gymnastikkøvelse',),
'gymnastikkøving': ('gymnastikkøving',),
'gymnastikkøvinga': ('gymnastikkøving',),
'gymnastikkøvingen': ('gymnastikkøving',),
'gymnastikkøvingene': ('gymnastikkøving',),
'gymnastikkøvinger': ('gymnastikkøving',),
'gymnospermene': ('gymnospermer',),
'gymnospermer': ('gymnospermer',),
'gynekolog': ('gynekolog',),
'gynekologen': ('gynekolog',),
'gynekologene': ('gynekolog',),
'gynekologer': ('gynekolog',),
'gynekologi': ('gynekologi',),
'gynekologien': ('gynekologi',),
'gynekologiene': ('gynekologi',),
'gynekologier': ('gynekologi',),
'gynga': ('gynge',),
'gynge': ('gynge',),
'gyngen': ('gynge',),
'gyngene': ('gynge',),
'gynger': ('gynge',),
'gyngehest': ('gyngehest',),
'gyngehesten': ('gyngehest',),
'gyngehestene': ('gyngehest',),
'gyngehester': ('gyngehest',),
'gyngestol': ('gyngestol',),
'gyngestolen': ('gyngestol',),
'gyngestolene': ('gyngestol',),
'gyngestoler': ('gyngestol',),
'gyro': ('gyro',),
'gyroen': ('gyro',),
'gyroene': ('gyro',),
'gyroer': ('gyro',),
'gyrokompas': ('gyrokompas',),
'gyrokompasa': ('gyrokompas',),
'gyrokompasen': ('gyrokompas',),
'gyrokompasene': ('gyrokompas',),
'gyrokompaser': ('gyrokompas',),
'gyrokompaset': ('gyrokompas',),
'gyrokompass': ('gyrokompass',),
'gyrokompassa': ('gyrokompass',),
'gyrokompassen': ('gyrokompass',),
'gyrokompassene': ('gyrokompass',),
'gyrokompasser': ('gyrokompass',),
'gyrokompasset': ('gyrokompass',),
'gyrometer': ('gyrometer',),
'gyrometeret': ('gyrometer',),
'gyrometra': ('gyrometer',),
'gyrometre': ('gyrometer',),
'gyrometrene': ('gyrometer',),
'gyrometret': ('gyrometer',),
'gyrosikta': ('gyrosikte',),
'gyrosikte': ('gyrosikte',),
'gyrosiktene': ('gyrosikte',),
'gyrosikter': ('gyrosikte',),
'gyrosiktet': ('gyrosikte',),
'gyroskop': ('gyroskop',),
'gyroskopa': ('gyroskop',),
'gyroskopene': ('gyroskop',),
'gyroskoper': ('gyroskop',),
'gyroskopet': ('gyroskop',),
'gyroskopstyring': ('gyroskopstyring',),
'gyroskopstyringa': ('gyroskopstyring',),
'gyroskopstyringen': ('gyroskopstyring',),
'gyroskopstyringene': ('gyroskopstyring',),
'gyroskopstyringer': ('gyroskopstyring',),
'gyrostabilisator': ('gyrostabilisator',),
'gyrostabilisatoren': ('gyrostabilisator',),
'gyrostabilisatorene': ('gyrostabilisator',),
'gyrostabilisatorer': ('gyrostabilisator',),
'gys': ('gys',),
'gysa': ('gys',),
'gysene': ('gys',),
'gyset': ('gys',),
'gyser': ('gyser',),
'gysere': ('gyser',),
'gyseren': ('gyser',),
'gyserer': ('gyser',),
'gyserne': ('gyser',),
'gysning': ('gysning',),
'gysninga': ('gysning',),
'gysningen': ('gysning',),
'gysningene': ('gysning',),
'gysninger': ('gysning',),
'gyta': ('gyte',),
'gyte': ('gyte',),
'gyten': ('gyte',),
'gytene': ('gyte',),
'gyter': ('gyte',),
'gyteplass': ('gyteplass',),
'gyteplassen': ('gyteplass',),
'gyteplassene': ('gyteplass',),
'gyteplasser': ('gyteplass',),
'gytetid': ('gytetid',),
'gytetida': ('gytetid',),
'gytetiden': ('gytetid',),
'gytetidene': ('gytetid',),
'gytetider': ('gytetid',),
'gytjebad': ('gytjebad',),
'gytjebada': ('gytjebad',),
'gytjebadene': ('gytjebad',),
'gytjebadet': ('gytjebad',),
'gytjekur': ('gytjekur',),
'gytjekuren': ('gytjekur',),
'gytjekurene': ('gytjekur',),
'gytjekurer': ('gytjekur',),
'gytjeomslag': ('gytjeomslag',),
'gytjeomslaga': ('gytjeomslag',),
'gytjeomslagene': ('gytjeomslag',),
'gytjeomslaget': ('gytjeomslag',),
'gyv': ('gyv',),
'gyva': ('gyv',),
'gyvene': ('gyv',),
'gyvet': ('gyv',),
'gyvel': ('gyvel',),
'gyvelen': ('gyvel',),
'gyvlene': ('gyvel',),
'gyvler': ('gyvel',),
'gå-sakte-aksjon': ('gå-sakte-aksjon',),
'gå-sakte-aksjonen': ('gå-sakte-aksjon',),
'gå-sakte-aksjonene': ('gå-sakte-aksjon',),
'gå-sakte-aksjoner': ('gå-sakte-aksjon',),
'gåavstand': ('gåavstand',),
'gåavstanden': ('gåavstand',),
'gåavstandene': ('gåavstand',),
'gåavstander': ('gåavstand',),
'gåbortdress': ('gåbortdress',),
'gåbortdressen': ('gåbortdress',),
'gåbortdressene': ('gåbortdress',),
'gåbortdresser': ('gåbortdress',),
'gåbortkjole': ('gåbortkjole',),
'gåbortkjolen': ('gåbortkjole',),
'gåbortkjolene': ('gåbortkjole',),
'gåbortkjoler': ('gåbortkjole',),
'gåfotball': ('gåfotball',),
'gåfotballen': ('gåfotball',),
'gåfotballene': ('gåfotball',),
'gåfotballer': ('gåfotball',),
'gågata': ('gågate',),
'gågate': ('gågate',),
'gågaten': ('gågate',),
'gågatene': ('gågate',),
'gågater': ('gågate',),
'gåing': ('gåing',),
'gåinga': ('gåing',),
'gåingen': ('gåing',),
'gåingene': ('gåing',),
'gåinger': ('gåing',),
'gåpåhumør': ('gåpåhumør',),
'gåpåhumøra': ('gåpåhumør',),
'gåpåhumørene': ('gåpåhumør',),
'gåpåhumøret': ('gåpåhumør',),
'går': ('går',),
'gård': ('gård',),
'gården': ('gård',),
'gårdene': ('gård',),
'gårder': ('gård',),
'gårdbruker': ('gårdbruker',),
'gårdbrukere': ('gårdbruker',),
'gårdbrukeren': ('gårdbruker',),
'gårdbrukerer': ('gårdbruker',),
'gårdbrukerne': ('gårdbruker',),
'gårdeier': ('gårdeier',),
'gårdeiere': ('gårdeier',),
'gårdeieren': ('gårdeier',),
'gårdeierer': ('gårdeier',),
'gårdeierne': ('gårdeier',),
'gårdpart': ('gårdpart',),
'gårdparten': ('gårdpart',),
'gårdpartene': ('gårdpart',),
'gårdparter': ('gårdpart',),
'gårdsarbeid': ('gårdsarbeid',),
'gårdsarbeida': ('gårdsarbeid',),
'gårdsarbeidene': ('gårdsarbeid',),
'gårdsarbeider': ('gårdsarbeid',),
'gårdsarbeidet': ('gårdsarbeid',),
'gårdsarbeider': ('gårdsarbeider',),
'gårdsarbeidere': ('gårdsarbeider',),
'gårdsarbeideren': ('gårdsarbeider',),
'gårdsarbeiderer': ('gårdsarbeider',),
'gårdsarbeiderne': ('gårdsarbeider',),
'gårdsbruk': ('gårdsbruk',),
'gårdsbruka': ('gårdsbruk',),
'gårdsbrukene': ('gårdsbruk',),
'gårdsbruket': ('gårdsbruk',),
'gårdsdreng': ('gårdsdreng',),
'gårdsdrengen': ('gårdsdreng',),
'gårdsdrengene': ('gårdsdreng',),
'gårdsdrenger': ('gårdsdreng',),
'gårdsdrift': ('gårdsdrift',),
'gårdsdrifta': ('gårdsdrift',),
'gårdsdriften': ('gårdsdrift',),
'gårdsdriftene': ('gårdsdrift',),
'gårdsdrifter': ('gårdsdrift',),
'gårdsfolk': ('gårdsfolk',),
'gårdsfolka': ('gårdsfolk',),
'gårdsfolkene': ('gårdsfolk',),
'gårdsfolket': ('gårdsfolk',),
'gårdsgutt': ('gårdsgutt',),
'gårdsgutten': ('gårdsgutt',),
'gårdsguttene': ('gårdsgutt',),
'gårdsgutter': ('gårdsgutt',),
'gårdshund': ('gårdshund',),
'gårdshunden': ('gårdshund',),
'gårdshundene': ('gårdshund',),
'gårdshunder': ('gårdshund',),
'gårdsnavn': ('gårdsnavn',),
'gårdsnavna': ('gårdsnavn',),
'gårdsnavnene': ('gårdsnavn',),
'gårdsnavnet': ('gårdsnavn',),
'gårdsnummer': ('gårdsnummer',),
'gårdsnummeret': ('gårdsnummer',),
'gårdsnumra': ('gårdsnummer',),
'gårdsnumre': ('gårdsnummer',),
'gårdsnumrene': ('gårdsnummer',),
'gårdsplass': ('gårdsplass',),
'gårdsplassen': ('gårdsplass',),
'gårdsplassene': ('gårdsplass',),
'gårdsplasser': ('gårdsplass',),
'gårdsrom': ('gårdsrom',),
'gårdsromma': ('gårdsrom',),
'gårdsrommene': ('gårdsrom',),
'gårdsrommet': ('gårdsrom',),
'gårdssmør': ('gårdssmør',),
'gårdssmøra': ('gårdssmør',),
'gårdssmørene': ('gårdssmør',),
'gårdssmøret': ('gårdssmør',),
'gårdsstell': ('gårdsstell',),
'gårdsstella': ('gårdsstell',),
'gårdsstellene': ('gårdsstell',),
'gårdsstellet': ('gårdsstell',),
'gårdstank': ('gårdstank',),
'gårdstanken': ('gårdstank',),
'gårdstankene': ('gårdstank',),
'gårdstanker': ('gårdstank',),
'gårdstanksystem': ('gårdstanksystem',),
'gårdstanksystema': ('gårdstanksystem',),
'gårdstanksystemene': ('gårdstanksystem',),
'gårdstanksystemer': ('gårdstanksystem',),
'gårdstanksystemet': ('gårdstanksystem',),
'gårdsteig': ('gårdsteig',),
'gårdsteigen': ('gårdsteig',),
'gårdsteigene': ('gårdsteig',),
'gårdsteiger': ('gårdsteig',),
'gårdstun': ('gårdstun',),
'gårdstuna': ('gårdstun',),
'gårdstunene': ('gårdstun',),
'gårdstunet': ('gårdstun',),
'gårdsveg': ('gårdsveg',),
'gårdsvegen': ('gårdsveg',),
'gårdsvegene': ('gårdsveg',),
'gårdsveger': ('gårdsveg',),
'gårdsvei': ('gårdsvei',),
'gårdsveien': ('gårdsvei',),
'gårdsveiene': ('gårdsvei',),
'gårdsveier': ('gårdsvei',),
'gåra': ('gåre',),
'gåre': ('gåre',),
'gåren': ('gåre',),
'gårene': ('gåre',),
'gårer': ('gåre',),
'gårsdag': ('gårsdag',),
'gårsdagen': ('gårsdag',),
'gårsdagene': ('gårsdag',),
'gårsdager': ('gårsdag',),
'gjess': ('gås',),
'gjessene': ('gås',),
'gjæsene': ('gås',),
'gjæser': ('gås',),
'gås': ('gås',),
'gåsa': ('gås',),
'gåsen': ('gås',),
'gåseblom': ('gåseblom',),
'gåseblommen': ('gåseblom',),
'gåseblommene': ('gåseblom',),
'gåseblommer': ('gåseblom',),
'gåsefot': ('gåsefot',),
'gåsefoten': ('gåsefot',),
'gåsefotene': ('gåsefot',),
'gåsegang': ('gåsegang',),
'gåsegangen': ('gåsegang',),
'gåsegangene': ('gåsegang',),
'gåseganger': ('gåsegang',),
'gåsegribb': ('gåsegribb',),
'gåsegribben': ('gåsegribb',),
'gåsegribbene': ('gåsegribb',),
'gåsegribber': ('gåsegribb',),
'gåsehud': ('gåsehud',),
'gåsehuda': ('gåsehud',),
'gåsehuden': ('gåsehud',),
'gåsehudene': ('gåsehud',),
'gåsehuder': ('gåsehud',),
'gåselabb': ('gåselabb',),
'gåselabben': ('gåselabb',),
'gåselabbene': ('gåselabb',),
'gåselabber': ('gåselabb',),
'gåselever': ('gåselever',),
'gåselevere': ('gåselever',),
'gåseleveren': ('gåselever',),
'gåseleverer': ('gåselever',),
'gåseleverne': ('gåselever',),
'gåselevra': ('gåselever',),
'gåselevre': ('gåselever',),
'gåselevrene': ('gåselever',),
'gåselevrer': ('gåselever',),
'gåseleverpostei': ('gåseleverpostei',),
'gåseleverposteien': ('gåseleverpostei',),
'gåseleverposteiene': ('gåseleverpostei',),
'gåseleverposteier': ('gåseleverpostei',),
'gåsemura': ('gåsemure',),
'gåsemure': ('gåsemure',),
'gåsemuren': ('gåsemure',),
'gåsemurene': ('gåsemure',),
'gåsemurer': ('gåsemure',),
'gåsestegg': ('gåsestegg',),
'gåsesteggen': ('gåsestegg',),
'gåsesteggene': ('gåsestegg',),
'gåsestegger': ('gåsestegg',),
'gåsesteik': ('gåsesteik',),
'gåsesteika': ('gåsesteik',),
'gåsesteiken': ('gåsesteik',),
'gåsesteikene': ('gåsesteik',),
'gåsesteiker': ('gåsesteik',),
'gåsestek': ('gåsestek',),
'gåsesteka': ('gåsestek',),
'gåsesteken': ('gåsestek',),
'gåsestekene': ('gåsestek',),
'gåsesteker': ('gåsestek',),
'gåseøya': ('gåseøyer',),
'gåseøyene': ('gåseøyer',),
'gåseøyer': ('gåseøyer',),
'gåseøyne': ('gåseøyer',),
'gåseøynene': ('gåseøyer',),
'gåseøya': ('gåseøyne',),
'gåseøyene': ('gåseøyne',),
'gåseøyer': ('gåseøyne',),
'gåseøyne': ('gåseøyne',),
'gåseøynene': ('gåseøyne',),
'gåstol': ('gåstol',),
'gåstolen': ('gåstol',),
'gåstolene': ('gåstol',),
'gåstoler': ('gåstol',),
'gåsunge': ('gåsunge',),
'gåsungen': ('gåsunge',),
'gåsungene': ('gåsunge',),
'gåsunger': ('gåsunge',),
'gåta': ('gåte',),
'gåte': ('gåte',),
'gåten': ('gåte',),
'gåtene': ('gåte',),
'gåter': ('gåte',),
'gåteleik': ('gåteleik',),
'gåteleiken': ('gåteleik',),
'gåteleikene': ('gåteleik',),
'gåteleiker': ('gåteleik',),
'gåtelek': ('gåtelek',),
'gåteleken': ('gåtelek',),
'gåtelekene': ('gåtelek',),
'gåteleker': ('gåtelek',),
'gåtesamling': ('gåtesamling',),
'gåtesamlinga': ('gåtesamling',),
'gåtesamlingen': ('gåtesamling',),
'gåtesamlingene': ('gåtesamling',),
'gåtesamlinger': ('gåtesamling',),
'gæler': ('gæler',),
'gælere': ('gæler',),
'gæleren': ('gæler',),
'gælerer': ('gæler',),
'gælerne': ('gæler',),
'gælisk': ('gælisk',),
'gælisken': ('gælisk',),
'gæliskene': ('gælisk',),
'gælisker': ('gælisk',),
'gørr': ('gørr',),
'gørra': ('gørr',),
'gørrene': ('gørr',),
'gørret': ('gørr',),
'gøy': ('gøy',),
'gøys': ('gøys',),
'gøysen': ('gøys',),
'gøysene': ('gøys',),
'gøyser': ('gøys',),
'h': ('h',),
'h\'en': ('h',),
'h-en': ('h',),
'h-ene': ('h',),
'h-er': ('h',),
'h-bomba': ('h-bombe',),
'h-bombe': ('h-bombe',),
'h-bomben': ('h-bombe',),
'h-bombene': ('h-bombe',),
'h-bomber': ('h-bombe',),
'h-moll': ('h-moll',),
'h-mollen': ('h-moll',),
'h-mollene': ('h-moll',),
'h-moller': ('h-moll',),
'habanera': ('habanera',),
'habaneraen': ('habanera',),
'habaneraene': ('habanera',),
'habaneraer': ('habanera',),
'habengut': ('habengut',),
'habenguta': ('habengut',),
'habengutene': ('habengut',),
'habengutet': ('habengut',),
'habilitasjon': ('habilitasjon',),
'habilitasjonen': ('habilitasjon',),
'habilitasjonene': ('habilitasjon',),
'habilitasjoner': ('habilitasjon',),
'habilitet': ('habilitet',),
'habiliteten': ('habilitet',),
'habilitetene': ('habilitet',),
'habiliteter': ('habilitet',),
'habitat': ('habitat',),
'habitata': ('habitat',),
'habitatene': ('habitat',),
'habitater': ('habitat',),
'habitatet': ('habitat',),
'habitt': ('habitt',),
'habitten': ('habitt',),
'habittene': ('habitt',),
'habitter': ('habitt',),
'habitus': ('habitus',),
'habitusen': ('habitus',),
'habitusene': ('habitus',),
'habituser': ('habitus',),
'habsburger': ('habsburger',),
'habsburgere': ('habsburger',),
'habsburgeren': ('habsburger',),
'habsburgerer': ('habsburger',),
'habsburgerne': ('habsburger',),
'hacienda': ('hacienda',),
'haciendaen': ('hacienda',),
'haciendaene': ('hacienda',),
'haciendaer': ('hacienda',),
'hadelending': ('hadelending',),
'hadelendingen': ('hadelending',),
'hadelendingene': ('hadelending',),
'hadelendinger': ('hadelending',),
'hafella': ('hafelle',),
'hafelle': ('hafelle',),
'hafellen': ('hafelle',),
'hafellene': ('hafelle',),
'hafeller': ('hafelle',),
'hafella': ('hafelle',),
'hafelle': ('hafelle',),
'hafellen': ('hafelle',),
'hafellene': ('hafelle',),
'hafeller': ('hafelle',),
'hafnium': ('hafnium',),
'hafniuma': ('hafnium',),
'hafniumene': ('hafnium',),
'hafniumet': ('hafnium',),
'hage': ('hage',),
'hagen': ('hage',),
'hagene': ('hage',),
'hager': ('hage',),
'hagearkitekt': ('hagearkitekt',),
'hagearkitekten': ('hagearkitekt',),
'hagearkitektene': ('hagearkitekt',),
'hagearkitekter': ('hagearkitekt',),
'hageblomst': ('hageblomst',),
'hageblomsten': ('hageblomst',),
'hageblomstene': ('hageblomst',),
'hageblomster': ('hageblomst',),
'hagebok': ('hagebok',),
'hageboka': ('hagebok',),
'hageboken': ('hagebok',),
'hagebøkene': ('hagebok',),
'hagebøker': ('hagebok',),
'hagebruk': ('hagebruk',),
'hagebruka': ('hagebruk',),
'hagebrukene': ('hagebruk',),
'hagebruket': ('hagebruk',),
'hagebrukskandidat': ('hagebrukskandidat',),
'hagebrukskandidaten': ('hagebrukskandidat',),
'hagebrukskandidatene': ('hagebrukskandidat',),
'hagebrukskandidater': ('hagebrukskandidat',),
'hagebruksskole': ('hagebruksskole',),
'hagebruksskolen': ('hagebruksskole',),
'hagebruksskolene': ('hagebruksskole',),
'hagebruksskoler': ('hagebruksskole',),
'hageby': ('hageby',),
'hagebyen': ('hageby',),
'hagebyene': ('hageby',),
'hagebyer': ('hageby',),
'hagebær': ('hagebær',),
'hagebæra': ('hagebær',),
'hagebærene': ('hagebær',),
'hagebæret': ('hagebær',),
'hageert': ('hageert',),
'hageerta': ('hageert',),
'hageerten': ('hageert',),
'hageertene': ('hageert',),
'hageerter': ('hageert',),
'hagegang': ('hagegang',),
'hagegangen': ('hagegang',),
'hagegangene': ('hagegang',),
'hageganger': ('hagegang',),
'hagegynga': ('hagegynge',),
'hagegynge': ('hagegynge',),
'hagegyngen': ('hagegynge',),
'hagegyngene': ('hagegynge',),
'hagegynger': ('hagegynge',),
'hagejordbær': ('hagejordbær',),
'hagejordbæra': ('hagejordbær',),
'hagejordbærene': ('hagejordbær',),
'hagejordbæret': ('hagejordbær',),
'hagekniv': ('hagekniv',),
'hagekniven': ('hagekniv',),
'hageknivene': ('hagekniv',),
'hagekniver': ('hagekniv',),
'hagekoloni': ('hagekoloni',),
'hagekolonien': ('hagekoloni',),
'hagekoloniene': ('hagekoloni',),
'hagekolonier': ('hagekoloni',),
'hagekunst': ('hagekunst',),
'hagekunsten': ('hagekunst',),
'hagekunstene': ('hagekunst',),
'hagekunster': ('hagekunst',),
'hagel': ('hagel',),
'hagelen': ('hagel',),
'haglene': ('hagel',),
'hagler': ('hagel',),
'hageløper': ('hageløper',),
'hageløpere': ('hageløper',),
'hageløperen': ('hageløper',),
'hageløperer': ('hageløper',),
'hageløperne': ('hageløper',),
'hagenellik': ('hagenellik',),
'hagenelliken': ('hagenellik',),
'hagenellikene': ('hagenellik',),
'hagenelliker': ('hagenellik',),
'hageredskap': ('hageredskap',),
'hageredskapa': ('hageredskap',),
'hageredskapen': ('hageredskap',),
'hageredskapene': ('hageredskap',),
'hageredskaper': ('hageredskap',),
'hageredskapet': ('hageredskap',),
'hagesaks': ('hagesaks',),
'hagesaksa': ('hagesaks',),
'hagesaksen': ('hagesaks',),
'hagesaksene': ('hagesaks',),
'hagesakser': ('hagesaks',),
'hagesanger': ('hagesanger',),
'hagesangere': ('hagesanger',),
'hagesangeren': ('hagesanger',),
'hagesangerer': ('hagesanger',),
'hagesangerne': ('hagesanger',),
'hageselskap': ('hageselskap',),
'hageselskapa': ('hageselskap',),
'hageselskapene': ('hageselskap',),
'hageselskaper': ('hageselskap',),
'hageselskapet': ('hageselskap',),
'hagesenter': ('hagesenter',),
'hagesenteret': ('hagesenter',),
'hagesentra': ('hagesenter',),
'hagesentre': ('hagesenter',),
'hagesentrene': ('hagesenter',),
'hagesentret': ('hagesenter',),
'hageslange': ('hageslange',),
'hageslangen': ('hageslange',),
'hageslangene': ('hageslange',),
'hageslanger': ('hageslange',),
'hagesnegl': ('hagesnegl',),
'hagesneglen': ('hagesnegl',),
'hagesneglene': ('hagesnegl',),
'hagesnegler': ('hagesnegl',),
'hagesnile': ('hagesnile',),
'hagesnilen': ('hagesnile',),
'hagesnilene': ('hagesnile',),
'hagesniler': ('hagesnile',),
'hagestova': ('hagestove',),
'hagestove': ('hagestove',),
'hagestoven': ('hagestove',),
'hagestovene': ('hagestove',),
'hagestover': ('hagestove',),
'hagestua': ('hagestue',),
'hagestue': ('hagestue',),
'hagestuen': ('hagestue',),
'hagestuene': ('hagestue',),
'hagestuer': ('hagestue',),
'hagfella': ('hagfelle',),
'hagfelle': ('hagfelle',),
'hagfellen': ('hagfelle',),
'hagfellene': ('hagfelle',),
'hagfeller': ('hagfelle',),
'hagfella': ('hagfelle',),
'hagfelle': ('hagfelle',),
'hagfellen': ('hagfelle',),
'hagfellene': ('hagfelle',),
'hagfeller': ('hagfelle',),
'hagl': ('hagl',),
'hagla': ('hagl',),
'haglene': ('hagl',),
'haglet': ('hagl',),
'haglbya': ('haglbye',),
'haglbye': ('haglbye',),
'haglbyen': ('haglbye',),
'haglbyene': ('haglbye',),
'haglbyer': ('haglbye',),
'haglbyga': ('haglbyge',),
'haglbyge': ('haglbyge',),
'haglbygen': ('haglbyge',),
'haglbygene': ('haglbyge',),
'haglbyger': ('haglbyge',),
'haglbøya': ('haglbøye',),
'haglbøye': ('haglbøye',),
'haglbøyen': ('haglbøye',),
'haglbøyene': ('haglbøye',),
'haglbøyer': ('haglbøye',),
'hagla': ('hagle',),
'hagle': ('hagle',),
'haglen': ('hagle',),
'haglene': ('hagle',),
'hagler': ('hagle',),
'haglgevær': ('haglgevær',),
'haglgeværa': ('haglgevær',),
'haglgeværene': ('haglgevær',),
'haglgeværer': ('haglgevær',),
'haglgeværet': ('haglgevær',),
'haglkorn': ('haglkorn',),
'haglkorna': ('haglkorn',),
'haglkornene': ('haglkorn',),
'haglkornet': ('haglkorn',),
'haglladning': ('haglladning',),
'haglladninga': ('haglladning',),
'haglladningen': ('haglladning',),
'haglladningene': ('haglladning',),
'haglladninger': ('haglladning',),
'haglpatron': ('haglpatron',),
'haglpatronen': ('haglpatron',),
'haglpatronene': ('haglpatron',),
'haglpatroner': ('haglpatron',),
'haglpung': ('haglpung',),
'haglpungen': ('haglpung',),
'haglpungene': ('haglpung',),
'haglpunger': ('haglpung',),
'haglskur': ('haglskur',),
'haglskura': ('haglskur',),
'haglskuren': ('haglskur',),
'haglskurene': ('haglskur',),
'haglskurer': ('haglskur',),
'hagtorn': ('hagtorn',),
'hagtornen': ('hagtorn',),
'hagtornene': ('hagtorn',),
'hagtorner': ('hagtorn',),
'hai': ('hai',),
'haien': ('hai',),
'haiene': ('hai',),
'haier': ('hai',),
'haifisk': ('haifisk',),
'haifisken': ('haifisk',),
'haifiskene': ('haifisk',),
'haifisker': ('haifisk',),
'haik': ('haik',),
'haiken': ('haik',),
'haikene': ('haik',),
'haiker': ('haik',),
'haiker': ('haiker',),
'haikere': ('haiker',),
'haikeren': ('haiker',),
'haikerer': ('haiker',),
'haikerne': ('haiker',),
'haiketur': ('haiketur',),
'haiketuren': ('haiketur',),
'haiketurene': ('haiketur',),
'haiketurer': ('haiketur',),
'haiku': ('haiku',),
'haikuen': ('haiku',),
'haikuene': ('haiku',),
'haikuer': ('haiku',),
'haikudikt': ('haikudikt',),
'haikudikta': ('haikudikt',),
'haikudiktene': ('haikudikt',),
'haikudiktet': ('haikudikt',),
'haitianer': ('haitianer',),
'haitianere': ('haitianer',),
'haitianeren': ('haitianer',),
'haitianerer': ('haitianer',),
'haitianerne': ('haitianer',),
'haitier': ('haitier',),
'haitiere': ('haitier',),
'haitieren': ('haitier',),
'haitierer': ('haitier',),
'haitierne': ('haitier',),
'hakapik': ('hakapik',),
'hakapiken': ('hakapik',),
'hakapikene': ('hakapik',),
'hakapiker': ('hakapik',),
'hakaure': ('hakaure',),
'hakauren': ('hakaure',),
'hakaurene': ('hakaure',),
'hakaurer': ('hakaure',),
'hake': ('hake',),
'haken': ('hake',),
'hakene': ('hake',),
'haker': ('hake',),
'haka': ('hake',),
'hake': ('hake',),
'haken': ('hake',),
'hakene': ('hake',),
'haker': ('hake',),
'hakeaure': ('hakeaure',),
'hakeauren': ('hakeaure',),
'hakeaurene': ('hakeaure',),
'hakeaurer': ('hakeaure',),
'hakeband': ('hakeband',),
'hakebanda': ('hakeband',),
'hakebandene': ('hakeband',),
'hakebandet': ('hakeband',),
'hakebrett': ('hakebrett',),
'hakebretta': ('hakebrett',),
'hakebrettene': ('hakebrett',),
'hakebretter': ('hakebrett',),
'hakebrettet': ('hakebrett',),
'hakebånd': ('hakebånd',),
'hakebånda': ('hakebånd',),
'hakebåndene': ('hakebånd',),
'hakebåndet': ('hakebånd',),
'hakefisk': ('hakefisk',),
'hakefisken': ('hakefisk',),
'hakefiskene': ('hakefisk',),
'hakefisker': ('hakefisk',),
'hakekors': ('hakekors',),
'hakekorsa': ('hakekors',),
'hakekorsene': ('hakekors',),
'hakekorset': ('hakekors',),
'hakelaks': ('hakelaks',),
'hakelaksen': ('hakelaks',),
'hakelaksene': ('hakelaks',),
'hakelakser': ('hakelaks',),
'hakeparentes': ('hakeparentes',),
'hakeparentesen': ('hakeparentes',),
'hakeparentesene': ('hakeparentes',),
'hakeparenteser': ('hakeparentes',),
'hakepigg': ('hakepigg',),
'hakepiggen': ('hakepigg',),
'hakepiggene': ('hakepigg',),
'hakepigger': ('hakepigg',),
'hakeslepp': ('hakeslepp',),
'hakesleppa': ('hakeslepp',),
'hakesleppene': ('hakeslepp',),
'hakesleppet': ('hakeslepp',),
'hakeslipp': ('hakeslipp',),
'hakeslippa': ('hakeslipp',),
'hakeslippene': ('hakeslipp',),
'hakeslippet': ('hakeslipp',),
'hakespiss': ('hakespiss',),
'hakespissen': ('hakespiss',),
'hakespissene': ('hakespiss',),
'hakespisser': ('hakespiss',),
'hakeørret': ('hakeørret',),
'hakeørreten': ('hakeørret',),
'hakeørretene': ('hakeørret',),
'hakeørreter': ('hakeørret',),
'hakka': ('hakke',),
'hakke': ('hakke',),
'hakken': ('hakke',),
'hakkene': ('hakke',),
'hakker': ('hakke',),
'hakkebiff': ('hakkebiff',),
'hakkebiffen': ('hakkebiff',),
'hakkebiffene': ('hakkebiff',),
'hakkebiffer': ('hakkebiff',),
'hakkeblokk': ('hakkeblokk',),
'hakkeblokka': ('hakkeblokk',),
'hakkeblokken': ('hakkeblokk',),
'hakkeblokkene': ('hakkeblokk',),
'hakkeblokker': ('hakkeblokk',),
'hakkebrett': ('hakkebrett',),
'hakkebretta': ('hakkebrett',),
'hakkebrettene': ('hakkebrett',),
'hakkebretter': ('hakkebrett',),
'hakkebrettet': ('hakkebrett',),
'hakkebrett': ('hakkebrett',),
'hakkebretta': ('hakkebrett',),
'hakkebrettene': ('hakkebrett',),
'hakkebretter': ('hakkebrett',),
'hakkebrettet': ('hakkebrett',),
'hakkebruk': ('hakkebruk',),
'hakkebruka': ('hakkebruk',),
'hakkebrukene': ('hakkebruk',),
'hakkebruket': ('hakkebruk',),
'hakkelov': ('hakkelov',),
'hakkeloven': ('hakkelov',),
'hakkelovene': ('hakkelov',),
'hakkelover': ('hakkelov',),
'hakkels': ('hakkels',),
'hakkelsen': ('hakkels',),
'hakkelsene': ('hakkels',),
'hakkelser': ('hakkels',),
'hakkelse': ('hakkelse',),
'hakkelsen': ('hakkelse',),
'hakkelsene': ('hakkelse',),
'hakkelser': ('hakkelse',),
'hakkemat': ('hakkemat',),
'hakkematen': ('hakkemat',),
'hakkematene': ('hakkemat',),
'hakkemater': ('hakkemat',),
'hakkeskaft': ('hakkeskaft',),
'hakkeskafta': ('hakkeskaft',),
'hakkeskaftene': ('hakkeskaft',),
'hakkeskafter': ('hakkeskaft',),
'hakkeskaftet': ('hakkeskaft',),
'hakkespett': ('hakkespett',),
'hakkespetten': ('hakkespett',),
'hakkespettene': ('hakkespett',),
'hakkespetter': ('hakkespett',),
'hakkespetta': ('hakkespette',),
'hakkespette': ('hakkespette',),
'hakkespetten': ('hakkespette',),
'hakkespettene': ('hakkespette',),
'hakkespetter': ('hakkespette',),
'hakørret': ('hakørret',),
'hakørreten': ('hakørret',),
'hakørretene': ('hakørret',),
'hakørreter': ('hakørret',),
'hal': ('hal',),
'hal': ('hal',),
'hala': ('hal',),
'halene': ('hal',),
'halet': ('hal',),
'hald': ('hald',),
'halda': ('hald',),
'haldene': ('hald',),
'haldet': ('hald',),
'haldar': ('haldar',),
'haldaren': ('haldar',),
'haldarene': ('haldar',),
'haldarer': ('haldar',),
'haldenser': ('haldenser',),
'haldensere': ('haldenser',),
'haldenseren': ('haldenser',),
'haldenserer': ('haldenser',),
'haldenserne': ('haldenser',),
'haldsbukk': ('haldsbukk',),
'haldsbukken': ('haldsbukk',),
'haldsbukkene': ('haldsbukk',),
'haldsbukker': ('haldsbukk',),
'haldstid': ('haldstid',),
'haldstida': ('haldstid',),
'haldstiden': ('haldstid',),
'haldstidene': ('haldstid',),
'haldstider': ('haldstid',),
'hale': ('hale',),
'halen': ('hale',),
'halene': ('hale',),
'haler': ('hale',),
'halebein': ('halebein',),
'halebeina': ('halebein',),
'halebeinene': ('halebein',),
'halebeinet': ('halebein',),
'haleben': ('haleben',),
'halebena': ('haleben',),
'halebenene': ('haleben',),
'halebenet': ('haleben',),
'halefinna': ('halefinne',),
'halefinne': ('halefinne',),
'halefinnen': ('halefinne',),
'halefinnene': ('halefinne',),
'halefinner': ('halefinne',),
'halegatt': ('halegatt',),
'halegatta': ('halegatt',),
'halegattene': ('halegatt',),
'halegattet': ('halegatt',),
'haleheng': ('haleheng',),
'halehenga': ('haleheng',),
'halehengene': ('haleheng',),
'halehenget': ('haleheng',),
'halepadda': ('halepadde',),
'halepadde': ('halepadde',),
'halepadden': ('halepadde',),
'halepaddene': ('halepadde',),
'halepadder': ('halepadde',),
'haleparti': ('haleparti',),
'halepartia': ('haleparti',),
'halepartiene': ('haleparti',),
'halepartier': ('haleparti',),
'halepartiet': ('haleparti',),
'haleplan': ('haleplan',),
'haleplana': ('haleplan',),
'haleplanene': ('haleplan',),
'haleplanet': ('haleplan',),
'halereim': ('halereim',),
'halereima': ('halereim',),
'halereimen': ('halereim',),
'halereimene': ('halereim',),
'halereimer': ('halereim',),
'halerem': ('halerem',),
'haleremma': ('halerem',),
'haleremmen': ('halerem',),
'haleremmene': ('halerem',),
'haleremmer': ('halerem',),
'haletipp': ('haletipp',),
'haletippen': ('haletipp',),
'haletippene': ('haletipp',),
'haletipper': ('haletipp',),
'halevirvel': ('halevirvel',),
'halevirvelen': ('halevirvel',),
'halevirvlene': ('halevirvel',),
'halevirvler': ('halevirvel',),
'half': ('half',),
'halfen': ('half',),
'halfene': ('half',),
'halfer': ('half',),
'halfback': ('halfback',),
'halfbacken': ('halfback',),
'halfbackene': ('halfback',),
'halfbacker': ('halfback',),
'halfrekka': ('halfrekke',),
'halfrekke': ('halfrekke',),
'halfrekken': ('halfrekke',),
'halfrekkene': ('halfrekke',),
'halfrekker': ('halfrekke',),
'halgatt': ('halgatt',),
'halgatta': ('halgatt',),
'halgattene': ('halgatt',),
'halgattet': ('halgatt',),
'haling': ('haling',),
'halinga': ('haling',),
'halingen': ('haling',),
'halingene': ('haling',),
'halinger': ('haling',),
'halingsbåt': ('halingsbåt',),
'halingsbåten': ('halingsbåt',),
'halingsbåtene': ('halingsbåt',),
'halingsbåter': ('halingsbåt',),
'halingsdrift': ('halingsdrift',),
'halingsdrifta': ('halingsdrift',),
'halingsdriften': ('halingsdrift',),
'halingsdriftene': ('halingsdrift',),
'halingsdrifter': ('halingsdrift',),
'halitose': ('halitose',),
'halitosen': ('halitose',),
'halitosene': ('halitose',),
'halitoser': ('halitose',),
'hall': ('hall',),
'hallen': ('hall',),
'hallene': ('hall',),
'haller': ('hall',),
'hall': ('hall',),
'hallen': ('hall',),
'hallene': ('hall',),
'haller': ('hall',),
'hall': ('hall',),
'halla': ('hall',),
'hallene': ('hall',),
'hallet': ('hall',),
'halleluja': ('halleluja',),
'hallelujaene': ('halleluja',),
'hallelujaer': ('halleluja',),
'hallelujaet': ('halleluja',),
'hallelujarop': ('hallelujarop',),
'hallelujaropa': ('hallelujarop',),
'hallelujaropene': ('hallelujarop',),
'hallelujaropet': ('hallelujarop',),
'hallelujasang': ('hallelujasang',),
'hallelujasangen': ('hallelujasang',),
'hallelujasangene': ('hallelujasang',),
'hallelujasanger': ('hallelujasang',),
'hallik': ('hallik',),
'halliken': ('hallik',),
'hallikene': ('hallik',),
'halliker': ('hallik',),
'hallikvirksomhet': ('hallikvirksomhet',),
'hallikvirksomheta': ('hallikvirksomhet',),
'hallikvirksomheten': ('hallikvirksomhet',),
'hallikvirksomhetene': ('hallikvirksomhet',),
'hallikvirksomheter': ('hallikvirksomhet',),
'halling': ('halling',),
'hallingen': ('halling',),
'hallingene': ('halling',),
'hallinger': ('halling',),
'hallingdans': ('hallingdans',),
'hallingdansen': ('hallingdans',),
'hallingdansene': ('hallingdans',),
'hallingdanser': ('hallingdans',),
'hallingdanser': ('hallingdanser',),
'hallingdansere': ('hallingdanser',),
'hallingdanseren': ('hallingdanser',),
'hallingdanserer': ('hallingdanser',),
'hallingdanserne': ('hallingdanser',),
'hallingdøl': ('hallingdøl',),
'hallingdølen': ('hallingdøl',),
'hallingdølene': ('hallingdøl',),
'hallingdøler': ('hallingdøl',),
'hallingkast': ('hallingkast',),
'hallingkasta': ('hallingkast',),
'hallingkastene': ('hallingkast',),
'hallingkastet': ('hallingkast',),
'hallingslått': ('hallingslått',),
'hallingslåtten': ('hallingslått',),
'hallingslåttene': ('hallingslått',),
'hallingslåtter': ('hallingslått',),
'hallo': ('hallo',),
'halloa': ('hallo',),
'halloene': ('hallo',),
'halloer': ('hallo',),
'halloet': ('hallo',),
'hallodama': ('hallodame',),
'hallodame': ('hallodame',),
'hallodamen': ('hallodame',),
'hallodamene': ('hallodame',),
'hallodamer': ('hallodame',),
'halloi': ('halloi',),
'halloien': ('halloi',),
'halloiene': ('halloi',),
'halloier': ('halloi',),
'halloi': ('halloi',),
'halloien': ('halloi',),
'halloiene': ('halloi',),
'halloier': ('halloi',),
'hallomann': ('hallomann',),
'hallomannen': ('hallomann',),
'hallomenn': ('hallomann',),
'hallomennene': ('hallomann',),
'hallusinasjon': ('hallusinasjon',),
'hallusinasjonen': ('hallusinasjon',),
'hallusinasjonene': ('hallusinasjon',),
'hallusinasjoner': ('hallusinasjon',),
'hallusinogen': ('hallusinogen',),
'hallusinogena': ('hallusinogen',),
'hallusinogenene': ('hallusinogen',),
'hallusinogener': ('hallusinogen',),
'hallusinogenet': ('hallusinogen',),
'hallvardsmess': ('hallvardsmess',),
'hallvardsmesse': ('hallvardsmesse',),
'hallvardsok': ('hallvardsok',),
'halm': ('halm',),
'halmen': ('halm',),
'halmene': ('halm',),
'halmer': ('halm',),
'halma': ('halma',),
'halmaen': ('halma',),
'halmaene': ('halma',),
'halmaer': ('halma',),
'halmhakk': ('halmhakk',),
'halmhakka': ('halmhakk',),
'halmhakkene': ('halmhakk',),
'halmhakket': ('halmhakk',),
'halmhatt': ('halmhatt',),
'halmhatten': ('halmhatt',),
'halmhattene': ('halmhatt',),
'halmhatter': ('halmhatt',),
'halmmadrass': ('halmmadrass',),
'halmmadrassen': ('halmmadrass',),
'halmmadrassene': ('halmmadrass',),
'halmmadrasser': ('halmmadrass',),
'halmmatta': ('halmmatte',),
'halmmatte': ('halmmatte',),
'halmmatten': ('halmmatte',),
'halmmattene': ('halmmatte',),
'halmmatter': ('halmmatte',),
'halmstrå': ('halmstrå',),
'halmstråa': ('halmstrå',),
'halmstråene': ('halmstrå',),
'halmstrået': ('halmstrå',),
'halmtak': ('halmtak',),
'halmtaka': ('halmtak',),
'halmtakene': ('halmtak',),
'halmtaket': ('halmtak',),
'halo': ('halo',),
'haloen': ('halo',),
'haloene': ('halo',),
'haloer': ('halo',),
'halofytt': ('halofytt',),
'halofytten': ('halofytt',),
'halofyttene': ('halofytt',),
'halofytter': ('halofytt',),
'halogen': ('halogen',),
'halogena': ('halogen',),
'halogenene': ('halogen',),
'halogener': ('halogen',),
'halogenet': ('halogen',),
'halogenlampa': ('halogenlampe',),
'halogenlampe': ('halogenlampe',),
'halogenlampen': ('halogenlampe',),
'halogenlampene': ('halogenlampe',),
'halogenlamper': ('halogenlampe',),
'haloi': ('haloi',),
'haloien': ('haloi',),
'haloiene': ('haloi',),
'haloier': ('haloi',),
'haloi': ('haloi',),
'haloien': ('haloi',),
'haloiene': ('haloi',),
'haloier': ('haloi',),
'hals': ('hals',),
'halsen': ('hals',),
'halsene': ('hals',),
'halser': ('hals',),
'halsband': ('halsband',),
'halsbanda': ('halsband',),
'halsbandene': ('halsband',),
'halsbandet': ('halsband',),
'halsbrann': ('halsbrann',),
'halsbrannen': ('halsbrann',),
'halsbrannene': ('halsbrann',),
'halsbranner': ('halsbrann',),
'halsbyll': ('halsbyll',),
'halsbyllen': ('halsbyll',),
'halsbyllene': ('halsbyll',),
'halsbyller': ('halsbyll',),
'halsbånd': ('halsbånd',),
'halsbånda': ('halsbånd',),
'halsbåndene': ('halsbånd',),
'halsbåndet': ('halsbånd',),
'halseitel': ('halseitel',),
'halseitelen': ('halseitel',),
'halseitlene': ('halseitel',),
'halseitler': ('halseitel',),
'halsesjuka': ('halsesjuke',),
'halsesjuke': ('halsesjuke',),
'halsesjuken': ('halsesjuke',),
'halsesjukene': ('halsesjuke',),
'halsesjuker': ('halsesjuke',),
'halsesyka': ('halsesyke',),
'halsesyke': ('halsesyke',),
'halsesyken': ('halsesyke',),
'halsesykene': ('halsesyke',),
'halsesyker': ('halsesyke',),
'halsgrop': ('halsgrop',),
'halsgropa': ('halsgrop',),
'halsgropen': ('halsgrop',),
'halsgropene': ('halsgrop',),
'halsgroper': ('halsgrop',),
'halsitle': ('halsitle',),
'halsitlen': ('halsitle',),
'halsitlene': ('halsitle',),
'halsitler': ('halsitle',),
'halskatarr': ('halskatarr',),
'halskatarren': ('halskatarr',),
'halskatarrene': ('halskatarr',),
'halskatarrer': ('halskatarr',),
'halskjertel': ('halskjertel',),
'halskjertelen': ('halskjertel',),
'halskjertlene': ('halskjertel',),
'halskjertler': ('halskjertel',),
'halsklut': ('halsklut',),
'halskluten': ('halsklut',),
'halsklutene': ('halsklut',),
'halskluter': ('halsklut',),
'halskrage': ('halskrage',),
'halskragen': ('halskrage',),
'halskragene': ('halskrage',),
'halskrager': ('halskrage',),
'halskrave': ('halskrave',),
'halskraven': ('halskrave',),
'halskravene': ('halskrave',),
'halskraver': ('halskrave',),
'halsmandel': ('halsmandel',),
'halsmandelen': ('halsmandel',),
'halsmandlene': ('halsmandel',),
'halsmandler': ('halsmandel',),
'halspastill': ('halspastill',),
'halspastillen': ('halspastill',),
'halspastillene': ('halspastill',),
'halspastiller': ('halspastill',),
'halspulsåra': ('halspulsåre',),
'halspulsåre': ('halspulsåre',),
'halspulsåren': ('halspulsåre',),
'halspulsårene': ('halspulsåre',),
'halspulsårer': ('halspulsåre',),
'halsrett': ('halsrett',),
'halsretten': ('halsrett',),
'halsrettene': ('halsrett',),
'halsretter': ('halsrett',),
'halstørkle': ('halstørkle',),
'halstørkleet': ('halstørkle',),
'halstørklær': ('halstørkle',),
'halstørklærne': ('halstørkle',),
'halsvirvel': ('halsvirvel',),
'halsvirvelen': ('halsvirvel',),
'halsvirvlene': ('halsvirvel',),
'halsvirvler': ('halsvirvel',),
'haltefanden': ('haltefanden',),
'haltepink': ('haltepink',),
'haltepinken': ('haltepink',),
'haltepinkene': ('haltepink',),
'haltepinker': ('haltepink',),
'halunk': ('halunk',),
'halunken': ('halunk',),
'halunkene': ('halunk',),
'halunker': ('halunk',),
'halvapa': ('halvape',),
'halvape': ('halvape',),
'halvapen': ('halvape',),
'halvapene': ('halvape',),
'halvaper': ('halvape',),
'halvbind': ('halvbind',),
'halvbinda': ('halvbind',),
'halvbindene': ('halvbind',),
'halvbindet': ('halvbind',),
'halvbjørn': ('halvbjørn',),
'halvbjørnen': ('halvbjørn',),
'halvbjørnene': ('halvbjørn',),
'halvbjørner': ('halvbjørn',),
'halvblodshest': ('halvblodshest',),
'halvblodshesten': ('halvblodshest',),
'halvblodshestene': ('halvblodshest',),
'halvblodshester': ('halvblodshest',),
'halvbror': ('halvbror',),
'halvbroren': ('halvbror',),
'halvbrødre': ('halvbror',),
'halvbrødrene': ('halvbror',),
'halvbusk': ('halvbusk',),
'halvbusken': ('halvbusk',),
'halvbuskene': ('halvbusk',),
'halvbusker': ('halvbusk',),
'halvdagsstilling': ('halvdagsstilling',),
'halvdagsstillinga': ('halvdagsstilling',),
'halvdagsstillingen': ('halvdagsstilling',),
'halvdagsstillingene': ('halvdagsstilling',),
'halvdagsstillinger': ('halvdagsstilling',),
'halvdekk': ('halvdekk',),
'halvdekka': ('halvdekk',),
'halvdekkene': ('halvdekk',),
'halvdekket': ('halvdekk',),
'halvdekker': ('halvdekker',),
'halvdekkere': ('halvdekker',),
'halvdekkeren': ('halvdekker',),
'halvdekkerer': ('halvdekker',),
'halvdekkerne': ('halvdekker',),
'halvdel': ('halvdel',),
'halvdelen': ('halvdel',),
'halvdelene': ('halvdel',),
'halvdeler': ('halvdel',),
'halvdrøm': ('halvdrøm',),
'halvdrømmen': ('halvdrøm',),
'halvdrømmene': ('halvdrøm',),
'halvdrømmer': ('halvdrøm',),
'halvdøs': ('halvdøs',),
'halvdøsen': ('halvdøs',),
'halvdøsene': ('halvdøs',),
'halvdøser': ('halvdøs',),
'halva': ('halve',),
'halve': ('halve',),
'halven': ('halve',),
'halvene': ('halve',),
'halver': ('halve',),
'halvedelstein': ('halvedelstein',),
'halvedelsteinen': ('halvedelstein',),
'halvedelsteinene': ('halvedelstein',),
'halvedelsteiner': ('halvedelstein',),
'halvedelsten': ('halvedelsten',),
'halvedelstenen': ('halvedelsten',),
'halvedelstenene': ('halvedelsten',),
'halvedelstener': ('halvedelsten',),
'halvemål': ('halvemål',),
'halvemåla': ('halvemål',),
'halvemålene': ('halvemål',),
'halvemålet': ('halvemål',),
'halveringstid': ('halveringstid',),
'halveringstida': ('halveringstid',),
'halveringstiden': ('halveringstid',),
'halveringstidene': ('halveringstid',),
'halveringstider': ('halveringstid',),
'halvfabrikat': ('halvfabrikat',),
'halvfabrikata': ('halvfabrikat',),
'halvfabrikatene': ('halvfabrikat',),
'halvfabrikater': ('halvfabrikat',),
'halvfabrikatet': ('halvfabrikat',),
'halvfigur': ('halvfigur',),
'halvfiguren': ('halvfigur',),
'halvfigurene': ('halvfigur',),
'halvfigurer': ('halvfigur',),
'halvflaska': ('halvflaske',),
'halvflaske': ('halvflaske',),
'halvflasken': ('halvflaske',),
'halvflaskene': ('halvflaske',),
'halvflasker': ('halvflaske',),
'halvgras': ('halvgras',),
'halvgrasa': ('halvgras',),
'halvgrasene': ('halvgras',),
'halvgraset': ('halvgras',),
'halvgress': ('halvgress',),
'halvgressa': ('halvgress',),
'halvgressene': ('halvgress',),
'halvgresset': ('halvgress',),
'halvgud': ('halvgud',),
'halvguden': ('halvgud',),
'halvgudene': ('halvgud',),
'halvguder': ('halvgud',),
'halvhet': ('halvhet',),
'halvheta': ('halvhet',),
'halvheten': ('halvhet',),
'halvhetene': ('halvhet',),
'halvheter': ('halvhet',),
'halvkilo': ('halvkilo',),
'halvkiloa': ('halvkilo',),
'halvkiloen': ('halvkilo',),
'halvkiloene': ('halvkilo',),
'halvkiloet': ('halvkilo',),
'halvkula': ('halvkule',),
'halvkule': ('halvkule',),
'halvkulen': ('halvkule',),
'halvkulene': ('halvkule',),
'halvkuler': ('halvkule',),
'halvleder': ('halvleder',),
'halvledere': ('halvleder',),
'halvlederen': ('halvleder',),
'halvlederer': ('halvleder',),
'halvlederne': ('halvleder',),
'halvliter': ('halvliter',),
'halvlitere': ('halvliter',),
'halvliteren': ('halvliter',),
'halvliterer': ('halvliter',),
'halvliterne': ('halvliter',),
'halvlys': ('halvlys',),
'halvlysa': ('halvlys',),
'halvlysene': ('halvlys',),
'halvlyset': ('halvlys',),
'halvlys': ('halvlys',),
'halvlysa': ('halvlys',),
'halvlysene': ('halvlys',),
'halvlyset': ('halvlys',),
'halvmeter': ('halvmeter',),
'halvmetere': ('halvmeter',),
'halvmeteren': ('halvmeter',),
'halvmeterer': ('halvmeter',),
'halvmeterne': ('halvmeter',),
'halvmåne': ('halvmåne',),
'halvmånen': ('halvmåne',),
'halvmånene': ('halvmåne',),
'halvmåner': ('halvmåne',),
'halvmørka': ('halvmørke',),
'halvmørke': ('halvmørke',),
'halvmørkene': ('halvmørke',),
'halvmørker': ('halvmørke',),
'halvmørket': ('halvmørke',),
'halvnote': ('halvnote',),
'halvnoten': ('halvnote',),
'halvnotene': ('halvnote',),
'halvnoter': ('halvnote',),
'halvpart': ('halvpart',),
'halvparten': ('halvpart',),
'halvpartene': ('halvpart',),
'halvparter': ('halvpart',),
'halvpensjon': ('halvpensjon',),
'halvpensjonen': ('halvpensjon',),
'halvpensjonene': ('halvpensjon',),
'halvpensjoner': ('halvpensjon',),
'halvrim': ('halvrim',),
'halvrima': ('halvrim',),
'halvrimene': ('halvrim',),
'halvrimet': ('halvrim',),
'halvsirkel': ('halvsirkel',),
'halvsirkelen': ('halvsirkel',),
'halvsirklene': ('halvsirkel',),
'halvsirkler': ('halvsirkel',),
'halvskjerm': ('halvskjerm',),
'halvskjermen': ('halvskjerm',),
'halvskjermene': ('halvskjerm',),
'halvskjermer': ('halvskjerm',),
'halvslank': ('halvslank',),
'halvsnylter': ('halvsnylter',),
'halvsnyltere': ('halvsnylter',),
'halvsnylteren': ('halvsnylter',),
'halvsnylterer': ('halvsnylter',),
'halvsnylterne': ('halvsnylter',),
'halvspenn': ('halvspenn',),
'halvspenna': ('halvspenn',),
'halvspennene': ('halvspenn',),
'halvspennet': ('halvspenn',),
'halvstaut': ('halvstaut',),
'halvstikk': ('halvstikk',),
'halvstikka': ('halvstikk',),
'halvstikkene': ('halvstikk',),
'halvstikket': ('halvstikk',),
'halvstrømpa': ('halvstrømpe',),
'halvstrømpe': ('halvstrømpe',),
'halvstrømpen': ('halvstrømpe',),
'halvstrømpene': ('halvstrømpe',),
'halvstrømper': ('halvstrømpe',),
'halvsåle': ('halvsåle',),
'halvsålen': ('halvsåle',),
'halvsålene': ('halvsåle',),
'halvsåler': ('halvsåle',),
'halvsøsken': ('halvsøsken',),
'halvsøskena': ('halvsøsken',),
'halvsøskenet': ('halvsøsken',),
'halvsøsknene': ('halvsøsken',),
'halvsøster': ('halvsøster',),
'halvsøstera': ('halvsøster',),
'halvsøsteren': ('halvsøster',),
'halvsøstre': ('halvsøster',),
'halvsøstrene': ('halvsøster',),
'halvsøstrer': ('halvsøster',),
'halvsøvn': ('halvsøvn',),
'halvsøvnen': ('halvsøvn',),
'halvsøvnene': ('halvsøvn',),
'halvsøvner': ('halvsøvn',),
'halvt': ('halvt',),
'halvten': ('halvt',),
'halvtene': ('halvt',),
'halvter': ('halvt',),
'halvtak': ('halvtak',),
'halvtaka': ('halvtak',),
'halvtakene': ('halvtak',),
'halvtaket': ('halvtak',),
'halvtid': ('halvtid',),
'halvtida': ('halvtid',),
'halvtiden': ('halvtid',),
'halvtidene': ('halvtid',),
'halvtider': ('halvtid',),
'halvtime': ('halvtime',),
'halvtimen': ('halvtime',),
'halvtimene': ('halvtime',),
'halvtimer': ('halvtime',),
'halvtone': ('halvtone',),
'halvtonen': ('halvtone',),
'halvtonene': ('halvtone',),
'halvtoner': ('halvtone',),
'halvtonetrinn': ('halvtonetrinn',),
'halvtonetrinna': ('halvtonetrinn',),
'halvtonetrinnene': ('halvtonetrinn',),
'halvtonetrinnet': ('halvtonetrinn',),
'halvtynna': ('halvtynne',),
'halvtynne': ('halvtynne',),
'halvtynnen': ('halvtynne',),
'halvtynnene': ('halvtynne',),
'halvtynner': ('halvtynne',),
'halvtønna': ('halvtønne',),
'halvtønne': ('halvtønne',),
'halvtønnen': ('halvtønne',),
'halvtønnene': ('halvtønne',),
'halvtønner': ('halvtønne',),
'halvull': ('halvull',),
'halvulla': ('halvull',),
'halvullen': ('halvull',),
'halvullene': ('halvull',),
'halvuller': ('halvull',),
'halvveg': ('halvveg',),
'halvvegen': ('halvveg',),
'halvvegene': ('halvveg',),
'halvveger': ('halvveg',),
'halvvei': ('halvvei',),
'halvveien': ('halvvei',),
'halvveiene': ('halvvei',),
'halvveier': ('halvvei',),
'halvvokal': ('halvvokal',),
'halvvokalen': ('halvvokal',),
'halvvokalene': ('halvvokal',),
'halvvokaler': ('halvvokal',),
'halvår': ('halvår',),
'halvåra': ('halvår',),
'halvårene': ('halvår',),
'halvåret': ('halvår',),
'halvårsoppgjør': ('halvårsoppgjør',),
'halvårsoppgjøra': ('halvårsoppgjør',),
'halvårsoppgjørene': ('halvårsoppgjør',),
'halvårsoppgjøret': ('halvårsoppgjør',),
'halvårsregnskap': ('halvårsregnskap',),
'halvårsregnskapa': ('halvårsregnskap',),
'halvårsregnskapene': ('halvårsregnskap',),
'halvårsregnskaper': ('halvårsregnskap',),
'halvårsregnskapet': ('halvårsregnskap',),
'halvårsrekneskap': ('halvårsrekneskap',),
'halvårsrekneskapen': ('halvårsrekneskap',),
'halvårsrekneskapene': ('halvårsrekneskap',),
'halvårsrekneskaper': ('halvårsrekneskap',),
'halvøy': ('halvøy',),
'halvøya': ('halvøy',),
'halvøyen': ('halvøy',),
'halvøyene': ('halvøy',),
'halvøyer': ('halvøy',),
'ham': ('ham',),
'hammen': ('ham',),
'hammene': ('ham',),
'hammer': ('ham',),
'hamarsing': ('hamarsing',),
'hamarsingen': ('hamarsing',),
'hamarsingene': ('hamarsing',),
'hamarsinger': ('hamarsing',),
'hambo': ('hambo',),
'hamboen': ('hambo',),
'hamboene': ('hambo',),
'hamboer': ('hambo',),
'hamburgblått': ('hamburgblått',),
'hamburger': ('hamburger',),
'hamburgere': ('hamburger',),
'hamburgeren': ('hamburger',),
'hamburgerer': ('hamburger',),
'hamburgerne': ('hamburger',),
'hamburgerblått': ('hamburgerblått',),
'hamburgerrygg': ('hamburgerrygg',),
'hamburgerryggen': ('hamburgerrygg',),
'hamburgerryggene': ('hamburgerrygg',),
'hamburgerrygger': ('hamburgerrygg',),
'hamingja': ('hamingje',),
'hamingje': ('hamingje',),
'hamingjen': ('hamingje',),
'hamingjene': ('hamingje',),
'hamingjer': ('hamingje',),
'hamitt': ('hamitt',),
'hamitten': ('hamitt',),
'hamittene': ('hamitt',),
'hamitter': ('hamitt',),
'hamleband': ('hamleband',),
'hamlebanda': ('hamleband',),
'hamlebandene': ('hamleband',),
'hamlebandet': ('hamleband',),
'hamlebånd': ('hamlebånd',),
'hamlebånda': ('hamlebånd',),
'hamlebåndene': ('hamlebånd',),
'hamlebåndet': ('hamlebånd',),
'hamlett': ('hamlett',),
'hamletten': ('hamlett',),
'hamlettene': ('hamlett',),
'hamletter': ('hamlett',),
'hamløper': ('hamløper',),
'hamløpere': ('hamløper',),
'hamløperen': ('hamløper',),
'hamløperer': ('hamløper',),
'hamløperne': ('hamløper',),
'hammar': ('hammar',),
'hammaren': ('hammar',),
'hamrene': ('hammar',),
'hamrer': ('hammar',),
'hammarslag': ('hammarslag',),
'hammarslaga': ('hammarslag',),
'hammarslagene': ('hammarslag',),
'hammarslaget': ('hammarslag',),
'hammarverk': ('hammarverk',),
'hammarverka': ('hammarverk',),
'hammarverkene': ('hammarverk',),
'hammarverker': ('hammarverk',),
'hammarverket': ('hammarverk',),
'hammer': ('hammer',),
'hammere': ('hammer',),
'hammeren': ('hammer',),
'hammerer': ('hammer',),
'hammerne': ('hammer',),
'hamrene': ('hammer',),
'hamrer': ('hammer',),
'hammerfesting': ('hammerfesting',),
'hammerfestingen': ('hammerfesting',),
'hammerfestingene': ('hammerfesting',),
'hammerfestinger': ('hammerfesting',),
'hammerslag': ('hammerslag',),
'hammerslaga': ('hammerslag',),
'hammerslagene': ('hammerslag',),
'hammerslaget': ('hammerslag',),
'hammerverk': ('hammerverk',),
'hammerverka': ('hammerverk',),
'hammerverkene': ('hammerverk',),
'hammerverker': ('hammerverk',),
'hammerverket': ('hammerverk',),
'hammock': ('hammock',),
'hammocken': ('hammock',),
'hammockene': ('hammock',),
'hammocker': ('hammock',),
'hammondorgel': ('hammondorgel',),
'hammondorgelet': ('hammondorgel',),
'hammondorgla': ('hammondorgel',),
'hammondorglene': ('hammondorgel',),
'hammondorgler': ('hammondorgel',),
'hammondorglet': ('hammondorgel',),
'hamn': ('hamn',),
'hamna': ('hamn',),
'hamnen': ('hamn',),
'hamnene': ('hamn',),
'hamner': ('hamn',),
'hamn': ('hamn',),
'hamna': ('hamn',),
'hamnen': ('hamn',),
'hamnene': ('hamn',),
'hamner': ('hamn',),
'hamn': ('hamn',),
'hamna': ('hamn',),
'hamnen': ('hamn',),
'hamnene': ('hamn',),
'hamner': ('hamn',),
'hamneanlegg': ('hamneanlegg',),
'hamneanlegga': ('hamneanlegg',),
'hamneanleggene': ('hamneanlegg',),
'hamneanlegget': ('hamneanlegg',),
'hamneanlegg': ('hamneanlegg',),
'hamneanlegga': ('hamneanlegg',),
'hamneanleggene': ('hamneanlegg',),
'hamneanlegget': ('hamneanlegg',),
'hamnearbeider': ('hamnearbeider',),
'hamnearbeidere': ('hamnearbeider',),
'hamnearbeideren': ('hamnearbeider',),
'hamnearbeiderer': ('hamnearbeider',),
'hamnearbeiderne': ('hamnearbeider',),
'hamnearbeider': ('hamnearbeider',),
'hamnearbeidere': ('hamnearbeider',),
'hamnearbeideren': ('hamnearbeider',),
'hamnearbeiderer': ('hamnearbeider',),
'hamnearbeiderne': ('hamnearbeider',),
'hamneavgift': ('hamneavgift',),
'hamneavgifta': ('hamneavgift',),
'hamneavgiften': ('hamneavgift',),
'hamneavgiftene': ('hamneavgift',),
'hamneavgifter': ('hamneavgift',),
'hamneavgift': ('hamneavgift',),
'hamneavgifta': ('hamneavgift',),
'hamneavgiften': ('hamneavgift',),
'hamneavgiftene': ('hamneavgift',),
'hamneavgifter': ('hamneavgift',),
'hamnebasseng': ('hamnebasseng',),
'hamnebassenga': ('hamnebasseng',),
'hamnebassengene': ('hamnebasseng',),
'hamnebassenger': ('hamnebasseng',),
'hamnebassenget': ('hamnebasseng',),
'hamnebasseng': ('hamnebasseng',),
'hamnebassenga': ('hamnebasseng',),
'hamnebassengene': ('hamnebasseng',),
'hamnebassenger': ('hamnebasseng',),
'hamnebassenget': ('hamnebasseng',),
'hamneby': ('hamneby',),
'hamnebyen': ('hamneby',),
'hamnebyene': ('hamneby',),
'hamnebyer': ('hamneby',),
'hamneby': ('hamneby',),
'hamnebyen': ('hamneby',),
'hamnebyene': ('hamneby',),
'hamnebyer': ('hamneby',),
'hamnefogd': ('hamnefogd',),
'hamnefogden': ('hamnefogd',),
'hamnefogdene': ('hamnefogd',),
'hamnefogder': ('hamnefogd',),
'hamnefogd': ('hamnefogd',),
'hamnefogden': ('hamnefogd',),
'hamnefogdene': ('hamnefogd',),
'hamnefogder': ('hamnefogd',),
'hamnefut': ('hamnefut',),
'hamnefuten': ('hamnefut',),
'hamnefutene': ('hamnefut',),
'hamnefuter': ('hamnefut',),
'hamnegang': ('hamnegang',),
'hamnegangen': ('hamnegang',),
'hamnegangene': ('hamnegang',),
'hamneganger': ('hamnegang',),
'hamnehage': ('hamnehage',),
'hamnehagen': ('hamnehage',),
'hamnehagene': ('hamnehage',),
'hamnehager': ('hamnehage',),
'hamnekontor': ('hamnekontor',),
'hamnekontora': ('hamnekontor',),
'hamnekontorene': ('hamnekontor',),
'hamnekontorer': ('hamnekontor',),
'hamnekontoret': ('hamnekontor',),
'hamnekontor': ('hamnekontor',),
'hamnekontora': ('hamnekontor',),
'hamnekontorene': ('hamnekontor',),
'hamnekontorer': ('hamnekontor',),
'hamnekontoret': ('hamnekontor',),
'hamnelos': ('hamnelos',),
'hamnelosen': ('hamnelos',),
'hamnelosene': ('hamnelos',),
'hamneloser': ('hamnelos',),
'hamnelos': ('hamnelos',),
'hamnelosen': ('hamnelos',),
'hamnelosene': ('hamnelos',),
'hamneloser': ('hamnelos',),
'hamnevesen': ('hamnevesen',),
'hamnevesena': ('hamnevesen',),
'hamnevesenene': ('hamnevesen',),
'hamnevesener': ('hamnevesen',),
'hamnevesenet': ('hamnevesen',),
'hamnevesen': ('hamnevesen',),
'hamnevesena': ('hamnevesen',),
'hamnevesenene': ('hamnevesen',),
'hamnevesener': ('hamnevesen',),
'hamnevesenet': ('hamnevesen',),
'hamning': ('hamning',),
'hamninga': ('hamning',),
'hamningen': ('hamning',),
'hamningene': ('hamning',),
'hamninger': ('hamning',),
'hamningsfe': ('hamningsfe',),
'hamningsfea': ('hamningsfe',),
'hamningsfeene': ('hamningsfe',),
'hamningsfeet': ('hamningsfe',),
'hamp': ('hamp',),
'hampen': ('hamp',),
'hampene': ('hamp',),
'hamper': ('hamp',),
'hampefamilie': ('hampefamilie',),
'hampefamilien': ('hampefamilie',),
'hampefamiliene': ('hampefamilie',),
'hampefamilier': ('hampefamilie',),
'hampefrø': ('hampefrø',),
'hampefrøa': ('hampefrø',),
'hampefrøene': ('hampefrø',),
'hampefrøet': ('hampefrø',),
'hampeolja': ('hampeolje',),
'hampeolje': ('hampeolje',),
'hampeoljen': ('hampeolje',),
'hampeoljene': ('hampeolje',),
'hampeoljer': ('hampeolje',),
'hampetau': ('hampetau',),
'hampetaua': ('hampetau',),
'hampetauene': ('hampetau',),
'hampetauer': ('hampetau',),
'hampetauet': ('hampetau',),
'hampolja': ('hampolje',),
'hampolje': ('hampolje',),
'hampoljen': ('hampolje',),
'hampoljene': ('hampolje',),
'hampoljer': ('hampolje',),
'hams': ('hams',),
'hamsen': ('hams',),
'hamsene': ('hams',),
'hamser': ('hams',),
'hamskifta': ('hamskifte',),
'hamskifte': ('hamskifte',),
'hamskiftene': ('hamskifte',),
'hamskifter': ('hamskifte',),
'hamskiftet': ('hamskifte',),
'hamster': ('hamster',),
'hamstere': ('hamster',),
'hamsteren': ('hamster',),
'hamsterer': ('hamster',),
'hamsterne': ('hamster',),
'hamstre': ('hamster',),
'hamstrene': ('hamster',),
'hamstrer': ('hamster',),
'handalfabet': ('handalfabet',),
'handalfabeta': ('handalfabet',),
'handalfabetene': ('handalfabet',),
'handalfabeter': ('handalfabet',),
'handalfabetet': ('handalfabet',),
'handarbeid': ('handarbeid',),
'handarbeida': ('handarbeid',),
'handarbeidene': ('handarbeid',),
'handarbeider': ('handarbeid',),
'handarbeidet': ('handarbeid',),
'handbagasje': ('handbagasje',),
'handbagasjen': ('handbagasje',),
'handbagasjene': ('handbagasje',),
'handbagasjer': ('handbagasje',),
'handball': ('handball',),
'handballen': ('handball',),
'handballene': ('handball',),
'handballer': ('handball',),
'handballkamp': ('handballkamp',),
'handballkampen': ('handballkamp',),
'handballkampene': ('handballkamp',),
'handballkamper': ('handballkamp',),
'handballspeller': ('handballspeller',),
'handballspellere': ('handballspeller',),
'handballspelleren': ('handballspeller',),
'handballspellerer': ('handballspeller',),
'handballspellerne': ('handballspeller',),
'handballspiller': ('handballspiller',),
'handballspillere': ('handballspiller',),
'handballspilleren': ('handballspiller',),
'handballspillerer': ('handballspiller',),
'handballspillerne': ('handballspiller',),
'handbevegelse': ('handbevegelse',),
'handbevegelsen': ('handbevegelse',),
'handbevegelsene': ('handbevegelse',),
'handbevegelser': ('handbevegelse',),
'handbibliotek': ('handbibliotek',),
'handbiblioteka': ('handbibliotek',),
'handbibliotekene': ('handbibliotek',),
'handbiblioteker': ('handbibliotek',),
'handbiblioteket': ('handbibliotek',),
'handbrekk': ('handbrekk',),
'handbrekka': ('handbrekk',),
'handbrekkene': ('handbrekk',),
'handbrekket': ('handbrekk',),
'handbrems': ('handbrems',),
'handbremsen': ('handbrems',),
'handbremsene': ('handbrems',),
'handbremser': ('handbrems',),
'handbremsa': ('handbremse',),
'handbremse': ('handbremse',),
'handbremsen': ('handbremse',),
'handbremsene': ('handbremse',),
'handbremser': ('handbremse',),
'handduk': ('handduk',),
'handduken': ('handduk',),
'handdukene': ('handduk',),
'handduker': ('handduk',),
'handel': ('handel',),
'handelen': ('handel',),
'handlene': ('handel',),
'handler': ('handel',),
'handelsavtale': ('handelsavtale',),
'handelsavtalen': ('handelsavtale',),
'handelsavtalene': ('handelsavtale',),
'handelsavtaler': ('handelsavtale',),
'handelsbalanse': ('handelsbalanse',),
'handelsbalansen': ('handelsbalanse',),
'handelsbalansene': ('handelsbalanse',),
'handelsbalanser': ('handelsbalanse',),
'handelsbank': ('handelsbank',),
'handelsbanken': ('handelsbank',),
'handelsbankene': ('handelsbank',),
'handelsbanker': ('handelsbank',),
'handelsbetjent': ('handelsbetjent',),
'handelsbetjenten': ('handelsbetjent',),
'handelsbetjentene': ('handelsbetjent',),
'handelsbetjenter': ('handelsbetjent',),
'handelsblokade': ('handelsblokade',),
'handelsblokaden': ('handelsblokade',),
'handelsblokadene': ('handelsblokade',),
'handelsblokader': ('handelsblokade',),
'handelsbrev': ('handelsbrev',),
'handelsbreva': ('handelsbrev',),
'handelsbrevene': ('handelsbrev',),
'handelsbrever': ('handelsbrev',),
'handelsbrevet': ('handelsbrev',),
'handelsdelegasjon': ('handelsdelegasjon',),
'handelsdelegasjonen': ('handelsdelegasjon',),
'handelsdelegasjonene': ('handelsdelegasjon',),
'handelsdelegasjoner': ('handelsdelegasjon',),
'handelsdepartement': ('handelsdepartement',),
'handelsdepartementa': ('handelsdepartement',),
'handelsdepartementene': ('handelsdepartement',),
'handelsdepartementer': ('handelsdepartement',),
'handelsdepartementet': ('handelsdepartement',),
'handelsdistrikt': ('handelsdistrikt',),
'handelsdistrikta': ('handelsdistrikt',),
'handelsdistriktene': ('handelsdistrikt',),
'handelsdistrikter': ('handelsdistrikt',),
'handelsdistriktet': ('handelsdistrikt',),
'handelsfag': ('handelsfag',),
'handelsfaga': ('handelsfag',),
'handelsfagene': ('handelsfag',),
'handelsfaget': ('handelsfag',),
'handelsfagprøva': ('handelsfagprøve',),
'handelsfagprøve': ('handelsfagprøve',),
'handelsfagprøven': ('handelsfagprøve',),
'handelsfagprøvene': ('handelsfagprøve',),
'handelsfagprøver': ('handelsfagprøve',),
'handelsfelt': ('handelsfelt',),
'handelsfelta': ('handelsfelt',),
'handelsfeltene': ('handelsfelt',),
'handelsfelter': ('handelsfelt',),
'handelsfeltet': ('handelsfelt',),
'handelsflagg': ('handelsflagg',),
'handelsflagga': ('handelsflagg',),
'handelsflaggene': ('handelsflagg',),
'handelsflagget': ('handelsflagg',),
'handelsflåte': ('handelsflåte',),
'handelsflåten': ('handelsflåte',),
'handelsflåtene': ('handelsflåte',),
'handelsflåter': ('handelsflåte',),
'handelsgartner': ('handelsgartner',),
'handelsgartnere': ('handelsgartner',),
'handelsgartneren': ('handelsgartner',),
'handelsgartnerer': ('handelsgartner',),
'handelsgartnerne': ('handelsgartner',),
'handelsgeografi': ('handelsgeografi',),
'handelsgeografien': ('handelsgeografi',),
'handelsgeografiene': ('handelsgeografi',),
'handelsgeografier': ('handelsgeografi',),
'handelsgjødsel': ('handelsgjødsel',),
'handelsgjødselen': ('handelsgjødsel',),
'handelsgjødsla': ('handelsgjødsel',),
'handelsgjødslene': ('handelsgjødsel',),
'handelsgjødsler': ('handelsgjødsel',),
'handelsgymnas': ('handelsgymnas',),
'handelsgymnasa': ('handelsgymnas',),
'handelsgymnasene': ('handelsgymnas',),
'handelsgymnaser': ('handelsgymnas',),
'handelsgymnaset': ('handelsgymnas',),
'handelsgymnasia': ('handelsgymnasium',),
'handelsgymnasiene': ('handelsgymnasium',),
'handelsgymnasier': ('handelsgymnasium',),
'handelsgymnasiet': ('handelsgymnasium',),
'handelsgymnasium': ('handelsgymnasium',),
'handelshus': ('handelshus',),
'handelshusa': ('handelshus',),
'handelshusene': ('handelshus',),
'handelshuset': ('handelshus',),
'handelshøgskole': ('handelshøgskole',),
'handelshøgskolen': ('handelshøgskole',),
'handelshøgskolene': ('handelshøgskole',),
'handelshøgskoler': ('handelshøgskole',),
'handelshøyskole': ('handelshøyskole',),
'handelshøyskolen': ('handelshøyskole',),
'handelshøyskolene': ('handelshøyskole',),
'handelshøyskoler': ('handelshøyskole',),
'handelskalender': ('handelskalender',),
'handelskalendere': ('handelskalender',),
'handelskalenderen': ('handelskalender',),
'handelskalenderer': ('handelskalender',),
'handelskalenderne': ('handelskalender',),
'handelskalendre': ('handelskalender',),
'handelskalendrene': ('handelskalender',),
'handelskalendrer': ('handelskalender',),
'handelskammer': ('handelskammer',),
'handelskammeret': ('handelskammer',),
'handelskamra': ('handelskammer',),
'handelskamre': ('handelskammer',),
'handelskamrene': ('handelskammer',),
'handelskompani': ('handelskompani',),
'handelskompania': ('handelskompani',),
'handelskompaniene': ('handelskompani',),
'handelskompanier': ('handelskompani',),
'handelskompaniet': ('handelskompani',),
'handelskorrespondanse': ('handelskorrespondanse',),
'handelskorrespondansen': ('handelskorrespondanse',),
'handelskorrespondansene': ('handelskorrespondanse',),
'handelskorrespondanser': ('handelskorrespondanse',),
'handelslag': ('handelslag',),
'handelslaga': ('handelslag',),
'handelslagene': ('handelslag',),
'handelslaget': ('handelslag',),
'handelslæra': ('handelslære',),
'handelslære': ('handelslære',),
'handelslæren': ('handelslære',),
'handelslærene': ('handelslære',),
'handelslærer': ('handelslære',),
'handelsmann': ('handelsmann',),
'handelsmannen': ('handelsmann',),
'handelsmenn': ('handelsmann',),
'handelsmennene': ('handelsmann',),
'handelsmarine': ('handelsmarine',),
'handelsmarinen': ('handelsmarine',),
'handelsmarinene': ('handelsmarine',),
'handelsmariner': ('handelsmarine',),
'handelsminister': ('handelsminister',),
'handelsministere': ('handelsminister',),
'handelsministeren': ('handelsminister',),
'handelsministerer': ('handelsminister',),
'handelsministerne': ('handelsminister',),
'handelsministre': ('handelsminister',),
'handelsministrene': ('handelsminister',),
'handelsministrer': ('handelsminister',),
'handelsnæring': ('handelsnæring',),
'handelsnæringa': ('handelsnæring',),
'handelsnæringen': ('handelsnæring',),
'handelsnæringene': ('handelsnæring',),
'handelsnæringer': ('handelsnæring',),
'handelsområda': ('handelsområde',),
'handelsområde': ('handelsområde',),
'handelsområdene': ('handelsområde',),
'handelsområder': ('handelsområde',),
'handelsområdet': ('handelsområde',),
'handelspolitikk': ('handelspolitikk',),
'handelspolitikken': ('handelspolitikk',),
'handelspolitikkene': ('handelspolitikk',),
'handelspolitikker': ('handelspolitikk',),
'handelsregister': ('handelsregister',),
'handelsregisteret': ('handelsregister',),
'handelsregistra': ('handelsregister',),
'handelsregistre': ('handelsregister',),
'handelsregistrene': ('handelsregister',),
'handelsregistret': ('handelsregister',),
'handelsregning': ('handelsregning',),
'handelsregninga': ('handelsregning',),
'handelsregningen': ('handelsregning',),
'handelsregningene': ('handelsregning',),
'handelsregninger': ('handelsregning',),
'handelsreisende': ('handelsreisende',),
'handelsreisenden': ('handelsreisende',),
'handelsreisendene': ('handelsreisende',),
'handelsreisender': ('handelsreisende',),
'handelsrekning': ('handelsrekning',),
'handelsrekninga': ('handelsrekning',),
'handelsrekningen': ('handelsrekning',),
'handelsrekningene': ('handelsrekning',),
'handelsrekninger': ('handelsrekning',),
'handelsrett': ('handelsrett',),
'handelsretten': ('handelsrett',),
'handelsrettene': ('handelsrett',),
'handelsretter': ('handelsrett',),
'handelsselskap': ('handelsselskap',),
'handelsselskapa': ('handelsselskap',),
'handelsselskapene': ('handelsselskap',),
'handelsselskaper': ('handelsselskap',),
'handelsselskapet': ('handelsselskap',),
'handelsskip': ('handelsskip',),
'handelsskipa': ('handelsskip',),
'handelsskipene': ('handelsskip',),
'handelsskipet': ('handelsskip',),
'handelsskole': ('handelsskole',),
'handelsskolen': ('handelsskole',),
'handelsskolene': ('handelsskole',),
'handelsskoler': ('handelsskole',),
'handelsstand': ('handelsstand',),
'handelsstanden': ('handelsstand',),
'handelsstandene': ('handelsstand',),
'handelsstander': ('handelsstand',),
'handelstraktat': ('handelstraktat',),
'handelstraktaten': ('handelstraktat',),
'handelstraktatene': ('handelstraktat',),
'handelstraktater': ('handelstraktat',),
'handelsveg': ('handelsveg',),
'handelsvegen': ('handelsveg',),
'handelsvegene': ('handelsveg',),
'handelsveger': ('handelsveg',),
'handelsvei': ('handelsvei',),
'handelsveien': ('handelsvei',),
'handelsveiene': ('handelsvei',),
'handelsveier': ('handelsvei',),
'handfestning': ('handfestning',),
'handfestninga': ('handfestning',),
'handfestningen': ('handfestning',),
'handfestningene': ('handfestning',),
'handfestninger': ('handfestning',),
'handflata': ('handflate',),
'handflate': ('handflate',),
'handflaten': ('handflate',),
'handflatene': ('handflate',),
'handflater': ('handflate',),
'handfull': ('handfull',),
'handfullen': ('handfull',),
'handfullene': ('handfull',),
'handfuller': ('handfull',),
'handgivelse': ('handgivelse',),
'handgivelsen': ('handgivelse',),
'handgivelsene': ('handgivelse',),
'handgivelser': ('handgivelse',),
'handgranat': ('handgranat',),
'handgranaten': ('handgranat',),
'handgranatene': ('handgranat',),
'handgranater': ('handgranat',),
'handgrep': ('handgrep',),
'handgrepa': ('handgrep',),
'handgrepene': ('handgrep',),
'handgrepet': ('handgrep',),
'handgripelighet': ('handgripelighet',),
'handgripeligheta': ('handgripelighet',),
'handgripeligheten': ('handgripelighet',),
'handgripelighetene': ('handgripelighet',),
'handgripeligheter': ('handgripelighet',),
'handhevelse': ('handhevelse',),
'handhevelsen': ('handhevelse',),
'handhevelsene': ('handhevelse',),
'handhevelser': ('handhevelse',),
'handhevelse': ('handhevelse',),
'handhevelsen': ('handhevelse',),
'handhevelsene': ('handhevelse',),
'handhevelser': ('handhevelse',),
'handhever': ('handhever',),
'handhevere': ('handhever',),
'handheveren': ('handhever',),
'handheverer': ('handhever',),
'handheverne': ('handhever',),
'handhever': ('handhever',),
'handhevere': ('handhever',),
'handheveren': ('handhever',),
'handheverer': ('handhever',),
'handheverne': ('handhever',),
'handheving': ('handheving',),
'handhevinga': ('handheving',),
'handhevingen': ('handheving',),
'handhevingene': ('handheving',),
'handhevinger': ('handheving',),
'handikap': ('handikap',),
'handikapa': ('handikap',),
'handikapene': ('handikap',),
'handikaper': ('handikap',),
'handikapet': ('handikap',),
'handikapidrett': ('handikapidrett',),
'handikapidretten': ('handikapidrett',),
'handikapidrettene': ('handikapidrett',),
'handikapidretter': ('handikapidrett',),
'handjern': ('handjern',),
'handjerna': ('handjern',),
'handjernene': ('handjern',),
'handjernet': ('handjern',),
'handkjerra': ('handkjerre',),
'handkjerre': ('handkjerre',),
'handkjerren': ('handkjerre',),
'handkjerrene': ('handkjerre',),
'handkjerrer': ('handkjerre',),
'handkjøp': ('handkjøp',),
'handkjøpa': ('handkjøp',),
'handkjøpene': ('handkjøp',),
'handkjøpet': ('handkjøp',),
'handkle': ('handkle',),
'handkleet': ('handkle',),
'handklær': ('handkle',),
'handklærne': ('handkle',),
'handkoffert': ('handkoffert',),
'handkofferten': ('handkoffert',),
'handkoffertene': ('handkoffert',),
'handkofferter': ('handkoffert',),
'handkraft': ('handkraft',),
'handkrafta': ('handkraft',),
'handkraften': ('handkraft',),
'handkreftene': ('handkraft',),
'handkrefter': ('handkraft',),
'handlag': ('handlag',),
'handlaga': ('handlag',),
'handlagene': ('handlag',),
'handlaget': ('handlag',),
'handlanger': ('handlanger',),
'handlangere': ('handlanger',),
'handlangeren': ('handlanger',),
'handlangerer': ('handlanger',),
'handlangerne': ('handlanger',),
'handledd': ('handledd',),
'handledda': ('handledd',),
'handleddene': ('handledd',),
'handleddet': ('handledd',),
'handlefrihet': ('handlefrihet',),
'handlefriheta': ('handlefrihet',),
'handlefriheten': ('handlefrihet',),
'handlefrihetene': ('handlefrihet',),
'handlefriheter': ('handlefrihet',),
'handlekraft': ('handlekraft',),
'handlekrafta': ('handlekraft',),
'handlekraften': ('handlekraft',),
'handlekreftene': ('handlekraft',),
'handlekrefter': ('handlekraft',),
'handlemåte': ('handlemåte',),
'handlemåten': ('handlemåte',),
'handlemåtene': ('handlemåte',),
'handlemåter': ('handlemåte',),
'handlende': ('handlende',),
'handler': ('handler',),
'handlere': ('handler',),
'handleren': ('handler',),
'handlerer': ('handler',),
'handlerne': ('handler',),
'handling': ('handling',),
'handlinga': ('handling',),
'handlingen': ('handling',),
'handlingene': ('handling',),
'handlinger': ('handling',),
'handlingsgang': ('handlingsgang',),
'handlingsgangen': ('handlingsgang',),
'handlingsgangene': ('handlingsgang',),
'handlingsganger': ('handlingsgang',),
'handlingsmønster': ('handlingsmønster',),
'handlingsmønsteret': ('handlingsmønster',),
'handlingsmønstra': ('handlingsmønster',),
'handlingsmønstre': ('handlingsmønster',),
'handlingsmønstrene': ('handlingsmønster',),
'handlingsmønstret': ('handlingsmønster',),
'handlingsplan': ('handlingsplan',),
'handlingsplanen': ('handlingsplan',),
'handlingsplanene': ('handlingsplan',),
'handlingsplaner': ('handlingsplan',),
'handlingsprogram': ('handlingsprogram',),
'handlingsprogramma': ('handlingsprogram',),
'handlingsprogrammene': ('handlingsprogram',),
'handlingsprogrammer': ('handlingsprogram',),
'handlingsprogrammet': ('handlingsprogram',),
'handmikser': ('handmikser',),
'handmiksere': ('handmikser',),
'handmikseren': ('handmikser',),
'handmikserer': ('handmikser',),
'handmikserne': ('handmikser',),
'handpant': ('handpant',),
'handpanta': ('handpant',),
'handpantene': ('handpant',),
'handpantet': ('handpant',),
'handpengene': ('handpenger',),
'handpenger': ('handpenger',),
'handpleia': ('handpleie',),
'handpleie': ('handpleie',),
'handpleien': ('handpleie',),
'handpleiene': ('handpleie',),
'handpleier': ('handpleie',),
'handred': ('handred',),
'handreda': ('handred',),
'handredene': ('handred',),
'handredet': ('handred',),
'handrev': ('handrev',),
'handreva': ('handrev',),
'handrevene': ('handrev',),
'handrevet': ('handrev',),
'handrot': ('handrot',),
'handrota': ('handrot',),
'handroten': ('handrot',),
'handrøttene': ('handrot',),
'handrøtter': ('handrot',),
'hands': ('hands',),
'handsen': ('hands',),
'handsene': ('hands',),
'handser': ('hands',),
'handsag': ('handsag',),
'handsaga': ('handsag',),
'handsagen': ('handsag',),
'handsagene': ('handsag',),
'handsager': ('handsag',),
'handsbredd': ('handsbredd',),
'handsbredden': ('handsbredd',),
'handsbreddene': ('handsbredd',),
'handsbredder': ('handsbredd',),
'handsbredd': ('handsbredd',),
'handsbredda': ('handsbredd',),
'handsbredden': ('handsbredd',),
'handsbreddene': ('handsbredd',),
'handsbredder': ('handsbredd',),
'handskrift': ('handskrift',),
'handskrifta': ('handskrift',),
'handskriftene': ('handskrift',),
'handskrifter': ('handskrift',),
'handskriftet': ('handskrift',),
'handskrift': ('handskrift',),
'handskrifta': ('handskrift',),
'handskriften': ('handskrift',),
'handskriftene': ('handskrift',),
'handskrifter': ('handskrift',),
'handskriftsamling': ('handskriftsamling',),
'handskriftsamlinga': ('handskriftsamling',),
'handskriftsamlingen': ('handskriftsamling',),
'handskriftsamlingene': ('handskriftsamling',),
'handskriftsamlinger': ('handskriftsamling',),
'handskytevåpen': ('handskytevåpen',),
'handskytevåpenet': ('handskytevåpen',),
'handskytevåpna': ('handskytevåpen',),
'handskytevåpnene': ('handskytevåpen',),
'handslag': ('handslag',),
'handslaga': ('handslag',),
'handslagene': ('handslag',),
'handslaget': ('handslag',),
'handslokkingsapparat': ('handslokkingsapparat',),
'handslokkingsapparata': ('handslokkingsapparat',),
'handslokkingsapparatene': ('handslokkingsapparat',),
'handslokkingsapparater': ('handslokkingsapparat',),
'handslokkingsapparatet': ('handslokkingsapparat',),
'handslokningsapparat': ('handslokningsapparat',),
'handslokningsapparata': ('handslokningsapparat',),
'handslokningsapparatene': ('handslokningsapparat',),
'handslokningsapparater': ('handslokningsapparat',),
'handslokningsapparatet': ('handslokningsapparat',),
'handslukkingsapparat': ('handslukkingsapparat',),
'handslukkingsapparata': ('handslukkingsapparat',),
'handslukkingsapparatene': ('handslukkingsapparat',),
'handslukkingsapparater': ('handslukkingsapparat',),
'handslukkingsapparatet': ('handslukkingsapparat',),
'handslukningsapparat': ('handslukningsapparat',),
'handslukningsapparata': ('handslukningsapparat',),
'handslukningsapparatene': ('handslukningsapparat',),
'handslukningsapparater': ('handslukningsapparat',),
'handslukningsapparatet': ('handslukningsapparat',),
'handsnøra': ('handsnøre',),
'handsnøre': ('handsnøre',),
'handsnørene': ('handsnøre',),
'handsnører': ('handsnøre',),
'handsnøret': ('handsnøre',),
'handsopprekking': ('handsopprekking',),
'handsopprekkinga': ('handsopprekking',),
'handsopprekkingen': ('handsopprekking',),
'handsopprekkingene': ('handsopprekking',),
'handsopprekkinger': ('handsopprekking',),
'handsopprekning': ('handsopprekning',),
'handsopprekninga': ('handsopprekning',),
'handsopprekningen': ('handsopprekning',),
'handsopprekningene': ('handsopprekning',),
'handsopprekninger': ('handsopprekning',),
'handspåleggelse': ('handspåleggelse',),
'handspåleggelsen': ('handspåleggelse',),
'handspåleggelsene': ('handspåleggelse',),
'handspåleggelser': ('handspåleggelse',),
'handspålegging': ('handspålegging',),
'handspålegginga': ('handspålegging',),
'handspåleggingen': ('handspålegging',),
'handspåleggingene': ('handspålegging',),
'handspålegginger': ('handspålegging',),
'handsrekning': ('handsrekning',),
'handsrekninga': ('handsrekning',),
'handsrekningen': ('handsrekning',),
'handsrekningene': ('handsrekning',),
'handsrekninger': ('handsrekning',),
'handsrett': ('handsrett',),
'handsretten': ('handsrett',),
'handsrettene': ('handsrett',),
'handsretter': ('handsrett',),
'handtak': ('handtak',),
'handtaka': ('handtak',),
'handtakene': ('handtak',),
'handtaket': ('handtak',),
'handtein': ('handtein',),
'handteinen': ('handtein',),
'handteinene': ('handtein',),
'handteiner': ('handtein',),
'handtering': ('handtering',),
'handteringa': ('handtering',),
'handteringen': ('handtering',),
'handteringene': ('handtering',),
'handteringer': ('handtering',),
'handtrykk': ('handtrykk',),
'handtrykka': ('handtrykk',),
'handtrykkene': ('handtrykk',),
'handtrykket': ('handtrykk',),
'handvask': ('handvask',),
'handvasken': ('handvask',),
'handvaskene': ('handvask',),
'handvasker': ('handvask',),
'handvekt': ('handvekt',),
'handvekta': ('handvekt',),
'handvekten': ('handvekt',),
'handvektene': ('handvekt',),
'handvekter': ('handvekt',),
'handvending': ('handvending',),
'handvendinga': ('handvending',),
'handvendingen': ('handvending',),
'handvendingene': ('handvending',),
'handvendinger': ('handvending',),
'handverk': ('handverk',),
'handverka': ('handverk',),
'handverkene': ('handverk',),
'handverket': ('handverk',),
'handverker': ('handverker',),
'handverkere': ('handverker',),
'handverkeren': ('handverker',),
'handverkerer': ('handverker',),
'handverkerne': ('handverker',),
'handverkerforening': ('handverkerforening',),
'handverkerforeninga': ('handverkerforening',),
'handverkerforeningen': ('handverkerforening',),
'handverkerforeningene': ('handverkerforening',),
'handverkerforeninger': ('handverkerforening',),
'handverkerlaug': ('handverkerlaug',),
'handverkerlauga': ('handverkerlaug',),
'handverkerlaugene': ('handverkerlaug',),
'handverkerlauget': ('handverkerlaug',),
'handverkerlæra': ('handverkerlære',),
'handverkerlære': ('handverkerlære',),
'handverkerlæren': ('handverkerlære',),
'handverkerlærene': ('handverkerlære',),
'handverkerlærer': ('handverkerlære',),
'handverkerlærling': ('handverkerlærling',),
'handverkerlærlingen': ('handverkerlærling',),
'handverkerlærlingene': ('handverkerlærling',),
'handverkerlærlinger': ('handverkerlærling',),
'handverkersvenn': ('handverkersvenn',),
'handverkersvennen': ('handverkersvenn',),
'handverkersvennene': ('handverkersvenn',),
'handverkersvenner': ('handverkersvenn',),
'handverksbrev': ('handverksbrev',),
'handverksbreva': ('handverksbrev',),
'handverksbrevene': ('handverksbrev',),
'handverksbrever': ('handverksbrev',),
'handverksbrevet': ('handverksbrev',),
'handverkslaug': ('handverkslaug',),
'handverkslauga': ('handverkslaug',),
'handverkslaugene': ('handverkslaug',),
'handverkslauget': ('handverkslaug',),
'handverkslærling': ('handverkslærling',),
'handverkslærlingen': ('handverkslærling',),
'handverkslærlingene': ('handverkslærling',),
'handverkslærlinger': ('handverkslærling',),
'handverksmester': ('handverksmester',),
'handverksmestere': ('handverksmester',),
'handverksmesteren': ('handverksmester',),
'handverksmesterer': ('handverksmester',),
'handverksmesterne': ('handverksmester',),
'handverksmestre': ('handverksmester',),
'handverksmestrene': ('handverksmester',),
'handverksmestrer': ('handverksmester',),
'handverkssvenn': ('handverkssvenn',),
'handverkssvennen': ('handverkssvenn',),
'handverkssvennene': ('handverkssvenn',),
'handverkssvenner': ('handverkssvenn',),
'handveska': ('handveske',),
'handveske': ('handveske',),
'handvesken': ('handveske',),
'handveskene': ('handveske',),
'handvesker': ('handveske',),
'handvåpen': ('handvåpen',),
'handvåpenet': ('handvåpen',),
'handvåpna': ('handvåpen',),
'handvåpnene': ('handvåpen',),
'handøvla': ('handøvle',),
'handøvle': ('handøvle',),
'handøvlene': ('handøvle',),
'handøvler': ('handøvle',),
'handøvlet': ('handøvle',),
'hane': ('hane',),
'hanen': ('hane',),
'hanene': ('hane',),
'haner': ('hane',),
'hanebein': ('hanebein',),
'hanebeina': ('hanebein',),
'hanebeinene': ('hanebein',),
'hanebeinet': ('hanebein',),
'haneben': ('haneben',),
'hanebena': ('haneben',),
'hanebenene': ('haneben',),
'hanebenet': ('haneben',),
'hanebjelke': ('hanebjelke',),
'hanebjelken': ('hanebjelke',),
'hanebjelkene': ('hanebjelke',),
'hanebjelker': ('hanebjelke',),
'hanefjed': ('hanefjed',),
'hanefjeda': ('hanefjed',),
'hanefjedene': ('hanefjed',),
'hanefjedet': ('hanefjed',),
'hanefot': ('hanefot',),
'hanefoten': ('hanefot',),
'hanefotene': ('hanefot',),
'hanefot': ('hanefot',),
'hanefoten': ('hanefot',),
'haneføttene': ('hanefot',),
'haneføtter': ('hanefot',),
'hanegal': ('hanegal',),
'hanegala': ('hanegal',),
'hanegalene': ('hanegal',),
'hanegalet': ('hanegal',),
'hanekam': ('hanekam',),
'hanekammen': ('hanekam',),
'hanekammene': ('hanekam',),
'hanekammer': ('hanekam',),
'hanekamp': ('hanekamp',),
'hanekampen': ('hanekamp',),
'hanekampene': ('hanekamp',),
'hanekamper': ('hanekamp',),
'hanekjukling': ('hanekjukling',),
'hanekjuklingen': ('hanekjukling',),
'hanekjuklingene': ('hanekjukling',),
'hanekjuklinger': ('hanekjukling',),
'hanekylling': ('hanekylling',),
'hanekyllingen': ('hanekylling',),
'hanekyllingene': ('hanekylling',),
'hanekyllinger': ('hanekylling',),
'hanemarsj': ('hanemarsj',),
'hanemarsjen': ('hanemarsj',),
'hanemarsjene': ('hanemarsj',),
'hanemarsjer': ('hanemarsj',),
'hanesteg': ('hanesteg',),
'hanestega': ('hanesteg',),
'hanestegene': ('hanesteg',),
'hanesteget': ('hanesteg',),
'hanetrinn': ('hanetrinn',),
'hanetrinna': ('hanetrinn',),
'hanetrinnene': ('hanetrinn',),
'hanetrinnet': ('hanetrinn',),
'hang': ('hang',),
'hanga': ('hang',),
'hangen': ('hang',),
'hangene': ('hang',),
'hanger': ('hang',),
'hanget': ('hang',),
'hang glider': ('hang glider',),
'hang glidere': ('hang glider',),
'hang glideren': ('hang glider',),
'hang gliderer': ('hang glider',),
'hang gliderne': ('hang glider',),
'hang gliding': ('hang gliding',),
'hang glidingen': ('hang gliding',),
'hang glidingene': ('hang gliding',),
'hang glidinger': ('hang gliding',),
'hangar': ('hangar',),
'hangaren': ('hangar',),
'hangarene': ('hangar',),
'hangarer': ('hangar',),
'hangarskip': ('hangarskip',),
'hangarskipa': ('hangarskip',),
'hangarskipene': ('hangarskip',),
'hangarskipet': ('hangarskip',),
'hanger': ('hanger',),
'hangere': ('hanger',),
'hangeren': ('hanger',),
'hangerer': ('hanger',),
'hangerne': ('hanger',),
'hank': ('hank',),
'hanka': ('hank',),
'hanken': ('hank',),
'hankene': ('hank',),
'hanker': ('hank',),
'hankjønn': ('hankjønn',),
'hankjønna': ('hankjønn',),
'hankjønnene': ('hankjønn',),
'hankjønnet': ('hankjønn',),
'hankjønnsord': ('hankjønnsord',),
'hankjønnsorda': ('hankjønnsord',),
'hankjønnsordene': ('hankjønnsord',),
'hankjønnsordet': ('hankjønnsord',),
'hann': ('hann',),
'hannen': ('hann',),
'hannene': ('hann',),
'hanner': ('hann',),
'hannblomst': ('hannblomst',),
'hannblomsten': ('hannblomst',),
'hannblomstene': ('hannblomst',),
'hannblomster': ('hannblomst',),
'hanndyr': ('hanndyr',),
'hanndyra': ('hanndyr',),
'hanndyrene': ('hanndyr',),
'hanndyret': ('hanndyr',),
'hannfisk': ('hannfisk',),
'hannfisken': ('hannfisk',),
'hannfiskene': ('hannfisk',),
'hannfisker': ('hannfisk',),
'hannfugl': ('hannfugl',),
'hannfuglen': ('hannfugl',),
'hannfuglene': ('hannfugl',),
'hannfugler': ('hannfugl',),
'hannkatt': ('hannkatt',),
'hannkatten': ('hannkatt',),
'hannkattene': ('hannkatt',),
'hannkatter': ('hannkatt',),
'hannkjønn': ('hannkjønn',),
'hannkjønna': ('hannkjønn',),
'hannkjønnene': ('hannkjønn',),
'hannkjønnet': ('hannkjønn',),
'hannkjønnsord': ('hannkjønnsord',),
'hannkjønnsorda': ('hannkjønnsord',),
'hannkjønnsordene': ('hannkjønnsord',),
'hannkjønnsordet': ('hannkjønnsord',),
'hannplanta': ('hannplante',),
'hannplante': ('hannplante',),
'hannplanten': ('hannplante',),
'hannplantene': ('hannplante',),
'hannplanter': ('hannplante',),
'hannrakle': ('hannrakle',),
'hannraklen': ('hannrakle',),
'hannraklene': ('hannrakle',),
'hannrakler': ('hannrakle',),
'hanrei': ('hanrei',),
'hanreien': ('hanrei',),
'hanreiene': ('hanrei',),
'hanreier': ('hanrei',),
'hansa': ('hansa',),
'hansaen': ('hansa',),
'hansaene': ('hansa',),
'hansaer': ('hansa',),
'hansaby': ('hansaby',),
'hansabyen': ('hansaby',),
'hansabyene': ('hansaby',),
'hansabyer': ('hansaby',),
'hansaforbund': ('hansaforbund',),
'hansaforbunda': ('hansaforbund',),
'hansaforbundene': ('hansaforbund',),
'hansaforbundet': ('hansaforbund',),
'hanseat': ('hanseat',),
'hanseaten': ('hanseat',),
'hanseatene': ('hanseat',),
'hanseater': ('hanseat',),
'hanske': ('hanske',),
'hansken': ('hanske',),
'hanskene': ('hanske',),
'hansker': ('hanske',),
'hanskemoral': ('hanskemoral',),
'hanskemoralen': ('hanskemoral',),
'hanskemoralene': ('hanskemoral',),
'hanskemoraler': ('hanskemoral',),
'happ': ('happ',),
'happening': ('happening',),
'happeninga': ('happening',),
'happeningen': ('happening',),
'happeningene': ('happening',),
'happeninger': ('happening',),
'happy end': ('happy end',),
'happy ending': ('happy ending',),
'harakiri': ('harakiri',),
'harakirien': ('harakiri',),
'harakiriene': ('harakiri',),
'harakirier': ('harakiri',),
'harang': ('harang',),
'harangen': ('harang',),
'harangene': ('harang',),
'haranger': ('harang',),
'hard-top': ('hard-top',),
'hard-topen': ('hard-top',),
'hard-topene': ('hard-top',),
'hard-toper': ('hard-top',),
'hardangerbåt': ('hardangerbåt',),
'hardangerbåten': ('hardangerbåt',),
'hardangerbåtene': ('hardangerbåt',),
'hardangerbåter': ('hardangerbåt',),
'hardangersøm': ('hardangersøm',),
'hardangersømmen': ('hardangersøm',),
'hardangersømmene': ('hardangersøm',),
'hardangersømmer': ('hardangersøm',),
'harddisk': ('harddisk',),
'harddisken': ('harddisk',),
'harddiskene': ('harddisk',),
'harddisker': ('harddisk',),
'hardhaus': ('hardhaus',),
'hardhausen': ('hardhaus',),
'hardhausene': ('hardhaus',),
'hardhauser': ('hardhaus',),
'hardhet': ('hardhet',),
'hardheta': ('hardhet',),
'hardheten': ('hardhet',),
'hardhetene': ('hardhet',),
'hardheter': ('hardhet',),
'harding': ('harding',),
'hardingen': ('harding',),
'hardingene': ('harding',),
'hardinger': ('harding',),
'harding': ('harding',),
'hardingen': ('harding',),
'hardingene': ('harding',),
'hardinger': ('harding',),
'hardingfela': ('hardingfele',),
'hardingfele': ('hardingfele',),
'hardingfelen': ('hardingfele',),
'hardingfelene': ('hardingfele',),
'hardingfeler': ('hardingfele',),
'hardkjør': ('hardkjør',),
'hardkjøra': ('hardkjør',),
'hardkjørene': ('hardkjør',),
'hardkjøret': ('hardkjør',),
'hardkjøring': ('hardkjøring',),
'hardkjøringa': ('hardkjøring',),
'hardkjøringen': ('hardkjøring',),
'hardkjøringene': ('hardkjøring',),
'hardkjøringer': ('hardkjøring',),
'hardleik': ('hardleik',),
'hardleiken': ('hardleik',),
'hardleikene': ('hardleik',),
'hardleiker': ('hardleik',),
'hardmetall': ('hardmetall',),
'hardmetalla': ('hardmetall',),
'hardmetallene': ('hardmetall',),
'hardmetaller': ('hardmetall',),
'hardmetallet': ('hardmetall',),
'hardplata': ('hardplate',),
'hardplate': ('hardplate',),
'hardplaten': ('hardplate',),
'hardplatene': ('hardplate',),
'hardplater': ('hardplate',),
'hardstyra': ('hardstyre',),
'hardstyre': ('hardstyre',),
'hardstyrene': ('hardstyre',),
'hardstyrer': ('hardstyre',),
'hardstyret': ('hardstyre',),
'hardstyrer': ('hardstyrer',),
'hardstyrere': ('hardstyrer',),
'hardstyreren': ('hardstyrer',),
'hardstyrerer': ('hardstyrer',),
'hardstyrerne': ('hardstyrer',),
'hardved': ('hardved',),
'hardveden': ('hardved',),
'hardvedene': ('hardved',),
'hardveder': ('hardved',),
'hardvedkant': ('hardvedkant',),
'hardvedkanten': ('hardvedkant',),
'hardvedkantene': ('hardvedkant',),
'hardvedkanter': ('hardvedkant',),
'hardware': ('hardware',),
'hardwaren': ('hardware',),
'hardwarene': ('hardware',),
'hardwarer': ('hardware',),
'hare': ('hare',),
'haren': ('hare',),
'harene': ('hare',),
'harer': ('hare',),
'harehjerta': ('harehjerte',),
'harehjerte': ('harehjerte',),
'harehjertene': ('harehjerte',),
'harehjerter': ('harehjerte',),
'harehjertet': ('harehjerte',),
'harehund': ('harehund',),
'harehunden': ('harehund',),
'harehundene': ('harehund',),
'harehunder': ('harehund',),
'harejakt': ('harejakt',),
'harejakta': ('harejakt',),
'harejakten': ('harejakt',),
'harejaktene': ('harejakt',),
'harejakter': ('harejakt',),
'harekanin': ('harekanin',),
'harekaninen': ('harekanin',),
'harekaninene': ('harekanin',),
'harekaniner': ('harekanin',),
'harelabb': ('harelabb',),
'harelabben': ('harelabb',),
'harelabbene': ('harelabb',),
'harelabber': ('harelabb',),
'harelos': ('harelos',),
'harelosen': ('harelos',),
'harelosene': ('harelos',),
'hareloser': ('harelos',),
'harem': ('harem',),
'harema': ('harem',),
'haremene': ('harem',),
'haremer': ('harem',),
'haremet': ('harem',),
'haremat': ('haremat',),
'harematen': ('haremat',),
'harematene': ('haremat',),
'haremater': ('haremat',),
'haremskvinna': ('haremskvinne',),
'haremskvinne': ('haremskvinne',),
'haremskvinnen': ('haremskvinne',),
'haremskvinnene': ('haremskvinne',),
'haremskvinner': ('haremskvinne',),
'haremsvokter': ('haremsvokter',),
'haremsvoktere': ('haremsvokter',),
'haremsvokteren': ('haremsvokter',),
'haremsvokterer': ('haremsvokter',),
'haremsvokterne': ('haremsvokter',),
'haremunn': ('haremunn',),
'haremunnen': ('haremunn',),
'haremunnene': ('haremunn',),
'haremunner': ('haremunn',),
'harepest': ('harepest',),
'harepesta': ('harepest',),
'harepesten': ('harepest',),
'harepestene': ('harepest',),
'harepester': ('harepest',),
'harerug': ('harerug',),
'harerugen': ('harerug',),
'harerugene': ('harerug',),
'hareruger': ('harerug',),
'hareskår': ('hareskår',),
'hareskåra': ('hareskår',),
'hareskårene': ('hareskår',),
'hareskåret': ('hareskår',),
'hark': ('hark',),
'harka': ('hark',),
'harken': ('hark',),
'harkene': ('hark',),
'harket': ('hark',),
'harlekin': ('harlekin',),
'harlekinen': ('harlekin',),
'harlekinene': ('harlekin',),
'harlekiner': ('harlekin',),
'harlekinsdrakt': ('harlekinsdrakt',),
'harlekinsdrakta': ('harlekinsdrakt',),
'harlekinsdrakten': ('harlekinsdrakt',),
'harlekinsdraktene': ('harlekinsdrakt',),
'harlekinsdrakter': ('harlekinsdrakt',),
'harm': ('harm',),
'harmen': ('harm',),
'harmene': ('harm',),
'harmer': ('harm',),
'harme': ('harme',),
'harmen': ('harme',),
'harmene': ('harme',),
'harmer': ('harme',),
'harmoni': ('harmoni',),
'harmonien': ('harmoni',),
'harmoniene': ('harmoni',),
'harmonier': ('harmoni',),
'harmonika': ('harmonika',),
'harmonikaen': ('harmonika',),
'harmonikaene': ('harmonika',),
'harmonikaer': ('harmonika',),
'harmonikk': ('harmonikk',),
'harmonikken': ('harmonikk',),
'harmonikkene': ('harmonikk',),
'harmonikker': ('harmonikk',),
'harmonilæra': ('harmonilære',),
'harmonilære': ('harmonilære',),
'harmonilæren': ('harmonilære',),
'harmonilærene': ('harmonilære',),
'harmonilærer': ('harmonilære',),
'harmoniorkester': ('harmoniorkester',),
'harmoniorkesteret': ('harmoniorkester',),
'harmoniorkestra': ('harmoniorkester',),
'harmoniorkestre': ('harmoniorkester',),
'harmoniorkestrene': ('harmoniorkester',),
'harmoniorkestret': ('harmoniorkester',),
'harmonia': ('harmonium',),
'harmoniene': ('harmonium',),
'harmonier': ('harmonium',),
'harmoniet': ('harmonium',),
'harmonium': ('harmonium',),
'harnisk': ('harnisk',),
'harniska': ('harnisk',),
'harniskene': ('harnisk',),
'harnisker': ('harnisk',),
'harnisket': ('harnisk',),
'harpa': ('harpe',),
'harpe': ('harpe',),
'harpen': ('harpe',),
'harpene': ('harpe',),
'harper': ('harpe',),
'harpa': ('harpe',),
'harpe': ('harpe',),
'harpen': ('harpe',),
'harpene': ('harpe',),
'harper': ('harpe',),
'harpeklang': ('harpeklang',),
'harpeklangen': ('harpeklang',),
'harpeklangene': ('harpeklang',),
'harpeklanger': ('harpeklang',),
'harpespell': ('harpespell',),
'harpespella': ('harpespell',),
'harpespellene': ('harpespell',),
'harpespellet': ('harpespell',),
'harpespeller': ('harpespeller',),
'harpespellere': ('harpespeller',),
'harpespelleren': ('harpespeller',),
'harpespellerer': ('harpespeller',),
'harpespellerne': ('harpespeller',),
'harpespill': ('harpespill',),
'harpespilla': ('harpespill',),
'harpespillene': ('harpespill',),
'harpespillet': ('harpespill',),
'harpespiller': ('harpespiller',),
'harpespillere': ('harpespiller',),
'harpespilleren': ('harpespiller',),
'harpespillerer': ('harpespiller',),
'harpespillerne': ('harpespiller',),
'harpestreng': ('harpestreng',),
'harpestrengen': ('harpestreng',),
'harpestrengene': ('harpestreng',),
'harpestrenger': ('harpestreng',),
'harpiks': ('harpiks',),
'harpiksen': ('harpiks',),
'harpiksene': ('harpiks',),
'harpikser': ('harpiks',),
'harpiksolja': ('harpiksolje',),
'harpiksolje': ('harpiksolje',),
'harpiksoljen': ('harpiksolje',),
'harpiksoljene': ('harpiksolje',),
'harpiksoljer': ('harpiksolje',),
'harpist': ('harpist',),
'harpisten': ('harpist',),
'harpistene': ('harpist',),
'harpister': ('harpist',),
'harpun': ('harpun',),
'harpunen': ('harpun',),
'harpunene': ('harpun',),
'harpuner': ('harpun',),
'harpuner': ('harpuner',),
'harpuneren': ('harpuner',),
'harpunerene': ('harpuner',),
'harpunerer': ('harpuner',),
'harpungevær': ('harpungevær',),
'harpungeværa': ('harpungevær',),
'harpungeværene': ('harpungevær',),
'harpungeværer': ('harpungevær',),
'harpungeværet': ('harpungevær',),
'harpunkanon': ('harpunkanon',),
'harpunkanonen': ('harpunkanon',),
'harpunkanonene': ('harpunkanon',),
'harpunkanoner': ('harpunkanon',),
'harpunlina': ('harpunline',),
'harpunline': ('harpunline',),
'harpunlinen': ('harpunline',),
'harpunlinene': ('harpunline',),
'harpunliner': ('harpunline',),
'harpy': ('harpy',),
'harpyen': ('harpy',),
'harpyene': ('harpy',),
'harpyer': ('harpy',),
'harr': ('harr',),
'harren': ('harr',),
'harrene': ('harr',),
'harrer': ('harr',),
'harselas': ('harselas',),
'harselasen': ('harselas',),
'harselasene': ('harselas',),
'harselaser': ('harselas',),
'hartkorn': ('hartkorn',),
'harv': ('harv',),
'harva': ('harv',),
'harven': ('harv',),
'harvene': ('harv',),
'harver': ('harv',),
'has': ('has',),
'hasard': ('hasard',),
'hasarden': ('hasard',),
'hasardene': ('hasard',),
'hasarder': ('hasard',),
'hasardspell': ('hasardspell',),
'hasardspella': ('hasardspell',),
'hasardspellene': ('hasardspell',),
'hasardspellet': ('hasardspell',),
'hasardspeller': ('hasardspeller',),
'hasardspellere': ('hasardspeller',),
'hasardspelleren': ('hasardspeller',),
'hasardspellerer': ('hasardspeller',),
'hasardspellerne': ('hasardspeller',),
'hasardspill': ('hasardspill',),
'hasardspilla': ('hasardspill',),
'hasardspillene': ('hasardspill',),
'hasardspillet': ('hasardspill',),
'hasardspiller': ('hasardspiller',),
'hasardspillere': ('hasardspiller',),
'hasardspilleren': ('hasardspiller',),
'hasardspillerer': ('hasardspiller',),
'hasardspillerne': ('hasardspiller',),
'hase': ('hase',),
'hasen': ('hase',),
'hasene': ('hase',),
'haser': ('hase',),
'hasj': ('hasj',),
'hasjen': ('hasj',),
'hasjene': ('hasj',),
'hasjer': ('hasj',),
'hasjgjeng': ('hasjgjeng',),
'hasjgjengen': ('hasjgjeng',),
'hasjgjengene': ('hasjgjeng',),
'hasjgjenger': ('hasjgjeng',),
'hasjisj': ('hasjisj',),
'hasjisjen': ('hasjisj',),
'hasjisjene': ('hasjisj',),
'hasjisjer': ('hasjisj',),
'hasjmiljø': ('hasjmiljø',),
'hasjmiljøa': ('hasjmiljø',),
'hasjmiljøene': ('hasjmiljø',),
'hasjmiljøer': ('hasjmiljø',),
'hasjmiljøet': ('hasjmiljø',),
'hasjungdom': ('hasjungdom',),
'hasjungdommen': ('hasjungdom',),
'hasjungdommene': ('hasjungdom',),
'hasjungdommer': ('hasjungdom',),
'hasp': ('hasp',),
'haspen': ('hasp',),
'haspene': ('hasp',),
'hasper': ('hasp',),
'haspe': ('haspe',),
'haspen': ('haspe',),
'haspene': ('haspe',),
'hasper': ('haspe',),
'haspel': ('haspel',),
'haspelen': ('haspel',),
'hasplene': ('haspel',),
'haspler': ('haspel',),
'haspelsnella': ('haspelsnelle',),
'haspelsnelle': ('haspelsnelle',),
'haspelsnellen': ('haspelsnelle',),
'haspelsnellene': ('haspelsnelle',),
'haspelsneller': ('haspelsnelle',),
'haspelstang': ('haspelstang',),
'haspelstanga': ('haspelstang',),
'haspelstangen': ('haspelstang',),
'haspelstengene': ('haspelstang',),
'haspelstenger': ('haspelstang',),
'haslene': ('hassel',),
'hasler': ('hassel',),
'hassel': ('hassel',),
'hasselen': ('hassel',),
'hasselfamilie': ('hasselfamilie',),
'hasselfamilien': ('hasselfamilie',),
'hasselfamiliene': ('hasselfamilie',),
'hasselfamilier': ('hasselfamilie',),
'hasselnøtt': ('hasselnøtt',),
'hasselnøtta': ('hasselnøtt',),
'hasselnøtten': ('hasselnøtt',),
'hasselnøttene': ('hasselnøtt',),
'hasselnøtter': ('hasselnøtt',),
'hast': ('hast',),
'hasten': ('hast',),
'hastene': ('hast',),
'haster': ('hast',),
'hastesak': ('hastesak',),
'hastesaka': ('hastesak',),
'hastesaken': ('hastesak',),
'hastesakene': ('hastesak',),
'hastesaker': ('hastesak',),
'hastighet': ('hastighet',),
'hastigheta': ('hastighet',),
'hastigheten': ('hastighet',),
'hastighetene': ('hastighet',),
'hastigheter': ('hastighet',),
'hastighetsmåler': ('hastighetsmåler',),
'hastighetsmålere': ('hastighetsmåler',),
'hastighetsmåleren': ('hastighetsmåler',),
'hastighetsmålerer': ('hastighetsmåler',),
'hastighetsmålerne': ('hastighetsmåler',),
'hastverk': ('hastverk',),
'hastverka': ('hastverk',),
'hastverkene': ('hastverk',),
'hastverket': ('hastverk',),
'hastverksarbeid': ('hastverksarbeid',),
'hastverksarbeida': ('hastverksarbeid',),
'hastverksarbeidene': ('hastverksarbeid',),
'hastverksarbeider': ('hastverksarbeid',),
'hastverksarbeidet': ('hastverksarbeid',),
'hat': ('hat',),
'hata': ('hat',),
'hatene': ('hat',),
'hatet': ('hat',),
'hat trick': ('hat trick',),
'hat tricka': ('hat trick',),
'hat trickene': ('hat trick',),
'hat tricket': ('hat trick',),
'hater': ('hater',),
'hatere': ('hater',),
'hateren': ('hater',),
'haterer': ('hater',),
'haterne': ('hater',),
'hatskhet': ('hatskhet',),
'hatskheta': ('hatskhet',),
'hatskheten': ('hatskhet',),
'hatskhetene': ('hatskhet',),
'hatskheter': ('hatskhet',),
'hatt': ('hatt',),
'hatten': ('hatt',),
'hattene': ('hatt',),
'hatter': ('hatt',),
'hatteband': ('hatteband',),
'hattebanda': ('hatteband',),
'hattebandene': ('hatteband',),
'hattebandet': ('hatteband',),
'hattebrem': ('hattebrem',),
'hattebremmen': ('hattebrem',),
'hattebremmene': ('hattebrem',),
'hattebremmer': ('hattebrem',),
'hattebånd': ('hattebånd',),
'hattebånda': ('hattebånd',),
'hattebåndene': ('hattebånd',),
'hattebåndet': ('hattebånd',),
'hatteeska': ('hatteeske',),
'hatteeske': ('hatteeske',),
'hatteesken': ('hatteeske',),
'hatteeskene': ('hatteeske',),
'hatteesker': ('hatteeske',),
'hatteforretning': ('hatteforretning',),
'hatteforretninga': ('hatteforretning',),
'hatteforretningen': ('hatteforretning',),
'hatteforretningene': ('hatteforretning',),
'hatteforretninger': ('hatteforretning',),
'hattemaker': ('hattemaker',),
'hattemakere': ('hattemaker',),
'hattemakeren': ('hattemaker',),
'hattemakerer': ('hattemaker',),
'hattemakerne': ('hattemaker',),
'hattenål': ('hattenål',),
'hattenåla': ('hattenål',),
'hattenålen': ('hattenål',),
'hattenålene': ('hattenål',),
'hattenåler': ('hattenål',),
'hattepull': ('hattepull',),
'hattepullen': ('hattepull',),
'hattepullene': ('hattepull',),
'hattepuller': ('hattepull',),
'hatteska': ('hatteske',),
'hatteske': ('hatteske',),
'hattesken': ('hatteske',),
'hatteskene': ('hatteske',),
'hattesker': ('hatteske',),
'hattestativ': ('hattestativ',),
'hattestativa': ('hattestativ',),
'hattestativene': ('hattestativ',),
'hattestativer': ('hattestativ',),
'hattestativet': ('hattestativ',),
'hattsopp': ('hattsopp',),
'hattsoppen': ('hattsopp',),
'hattsoppene': ('hattsopp',),
'hattsopper': ('hattsopp',),
'haubits': ('haubits',),
'haubitsen': ('haubits',),
'haubitsene': ('haubits',),
'haubitser': ('haubits',),
'haud': ('haud',),
'hauden': ('haud',),
'haudene': ('haud',),
'hauder': ('haud',),
'haug': ('haug',),
'haugen': ('haug',),
'haugene': ('haug',),
'hauger': ('haug',),
'haugbonde': ('haugbonde',),
'haugbonden': ('haugbonde',),
'haugbøndene': ('haugbonde',),
'haugbønder': ('haugbonde',),
'haugfolk': ('haugfolk',),
'haugfolka': ('haugfolk',),
'haugfolkene': ('haugfolk',),
'haugfolket': ('haugfolk',),
'haugianer': ('haugianer',),
'haugianere': ('haugianer',),
'haugianeren': ('haugianer',),
'haugianerer': ('haugianer',),
'haugianerne': ('haugianer',),
'haugianisme': ('haugianisme',),
'haugianismen': ('haugianisme',),
'haugianismene': ('haugianisme',),
'haugianismer': ('haugianisme',),
'haugkall': ('haugkall',),
'haugkallen': ('haugkall',),
'haugkallene': ('haugkall',),
'haugkaller': ('haugkall',),
'haugsky': ('haugsky',),
'haugskya': ('haugsky',),
'haugskyen': ('haugsky',),
'haugskyene': ('haugsky',),
'haugskyer': ('haugsky',),
'haugtuss': ('haugtuss',),
'haugtussen': ('haugtuss',),
'haugtussene': ('haugtuss',),
'haugtusser': ('haugtuss',),
'haugtusse': ('haugtusse',),
'haugtussen': ('haugtusse',),
'haugtussene': ('haugtusse',),
'haugtusser': ('haugtusse',),
'haugtussa': ('haugtusse',),
'haugtusse': ('haugtusse',),
'haugtussen': ('haugtusse',),
'haugtussene': ('haugtusse',),
'haugtusser': ('haugtusse',),
'hauk': ('hauk',),
'hauken': ('hauk',),
'haukene': ('hauk',),
'hauker': ('hauk',),
'haukenesa': ('haukenese',),
'haukenese': ('haukenese',),
'haukenesen': ('haukenese',),
'haukenesene': ('haukenese',),
'haukeneser': ('haukenese',),
'haukeskjegg': ('haukeskjegg',),
'haukeskjegga': ('haukeskjegg',),
'haukeskjeggen': ('haukeskjegg',),
'haukeskjeggene': ('haukeskjegg',),
'haukeskjegger': ('haukeskjegg',),
'haukeskjegget': ('haukeskjegg',),
'hauksanger': ('hauksanger',),
'hauksangere': ('hauksanger',),
'hauksangeren': ('hauksanger',),
'hauksangerer': ('hauksanger',),
'hauksangerne': ('hauksanger',),
'haukugla': ('haukugle',),
'haukugle': ('haukugle',),
'haukuglen': ('haukugle',),
'haukuglene': ('haukugle',),
'haukugler': ('haukugle',),
'hauld': ('hauld',),
'haulden': ('hauld',),
'hauldene': ('hauld',),
'haulder': ('hauld',),
'haus': ('haus',),
'hausen': ('haus',),
'hausene': ('haus',),
'hauser': ('haus',),
'hausa': ('hausa',),
'hausaen': ('hausa',),
'hausaene': ('hausa',),
'hausaer': ('hausa',),
'haussa': ('haussa',),
'haussaen': ('haussa',),
'haussaene': ('haussa',),
'haussaer': ('haussa',),
'hausse': ('hausse',),
'haussen': ('hausse',),
'haussene': ('hausse',),
'hausser': ('hausse',),
'haussist': ('haussist',),
'haussisten': ('haussist',),
'haussistene': ('haussist',),
'haussister': ('haussist',),
'haute couture': ('haute couture',),
'hautrelieff': ('hautrelieff',),
'hautrelieffa': ('hautrelieff',),
'hautrelieffene': ('hautrelieff',),
'hautrelieffer': ('hautrelieff',),
'hautrelieffet': ('hautrelieff',),
'hav': ('hav',),
'hava': ('hav',),
'havene': ('hav',),
'havet': ('hav',),
'hav': ('hav',),
'hava': ('hav',),
'havene': ('hav',),
'havet': ('hav',),
'havannasigar': ('havannasigar',),
'havannasigaren': ('havannasigar',),
'havannasigarene': ('havannasigar',),
'havannasigarer': ('havannasigar',),
'havanneser': ('havanneser',),
'havannesere': ('havanneser',),
'havanneseren': ('havanneser',),
'havanneserer': ('havanneser',),
'havanneserne': ('havanneser',),
'havari': ('havari',),
'havaria': ('havari',),
'havariene': ('havari',),
'havarier': ('havari',),
'havariet': ('havari',),
'havarist': ('havarist',),
'havaristen': ('havarist',),
'havaristene': ('havarist',),
'havarister': ('havarist',),
'havblikk': ('havblikk',),
'havblikka': ('havblikk',),
'havblikkene': ('havblikk',),
'havblikket': ('havblikk',),
'havbotn': ('havbotn',),
'havbotnen': ('havbotn',),
'havbotnene': ('havbotn',),
'havbotner': ('havbotn',),
'havbris': ('havbris',),
'havbrisen': ('havbris',),
'havbrisene': ('havbris',),
'havbriser': ('havbris',),
'havbruk': ('havbruk',),
'havbruka': ('havbruk',),
'havbrukene': ('havbruk',),
'havbruket': ('havbruk',),
'havbryn': ('havbryn',),
'havbryna': ('havbryn',),
'havbrynene': ('havbryn',),
'havbrynet': ('havbryn',),
'havbukt': ('havbukt',),
'havbukta': ('havbukt',),
'havbukten': ('havbukt',),
'havbuktene': ('havbukt',),
'havbukter': ('havbukt',),
'havbunn': ('havbunn',),
'havbunnen': ('havbunn',),
'havbunnene': ('havbunn',),
'havbunner': ('havbunn',),
'havbåra': ('havbåre',),
'havbåre': ('havbåre',),
'havbåren': ('havbåre',),
'havbårene': ('havbåre',),
'havbårer': ('havbåre',),
'havbølga': ('havbølge',),
'havbølge': ('havbølge',),
'havbølgen': ('havbølge',),
'havbølgene': ('havbølge',),
'havbølger': ('havbølge',),
'havbølgja': ('havbølgje',),
'havbølgje': ('havbølgje',),
'havbølgjen': ('havbølgje',),
'havbølgjene': ('havbølgje',),
'havbølgjer': ('havbølgje',),
'havdjup': ('havdjup',),
'havdjupa': ('havdjup',),
'havdjupene': ('havdjup',),
'havdjupet': ('havdjup',),
'havdyp': ('havdyp',),
'havdypa': ('havdyp',),
'havdypene': ('havdyp',),
'havdypet': ('havdyp',),
'havella': ('havelle',),
'havelle': ('havelle',),
'havellen': ('havelle',),
'havellene': ('havelle',),
'haveller': ('havelle',),
'havengel': ('havengel',),
'havengelen': ('havengel',),
'havenglene': ('havengel',),
'havengler': ('havengel',),
'haverkn': ('haverkn',),
'haverknen': ('haverkn',),
'haverknene': ('haverkn',),
'haverkner': ('haverkn',),
'havert': ('havert',),
'haverten': ('havert',),
'havertene': ('havert',),
'haverter': ('havert',),
'havesjuka': ('havesjuke',),
'havesjuke': ('havesjuke',),
'havesjuken': ('havesjuke',),
'havesjukene': ('havesjuke',),
'havesjuker': ('havesjuke',),
'havesyka': ('havesyke',),
'havesyke': ('havesyke',),
'havesyken': ('havesyke',),
'havesykene': ('havesyke',),
'havesyker': ('havesyke',),
'havfauna': ('havfauna',),
'havfaunaen': ('havfauna',),
'havfaunaene': ('havfauna',),
'havfaunaer': ('havfauna',),
'havfiska': ('havfiske',),
'havfiske': ('havfiske',),
'havfiskene': ('havfiske',),
'havfisker': ('havfiske',),
'havfisket': ('havfiske',),
'havflora': ('havflora',),
'havfloraen': ('havflora',),
'havfloraene': ('havflora',),
'havfloraer': ('havflora',),
'havforsking': ('havforsking',),
'havforskinga': ('havforsking',),
'havforskingen': ('havforsking',),
'havforskingene': ('havforsking',),
'havforskinger': ('havforsking',),
'havforskning': ('havforskning',),
'havforskninga': ('havforskning',),
'havforskningen': ('havforskning',),
'havforskningene': ('havforskning',),
'havforskninger': ('havforskning',),
'havfrua': ('havfrue',),
'havfrue': ('havfrue',),
'havfruen': ('havfrue',),
'havfruene': ('havfrue',),
'havfruer': ('havfrue',),
'havgap': ('havgap',),
'havgapa': ('havgap',),
'havgapene': ('havgap',),
'havgapet': ('havgap',),
'havgud': ('havgud',),
'havguden': ('havgud',),
'havgudene': ('havgud',),
'havguder': ('havgud',),
'havgudinna': ('havgudinne',),
'havgudinne': ('havgudinne',),
'havgudinnen': ('havgudinne',),
'havgudinnene': ('havgudinne',),
'havgudinner': ('havgudinne',),
'havgul': ('havgul',),
'havgula': ('havgul',),
'havgulen': ('havgul',),
'havgulene': ('havgul',),
'havguler': ('havgul',),
'havgula': ('havgule',),
'havgule': ('havgule',),
'havgulen': ('havgule',),
'havgulene': ('havgule',),
'havguler': ('havgule',),
'havhest': ('havhest',),
'havhesten': ('havhest',),
'havhestene': ('havhest',),
'havhester': ('havhest',),
'havkatt': ('havkatt',),
'havkatten': ('havkatt',),
'havkattene': ('havkatt',),
'havkatter': ('havkatt',),
'havklima': ('havklima',),
'havklimaene': ('havklima',),
'havklimaer': ('havklima',),
'havklimaet': ('havklima',),
'havlira': ('havlire',),
'havlire': ('havlire',),
'havliren': ('havlire',),
'havlirene': ('havlire',),
'havlirer': ('havlire',),
'havmus': ('havmus',),
'havmusa': ('havmus',),
'havmusen': ('havmus',),
'havmusene': ('havmus',),
'havmåka': ('havmåke',),
'havmåke': ('havmåke',),
'havmåken': ('havmåke',),
'havmåkene': ('havmåke',),
'havmåker': ('havmåke',),
'havmåse': ('havmåse',),
'havmåsen': ('havmåse',),
'havmåsene': ('havmåse',),
'havmåser': ('havmåse',),
'havn': ('havn',),
'havna': ('havn',),
'havnen': ('havn',),
'havnene': ('havn',),
'havner': ('havn',),
'havn': ('havn',),
'havna': ('havn',),
'havnen': ('havn',),
'havnene': ('havn',),
'havner': ('havn',),
'havn': ('havn',),
'havna': ('havn',),
'havnen': ('havn',),
'havnene': ('havn',),
'havner': ('havn',),
'havneanlegg': ('havneanlegg',),
'havneanlegga': ('havneanlegg',),
'havneanleggene': ('havneanlegg',),
'havneanlegget': ('havneanlegg',),
'havneanlegg': ('havneanlegg',),
'havneanlegga': ('havneanlegg',),
'havneanleggene': ('havneanlegg',),
'havneanlegget': ('havneanlegg',),
'havnearbeider': ('havnearbeider',),
'havnearbeidere': ('havnearbeider',),
'havnearbeideren': ('havnearbeider',),
'havnearbeiderer': ('havnearbeider',),
'havnearbeiderne': ('havnearbeider',),
'havnearbeider': ('havnearbeider',),
'havnearbeidere': ('havnearbeider',),
'havnearbeideren': ('havnearbeider',),
'havnearbeiderer': ('havnearbeider',),
'havnearbeiderne': ('havnearbeider',),
'havneavgift': ('havneavgift',),
'havneavgifta': ('havneavgift',),
'havneavgiften': ('havneavgift',),
'havneavgiftene': ('havneavgift',),
'havneavgifter': ('havneavgift',),
'havneavgift': ('havneavgift',),
'havneavgifta': ('havneavgift',),
'havneavgiften': ('havneavgift',),
'havneavgiftene': ('havneavgift',),
'havneavgifter': ('havneavgift',),
'havnebasseng': ('havnebasseng',),
'havnebassenga': ('havnebasseng',),
'havnebassengene': ('havnebasseng',),
'havnebassenger': ('havnebasseng',),
'havnebassenget': ('havnebasseng',),
'havnebasseng': ('havnebasseng',),
'havnebassenga': ('havnebasseng',),
'havnebassengene': ('havnebasseng',),
'havnebassenger': ('havnebasseng',),
'havnebassenget': ('havnebasseng',),
'havneby': ('havneby',),
'havnebyen': ('havneby',),
'havnebyene': ('havneby',),
'havnebyer': ('havneby',),
'havneby': ('havneby',),
'havnebyen': ('havneby',),
'havnebyene': ('havneby',),
'havnebyer': ('havneby',),
'havnefogd': ('havnefogd',),
'havnefogden': ('havnefogd',),
'havnefogdene': ('havnefogd',),
'havnefogder': ('havnefogd',),
'havnefogd': ('havnefogd',),
'havnefogden': ('havnefogd',),
'havnefogdene': ('havnefogd',),
'havnefogder': ('havnefogd',),
'havnefut': ('havnefut',),
'havnefuten': ('havnefut',),
'havnefutene': ('havnefut',),
'havnefuter': ('havnefut',),
'havnegang': ('havnegang',),
'havnegangen': ('havnegang',),
'havnegangene': ('havnegang',),
'havneganger': ('havnegang',),
'havnehage': ('havnehage',),
'havnehagen': ('havnehage',),
'havnehagene': ('havnehage',),
'havnehager': ('havnehage',),
'havnekontor': ('havnekontor',),
'havnekontora': ('havnekontor',),
'havnekontorene': ('havnekontor',),
'havnekontorer': ('havnekontor',),
'havnekontoret': ('havnekontor',),
'havnekontor': ('havnekontor',),
'havnekontora': ('havnekontor',),
'havnekontorene': ('havnekontor',),
'havnekontorer': ('havnekontor',),
'havnekontoret': ('havnekontor',),
'havnelos': ('havnelos',),
'havnelosen': ('havnelos',),
'havnelosene': ('havnelos',),
'havneloser': ('havnelos',),
'havnelos': ('havnelos',),
'havnelosen': ('havnelos',),
'havnelosene': ('havnelos',),
'havneloser': ('havnelos',),
'havnevesen': ('havnevesen',),
'havnevesena': ('havnevesen',),
'havnevesenene': ('havnevesen',),
'havnevesener': ('havnevesen',),
'havnevesenet': ('havnevesen',),
'havnevesen': ('havnevesen',),
'havnevesena': ('havnevesen',),
'havnevesenene': ('havnevesen',),
'havnevesener': ('havnevesen',),
'havnevesenet': ('havnevesen',),
'havning': ('havning',),
'havninga': ('havning',),
'havningen': ('havning',),
'havningene': ('havning',),
'havninger': ('havning',),
'havningsfe': ('havningsfe',),
'havningsfea': ('havningsfe',),
'havningsfeene': ('havningsfe',),
'havningsfeet': ('havningsfe',),
'havniøye': ('havniøye',),
'havniøyen': ('havniøye',),
'havniøyene': ('havniøye',),
'havniøyer': ('havniøye',),
'havre': ('havre',),
'havren': ('havre',),
'havrene': ('havre',),
'havrer': ('havre',),
'havregraut': ('havregraut',),
'havregrauten': ('havregraut',),
'havregrautene': ('havregraut',),
'havregrauter': ('havregraut',),
'havregryn': ('havregryn',),
'havregryna': ('havregryn',),
'havregrynene': ('havregryn',),
'havregrynet': ('havregryn',),
'havregrøt': ('havregrøt',),
'havregrøten': ('havregrøt',),
'havregrøtene': ('havregrøt',),
'havregrøter': ('havregrøt',),
'havrekjeks': ('havrekjeks',),
'havrekjeksen': ('havrekjeks',),
'havrekjeksene': ('havrekjeks',),
'havrelefsa': ('havrelefse',),
'havrelefse': ('havrelefse',),
'havrelefsen': ('havrelefse',),
'havrelefsene': ('havrelefse',),
'havrelefser': ('havrelefse',),
'havremel': ('havremel',),
'havremela': ('havremel',),
'havremelene': ('havremel',),
'havremelet': ('havremel',),
'havremjøl': ('havremjøl',),
'havremjøla': ('havremjøl',),
'havremjølene': ('havremjøl',),
'havremjølet': ('havremjøl',),
'havrerisla': ('havrerisle',),
'havrerisle': ('havrerisle',),
'havrerislen': ('havrerisle',),
'havrerislene': ('havrerisle',),
'havrerisler': ('havrerisle',),
'havresekk': ('havresekk',),
'havresekken': ('havresekk',),
'havresekkene': ('havresekk',),
'havresekker': ('havresekk',),
'havresuppa': ('havresuppe',),
'havresuppe': ('havresuppe',),
'havresuppen': ('havresuppe',),
'havresuppene': ('havresuppe',),
'havresupper': ('havresuppe',),
'havrett': ('havrett',),
'havretten': ('havrett',),
'havrettene': ('havrett',),
'havretter': ('havrett',),
'havrevelling': ('havrevelling',),
'havrevellinga': ('havrevelling',),
'havrevellingen': ('havrevelling',),
'havrevellingene': ('havrevelling',),
'havrevellinger': ('havrevelling',),
'havsalt': ('havsalt',),
'havsalta': ('havsalt',),
'havsaltene': ('havsalt',),
'havsalter': ('havsalt',),
'havsaltet': ('havsalt',),
'havsegler': ('havsegler',),
'havseglere': ('havsegler',),
'havsegleren': ('havsegler',),
'havseglerer': ('havsegler',),
'havseglerne': ('havsegler',),
'havseilas': ('havseilas',),
'havseilasen': ('havseilas',),
'havseilasene': ('havseilas',),
'havseilaser': ('havseilas',),
'havseiler': ('havseiler',),
'havseilere': ('havseiler',),
'havseileren': ('havseiler',),
'havseilerer': ('havseiler',),
'havseilerne': ('havseiler',),
'havskilpadda': ('havskilpadde',),
'havskilpadde': ('havskilpadde',),
'havskilpadden': ('havskilpadde',),
'havskilpaddene': ('havskilpadde',),
'havskilpadder': ('havskilpadde',),
'havskodda': ('havskodde',),
'havskodde': ('havskodde',),
'havskodden': ('havskodde',),
'havskoddene': ('havskodde',),
'havskodder': ('havskodde',),
'havsnød': ('havsnød',),
'havsnøda': ('havsnød',),
'havsnøden': ('havsnød',),
'havsnødene': ('havsnød',),
'havsnøder': ('havsnød',),
'havstrekning': ('havstrekning',),
'havstrekninga': ('havstrekning',),
'havstrekningen': ('havstrekning',),
'havstrekningene': ('havstrekning',),
'havstrekninger': ('havstrekning',),
'havstrøm': ('havstrøm',),
'havstrømmen': ('havstrøm',),
'havstrømmene': ('havstrøm',),
'havstrømmer': ('havstrøm',),
'havstykka': ('havstykke',),
'havstykke': ('havstykke',),
'havstykkene': ('havstykke',),
'havstykker': ('havstykke',),
'havstykket': ('havstykke',),
'havsula': ('havsule',),
'havsule': ('havsule',),
'havsulen': ('havsule',),
'havsulene': ('havsule',),
'havsuler': ('havsule',),
'havteknologi': ('havteknologi',),
'havteknologien': ('havteknologi',),
'havteknologiene': ('havteknologi',),
'havteknologier': ('havteknologi',),
'havål': ('havål',),
'havålen': ('havål',),
'havålene': ('havål',),
'havåler': ('havål',),
'havørn': ('havørn',),
'havørna': ('havørn',),
'havørnen': ('havørn',),
'havørnene': ('havørn',),
'havørner': ('havørn',),
'hawaier': ('hawaier',),
'hawaiere': ('hawaier',),
'hawaieren': ('hawaier',),
'hawaierer': ('hawaier',),
'hawaierne': ('hawaier',),
'he-man': ('he-man',),
'heading': ('heading',),
'headingen': ('heading',),
'headingene': ('heading',),
'headinger': ('heading',),
'heading': ('heading',),
'headingen': ('heading',),
'headingene': ('heading',),
'headinger': ('heading',),
'heat': ('heat',),
'heata': ('heat',),
'heatene': ('heat',),
'heatet': ('heat',),
'hebraisk': ('hebraisk',),
'hebraisken': ('hebraisk',),
'hebraiskene': ('hebraisk',),
'hebraisker': ('hebraisk',),
'hebreer': ('hebreer',),
'hebreere': ('hebreer',),
'hebreeren': ('hebreer',),
'hebreerer': ('hebreer',),
'hebreerne': ('hebreer',),
'hebrider': ('hebrider',),
'hebridere': ('hebrider',),
'hebrideren': ('hebrider',),
'hebriderer': ('hebrider',),
'hebriderne': ('hebrider',),
'hede': ('hede',),
'heden': ('hede',),
'hedene': ('hede',),
'heder': ('hede',),
'hedendom': ('hedendom',),
'hedendommen': ('hedendom',),
'hedendommene': ('hedendom',),
'hedendommer': ('hedendom',),
'hedenold': ('hedenold',),
'hedenskap': ('hedenskap',),
'hedenskapa': ('hedenskap',),
'hedenskapen': ('hedenskap',),
'hedenskapene': ('hedenskap',),
'hedenskaper': ('hedenskap',),
'hedenskapet': ('hedenskap',),
'heder': ('heder',),
'hedere': ('heder',),
'hederen': ('heder',),
'hederer': ('heder',),
'hederne': ('heder',),
'hedre': ('heder',),
'hedrene': ('heder',),
'hedrer': ('heder',),
'hederlighet': ('hederlighet',),
'hederligheta': ('hederlighet',),
'hederligheten': ('hederlighet',),
'hederlighetene': ('hederlighet',),
'hederligheter': ('hederlighet',),
'hedersbevisning': ('hedersbevisning',),
'hedersbevisninga': ('hedersbevisning',),
'hedersbevisningen': ('hedersbevisning',),
'hedersbevisningene': ('hedersbevisning',),
'hedersbevisninger': ('hedersbevisning',),
'hedersgjest': ('hedersgjest',),
'hedersgjesten': ('hedersgjest',),
'hedersgjestene': ('hedersgjest',),
'hedersgjester': ('hedersgjest',),
'hedersmann': ('hedersmann',),
'hedersmannen': ('hedersmann',),
'hedersmenn': ('hedersmann',),
'hedersmennene': ('hedersmann',),
'hedersplass': ('hedersplass',),
'hedersplassen': ('hedersplass',),
'hedersplassene': ('hedersplass',),
'hedersplasser': ('hedersplass',),
'hederstegn': ('hederstegn',),
'hederstegna': ('hederstegn',),
'hederstegnene': ('hederstegn',),
'hederstegnet': ('hederstegn',),
'hedmarking': ('hedmarking',),
'hedmarkingen': ('hedmarking',),
'hedmarkingene': ('hedmarking',),
'hedmarkinger': ('hedmarking',),
'hedning': ('hedning',),
'hedninga': ('hedning',),
'hedningen': ('hedning',),
'hedningene': ('hedning',),
'hedninger': ('hedning',),
'hedningland': ('hedningland',),
'hedninglanda': ('hedningland',),
'hedninglandene': ('hedningland',),
'hedninglandet': ('hedningland',),
'hedningmisjon': ('hedningmisjon',),
'hedningmisjonen': ('hedningmisjon',),
'hedningmisjonene': ('hedningmisjon',),
'hedningmisjoner': ('hedningmisjon',),
'hedningmisjonær': ('hedningmisjonær',),
'hedningmisjonæren': ('hedningmisjonær',),
'hedningmisjonærene': ('hedningmisjonær',),
'hedningmisjonærer': ('hedningmisjonær',),
'hedonisme': ('hedonisme',),
'hedonismen': ('hedonisme',),
'hedonismene': ('hedonisme',),
'hedonismer': ('hedonisme',),
'hedonist': ('hedonist',),
'hedonisten': ('hedonist',),
'hedonistene': ('hedonist',),
'hedonister': ('hedonist',),
'heft': ('heft',),
'heften': ('heft',),
'heftene': ('heft',),
'hefter': ('heft',),
'heft': ('heft',),
'hefta': ('heft',),
'heftene': ('heft',),
'heftet': ('heft',),
'hefta': ('hefte',),
'hefte': ('hefte',),
'heftene': ('hefte',),
'hefter': ('hefte',),
'heftet': ('hefte',),
'heftelse': ('heftelse',),
'heftelsen': ('heftelse',),
'heftelsene': ('heftelse',),
'heftelser': ('heftelse',),
'heftplaster': ('heftplaster',),
'heftplasteret': ('heftplaster',),
'heftplastra': ('heftplaster',),
'heftplastre': ('heftplaster',),
'heftplastrene': ('heftplaster',),
'heftplastret': ('heftplaster',),
'hegelianer': ('hegelianer',),
'hegelianere': ('hegelianer',),
'hegelianeren': ('hegelianer',),
'hegelianerer': ('hegelianer',),
'hegelianerne': ('hegelianer',),
'hegelianisme': ('hegelianisme',),
'hegelianismen': ('hegelianisme',),
'hegelianismene': ('hegelianisme',),
'hegelianismer': ('hegelianisme',),
'hegemoni': ('hegemoni',),
'hegemonia': ('hegemoni',),
'hegemoniene': ('hegemoni',),
'hegemonier': ('hegemoni',),
'hegemoniet': ('hegemoni',),
'hegg': ('hegg',),
'heggen': ('hegg',),
'heggene': ('hegg',),
'hegger': ('hegg',),
'heggebær': ('heggebær',),
'heggebæra': ('heggebær',),
'heggebærene': ('heggebær',),
'heggebæret': ('heggebær',),
'heggebær': ('heggebær',),
'heggebæra': ('heggebær',),
'heggebærene': ('heggebær',),
'heggebæret': ('heggebær',),
'hegn': ('hegn',),
'hegna': ('hegn',),
'hegnene': ('hegn',),
'hegnet': ('hegn',),
'hegre': ('hegre',),
'hegren': ('hegre',),
'hegrene': ('hegre',),
'hegrer': ('hegre',),
'hei': ('hei',),
'heia': ('hei',),
'heien': ('hei',),
'heiene': ('hei',),
'heier': ('hei',),
'heiagjeng': ('heiagjeng',),
'heiagjengen': ('heiagjeng',),
'heiagjengene': ('heiagjeng',),
'heiagjenger': ('heiagjeng',),
'heiarop': ('heiarop',),
'heiaropa': ('heiarop',),
'heiaropene': ('heiarop',),
'heiaropet': ('heiarop',),
'heiegard': ('heiegard',),
'heiegarden': ('heiegard',),
'heiegardene': ('heiegard',),
'heiegarder': ('heiegard',),
'heiegård': ('heiegård',),
'heiegården': ('heiegård',),
'heiegårdene': ('heiegård',),
'heiegårder': ('heiegård',),
'heigard': ('heigard',),
'heigarden': ('heigard',),
'heigardene': ('heigard',),
'heigarder': ('heigard',),
'heigård': ('heigård',),
'heigården': ('heigård',),
'heigårdene': ('heigård',),
'heigårder': ('heigård',),
'heilaften': ('heilaften',),
'heilaftenen': ('heilaften',),
'heilaftenene': ('heilaften',),
'heilaftener': ('heilaften',),
'heilbind': ('heilbind',),
'heilbinda': ('heilbind',),
'heilbindene': ('heilbind',),
'heilbindet': ('heilbind',),
'heildagspost': ('heildagspost',),
'heildagsposten': ('heildagspost',),
'heildagspostene': ('heildagspost',),
'heildagsposter': ('heildagspost',),
'heildagsstilling': ('heildagsstilling',),
'heildagsstillinga': ('heildagsstilling',),
'heildagsstillingen': ('heildagsstilling',),
'heildagsstillingene': ('heildagsstilling',),
'heildagsstillinger': ('heildagsstilling',),
'heildekkteppa': ('heildekkteppe',),
'heildekkteppe': ('heildekkteppe',),
'heildekkteppene': ('heildekkteppe',),
'heildekktepper': ('heildekkteppe',),
'heildekkteppet': ('heildekkteppe',),
'heile': ('heile',),
'heilen': ('heile',),
'heilene': ('heile',),
'heiler': ('heile',),
'heilfabrikat': ('heilfabrikat',),
'heilfabrikata': ('heilfabrikat',),
'heilfabrikatene': ('heilfabrikat',),
'heilfabrikater': ('heilfabrikat',),
'heilfabrikatet': ('heilfabrikat',),
'heilfigur': ('heilfigur',),
'heilfiguren': ('heilfigur',),
'heilfigurene': ('heilfigur',),
'heilfigurer': ('heilfigur',),
'heilflaska': ('heilflaske',),
'heilflaske': ('heilflaske',),
'heilflasken': ('heilflaske',),
'heilflaskene': ('heilflaske',),
'heilflasker': ('heilflaske',),
'heilhet': ('heilhet',),
'heilheta': ('heilhet',),
'heilheten': ('heilhet',),
'heilhetene': ('heilhet',),
'heilheter': ('heilhet',),
'heilhetsinntrykk': ('heilhetsinntrykk',),
'heilhetsinntrykka': ('heilhetsinntrykk',),
'heilhetsinntrykkene': ('heilhetsinntrykk',),
'heilhetsinntrykket': ('heilhetsinntrykk',),
'heilhetsløsning': ('heilhetsløsning',),
'heilhetsløsninga': ('heilhetsløsning',),
'heilhetsløsningen': ('heilhetsløsning',),
'heilhetsløsningene': ('heilhetsløsning',),
'heilhetsløsninger': ('heilhetsløsning',),
'heilhetssyn': ('heilhetssyn',),
'heilhetssyna': ('heilhetssyn',),
'heilhetssynene': ('heilhetssyn',),
'heilhetssynet': ('heilhetssyn',),
'heilhetsvirkning': ('heilhetsvirkning',),
'heilhetsvirkninga': ('heilhetsvirkning',),
'heilhetsvirkningen': ('heilhetsvirkning',),
'heilhetsvirkningene': ('heilhetsvirkning',),
'heilhetsvirkninger': ('heilhetsvirkning',),
'heilkornbrød': ('heilkornbrød',),
'heilkornbrøda': ('heilkornbrød',),
'heilkornbrødene': ('heilkornbrød',),
'heilkornbrødet': ('heilkornbrød',),
'heilmelk': ('heilmelk',),
'heilmelka': ('heilmelk',),
'heilmelken': ('heilmelk',),
'heilmelkene': ('heilmelk',),
'heilmelker': ('heilmelk',),
'heilnote': ('heilnote',),
'heilnoten': ('heilnote',),
'heilnotene': ('heilnote',),
'heilnoter': ('heilnote',),
'heilo': ('heilo',),
'heiloa': ('heilo',),
'heiloen': ('heilo',),
'heiloene': ('heilo',),
'heiloer': ('heilo',),
'heilomvending': ('heilomvending',),
'heilomvendinga': ('heilomvending',),
'heilomvendingen': ('heilomvending',),
'heilomvendingene': ('heilomvending',),
'heilomvendinger': ('heilomvending',),
'heilpensjon': ('heilpensjon',),
'heilpensjonen': ('heilpensjon',),
'heilpensjonene': ('heilpensjon',),
'heilpensjoner': ('heilpensjon',),
'heilrim': ('heilrim',),
'heilrima': ('heilrim',),
'heilrimene': ('heilrim',),
'heilrimet': ('heilrim',),
'heilsetning': ('heilsetning',),
'heilsetninga': ('heilsetning',),
'heilsetningen': ('heilsetning',),
'heilsetningene': ('heilsetning',),
'heilsetninger': ('heilsetning',),
'heilsida': ('heilside',),
'heilside': ('heilside',),
'heilsiden': ('heilside',),
'heilsidene': ('heilside',),
'heilsider': ('heilside',),
'heilskap': ('heilskap',),
'heilskapen': ('heilskap',),
'heilskapene': ('heilskap',),
'heilskaper': ('heilskap',),
'heilskjegg': ('heilskjegg',),
'heilskjegga': ('heilskjegg',),
'heilskjeggene': ('heilskjegg',),
'heilskjegget': ('heilskjegg',),
'heilskru': ('heilskru',),
'heilskruen': ('heilskru',),
'heilskruene': ('heilskru',),
'heilskruer': ('heilskru',),
'heilslank': ('heilslank',),
'heilspenn': ('heilspenn',),
'heilspenna': ('heilspenn',),
'heilspennene': ('heilspenn',),
'heilspennet': ('heilspenn',),
'heilstaut': ('heilstaut',),
'heilstikk': ('heilstikk',),
'heilstikka': ('heilstikk',),
'heilstikkene': ('heilstikk',),
'heilstikket': ('heilstikk',),
'heilsøsken': ('heilsøsken',),
'heilsøskena': ('heilsøsken',),
'heilsøskenet': ('heilsøsken',),
'heilsøsknene': ('heilsøsken',),
'heiltal': ('heiltal',),
'heiltala': ('heiltal',),
'heiltalene': ('heiltal',),
'heiltalet': ('heiltal',),
'heiltall': ('heiltall',),
'heiltalla': ('heiltall',),
'heiltallene': ('heiltall',),
'heiltallet': ('heiltall',),
'heiltid': ('heiltid',),
'heiltidsstilling': ('heiltidsstilling',),
'heiltidsstillinga': ('heiltidsstilling',),
'heiltidsstillingen': ('heiltidsstilling',),
'heiltidsstillingene': ('heiltidsstilling',),
'heiltidsstillinger': ('heiltidsstilling',),
'heiltone': ('heiltone',),
'heiltonen': ('heiltone',),
'heiltonene': ('heiltone',),
'heiltoner': ('heiltone',),
'heiltonetrinn': ('heiltonetrinn',),
'heiltonetrinna': ('heiltonetrinn',),
'heiltonetrinnene': ('heiltonetrinn',),
'heiltonetrinnet': ('heiltonetrinn',),
'heilull': ('heilull',),
'heilulla': ('heilull',),
'heilullen': ('heilull',),
'heilullene': ('heilull',),
'heiluller': ('heilull',),
'heilårsdrift': ('heilårsdrift',),
'heilårsdrifta': ('heilårsdrift',),
'heilårsdriften': ('heilårsdrift',),
'heilårsdriftene': ('heilårsdrift',),
'heilårsdrifter': ('heilårsdrift',),
'heilårsforbindelse': ('heilårsforbindelse',),
'heilårsforbindelsen': ('heilårsforbindelse',),
'heilårsforbindelsene': ('heilårsforbindelse',),
'heilårsforbindelser': ('heilårsforbindelse',),
'heilårsveg': ('heilårsveg',),
'heilårsvegen': ('heilårsveg',),
'heilårsvegene': ('heilårsveg',),
'heilårsveger': ('heilårsveg',),
'heilårsvei': ('heilårsvei',),
'heilårsveien': ('heilårsvei',),
'heilårsveiene': ('heilårsvei',),
'heilårsveier': ('heilårsvei',),
'heim': ('heim',),
'heimen': ('heim',),
'heimene': ('heim',),
'heimer': ('heim',),
'heim': ('heim',),
'heimen': ('heim',),
'heimene': ('heim',),
'heimer': ('heim',),
'heimafølgja': ('heimafølgje',),
'heimafølgje': ('heimafølgje',),
'heimafølgjen': ('heimafølgje',),
'heimafølgjene': ('heimafølgje',),
'heimafølgjer': ('heimafølgje',),
'heimanfølgja': ('heimanfølgje',),
'heimanfølgje': ('heimanfølgje',),
'heimanfølgjen': ('heimanfølgje',),
'heimanfølgjene': ('heimanfølgje',),
'heimanfølgjer': ('heimanfølgje',),
'heimby': ('heimby',),
'heimbyen': ('heimby',),
'heimbyene': ('heimby',),
'heimbyer': ('heimby',),
'heimbygd': ('heimbygd',),
'heimbygda': ('heimbygd',),
'heimbygden': ('heimbygd',),
'heimbygdene': ('heimbygd',),
'heimbygder': ('heimbygd',),
'heimearbeid': ('heimearbeid',),
'heimearbeida': ('heimearbeid',),
'heimearbeidene': ('heimearbeid',),
'heimearbeider': ('heimearbeid',),
'heimearbeidet': ('heimearbeid',),
'heimebakeri': ('heimebakeri',),
'heimebakeria': ('heimebakeri',),
'heimebakeriene': ('heimebakeri',),
'heimebakerier': ('heimebakeri',),
'heimebakeriet': ('heimebakeri',),
'heimebane': ('heimebane',),
'heimebanen': ('heimebane',),
'heimebanene': ('heimebane',),
'heimebaner': ('heimebane',),
'heimebrenner': ('heimebrenner',),
'heimebrennere': ('heimebrenner',),
'heimebrenneren': ('heimebrenner',),
'heimebrennerer': ('heimebrenner',),
'heimebrennerne': ('heimebrenner',),
'heimebrenning': ('heimebrenning',),
'heimebrenninga': ('heimebrenning',),
'heimebrenningen': ('heimebrenning',),
'heimebrenningene': ('heimebrenning',),
'heimebrenninger': ('heimebrenning',),
'heimebrent': ('heimebrent',),
'heimebrenten': ('heimebrent',),
'heimebrentene': ('heimebrent',),
'heimebrenter': ('heimebrent',),
'heimebrygg': ('heimebrygg',),
'heimebrygga': ('heimebrygg',),
'heimebryggene': ('heimebrygg',),
'heimebrygget': ('heimebrygg',),
'heimedatamaskin': ('heimedatamaskin',),
'heimedatamaskina': ('heimedatamaskin',),
'heimedatamaskinen': ('heimedatamaskin',),
'heimedatamaskinene': ('heimedatamaskin',),
'heimedatamaskiner': ('heimedatamaskin',),
'heimedåp': ('heimedåp',),
'heimedåpen': ('heimedåp',),
'heimedåpene': ('heimedåp',),
'heimedåper': ('heimedåp',),
'heimefiska': ('heimefiske',),
'heimefiske': ('heimefiske',),
'heimefiskene': ('heimefiske',),
'heimefisker': ('heimefiske',),
'heimefisket': ('heimefiske',),
'heimefront': ('heimefront',),
'heimefronten': ('heimefront',),
'heimefrontene': ('heimefront',),
'heimefronter': ('heimefront',),
'heimehjelp': ('heimehjelp',),
'heimehjelpa': ('heimehjelp',),
'heimehjelpen': ('heimehjelp',),
'heimehjelpene': ('heimehjelp',),
'heimehjelper': ('heimehjelp',),
'heimehjelper': ('heimehjelper',),
'heimehjelpere': ('heimehjelper',),
'heimehjelperen': ('heimehjelper',),
'heimehjelperer': ('heimehjelper',),
'heimehjelperne': ('heimehjelper',),
'heimeindustri': ('heimeindustri',),
'heimeindustrien': ('heimeindustri',),
'heimeindustriene': ('heimeindustri',),
'heimeindustrier': ('heimeindustri',),
'heimekamp': ('heimekamp',),
'heimekampen': ('heimekamp',),
'heimekampene': ('heimekamp',),
'heimekamper': ('heimekamp',),
'heimel': ('heimel',),
'heimelen': ('heimel',),
'heimlene': ('heimel',),
'heimler': ('heimel',),
'heimelag': ('heimelag',),
'heimelaga': ('heimelag',),
'heimelagene': ('heimelag',),
'heimelaget': ('heimelag',),
'heimeleksa': ('heimelekse',),
'heimelekse': ('heimelekse',),
'heimeleksen': ('heimelekse',),
'heimeleksene': ('heimelekse',),
'heimelekser': ('heimelekse',),
'heimelsmann': ('heimelsmann',),
'heimelsmannen': ('heimelsmann',),
'heimelsmenn': ('heimelsmann',),
'heimelsmennene': ('heimelsmann',),
'heimemarked': ('heimemarked',),
'heimemarkeda': ('heimemarked',),
'heimemarkedene': ('heimemarked',),
'heimemarkeder': ('heimemarked',),
'heimemarkedet': ('heimemarked',),
'heimemarknad': ('heimemarknad',),
'heimemarknaden': ('heimemarknad',),
'heimemarknadene': ('heimemarknad',),
'heimemarknader': ('heimemarknad',),
'heimeoppgava': ('heimeoppgave',),
'heimeoppgave': ('heimeoppgave',),
'heimeoppgaven': ('heimeoppgave',),
'heimeoppgavene': ('heimeoppgave',),
'heimeoppgaver': ('heimeoppgave',),
'heimeregning': ('heimeregning',),
'heimeregninga': ('heimeregning',),
'heimeregningen': ('heimeregning',),
'heimeregningene': ('heimeregning',),
'heimeregninger': ('heimeregning',),
'heimerekning': ('heimerekning',),
'heimerekninga': ('heimerekning',),
'heimerekningen': ('heimerekning',),
'heimerekningene': ('heimerekning',),
'heimerekninger': ('heimerekning',),
'heimesitter': ('heimesitter',),
'heimesittere': ('heimesitter',),
'heimesitteren': ('heimesitter',),
'heimesitterer': ('heimesitter',),
'heimesitterne': ('heimesitter',),
'heimesitter': ('heimesitter',),
'heimesittere': ('heimesitter',),
'heimesitteren': ('heimesitter',),
'heimesitterer': ('heimesitter',),
'heimesitterne': ('heimesitter',),
'heimesitting': ('heimesitting',),
'heimesittinga': ('heimesitting',),
'heimesittingen': ('heimesitting',),
'heimesittingene': ('heimesitting',),
'heimesittinger': ('heimesitting',),
'heimesjukepleia': ('heimesjukepleie',),
'heimesjukepleie': ('heimesjukepleie',),
'heimesjukepleien': ('heimesjukepleie',),
'heimesjukepleiene': ('heimesjukepleie',),
'heimesjukepleier': ('heimesjukepleie',),
'heimestyrke': ('heimestyrke',),
'heimestyrken': ('heimestyrke',),
'heimestyrkene': ('heimestyrke',),
'heimestyrker': ('heimestyrke',),
'heimesykepleia': ('heimesykepleie',),
'heimesykepleie': ('heimesykepleie',),
'heimesykepleien': ('heimesykepleie',),
'heimesykepleiene': ('heimesykepleie',),
'heimesykepleier': ('heimesykepleie',),
'heimeulykka': ('heimeulykke',),
'heimeulykke': ('heimeulykke',),
'heimeulykken': ('heimeulykke',),
'heimeulykkene': ('heimeulykke',),
'heimeulykker': ('heimeulykke',),
'heimevern': ('heimevern',),
'heimeverna': ('heimevern',),
'heimevernene': ('heimevern',),
'heimevernet': ('heimevern',),
'heimfall': ('heimfall',),
'heimfalla': ('heimfall',),
'heimfallene': ('heimfall',),
'heimfallet': ('heimfall',),
'heimfallsrett': ('heimfallsrett',),
'heimfallsretten': ('heimfallsrett',),
'heimfallsrettene': ('heimfallsrett',),
'heimfallsretter': ('heimfallsrett',),
'heimforsikring': ('heimforsikring',),
'heimforsikringa': ('heimforsikring',),
'heimforsikringen': ('heimforsikring',),
'heimforsikringene': ('heimforsikring',),
'heimforsikringer': ('heimforsikring',),
'heimføding': ('heimføding',),
'heimfødingen': ('heimføding',),
'heimfødingene': ('heimføding',),
'heimfødinger': ('heimføding',),
'heimhug': ('heimhug',),
'heimhugen': ('heimhug',),
'heimhugene': ('heimhug',),
'heimhuger': ('heimhug',),
'heimkjensla': ('heimkjensle',),
'heimkjensle': ('heimkjensle',),
'heimkjenslen': ('heimkjensle',),
'heimkjenslene': ('heimkjensle',),
'heimkjensler': ('heimkjensle',),
'heimkjøp': ('heimkjøp',),
'heimkjøpa': ('heimkjøp',),
'heimkjøpene': ('heimkjøp',),
'heimkjøpet': ('heimkjøp',),
'heimkommerøl': ('heimkommerøl',),
'heimkommerøla': ('heimkommerøl',),
'heimkommerølene': ('heimkommerøl',),
'heimkommerølet': ('heimkommerøl',),
'heimkommune': ('heimkommune',),
'heimkommunen': ('heimkommune',),
'heimkommunene': ('heimkommune',),
'heimkommuner': ('heimkommune',),
'heimkomst': ('heimkomst',),
'heimkomsten': ('heimkomst',),
'heimkomstene': ('heimkomst',),
'heimkomster': ('heimkomst',),
'heimkunnskap': ('heimkunnskap',),
'heimkunnskapen': ('heimkunnskap',),
'heimkunnskapene': ('heimkunnskap',),
'heimkunnskaper': ('heimkunnskap',),
'heimland': ('heimland',),
'heimlanda': ('heimland',),
'heimlandene': ('heimland',),
'heimlandet': ('heimland',),
'heimlengsel': ('heimlengsel',),
'heimlengselen': ('heimlengsel',),
'heimlengslene': ('heimlengsel',),
'heimlengsler': ('heimlengsel',),
'heimlengt': ('heimlengt',),
'heimlengten': ('heimlengt',),
'heimlengtene': ('heimlengt',),
'heimlengter': ('heimlengt',),
'heimlov': ('heimlov',),
'heimloven': ('heimlov',),
'heimlovene': ('heimlov',),
'heimlover': ('heimlov',),
'heimlån': ('heimlån',),
'heimlåna': ('heimlån',),
'heimlånene': ('heimlån',),
'heimlånet': ('heimlån',),
'heimrast': ('heimrast',),
'heimrasten': ('heimrast',),
'heimrastene': ('heimrast',),
'heimraster': ('heimrast',),
'heimreisa': ('heimreise',),
'heimreise': ('heimreise',),
'heimreisen': ('heimreise',),
'heimreisene': ('heimreise',),
'heimreiser': ('heimreise',),
'heimseter': ('heimseter',),
'heimseteren': ('heimseter',),
'heimsetra': ('heimseter',),
'heimsetre': ('heimseter',),
'heimsetrene': ('heimseter',),
'heimsetrer': ('heimseter',),
'heimstad': ('heimstad',),
'heimstaden': ('heimstad',),
'heimstedene': ('heimstad',),
'heimsteder': ('heimstad',),
'heimstad': ('heimstad',),
'heimstaden': ('heimstad',),
'heimstedene': ('heimstad',),
'heimsteder': ('heimstad',),
'heimstaddikting': ('heimstaddikting',),
'heimstaddiktinga': ('heimstaddikting',),
'heimstaddiktingen': ('heimstaddikting',),
'heimstaddiktingene': ('heimstaddikting',),
'heimstaddiktinger': ('heimstaddikting',),
'heimstaddiktning': ('heimstaddiktning',),
'heimstaddiktninga': ('heimstaddiktning',),
'heimstaddiktningen': ('heimstaddiktning',),
'heimstaddiktningene': ('heimstaddiktning',),
'heimstaddiktninger': ('heimstaddiktning',),
'heimstadlæra': ('heimstadlære',),
'heimstadlære': ('heimstadlære',),
'heimstadlæren': ('heimstadlære',),
'heimstadlærene': ('heimstadlære',),
'heimstadlærer': ('heimstadlære',),
'heimsted': ('heimsted',),
'heimstedene': ('heimsted',),
'heimsteder': ('heimsted',),
'heimstedet': ('heimsted',),
'heimstøl': ('heimstøl',),
'heimstølen': ('heimstøl',),
'heimstølene': ('heimstøl',),
'heimstøler': ('heimstøl',),
'heimtur': ('heimtur',),
'heimturen': ('heimtur',),
'heimturene': ('heimtur',),
'heimturer': ('heimtur',),
'heimveg': ('heimveg',),
'heimvegen': ('heimveg',),
'heimvegene': ('heimveg',),
'heimveger': ('heimveg',),
'heimvei': ('heimvei',),
'heimveien': ('heimvei',),
'heimveiene': ('heimvei',),
'heimveier': ('heimvei',),
'heimvist': ('heimvist',),
'heimvista': ('heimvist',),
'heimvisten': ('heimvist',),
'heimvistene': ('heimvist',),
'heimvister': ('heimvist',),
'hein': ('hein',),
'heinen': ('hein',),
'heinene': ('hein',),
'heiner': ('hein',),
'heis': ('heis',),
'heisen': ('heis',),
'heisene': ('heis',),
'heiser': ('heis',),
'heis': ('heis',),
'heisa': ('heis',),
'heisene': ('heis',),
'heiset': ('heis',),
'heisatur': ('heisatur',),
'heisaturen': ('heisatur',),
'heisaturene': ('heisatur',),
'heisaturer': ('heisatur',),
'heisekran': ('heisekran',),
'heisekrana': ('heisekran',),
'heisekranen': ('heisekran',),
'heisekranene': ('heisekran',),
'heisekraner': ('heisekran',),
'heisfører': ('heisfører',),
'heisførere': ('heisfører',),
'heisføreren': ('heisfører',),
'heisførerer': ('heisfører',),
'heisførerne': ('heisfører',),
'heismontør': ('heismontør',),
'heismontøren': ('heismontør',),
'heismontørene': ('heismontør',),
'heismontører': ('heismontør',),
'heissjakt': ('heissjakt',),
'heissjakta': ('heissjakt',),
'heissjakten': ('heissjakt',),
'heissjaktene': ('heissjakt',),
'heissjakter': ('heissjakt',),
'heitevegg': ('heitevegg',),
'heiteveggen': ('heitevegg',),
'heiteveggene': ('heitevegg',),
'heitevegger': ('heitevegg',),
'heiti': ('heiti',),
'heitia': ('heiti',),
'heitiene': ('heiti',),
'heitiet': ('heiti',),
'heitvin': ('heitvin',),
'heitvinen': ('heitvin',),
'heitvinene': ('heitvin',),
'heitviner': ('heitvin',),
'hekatombe': ('hekatombe',),
'hekatomben': ('hekatombe',),
'hekatombene': ('hekatombe',),
'hekatomber': ('hekatombe',),
'hekk': ('hekk',),
'hekken': ('hekk',),
'hekkene': ('hekk',),
'hekker': ('hekk',),
'hekk': ('hekk',),
'hekken': ('hekk',),
'hekkene': ('hekk',),
'hekker': ('hekk',),
'hekkbåt': ('hekkbåt',),
'hekkbåten': ('hekkbåt',),
'hekkbåtene': ('hekkbåt',),
'hekkbåter': ('hekkbåt',),
'hekkeløp': ('hekkeløp',),
'hekkeløpa': ('hekkeløp',),
'hekkeløpene': ('hekkeløp',),
'hekkeløpet': ('hekkeløp',),
'hekkeløper': ('hekkeløper',),
'hekkeløpere': ('hekkeløper',),
'hekkeløperen': ('hekkeløper',),
'hekkeløperer': ('hekkeløper',),
'hekkeløperne': ('hekkeløper',),
'hekkeplass': ('hekkeplass',),
'hekkeplassen': ('hekkeplass',),
'hekkeplassene': ('hekkeplass',),
'hekkeplasser': ('hekkeplass',),
'hekkmotor': ('hekkmotor',),
'hekkmotoren': ('hekkmotor',),
'hekkmotorene': ('hekkmotor',),
'hekkmotorer': ('hekkmotor',),
'hekktråler': ('hekktråler',),
'hekktrålere': ('hekktråler',),
'hekktråleren': ('hekktråler',),
'hekktrålerer': ('hekktråler',),
'hekktrålerne': ('hekktråler',),
'hekla': ('hekle',),
'hekle': ('hekle',),
'heklen': ('hekle',),
'heklene': ('hekle',),
'hekler': ('hekle',),
'heklenål': ('heklenål',),
'heklenåla': ('heklenål',),
'heklenålen': ('heklenål',),
'heklenålene': ('heklenål',),
'heklenåler': ('heklenål',),
'hekleteppa': ('hekleteppe',),
'hekleteppe': ('hekleteppe',),
'hekleteppene': ('hekleteppe',),
'hekletepper': ('hekleteppe',),
'hekleteppet': ('hekleteppe',),
'hekletøy': ('hekletøy',),
'hekletøya': ('hekletøy',),
'hekletøyene': ('hekletøy',),
'hekletøyer': ('hekletøy',),
'hekletøyet': ('hekletøy',),
'heks': ('heks',),
'heksa': ('heks',),
'heksen': ('heks',),
'heksene': ('heks',),
'hekser': ('heks',),
'heksaeder': ('heksaeder',),
'heksaederet': ('heksaeder',),
'heksaedra': ('heksaeder',),
'heksaedre': ('heksaeder',),
'heksaedrene': ('heksaeder',),
'heksaedret': ('heksaeder',),
'heksameter': ('heksameter',),
'heksameteret': ('heksameter',),
'heksametra': ('heksameter',),
'heksametre': ('heksameter',),
'heksametrene': ('heksameter',),
'heksametret': ('heksameter',),
'heksebrenning': ('heksebrenning',),
'heksebrenninga': ('heksebrenning',),
'heksebrenningen': ('heksebrenning',),
'heksebrenningene': ('heksebrenning',),
'heksebrenninger': ('heksebrenning',),
'heksedans': ('heksedans',),
'heksedansen': ('heksedans',),
'heksedansene': ('heksedans',),
'heksedanser': ('heksedans',),
'heksegryta': ('heksegryte',),
'heksegryte': ('heksegryte',),
'heksegryten': ('heksegryte',),
'heksegrytene': ('heksegryte',),
'heksegryter': ('heksegryte',),
'heksekunst': ('heksekunst',),
'heksekunsten': ('heksekunst',),
'heksekunstene': ('heksekunst',),
'heksekunster': ('heksekunst',),
'hekseprosess': ('hekseprosess',),
'hekseprosessen': ('hekseprosess',),
'hekseprosessene': ('hekseprosess',),
'hekseprosesser': ('hekseprosess',),
'hekseri': ('hekseri',),
'hekseria': ('hekseri',),
'hekseriene': ('hekseri',),
'hekserier': ('hekseri',),
'hekseriet': ('hekseri',),
'heksering': ('heksering',),
'hekseringen': ('heksering',),
'hekseringene': ('heksering',),
'hekseringer': ('heksering',),
'heksesabbat': ('heksesabbat',),
'heksesabbaten': ('heksesabbat',),
'heksesabbatene': ('heksesabbat',),
'heksesabbater': ('heksesabbat',),
'hekseskott': ('hekseskott',),
'hekseskotta': ('hekseskott',),
'hekseskottene': ('hekseskott',),
'hekseskottet': ('hekseskott',),
'hekseskudd': ('hekseskudd',),
'hekseskudda': ('hekseskudd',),
'hekseskuddene': ('hekseskudd',),
'hekseskuddet': ('hekseskudd',),
'hekt': ('hekt',),
'hekta': ('hekt',),
'hekten': ('hekt',),
'hektene': ('hekt',),
'hekter': ('hekt',),
'hektar': ('hektar',),
'hektara': ('hektar',),
'hektarene': ('hektar',),
'hektaret': ('hektar',),
'hekta': ('hekte',),
'hekte': ('hekte',),
'hekten': ('hekte',),
'hektene': ('hekte',),
'hekter': ('hekte',),
'hekto': ('hekto',),
'hektoa': ('hekto',),
'hektoen': ('hekto',),
'hektoene': ('hekto',),
'hektoet': ('hekto',),
'hektograf': ('hektograf',),
'hektografen': ('hektograf',),
'hektografene': ('hektograf',),
'hektografer': ('hektograf',),
'hektogram': ('hektogram',),
'hektogramma': ('hektogram',),
'hektogrammene': ('hektogram',),
'hektogrammet': ('hektogram',),
'hel': ('hel',),
'hel': ('hel',),
'helaften': ('helaften',),
'helaftenen': ('helaften',),
'helaftenene': ('helaften',),
'helaftener': ('helaften',),
'helbind': ('helbind',),
'helbinda': ('helbind',),
'helbindene': ('helbind',),
'helbindet': ('helbind',),
'helbred': ('helbred',),
'helbreden': ('helbred',),
'helbredene': ('helbred',),
'helbreder': ('helbred',),
'helbredelse': ('helbredelse',),
'helbredelsen': ('helbredelse',),
'helbredelsene': ('helbredelse',),
'helbredelser': ('helbredelse',),
'helbredshensyn': ('helbredshensyn',),
'helbredshensyna': ('helbredshensyn',),
'helbredshensynene': ('helbredshensyn',),
'helbredshensynet': ('helbredshensyn',),
'heldagsstilling': ('heldagsstilling',),
'heldagsstillinga': ('heldagsstilling',),
'heldagsstillingen': ('heldagsstilling',),
'heldagsstillingene': ('heldagsstilling',),
'heldagsstillinger': ('heldagsstilling',),
'helda': ('helde',),
'helde': ('helde',),
'helden': ('helde',),
'heldene': ('helde',),
'helder': ('helde',),
'heldekkteppa': ('heldekkteppe',),
'heldekkteppe': ('heldekkteppe',),
'heldekkteppene': ('heldekkteppe',),
'heldekktepper': ('heldekkteppe',),
'heldekkteppet': ('heldekkteppe',),
'heldiggris': ('heldiggris',),
'heldiggrisen': ('heldiggris',),
'heldiggrisene': ('heldiggris',),
'heldiggriser': ('heldiggris',),
'hela': ('hele',),
'hele': ('hele',),
'helene': ('hele',),
'heler': ('hele',),
'helet': ('hele',),
'hela': ('hele',),
'hele': ('hele',),
'helen': ('hele',),
'helene': ('hele',),
'heler': ('hele',),
'heler': ('heler',),
'helere': ('heler',),
'heleren': ('heler',),
'helerer': ('heler',),
'helerne': ('heler',),
'heleri': ('heleri',),
'heleria': ('heleri',),
'heleriene': ('heleri',),
'helerier': ('heleri',),
'heleriet': ('heleri',),
'helfabrikat': ('helfabrikat',),
'helfabrikata': ('helfabrikat',),
'helfabrikatene': ('helfabrikat',),
'helfabrikater': ('helfabrikat',),
'helfabrikatet': ('helfabrikat',),
'helfigur': ('helfigur',),
'helfiguren': ('helfigur',),
'helfigurene': ('helfigur',),
'helfigurer': ('helfigur',),
'helflaska': ('helflaske',),
'helflaske': ('helflaske',),
'helflasken': ('helflaske',),
'helflaskene': ('helflaske',),
'helflasker': ('helflaske',),
'helg': ('helg',),
'helga': ('helg',),
'helgen': ('helg',),
'helgene': ('helg',),
'helger': ('helg',),
'helgedag': ('helgedag',),
'helgedagen': ('helgedag',),
'helgedagene': ('helgedag',),
'helgedager': ('helgedag',),
'helgedagsfred': ('helgedagsfred',),
'helgedagsfreden': ('helgedagsfred',),
'helgedagsfredene': ('helgedagsfred',),
'helgedagsfreder': ('helgedagsfred',),
'helgefri': ('helgefri',),
'helgeklær': ('helgeklær',),
'helgeklærne': ('helgeklær',),
'helgelending': ('helgelending',),
'helgelendingen': ('helgelending',),
'helgelendingene': ('helgelending',),
'helgelendinger': ('helgelending',),
'helgemess': ('helgemess',),
'helgemess': ('helgemess',),
'helgemesse': ('helgemesse',),
'helgen': ('helgen',),
'helgenen': ('helgen',),
'helgenene': ('helgen',),
'helgener': ('helgen',),
'helgenbilda': ('helgenbilde',),
'helgenbilde': ('helgenbilde',),
'helgenbildene': ('helgenbilde',),
'helgenbilder': ('helgenbilde',),
'helgenbildet': ('helgenbilde',),
'helgendyrkelse': ('helgendyrkelse',),
'helgendyrkelsen': ('helgendyrkelse',),
'helgendyrkelsene': ('helgendyrkelse',),
'helgendyrkelser': ('helgendyrkelse',),
'helgendyrking': ('helgendyrking',),
'helgendyrkinga': ('helgendyrking',),
'helgendyrkingen': ('helgendyrking',),
'helgendyrkingene': ('helgendyrking',),
'helgendyrkinger': ('helgendyrking',),
'helgenglorie': ('helgenglorie',),
'helgenglorien': ('helgenglorie',),
'helgengloriene': ('helgenglorie',),
'helgenglorier': ('helgenglorie',),
'helgetorsdag': ('helgetorsdag',),
'helgetorsdagen': ('helgetorsdag',),
'helgetorsdagene': ('helgetorsdag',),
'helgetorsdager': ('helgetorsdag',),
'helgetur': ('helgetur',),
'helgeturen': ('helgetur',),
'helgeturene': ('helgetur',),
'helgeturer': ('helgetur',),
'helheim': ('helheim',),
'helheimen': ('helheim',),
'helheimene': ('helheim',),
'helheimer': ('helheim',),
'helhest': ('helhest',),
'helhesten': ('helhest',),
'helhestene': ('helhest',),
'helhester': ('helhest',),
'helhet': ('helhet',),
'helheta': ('helhet',),
'helheten': ('helhet',),
'helhetene': ('helhet',),
'helheter': ('helhet',),
'helhetsinntrykk': ('helhetsinntrykk',),
'helhetsinntrykka': ('helhetsinntrykk',),
'helhetsinntrykkene': ('helhetsinntrykk',),
'helhetsinntrykket': ('helhetsinntrykk',),
'helhetsløsning': ('helhetsløsning',),
'helhetsløsninga': ('helhetsløsning',),
'helhetsløsningen': ('helhetsløsning',),
'helhetsløsningene': ('helhetsløsning',),
'helhetsløsninger': ('helhetsløsning',),
'helhetssyn': ('helhetssyn',),
'helhetssyna': ('helhetssyn',),
'helhetssynene': ('helhetssyn',),
'helhetssynet': ('helhetssyn',),
'helhetsvirkning': ('helhetsvirkning',),
'helhetsvirkninga': ('helhetsvirkning',),
'helhetsvirkningen': ('helhetsvirkning',),
'helhetsvirkningene': ('helhetsvirkning',),
'helhetsvirkninger': ('helhetsvirkning',),
'helikon': ('helikon',),
'helikona': ('helikon',),
'helikonene': ('helikon',),
'helikoner': ('helikon',),
'helikonet': ('helikon',),
'helikopter': ('helikopter',),
'helikopteret': ('helikopter',),
'helikoptra': ('helikopter',),
'helikoptre': ('helikopter',),
'helikoptrene': ('helikopter',),
'helikoptret': ('helikopter',),
'helioskop': ('helioskop',),
'helioskopa': ('helioskop',),
'helioskopene': ('helioskop',),
'helioskoper': ('helioskop',),
'helioskopet': ('helioskop',),
'heliotrop': ('heliotrop',),
'heliotropen': ('heliotrop',),
'heliotropene': ('heliotrop',),
'heliotroper': ('heliotrop',),
'heliotropisme': ('heliotropisme',),
'heliotropismen': ('heliotropisme',),
'heliotropismene': ('heliotropisme',),
'heliotropismer': ('heliotropisme',),
'heliport': ('heliport',),
'heliporten': ('heliport',),
'heliportene': ('heliport',),
'heliporter': ('heliport',),
'helium': ('helium',),
'heliuma': ('helium',),
'heliumene': ('helium',),
'heliumet': ('helium',),
'helkornbrød': ('helkornbrød',),
'helkornbrøda': ('helkornbrød',),
'helkornbrødene': ('helkornbrød',),
'helkornbrødet': ('helkornbrød',),
'hella': ('helle',),
'helle': ('helle',),
'hellen': ('helle',),
'hellene': ('helle',),
'heller': ('helle',),
'hellebard': ('hellebard',),
'hellebarden': ('hellebard',),
'hellebardene': ('hellebard',),
'hellebarder': ('hellebard',),
'hellebarn': ('hellebarn',),
'hellebarna': ('hellebarn',),
'hellebarnene': ('hellebarn',),
'hellebarnet': ('hellebarn',),
'hellebrott': ('hellebrott',),
'hellebrotta': ('hellebrott',),
'hellebrottene': ('hellebrott',),
'hellebrottet': ('hellebrott',),
'hellebrudd': ('hellebrudd',),
'hellebrudda': ('hellebrudd',),
'hellebruddene': ('hellebrudd',),
'hellebruddet': ('hellebrudd',),
'hellefisk': ('hellefisk',),
'hellefisken': ('hellefisk',),
'hellefiskene': ('hellefisk',),
'hellefisker': ('hellefisk',),
'hellener': ('hellener',),
'hellenere': ('hellener',),
'helleneren': ('hellener',),
'hellenerer': ('hellener',),
'hellenerne': ('hellener',),
'hellenisme': ('hellenisme',),
'hellenismen': ('hellenisme',),
'hellenismene': ('hellenisme',),
'hellenismer': ('hellenisme',),
'hellenist': ('hellenist',),
'hellenisten': ('hellenist',),
'hellenistene': ('hellenist',),
'hellenister': ('hellenist',),
'heller': ('heller',),
'hellere': ('heller',),
'helleren': ('heller',),
'hellerer': ('heller',),
'hellerne': ('heller',),
'helleristning': ('helleristning',),
'helleristninga': ('helleristning',),
'helleristningen': ('helleristning',),
'helleristningene': ('helleristning',),
'helleristninger': ('helleristning',),
'helligbrøde': ('helligbrøde',),
'helligbrøden': ('helligbrøde',),
'helligbrødene': ('helligbrøde',),
'helligbrøder': ('helligbrøde',),
'helligdag': ('helligdag',),
'helligdagen': ('helligdag',),
'helligdagene': ('helligdag',),
'helligdager': ('helligdag',),
'helligdagsfredning': ('helligdagsfredning',),
'helligdagsfredninga': ('helligdagsfredning',),
'helligdagsfredningen': ('helligdagsfredning',),
'helligdagsfredningene': ('helligdagsfredning',),
'helligdagsfredninger': ('helligdagsfredning',),
'helligdom': ('helligdom',),
'helligdommen': ('helligdom',),
'helligdommene': ('helligdom',),
'helligdommer': ('helligdom',),
'hellighet': ('hellighet',),
'helligheta': ('hellighet',),
'helligheten': ('hellighet',),
'hellighetene': ('hellighet',),
'helligheter': ('hellighet',),
'helligtrekongersdag': ('helligtrekongersdag',),
'helligtrekongersdagen': ('helligtrekongersdag',),
'helligtrekongersdagene': ('helligtrekongersdag',),
'helligtrekongersdager': ('helligtrekongersdag',),
'helligånd': ('helligånd',),
'helligånden': ('helligånd',),
'helligåndene': ('helligånd',),
'helligånder': ('helligånd',),
'helling': ('helling',),
'hellinga': ('helling',),
'hellingen': ('helling',),
'hellingene': ('helling',),
'hellinger': ('helling',),
'helling': ('helling',),
'hellinga': ('helling',),
'hellingen': ('helling',),
'hellingene': ('helling',),
'hellinger': ('helling',),
'hellingsvinkel': ('hellingsvinkel',),
'hellingsvinkelen': ('hellingsvinkel',),
'hellingsvinklene': ('hellingsvinkel',),
'hellingsvinkler': ('hellingsvinkel',),
'helmelk': ('helmelk',),
'helmelka': ('helmelk',),
'helmelken': ('helmelk',),
'helmelkene': ('helmelk',),
'helmelker': ('helmelk',),
'helning': ('helning',),
'helninga': ('helning',),
'helningen': ('helning',),
'helningene': ('helning',),
'helninger': ('helning',),
'helningsvinkel': ('helningsvinkel',),
'helningsvinkelen': ('helningsvinkel',),
'helningsvinklene': ('helningsvinkel',),
'helningsvinkler': ('helningsvinkel',),
'helnote': ('helnote',),
'helnoten': ('helnote',),
'helnotene': ('helnote',),
'helnoter': ('helnote',),
'helomvending': ('helomvending',),
'helomvendinga': ('helomvending',),
'helomvendingen': ('helomvending',),
'helomvendingene': ('helomvending',),
'helomvendinger': ('helomvending',),
'helot': ('helot',),
'heloten': ('helot',),
'helotene': ('helot',),
'heloter': ('helot',),
'helpensjon': ('helpensjon',),
'helpensjonen': ('helpensjon',),
'helpensjonene': ('helpensjon',),
'helpensjoner': ('helpensjon',),
'helrim': ('helrim',),
'helrima': ('helrim',),
'helrimene': ('helrim',),
'helrimet': ('helrim',),
'helsa': ('helse',),
'helse': ('helse',),
'helsen': ('helse',),
'helsene': ('helse',),
'helser': ('helse',),
'helse- og velferdssentral': ('helse- og velferdssentral',),
'helse- og velferdssentralen': ('helse- og velferdssentral',),
'helse- og velferdssentralene': ('helse- og velferdssentral',),
'helse- og velferdssentraler': ('helse- og velferdssentral',),
'helseattest': ('helseattest',),
'helseattesten': ('helseattest',),
'helseattestene': ('helseattest',),
'helseattester': ('helseattest',),
'helsebot': ('helsebot',),
'helsebota': ('helsebot',),
'helseboten': ('helsebot',),
'helsebotene': ('helsebot',),
'helseboter': ('helsebot',),
'helsedirektorat': ('helsedirektorat',),
'helsedirektorata': ('helsedirektorat',),
'helsedirektoratene': ('helsedirektorat',),
'helsedirektorater': ('helsedirektorat',),
'helsedirektoratet': ('helsedirektorat',),
'helsedirektør': ('helsedirektør',),
'helsedirektøren': ('helsedirektør',),
'helsedirektørene': ('helsedirektør',),
'helsedirektører': ('helsedirektør',),
'helsedrikk': ('helsedrikk',),
'helsedrikken': ('helsedrikk',),
'helsedrikkene': ('helsedrikk',),
'helsedrikker': ('helsedrikk',),
'helsefot': ('helsefot',),
'helsefoten': ('helsefot',),
'helseføttene': ('helsefot',),
'helseføtter': ('helsefot',),
'helsefot': ('helsefot',),
'helsefoten': ('helsefot',),
'helseføttene': ('helsefot',),
'helseføtter': ('helsefot',),
'helsefysiker': ('helsefysiker',),
'helsefysikere': ('helsefysiker',),
'helsefysikeren': ('helsefysiker',),
'helsefysikerer': ('helsefysiker',),
'helsefysikerne': ('helsefysiker',),
'helsefysikk': ('helsefysikk',),
'helsefysikken': ('helsefysikk',),
'helsefysikkene': ('helsefysikk',),
'helsefysikker': ('helsefysikk',),
'helsehus': ('helsehus',),
'helsehusa': ('helsehus',),
'helsehusene': ('helsehus',),
'helsehuset': ('helsehus',),
'helseinstitusjon': ('helseinstitusjon',),
'helseinstitusjonen': ('helseinstitusjon',),
'helseinstitusjonene': ('helseinstitusjon',),
'helseinstitusjoner': ('helseinstitusjon',),
'helseknekk': ('helseknekk',),
'helseknekka': ('helseknekk',),
'helseknekken': ('helseknekk',),
'helseknekkene': ('helseknekk',),
'helseknekket': ('helseknekk',),
'helsekost': ('helsekost',),
'helsekosten': ('helsekost',),
'helsekostene': ('helsekost',),
'helsekoster': ('helsekost',),
'helselag': ('helselag',),
'helselaga': ('helselag',),
'helselagene': ('helselag',),
'helselaget': ('helselag',),
'helselæra': ('helselære',),
'helselære': ('helselære',),
'helselæren': ('helselære',),
'helselærene': ('helselære',),
'helselærer': ('helselære',),
'helseorganisasjon': ('helseorganisasjon',),
'helseorganisasjonen': ('helseorganisasjon',),
'helseorganisasjonene': ('helseorganisasjon',),
'helseorganisasjoner': ('helseorganisasjon',),
'helseplikt': ('helseplikt',),
'helseplikta': ('helseplikt',),
'helseplikten': ('helseplikt',),
'helsepliktene': ('helseplikt',),
'helseplikter': ('helseplikt',),
'helseplikt': ('helseplikt',),
'helseplikta': ('helseplikt',),
'helseplikten': ('helseplikt',),
'helsepliktene': ('helseplikt',),
'helseplikter': ('helseplikt',),
'helsereisa': ('helsereise',),
'helsereise': ('helsereise',),
'helsereisen': ('helsereise',),
'helsereisene': ('helsereise',),
'helsereiser': ('helsereise',),
'helseråd': ('helseråd',),
'helseråda': ('helseråd',),
'helserådene': ('helseråd',),
'helserådet': ('helseråd',),
'helsesenter': ('helsesenter',),
'helsesenteret': ('helsesenter',),
'helsesentra': ('helsesenter',),
'helsesentre': ('helsesenter',),
'helsesentrene': ('helsesenter',),
'helsesentret': ('helsesenter',),
'helsesport': ('helsesport',),
'helsesporten': ('helsesport',),
'helsesportene': ('helsesport',),
'helsesporter': ('helsesport',),
'helsestasjon': ('helsestasjon',),
'helsestasjonen': ('helsestasjon',),
'helsestasjonene': ('helsestasjon',),
'helsestasjoner': ('helsestasjon',),
'helsestell': ('helsestell',),
'helsestella': ('helsestell',),
'helsestellene': ('helsestell',),
'helsestellet': ('helsestell',),
'helsestudio': ('helsestudio',),
'helsestudioa': ('helsestudio',),
'helsestudioene': ('helsestudio',),
'helsestudioer': ('helsestudio',),
'helsestudioet': ('helsestudio',),
'helsesøster': ('helsesøster',),
'helsesøstera': ('helsesøster',),
'helsesøsteren': ('helsesøster',),
'helsesøstre': ('helsesøster',),
'helsesøstrene': ('helsesøster',),
'helsesøstrer': ('helsesøster',),
'helsetjeneste': ('helsetjeneste',),
'helsetjenesten': ('helsetjeneste',),
'helsetjenestene': ('helsetjeneste',),
'helsetjenester': ('helsetjeneste',),
'helsetning': ('helsetning',),
'helsetninga': ('helsetning',),
'helsetningen': ('helsetning',),
'helsetningene': ('helsetning',),
'helsetninger': ('helsetning',),
'helsetrøya': ('helsetrøye',),
'helsetrøye': ('helsetrøye',),
'helsetrøyen': ('helsetrøye',),
'helsetrøyene': ('helsetrøye',),
'helsetrøyer': ('helsetrøye',),
'helsetun': ('helsetun',),
'helsetuna': ('helsetun',),
'helsetunene': ('helsetun',),
'helsetunet': ('helsetun',),
'helsevern': ('helsevern',),
'helseverna': ('helsevern',),
'helsevernene': ('helsevern',),
'helsevernet': ('helsevern',),
'helsevesen': ('helsevesen',),
'helsevesena': ('helsevesen',),
'helsevesenene': ('helsevesen',),
'helsevesener': ('helsevesen',),
'helsevesenet': ('helsevesen',),
'helsida': ('helside',),
'helside': ('helside',),
'helsiden': ('helside',),
'helsidene': ('helside',),
'helsider': ('helside',),
'helsike': ('helsike',),
'helsing': ('helsing',),
'helsinga': ('helsing',),
'helsingen': ('helsing',),
'helsingene': ('helsing',),
'helsinger': ('helsing',),
'helskjegg': ('helskjegg',),
'helskjegga': ('helskjegg',),
'helskjeggene': ('helskjegg',),
'helskjegget': ('helskjegg',),
'helskru': ('helskru',),
'helskruen': ('helskru',),
'helskruene': ('helskru',),
'helskruer': ('helskru',),
'helslank': ('helslank',),
'helspenn': ('helspenn',),
'helspenna': ('helspenn',),
'helspennene': ('helspenn',),
'helspennet': ('helspenn',),
'helstaut': ('helstaut',),
'helstikk': ('helstikk',),
'helstikka': ('helstikk',),
'helstikkene': ('helstikk',),
'helstikket': ('helstikk',),
'helsøsken': ('helsøsken',),
'helsøskena': ('helsøsken',),
'helsøskenet': ('helsøsken',),
'helsøsknene': ('helsøsken',),
'helt': ('helt',),
'helten': ('helt',),
'heltene': ('helt',),
'helter': ('helt',),
'heltal': ('heltal',),
'heltala': ('heltal',),
'heltalene': ('heltal',),
'heltalet': ('heltal',),
'heltall': ('heltall',),
'heltalla': ('heltall',),
'heltallene': ('heltall',),
'heltallet': ('heltall',),
'heltedikt': ('heltedikt',),
'heltedikta': ('heltedikt',),
'heltediktene': ('heltedikt',),
'heltediktet': ('heltedikt',),
'heltedikting': ('heltedikting',),
'heltediktinga': ('heltedikting',),
'heltediktingen': ('heltedikting',),
'heltediktingene': ('heltedikting',),
'heltediktinger': ('heltedikting',),
'heltediktning': ('heltediktning',),
'heltediktninga': ('heltediktning',),
'heltediktningen': ('heltediktning',),
'heltediktningene': ('heltediktning',),
'heltediktninger': ('heltediktning',),
'heltedyrkelse': ('heltedyrkelse',),
'heltedyrkelsen': ('heltedyrkelse',),
'heltedyrkelsene': ('heltedyrkelse',),
'heltedyrkelser': ('heltedyrkelse',),
'heltedyrking': ('heltedyrking',),
'heltedyrkinga': ('heltedyrking',),
'heltedyrkingen': ('heltedyrking',),
'heltedyrkingene': ('heltedyrking',),
'heltedyrkinger': ('heltedyrking',),
'heltedåd': ('heltedåd',),
'heltedåden': ('heltedåd',),
'heltedådene': ('heltedåd',),
'heltedåder': ('heltedåd',),
'heltedød': ('heltedød',),
'heltedøden': ('heltedød',),
'heltedødene': ('heltedød',),
'heltedøder': ('heltedød',),
'helteepos': ('helteepos',),
'helteeposa': ('helteepos',),
'helteeposene': ('helteepos',),
'helteeposer': ('helteepos',),
'helteeposet': ('helteepos',),
'heltefond': ('heltefond',),
'heltefonda': ('heltefond',),
'heltefondene': ('heltefond',),
'heltefondet': ('heltefond',),
'heltemot': ('heltemot',),
'heltemota': ('heltemot',),
'heltemotene': ('heltemot',),
'heltemotet': ('heltemot',),
'helterolla': ('helterolle',),
'helterolle': ('helterolle',),
'helterollen': ('helterolle',),
'helterollene': ('helterolle',),
'helteroller': ('helterolle',),
'heltesagn': ('heltesagn',),
'heltesagna': ('heltesagn',),
'heltesagnene': ('heltesagn',),
'heltesagnet': ('heltesagn',),
'heltetenor': ('heltetenor',),
'heltetenoren': ('heltetenor',),
'heltetenorene': ('heltetenor',),
'heltetenorer': ('heltetenor',),
'heltid': ('heltid',),
'heltidsstilling': ('heltidsstilling',),
'heltidsstillinga': ('heltidsstilling',),
'heltidsstillingen': ('heltidsstilling',),
'heltidsstillingene': ('heltidsstilling',),
'heltidsstillinger': ('heltidsstilling',),
'heltone': ('heltone',),
'heltonen': ('heltone',),
'heltonene': ('heltone',),
'heltoner': ('heltone',),
'heltonetrinn': ('heltonetrinn',),
'heltonetrinna': ('heltonetrinn',),
'heltonetrinnene': ('heltonetrinn',),
'heltonetrinnet': ('heltonetrinn',),
'helull': ('helull',),
'helulla': ('helull',),
'helullen': ('helull',),
'helullene': ('helull',),
'heluller': ('helull',),
'helveta': ('helvete',),
'helvete': ('helvete',),
'helvetene': ('helvete',),
'helveter': ('helvete',),
'helvetet': ('helvete',),
'helvetesangst': ('helvetesangst',),
'helvetesangsten': ('helvetesangst',),
'helvetesangstene': ('helvetesangst',),
'helvetesangster': ('helvetesangst',),
'helveteseld': ('helveteseld',),
'helveteselden': ('helveteseld',),
'helveteseldene': ('helveteseld',),
'helveteselder': ('helveteseld',),
'helvetesild': ('helvetesild',),
'helvetesilden': ('helvetesild',),
'helvetesildene': ('helvetesild',),
'helvetesilder': ('helvetesild',),
'helveteslæra': ('helveteslære',),
'helveteslære': ('helveteslære',),
'helveteslæren': ('helveteslære',),
'helveteslærene': ('helveteslære',),
'helveteslærer': ('helveteslære',),
'helvetesmaskin': ('helvetesmaskin',),
'helvetesmaskina': ('helvetesmaskin',),
'helvetesmaskinen': ('helvetesmaskin',),
'helvetesmaskinene': ('helvetesmaskin',),
'helvetesmaskiner': ('helvetesmaskin',),
'helvetesstein': ('helvetesstein',),
'helvetessteinen': ('helvetesstein',),
'helvetessteinene': ('helvetesstein',),
'helvetessteiner': ('helvetesstein',),
'helvt': ('helvt',),
'helvta': ('helvt',),
'helvten': ('helvt',),
'helvtene': ('helvt',),
'helvter': ('helvt',),
'helårsdrift': ('helårsdrift',),
'helårsdrifta': ('helårsdrift',),
'helårsdriften': ('helårsdrift',),
'helårsdriftene': ('helårsdrift',),
'helårsdrifter': ('helårsdrift',),
'helårsforbindelse': ('helårsforbindelse',),
'helårsforbindelsen': ('helårsforbindelse',),
'helårsforbindelsene': ('helårsforbindelse',),
'helårsforbindelser': ('helårsforbindelse',),
'helårsveg': ('helårsveg',),
'helårsvegen': ('helårsveg',),
'helårsvegene': ('helårsveg',),
'helårsveger': ('helårsveg',),
'helårsvei': ('helårsvei',),
'helårsveien': ('helårsvei',),
'helårsveiene': ('helårsvei',),
'helårsveier': ('helårsvei',),
'hematologi': ('hematologi',),
'hematologien': ('hematologi',),
'hematologiene': ('hematologi',),
'hematologier': ('hematologi',),
'hemisfære': ('hemisfære',),
'hemisfæren': ('hemisfære',),
'hemisfærene': ('hemisfære',),
'hemisfærer': ('hemisfære',),
'hemmelighet': ('hemmelighet',),
'hemmeligheta': ('hemmelighet',),
'hemmeligheten': ('hemmelighet',),
'hemmelighetene': ('hemmelighet',),
'hemmeligheter': ('hemmelighet',),
'hemmelighetskremmer': ('hemmelighetskremmer',),
'hemmelighetskremmere': ('hemmelighetskremmer',),
'hemmelighetskremmeren': ('hemmelighetskremmer',),
'hemmelighetskremmerer': ('hemmelighetskremmer',),
'hemmelighetskremmerne': ('hemmelighetskremmer',),
'hemmelighetskremmeri': ('hemmelighetskremmeri',),
'hemmelighetskremmeria': ('hemmelighetskremmeri',),
'hemmelighetskremmeriene': ('hemmelighetskremmeri',),
'hemmelighetskremmerier': ('hemmelighetskremmeri',),
'hemmelighetskremmeriet': ('hemmelighetskremmeri',),
'hemmeligholdelse': ('hemmeligholdelse',),
'hemmeligholdelsen': ('hemmeligholdelse',),
'hemmeligholdelsene': ('hemmeligholdelse',),
'hemmeligholdelser': ('hemmeligholdelse',),
'hemming': ('hemming',),
'hemminga': ('hemming',),
'hemmingen': ('hemming',),
'hemmingene': ('hemming',),
'hemminger': ('hemming',),
'hemning': ('hemning',),
'hemninga': ('hemning',),
'hemningen': ('hemning',),
'hemningene': ('hemning',),
'hemninger': ('hemning',),
'hemofili': ('hemofili',),
'hemofilien': ('hemofili',),
'hemofiliene': ('hemofili',),
'hemofilier': ('hemofili',),
'hemoglobin': ('hemoglobin',),
'hemoglobina': ('hemoglobin',),
'hemoglobinene': ('hemoglobin',),
'hemoglobinet': ('hemoglobin',),
'hemoroide': ('hemoroide',),
'hemoroiden': ('hemoroide',),
'hemoroidene': ('hemoroide',),
'hemoroider': ('hemoroide',),
'hemp': ('hemp',),
'hempen': ('hemp',),
'hempene': ('hemp',),
'hemper': ('hemp',),
'hempa': ('hempe',),
'hempe': ('hempe',),
'hempen': ('hempe',),
'hempene': ('hempe',),
'hemper': ('hempe',),
'hems': ('hems',),
'hemsen': ('hems',),
'hemsene': ('hems',),
'hemser': ('hems',),
'hemse': ('hemse',),
'hemsen': ('hemse',),
'hemsene': ('hemse',),
'hemser': ('hemse',),
'hemsko': ('hemsko',),
'hemskoa': ('hemsko',),
'hemskoen': ('hemsko',),
'hemskoene': ('hemsko',),
'hemskor': ('hemsko',),
'hemskorne': ('hemsko',),
'henblikk': ('henblikk',),
'henblikka': ('henblikk',),
'henblikkene': ('henblikk',),
'henblikket': ('henblikk',),
'henda': ('hende',),
'hende': ('hende',),
'hendene': ('hende',),
'hender': ('hende',),
'hendet': ('hende',),
'hende': ('hende',),
'hendel': ('hendel',),
'hendelen': ('hendel',),
'hendlene': ('hendel',),
'hendler': ('hendel',),
'hendelse': ('hendelse',),
'hendelsen': ('hendelse',),
'hendelsene': ('hendelse',),
'hendelser': ('hendelse',),
'hendelsesforløp': ('hendelsesforløp',),
'hendelsesforløpa': ('hendelsesforløp',),
'hendelsesforløpene': ('hendelsesforløp',),
'hendelsesforløpet': ('hendelsesforløp',),
'hending': ('hending',),
'hendinga': ('hending',),
'hendingen': ('hending',),
'hendingene': ('hending',),
'hendinger': ('hending',),
'henførelse': ('henførelse',),
'henførelsen': ('henførelse',),
'henførelsene': ('henførelse',),
'henførelser': ('henførelse',),
'heng': ('heng',),
'henga': ('heng',),
'hengene': ('heng',),
'henget': ('heng',),
'hengeaks': ('hengeaks',),
'hengeaksa': ('hengeaks',),
'hengeaksene': ('hengeaks',),
'hengeakset': ('hengeaks',),
'hengebjerk': ('hengebjerk',),
'hengebjerka': ('hengebjerk',),
'hengebjerken': ('hengebjerk',),
'hengebjerkene': ('hengebjerk',),
'hengebjerker': ('hengebjerk',),
'hengebjørk': ('hengebjørk',),
'hengebjørka': ('hengebjørk',),
'hengebjørken': ('hengebjørk',),
'hengebjørkene': ('hengebjørk',),
'hengebjørker': ('hengebjørk',),
'hengebro': ('hengebro',),
'hengebroa': ('hengebro',),
'hengebroen': ('hengebro',),
'hengebroene': ('hengebro',),
'hengebroer': ('hengebro',),
'hengebru': ('hengebru',),
'hengebrua': ('hengebru',),
'hengebruen': ('hengebru',),
'hengebruene': ('hengebru',),
'hengebruer': ('hengebru',),
'hengefly': ('hengefly',),
'hengeflya': ('hengefly',),
'hengeflyene': ('hengefly',),
'hengeflyet': ('hengefly',),
'hengeflyger': ('hengeflyger',),
'hengeflygere': ('hengeflyger',),
'hengeflygeren': ('hengeflyger',),
'hengeflygerer': ('hengeflyger',),
'hengeflygerne': ('hengeflyger',),
'hengeflyging': ('hengeflyging',),
'hengeflyginga': ('hengeflyging',),
'hengeflygingen': ('hengeflyging',),
'hengeflygingene': ('hengeflyging',),
'hengeflyginger': ('hengeflyging',),
'hengeflying': ('hengeflying',),
'hengeflyinga': ('hengeflying',),
'hengeflyingen': ('hengeflying',),
'hengeflyingene': ('hengeflying',),
'hengeflyinger': ('hengeflying',),
'hengeglider': ('hengeglider',),
'hengeglidere': ('hengeglider',),
'hengeglideren': ('hengeglider',),
'hengegliderer': ('hengeglider',),
'hengegliderne': ('hengeglider',),
'hengegliding': ('hengegliding',),
'hengeglidinga': ('hengegliding',),
'hengeglidingen': ('hengegliding',),
'hengeglidingene': ('hengegliding',),
'hengeglidinger': ('hengegliding',),
'hengegliing': ('hengegliing',),
'hengegliinga': ('hengegliing',),
'hengegliingen': ('hengegliing',),
'hengegliingene': ('hengegliing',),
'hengegliinger': ('hengegliing',),
'hengehoda': ('hengehode',),
'hengehode': ('hengehode',),
'hengehodene': ('hengehode',),
'hengehoder': ('hengehode',),
'hengehodet': ('hengehode',),
'hengekamp': ('hengekamp',),
'hengekampen': ('hengekamp',),
'hengekampene': ('hengekamp',),
'hengekamper': ('hengekamp',),
'hengekøy': ('hengekøy',),
'hengekøya': ('hengekøy',),
'hengekøyen': ('hengekøy',),
'hengekøyene': ('hengekøy',),
'hengekøyer': ('hengekøy',),
'hengekøya': ('hengekøye',),
'hengekøye': ('hengekøye',),
'hengekøyen': ('hengekøye',),
'hengekøyene': ('hengekøye',),
'hengekøyer': ('hengekøye',),
'hengelås': ('hengelås',),
'hengelåsa': ('hengelås',),
'hengelåsen': ('hengelås',),
'hengelåsene': ('hengelås',),
'hengelåser': ('hengelås',),
'hengelåset': ('hengelås',),
'hengemage': ('hengemage',),
'hengemagen': ('hengemage',),
'hengemagene': ('hengemage',),
'hengemager': ('hengemage',),
'hengemave': ('hengemave',),
'hengemaven': ('hengemave',),
'hengemavene': ('hengemave',),
'hengemaver': ('hengemave',),
'hengemyr': ('hengemyr',),
'hengemyra': ('hengemyr',),
'hengemyren': ('hengemyr',),
'hengemyrene': ('hengemyr',),
'hengemyrer': ('hengemyr',),
'hengeparti': ('hengeparti',),
'hengepartia': ('hengeparti',),
'hengepartiene': ('hengeparti',),
'hengepartier': ('hengeparti',),
'hengepartiet': ('hengeparti',),
'henger': ('henger',),
'hengere': ('henger',),
'hengeren': ('henger',),
'hengerer': ('henger',),
'hengerne': ('henger',),
'hengeskavl': ('hengeskavl',),
'hengeskavlen': ('hengeskavl',),
'hengeskavlene': ('hengeskavl',),
'hengeskavler': ('hengeskavl',),
'hengevom': ('hengevom',),
'hengevomma': ('hengevom',),
'hengevommen': ('hengevom',),
'hengevommene': ('hengevom',),
'hengevommer': ('hengevom',),
'hengeøra': ('hengeøre',),
'hengeøre': ('hengeøre',),
'hengeørene': ('hengeøre',),
'hengeører': ('hengeøre',),
'hengeøret': ('hengeøre',),
'hengfly': ('hengfly',),
'hengflya': ('hengfly',),
'hengflyene': ('hengfly',),
'hengflyet': ('hengfly',),
'hengflyger': ('hengflyger',),
'hengflygere': ('hengflyger',),
'hengflygeren': ('hengflyger',),
'hengflygerer': ('hengflyger',),
'hengflygerne': ('hengflyger',),
'hengflyging': ('hengflyging',),
'hengflyginga': ('hengflyging',),
'hengflygingen': ('hengflyging',),
'hengflygingene': ('hengflyging',),
'hengflyginger': ('hengflyging',),
'hengflying': ('hengflying',),
'hengflyinga': ('hengflying',),
'hengflyingen': ('hengflying',),
'hengflyingene': ('hengflying',),
'hengflyinger': ('hengflying',),
'hengglider': ('hengglider',),
'hengglidere': ('hengglider',),
'hengglideren': ('hengglider',),
'henggliderer': ('hengglider',),
'henggliderne': ('hengglider',),
'henggliding': ('henggliding',),
'hengglidinga': ('henggliding',),
'hengglidingen': ('henggliding',),
'hengglidingene': ('henggliding',),
'hengglidinger': ('henggliding',),
'henggliing': ('henggliing',),
'henggliinga': ('henggliing',),
'henggliingen': ('henggliing',),
'henggliingene': ('henggliing',),
'henggliinger': ('henggliing',),
'hengivelse': ('hengivelse',),
'hengivelsen': ('hengivelse',),
'hengivelsene': ('hengivelse',),
'hengivelser': ('hengivelse',),
'hengivenhet': ('hengivenhet',),
'hengivenheta': ('hengivenhet',),
'hengivenheten': ('hengivenhet',),
'hengivenhetene': ('hengivenhet',),
'hengivenheter': ('hengivenhet',),
'hengning': ('hengning',),
'hengninga': ('hengning',),
'hengningen': ('hengning',),
'hengningene': ('hengning',),
'hengninger': ('hengning',),
'hengsel': ('hengsel',),
'hengselen': ('hengsel',),
'hengselet': ('hengsel',),
'hengsla': ('hengsel',),
'hengslene': ('hengsel',),
'hengsler': ('hengsel',),
'hengslet': ('hengsel',),
'hengsla': ('hengsle',),
'hengsle': ('hengsle',),
'hengslen': ('hengsle',),
'hengslene': ('hengsle',),
'hengsler': ('hengsle',),
'hengslet': ('hengsle',),
'henhold': ('henhold',),
'henleggelse': ('henleggelse',),
'henleggelsen': ('henleggelse',),
'henleggelsene': ('henleggelse',),
'henleggelser': ('henleggelse',),
'henna': ('henna',),
'hennaen': ('henna',),
'hennaene': ('henna',),
'hennaer': ('henna',),
'henrettelse': ('henrettelse',),
'henrettelsen': ('henrettelse',),
'henrettelsene': ('henrettelse',),
'henrettelser': ('henrettelse',),
'henry': ('henry',),
'henryen': ('henry',),
'henryene': ('henry',),
'henrykkelse': ('henrykkelse',),
'henrykkelsen': ('henrykkelse',),
'henrykkelsene': ('henrykkelse',),
'henrykkelser': ('henrykkelse',),
'henseende': ('henseende',),
'henseenden': ('henseende',),
'henseendene': ('henseende',),
'henseender': ('henseende',),
'henseendet': ('henseende',),
'hensikt': ('hensikt',),
'hensikta': ('hensikt',),
'hensikten': ('hensikt',),
'hensiktene': ('hensikt',),
'hensikter': ('hensikt',),
'hensiktskonjunksjon': ('hensiktskonjunksjon',),
'hensiktskonjunksjonen': ('hensiktskonjunksjon',),
'hensiktskonjunksjonene': ('hensiktskonjunksjon',),
'hensiktskonjunksjoner': ('hensiktskonjunksjon',),
'hensiktssetning': ('hensiktssetning',),
'hensiktssetninga': ('hensiktssetning',),
'hensiktssetningen': ('hensiktssetning',),
'hensiktssetningene': ('hensiktssetning',),
'hensiktssetninger': ('hensiktssetning',),
'henstand': ('henstand',),
'henstanden': ('henstand',),
'henstandene': ('henstand',),
'henstander': ('henstand',),
'henstilling': ('henstilling',),
'henstillinga': ('henstilling',),
'henstillingen': ('henstilling',),
'henstillingene': ('henstilling',),
'henstillinger': ('henstilling',),
'hensyn': ('hensyn',),
'hensyna': ('hensyn',),
'hensynene': ('hensyn',),
'hensynet': ('hensyn',),
'hensynsledd': ('hensynsledd',),
'hensynsledda': ('hensynsledd',),
'hensynsleddene': ('hensynsledd',),
'hensynsleddet': ('hensynsledd',),
'hensyntagen': ('hensyntagen',),
'hensyntagenen': ('hensyntagen',),
'hensyntagenene': ('hensyntagen',),
'hensyntagener': ('hensyntagen',),
'hensyntaing': ('hensyntaing',),
'hensyntainga': ('hensyntaing',),
'hensyntaingen': ('hensyntaing',),
'hensyntaingene': ('hensyntaing',),
'hensyntainger': ('hensyntaing',),
'hensyntaken': ('hensyntaken',),
'hensyntakenen': ('hensyntaken',),
'hensyntakenene': ('hensyntaken',),
'hensyntakener': ('hensyntaken',),
'hensyntaking': ('hensyntaking',),
'hensyntakinga': ('hensyntaking',),
'hensyntakingen': ('hensyntaking',),
'hensyntakingene': ('hensyntaking',),
'hensyntakinger': ('hensyntaking',),
'hentepris': ('hentepris',),
'henteprisen': ('hentepris',),
'henteprisene': ('hentepris',),
'hentepriser': ('hentepris',),
'hentesalg': ('hentesalg',),
'hentesalga': ('hentesalg',),
'hentesalgene': ('hentesalg',),
'hentesalget': ('hentesalg',),
'hentydning': ('hentydning',),
'hentydninga': ('hentydning',),
'hentydningen': ('hentydning',),
'hentydningene': ('hentydning',),
'hentydninger': ('hentydning',),
'henvendelse': ('henvendelse',),
'henvendelsen': ('henvendelse',),
'henvendelsene': ('henvendelse',),
'henvendelser': ('henvendelse',),
'henvisning': ('henvisning',),
'henvisninga': ('henvisning',),
'henvisningen': ('henvisning',),
'henvisningene': ('henvisning',),
'henvisninger': ('henvisning',),
'hepatitt': ('hepatitt',),
'hepatitten': ('hepatitt',),
'hepatittene': ('hepatitt',),
'hepatitter': ('hepatitt',),
'heppa': ('heppe',),
'heppe': ('heppe',),
'heppen': ('heppe',),
'heppene': ('heppe',),
'hepper': ('heppe',),
'heptaeder': ('heptaeder',),
'heptaederet': ('heptaeder',),
'heptaedra': ('heptaeder',),
'heptaedre': ('heptaeder',),
'heptaedrene': ('heptaeder',),
'heptaedret': ('heptaeder',),
'heptagon': ('heptagon',),
'heptagonen': ('heptagon',),
'heptagonene': ('heptagon',),
'heptagoner': ('heptagon',),
'heraldiker': ('heraldiker',),
'heraldikere': ('heraldiker',),
'heraldikeren': ('heraldiker',),
'heraldikerer': ('heraldiker',),
'heraldikerne': ('heraldiker',),
'heraldikk': ('heraldikk',),
'heraldikken': ('heraldikk',),
'heraldikkene': ('heraldikk',),
'heraldikker': ('heraldikk',),
'herbaria': ('herbarium',),
'herbariene': ('herbarium',),
'herbarier': ('herbarium',),
'herbariet': ('herbarium',),
'herbarium': ('herbarium',),
'herberga': ('herberge',),
'herberge': ('herberge',),
'herbergene': ('herberge',),
'herberger': ('herberge',),
'herberget': ('herberge',),
'herbergist': ('herbergist',),
'herbergisten': ('herbergist',),
'herbergistene': ('herbergist',),
'herbergister': ('herbergist',),
'herbicid': ('herbicid',),
'herbicida': ('herbicid',),
'herbicidene': ('herbicid',),
'herbicider': ('herbicid',),
'herbicidet': ('herbicid',),
'herd': ('herd',),
'herda': ('herd',),
'herden': ('herd',),
'herdene': ('herd',),
'herder': ('herd',),
'herdeplast': ('herdeplast',),
'herdeplasten': ('herdeplast',),
'herdeplastene': ('herdeplast',),
'herdeplaster': ('herdeplast',),
'herder': ('herder',),
'herdere': ('herder',),
'herderen': ('herder',),
'herderer': ('herder',),
'herderne': ('herder',),
'herding': ('herding',),
'herdinga': ('herding',),
'herdingen': ('herding',),
'herdingene': ('herding',),
'herdinger': ('herding',),
'herdning': ('herdning',),
'herdningen': ('herdning',),
'herdningene': ('herdning',),
'herdninger': ('herdning',),
'herdsel': ('herdsel',),
'herdselen': ('herdsel',),
'herdslene': ('herdsel',),
'herdsler': ('herdsel',),
'herdsla': ('herdsle',),
'herdsle': ('herdsle',),
'herdslen': ('herdsle',),
'herdslene': ('herdsle',),
'herdsler': ('herdsle',),
'herdslevann': ('herdslevann',),
'herdslevanna': ('herdslevann',),
'herdslevannene': ('herdslevann',),
'herdslevannet': ('herdslevann',),
'herdslevatn': ('herdslevatn',),
'herdslevatna': ('herdslevatn',),
'herdslevatnene': ('herdslevatn',),
'herdslevatnet': ('herdslevatn',),
'hereditet': ('hereditet',),
'herediteten': ('hereditet',),
'hereditetene': ('hereditet',),
'herediteter': ('hereditet',),
'heresi': ('heresi',),
'heresien': ('heresi',),
'heresiene': ('heresi',),
'heresier': ('heresi',),
'heretiker': ('heretiker',),
'heretikere': ('heretiker',),
'heretikeren': ('heretiker',),
'heretikerer': ('heretiker',),
'heretikerne': ('heretiker',),
'herk': ('herk',),
'herka': ('herk',),
'herkene': ('herk',),
'herket': ('herk',),
'herka': ('herke',),
'herke': ('herke',),
'herkene': ('herke',),
'herker': ('herke',),
'herket': ('herke',),
'herkomst': ('herkomst',),
'herkomsten': ('herkomst',),
'herkomstene': ('herkomst',),
'herkomster': ('herkomst',),
'herkulesarbeid': ('herkulesarbeid',),
'herkulesarbeida': ('herkulesarbeid',),
'herkulesarbeidene': ('herkulesarbeid',),
'herkulesarbeider': ('herkulesarbeid',),
'herkulesarbeidet': ('herkulesarbeid',),
'herkulesbedrift': ('herkulesbedrift',),
'herkulesbedriften': ('herkulesbedrift',),
'herkulesbedriftene': ('herkulesbedrift',),
'herkulesbedrifter': ('herkulesbedrift',),
'herlighet': ('herlighet',),
'herligheta': ('herlighet',),
'herligheten': ('herlighet',),
'herlighetene': ('herlighet',),
'herligheter': ('herlighet',),
'hermafroditt': ('hermafroditt',),
'hermafroditten': ('hermafroditt',),
'hermafrodittene': ('hermafroditt',),
'hermafroditter': ('hermafroditt',),
'hermafrodittisme': ('hermafrodittisme',),
'hermafrodittismen': ('hermafrodittisme',),
'hermafrodittismene': ('hermafrodittisme',),
'hermafrodittismer': ('hermafrodittisme',),
'herme': ('herme',),
'hermen': ('herme',),
'hermene': ('herme',),
'hermer': ('herme',),
'herma': ('herme',),
'herme': ('herme',),
'hermen': ('herme',),
'hermene': ('herme',),
'hermer': ('herme',),
'hermefugl': ('hermefugl',),
'hermefuglen': ('hermefugl',),
'hermefuglene': ('hermefugl',),
'hermefugler': ('hermefugl',),
'hermelin': ('hermelin',),
'hermelinen': ('hermelin',),
'hermelinene': ('hermelin',),
'hermeliner': ('hermelin',),
'hermelinskåpa': ('hermelinskåpe',),
'hermelinskåpe': ('hermelinskåpe',),
'hermelinskåpen': ('hermelinskåpe',),
'hermelinskåpene': ('hermelinskåpe',),
'hermelinskåper': ('hermelinskåpe',),
'hermeneutikk': ('hermeneutikk',),
'hermeneutikken': ('hermeneutikk',),
'hermeneutikkene': ('hermeneutikk',),
'hermeneutikker': ('hermeneutikk',),
'hermetegn': ('hermetegn',),
'hermetegna': ('hermetegn',),
'hermetegnene': ('hermetegn',),
'hermetegnet': ('hermetegn',),
'hermetikk': ('hermetikk',),
'hermetikken': ('hermetikk',),
'hermetikkene': ('hermetikk',),
'hermetikker': ('hermetikk',),
'hermetikkboks': ('hermetikkboks',),
'hermetikkboksen': ('hermetikkboks',),
'hermetikkboksene': ('hermetikkboks',),
'hermetikkbokser': ('hermetikkboks',),
'hermetikkåpner': ('hermetikkåpner',),
'hermetikkåpnere': ('hermetikkåpner',),
'hermetikkåpneren': ('hermetikkåpner',),
'hermetikkåpnerer': ('hermetikkåpner',),
'hermetikkåpnerne': ('hermetikkåpner',),
'hero': ('hero',),
'heroen': ('hero',),
'heroene': ('hero',),
'heroer': ('hero',),
'heroin': ('heroin',),
'heroina': ('heroin',),
'heroinen': ('heroin',),
'heroinene': ('heroin',),
'heroiner': ('heroin',),
'heroinet': ('heroin',),
'heroinist': ('heroinist',),
'heroinisten': ('heroinist',),
'heroinistene': ('heroinist',),
'heroinister': ('heroinist',),
'heroisme': ('heroisme',),
'heroismen': ('heroisme',),
'heroismene': ('heroisme',),
'heroismer': ('heroisme',),
'herold': ('herold',),
'herolden': ('herold',),
'heroldene': ('herold',),
'herolder': ('herold',),
'heroene': ('heros',),
'heroer': ('heros',),
'heros': ('heros',),
'herosen': ('heros',),
'herpes': ('herpes',),
'herpesen': ('herpes',),
'herpesene': ('herpes',),
'herpeser': ('herpes',),
'herr': ('herr',),
'herren': ('herr',),
'herrene': ('herr',),
'herrer': ('herr',),
'herre': ('herre',),
'herren': ('herre',),
'herrene': ('herre',),
'herrer': ('herre',),
'herrebekjentskap': ('herrebekjentskap',),
'herrebekjentskapa': ('herrebekjentskap',),
'herrebekjentskapene': ('herrebekjentskap',),
'herrebekjentskaper': ('herrebekjentskap',),
'herrebekjentskapet': ('herrebekjentskap',),
'herrebesøk': ('herrebesøk',),
'herrebesøka': ('herrebesøk',),
'herrebesøkene': ('herrebesøk',),
'herrebesøket': ('herrebesøk',),
'herred': ('herred',),
'herreda': ('herred',),
'herredene': ('herred',),
'herreder': ('herred',),
'herredet': ('herred',),
'herredag': ('herredag',),
'herredagen': ('herredag',),
'herredagene': ('herredag',),
'herredager': ('herredag',),
'herredsagronom': ('herredsagronom',),
'herredsagronomen': ('herredsagronom',),
'herredsagronomene': ('herredsagronom',),
'herredsagronomer': ('herredsagronom',),
'herredsdommer': ('herredsdommer',),
'herredsdommere': ('herredsdommer',),
'herredsdommeren': ('herredsdommer',),
'herredsdommerer': ('herredsdommer',),
'herredsdommerne': ('herredsdommer',),
'herredskommune': ('herredskommune',),
'herredskommunen': ('herredskommune',),
'herredskommunene': ('herredskommune',),
'herredskommuner': ('herredskommune',),
'herredsrett': ('herredsrett',),
'herredsretten': ('herredsrett',),
'herredsrettene': ('herredsrett',),
'herredsretter': ('herredsrett',),
'herredsskogmester': ('herredsskogmester',),
'herredsskogmestere': ('herredsskogmester',),
'herredsskogmesteren': ('herredsskogmester',),
'herredsskogmesterer': ('herredsskogmester',),
'herredsskogmesterne': ('herredsskogmester',),
'herredsskogmestre': ('herredsskogmester',),
'herredsskogmestrene': ('herredsskogmester',),
'herredsskogmestrer': ('herredsskogmester',),
'herredsstyra': ('herredsstyre',),
'herredsstyre': ('herredsstyre',),
'herredsstyrene': ('herredsstyre',),
'herredsstyrer': ('herredsstyre',),
'herredsstyret': ('herredsstyre',),
'herredømma': ('herredømme',),
'herredømme': ('herredømme',),
'herredømmene': ('herredømme',),
'herredømmer': ('herredømme',),
'herredømmet': ('herredømme',),
'herreekvipering': ('herreekvipering',),
'herreekviperinga': ('herreekvipering',),
'herreekviperingen': ('herreekvipering',),
'herreekviperingene': ('herreekvipering',),
'herreekviperinger': ('herreekvipering',),
'herreekviperingsforretning': ('herreekviperingsforretning',),
'herreekviperingsforretninga': ('herreekviperingsforretning',),
'herreekviperingsforretningen': ('herreekviperingsforretning',),
'herreekviperingsforretningene': ('herreekviperingsforretning',),
'herreekviperingsforretninger': ('herreekviperingsforretning',),
'herrefolk': ('herrefolk',),
'herrefolka': ('herrefolk',),
'herrefolkene': ('herrefolk',),
'herrefolket': ('herrefolk',),
'herrefrisør': ('herrefrisør',),
'herrefrisøren': ('herrefrisør',),
'herrefrisørene': ('herrefrisør',),
'herrefrisører': ('herrefrisør',),
'herregard': ('herregard',),
'herregarden': ('herregard',),
'herregardene': ('herregard',),
'herregarder': ('herregard',),
'herregardsvogn': ('herregardsvogn',),
'herregardsvogna': ('herregardsvogn',),
'herregardsvognen': ('herregardsvogn',),
'herregardsvognene': ('herregardsvogn',),
'herregardsvogner': ('herregardsvogn',),
'herregård': ('herregård',),
'herregården': ('herregård',),
'herregårdene': ('herregård',),
'herregårder': ('herregård',),
'herregårdsvogn': ('herregårdsvogn',),
'herregårdsvogna': ('herregårdsvogn',),
'herregårdsvognen': ('herregårdsvogn',),
'herregårdsvognene': ('herregårdsvogn',),
'herregårdsvogner': ('herregårdsvogn',),
'herrekonfeksjon': ('herrekonfeksjon',),
'herrekonfeksjonen': ('herrekonfeksjon',),
'herrekonfeksjonene': ('herrekonfeksjon',),
'herrekonfeksjoner': ('herrekonfeksjon',),
'herremann': ('herremann',),
'herremannen': ('herremann',),
'herremenn': ('herremann',),
'herremennene': ('herremann',),
'herremåltid': ('herremåltid',),
'herremåltida': ('herremåltid',),
'herremåltidene': ('herremåltid',),
'herremåltider': ('herremåltid',),
'herremåltidet': ('herremåltid',),
'herreselskap': ('herreselskap',),
'herreselskapa': ('herreselskap',),
'herreselskapene': ('herreselskap',),
'herreselskaper': ('herreselskap',),
'herreselskapet': ('herreselskap',),
'herreseta': ('herresete',),
'herresete': ('herresete',),
'herresetene': ('herresete',),
'herreseter': ('herresete',),
'herresetet': ('herresete',),
'herreskredder': ('herreskredder',),
'herreskreddere': ('herreskredder',),
'herreskredderen': ('herreskredder',),
'herreskredderer': ('herreskredder',),
'herreskredderne': ('herreskredder',),
'herresykkel': ('herresykkel',),
'herresykkelen': ('herresykkel',),
'herresyklene': ('herresykkel',),
'herresykler': ('herresykkel',),
'herretekka': ('herretekke',),
'herretekke': ('herretekke',),
'herretekkene': ('herretekke',),
'herretekker': ('herretekke',),
'herretekket': ('herretekke',),
'herretoalett': ('herretoalett',),
'herretoaletta': ('herretoalett',),
'herretoalettene': ('herretoalett',),
'herretoaletter': ('herretoalett',),
'herretoalettet': ('herretoalett',),
'herrnhuter': ('herrnhuter',),
'herrnhutere': ('herrnhuter',),
'herrnhuteren': ('herrnhuter',),
'herrnhuterer': ('herrnhuter',),
'herrnhuterne': ('herrnhuter',),
'herse': ('herse',),
'hersen': ('herse',),
'hersene': ('herse',),
'herser': ('herse',),
'herskap': ('herskap',),
'herskapa': ('herskap',),
'herskapene': ('herskap',),
'herskaper': ('herskap',),
'herskapet': ('herskap',),
'herskapshus': ('herskapshus',),
'herskapshusa': ('herskapshus',),
'herskapshusene': ('herskapshus',),
'herskapshuset': ('herskapshus',),
'hersker': ('hersker',),
'herskere': ('hersker',),
'herskeren': ('hersker',),
'herskerer': ('hersker',),
'herskerne': ('hersker',),
'hertug': ('hertug',),
'hertugen': ('hertug',),
'hertugene': ('hertug',),
'hertuger': ('hertug',),
'hertugdømma': ('hertugdømme',),
'hertugdømme': ('hertugdømme',),
'hertugdømmene': ('hertugdømme',),
'hertugdømmer': ('hertugdømme',),
'hertugdømmet': ('hertugdømme',),
'hertuginna': ('hertuginne',),
'hertuginne': ('hertuginne',),
'hertuginnen': ('hertuginne',),
'hertuginnene': ('hertuginne',),
'hertuginner': ('hertuginne',),
'hertz': ('hertz',),
'hertzen': ('hertz',),
'hertzene': ('hertz',),
'heshet': ('heshet',),
'hesheta': ('heshet',),
'hesheten': ('heshet',),
'heshetene': ('heshet',),
'hesheter': ('heshet',),
'heshet': ('heshet',),
'hesheta': ('heshet',),
'hesheten': ('heshet',),
'heshetene': ('heshet',),
'hesheter': ('heshet',),
'hesja': ('hesje',),
'hesje': ('hesje',),
'hesjen': ('hesje',),
'hesjene': ('hesje',),
'hesjer': ('hesje',),
'hesjestaur': ('hesjestaur',),
'hesjestauren': ('hesjestaur',),
'hesjestaurene': ('hesjestaur',),
'hesjestaurer': ('hesjestaur',),
'hesjetråd': ('hesjetråd',),
'hesjetråden': ('hesjetråd',),
'hesjetrådene': ('hesjetråd',),
'hesjetråder': ('hesjetråd',),
'hespa': ('hespe',),
'hespe': ('hespe',),
'hespen': ('hespe',),
'hespene': ('hespe',),
'hesper': ('hespe',),
'hespa': ('hespe',),
'hespe': ('hespe',),
'hespen': ('hespe',),
'hespene': ('hespe',),
'hesper': ('hespe',),
'hespel': ('hespel',),
'hespelen': ('hespel',),
'hesplene': ('hespel',),
'hespler': ('hespel',),
'hesperide': ('hesperide',),
'hesperiden': ('hesperide',),
'hesperidene': ('hesperide',),
'hesperider': ('hesperide',),
'hespetre': ('hespetre',),
'hespetrea': ('hespetre',),
'hespetreene': ('hespetre',),
'hespetreet': ('hespetre',),
'hest': ('hest',),
'hesten': ('hest',),
'hestene': ('hest',),
'hester': ('hest',),
'hesteansikt': ('hesteansikt',),
'hesteansikta': ('hesteansikt',),
'hesteansiktene': ('hesteansikt',),
'hesteansikter': ('hesteansikt',),
'hesteansiktet': ('hesteansikt',),
'hesteblomst': ('hesteblomst',),
'hesteblomsten': ('hesteblomst',),
'hesteblomstene': ('hesteblomst',),
'hesteblomster': ('hesteblomst',),
'hestedekken': ('hestedekken',),
'hestedekkena': ('hestedekken',),
'hestedekkenene': ('hestedekken',),
'hestedekkener': ('hestedekken',),
'hestedekkenet': ('hestedekken',),
'hestedrosja': ('hestedrosje',),
'hestedrosje': ('hestedrosje',),
'hestedrosjen': ('hestedrosje',),
'hestedrosjene': ('hestedrosje',),
'hestedrosjer': ('hestedrosje',),
'hesteføl': ('hesteføl',),
'hesteføla': ('hesteføl',),
'hestefølene': ('hesteføl',),
'hestefølet': ('hesteføl',),
'hesteføll': ('hesteføll',),
'hestefølla': ('hesteføll',),
'hesteføllene': ('hesteføll',),
'hesteføllet': ('hesteføll',),
'hestehale': ('hestehale',),
'hestehalen': ('hestehale',),
'hestehalene': ('hestehale',),
'hestehaler': ('hestehale',),
'hestehandel': ('hestehandel',),
'hestehandelen': ('hestehandel',),
'hestehandlene': ('hestehandel',),
'hestehandler': ('hestehandel',),
'hestehavre': ('hestehavre',),
'hestehavren': ('hestehavre',),
'hestehavrene': ('hestehavre',),
'hestehavrer': ('hestehavre',),
'hestehoda': ('hestehode',),
'hestehode': ('hestehode',),
'hestehodene': ('hestehode',),
'hestehoder': ('hestehode',),
'hestehodet': ('hestehode',),
'hestehår': ('hestehår',),
'hestehåra': ('hestehår',),
'hestehårene': ('hestehår',),
'hestehåret': ('hestehår',),
'hestekar': ('hestekar',),
'hestekaren': ('hestekar',),
'hestekarene': ('hestekar',),
'hestekarer': ('hestekar',),
'hestekastanje': ('hestekastanje',),
'hestekastanjen': ('hestekastanje',),
'hestekastanjene': ('hestekastanje',),
'hestekastanjer': ('hestekastanje',),
'hestekraft': ('hestekraft',),
'hestekrafta': ('hestekraft',),
'hestekraften': ('hestekraft',),
'hestekreftene': ('hestekraft',),
'hestekrefter': ('hestekraft',),
'hestekur': ('hestekur',),
'hestekuren': ('hestekur',),
'hestekurene': ('hestekur',),
'hestekurer': ('hestekur',),
'hestelengda': ('hestelengde',),
'hestelengde': ('hestelengde',),
'hestelengden': ('hestelengde',),
'hestelengdene': ('hestelengde',),
'hestelengder': ('hestelengde',),
'hestemaur': ('hestemaur',),
'hestemauren': ('hestemaur',),
'hestemaurene': ('hestemaur',),
'hestepæra': ('hestepære',),
'hestepære': ('hestepære',),
'hestepæren': ('hestepære',),
'hestepærene': ('hestepære',),
'hestepærer': ('hestepære',),
'hesterygg': ('hesterygg',),
'hesteryggen': ('hesterygg',),
'hesteryggene': ('hesterygg',),
'hesterygger': ('hesterygg',),
'hesteskjærer': ('hesteskjærer',),
'hesteskjærere': ('hesteskjærer',),
'hesteskjæreren': ('hesteskjærer',),
'hesteskjærerer': ('hesteskjærer',),
'hesteskjærerne': ('hesteskjærer',),
'hesteskomagnet': ('hesteskomagnet',),
'hesteskomagneten': ('hesteskomagnet',),
'hesteskomagnetene': ('hesteskomagnet',),
'hesteskomagneter': ('hesteskomagnet',),
'hestesport': ('hestesport',),
'hestesporten': ('hestesport',),
'hestesportene': ('hestesport',),
'hestesporter': ('hestesport',),
'hestetagl': ('hestetagl',),
'hestetagla': ('hestetagl',),
'hestetaglene': ('hestetagl',),
'hestetaglet': ('hestetagl',),
'hestevandring': ('hestevandring',),
'hestevandringa': ('hestevandring',),
'hestevandringen': ('hestevandring',),
'hestevandringene': ('hestevandring',),
'hestevandringer': ('hestevandring',),
'hesteveddeløp': ('hesteveddeløp',),
'hesteveddeløpa': ('hesteveddeløp',),
'hesteveddeløpene': ('hesteveddeløp',),
'hesteveddeløpet': ('hesteveddeløp',),
'hestføl': ('hestføl',),
'hestføla': ('hestføl',),
'hestfølene': ('hestføl',),
'hestfølet': ('hestføl',),
'hestføll': ('hestføll',),
'hestfølla': ('hestføll',),
'hestføllene': ('hestføll',),
'hestføllet': ('hestføll',),
'hestkar': ('hestkar',),
'hestkaren': ('hestkar',),
'hestkarene': ('hestkar',),
'hestkarer': ('hestkar',),
'hete': ('hete',),
'heten': ('hete',),
'hetene': ('hete',),
'heter': ('hete',),
'hetebølga': ('hetebølge',),
'hetebølge': ('hetebølge',),
'hetebølgen': ('hetebølge',),
'hetebølgene': ('hetebølge',),
'hetebølger': ('hetebølge',),
'hetebølgja': ('hetebølgje',),
'hetebølgje': ('hetebølgje',),
'hetebølgjen': ('hetebølgje',),
'hetebølgjene': ('hetebølgje',),
'hetebølgjer': ('hetebølgje',),
'hetedis': ('hetedis',),
'hetedisen': ('hetedis',),
'hetedisene': ('hetedis',),
'hetediser': ('hetedis',),
'heteflaga': ('heteflage',),
'heteflage': ('heteflage',),
'heteflagen': ('heteflage',),
'heteflagene': ('heteflage',),
'heteflager': ('heteflage',),
'heteri': ('heteri',),
'heteria': ('heteri',),
'heterien': ('heteri',),
'heteriene': ('heteri',),
'heterier': ('heteri',),
'heterofili': ('heterofili',),
'heterofilien': ('heterofili',),
'heterofiliene': ('heterofili',),
'heterofilier': ('heterofili',),
'heteromorfi': ('heteromorfi',),
'heteromorfien': ('heteromorfi',),
'heteromorfiene': ('heteromorfi',),
'heteromorfier': ('heteromorfi',),
'heteroseksualitet': ('heteroseksualitet',),
'heteroseksualiteten': ('heteroseksualitet',),
'heteroseksualitetene': ('heteroseksualitet',),
'heteroseksualiteter': ('heteroseksualitet',),
'hetetokt': ('hetetokt',),
'hetetokta': ('hetetokt',),
'hetetokten': ('hetetokt',),
'hetetoktene': ('hetetokt',),
'hetetokter': ('hetetokt',),
'hetman': ('hetman',),
'hetmanen': ('hetman',),
'hetmanene': ('hetman',),
'hetmaner': ('hetman',),
'hets': ('hets',),
'hetsen': ('hets',),
'hetsene': ('hets',),
'hetser': ('hets',),
'hetta': ('hette',),
'hette': ('hette',),
'hetten': ('hette',),
'hettene': ('hette',),
'hetter': ('hette',),
'hettekåpa': ('hettekåpe',),
'hettekåpe': ('hettekåpe',),
'hettekåpen': ('hettekåpe',),
'hettekåpene': ('hettekåpe',),
'hettekåper': ('hettekåpe',),
'hettemåka': ('hettemåke',),
'hettemåke': ('hettemåke',),
'hettemåken': ('hettemåke',),
'hettemåkene': ('hettemåke',),
'hettemåker': ('hettemåke',),
'hettemåse': ('hettemåse',),
'hettemåsen': ('hettemåse',),
'hettemåsene': ('hettemåse',),
'hettemåser': ('hettemåse',),
'hettitt': ('hettitt',),
'hettitten': ('hettitt',),
'hettittene': ('hettitt',),
'hettitter': ('hettitt',),
'hettitterrika': ('hettitterrike',),
'hettitterrike': ('hettitterrike',),
'hettitterrikene': ('hettitterrike',),
'hettitterriker': ('hettitterrike',),
'hettitterriket': ('hettitterrike',),
'hettittrika': ('hettittrike',),
'hettittrike': ('hettittrike',),
'hettittrikene': ('hettittrike',),
'hettittriker': ('hettittrike',),
'hettittriket': ('hettittrike',),
'hetvin': ('hetvin',),
'hetvinen': ('hetvin',),
'hetvinene': ('hetvin',),
'hetviner': ('hetvin',),
'hetæra': ('hetære',),
'hetære': ('hetære',),
'hetæren': ('hetære',),
'hetærene': ('hetære',),
'hetærer': ('hetære',),
'hev': ('hev',),
'heven': ('hev',),
'hevene': ('hev',),
'hever': ('hev',),
'hevarm': ('hevarm',),
'hevarmen': ('hevarm',),
'hevarmene': ('hevarm',),
'hevarmer': ('hevarm',),
'hevdnavn': ('hevdnavn',),
'hevdnavna': ('hevdnavn',),
'hevdnavnene': ('hevdnavn',),
'hevdnavnet': ('hevdnavn',),
'hevdsrett': ('hevdsrett',),
'hevdsretten': ('hevdsrett',),
'hevdsrettene': ('hevdsrett',),
'hevdsretter': ('hevdsrett',),
'hevedør': ('hevedør',),
'hevedøra': ('hevedør',),
'hevedøren': ('hevedør',),
'hevedørene': ('hevedør',),
'hevedører': ('hevedør',),
'hevelse': ('hevelse',),
'hevelsen': ('hevelse',),
'hevelsene': ('hevelse',),
'hevelser': ('hevelse',),
'hevemiddel': ('hevemiddel',),
'hevemiddelet': ('hevemiddel',),
'hevemidla': ('hevemiddel',),
'hevemidlene': ('hevemiddel',),
'hevemidler': ('hevemiddel',),
'hevemidlet': ('hevemiddel',),
'hevert': ('hevert',),
'heverten': ('hevert',),
'hevertene': ('hevert',),
'heverter': ('hevert',),
'heving': ('heving',),
'hevinga': ('heving',),
'hevingen': ('heving',),
'hevingene': ('heving',),
'hevinger': ('heving',),
'hevingsmiddel': ('hevingsmiddel',),
'hevingsmiddelet': ('hevingsmiddel',),
'hevingsmidla': ('hevingsmiddel',),
'hevingsmidlene': ('hevingsmiddel',),
'hevingsmidler': ('hevingsmiddel',),
'hevingsmidlet': ('hevingsmiddel',),
'hevn': ('hevn',),
'hevnen': ('hevn',),
'hevnene': ('hevn',),
'hevner': ('hevn',),
'hevnaksjon': ('hevnaksjon',),
'hevnaksjonen': ('hevnaksjon',),
'hevnaksjonene': ('hevnaksjon',),
'hevnaksjoner': ('hevnaksjon',),
'hevnakt': ('hevnakt',),
'hevnakta': ('hevnakt',),
'hevnakten': ('hevnakt',),
'hevnaktene': ('hevnakt',),
'hevnakter': ('hevnakt',),
'hevner': ('hevner',),
'hevnere': ('hevner',),
'hevneren': ('hevner',),
'hevnerer': ('hevner',),
'hevnerne': ('hevner',),
'hevning': ('hevning',),
'hevninga': ('hevning',),
'hevningen': ('hevning',),
'hevningene': ('hevning',),
'hevninger': ('hevning',),
'hevning': ('hevning',),
'hevninga': ('hevning',),
'hevningen': ('hevning',),
'hevningene': ('hevning',),
'hevninger': ('hevning',),
'hevningsmiddel': ('hevningsmiddel',),
'hevningsmiddelet': ('hevningsmiddel',),
'hevningsmidla': ('hevningsmiddel',),
'hevningsmidlene': ('hevningsmiddel',),
'hevningsmidler': ('hevningsmiddel',),
'hevningsmidlet': ('hevningsmiddel',),
'hevnlyst': ('hevnlyst',),
'hevnlysta': ('hevnlyst',),
'hevnlysten': ('hevnlyst',),
'hevnlystene': ('hevnlyst',),
'hevnlyster': ('hevnlyst',),
'hi': ('hi',),
'hia': ('hi',),
'hiene': ('hi',),
'hiet': ('hi',),
'hi-fi': ('hi-fi',),
'hi-fien': ('hi-fi',),
'hi-fiene': ('hi-fi',),
'hi-fier': ('hi-fi',),
'hiatus': ('hiatus',),
'hiatusen': ('hiatus',),
'hiatusene': ('hiatus',),
'hiatuser': ('hiatus',),
'hibiskus': ('hibiskus',),
'hibiskusen': ('hibiskus',),
'hibiskusene': ('hibiskus',),
'hibiskuser': ('hibiskus',),
'hickory': ('hickory',),
'hickoryen': ('hickory',),
'hickoryene': ('hickory',),
'hickoryer': ('hickory',),
'hickoryski': ('hickoryski',),
'hickoryskia': ('hickoryski',),
'hickoryskien': ('hickoryski',),
'hickoryskiene': ('hickoryski',),
'hickoryskier': ('hickoryski',),
'hickorysåle': ('hickorysåle',),
'hickorysålen': ('hickorysåle',),
'hickorysålene': ('hickorysåle',),
'hickorysåler': ('hickorysåle',),
'hidalgo': ('hidalgo',),
'hidalgoen': ('hidalgo',),
'hidalgoene': ('hidalgo',),
'hidalgoer': ('hidalgo',),
'hierark': ('hierark',),
'hierarken': ('hierark',),
'hierarkene': ('hierark',),
'hierarker': ('hierark',),
'hierarki': ('hierarki',),
'hierarkia': ('hierarki',),
'hierarkiene': ('hierarki',),
'hierarkier': ('hierarki',),
'hierarkiet': ('hierarki',),
'hieroglyf': ('hieroglyf',),
'hieroglyfen': ('hieroglyf',),
'hieroglyfene': ('hieroglyf',),
'hieroglyfer': ('hieroglyf',),
'higen': ('higen',),
'higenen': ('higen',),
'higenene': ('higen',),
'higener': ('higen',),
'high fidelity': ('high fidelity',),
'hijakt': ('hijakt',),
'hijakta': ('hijakt',),
'hijakten': ('hijakt',),
'hijaktene': ('hijakt',),
'hijakter': ('hijakt',),
'hikk': ('hikk',),
'hikka': ('hikk',),
'hikken': ('hikk',),
'hikkene': ('hikk',),
'hikket': ('hikk',),
'hikkas': ('hikkas',),
'hikkasen': ('hikkas',),
'hikkasene': ('hikkas',),
'hikkaser': ('hikkas',),
'hikke': ('hikke',),
'hikken': ('hikke',),
'hikkene': ('hikke',),
'hikker': ('hikke',),
'hikst': ('hikst',),
'hiksta': ('hikst',),
'hiksten': ('hikst',),
'hikstene': ('hikst',),
'hikstet': ('hikst',),
'hikstegråt': ('hikstegråt',),
'hikstegråten': ('hikstegråt',),
'hikstegråtene': ('hikstegråt',),
'hikstegråter': ('hikstegråt',),
'hikstelatrene': ('hikstelatter',),
'hikstelatrer': ('hikstelatter',),
'hikstelatter': ('hikstelatter',),
'hikstelattere': ('hikstelatter',),
'hikstelatteren': ('hikstelatter',),
'hikstelatterer': ('hikstelatter',),
'hikstelatterne': ('hikstelatter',),
'hilder': ('hilder',),
'hilderet': ('hilder',),
'hildra': ('hilder',),
'hildre': ('hilder',),
'hildrene': ('hilder',),
'hildret': ('hilder',),
'hildersyn': ('hildersyn',),
'hildersyna': ('hildersyn',),
'hildersynene': ('hildersyn',),
'hildersyner': ('hildersyn',),
'hildersynet': ('hildersyn',),
'hildring': ('hildring',),
'hildringa': ('hildring',),
'hildringen': ('hildring',),
'hildringene': ('hildring',),
'hildringer': ('hildring',),
'hils': ('hils',),
'hilsefot': ('hilsefot',),
'hilsefoten': ('hilsefot',),
'hilseføttene': ('hilsefot',),
'hilseføtter': ('hilsefot',),
'hilsefot': ('hilsefot',),
'hilsefoten': ('hilsefot',),
'hilseføttene': ('hilsefot',),
'hilseføtter': ('hilsefot',),
'hilsen': ('hilsen',),
'hilsenen': ('hilsen',),
'hilsenene': ('hilsen',),
'hilsener': ('hilsen',),
'hilseplikt': ('hilseplikt',),
'hilseplikta': ('hilseplikt',),
'hilseplikten': ('hilseplikt',),
'hilsepliktene': ('hilseplikt',),
'hilseplikter': ('hilseplikt',),
'hilseplikt': ('hilseplikt',),
'hilseplikta': ('hilseplikt',),
'hilseplikten': ('hilseplikt',),
'hilsepliktene': ('hilseplikt',),
'hilseplikter': ('hilseplikt',),
'hilsning': ('hilsning',),
'hilsninga': ('hilsning',),
'hilsningen': ('hilsning',),
'hilsningene': ('hilsning',),
'hilsninger': ('hilsning',),
'hilsningstale': ('hilsningstale',),
'hilsningstalen': ('hilsningstale',),
'hilsningstalene': ('hilsningstale',),
'hilsningstaler': ('hilsningstale',),
'hilsningstelegram': ('hilsningstelegram',),
'hilsningstelegramma': ('hilsningstelegram',),
'hilsningstelegrammene': ('hilsningstelegram',),
'hilsningstelegrammer': ('hilsningstelegram',),
'hilsningstelegrammet': ('hilsningstelegram',),
'hima': ('hime',),
'hime': ('hime',),
'himen': ('hime',),
'himene': ('hime',),
'himer': ('hime',),
'himling': ('himling',),
'himlinga': ('himling',),
'himlingen': ('himling',),
'himlingene': ('himling',),
'himlinger': ('himling',),
'himlene': ('himmel',),
'himler': ('himmel',),
'himmel': ('himmel',),
'himmelen': ('himmel',),
'himmelfart': ('himmelfart',),
'himmelfarten': ('himmelfart',),
'himmelfartene': ('himmelfart',),
'himmelfarter': ('himmelfart',),
'himmelfartsdag': ('himmelfartsdag',),
'himmelfartsdagen': ('himmelfartsdag',),
'himmelfartsdagene': ('himmelfartsdag',),
'himmelfartsdager': ('himmelfartsdag',),
'himmelhvelv': ('himmelhvelv',),
'himmelhvelva': ('himmelhvelv',),
'himmelhvelvene': ('himmelhvelv',),
'himmelhvelvet': ('himmelhvelv',),
'himmelhvelving': ('himmelhvelving',),
'himmelhvelvingen': ('himmelhvelving',),
'himmelhvelvingene': ('himmelhvelving',),
'himmelhvelvinger': ('himmelhvelving',),
'himmelkropp': ('himmelkropp',),
'himmelkroppen': ('himmelkropp',),
'himmelkroppene': ('himmelkropp',),
'himmelkropper': ('himmelkropp',),
'himmelkvelv': ('himmelkvelv',),
'himmelkvelva': ('himmelkvelv',),
'himmelkvelven': ('himmelkvelv',),
'himmelkvelvene': ('himmelkvelv',),
'himmelkvelver': ('himmelkvelv',),
'himmelkvelvet': ('himmelkvelv',),
'himmelkvelving': ('himmelkvelving',),
'himmelkvelvingen': ('himmelkvelving',),
'himmelkvelvingene': ('himmelkvelving',),
'himmelkvelvinger': ('himmelkvelving',),
'himmellegema': ('himmellegeme',),
'himmellegeme': ('himmellegeme',),
'himmellegemene': ('himmellegeme',),
'himmellegemer': ('himmellegeme',),
'himmellegemet': ('himmellegeme',),
'himmelrand': ('himmelrand',),
'himmelranda': ('himmelrand',),
'himmelranden': ('himmelrand',),
'himmelrendene': ('himmelrand',),
'himmelrender': ('himmelrand',),
'himmelrika': ('himmelrike',),
'himmelrike': ('himmelrike',),
'himmelrikene': ('himmelrike',),
'himmelriker': ('himmelrike',),
'himmelriket': ('himmelrike',),
'himmelrom': ('himmelrom',),
'himmelromma': ('himmelrom',),
'himmelrommene': ('himmelrom',),
'himmelrommet': ('himmelrom',),
'himmelseng': ('himmelseng',),
'himmelsenga': ('himmelseng',),
'himmelsengen': ('himmelseng',),
'himmelsengene': ('himmelseng',),
'himmelsenger': ('himmelseng',),
'himmelsprett': ('himmelsprett',),
'himmelspretta': ('himmelsprett',),
'himmelspretten': ('himmelsprett',),
'himmelsprettene': ('himmelsprett',),
'himmelspretter': ('himmelsprett',),
'himmelsprettet': ('himmelsprett',),
'himmelstige': ('himmelstige',),
'himmelstigen': ('himmelstige',),
'himmelstigene': ('himmelstige',),
'himmelstiger': ('himmelstige',),
'himmelstormer': ('himmelstormer',),
'himmelstormere': ('himmelstormer',),
'himmelstormeren': ('himmelstormer',),
'himmelstormerer': ('himmelstormer',),
'himmelstormerne': ('himmelstormer',),
'himmelstrøk': ('himmelstrøk',),
'himmelstrøka': ('himmelstrøk',),
'himmelstrøkene': ('himmelstrøk',),
'himmelstrøket': ('himmelstrøk',),
'himmeltegn': ('himmeltegn',),
'himmeltegna': ('himmeltegn',),
'himmeltegnene': ('himmeltegn',),
'himmeltegnet': ('himmeltegn',),
'himmerika': ('himmerike',),
'himmerike': ('himmerike',),
'himmerikene': ('himmerike',),
'himmeriker': ('himmerike',),
'himmeriket': ('himmerike',),
'hind': ('hind',),
'hinda': ('hind',),
'hinden': ('hind',),
'hindene': ('hind',),
'hinder': ('hind',),
'hinder': ('hinder',),
'hinderet': ('hinder',),
'hindra': ('hinder',),
'hindre': ('hinder',),
'hindrene': ('hinder',),
'hindret': ('hinder',),
'hinderbane': ('hinderbane',),
'hinderbanen': ('hinderbane',),
'hinderbanene': ('hinderbane',),
'hinderbaner': ('hinderbane',),
'hinderløp': ('hinderløp',),
'hinderløpa': ('hinderløp',),
'hinderløpene': ('hinderløp',),
'hinderløpet': ('hinderløp',),
'hinderløper': ('hinderløper',),
'hinderløpere': ('hinderløper',),
'hinderløperen': ('hinderløper',),
'hinderløperer': ('hinderløper',),
'hinderløperne': ('hinderløper',),
'hinderritt': ('hinderritt',),
'hinderritta': ('hinderritt',),
'hinderrittene': ('hinderritt',),
'hinderrittet': ('hinderritt',),
'hindi': ('hindi',),
'hindien': ('hindi',),
'hindiene': ('hindi',),
'hindier': ('hindi',),
'hindring': ('hindring',),
'hindringa': ('hindring',),
'hindringen': ('hindring',),
'hindringene': ('hindring',),
'hindringer': ('hindring',),
'hindu': ('hindu',),
'hinduen': ('hindu',),
'hinduene': ('hindu',),
'hinduer': ('hindu',),
'hinduisme': ('hinduisme',),
'hinduismen': ('hinduisme',),
'hinduismene': ('hinduisme',),
'hinduismer': ('hinduisme',),
'hindustani': ('hindustani',),
'hindustanien': ('hindustani',),
'hindustaniene': ('hindustani',),
'hindustanier': ('hindustani',),
'hingst': ('hingst',),
'hingsten': ('hingst',),
'hingstene': ('hingst',),
'hingster': ('hingst',),
'hingsteføl': ('hingsteføl',),
'hingsteføla': ('hingsteføl',),
'hingstefølene': ('hingsteføl',),
'hingstefølet': ('hingsteføl',),
'hingsteføll': ('hingsteføll',),
'hingstefølla': ('hingsteføll',),
'hingsteføllene': ('hingsteføll',),
'hingsteføllet': ('hingsteføll',),
'hingstføl': ('hingstføl',),
'hingstføla': ('hingstføl',),
'hingstfølene': ('hingstføl',),
'hingstfølet': ('hingstføl',),
'hingstføll': ('hingstføll',),
'hingstfølla': ('hingstføll',),
'hingstføllene': ('hingstføll',),
'hingstføllet': ('hingstføll',),
'hinmannen': ('hinmannen',),
'hinna': ('hinne',),
'hinne': ('hinne',),
'hinnen': ('hinne',),
'hinnene': ('hinne',),
'hinner': ('hinne',),
'hinnebregna': ('hinnebregne',),
'hinnebregne': ('hinnebregne',),
'hinnebregnen': ('hinnebregne',),
'hinnebregnene': ('hinnebregne',),
'hinnebregner': ('hinnebregne',),
'hint': ('hint',),
'hinta': ('hint',),
'hintene': ('hint',),
'hintet': ('hint',),
'hipp': ('hipp',),
'hippa': ('hipp',),
'hippene': ('hipp',),
'hippet': ('hipp',),
'hipp': ('hipp',),
'hippie': ('hippie',),
'hippien': ('hippie',),
'hippiene': ('hippie',),
'hippier': ('hippie',),
'hippiebevegelse': ('hippiebevegelse',),
'hippiebevegelsen': ('hippiebevegelse',),
'hippiebevegelsene': ('hippiebevegelse',),
'hippiebevegelser': ('hippiebevegelse',),
'hippiekultur': ('hippiekultur',),
'hippiekulturen': ('hippiekultur',),
'hippiekulturene': ('hippiekultur',),
'hippiekulturer': ('hippiekultur',),
'hippodrom': ('hippodrom',),
'hippodromen': ('hippodrom',),
'hippodromene': ('hippodrom',),
'hippodromer': ('hippodrom',),
'hippolog': ('hippolog',),
'hippologen': ('hippolog',),
'hippologene': ('hippolog',),
'hippologer': ('hippolog',),
'hippologi': ('hippologi',),
'hippologien': ('hippologi',),
'hippologiene': ('hippologi',),
'hippologier': ('hippologi',),
'hird': ('hird',),
'hirda': ('hird',),
'hirden': ('hird',),
'hirdene': ('hird',),
'hirder': ('hird',),
'hirdmann': ('hirdmann',),
'hirdmannen': ('hirdmann',),
'hirdmenn': ('hirdmann',),
'hirdmennene': ('hirdmann',),
'hirdskald': ('hirdskald',),
'hirdskalden': ('hirdskald',),
'hirdskaldene': ('hirdskald',),
'hirdskalder': ('hirdskald',),
'hirdskrå': ('hirdskrå',),
'hirdskråa': ('hirdskrå',),
'hirdskråen': ('hirdskrå',),
'hirdskråene': ('hirdskrå',),
'hirdskråer': ('hirdskrå',),
'hirse': ('hirse',),
'hirsen': ('hirse',),
'hirsene': ('hirse',),
'hirser': ('hirse',),
'hirsefrø': ('hirsefrø',),
'hirsefrøa': ('hirsefrø',),
'hirsefrøene': ('hirsefrø',),
'hirsefrøet': ('hirsefrø',),
'hissigpropp': ('hissigpropp',),
'hissigproppen': ('hissigpropp',),
'hissigproppene': ('hissigpropp',),
'hissigpropper': ('hissigpropp',),
'histamin': ('histamin',),
'histamina': ('histamin',),
'histaminene': ('histamin',),
'histaminer': ('histamin',),
'histaminet': ('histamin',),
'histaminbehandling': ('histaminbehandling',),
'histaminbehandlinga': ('histaminbehandling',),
'histaminbehandlingen': ('histaminbehandling',),
'histaminbehandlingene': ('histaminbehandling',),
'histaminbehandlinger': ('histaminbehandling',),
'histolog': ('histolog',),
'histologen': ('histolog',),
'histologene': ('histolog',),
'histologer': ('histolog',),
'histologi': ('histologi',),
'histologien': ('histologi',),
'histologiene': ('histologi',),
'histologier': ('histologi',),
'historia': ('historie',),
'historie': ('historie',),
'historien': ('historie',),
'historiene': ('historie',),
'historier': ('historie',),
'historiefilosofi': ('historiefilosofi',),
'historiefilosofien': ('historiefilosofi',),
'historiefilosofiene': ('historiefilosofi',),
'historiefilosofier': ('historiefilosofi',),
'historieforfalskning': ('historieforfalskning',),
'historieforfalskninga': ('historieforfalskning',),
'historieforfalskningen': ('historieforfalskning',),
'historieforfalskningene': ('historieforfalskning',),
'historieforfalskninger': ('historieforfalskning',),
'historielag': ('historielag',),
'historielaga': ('historielag',),
'historielagene': ('historielag',),
'historielaget': ('historielag',),
'historiemaleri': ('historiemaleri',),
'historiemaleria': ('historiemaleri',),
'historiemaleriene': ('historiemaleri',),
'historiemalerier': ('historiemaleri',),
'historiemaleriet': ('historiemaleri',),
'historieoppfatning': ('historieoppfatning',),
'historieoppfatninga': ('historieoppfatning',),
'historieoppfatningen': ('historieoppfatning',),
'historieoppfatningene': ('historieoppfatning',),
'historieoppfatninger': ('historieoppfatning',),
'historiker': ('historiker',),
'historikere': ('historiker',),
'historikeren': ('historiker',),
'historikerene': ('historiker',),
'historikerer': ('historiker',),
'historikerne': ('historiker',),
'historikk': ('historikk',),
'historikken': ('historikk',),
'historikkene': ('historikk',),
'historikker': ('historikk',),
'historiograf': ('historiograf',),
'historiografen': ('historiograf',),
'historiografene': ('historiograf',),
'historiografer': ('historiograf',),
'historiografi': ('historiografi',),
'historiografien': ('historiografi',),
'historiografiene': ('historiografi',),
'historiografier': ('historiografi',),
'historisitet': ('historisitet',),
'historisiteten': ('historisitet',),
'historisitetene': ('historisitet',),
'historisiteter': ('historisitet',),
'historisme': ('historisme',),
'historismen': ('historisme',),
'historismene': ('historisme',),
'historismer': ('historisme',),
'hit': ('hit',),
'hita': ('hit',),
'hiten': ('hit',),
'hitene': ('hit',),
'hiter': ('hit',),
'hit': ('hit',),
'hiten': ('hit',),
'hitene': ('hit',),
'hiter': ('hit',),
'hitlista': ('hitliste',),
'hitliste': ('hitliste',),
'hitlisten': ('hitliste',),
'hitlistene': ('hitliste',),
'hitlister': ('hitliste',),
'hitlåt': ('hitlåt',),
'hitlåten': ('hitlåt',),
'hitlåtene': ('hitlåt',),
'hitlåter': ('hitlåt',),
'hitsida': ('hitside',),
'hitside': ('hitside',),
'hitsiden': ('hitside',),
'hitsidene': ('hitside',),
'hitsider': ('hitside',),
'hitt': ('hitt',),
'hitten': ('hitt',),
'hittene': ('hitt',),
'hitter': ('hitt',),
'hittebarn': ('hittebarn',),
'hittebarna': ('hittebarn',),
'hittebarnene': ('hittebarn',),
'hittebarnet': ('hittebarn',),
'hittegods': ('hittegods',),
'hittegodsa': ('hittegods',),
'hittegodsene': ('hittegods',),
'hittegodset': ('hittegods',),
'hittegodskontor': ('hittegodskontor',),
'hittegodskontora': ('hittegodskontor',),
'hittegodskontorene': ('hittegodskontor',),
'hittegodskontorer': ('hittegodskontor',),
'hittegodskontoret': ('hittegodskontor',),
'hittfolk': ('hittfolk',),
'hittfolka': ('hittfolk',),
'hittfolkene': ('hittfolk',),
'hittfolket': ('hittfolk',),
'hitveg': ('hitveg',),
'hitvegen': ('hitveg',),
'hitvegene': ('hitveg',),
'hitveger': ('hitveg',),
'hitvei': ('hitvei',),
'hitveien': ('hitvei',),
'hitveiene': ('hitvei',),
'hitveier': ('hitvei',),
'hiv': ('hiv',),
'hiva': ('hiv',),
'hiven': ('hiv',),
'hivene': ('hiv',),
'hivet': ('hiv',),
'hiv': ('hiv',),
'hivert': ('hivert',),
'hiverten': ('hivert',),
'hivertene': ('hivert',),
'hiverter': ('hivert',),
'hivsmitte': ('hivsmitte',),
'hivsmitten': ('hivsmitte',),
'hivsmittene': ('hivsmitte',),
'hivsmitter': ('hivsmitte',),
'hivvirus': ('hivvirus',),
'hivvirusa': ('hivvirus',),
'hivvirusene': ('hivvirus',),
'hivviruset': ('hivvirus',),
'hjalt': ('hjalt',),
'hjalta': ('hjalt',),
'hjaltene': ('hjalt',),
'hjaltet': ('hjalt',),
'hjel': ('hjel',),
'hjell': ('hjell',),
'hjellen': ('hjell',),
'hjellene': ('hjell',),
'hjeller': ('hjell',),
'hjelm': ('hjelm',),
'hjelmen': ('hjelm',),
'hjelmene': ('hjelm',),
'hjelmer': ('hjelm',),
'hjelmbusk': ('hjelmbusk',),
'hjelmbusken': ('hjelmbusk',),
'hjelmbuskene': ('hjelmbusk',),
'hjelmbusker': ('hjelmbusk',),
'hjelp': ('hjelp',),
'hjelpa': ('hjelp',),
'hjelpen': ('hjelp',),
'hjelpene': ('hjelp',),
'hjelper': ('hjelp',),
'hjelpeaksjon': ('hjelpeaksjon',),
'hjelpeaksjonen': ('hjelpeaksjon',),
'hjelpeaksjonene': ('hjelpeaksjon',),
'hjelpeaksjoner': ('hjelpeaksjon',),
'hjelpearbeid': ('hjelpearbeid',),
'hjelpearbeida': ('hjelpearbeid',),
'hjelpearbeidene': ('hjelpearbeid',),
'hjelpearbeider': ('hjelpearbeid',),
'hjelpearbeidet': ('hjelpearbeid',),
'hjelpearbeider': ('hjelpearbeider',),
'hjelpearbeidere': ('hjelpearbeider',),
'hjelpearbeideren': ('hjelpearbeider',),
'hjelpearbeiderer': ('hjelpearbeider',),
'hjelpearbeiderne': ('hjelpearbeider',),
'hjelpedommer': ('hjelpedommer',),
'hjelpedommere': ('hjelpedommer',),
'hjelpedommeren': ('hjelpedommer',),
'hjelpedommerer': ('hjelpedommer',),
'hjelpedommerne': ('hjelpedommer',),
'hjelpefengsel': ('hjelpefengsel',),
'hjelpefengselet': ('hjelpefengsel',),
'hjelpefengsla': ('hjelpefengsel',),
'hjelpefengslene': ('hjelpefengsel',),
'hjelpefengsler': ('hjelpefengsel',),
'hjelpefengslet': ('hjelpefengsel',),
'hjelpekilde': ('hjelpekilde',),
'hjelpekilden': ('hjelpekilde',),
'hjelpekildene': ('hjelpekilde',),
'hjelpekilder': ('hjelpekilde',),
'hjelpekjelda': ('hjelpekjelde',),
'hjelpekjelde': ('hjelpekjelde',),
'hjelpekjelden': ('hjelpekjelde',),
'hjelpekjeldene': ('hjelpekjelde',),
'hjelpekjelder': ('hjelpekjelde',),
'hjelpeklassa': ('hjelpeklasse',),
'hjelpeklasse': ('hjelpeklasse',),
'hjelpeklassen': ('hjelpeklasse',),
'hjelpeklassene': ('hjelpeklasse',),
'hjelpeklasser': ('hjelpeklasse',),
'hjelpekorps': ('hjelpekorps',),
'hjelpekorpsa': ('hjelpekorps',),
'hjelpekorpsene': ('hjelpekorps',),
'hjelpekorpset': ('hjelpekorps',),
'hjelpelærer': ('hjelpelærer',),
'hjelpelærere': ('hjelpelærer',),
'hjelpelæreren': ('hjelpelærer',),
'hjelpelærerer': ('hjelpelærer',),
'hjelpelærerne': ('hjelpelærer',),
'hjelpeløshet': ('hjelpeløshet',),
'hjelpeløsheta': ('hjelpeløshet',),
'hjelpeløsheten': ('hjelpeløshet',),
'hjelpeløshetene': ('hjelpeløshet',),
'hjelpeløsheter': ('hjelpeløshet',),
'hjelpeløysa': ('hjelpeløyse',),
'hjelpeløyse': ('hjelpeløyse',),
'hjelpeløysen': ('hjelpeløyse',),
'hjelpeløysene': ('hjelpeløyse',),
'hjelpeløyser': ('hjelpeløyse',),
'hjelpemann': ('hjelpemann',),
'hjelpemannen': ('hjelpemann',),
'hjelpemenn': ('hjelpemann',),
'hjelpemennene': ('hjelpemann',),
'hjelpemannskap': ('hjelpemannskap',),
'hjelpemannskapa': ('hjelpemannskap',),
'hjelpemannskapene': ('hjelpemannskap',),
'hjelpemannskaper': ('hjelpemannskap',),
'hjelpemannskapet': ('hjelpemannskap',),
'hjelpemiddel': ('hjelpemiddel',),
'hjelpemiddelet': ('hjelpemiddel',),
'hjelpemidla': ('hjelpemiddel',),
'hjelpemidlene': ('hjelpemiddel',),
'hjelpemidler': ('hjelpemiddel',),
'hjelpemidlet': ('hjelpemiddel',),
'hjelpemotor': ('hjelpemotor',),
'hjelpemotoren': ('hjelpemotor',),
'hjelpemotorene': ('hjelpemotor',),
'hjelpemotorer': ('hjelpemotor',),
'hjelpepleier': ('hjelpepleier',),
'hjelpepleiere': ('hjelpepleier',),
'hjelpepleieren': ('hjelpepleier',),
'hjelpepleierer': ('hjelpepleier',),
'hjelpepleierne': ('hjelpepleier',),
'hjelpeprest': ('hjelpeprest',),
'hjelpepresten': ('hjelpeprest',),
'hjelpeprestene': ('hjelpeprest',),
'hjelpeprester': ('hjelpeprest',),
'hjelper': ('hjelper',),
'hjelpere': ('hjelper',),
'hjelperen': ('hjelper',),
'hjelperer': ('hjelper',),
'hjelperne': ('hjelper',),
'hjelperåd': ('hjelperåd',),
'hjelperåda': ('hjelperåd',),
'hjelperåden': ('hjelperåd',),
'hjelperådene': ('hjelperåd',),
'hjelperåder': ('hjelperåd',),
'hjelperådet': ('hjelperåd',),
'hjelpeskole': ('hjelpeskole',),
'hjelpeskolen': ('hjelpeskole',),
'hjelpeskolene': ('hjelpeskole',),
'hjelpeskoler': ('hjelpeskole',),
'hjelpesmann': ('hjelpesmann',),
'hjelpesmannen': ('hjelpesmann',),
'hjelpesmenn': ('hjelpesmann',),
'hjelpesmennene': ('hjelpesmann',),
'hjelpespråk': ('hjelpespråk',),
'hjelpespråka': ('hjelpespråk',),
'hjelpespråkene': ('hjelpespråk',),
'hjelpespråket': ('hjelpespråk',),
'hjelpestikka': ('hjelpestikke',),
'hjelpestikke': ('hjelpestikke',),
'hjelpestikken': ('hjelpestikke',),
'hjelpestikkene': ('hjelpestikke',),
'hjelpestikker': ('hjelpestikke',),
'hjelpestønad': ('hjelpestønad',),
'hjelpestønaden': ('hjelpestønad',),
'hjelpestønadene': ('hjelpestønad',),
'hjelpestønader': ('hjelpestønad',),
'hjelpeundervisning': ('hjelpeundervisning',),
'hjelpeundervisninga': ('hjelpeundervisning',),
'hjelpeundervisningen': ('hjelpeundervisning',),
'hjelpeundervisningene': ('hjelpeundervisning',),
'hjelpeundervisninger': ('hjelpeundervisning',),
'hjelpeverb': ('hjelpeverb',),
'hjelpeverba': ('hjelpeverb',),
'hjelpeverbene': ('hjelpeverb',),
'hjelpeverber': ('hjelpeverb',),
'hjelpeverbet': ('hjelpeverb',),
'hjelpeverba': ('hjelpeverbum',),
'hjelpeverbene': ('hjelpeverbum',),
'hjelpeverber': ('hjelpeverbum',),
'hjelpeverbet': ('hjelpeverbum',),
'hjelpeverbum': ('hjelpeverbum',),
'hjelpeverbumet': ('hjelpeverbum',),
'hjem': ('hjem',),
'hjemma': ('hjem',),
'hjemmene': ('hjem',),
'hjemmet': ('hjem',),
'hjemby': ('hjemby',),
'hjembyen': ('hjemby',),
'hjembyene': ('hjemby',),
'hjembyer': ('hjemby',),
'hjembygd': ('hjembygd',),
'hjembygda': ('hjembygd',),
'hjembygden': ('hjembygd',),
'hjembygdene': ('hjembygd',),
'hjembygder': ('hjembygd',),
'hjemfall': ('hjemfall',),
'hjemfalla': ('hjemfall',),
'hjemfallene': ('hjemfall',),
'hjemfallet': ('hjemfall',),
'hjemfallsrett': ('hjemfallsrett',),
'hjemfallsretten': ('hjemfallsrett',),
'hjemfallsrettene': ('hjemfallsrett',),
'hjemfallsretter': ('hjemfallsrett',),
'hjemforsikring': ('hjemforsikring',),
'hjemforsikringa': ('hjemforsikring',),
'hjemforsikringen': ('hjemforsikring',),
'hjemforsikringene': ('hjemforsikring',),
'hjemforsikringer': ('hjemforsikring',),
'hjemkjøp': ('hjemkjøp',),
'hjemkjøpa': ('hjemkjøp',),
'hjemkjøpene': ('hjemkjøp',),
'hjemkjøpet': ('hjemkjøp',),
'hjemkommerøl': ('hjemkommerøl',),
'hjemkommerøla': ('hjemkommerøl',),
'hjemkommerølene': ('hjemkommerøl',),
'hjemkommerølet': ('hjemkommerøl',),
'hjemkommune': ('hjemkommune',),
'hjemkommunen': ('hjemkommune',),
'hjemkommunene': ('hjemkommune',),
'hjemkommuner': ('hjemkommune',),
'hjemkomst': ('hjemkomst',),
'hjemkomsten': ('hjemkomst',),
'hjemkomstene': ('hjemkomst',),
'hjemkomster': ('hjemkomst',),
'hjemland': ('hjemland',),
'hjemlanda': ('hjemland',),
'hjemlandene': ('hjemland',),
'hjemlandet': ('hjemland',),
'hjemlengsel': ('hjemlengsel',),
'hjemlengselen': ('hjemlengsel',),
'hjemlengslene': ('hjemlengsel',),
'hjemlengsler': ('hjemlengsel',),
'hjemlov': ('hjemlov',),
'hjemloven': ('hjemlov',),
'hjemlovene': ('hjemlov',),
'hjemlover': ('hjemlov',),
'hjemlån': ('hjemlån',),
'hjemlåna': ('hjemlån',),
'hjemlånene': ('hjemlån',),
'hjemlånet': ('hjemlån',),
'hjemmearbeid': ('hjemmearbeid',),
'hjemmearbeida': ('hjemmearbeid',),
'hjemmearbeidene': ('hjemmearbeid',),
'hjemmearbeider': ('hjemmearbeid',),
'hjemmearbeidet': ('hjemmearbeid',),
'hjemmebakeri': ('hjemmebakeri',),
'hjemmebakeria': ('hjemmebakeri',),
'hjemmebakeriene': ('hjemmebakeri',),
'hjemmebakerier': ('hjemmebakeri',),
'hjemmebakeriet': ('hjemmebakeri',),
'hjemmebane': ('hjemmebane',),
'hjemmebanen': ('hjemmebane',),
'hjemmebanene': ('hjemmebane',),
'hjemmebaner': ('hjemmebane',),
'hjemmebrenner': ('hjemmebrenner',),
'hjemmebrennere': ('hjemmebrenner',),
'hjemmebrenneren': ('hjemmebrenner',),
'hjemmebrennerer': ('hjemmebrenner',),
'hjemmebrennerne': ('hjemmebrenner',),
'hjemmebrenning': ('hjemmebrenning',),
'hjemmebrenninga': ('hjemmebrenning',),
'hjemmebrenningen': ('hjemmebrenning',),
'hjemmebrenningene': ('hjemmebrenning',),
'hjemmebrenninger': ('hjemmebrenning',),
'hjemmebrent': ('hjemmebrent',),
'hjemmebrenten': ('hjemmebrent',),
'hjemmebrentene': ('hjemmebrent',),
'hjemmebrenter': ('hjemmebrent',),
'hjemmebrygg': ('hjemmebrygg',),
'hjemmebrygga': ('hjemmebrygg',),
'hjemmebryggene': ('hjemmebrygg',),
'hjemmebrygget': ('hjemmebrygg',),
'hjemmedatamaskin': ('hjemmedatamaskin',),
'hjemmedatamaskina': ('hjemmedatamaskin',),
'hjemmedatamaskinen': ('hjemmedatamaskin',),
'hjemmedatamaskinene': ('hjemmedatamaskin',),
'hjemmedatamaskiner': ('hjemmedatamaskin',),
'hjemmedåp': ('hjemmedåp',),
'hjemmedåpen': ('hjemmedåp',),
'hjemmedåpene': ('hjemmedåp',),
'hjemmedåper': ('hjemmedåp',),
'hjemmefiska': ('hjemmefiske',),
'hjemmefiske': ('hjemmefiske',),
'hjemmefiskene': ('hjemmefiske',),
'hjemmefisker': ('hjemmefiske',),
'hjemmefisket': ('hjemmefiske',),
'hjemmefront': ('hjemmefront',),
'hjemmefronten': ('hjemmefront',),
'hjemmefrontene': ('hjemmefront',),
'hjemmefronter': ('hjemmefront',),
'hjemmehjelp': ('hjemmehjelp',),
'hjemmehjelpa': ('hjemmehjelp',),
'hjemmehjelpen': ('hjemmehjelp',),
'hjemmehjelpene': ('hjemmehjelp',),
'hjemmehjelper': ('hjemmehjelp',),
'hjemmehjelper': ('hjemmehjelper',),
'hjemmehjelpere': ('hjemmehjelper',),
'hjemmehjelperen': ('hjemmehjelper',),
'hjemmehjelperer': ('hjemmehjelper',),
'hjemmehjelperne': ('hjemmehjelper',),
'hjemmeindustri': ('hjemmeindustri',),
'hjemmeindustrien': ('hjemmeindustri',),
'hjemmeindustriene': ('hjemmeindustri',),
'hjemmeindustrier': ('hjemmeindustri',),
'hjemmekamp': ('hjemmekamp',),
'hjemmekampen': ('hjemmekamp',),
'hjemmekampene': ('hjemmekamp',),
'hjemmekamper': ('hjemmekamp',),
'hjemlene': ('hjemmel',),
'hjemler': ('hjemmel',),
'hjemmel': ('hjemmel',),
'hjemmelen': ('hjemmel',),
'hjemmelag': ('hjemmelag',),
'hjemmelaga': ('hjemmelag',),
'hjemmelagene': ('hjemmelag',),
'hjemmelaget': ('hjemmelag',),
'hjemmeleksa': ('hjemmelekse',),
'hjemmelekse': ('hjemmelekse',),
'hjemmeleksen': ('hjemmelekse',),
'hjemmeleksene': ('hjemmelekse',),
'hjemmelekser': ('hjemmelekse',),
'hjemmelsmann': ('hjemmelsmann',),
'hjemmelsmannen': ('hjemmelsmann',),
'hjemmelsmenn': ('hjemmelsmann',),
'hjemmelsmennene': ('hjemmelsmann',),
'hjemmemarked': ('hjemmemarked',),
'hjemmemarkeda': ('hjemmemarked',),
'hjemmemarkedene': ('hjemmemarked',),
'hjemmemarkeder': ('hjemmemarked',),
'hjemmemarkedet': ('hjemmemarked',),
'hjemmeoppgava': ('hjemmeoppgave',),
'hjemmeoppgave': ('hjemmeoppgave',),
'hjemmeoppgaven': ('hjemmeoppgave',),
'hjemmeoppgavene': ('hjemmeoppgave',),
'hjemmeoppgaver': ('hjemmeoppgave',),
'hjemmeregning': ('hjemmeregning',),
'hjemmeregninga': ('hjemmeregning',),
'hjemmeregningen': ('hjemmeregning',),
'hjemmeregningene': ('hjemmeregning',),
'hjemmeregninger': ('hjemmeregning',),
'hjemmerekning': ('hjemmerekning',),
'hjemmerekninga': ('hjemmerekning',),
'hjemmerekningen': ('hjemmerekning',),
'hjemmerekningene': ('hjemmerekning',),
'hjemmerekninger': ('hjemmerekning',),
'hjemmesitter': ('hjemmesitter',),
'hjemmesittere': ('hjemmesitter',),
'hjemmesitteren': ('hjemmesitter',),
'hjemmesitterer': ('hjemmesitter',),
'hjemmesitterne': ('hjemmesitter',),
'hjemmesitter': ('hjemmesitter',),
'hjemmesittere': ('hjemmesitter',),
'hjemmesitteren': ('hjemmesitter',),
'hjemmesitterer': ('hjemmesitter',),
'hjemmesitterne': ('hjemmesitter',),
'hjemmesitting': ('hjemmesitting',),
'hjemmesittinga': ('hjemmesitting',),
'hjemmesittingen': ('hjemmesitting',),
'hjemmesittingene': ('hjemmesitting',),
'hjemmesittinger': ('hjemmesitting',),
'hjemmesjukepleia': ('hjemmesjukepleie',),
'hjemmesjukepleie': ('hjemmesjukepleie',),
'hjemmesjukepleien': ('hjemmesjukepleie',),
'hjemmesjukepleiene': ('hjemmesjukepleie',),
'hjemmesjukepleier': ('hjemmesjukepleie',),
'hjemmestyrke': ('hjemmestyrke',),
'hjemmestyrken': ('hjemmestyrke',),
'hjemmestyrkene': ('hjemmestyrke',),
'hjemmestyrker': ('hjemmestyrke',),
'hjemmesykepleia': ('hjemmesykepleie',),
'hjemmesykepleie': ('hjemmesykepleie',),
'hjemmesykepleien': ('hjemmesykepleie',),
'hjemmesykepleiene': ('hjemmesykepleie',),
'hjemmesykepleier': ('hjemmesykepleie',),
'hjemmeulykka': ('hjemmeulykke',),
'hjemmeulykke': ('hjemmeulykke',),
'hjemmeulykken': ('hjemmeulykke',),
'hjemmeulykkene': ('hjemmeulykke',),
'hjemmeulykker': ('hjemmeulykke',),
'hjemreisa': ('hjemreise',),
'hjemreise': ('hjemreise',),
'hjemreisen': ('hjemreise',),
'hjemreisene': ('hjemreise',),
'hjemreiser': ('hjemreise',),
'hjemstavn': ('hjemstavn',),
'hjemstavnen': ('hjemstavn',),
'hjemstavnene': ('hjemstavn',),
'hjemstavner': ('hjemstavn',),
'hjemstavnsdikting': ('hjemstavnsdikting',),
'hjemstavnsdiktinga': ('hjemstavnsdikting',),
'hjemstavnsdiktingen': ('hjemstavnsdikting',),
'hjemstavnsdiktingene': ('hjemstavnsdikting',),
'hjemstavnsdiktinger': ('hjemstavnsdikting',),
'hjemstavnsdiktning': ('hjemstavnsdiktning',),
'hjemstavnsdiktninga': ('hjemstavnsdiktning',),
'hjemstavnsdiktningen': ('hjemstavnsdiktning',),
'hjemstavnsdiktningene': ('hjemstavnsdiktning',),
'hjemstavnsdiktninger': ('hjemstavnsdiktning',),
'hjemstavnskommune': ('hjemstavnskommune',),
'hjemstavnskommunen': ('hjemstavnskommune',),
'hjemstavnskommunene': ('hjemstavnskommune',),
'hjemstavnskommuner': ('hjemstavnskommune',),
'hjemstavnsrett': ('hjemstavnsrett',),
'hjemstavnsretten': ('hjemstavnsrett',),
'hjemstavnsrettene': ('hjemstavnsrett',),
'hjemstavnsretter': ('hjemstavnsrett',),
'hjemsted': ('hjemsted',),
'hjemstedene': ('hjemsted',),
'hjemsteder': ('hjemsted',),
'hjemstedet': ('hjemsted',),
'hjemtur': ('hjemtur',),
'hjemturen': ('hjemtur',),
'hjemturene': ('hjemtur',),
'hjemturer': ('hjemtur',),
'hjemve': ('hjemve',),
'hjemveen': ('hjemve',),
'hjemveene': ('hjemve',),
'hjemveer': ('hjemve',),
'hjemveg': ('hjemveg',),
'hjemvegen': ('hjemveg',),
'hjemvegene': ('hjemveg',),
'hjemveger': ('hjemveg',),
'hjemvei': ('hjemvei',),
'hjemveien': ('hjemvei',),
'hjemveiene': ('hjemvei',),
'hjemveier': ('hjemvei',),
'hjerne': ('hjerne',),
'hjernen': ('hjerne',),
'hjernene': ('hjerne',),
'hjerner': ('hjerne',),
'hjernebark': ('hjernebark',),
'hjernebarken': ('hjernebark',),
'hjernebarkene': ('hjernebark',),
'hjernebarker': ('hjernebark',),
'hjernebetennelse': ('hjernebetennelse',),
'hjernebetennelsen': ('hjernebetennelse',),
'hjernebetennelsene': ('hjernebetennelse',),
'hjernebetennelser': ('hjernebetennelse',),
'hjerneblødning': ('hjerneblødning',),
'hjerneblødninga': ('hjerneblødning',),
'hjerneblødningen': ('hjerneblødning',),
'hjerneblødningene': ('hjerneblødning',),
'hjerneblødninger': ('hjerneblødning',),
'hjerneflukt': ('hjerneflukt',),
'hjerneflukta': ('hjerneflukt',),
'hjerneflukten': ('hjerneflukt',),
'hjernefluktene': ('hjerneflukt',),
'hjerneflukter': ('hjerneflukt',),
'hjernegymnastikk': ('hjernegymnastikk',),
'hjernegymnastikken': ('hjernegymnastikk',),
'hjernegymnastikkene': ('hjernegymnastikk',),
'hjernegymnastikker': ('hjernegymnastikk',),
'hjernehemisfære': ('hjernehemisfære',),
'hjernehemisfæren': ('hjernehemisfære',),
'hjernehemisfærene': ('hjernehemisfære',),
'hjernehemisfærer': ('hjernehemisfære',),
'hjernehinna': ('hjernehinne',),
'hjernehinne': ('hjernehinne',),
'hjernehinnen': ('hjernehinne',),
'hjernehinnene': ('hjernehinne',),
'hjernehinner': ('hjernehinne',),
'hjernehinnebetennelse': ('hjernehinnebetennelse',),
'hjernehinnebetennelsen': ('hjernehinnebetennelse',),
'hjernehinnebetennelsene': ('hjernehinnebetennelse',),
'hjernehinnebetennelser': ('hjernehinnebetennelse',),
'hjernelammelse': ('hjernelammelse',),
'hjernelammelsen': ('hjernelammelse',),
'hjernelammelsene': ('hjernelammelse',),
'hjernelammelser': ('hjernelammelse',),
'hjernemasse': ('hjernemasse',),
'hjernemassen': ('hjernemasse',),
'hjernemassene': ('hjernemasse',),
'hjernemasser': ('hjernemasse',),
'hjernerystelse': ('hjernerystelse',),
'hjernerystelsen': ('hjernerystelse',),
'hjernerystelsene': ('hjernerystelse',),
'hjernerystelser': ('hjernerystelse',),
'hjerneskade': ('hjerneskade',),
'hjerneskaden': ('hjerneskade',),
'hjerneskadene': ('hjerneskade',),
'hjerneskader': ('hjerneskade',),
'hjerneskalle': ('hjerneskalle',),
'hjerneskallen': ('hjerneskalle',),
'hjerneskallene': ('hjerneskalle',),
'hjerneskaller': ('hjerneskalle',),
'hjerneslag': ('hjerneslag',),
'hjerneslaga': ('hjerneslag',),
'hjerneslagene': ('hjerneslag',),
'hjerneslaget': ('hjerneslag',),
'hjernespinn': ('hjernespinn',),
'hjernespinna': ('hjernespinn',),
'hjernespinnene': ('hjernespinn',),
'hjernespinnet': ('hjernespinn',),
'hjernestamme': ('hjernestamme',),
'hjernestammen': ('hjernestamme',),
'hjernestammene': ('hjernestamme',),
'hjernestammer': ('hjernestamme',),
'hjernesvulst': ('hjernesvulst',),
'hjernesvulsten': ('hjernesvulst',),
'hjernesvulstene': ('hjernesvulst',),
'hjernesvulster': ('hjernesvulst',),
'hjernetrust': ('hjernetrust',),
'hjernetrusten': ('hjernetrust',),
'hjernetrustene': ('hjernetrust',),
'hjernetruster': ('hjernetrust',),
'hjernevask': ('hjernevask',),
'hjernevasken': ('hjernevask',),
'hjernevaskene': ('hjernevask',),
'hjernevasker': ('hjernevask',),
'hjernevasking': ('hjernevasking',),
'hjernevaskinga': ('hjernevasking',),
'hjernevaskingen': ('hjernevasking',),
'hjernevaskingene': ('hjernevasking',),
'hjernevaskinger': ('hjernevasking',),
'hjernevinding': ('hjernevinding',),
'hjernevindinga': ('hjernevinding',),
'hjernevindingen': ('hjernevinding',),
'hjernevindingene': ('hjernevinding',),
'hjernevindinger': ('hjernevinding',),
'hjerta': ('hjerte',),
'hjerte': ('hjerte',),
'hjertene': ('hjerte',),
'hjerter': ('hjerte',),
'hjertet': ('hjerte',),
'hjerte- og karsjukdom': ('hjerte- og karsjukdom',),
'hjerte- og karsjukdommen': ('hjerte- og karsjukdom',),
'hjerte- og karsjukdommene': ('hjerte- og karsjukdom',),
'hjerte- og karsjukdommer': ('hjerte- og karsjukdom',),
'hjerte- og karsykdom': ('hjerte- og karsykdom',),
'hjerte- og karsykdommen': ('hjerte- og karsykdom',),
'hjerte- og karsykdommene': ('hjerte- og karsykdom',),
'hjerte- og karsykdommer': ('hjerte- og karsykdom',),
'hjerte-karsjukdom': ('hjerte-karsjukdom',),
'hjerte-karsjukdommen': ('hjerte-karsjukdom',),
'hjerte-karsjukdommene': ('hjerte-karsjukdom',),
'hjerte-karsjukdommer': ('hjerte-karsjukdom',),
'hjerte-karsykdom': ('hjerte-karsykdom',),
'hjerte-karsykdommen': ('hjerte-karsykdom',),
'hjerte-karsykdommene': ('hjerte-karsykdom',),
'hjerte-karsykdommer': ('hjerte-karsykdom',),
'hjerte-lunge-maskin': ('hjerte-lunge-maskin',),
'hjerte-lunge-maskina': ('hjerte-lunge-maskin',),
'hjerte-lunge-maskinen': ('hjerte-lunge-maskin',),
'hjerte-lunge-maskinene': ('hjerte-lunge-maskin',),
'hjerte-lunge-maskiner': ('hjerte-lunge-maskin',),
'hjerteanfall': ('hjerteanfall',),
'hjerteanfalla': ('hjerteanfall',),
'hjerteanfallene': ('hjerteanfall',),
'hjerteanfallet': ('hjerteanfall',),
'hjerteattakk': ('hjerteattakk',),
'hjerteattakka': ('hjerteattakk',),
'hjerteattakkene': ('hjerteattakk',),
'hjerteattakker': ('hjerteattakk',),
'hjerteattakket': ('hjerteattakk',),
'hjertebank': ('hjertebank',),
'hjertebanken': ('hjertebank',),
'hjertebankene': ('hjertebank',),
'hjertebanker': ('hjertebank',),
'hjertebarn': ('hjertebarn',),
'hjertebarna': ('hjertebarn',),
'hjertebarnene': ('hjertebarn',),
'hjertebarnet': ('hjertebarn',),
'hjerteblod': ('hjerteblod',),
'hjertebloda': ('hjerteblod',),
'hjerteblodene': ('hjerteblod',),
'hjerteblodet': ('hjerteblod',),
'hjerteblokk': ('hjerteblokk',),
'hjerteblokka': ('hjerteblokk',),
'hjerteblokkene': ('hjerteblokk',),
'hjerteblokket': ('hjerteblokk',),
'hjertedør': ('hjertedør',),
'hjertedøra': ('hjertedør',),
'hjertedøren': ('hjertedør',),
'hjertedørene': ('hjertedør',),
'hjertedører': ('hjertedør',),
'hjertefeil': ('hjertefeil',),
'hjertefeilen': ('hjertefeil',),
'hjertefeilene': ('hjertefeil',),
'hjerteflimmer': ('hjerteflimmer',),
'hjerteflimmera': ('hjerteflimmer',),
'hjerteflimmerene': ('hjerteflimmer',),
'hjerteflimmeret': ('hjerteflimmer',),
'hjerteflimra': ('hjerteflimmer',),
'hjerteflimre': ('hjerteflimmer',),
'hjerteflimrene': ('hjerteflimmer',),
'hjerteform': ('hjerteform',),
'hjerteforma': ('hjerteform',),
'hjerteformen': ('hjerteform',),
'hjerteformene': ('hjerteform',),
'hjerteformer': ('hjerteform',),
'hjerteinfarkt': ('hjerteinfarkt',),
'hjerteinfarkta': ('hjerteinfarkt',),
'hjerteinfarktene': ('hjerteinfarkt',),
'hjerteinfarkter': ('hjerteinfarkt',),
'hjerteinfarktet': ('hjerteinfarkt',),
'hjertekammer': ('hjertekammer',),
'hjertekammeret': ('hjertekammer',),
'hjertekamra': ('hjertekammer',),
'hjertekamre': ('hjertekammer',),
'hjertekamrene': ('hjertekammer',),
'hjerteklaff': ('hjerteklaff',),
'hjerteklaffen': ('hjerteklaff',),
'hjerteklaffene': ('hjerteklaff',),
'hjerteklaffer': ('hjerteklaff',),
'hjerteklapp': ('hjerteklapp',),
'hjerteklappa': ('hjerteklapp',),
'hjerteklappen': ('hjerteklapp',),
'hjerteklappene': ('hjerteklapp',),
'hjerteklapper': ('hjerteklapp',),
'hjerteklappet': ('hjerteklapp',),
'hjerteklapp': ('hjerteklapp',),
'hjerteklappa': ('hjerteklapp',),
'hjerteklappen': ('hjerteklapp',),
'hjerteklappene': ('hjerteklapp',),
'hjerteklapper': ('hjerteklapp',),
'hjerteklappet': ('hjerteklapp',),
'hjerteknuser': ('hjerteknuser',),
'hjerteknusere': ('hjerteknuser',),
'hjerteknuseren': ('hjerteknuser',),
'hjerteknuserer': ('hjerteknuser',),
'hjerteknuserne': ('hjerteknuser',),
'hjertekrampe': ('hjertekrampe',),
'hjertekrampen': ('hjertekrampe',),
'hjertekrampene': ('hjertekrampe',),
'hjertekramper': ('hjertekrampe',),
'hjertekulda': ('hjertekulde',),
'hjertekulde': ('hjertekulde',),
'hjertekulden': ('hjertekulde',),
'hjertekuldene': ('hjertekulde',),
'hjertekulder': ('hjertekulde',),
'hjertekula': ('hjertekule',),
'hjertekule': ('hjertekule',),
'hjertekulen': ('hjertekule',),
'hjertekulene': ('hjertekule',),
'hjertekuler': ('hjertekule',),
'hjertelag': ('hjertelag',),
'hjertelaga': ('hjertelag',),
'hjertelagene': ('hjertelag',),
'hjertelaget': ('hjertelag',),
'hjertelammelse': ('hjertelammelse',),
'hjertelammelsen': ('hjertelammelse',),
'hjertelammelsene': ('hjertelammelse',),
'hjertelammelser': ('hjertelammelse',),
'hjerteløshet': ('hjerteløshet',),
'hjerteløsheta': ('hjerteløshet',),
'hjerteløsheten': ('hjerteløshet',),
'hjerteløshetene': ('hjerteløshet',),
'hjerteløsheter': ('hjerteløshet',),
'hjertenskjær': ('hjertenskjær',),
'hjerteonda': ('hjerteonde',),
'hjerteonde': ('hjerteonde',),
'hjerteondene': ('hjerteonde',),
'hjerteonder': ('hjerteonde',),
'hjerteondet': ('hjerteonde',),
'hjerter': ('hjerter',),
'hjertere': ('hjerter',),
'hjerteren': ('hjerter',),
'hjerterer': ('hjerter',),
'hjerterne': ('hjerter',),
'hjerterom': ('hjerterom',),
'hjerteromma': ('hjerterom',),
'hjerterommene': ('hjerterom',),
'hjerterommet': ('hjerterom',),
'hjertesak': ('hjertesak',),
'hjertesaka': ('hjertesak',),
'hjertesaken': ('hjertesak',),
'hjertesakene': ('hjertesak',),
'hjertesaker': ('hjertesak',),
'hjertesjukdom': ('hjertesjukdom',),
'hjertesjukdommen': ('hjertesjukdom',),
'hjertesjukdommene': ('hjertesjukdom',),
'hjertesjukdommer': ('hjertesjukdom',),
'hjerteslag': ('hjerteslag',),
'hjerteslaga': ('hjerteslag',),
'hjerteslagene': ('hjerteslag',),
'hjerteslaget': ('hjerteslag',),
'hjertesorg': ('hjertesorg',),
'hjertesorga': ('hjertesorg',),
'hjertesorgen': ('hjertesorg',),
'hjertesorgene': ('hjertesorg',),
'hjertesorger': ('hjertesorg',),
'hjertestyrker': ('hjertestyrker',),
'hjertestyrkere': ('hjertestyrker',),
'hjertestyrkeren': ('hjertestyrker',),
'hjertestyrkerer': ('hjertestyrker',),
'hjertestyrkerne': ('hjertestyrker',),
'hjertestyrking': ('hjertestyrking',),
'hjertestyrkinga': ('hjertestyrking',),
'hjertestyrkingen': ('hjertestyrking',),
'hjertestyrkingene': ('hjertestyrking',),
'hjertestyrkinger': ('hjertestyrking',),
'hjertestyrkning': ('hjertestyrkning',),
'hjertestyrkninga': ('hjertestyrkning',),
'hjertestyrkningen': ('hjertestyrkning',),
'hjertestyrkningene': ('hjertestyrkning',),
'hjertestyrkninger': ('hjertestyrkning',),
'hjertesukk': ('hjertesukk',),
'hjertesukka': ('hjertesukk',),
'hjertesukken': ('hjertesukk',),
'hjertesukkene': ('hjertesukk',),
'hjertesukket': ('hjertesukk',),
'hjertesvikt': ('hjertesvikt',),
'hjertesvikten': ('hjertesvikt',),
'hjertesviktene': ('hjertesvikt',),
'hjertesvikter': ('hjertesvikt',),
'hjertesykdom': ('hjertesykdom',),
'hjertesykdommen': ('hjertesykdom',),
'hjertesykdommene': ('hjertesykdom',),
'hjertesykdommer': ('hjertesykdom',),
'hjertesår': ('hjertesår',),
'hjertesåra': ('hjertesår',),
'hjertesårene': ('hjertesår',),
'hjertesåret': ('hjertesår',),
'hjertetilfella': ('hjertetilfelle',),
'hjertetilfelle': ('hjertetilfelle',),
'hjertetilfellene': ('hjertetilfelle',),
'hjertetilfeller': ('hjertetilfelle',),
'hjertetilfellet': ('hjertetilfelle',),
'hjertetransplantasjon': ('hjertetransplantasjon',),
'hjertetransplantasjonen': ('hjertetransplantasjon',),
'hjertetransplantasjonene': ('hjertetransplantasjon',),
'hjertetransplantasjoner': ('hjertetransplantasjon',),
'hjertevenn': ('hjertevenn',),
'hjertevennen': ('hjertevenn',),
'hjertevennene': ('hjertevenn',),
'hjertevenner': ('hjertevenn',),
'hjon': ('hjon',),
'hjona': ('hjon',),
'hjonene': ('hjon',),
'hjonet': ('hjon',),
'hjonelag': ('hjonelag',),
'hjonelaga': ('hjonelag',),
'hjonelagene': ('hjonelag',),
'hjonelaget': ('hjonelag',),
'hjonskap': ('hjonskap',),
'hjonskapa': ('hjonskap',),
'hjonskapen': ('hjonskap',),
'hjonskapene': ('hjonskap',),
'hjonskaper': ('hjonskap',),
'hjonskapet': ('hjonskap',),
'hjord': ('hjord',),
'hjorden': ('hjord',),
'hjordene': ('hjord',),
'hjorder': ('hjord',),
'hjort': ('hjort',),
'hjorten': ('hjort',),
'hjortene': ('hjort',),
'hjorter': ('hjort',),
'hjortejakt': ('hjortejakt',),
'hjortejakta': ('hjortejakt',),
'hjortejakten': ('hjortejakt',),
'hjortejaktene': ('hjortejakt',),
'hjortejakter': ('hjortejakt',),
'hjortekolla': ('hjortekolle',),
'hjortekolle': ('hjortekolle',),
'hjortekollen': ('hjortekolle',),
'hjortekollene': ('hjortekolle',),
'hjortekoller': ('hjortekolle',),
'hjortesvin': ('hjortesvin',),
'hjortesvina': ('hjortesvin',),
'hjortesvinene': ('hjortesvin',),
'hjortesvinet': ('hjortesvin',),
'hjortetagg': ('hjortetagg',),
'hjortetaggen': ('hjortetagg',),
'hjortetaggene': ('hjortetagg',),
'hjortetagger': ('hjortetagg',),
'hjortetakk': ('hjortetakk',),
'hjortetakken': ('hjortetakk',),
'hjortetakkene': ('hjortetakk',),
'hjortetakker': ('hjortetakk',),
'hjortetakksalt': ('hjortetakksalt',),
'hjortetakksalta': ('hjortetakksalt',),
'hjortetakksaltene': ('hjortetakksalt',),
'hjortetakksalter': ('hjortetakksalt',),
'hjortetakksaltet': ('hjortetakksalt',),
'hjortkolla': ('hjortkolle',),
'hjortkolle': ('hjortkolle',),
'hjortkollen': ('hjortkolle',),
'hjortkollene': ('hjortkolle',),
'hjortkoller': ('hjortkolle',),
'hjul': ('hjul',),
'hjula': ('hjul',),
'hjulene': ('hjul',),
'hjulet': ('hjul',),
'hjulbåt': ('hjulbåt',),
'hjulbåten': ('hjulbåt',),
'hjulbåtene': ('hjulbåt',),
'hjulbåter': ('hjulbåt',),
'hjuldamper': ('hjuldamper',),
'hjuldampere': ('hjuldamper',),
'hjuldamperen': ('hjuldamper',),
'hjuldamperer': ('hjuldamper',),
'hjuldamperne': ('hjuldamper',),
'hjuldyr': ('hjuldyr',),
'hjuldyra': ('hjuldyr',),
'hjuldyrene': ('hjuldyr',),
'hjuldyret': ('hjuldyr',),
'hjulkors': ('hjulkors',),
'hjulkorsa': ('hjulkors',),
'hjulkorsene': ('hjulkors',),
'hjulkorset': ('hjulkors',),
'hjullaster': ('hjullaster',),
'hjullastere': ('hjullaster',),
'hjullasteren': ('hjullaster',),
'hjullasterer': ('hjullaster',),
'hjullasterne': ('hjullaster',),
'hjulmaker': ('hjulmaker',),
'hjulmakere': ('hjulmaker',),
'hjulmakeren': ('hjulmaker',),
'hjulmakerer': ('hjulmaker',),
'hjulmakerne': ('hjulmaker',),
'hjulrytter': ('hjulrytter',),
'hjulryttere': ('hjulrytter',),
'hjulrytteren': ('hjulrytter',),
'hjulrytterer': ('hjulrytter',),
'hjulrytterne': ('hjulrytter',),
'hjulrytterkompani': ('hjulrytterkompani',),
'hjulrytterkompania': ('hjulrytterkompani',),
'hjulrytterkompaniene': ('hjulrytterkompani',),
'hjulrytterkompanier': ('hjulrytterkompani',),
'hjulrytterkompaniet': ('hjulrytterkompani',),
'hjulspinner': ('hjulspinner',),
'hjulspinnere': ('hjulspinner',),
'hjulspinneren': ('hjulspinner',),
'hjulspinnerer': ('hjulspinner',),
'hjulspinnerne': ('hjulspinner',),
'hjulspor': ('hjulspor',),
'hjulspora': ('hjulspor',),
'hjulsporene': ('hjulspor',),
'hjulsporet': ('hjulspor',),
'hjulvisp': ('hjulvisp',),
'hjulvispen': ('hjulvisp',),
'hjulvispene': ('hjulvisp',),
'hjulvisper': ('hjulvisp',),
'hjupa': ('hjupe',),
'hjupe': ('hjupe',),
'hjupen': ('hjupe',),
'hjupene': ('hjupe',),
'hjuper': ('hjupe',),
'hjuring': ('hjuring',),
'hjuringen': ('hjuring',),
'hjuringene': ('hjuring',),
'hjuringer': ('hjuring',),
'hjåm': ('hjåm',),
'hjåma': ('hjåm',),
'hjåmene': ('hjåm',),
'hjåmet': ('hjåm',),
'hjørna': ('hjørne',),
'hjørne': ('hjørne',),
'hjørnene': ('hjørne',),
'hjørner': ('hjørne',),
'hjørnet': ('hjørne',),
'hjørnegruppa': ('hjørnegruppe',),
'hjørnegruppe': ('hjørnegruppe',),
'hjørnegruppen': ('hjørnegruppe',),
'hjørnegruppene': ('hjørnegruppe',),
'hjørnegrupper': ('hjørnegruppe',),
'hjørnegård': ('hjørnegård',),
'hjørnegården': ('hjørnegård',),
'hjørnegårdene': ('hjørnegård',),
'hjørnegårder': ('hjørnegård',),
'hjørneskap': ('hjørneskap',),
'hjørneskapa': ('hjørneskap',),
'hjørneskapene': ('hjørneskap',),
'hjørneskapet': ('hjørneskap',),
'hjørnesofa': ('hjørnesofa',),
'hjørnesofaen': ('hjørnesofa',),
'hjørnesofaene': ('hjørnesofa',),
'hjørnesofaer': ('hjørnesofa',),
'hjørnespark': ('hjørnespark',),
'hjørnesparka': ('hjørnespark',),
'hjørnesparkene': ('hjørnespark',),
'hjørnesparket': ('hjørnespark',),
'hjørnestein': ('hjørnestein',),
'hjørnesteinen': ('hjørnestein',),
'hjørnesteinene': ('hjørnestein',),
'hjørnesteiner': ('hjørnestein',),
'hjørnesteinsbedrift': ('hjørnesteinsbedrift',),
'hjørnesteinsbedriften': ('hjørnesteinsbedrift',),
'hjørnesteinsbedriftene': ('hjørnesteinsbedrift',),
'hjørnesteinsbedrifter': ('hjørnesteinsbedrift',),
'hjørnetann': ('hjørnetann',),
'hjørnetanna': ('hjørnetann',),
'hjørnetannen': ('hjørnetann',),
'hjørnetennene': ('hjørnetann',),
'hjørnetenner': ('hjørnetann',),
'hobby': ('hobby',),
'hobbyen': ('hobby',),
'hobbyene': ('hobby',),
'hobbyer': ('hobby',),
'hobbyklubb': ('hobbyklubb',),
'hobbyklubben': ('hobbyklubb',),
'hobbyklubbene': ('hobbyklubb',),
'hobbyklubber': ('hobbyklubb',),
'hobbyrom': ('hobbyrom',),
'hobbyromma': ('hobbyrom',),
'hobbyrommene': ('hobbyrom',),
'hobbyrommet': ('hobbyrom',),
'hobbyverksted': ('hobbyverksted',),
'hobbyverkstedene': ('hobbyverksted',),
'hobbyverksteder': ('hobbyverksted',),
'hobbyverkstedet': ('hobbyverksted',),
'hobbyverktøy': ('hobbyverktøy',),
'hobbyverktøya': ('hobbyverktøy',),
'hobbyverktøyene': ('hobbyverktøy',),
'hobbyverktøyer': ('hobbyverktøy',),
'hobbyverktøyet': ('hobbyverktøy',),
'hocke': ('hocke',),
'hocken': ('hocke',),
'hockene': ('hocke',),
'hocker': ('hocke',),
'hockey': ('hockey',),
'hockeyen': ('hockey',),
'hockeyene': ('hockey',),
'hockeyer': ('hockey',),
'hodda': ('hodde',),
'hodde': ('hodde',),
'hodden': ('hodde',),
'hoddene': ('hodde',),
'hodder': ('hodde',),
'hoda': ('hode',),
'hode': ('hode',),
'hodene': ('hode',),
'hoder': ('hode',),
'hodet': ('hode',),
'hodearbeid': ('hodearbeid',),
'hodearbeida': ('hodearbeid',),
'hodearbeidene': ('hodearbeid',),
'hodearbeider': ('hodearbeid',),
'hodearbeidet': ('hodearbeid',),
'hodebotn': ('hodebotn',),
'hodebotnen': ('hodebotn',),
'hodebotnene': ('hodebotn',),
'hodebotner': ('hodebotn',),
'hodebry': ('hodebry',),
'hodebrya': ('hodebry',),
'hodebryene': ('hodebry',),
'hodebryet': ('hodebry',),
'hodebunn': ('hodebunn',),
'hodebunnen': ('hodebunn',),
'hodebunnene': ('hodebunn',),
'hodebunner': ('hodebunn',),
'hodeduell': ('hodeduell',),
'hodeduellen': ('hodeduell',),
'hodeduellene': ('hodeduell',),
'hodedueller': ('hodeduell',),
'hodegjerda': ('hodegjerde',),
'hodegjerde': ('hodegjerde',),
'hodegjerdene': ('hodegjerde',),
'hodegjerder': ('hodegjerde',),
'hodegjerdet': ('hodegjerde',),
'hodejakt': ('hodejakt',),
'hodejakta': ('hodejakt',),
'hodejakten': ('hodejakt',),
'hodejaktene': ('hodejakt',),
'hodejakter': ('hodejakt',),
'hodejeger': ('hodejeger',),
'hodejegere': ('hodejeger',),
'hodejegeren': ('hodejeger',),
'hodejegerer': ('hodejeger',),
'hodejegerne': ('hodejeger',),
'hodekål': ('hodekål',),
'hodekålen': ('hodekål',),
'hodekålene': ('hodekål',),
'hodekåler': ('hodekål',),
'hodelag': ('hodelag',),
'hodelaga': ('hodelag',),
'hodelagene': ('hodelag',),
'hodelaget': ('hodelag',),
'hodelus': ('hodelus',),
'hodelusa': ('hodelus',),
'hodelusen': ('hodelus',),
'hodelusene': ('hodelus',),
'hodelykt': ('hodelykt',),
'hodelykta': ('hodelykt',),
'hodelykten': ('hodelykt',),
'hodelyktene': ('hodelykt',),
'hodelykter': ('hodelykt',),
'hodepina': ('hodepine',),
'hodepine': ('hodepine',),
'hodepinen': ('hodepine',),
'hodepinene': ('hodepine',),
'hodepiner': ('hodepine',),
'hodeplagg': ('hodeplagg',),
'hodeplagga': ('hodeplagg',),
'hodeplaggene': ('hodeplagg',),
'hodeplagget': ('hodeplagg',),
'hodeputa': ('hodepute',),
'hodepute': ('hodepute',),
'hodeputen': ('hodepute',),
'hodeputene': ('hodepute',),
'hodeputer': ('hodepute',),
'hoderegning': ('hoderegning',),
'hoderegninga': ('hoderegning',),
'hoderegningen': ('hoderegning',),
'hoderegningene': ('hoderegning',),
'hoderegninger': ('hoderegning',),
'hoderekning': ('hoderekning',),
'hoderekninga': ('hoderekning',),
'hoderekningen': ('hoderekning',),
'hoderekningene': ('hoderekning',),
'hoderekninger': ('hoderekning',),
'hoderisting': ('hoderisting',),
'hoderistinga': ('hoderisting',),
'hoderistingen': ('hoderisting',),
'hoderistingene': ('hoderisting',),
'hoderistinger': ('hoderisting',),
'hodesalat': ('hodesalat',),
'hodesalaten': ('hodesalat',),
'hodesalatene': ('hodesalat',),
'hodesalater': ('hodesalat',),
'hodeskalle': ('hodeskalle',),
'hodeskallen': ('hodeskalle',),
'hodeskallene': ('hodeskalle',),
'hodeskaller': ('hodeskalle',),
'hodeskål': ('hodeskål',),
'hodeskåla': ('hodeskål',),
'hodeskålen': ('hodeskål',),
'hodeskålene': ('hodeskål',),
'hodeskåler': ('hodeskål',),
'hodestøtta': ('hodestøtte',),
'hodestøtte': ('hodestøtte',),
'hodestøtten': ('hodestøtte',),
'hodestøttene': ('hodestøtte',),
'hodestøtter': ('hodestøtte',),
'hodetelefon': ('hodetelefon',),
'hodetelefonen': ('hodetelefon',),
'hodetelefonene': ('hodetelefon',),
'hodetelefoner': ('hodetelefon',),
'hodetørkle': ('hodetørkle',),
'hodetørkleet': ('hodetørkle',),
'hodetørklær': ('hodetørkle',),
'hodetørklærne': ('hodetørkle',),
'hodeverk': ('hodeverk',),
'hodeverken': ('hodeverk',),
'hodeverkene': ('hodeverk',),
'hodeverker': ('hodeverk',),
'hoff': ('hoff',),
'hoffa': ('hoff',),
'hoffene': ('hoff',),
'hoffet': ('hoff',),
'hoffadel': ('hoffadel',),
'hoffadelen': ('hoffadel',),
'hoffadlene': ('hoffadel',),
'hoffadler': ('hoffadel',),
'hoffdama': ('hoffdame',),
'hoffdame': ('hoffdame',),
'hoffdamen': ('hoffdame',),
'hoffdamene': ('hoffdame',),
'hoffdamer': ('hoffdame',),
'hoffjegermester': ('hoffjegermester',),
'hoffjegermestere': ('hoffjegermester',),
'hoffjegermesteren': ('hoffjegermester',),
'hoffjegermesterer': ('hoffjegermester',),
'hoffjegermesterne': ('hoffjegermester',),
'hoffjegermestre': ('hoffjegermester',),
'hoffjegermestrene': ('hoffjegermester',),
'hoffjegermestrer': ('hoffjegermester',),
'hoffmannsdråpene': ('hoffmannsdråper',),
'hoffmannsdråper': ('hoffmannsdråper',),
'hoffmarskalk': ('hoffmarskalk',),
'hoffmarskalken': ('hoffmarskalk',),
'hoffmarskalkene': ('hoffmarskalk',),
'hoffmarskalker': ('hoffmarskalk',),
'hoffnarr': ('hoffnarr',),
'hoffnarren': ('hoffnarr',),
'hoffnarrene': ('hoffnarr',),
'hoffnarrer': ('hoffnarr',),
'hoffsjef': ('hoffsjef',),
'hoffsjefen': ('hoffsjef',),
'hoffsjefene': ('hoffsjef',),
'hoffsjefer': ('hoffsjef',),
'hoffsorg': ('hoffsorg',),
'hoffsorga': ('hoffsorg',),
'hoffsorgen': ('hoffsorg',),
'hoffsorgene': ('hoffsorg',),
'hoffsorger': ('hoffsorg',),
'hoffstallmester': ('hoffstallmester',),
'hoffstallmestere': ('hoffstallmester',),
'hoffstallmesteren': ('hoffstallmester',),
'hoffstallmesterer': ('hoffstallmester',),
'hoffstallmesterne': ('hoffstallmester',),
'hoffstallmestre': ('hoffstallmester',),
'hoffstallmestrene': ('hoffstallmester',),
'hoffstallmestrer': ('hoffstallmester',),
'hoffstat': ('hoffstat',),
'hoffstaten': ('hoffstat',),
'hoffstatene': ('hoffstat',),
'hoffstater': ('hoffstat',),
'hoft': ('hoft',),
'hofta': ('hoft',),
'hoften': ('hoft',),
'hoftene': ('hoft',),
'hofter': ('hoft',),
'hofta': ('hofte',),
'hofte': ('hofte',),
'hoften': ('hofte',),
'hoftene': ('hofte',),
'hofter': ('hofte',),
'hoftebein': ('hoftebein',),
'hoftebeina': ('hoftebein',),
'hoftebeinene': ('hoftebein',),
'hoftebeinet': ('hoftebein',),
'hofteben': ('hofteben',),
'hoftebena': ('hofteben',),
'hoftebenene': ('hofteben',),
'hoftebenet': ('hofteben',),
'hoftefest': ('hoftefest',),
'hofteholder': ('hofteholder',),
'hofteholdere': ('hofteholder',),
'hofteholderen': ('hofteholder',),
'hofteholderer': ('hofteholder',),
'hofteholderne': ('hofteholder',),
'hofteledd': ('hofteledd',),
'hofteledda': ('hofteledd',),
'hofteleddene': ('hofteledd',),
'hofteleddet': ('hofteledd',),
'hofteleddsluksasjon': ('hofteleddsluksasjon',),
'hofteleddsluksasjonen': ('hofteleddsluksasjon',),
'hofteleddsluksasjonene': ('hofteleddsluksasjon',),
'hofteleddsluksasjoner': ('hofteleddsluksasjon',),
'hofteskål': ('hofteskål',),
'hofteskåla': ('hofteskål',),
'hofteskålen': ('hofteskål',),
'hofteskålene': ('hofteskål',),
'hofteskåler': ('hofteskål',),
'hoftesving': ('hoftesving',),
'hoftesvingen': ('hoftesving',),
'hoftesvingene': ('hoftesving',),
'hoftesvinger': ('hoftesving',),
'hogger': ('hogger',),
'hoggere': ('hogger',),
'hoggeren': ('hogger',),
'hoggerer': ('hogger',),
'hoggerne': ('hogger',),
'hoggeri': ('hoggeri',),
'hoggeria': ('hoggeri',),
'hoggeriene': ('hoggeri',),
'hoggerier': ('hoggeri',),
'hoggeriet': ('hoggeri',),
'hoggestabbe': ('hoggestabbe',),
'hoggestabben': ('hoggestabbe',),
'hoggestabbene': ('hoggestabbe',),
'hoggestabber': ('hoggestabbe',),
'hoggjern': ('hoggjern',),
'hoggjerna': ('hoggjern',),
'hoggjernene': ('hoggjern',),
'hoggjernet': ('hoggjern',),
'hoggorm': ('hoggorm',),
'hoggormen': ('hoggorm',),
'hoggormene': ('hoggorm',),
'hoggormer': ('hoggorm',),
'hoggsår': ('hoggsår',),
'hoggsåra': ('hoggsår',),
'hoggsårene': ('hoggsår',),
'hoggsåret': ('hoggsår',),
'hoggtann': ('hoggtann',),
'hoggtanna': ('hoggtann',),
'hoggtannen': ('hoggtann',),
'hoggtennene': ('hoggtann',),
'hoggtenner': ('hoggtann',),
'hoggvåpen': ('hoggvåpen',),
'hoggvåpenet': ('hoggvåpen',),
'hoggvåpna': ('hoggvåpen',),
'hoggvåpnene': ('hoggvåpen',),
'hogst': ('hogst',),
'hogsten': ('hogst',),
'hogstene': ('hogst',),
'hogster': ('hogst',),
'hogstklassa': ('hogstklasse',),
'hogstklasse': ('hogstklasse',),
'hogstklassen': ('hogstklasse',),
'hogstklassene': ('hogstklasse',),
'hogstklasser': ('hogstklasse',),
'hogstredskap': ('hogstredskap',),
'hogstredskapa': ('hogstredskap',),
'hogstredskapen': ('hogstredskap',),
'hogstredskapene': ('hogstredskap',),
'hogstredskaper': ('hogstredskap',),
'hogstredskapet': ('hogstredskap',),
'hohenstaufer': ('hohenstaufer',),
'hohenstaufere': ('hohenstaufer',),
'hohenstauferen': ('hohenstaufer',),
'hohenstauferer': ('hohenstaufer',),
'hohenstauferne': ('hohenstaufer',),
'hohenzoller': ('hohenzoller',),
'hohenzollere': ('hohenzoller',),
'hohenzolleren': ('hohenzoller',),
'hohenzollerer': ('hohenzoller',),
'hohenzollerne': ('hohenzoller',),
'hokk': ('hokk',),
'hokka': ('hokk',),
'hokkene': ('hokk',),
'hokket': ('hokk',),
'hokuspokus': ('hokuspokus',),
'hokuspokusa': ('hokuspokus',),
'hokuspokusene': ('hokuspokus',),
'hokuspokuset': ('hokuspokus',),
'hol': ('hol',),
'holen': ('hol',),
'holene': ('hol',),
'holer': ('hol',),
'hol': ('hol',),
'hola': ('hol',),
'holene': ('hol',),
'holet': ('hol',),
'holband': ('holband',),
'holbanda': ('holband',),
'holbandene': ('holband',),
'holbandet': ('holband',),
'holbånd': ('holbånd',),
'holbånda': ('holbånd',),
'holbåndene': ('holbånd',),
'holbåndet': ('holbånd',),
'hold up': ('hold up',),
'hold upa': ('hold up',),
'hold upene': ('hold up',),
'hold upet': ('hold up',),
'holdeplass': ('holdeplass',),
'holdeplassen': ('holdeplass',),
'holdeplassene': ('holdeplass',),
'holdeplasser': ('holdeplass',),
'holdepunkt': ('holdepunkt',),
'holdepunkta': ('holdepunkt',),
'holdepunktene': ('holdepunkt',),
'holdepunkter': ('holdepunkt',),
'holdepunktet': ('holdepunkt',),
'holder': ('holder',),
'holdere': ('holder',),
'holderen': ('holder',),
'holderer': ('holder',),
'holderne': ('holder',),
'holdetid': ('holdetid',),
'holdetida': ('holdetid',),
'holdetiden': ('holdetid',),
'holdetidene': ('holdetid',),
'holdetider': ('holdetid',),
'holdingkompani': ('holdingkompani',),
'holdingkompania': ('holdingkompani',),
'holdingkompaniene': ('holdingkompani',),
'holdingkompanier': ('holdingkompani',),
'holdingkompaniet': ('holdingkompani',),
'holdingselskap': ('holdingselskap',),
'holdingselskapa': ('holdingselskap',),
'holdingselskapene': ('holdingselskap',),
'holdingselskaper': ('holdingselskap',),
'holdingselskapet': ('holdingselskap',),
'holdning': ('holdning',),
'holdninga': ('holdning',),
'holdningen': ('holdning',),
'holdningene': ('holdning',),
'holdninger': ('holdning',),
'holdningsendring': ('holdningsendring',),
'holdningsendringa': ('holdningsendring',),
'holdningsendringen': ('holdningsendring',),
'holdningsendringene': ('holdningsendring',),
'holdningsendringer': ('holdningsendring',),
'holdningsfeil': ('holdningsfeil',),
'holdningsfeilen': ('holdningsfeil',),
'holdningsfeilene': ('holdningsfeil',),
'holdt': ('holdt',),
'hole': ('hole',),
'holen': ('hole',),
'holene': ('hole',),
'holer': ('hole',),
'hola': ('hole',),
'hole': ('hole',),
'holen': ('hole',),
'holene': ('hole',),
'holer': ('hole',),
'holeboer': ('holeboer',),
'holeboere': ('holeboer',),
'holeboeren': ('holeboer',),
'holeboerer': ('holeboer',),
'holeboerne': ('holeboer',),
'holebuer': ('holebuer',),
'holebuere': ('holebuer',),
'holebueren': ('holebuer',),
'holebuerer': ('holebuer',),
'holebuerne': ('holebuer',),
'holemaleri': ('holemaleri',),
'holemaleria': ('holemaleri',),
'holemaleriene': ('holemaleri',),
'holemalerier': ('holemaleri',),
'holemaleriet': ('holemaleri',),
'holjern': ('holjern',),
'holjerna': ('holjern',),
'holjernene': ('holjern',),
'holjernet': ('holjern',),
'holk': ('holk',),
'holken': ('holk',),
'holkene': ('holk',),
'holker': ('holk',),
'holk': ('holk',),
'holken': ('holk',),
'holkene': ('holk',),
'holker': ('holk',),
'holkil': ('holkil',),
'holkilen': ('holkil',),
'holkilene': ('holkil',),
'holkiler': ('holkil',),
'holkort': ('holkort',),
'holkorta': ('holkort',),
'holkortene': ('holkort',),
'holkortet': ('holkort',),
'holkortmaskin': ('holkortmaskin',),
'holkortmaskina': ('holkortmaskin',),
'holkortmaskinen': ('holkortmaskin',),
'holkortmaskinene': ('holkortmaskin',),
'holkortmaskiner': ('holkortmaskin',),
'holkortmetode': ('holkortmetode',),
'holkortmetoden': ('holkortmetode',),
'holkortmetodene': ('holkortmetode',),
'holkortmetoder': ('holkortmetode',),
'holkortoperatør': ('holkortoperatør',),
'holkortoperatøren': ('holkortoperatør',),
'holkortoperatørene': ('holkortoperatør',),
'holkortoperatører': ('holkortoperatør',),
'hollandés': ('hollandés',),
'hollandésn': ('hollandés',),
'hollandésne': ('hollandés',),
'hollandésr': ('hollandés',),
'hollender': ('hollender',),
'hollendere': ('hollender',),
'hollenderen': ('hollender',),
'hollenderer': ('hollender',),
'hollenderne': ('hollender',),
'holme': ('holme',),
'holmen': ('holme',),
'holmene': ('holme',),
'holmer': ('holme',),
'holme': ('holme',),
'holmen': ('holme',),
'holmene': ('holme',),
'holmer': ('holme',),
'holmgang': ('holmgang',),
'holmgangen': ('holmgang',),
'holmgangene': ('holmgang',),
'holmganger': ('holmgang',),
'holmium': ('holmium',),
'holmiuma': ('holmium',),
'holmiumene': ('holmium',),
'holmiumet': ('holmium',),
'holmur': ('holmur',),
'holmuren': ('holmur',),
'holmurene': ('holmur',),
'holmurer': ('holmur',),
'holmål': ('holmål',),
'holmåla': ('holmål',),
'holmålene': ('holmål',),
'holmålet': ('holmål',),
'holocaust': ('holocaust',),
'holocausten': ('holocaust',),
'holocaustene': ('holocaust',),
'holocauster': ('holocaust',),
'holograf': ('holograf',),
'holografen': ('holograf',),
'holografene': ('holograf',),
'holografer': ('holograf',),
'holografi': ('holografi',),
'holografien': ('holografi',),
'holografiene': ('holografi',),
'holografier': ('holografi',),
'hologram': ('hologram',),
'hologramma': ('hologram',),
'hologrammene': ('hologram',),
'hologrammer': ('hologram',),
'hologrammet': ('hologram',),
'holrom': ('holrom',),
'holromma': ('holrom',),
'holrommene': ('holrom',),
'holrommet': ('holrom',),
'holsleiv': ('holsleiv',),
'holsleiva': ('holsleiv',),
'holsleiven': ('holsleiv',),
'holsleivene': ('holsleiv',),
'holsleiver': ('holsleiv',),
'holspeil': ('holspeil',),
'holspeila': ('holspeil',),
'holspeilene': ('holspeil',),
'holspeilet': ('holspeil',),
'holsteiner': ('holsteiner',),
'holsteinere': ('holsteiner',),
'holsteineren': ('holsteiner',),
'holsteinerer': ('holsteiner',),
'holsteinerne': ('holsteiner',),
'holsøm': ('holsøm',),
'holsømmen': ('holsøm',),
'holsømmene': ('holsøm',),
'holsømmer': ('holsøm',),
'holt': ('holt',),
'holta': ('holt',),
'holtene': ('holt',),
'holtet': ('holt',),
'holt': ('holt',),
'holta': ('holt',),
'holten': ('holt',),
'holtene': ('holt',),
'holter': ('holt',),
'holtet': ('holt',),
'holtann': ('holtann',),
'holtanna': ('holtann',),
'holtannen': ('holtann',),
'holtennene': ('holtann',),
'holtenner': ('holtann',),
'holveg': ('holveg',),
'holvegen': ('holveg',),
'holvegene': ('holveg',),
'holveger': ('holveg',),
'holvene': ('holvene',),
'holvenen': ('holvene',),
'holvenene': ('holvene',),
'holvener': ('holvene',),
'hombot': ('hombot',),
'hombota': ('hombot',),
'homboten': ('hombot',),
'hombøtene': ('hombot',),
'hombøter': ('hombot',),
'homiletikk': ('homiletikk',),
'homiletikken': ('homiletikk',),
'homiletikkene': ('homiletikk',),
'homiletikker': ('homiletikk',),
'homilie': ('homilie',),
'homilien': ('homilie',),
'homiliene': ('homilie',),
'homilier': ('homilie',),
'homiliebok': ('homiliebok',),
'homilieboka': ('homiliebok',),
'homilieboken': ('homiliebok',),
'homiliebøkene': ('homiliebok',),
'homiliebøker': ('homiliebok',),
'homo': ('homo',),
'homoen': ('homo',),
'homoene': ('homo',),
'homoer': ('homo',),
'homo sapiens': ('homo sapiens',),
'homofili': ('homofili',),
'homofilien': ('homofili',),
'homofiliene': ('homofili',),
'homofilier': ('homofili',),
'homofon': ('homofon',),
'homofonen': ('homofon',),
'homofonene': ('homofon',),
'homofoner': ('homofon',),
'homofoni': ('homofoni',),
'homofonien': ('homofoni',),
'homofoniene': ('homofoni',),
'homofonier': ('homofoni',),
'homogenitet': ('homogenitet',),
'homogeniteten': ('homogenitet',),
'homogenitetene': ('homogenitet',),
'homogeniteter': ('homogenitet',),
'homograf': ('homograf',),
'homografen': ('homograf',),
'homografene': ('homograf',),
'homografer': ('homograf',),
'homografi': ('homografi',),
'homografien': ('homografi',),
'homografiene': ('homografi',),
'homografier': ('homografi',),
'homonym': ('homonym',),
'homonyma': ('homonym',),
'homonymene': ('homonym',),
'homonymer': ('homonym',),
'homonymet': ('homonym',),
'homonymi': ('homonymi',),
'homonymien': ('homonymi',),
'homonymiene': ('homonymi',),
'homonymier': ('homonymi',),
'homoseksualitet': ('homoseksualitet',),
'homoseksualiteten': ('homoseksualitet',),
'homoseksualitetene': ('homoseksualitet',),
'homoseksualiteter': ('homoseksualitet',),
'homse': ('homse',),
'homsen': ('homse',),
'homsene': ('homse',),
'homser': ('homse',),
'homøopat': ('homøopat',),
'homøopaten': ('homøopat',),
'homøopatene': ('homøopat',),
'homøopater': ('homøopat',),
'homøopati': ('homøopati',),
'homøopatien': ('homøopati',),
'homøopatiene': ('homøopati',),
'homøopatier': ('homøopati',),
'honduraner': ('honduraner',),
'honduranere': ('honduraner',),
'honduraneren': ('honduraner',),
'honduranerer': ('honduraner',),
'honduranerne': ('honduraner',),
'honning': ('honning',),
'honningen': ('honning',),
'honningene': ('honning',),
'honninger': ('honning',),
'honningbia': ('honningbie',),
'honningbie': ('honningbie',),
'honningbien': ('honningbie',),
'honningbiene': ('honningbie',),
'honningbier': ('honningbie',),
'honningblom': ('honningblom',),
'honningblommen': ('honningblom',),
'honningblommene': ('honningblom',),
'honningblommer': ('honningblom',),
'honningdogg': ('honningdogg',),
'honningdogga': ('honningdogg',),
'honningdoggen': ('honningdogg',),
'honningdoggene': ('honningdogg',),
'honningdogger': ('honningdogg',),
'honningdugg': ('honningdugg',),
'honningduggen': ('honningdugg',),
'honningduggene': ('honningdugg',),
'honningdugger': ('honningdugg',),
'honninggjemma': ('honninggjemme',),
'honninggjemme': ('honninggjemme',),
'honninggjemmene': ('honninggjemme',),
'honninggjemmer': ('honninggjemme',),
'honninggjemmet': ('honninggjemme',),
'honningkaka': ('honningkake',),
'honningkake': ('honningkake',),
'honningkaken': ('honningkake',),
'honningkakene': ('honningkake',),
'honningkaker': ('honningkake',),
'honningplanta': ('honningplante',),
'honningplante': ('honningplante',),
'honningplanten': ('honningplante',),
'honningplantene': ('honningplante',),
'honningplanter': ('honningplante',),
'honningslynga': ('honningslynge',),
'honningslynge': ('honningslynge',),
'honningslyngen': ('honningslynge',),
'honningslyngene': ('honningslynge',),
'honningslynger': ('honningslynge',),
'honningsopp': ('honningsopp',),
'honningsoppen': ('honningsopp',),
'honningsoppene': ('honningsopp',),
'honningsopper': ('honningsopp',),
'honningtavla': ('honningtavle',),
'honningtavle': ('honningtavle',),
'honningtavlen': ('honningtavle',),
'honningtavlene': ('honningtavle',),
'honningtavler': ('honningtavle',),
'honnør': ('honnør',),
'honnøren': ('honnør',),
'honnørene': ('honnør',),
'honnører': ('honnør',),
'honnørbillett': ('honnørbillett',),
'honnørbilletten': ('honnørbillett',),
'honnørbillettene': ('honnørbillett',),
'honnørbilletter': ('honnørbillett',),
'honnørmarsj': ('honnørmarsj',),
'honnørmarsjen': ('honnørmarsj',),
'honnørmarsjene': ('honnørmarsj',),
'honnørmarsjer': ('honnørmarsj',),
'honnørord': ('honnørord',),
'honnørorda': ('honnørord',),
'honnørordene': ('honnørord',),
'honnørordet': ('honnørord',),
'honorar': ('honorar',),
'honorara': ('honorar',),
'honorarene': ('honorar',),
'honorarer': ('honorar',),
'honoraret': ('honorar',),
'honoratiores': ('honoratiores',),
'hook': ('hook',),
'hooken': ('hook',),
'hookene': ('hook',),
'hooker': ('hook',),
'hop': ('hop',),
'hopen': ('hop',),
'hopene': ('hop',),
'hoper': ('hop',),
'hopehav': ('hopehav',),
'hopehava': ('hopehav',),
'hopehavene': ('hopehav',),
'hopehavet': ('hopehav',),
'hopetal': ('hopetal',),
'hopetala': ('hopetal',),
'hopetalene': ('hopetal',),
'hopetalet': ('hopetal',),
'hopetall': ('hopetall',),
'hopetalla': ('hopetall',),
'hopetallene': ('hopetall',),
'hopetallet': ('hopetall',),
'hopp': ('hopp',),
'hoppa': ('hopp',),
'hoppene': ('hopp',),
'hoppet': ('hopp',),
'hoppbakke': ('hoppbakke',),
'hoppbakken': ('hoppbakke',),
'hoppbakkene': ('hoppbakke',),
'hoppbakker': ('hoppbakke',),
'hoppdommer': ('hoppdommer',),
'hoppdommere': ('hoppdommer',),
'hoppdommeren': ('hoppdommer',),
'hoppdommerer': ('hoppdommer',),
'hoppdommerne': ('hoppdommer',),
'hoppa': ('hoppe',),
'hoppe': ('hoppe',),
'hoppen': ('hoppe',),
'hoppene': ('hoppe',),
'hopper': ('hoppe',),
'hoppeføll': ('hoppeføll',),
'hoppefølla': ('hoppeføll',),
'hoppeføllene': ('hoppeføll',),
'hoppeføllet': ('hoppeføll',),
'hopper': ('hopper',),
'hoppere': ('hopper',),
'hopperen': ('hopper',),
'hopperer': ('hopper',),
'hopperne': ('hopper',),
'hoppestrikk': ('hoppestrikk',),
'hoppestrikken': ('hoppestrikk',),
'hoppestrikkene': ('hoppestrikk',),
'hoppestrikker': ('hoppestrikk',),
'hoppetau': ('hoppetau',),
'hoppetaua': ('hoppetau',),
'hoppetauene': ('hoppetau',),
'hoppetauer': ('hoppetau',),
'hoppetauet': ('hoppetau',),
'hopping': ('hopping',),
'hoppinga': ('hopping',),
'hoppingen': ('hopping',),
'hoppingene': ('hopping',),
'hoppinger': ('hopping',),
'hopprenn': ('hopprenn',),
'hopprenna': ('hopprenn',),
'hopprennene': ('hopprenn',),
'hopprennet': ('hopprenn',),
'hoppsa': ('hoppsa',),
'hoppsaen': ('hoppsa',),
'hoppsaene': ('hoppsa',),
'hoppsaer': ('hoppsa',),
'hoppsatakt': ('hoppsatakt',),
'hoppsatakta': ('hoppsatakt',),
'hoppsatakten': ('hoppsatakt',),
'hoppsataktene': ('hoppsatakt',),
'hoppsatakter': ('hoppsatakt',),
'hoppsatakt': ('hoppsatakt',),
'hoppsatakta': ('hoppsatakt',),
'hoppsatakten': ('hoppsatakt',),
'hoppsataktene': ('hoppsatakt',),
'hoppsatakter': ('hoppsatakt',),
'hoppski': ('hoppski',),
'hoppskia': ('hoppski',),
'hoppskien': ('hoppski',),
'hoppskiene': ('hoppski',),
'hoppskier': ('hoppski',),
'hoppuka': ('hoppuke',),
'hoppuke': ('hoppuke',),
'hoppuken': ('hoppuke',),
'hoppukene': ('hoppuke',),
'hoppuker': ('hoppuke',),
'hoppveka': ('hoppveke',),
'hoppveke': ('hoppveke',),
'hoppveken': ('hoppveke',),
'hoppvekene': ('hoppveke',),
'hoppveker': ('hoppveke',),
'hor': ('hor',),
'hora': ('hor',),
'horene': ('hor',),
'horet': ('hor',),
'hordalending': ('hordalending',),
'hordalendingen': ('hordalending',),
'hordalendingene': ('hordalending',),
'hordalendinger': ('hordalending',),
'horde': ('horde',),
'horden': ('horde',),
'hordene': ('horde',),
'horder': ('horde',),
'hordeinstinkt': ('hordeinstinkt',),
'hordeinstinkta': ('hordeinstinkt',),
'hordeinstinktene': ('hordeinstinkt',),
'hordeinstinkter': ('hordeinstinkt',),
'hordeinstinktet': ('hordeinstinkt',),
'hordementalitet': ('hordementalitet',),
'hordementaliteten': ('hordementalitet',),
'hordementalitetene': ('hordementalitet',),
'hordementaliteter': ('hordementalitet',),
'hora': ('hore',),
'hore': ('hore',),
'horen': ('hore',),
'horene': ('hore',),
'horer': ('hore',),
'horebukk': ('horebukk',),
'horebukken': ('horebukk',),
'horebukkene': ('horebukk',),
'horebukker': ('horebukk',),
'horehus': ('horehus',),
'horehusa': ('horehus',),
'horehusene': ('horehus',),
'horehuset': ('horehus',),
'horekunde': ('horekunde',),
'horekunden': ('horekunde',),
'horekundene': ('horekunde',),
'horekunder': ('horekunde',),
'horeunge': ('horeunge',),
'horeungen': ('horeunge',),
'horeungene': ('horeunge',),
'horeunger': ('horeunge',),
'horisont': ('horisont',),
'horisonten': ('horisont',),
'horisontene': ('horisont',),
'horisonter': ('horisont',),
'horisontal': ('horisontal',),
'horisontalen': ('horisontal',),
'horisontalene': ('horisontal',),
'horisontaler': ('horisontal',),
'horisontalplan': ('horisontalplan',),
'horisontalplana': ('horisontalplan',),
'horisontalplanene': ('horisontalplan',),
'horisontalplanet': ('horisontalplan',),
'hork': ('hork',),
'horka': ('hork',),
'horken': ('hork',),
'horkene': ('hork',),
'horker': ('hork',),
'horkar': ('horkar',),
'horkaren': ('horkar',),
'horkarene': ('horkar',),
'horkarer': ('horkar',),
'horkarl': ('horkarl',),
'horkarlen': ('horkarl',),
'horkarlene': ('horkarl',),
'horkarler': ('horkarl',),
'hormon': ('hormon',),
'hormona': ('hormon',),
'hormonene': ('hormon',),
'hormoner': ('hormon',),
'hormonet': ('hormon',),
'hormonpreparat': ('hormonpreparat',),
'hormonpreparata': ('hormonpreparat',),
'hormonpreparatene': ('hormonpreparat',),
'hormonpreparater': ('hormonpreparat',),
'hormonpreparatet': ('hormonpreparat',),
'horn': ('horn',),
'horna': ('horn',),
'hornene': ('horn',),
'hornet': ('horn',),
'hornblad': ('hornblad',),
'hornblada': ('hornblad',),
'hornbladene': ('hornblad',),
'hornblader': ('hornblad',),
'hornbladet': ('hornblad',),
'hornblende': ('hornblende',),
'hornblenden': ('hornblende',),
'hornblendene': ('hornblende',),
'hornblender': ('hornblende',),
'hornblenditt': ('hornblenditt',),
'hornblenditten': ('hornblenditt',),
'hornblendittene': ('hornblenditt',),
'hornblenditter': ('hornblenditt',),
'hornblåser': ('hornblåser',),
'hornblåsere': ('hornblåser',),
'hornblåseren': ('hornblåser',),
'hornblåserer': ('hornblåser',),
'hornblåserne': ('hornblåser',),
'hornbrilla': ('hornbrille',),
'hornbrille': ('hornbrille',),
'hornbrillen': ('hornbrille',),
'hornbrillene': ('hornbrille',),
'hornbriller': ('hornbrille',),
'horngjel': ('horngjel',),
'horngjela': ('horngjel',),
'horngjelene': ('horngjel',),
'horngjelet': ('horngjel',),
'hornhinna': ('hornhinne',),
'hornhinne': ('hornhinne',),
'hornhinnen': ('hornhinne',),
'hornhinnene': ('hornhinne',),
'hornhinner': ('hornhinne',),
'hornhinnebetennelse': ('hornhinnebetennelse',),
'hornhinnebetennelsen': ('hornhinnebetennelse',),
'hornhinnebetennelsene': ('hornhinnebetennelse',),
'hornhinnebetennelser': ('hornhinnebetennelse',),
'hornist': ('hornist',),
'hornisten': ('hornist',),
'hornistene': ('hornist',),
'hornister': ('hornist',),
'hornkam': ('hornkam',),
'hornkammen': ('hornkam',),
'hornkammene': ('hornkam',),
'hornkammer': ('hornkam',),
'hornlim': ('hornlim',),
'hornlima': ('hornlim',),
'hornlimene': ('hornlim',),
'hornlimet': ('hornlim',),
'hornmina': ('hornmine',),
'hornmine': ('hornmine',),
'hornminen': ('hornmine',),
'hornminene': ('hornmine',),
'hornminer': ('hornmine',),
'hornmusikk': ('hornmusikk',),
'hornmusikken': ('hornmusikk',),
'hornmusikkene': ('hornmusikk',),
'hornmusikker': ('hornmusikk',),
'hornorkester': ('hornorkester',),
'hornorkesteret': ('hornorkester',),
'hornorkestra': ('hornorkester',),
'hornorkestre': ('hornorkester',),
'hornorkestrene': ('hornorkester',),
'hornorkestret': ('hornorkester',),
'hornrot': ('hornrot',),
'hornrota': ('hornrot',),
'hornroten': ('hornrot',),
'hornrøttene': ('hornrot',),
'hornrøtter': ('hornrot',),
'hornsignal': ('hornsignal',),
'hornsignala': ('hornsignal',),
'hornsignalene': ('hornsignal',),
'hornsignaler': ('hornsignal',),
'hornsignalet': ('hornsignal',),
'hornskei': ('hornskei',),
'hornskeia': ('hornskei',),
'hornskeien': ('hornskei',),
'hornskeiene': ('hornskei',),
'hornskeier': ('hornskei',),
'hornskje': ('hornskje',),
'hornskjea': ('hornskje',),
'hornskjeen': ('hornskje',),
'hornskjeene': ('hornskje',),
'hornskjeer': ('hornskje',),
'hornstoff': ('hornstoff',),
'hornstoffa': ('hornstoff',),
'hornstoffene': ('hornstoff',),
'hornstoffer': ('hornstoff',),
'hornstoffet': ('hornstoff',),
'hornugla': ('hornugle',),
'hornugle': ('hornugle',),
'hornuglen': ('hornugle',),
'hornuglene': ('hornugle',),
'hornugler': ('hornugle',),
'horoskop': ('horoskop',),
'horoskopa': ('horoskop',),
'horoskopene': ('horoskop',),
'horoskoper': ('horoskop',),
'horoskopet': ('horoskop',),
'hors': ('hors',),
'horsa': ('hors',),
'horsene': ('hors',),
'horset': ('hors',),
'hors d\'oeuvre': ('hors d\'oeuvre',),
'horsa': ('horse',),
'horse': ('horse',),
'horsen': ('horse',),
'horsene': ('horse',),
'horser': ('horse',),
'horsegauk': ('horsegauk',),
'horsegauken': ('horsegauk',),
'horsegaukene': ('horsegauk',),
'horsegauker': ('horsegauk',),
'horst': ('horst',),
'horsten': ('horst',),
'horstene': ('horst',),
'horster': ('horst',),
'hortensia': ('hortensia',),
'hortensiaen': ('hortensia',),
'hortensiaene': ('hortensia',),
'hortensiaer': ('hortensia',),
'horunge': ('horunge',),
'horungen': ('horunge',),
'horungene': ('horunge',),
'horunger': ('horunge',),
'hosa': ('hose',),
'hose': ('hose',),
'hosen': ('hose',),
'hosene': ('hose',),
'hoser': ('hose',),
'hosebandsorden': ('hosebandsorden',),
'hosebandsordenen': ('hosebandsorden',),
'hosebandsordenene': ('hosebandsorden',),
'hosebandsordener': ('hosebandsorden',),
'hosebåndsorden': ('hosebåndsorden',),
'hosebåndsordenen': ('hosebåndsorden',),
'hosebåndsordenene': ('hosebåndsorden',),
'hosebåndsordener': ('hosebåndsorden',),
'hoseleist': ('hoseleist',),
'hoseleisten': ('hoseleist',),
'hoseleistene': ('hoseleist',),
'hoseleister': ('hoseleist',),
'hoselest': ('hoselest',),
'hoselesten': ('hoselest',),
'hoselestene': ('hoselest',),
'hoselester': ('hoselest',),
'hosianna': ('hosianna',),
'hosiannaene': ('hosianna',),
'hosiannaer': ('hosianna',),
'hosiannaet': ('hosianna',),
'hospital': ('hospital',),
'hospitala': ('hospital',),
'hospitalene': ('hospital',),
'hospitaler': ('hospital',),
'hospitalet': ('hospital',),
'hospitalsskip': ('hospitalsskip',),
'hospitalsskipa': ('hospitalsskip',),
'hospitalsskipene': ('hospitalsskip',),
'hospitalsskipet': ('hospitalsskip',),
'hospitant': ('hospitant',),
'hospitanten': ('hospitant',),
'hospitantene': ('hospitant',),
'hospitanter': ('hospitant',),
'hospits': ('hospits',),
'hospitsa': ('hospits',),
'hospitsene': ('hospits',),
'hospitser': ('hospits',),
'hospitset': ('hospits',),
'host': ('host',),
'hosta': ('host',),
'hosten': ('host',),
'hostene': ('host',),
'hostet': ('host',),
'hoste': ('hoste',),
'hosten': ('hoste',),
'hostene': ('hoste',),
'hoster': ('hoste',),
'hostedråpe': ('hostedråpe',),
'hostedråpen': ('hostedråpe',),
'hostedråpene': ('hostedråpe',),
'hostedråper': ('hostedråpe',),
'hostekula': ('hostekule',),
'hostekule': ('hostekule',),
'hostekulen': ('hostekule',),
'hostekulene': ('hostekule',),
'hostekuler': ('hostekule',),
'hostemikstur': ('hostemikstur',),
'hostemiksturen': ('hostemikstur',),
'hostemiksturene': ('hostemikstur',),
'hostemiksturer': ('hostemikstur',),
'hosteri': ('hosteri',),
'hosteria': ('hosteri',),
'hosterien': ('hosteri',),
'hosteriene': ('hosteri',),
'hosterier': ('hosteri',),
'hostesaft': ('hostesaft',),
'hostesafta': ('hostesaft',),
'hostesaften': ('hostesaft',),
'hostesaftene': ('hostesaft',),
'hostesafter': ('hostesaft',),
'hostess': ('hostess',),
'hostessen': ('hostess',),
'hostessene': ('hostess',),
'hostesser': ('hostess',),
'hostie': ('hostie',),
'hostien': ('hostie',),
'hostiene': ('hostie',),
'hostier': ('hostie',),
'hostilitet': ('hostilitet',),
'hostiliteten': ('hostilitet',),
'hostilitetene': ('hostilitet',),
'hostiliteter': ('hostilitet',),
'hot': ('hot',),
'hoten': ('hot',),
'hotene': ('hot',),
'hoter': ('hot',),
'hot-dog': ('hot-dog',),
'hot-dogen': ('hot-dog',),
'hot-dogene': ('hot-dog',),
'hot-doger': ('hot-dog',),
'hotell': ('hotell',),
'hotella': ('hotell',),
'hotellene': ('hotell',),
'hoteller': ('hotell',),
'hotellet': ('hotell',),
'hotell-lov': ('hotell-lov',),
'hotell-loven': ('hotell-lov',),
'hotell-lovene': ('hotell-lov',),
'hotell-lover': ('hotell-lov',),
'hotellbrev': ('hotellbrev',),
'hotellbreva': ('hotellbrev',),
'hotellbrevene': ('hotellbrev',),
'hotellbrever': ('hotellbrev',),
'hotellbrevet': ('hotellbrev',),
'hotellfag': ('hotellfag',),
'hotellfaga': ('hotellfag',),
'hotellfagene': ('hotellfag',),
'hotellfaget': ('hotellfag',),
'hotellfagskole': ('hotellfagskole',),
'hotellfagskolen': ('hotellfagskole',),
'hotellfagskolene': ('hotellfagskole',),
'hotellfagskoler': ('hotellfagskole',),
'hotellnæring': ('hotellnæring',),
'hotellnæringa': ('hotellnæring',),
'hotellnæringen': ('hotellnæring',),
'hotellnæringene': ('hotellnæring',),
'hotellnæringer': ('hotellnæring',),
'hotellov': ('hotellov',),
'hotelloven': ('hotellov',),
'hotellovene': ('hotellov',),
'hotellover': ('hotellov',),
'hotellskip': ('hotellskip',),
'hotellskipa': ('hotellskip',),
'hotellskipene': ('hotellskip',),
'hotellskipet': ('hotellskip',),
'hottentott': ('hottentott',),
'hottentotten': ('hottentott',),
'hottentottene': ('hottentott',),
'hottentotter': ('hottentott',),
'hov': ('hov',),
'hoven': ('hov',),
'hovene': ('hov',),
'hover': ('hov',),
'høvene': ('hov',),
'høver': ('hov',),
'hov': ('hov',),
'hova': ('hov',),
'hovene': ('hov',),
'hovet': ('hov',),
'hovde': ('hovde',),
'hovden': ('hovde',),
'hovdene': ('hovde',),
'hovder': ('hovde',),
'hovdyr': ('hovdyr',),
'hovdyra': ('hovdyr',),
'hovdyrene': ('hovdyr',),
'hovdyret': ('hovdyr',),
'hovedavtale': ('hovedavtale',),
'hovedavtalen': ('hovedavtale',),
'hovedavtalene': ('hovedavtale',),
'hovedavtaler': ('hovedavtale',),
'hovedbryter': ('hovedbryter',),
'hovedbrytere': ('hovedbryter',),
'hovedbryteren': ('hovedbryter',),
'hovedbryterer': ('hovedbryter',),
'hovedbryterne': ('hovedbryter',),
'hovedbygning': ('hovedbygning',),
'hovedbygninga': ('hovedbygning',),
'hovedbygningen': ('hovedbygning',),
'hovedbygningene': ('hovedbygning',),
'hovedbygninger': ('hovedbygning',),
'hovedbøla': ('hovedbøle',),
'hovedbøle': ('hovedbøle',),
'hovedbølene': ('hovedbøle',),
'hovedbøler': ('hovedbøle',),
'hovedbølet': ('hovedbøle',),
'hovedfag': ('hovedfag',),
'hovedfaga': ('hovedfag',),
'hovedfagene': ('hovedfag',),
'hovedfaget': ('hovedfag',),
'hovedfagseksamen': ('hovedfagseksamen',),
'hovedfagseksamenen': ('hovedfagseksamen',),
'hovedfagseksamenene': ('hovedfagseksamen',),
'hovedfagseksamener': ('hovedfagseksamen',),
'hovedfagskandidat': ('hovedfagskandidat',),
'hovedfagskandidaten': ('hovedfagskandidat',),
'hovedfagskandidatene': ('hovedfagskandidat',),
'hovedfagskandidater': ('hovedfagskandidat',),
'hovedfagsoppgava': ('hovedfagsoppgave',),
'hovedfagsoppgave': ('hovedfagsoppgave',),
'hovedfagsoppgaven': ('hovedfagsoppgave',),
'hovedfagsoppgavene': ('hovedfagsoppgave',),
'hovedfagsoppgaver': ('hovedfagsoppgave',),
'hovedflyplass': ('hovedflyplass',),
'hovedflyplassen': ('hovedflyplass',),
'hovedflyplassene': ('hovedflyplass',),
'hovedflyplasser': ('hovedflyplass',),
'hovedforhandling': ('hovedforhandling',),
'hovedforhandlinga': ('hovedforhandling',),
'hovedforhandlingen': ('hovedforhandling',),
'hovedforhandlingene': ('hovedforhandling',),
'hovedforhandlinger': ('hovedforhandling',),
'hovedform': ('hovedform',),
'hovedforma': ('hovedform',),
'hovedformen': ('hovedform',),
'hovedformene': ('hovedform',),
'hovedformer': ('hovedform',),
'hovedforsamling': ('hovedforsamling',),
'hovedforsamlinga': ('hovedforsamling',),
'hovedforsamlingen': ('hovedforsamling',),
'hovedforsamlingene': ('hovedforsamling',),
'hovedforsamlinger': ('hovedforsamling',),
'hovedgard': ('hovedgard',),
'hovedgarden': ('hovedgard',),
'hovedgardene': ('hovedgard',),
'hovedgarder': ('hovedgard',),
'hovedgata': ('hovedgate',),
'hovedgate': ('hovedgate',),
'hovedgaten': ('hovedgate',),
'hovedgatene': ('hovedgate',),
'hovedgater': ('hovedgate',),
'hovedgård': ('hovedgård',),
'hovedgården': ('hovedgård',),
'hovedgårdene': ('hovedgård',),
'hovedgårder': ('hovedgård',),
'hovedinngang': ('hovedinngang',),
'hovedinngangen': ('hovedinngang',),
'hovedinngangene': ('hovedinngang',),
'hovedinnganger': ('hovedinngang',),
'hovedkarakter': ('hovedkarakter',),
'hovedkarakteren': ('hovedkarakter',),
'hovedkarakterene': ('hovedkarakter',),
'hovedkarakterer': ('hovedkarakter',),
'hovedkasserer': ('hovedkasserer',),
'hovedkasserere': ('hovedkasserer',),
'hovedkassereren': ('hovedkasserer',),
'hovedkassererer': ('hovedkasserer',),
'hovedkassererne': ('hovedkasserer',),
'hovedkirka': ('hovedkirke',),
'hovedkirke': ('hovedkirke',),
'hovedkirken': ('hovedkirke',),
'hovedkirkene': ('hovedkirke',),
'hovedkirker': ('hovedkirke',),
'hovedkjerka': ('hovedkjerke',),
'hovedkjerke': ('hovedkjerke',),
'hovedkjerken': ('hovedkjerke',),
'hovedkjerkene': ('hovedkjerke',),
'hovedkjerker': ('hovedkjerke',),
'hovedkontor': ('hovedkontor',),
'hovedkontora': ('hovedkontor',),
'hovedkontorene': ('hovedkontor',),
'hovedkontorer': ('hovedkontor',),
'hovedkontoret': ('hovedkontor',),
'hovedkvarter': ('hovedkvarter',),
'hovedkvartera': ('hovedkvarter',),
'hovedkvarterene': ('hovedkvarter',),
'hovedkvarterer': ('hovedkvarter',),
'hovedkvarteret': ('hovedkvarter',),
'hovedlandsrenn': ('hovedlandsrenn',),
'hovedlandsrenna': ('hovedlandsrenn',),
'hovedlandsrennene': ('hovedlandsrenn',),
'hovedlandsrennet': ('hovedlandsrenn',),
'hovedlinja': ('hovedlinje',),
'hovedlinje': ('hovedlinje',),
'hovedlinjen': ('hovedlinje',),
'hovedlinjene': ('hovedlinje',),
'hovedlinjer': ('hovedlinje',),
'hovedmann': ('hovedmann',),
'hovedmannen': ('hovedmann',),
'hovedmenn': ('hovedmann',),
'hovedmennene': ('hovedmann',),
'hovedmål': ('hovedmål',),
'hovedmåla': ('hovedmål',),
'hovedmålene': ('hovedmål',),
'hovedmålet': ('hovedmål',),
'hovedmål': ('hovedmål',),
'hovedmåla': ('hovedmål',),
'hovedmålene': ('hovedmål',),
'hovedmålet': ('hovedmål',),
'hovednæring': ('hovednæring',),
'hovednæringa': ('hovednæring',),
'hovednæringen': ('hovednæring',),
'hovednæringene': ('hovednæring',),
'hovednæringer': ('hovednæring',),
'hovednøkkel': ('hovednøkkel',),
'hovednøkkelen': ('hovednøkkel',),
'hovednøklene': ('hovednøkkel',),
'hovednøkler': ('hovednøkkel',),
'hovedoppgava': ('hovedoppgave',),
'hovedoppgave': ('hovedoppgave',),
'hovedoppgaven': ('hovedoppgave',),
'hovedoppgavene': ('hovedoppgave',),
'hovedoppgaver': ('hovedoppgave',),
'hovedperson': ('hovedperson',),
'hovedpersonen': ('hovedperson',),
'hovedpersonene': ('hovedperson',),
'hovedpersoner': ('hovedperson',),
'hovedpunkt': ('hovedpunkt',),
'hovedpunkta': ('hovedpunkt',),
'hovedpunktene': ('hovedpunkt',),
'hovedpunkter': ('hovedpunkt',),
'hovedpunktet': ('hovedpunkt',),
'hovedredaktør': ('hovedredaktør',),
'hovedredaktøren': ('hovedredaktør',),
'hovedredaktørene': ('hovedredaktør',),
'hovedredaktører': ('hovedredaktør',),
'hovedregel': ('hovedregel',),
'hovedregelen': ('hovedregel',),
'hovedreglene': ('hovedregel',),
'hovedregler': ('hovedregel',),
'hovedrett': ('hovedrett',),
'hovedretten': ('hovedrett',),
'hovedrettene': ('hovedrett',),
'hovedretter': ('hovedrett',),
'hovedrolla': ('hovedrolle',),
'hovedrolle': ('hovedrolle',),
'hovedrollen': ('hovedrolle',),
'hovedrollene': ('hovedrolle',),
'hovedroller': ('hovedrolle',),
'hovedsak': ('hovedsak',),
'hovedsaka': ('hovedsak',),
'hovedsaken': ('hovedsak',),
'hovedsakene': ('hovedsak',),
'hovedsaker': ('hovedsak',),
'hovedscene': ('hovedscene',),
'hovedscenen': ('hovedscene',),
'hovedscenene': ('hovedscene',),
'hovedscener': ('hovedscene',),
'hovedserie': ('hovedserie',),
'hovedserien': ('hovedserie',),
'hovedseriene': ('hovedserie',),
'hovedserier': ('hovedserie',),
'hovedseta': ('hovedsete',),
'hovedsete': ('hovedsete',),
'hovedsetene': ('hovedsete',),
'hovedseter': ('hovedsete',),
'hovedsetet': ('hovedsete',),
'hovedsetning': ('hovedsetning',),
'hovedsetninga': ('hovedsetning',),
'hovedsetningen': ('hovedsetning',),
'hovedsetningene': ('hovedsetning',),
'hovedsetninger': ('hovedsetning',),
'hovedsikring': ('hovedsikring',),
'hovedsikringa': ('hovedsikring',),
'hovedsikringen': ('hovedsikring',),
'hovedsikringene': ('hovedsikring',),
'hovedsikringer': ('hovedsikring',),
'hovedsogn': ('hovedsogn',),
'hovedsogna': ('hovedsogn',),
'hovedsognene': ('hovedsogn',),
'hovedsognet': ('hovedsogn',),
'hovedsokn': ('hovedsokn',),
'hovedsokna': ('hovedsokn',),
'hovedsoknen': ('hovedsokn',),
'hovedsoknene': ('hovedsokn',),
'hovedsokner': ('hovedsokn',),
'hovedsoknet': ('hovedsokn',),
'hovedstil': ('hovedstil',),
'hovedstilen': ('hovedstil',),
'hovedstilene': ('hovedstil',),
'hovedstiler': ('hovedstil',),
'hovedstilling': ('hovedstilling',),
'hovedstillinga': ('hovedstilling',),
'hovedstillingen': ('hovedstilling',),
'hovedstillingene': ('hovedstilling',),
'hovedstillinger': ('hovedstilling',),
'hovedstol': ('hovedstol',),
'hovedstolen': ('hovedstol',),
'hovedstolene': ('hovedstol',),
'hovedstoler': ('hovedstol',),
'hovedstrømning': ('hovedstrømning',),
'hovedstrømninga': ('hovedstrømning',),
'hovedstrømningen': ('hovedstrømning',),
'hovedstrømningene': ('hovedstrømning',),
'hovedstrømninger': ('hovedstrømning',),
'hovedtaler': ('hovedtaler',),
'hovedtalere': ('hovedtaler',),
'hovedtaleren': ('hovedtaler',),
'hovedtalerer': ('hovedtaler',),
'hovedtalerne': ('hovedtaler',),
'hovedtrekk': ('hovedtrekk',),
'hovedtrekka': ('hovedtrekk',),
'hovedtrekkene': ('hovedtrekk',),
'hovedtrekket': ('hovedtrekk',),
'hovedtyngde': ('hovedtyngde',),
'hovedtyngden': ('hovedtyngde',),
'hovedtyngdene': ('hovedtyngde',),
'hovedtyngder': ('hovedtyngde',),
'hovedveg': ('hovedveg',),
'hovedvegen': ('hovedveg',),
'hovedvegene': ('hovedveg',),
'hovedveger': ('hovedveg',),
'hovedvei': ('hovedvei',),
'hovedveien': ('hovedvei',),
'hovedveiene': ('hovedvei',),
'hovedveier': ('hovedvei',),
'hovedvekt': ('hovedvekt',),
'hovedvekta': ('hovedvekt',),
'hovedvekten': ('hovedvekt',),
'hovedvektene': ('hovedvekt',),
'hovedvekter': ('hovedvekt',),
'hovedverb': ('hovedverb',),
'hovedverba': ('hovedverb',),
'hovedverbene': ('hovedverb',),
'hovedverber': ('hovedverb',),
'hovedverbet': ('hovedverb',),
'hovedverba': ('hovedverbum',),
'hovedverbene': ('hovedverbum',),
'hovedverber': ('hovedverbum',),
'hovedverbet': ('hovedverbum',),
'hovedverbum': ('hovedverbum',),
'hovedverbumet': ('hovedverbum',),
'hovedverk': ('hovedverk',),
'hovedverka': ('hovedverk',),
'hovedverkene': ('hovedverk',),
'hovedverker': ('hovedverk',),
'hovedverket': ('hovedverk',),
'hovedåra': ('hovedåre',),
'hovedåre': ('hovedåre',),
'hovedåren': ('hovedåre',),
'hovedårene': ('hovedåre',),
'hovedårer': ('hovedåre',),
'hovel': ('hovel',),
'hovelen': ('hovel',),
'hovlene': ('hovel',),
'hovler': ('hovel',),
'hovenhet': ('hovenhet',),
'hovenheta': ('hovenhet',),
'hovenheten': ('hovenhet',),
'hovenhetene': ('hovenhet',),
'hovenheter': ('hovenhet',),
'hovercraft': ('hovercraft',),
'hovercraften': ('hovercraft',),
'hovercraftene': ('hovercraft',),
'hovercrafter': ('hovercraft',),
'hoveri': ('hoveri',),
'hoveria': ('hoveri',),
'hoveriene': ('hoveri',),
'hoverier': ('hoveri',),
'hoveriet': ('hoveri',),
'hovmester': ('hovmester',),
'hovmestere': ('hovmester',),
'hovmesteren': ('hovmester',),
'hovmesterer': ('hovmester',),
'hovmesterne': ('hovmester',),
'hovmestre': ('hovmester',),
'hovmestrene': ('hovmester',),
'hovmestrer': ('hovmester',),
'hovmod': ('hovmod',),
'hovmoda': ('hovmod',),
'hovmodene': ('hovmod',),
'hovmodet': ('hovmod',),
'hovold': ('hovold',),
'hovolda': ('hovold',),
'hovolden': ('hovold',),
'hovoldene': ('hovold',),
'hovolder': ('hovold',),
'hovskjegg': ('hovskjegg',),
'hovskjegga': ('hovskjegg',),
'hovskjeggene': ('hovskjegg',),
'hovskjegget': ('hovskjegg',),
'hovslag': ('hovslag',),
'hovslaga': ('hovslag',),
'hovslagene': ('hovslag',),
'hovslaget': ('hovslag',),
'hovslager': ('hovslager',),
'hovslagere': ('hovslager',),
'hovslageren': ('hovslager',),
'hovslagerer': ('hovslager',),
'hovslagerne': ('hovslager',),
'hovtang': ('hovtang',),
'hovtanga': ('hovtang',),
'hovtangen': ('hovtang',),
'hovtengene': ('hovtang',),
'hovtenger': ('hovtang',),
'hu': ('hu',),
'huen': ('hu',),
'huene': ('hu',),
'huer': ('hu',),
'hubro': ('hubro',),
'hubroen': ('hubro',),
'hubroene': ('hubro',),
'hubroer': ('hubro',),
'hud': ('hud',),
'huda': ('hud',),
'huden': ('hud',),
'hudene': ('hud',),
'huder': ('hud',),
'hudavdeling': ('hudavdeling',),
'hudavdelinga': ('hudavdeling',),
'hudavdelingen': ('hudavdeling',),
'hudavdelingene': ('hudavdeling',),
'hudavdelinger': ('hudavdeling',),
'hudfarge': ('hudfarge',),
'hudfargen': ('hudfarge',),
'hudfargene': ('hudfarge',),
'hudfarger': ('hudfarge',),
'hudkreft': ('hudkreft',),
'hudkreften': ('hudkreft',),
'hudkreftene': ('hudkreft',),
'hudkrefter': ('hudkreft',),
'hudkrem': ('hudkrem',),
'hudkremen': ('hudkrem',),
'hudkremene': ('hudkrem',),
'hudkremer': ('hudkrem',),
'hudlege': ('hudlege',),
'hudlegen': ('hudlege',),
'hudlegene': ('hudlege',),
'hudleger': ('hudlege',),
'hudorm': ('hudorm',),
'hudormen': ('hudorm',),
'hudormene': ('hudorm',),
'hudormer': ('hudorm',),
'hudpleia': ('hudpleie',),
'hudpleie': ('hudpleie',),
'hudpleien': ('hudpleie',),
'hudpleiene': ('hudpleie',),
'hudpleier': ('hudpleie',),
'hudsjukdom': ('hudsjukdom',),
'hudsjukdommen': ('hudsjukdom',),
'hudsjukdommene': ('hudsjukdom',),
'hudsjukdommer': ('hudsjukdom',),
'hudsykdom': ('hudsykdom',),
'hudsykdommen': ('hudsykdom',),
'hudsykdommene': ('hudsykdom',),
'hudsykdommer': ('hudsykdom',),
'hua': ('hue',),
'hue': ('hue',),
'huene': ('hue',),
'huer': ('hue',),
'huet': ('hue',),
'hua': ('hue',),
'hue': ('hue',),
'huen': ('hue',),
'huene': ('hue',),
'huer': ('hue',),
'hua': ('hue',),
'hue': ('hue',),
'huen': ('hue',),
'huene': ('hue',),
'huer': ('hue',),
'huff': ('huff',),
'huffa': ('huff',),
'huffene': ('huff',),
'huffet': ('huff',),
'hufs': ('hufs',),
'hufsa': ('hufs',),
'hufsene': ('hufs',),
'hufset': ('hufs',),
'hug': ('hug',),
'hugen': ('hug',),
'hugene': ('hug',),
'huger': ('hug',),
'hugav': ('hugav',),
'hugaven': ('hugav',),
'hugavene': ('hugav',),
'hugaver': ('hugav',),
'hugenott': ('hugenott',),
'hugenotten': ('hugenott',),
'hugenottene': ('hugenott',),
'hugenotter': ('hugenott',),
'hugg': ('hugg',),
'hugga': ('hugg',),
'huggene': ('hugg',),
'hugget': ('hugg',),
'hugger': ('hugger',),
'huggere': ('hugger',),
'huggeren': ('hugger',),
'huggerer': ('hugger',),
'huggerne': ('hugger',),
'huggeri': ('huggeri',),
'huggeria': ('huggeri',),
'huggeriene': ('huggeri',),
'huggerier': ('huggeri',),
'huggeriet': ('huggeri',),
'huggert': ('huggert',),
'huggerten': ('huggert',),
'huggertene': ('huggert',),
'huggerter': ('huggert',),
'huggestabbe': ('huggestabbe',),
'huggestabben': ('huggestabbe',),
'huggestabbene': ('huggestabbe',),
'huggestabber': ('huggestabbe',),
'huggjern': ('huggjern',),
'huggjerna': ('huggjern',),
'huggjernene': ('huggjern',),
'huggjernet': ('huggjern',),
'huggorm': ('huggorm',),
'huggormen': ('huggorm',),
'huggormene': ('huggorm',),
'huggormer': ('huggorm',),
'huggsår': ('huggsår',),
'huggsåra': ('huggsår',),
'huggsårene': ('huggsår',),
'huggsåret': ('huggsår',),
'huggtann': ('huggtann',),
'huggtanna': ('huggtann',),
'huggtannen': ('huggtann',),
'huggtennene': ('huggtann',),
'huggtenner': ('huggtann',),
'huggvåpen': ('huggvåpen',),
'huggvåpenet': ('huggvåpen',),
'huggvåpna': ('huggvåpen',),
'huggvåpnene': ('huggvåpen',),
'hugnad': ('hugnad',),
'hugnaden': ('hugnad',),
'hugnadene': ('hugnad',),
'hugnader': ('hugnad',),
'hugs': ('hugs',),
'hugsa': ('hugs',),
'hugsen': ('hugs',),
'hugsene': ('hugs',),
'hugser': ('hugs',),
'hugset': ('hugs',),
'hugselapp': ('hugselapp',),
'hugselappen': ('hugselapp',),
'hugselappene': ('hugselapp',),
'hugselapper': ('hugselapp',),
'hugseregel': ('hugseregel',),
'hugseregelen': ('hugseregel',),
'hugsereglene': ('hugseregel',),
'hugseregler': ('hugseregel',),
'hugskott': ('hugskott',),
'hugskotta': ('hugskott',),
'hugskottene': ('hugskott',),
'hugskottet': ('hugskott',),
'hugsott': ('hugsott',),
'hugsotta': ('hugsott',),
'hugsotten': ('hugsott',),
'hugsottene': ('hugsott',),
'hugsotter': ('hugsott',),
'hugst': ('hugst',),
'hugsten': ('hugst',),
'hugstene': ('hugst',),
'hugster': ('hugst',),
'hugstklassa': ('hugstklasse',),
'hugstklasse': ('hugstklasse',),
'hugstklassen': ('hugstklasse',),
'hugstklassene': ('hugstklasse',),
'hugstklasser': ('hugstklasse',),
'hugstredskap': ('hugstredskap',),
'hugstredskapa': ('hugstredskap',),
'hugstredskapen': ('hugstredskap',),
'hugstredskapene': ('hugstredskap',),
'hugstredskaper': ('hugstredskap',),
'hugstredskapet': ('hugstredskap',),
'hugsvaling': ('hugsvaling',),
'hugsvalinga': ('hugsvaling',),
'hugsvalingen': ('hugsvaling',),
'hugsvalingene': ('hugsvaling',),
'hugsvalinger': ('hugsvaling',),
'hui': ('hui',),
'hui': ('hui',),
'huia': ('hui',),
'huiene': ('hui',),
'huiet': ('hui',),
'huk': ('huk',),
'huken': ('huk',),
'hukene': ('huk',),
'huker': ('huk',),
'huk': ('huk',),
'huken': ('huk',),
'hukene': ('huk',),
'huker': ('huk',),
'huk': ('huk',),
'hukk': ('hukk',),
'hukka': ('hukk',),
'hukkene': ('hukk',),
'hukket': ('hukk',),
'hukommelse': ('hukommelse',),
'hukommelsen': ('hukommelse',),
'hukommelsene': ('hukommelse',),
'hukommelser': ('hukommelse',),
'hukommelsestap': ('hukommelsestap',),
'hukommelsestapa': ('hukommelsestap',),
'hukommelsestapene': ('hukommelsestap',),
'hukommelsestapet': ('hukommelsestap',),
'hula': ('hula',),
'hulaen': ('hula',),
'hulaene': ('hula',),
'hulaer': ('hula',),
'hula-hula': ('hula-hula',),
'hula-hulaen': ('hula-hula',),
'hula-hulaene': ('hula-hula',),
'hula-hulaer': ('hula-hula',),
'hula-hula-pika': ('hula-hula-pike',),
'hula-hula-pike': ('hula-hula-pike',),
'hula-hula-piken': ('hula-hula-pike',),
'hula-hula-pikene': ('hula-hula-pike',),
'hula-hula-piker': ('hula-hula-pike',),
'hulag': ('hulag',),
'hulaga': ('hulag',),
'hulagene': ('hulag',),
'hulaget': ('hulag',),
'hulapika': ('hulapike',),
'hulapike': ('hulapike',),
'hulapiken': ('hulapike',),
'hulapikene': ('hulapike',),
'hulapiker': ('hulapike',),
'hulder': ('hulder',),
'huldere': ('hulder',),
'hulderen': ('hulder',),
'hulderne': ('hulder',),
'huldra': ('hulder',),
'huldre': ('hulder',),
'huldrene': ('hulder',),
'huldrer': ('hulder',),
'huldreblom': ('huldreblom',),
'huldreblommen': ('huldreblom',),
'huldreblommene': ('huldreblom',),
'huldreblommer': ('huldreblom',),
'huldrebuskap': ('huldrebuskap',),
'huldrebuskapen': ('huldrebuskap',),
'huldrebuskapene': ('huldrebuskap',),
'huldrebuskaper': ('huldrebuskap',),
'huldreeventyr': ('huldreeventyr',),
'huldreeventyra': ('huldreeventyr',),
'huldreeventyrene': ('huldreeventyr',),
'huldreeventyret': ('huldreeventyr',),
'huldrefolk': ('huldrefolk',),
'huldrefolka': ('huldrefolk',),
'huldrefolkene': ('huldrefolk',),
'huldrefolket': ('huldrefolk',),
'huldregras': ('huldregras',),
'huldregrasa': ('huldregras',),
'huldregrasene': ('huldregras',),
'huldregraset': ('huldregras',),
'huldregress': ('huldregress',),
'huldregressa': ('huldregress',),
'huldregressene': ('huldregress',),
'huldregresset': ('huldregress',),
'huldrehatt': ('huldrehatt',),
'huldrehatten': ('huldrehatt',),
'huldrehattene': ('huldrehatt',),
'huldrehatter': ('huldrehatt',),
'huldrekall': ('huldrekall',),
'huldrekallen': ('huldrekall',),
'huldrekallene': ('huldrekall',),
'huldrekaller': ('huldrekall',),
'huldrelokk': ('huldrelokk',),
'huldrelokken': ('huldrelokk',),
'huldrelokkene': ('huldrelokk',),
'huldrelokker': ('huldrelokk',),
'huldresagn': ('huldresagn',),
'huldresagna': ('huldresagn',),
'huldresagnene': ('huldresagn',),
'huldresagnet': ('huldresagn',),
'huldreslått': ('huldreslått',),
'huldreslåtten': ('huldreslått',),
'huldreslåttene': ('huldreslått',),
'huldreslåtter': ('huldreslått',),
'hula': ('hule',),
'hule': ('hule',),
'hulen': ('hule',),
'hulene': ('hule',),
'huler': ('hule',),
'huleboer': ('huleboer',),
'huleboere': ('huleboer',),
'huleboeren': ('huleboer',),
'huleboerer': ('huleboer',),
'huleboerne': ('huleboer',),
'hulebuer': ('hulebuer',),
'hulebuere': ('hulebuer',),
'hulebueren': ('hulebuer',),
'hulebuerer': ('hulebuer',),
'hulebuerne': ('hulebuer',),
'hulemaleri': ('hulemaleri',),
'hulemaleria': ('hulemaleri',),
'hulemaleriene': ('hulemaleri',),
'hulemalerier': ('hulemaleri',),
'hulemaleriet': ('hulemaleri',),
'hulhet': ('hulhet',),
'hulheta': ('hulhet',),
'hulheten': ('hulhet',),
'hulhetene': ('hulhet',),
'hulheter': ('hulhet',),
'huljern': ('huljern',),
'huljerna': ('huljern',),
'huljernene': ('huljern',),
'huljernet': ('huljern',),
'hulk': ('hulk',),
'hulka': ('hulk',),
'hulken': ('hulk',),
'hulkene': ('hulk',),
'hulket': ('hulk',),
'hulkil': ('hulkil',),
'hulkilen': ('hulkil',),
'hulkilene': ('hulkil',),
'hulkiler': ('hulkil',),
'hullband': ('hullband',),
'hullbanda': ('hullband',),
'hullbandene': ('hullband',),
'hullbandet': ('hullband',),
'hullbånd': ('hullbånd',),
'hullbånda': ('hullbånd',),
'hullbåndene': ('hullbånd',),
'hullbåndet': ('hullbånd',),
'hullkort': ('hullkort',),
'hullkorta': ('hullkort',),
'hullkortene': ('hullkort',),
'hullkortet': ('hullkort',),
'hullkortmaskin': ('hullkortmaskin',),
'hullkortmaskina': ('hullkortmaskin',),
'hullkortmaskinen': ('hullkortmaskin',),
'hullkortmaskinene': ('hullkortmaskin',),
'hullkortmaskiner': ('hullkortmaskin',),
'hullkortmetode': ('hullkortmetode',),
'hullkortmetoden': ('hullkortmetode',),
'hullkortmetodene': ('hullkortmetode',),
'hullkortmetoder': ('hullkortmetode',),
'hullkortoperatør': ('hullkortoperatør',),
'hullkortoperatøren': ('hullkortoperatør',),
'hullkortoperatørene': ('hullkortoperatør',),
'hullkortoperatører': ('hullkortoperatør',),
'hullsleiv': ('hullsleiv',),
'hullsleiva': ('hullsleiv',),
'hullsleiven': ('hullsleiv',),
'hullsleivene': ('hullsleiv',),
'hullsleiver': ('hullsleiv',),
'hullsøm': ('hullsøm',),
'hullsømmen': ('hullsøm',),
'hullsømmene': ('hullsøm',),
'hullsømmer': ('hullsøm',),
'hulmur': ('hulmur',),
'hulmuren': ('hulmur',),
'hulmurene': ('hulmur',),
'hulmurer': ('hulmur',),
'hulmål': ('hulmål',),
'hulmåla': ('hulmål',),
'hulmålene': ('hulmål',),
'hulmålet': ('hulmål',),
'hulning': ('hulning',),
'hulninga': ('hulning',),
'hulningen': ('hulning',),
'hulningene': ('hulning',),
'hulninger': ('hulning',),
'hulrom': ('hulrom',),
'hulromma': ('hulrom',),
'hulrommene': ('hulrom',),
'hulrommet': ('hulrom',),
'hulspeil': ('hulspeil',),
'hulspeila': ('hulspeil',),
'hulspeilene': ('hulspeil',),
'hulspeilet': ('hulspeil',),
'hultann': ('hultann',),
'hultanna': ('hultann',),
'hultannen': ('hultann',),
'hultennene': ('hultann',),
'hultenner': ('hultann',),
'hulveg': ('hulveg',),
'hulvegen': ('hulveg',),
'hulvegene': ('hulveg',),
'hulveger': ('hulveg',),
'hulvei': ('hulvei',),
'hulveien': ('hulvei',),
'hulveiene': ('hulvei',),
'hulveier': ('hulvei',),
'hulvene': ('hulvene',),
'hulvenen': ('hulvene',),
'hulvenene': ('hulvene',),
'hulvener': ('hulvene',),
'humanetiker': ('humanetiker',),
'humanetikere': ('humanetiker',),
'humanetikeren': ('humanetiker',),
'humanetikerer': ('humanetiker',),
'humanetikerne': ('humanetiker',),
'humanetikk': ('humanetikk',),
'humanetikken': ('humanetikk',),
'humanetikkene': ('humanetikk',),
'humanetikker': ('humanetikk',),
'humaniora': ('humaniora',),
'humanisme': ('humanisme',),
'humanismen': ('humanisme',),
'humanismene': ('humanisme',),
'humanismer': ('humanisme',),
'humanist': ('humanist',),
'humanisten': ('humanist',),
'humanistene': ('humanist',),
'humanister': ('humanist',),
'humanitet': ('humanitet',),
'humaniteten': ('humanitet',),
'humanitetene': ('humanitet',),
'humaniteter': ('humanitet',),
'humbug': ('humbug',),
'humbugen': ('humbug',),
'humbugene': ('humbug',),
'humbuger': ('humbug',),
'humbugmaker': ('humbugmaker',),
'humbugmakere': ('humbugmaker',),
'humbugmakeren': ('humbugmaker',),
'humbugmakerer': ('humbugmaker',),
'humbugmakerne': ('humbugmaker',),
'humiditet': ('humiditet',),
'humiditeten': ('humiditet',),
'humiditetene': ('humiditet',),
'humiditeter': ('humiditet',),
'humle': ('humle',),
'humlen': ('humle',),
'humlene': ('humle',),
'humler': ('humle',),
'humla': ('humle',),
'humle': ('humle',),
'humlen': ('humle',),
'humlene': ('humle',),
'humler': ('humle',),
'humleblom': ('humleblom',),
'humleblommen': ('humleblom',),
'humleblommene': ('humleblom',),
'humleblommer': ('humleblom',),
'humleblomst': ('humleblomst',),
'humleblomsten': ('humleblomst',),
'humleblomstene': ('humleblomst',),
'humleblomster': ('humleblomst',),
'humlebol': ('humlebol',),
'humlebola': ('humlebol',),
'humlebolene': ('humlebol',),
'humlebolet': ('humlebol',),
'humlebøla': ('humlebøle',),
'humlebøle': ('humlebøle',),
'humlebølene': ('humlebøle',),
'humlebøler': ('humlebøle',),
'humlebølet': ('humlebøle',),
'hummer': ('hummer',),
'hummere': ('hummer',),
'hummeren': ('hummer',),
'hummerer': ('hummer',),
'hummerne': ('hummer',),
'hummerpark': ('hummerpark',),
'hummerparken': ('hummerpark',),
'hummerparkene': ('hummerpark',),
'hummerparker': ('hummerpark',),
'hummerteina': ('hummerteine',),
'hummerteine': ('hummerteine',),
'hummerteinen': ('hummerteine',),
'hummerteinene': ('hummerteine',),
'hummerteiner': ('hummerteine',),
'humor': ('humor',),
'humoren': ('humor',),
'humorene': ('humor',),
'humorer': ('humor',),
'humoreske': ('humoreske',),
'humoresken': ('humoreske',),
'humoreskene': ('humoreske',),
'humoresker': ('humoreske',),
'humorist': ('humorist',),
'humoristen': ('humorist',),
'humoristene': ('humorist',),
'humorister': ('humorist',),
'hump': ('hump',),
'humpen': ('hump',),
'humpene': ('hump',),
'humper': ('hump',),
'hump': ('hump',),
'humpa': ('hump',),
'humpene': ('hump',),
'humpet': ('hump',),
'humul': ('humul',),
'humulen': ('humul',),
'humulene': ('humul',),
'humuler': ('humul',),
'humus': ('humus',),
'humusen': ('humus',),
'humusene': ('humus',),
'humuser': ('humus',),
'humusjord': ('humusjord',),
'humusjorda': ('humusjord',),
'humusjorden': ('humusjord',),
'humusjordene': ('humusjord',),
'humusjorder': ('humusjord',),
'humuslag': ('humuslag',),
'humuslaga': ('humuslag',),
'humuslagene': ('humuslag',),
'humuslaget': ('humuslag',),
'humør': ('humør',),
'humøra': ('humør',),
'humørene': ('humør',),
'humøret': ('humør',),
'hun': ('hun',),
'hunen': ('hun',),
'hunene': ('hun',),
'huner': ('hun',),
'hund': ('hund',),
'hunden': ('hund',),
'hundene': ('hund',),
'hunder': ('hund',),
'hundeavgift': ('hundeavgift',),
'hundeavgifta': ('hundeavgift',),
'hundeavgiften': ('hundeavgift',),
'hundeavgiftene': ('hundeavgift',),
'hundeavgifter': ('hundeavgift',),
'hundebitt': ('hundebitt',),
'hundebitta': ('hundebitt',),
'hundebittene': ('hundebitt',),
'hundebittet': ('hundebitt',),
'hundedag': ('hundedag',),
'hundedagen': ('hundedag',),
'hundedagene': ('hundedag',),
'hundedager': ('hundedag',),
'hundegalskap': ('hundegalskap',),
'hundegalskapen': ('hundegalskap',),
'hundegalskapene': ('hundegalskap',),
'hundegalskaper': ('hundegalskap',),
'hundeglam': ('hundeglam',),
'hundeglamma': ('hundeglam',),
'hundeglammene': ('hundeglam',),
'hundeglammet': ('hundeglam',),
'hundegras': ('hundegras',),
'hundegrasa': ('hundegras',),
'hundegrasene': ('hundegras',),
'hundegraset': ('hundegras',),
'hundegress': ('hundegress',),
'hundegressa': ('hundegress',),
'hundegressene': ('hundegress',),
'hundegresset': ('hundegress',),
'hundehold': ('hundehold',),
'hundeholda': ('hundehold',),
'hundeholdene': ('hundehold',),
'hundeholdet': ('hundehold',),
'hundehus': ('hundehus',),
'hundehusa': ('hundehus',),
'hundehusene': ('hundehus',),
'hundehuset': ('hundehus',),
'hundekjeks': ('hundekjeks',),
'hundekjeksen': ('hundekjeks',),
'hundekjeksene': ('hundekjeks',),
'hundekjeks': ('hundekjeks',),
'hundekjeksen': ('hundekjeks',),
'hundekjeksene': ('hundekjeks',),
'hundekjekser': ('hundekjeks',),
'hundekjøring': ('hundekjøring',),
'hundekjøringa': ('hundekjøring',),
'hundekjøringen': ('hundekjøring',),
'hundekjøringene': ('hundekjøring',),
'hundekjøringer': ('hundekjøring',),
'hundeleven': ('hundeleven',),
'hundelevena': ('hundeleven',),
'hundelevenene': ('hundeleven',),
'hundelevenet': ('hundeleven',),
'hundeliv': ('hundeliv',),
'hundeliva': ('hundeliv',),
'hundelivene': ('hundeliv',),
'hundelivet': ('hundeliv',),
'hundemat': ('hundemat',),
'hundematen': ('hundemat',),
'hundematene': ('hundemat',),
'hundemater': ('hundemat',),
'hundepersilla': ('hundepersille',),
'hundepersille': ('hundepersille',),
'hundepersillen': ('hundepersille',),
'hundepersillene': ('hundepersille',),
'hundepersiller': ('hundepersille',),
'hunderadd': ('hunderadd',),
'hunderadden': ('hunderadd',),
'hunderaddene': ('hunderadd',),
'hunderadder': ('hunderadd',),
'hundesele': ('hundesele',),
'hundeselen': ('hundesele',),
'hundeselene': ('hundesele',),
'hundeseler': ('hundesele',),
'hundeskatt': ('hundeskatt',),
'hundeskatten': ('hundeskatt',),
'hundeskattene': ('hundeskatt',),
'hundeskatter': ('hundeskatt',),
'hundeslede': ('hundeslede',),
'hundesleden': ('hundeslede',),
'hundesledene': ('hundeslede',),
'hundesleder': ('hundeslede',),
'hundesløka': ('hundesløke',),
'hundesløke': ('hundesløke',),
'hundesløken': ('hundesløke',),
'hundesløkene': ('hundesløke',),
'hundesløker': ('hundesløke',),
'hundespann': ('hundespann',),
'hundespanna': ('hundespann',),
'hundespannene': ('hundespann',),
'hundespannet': ('hundespann',),
'hundesport': ('hundesport',),
'hundesporten': ('hundesport',),
'hundesportene': ('hundesport',),
'hundesporter': ('hundesport',),
'hundestjerna': ('hundestjerne',),
'hundestjerne': ('hundestjerne',),
'hundestjernen': ('hundestjerne',),
'hundestjernene': ('hundestjerne',),
'hundestjerner': ('hundestjerne',),
'hundetunga': ('hundetunge',),
'hundetunge': ('hundetunge',),
'hundetungen': ('hundetunge',),
'hundetungene': ('hundetunge',),
'hundetunger': ('hundetunge',),
'hundevakt': ('hundevakt',),
'hundevakta': ('hundevakt',),
'hundevakten': ('hundevakt',),
'hundevaktene': ('hundevakt',),
'hundevakter': ('hundevakt',),
'hundevalp': ('hundevalp',),
'hundevalpen': ('hundevalp',),
'hundevalpene': ('hundevalp',),
'hundevalper': ('hundevalp',),
'hundevær': ('hundevær',),
'hundeværa': ('hundevær',),
'hundeværene': ('hundevær',),
'hundeværet': ('hundevær',),
'hundra': ('hundre',),
'hundre': ('hundre',),
'hundrene': ('hundre',),
'hundrer': ('hundre',),
'hundret': ('hundre',),
'hundredel': ('hundredel',),
'hundredelen': ('hundredel',),
'hundredelene': ('hundredel',),
'hundredeler': ('hundredel',),
'hundredweight': ('hundredweight',),
'hundredweighten': ('hundredweight',),
'hundredweightene': ('hundredweight',),
'hundredweights': ('hundredweight',),
'hundrekrona': ('hundrekrone',),
'hundrekrone': ('hundrekrone',),
'hundrekronen': ('hundrekrone',),
'hundrekronene': ('hundrekrone',),
'hundrekroner': ('hundrekrone',),
'hundrekroneseddel': ('hundrekroneseddel',),
'hundrekroneseddelen': ('hundrekroneseddel',),
'hundrekronesedlene': ('hundrekroneseddel',),
'hundrekronesedler': ('hundrekroneseddel',),
'hundrekroning': ('hundrekroning',),
'hundrekroningen': ('hundrekroning',),
'hundrekroningene': ('hundrekroning',),
'hundrekroninger': ('hundrekroning',),
'hundrelapp': ('hundrelapp',),
'hundrelappen': ('hundrelapp',),
'hundrelappene': ('hundrelapp',),
'hundrelapper': ('hundrelapp',),
'hundrer': ('hundrer',),
'hundrere': ('hundrer',),
'hundreren': ('hundrer',),
'hundrerer': ('hundrer',),
'hundrerne': ('hundrer',),
'hundretal': ('hundretal',),
'hundretala': ('hundretal',),
'hundretalene': ('hundretal',),
'hundretalet': ('hundretal',),
'hundretall': ('hundretall',),
'hundretalla': ('hundretall',),
'hundretallene': ('hundretall',),
'hundretallet': ('hundretall',),
'hundretusen': ('hundretusen',),
'hundretusena': ('hundretusen',),
'hundretusenene': ('hundretusen',),
'hundretusener': ('hundretusen',),
'hundretusenet': ('hundretusen',),
'hundreår': ('hundreår',),
'hundreåra': ('hundreår',),
'hundreårene': ('hundreår',),
'hundreåret': ('hundreår',),
'hundreåring': ('hundreåring',),
'hundreåringen': ('hundreåring',),
'hundreåringene': ('hundreåring',),
'hundreåringer': ('hundreåring',),
'hundreårsdag': ('hundreårsdag',),
'hundreårsdagen': ('hundreårsdag',),
'hundreårsdagene': ('hundreårsdag',),
'hundreårsdager': ('hundreårsdag',),
'hundreårsskifta': ('hundreårsskifte',),
'hundreårsskifte': ('hundreårsskifte',),
'hundreårsskiftene': ('hundreårsskifte',),
'hundreårsskifter': ('hundreårsskifte',),
'hundreårsskiftet': ('hundreårsskifte',),
'hundring': ('hundring',),
'hundringen': ('hundring',),
'hundringene': ('hundring',),
'hundringer': ('hundring',),
'hundsvott': ('hundsvott',),
'hundsvotten': ('hundsvott',),
'hundsvottene': ('hundsvott',),
'hundsvotter': ('hundsvott',),
'huner': ('huner',),
'hunere': ('huner',),
'huneren': ('huner',),
'hunerer': ('huner',),
'hunerne': ('huner',),
'hunger': ('hunger',),
'hungere': ('hunger',),
'hungeren': ('hunger',),
'hungerer': ('hunger',),
'hungerne': ('hunger',),
'hungre': ('hunger',),
'hungrene': ('hunger',),
'hungrer': ('hunger',),
'hungerkatastrofa': ('hungerkatastrofe',),
'hungerkatastrofe': ('hungerkatastrofe',),
'hungerkatastrofen': ('hungerkatastrofe',),
'hungerkatastrofene': ('hungerkatastrofe',),
'hungerkatastrofer': ('hungerkatastrofe',),
'hungersnød': ('hungersnød',),
'hungersnøda': ('hungersnød',),
'hungersnøden': ('hungersnød',),
'hungersnødene': ('hungersnød',),
'hungersnøder': ('hungersnød',),
'hunkjønn': ('hunkjønn',),
'hunkjønna': ('hunkjønn',),
'hunkjønnene': ('hunkjønn',),
'hunkjønnet': ('hunkjønn',),
'hunkjønnsord': ('hunkjønnsord',),
'hunkjønnsorda': ('hunkjønnsord',),
'hunkjønnsordene': ('hunkjønnsord',),
'hunkjønnsordet': ('hunkjønnsord',),
'hunn': ('hunn',),
'hunnen': ('hunn',),
'hunnene': ('hunn',),
'hunner': ('hunn',),
'hunnblomst': ('hunnblomst',),
'hunnblomsten': ('hunnblomst',),
'hunnblomstene': ('hunnblomst',),
'hunnblomster': ('hunnblomst',),
'hunndyr': ('hunndyr',),
'hunndyra': ('hunndyr',),
'hunndyrene': ('hunndyr',),
'hunndyret': ('hunndyr',),
'hunnfisk': ('hunnfisk',),
'hunnfisken': ('hunnfisk',),
'hunnfiskene': ('hunnfisk',),
'hunnfisker': ('hunnfisk',),
'hunnfugl': ('hunnfugl',),
'hunnfuglen': ('hunnfugl',),
'hunnfuglene': ('hunnfugl',),
'hunnfugler': ('hunnfugl',),
'hunnkatt': ('hunnkatt',),
'hunnkatten': ('hunnkatt',),
'hunnkattene': ('hunnkatt',),
'hunnkatter': ('hunnkatt',),
'hunnkjønn': ('hunnkjønn',),
'hunnkjønna': ('hunnkjønn',),
'hunnkjønnene': ('hunnkjønn',),
'hunnkjønnet': ('hunnkjønn',),
'hunnkjønnsord': ('hunnkjønnsord',),
'hunnkjønnsorda': ('hunnkjønnsord',),
'hunnkjønnsordene': ('hunnkjønnsord',),
'hunnkjønnsordet': ('hunnkjønnsord',),
'hunnplanta': ('hunnplante',),
'hunnplante': ('hunnplante',),
'hunnplanten': ('hunnplante',),
'hunnplantene': ('hunnplante',),
'hunnplanter': ('hunnplante',),
'hunnrakle': ('hunnrakle',),
'hunnraklen': ('hunnrakle',),
'hunnraklene': ('hunnrakle',),
'hunnrakler': ('hunnrakle',),
'hunved': ('hunved',),
'hunveden': ('hunved',),
'hunvedene': ('hunved',),
'hunveder': ('hunved',),
'huri': ('huri',),
'hurien': ('huri',),
'huriene': ('huri',),
'hurier': ('huri',),
'hurlumhei': ('hurlumhei',),
'hurlumheien': ('hurlumhei',),
'hurlumheiene': ('hurlumhei',),
'hurlumheier': ('hurlumhei',),
'hurpa': ('hurpe',),
'hurpe': ('hurpe',),
'hurpen': ('hurpe',),
'hurpene': ('hurpe',),
'hurper': ('hurpe',),
'hurr': ('hurr',),
'hurren': ('hurr',),
'hurrene': ('hurr',),
'hurrer': ('hurr',),
'hurra': ('hurra',),
'hurraene': ('hurra',),
'hurraer': ('hurra',),
'hurraet': ('hurra',),
'hurragutt': ('hurragutt',),
'hurragutten': ('hurragutt',),
'hurraguttene': ('hurragutt',),
'hurragutter': ('hurragutt',),
'hurrarop': ('hurrarop',),
'hurraropa': ('hurrarop',),
'hurraropene': ('hurrarop',),
'hurraropet': ('hurrarop',),
'hurtigbåt': ('hurtigbåt',),
'hurtigbåten': ('hurtigbåt',),
'hurtigbåtene': ('hurtigbåt',),
'hurtigbåter': ('hurtigbåt',),
'hurtighet': ('hurtighet',),
'hurtigheta': ('hurtighet',),
'hurtigheten': ('hurtighet',),
'hurtighetene': ('hurtighet',),
'hurtigheter': ('hurtighet',),
'hurtigløp': ('hurtigløp',),
'hurtigløpa': ('hurtigløp',),
'hurtigløpene': ('hurtigløp',),
'hurtigløpet': ('hurtigløp',),
'hurtigmat': ('hurtigmat',),
'hurtigmaten': ('hurtigmat',),
'hurtigmatene': ('hurtigmat',),
'hurtigmater': ('hurtigmat',),
'hurtigruta': ('hurtigrute',),
'hurtigrute': ('hurtigrute',),
'hurtigruten': ('hurtigrute',),
'hurtigrutene': ('hurtigrute',),
'hurtigruter': ('hurtigrute',),
'hurtigsegler': ('hurtigsegler',),
'hurtigseglere': ('hurtigsegler',),
'hurtigsegleren': ('hurtigsegler',),
'hurtigseglerer': ('hurtigsegler',),
'hurtigseglerne': ('hurtigsegler',),
'hurtigseiler': ('hurtigseiler',),
'hurtigseilere': ('hurtigseiler',),
'hurtigseileren': ('hurtigseiler',),
'hurtigseilerer': ('hurtigseiler',),
'hurtigseilerne': ('hurtigseiler',),
'hurtigtog': ('hurtigtog',),
'hurtigtoga': ('hurtigtog',),
'hurtigtogene': ('hurtigtog',),
'hurtigtoget': ('hurtigtog',),
'hurtigtogsfart': ('hurtigtogsfart',),
'hurtigtogsfarten': ('hurtigtogsfart',),
'hurtigtogsfartene': ('hurtigtogsfart',),
'hurtigtogsfarter': ('hurtigtogsfart',),
'hurv': ('hurv',),
'hurven': ('hurv',),
'hurvene': ('hurv',),
'hurver': ('hurv',),
'hus': ('hus',),
'husa': ('hus',),
'husene': ('hus',),
'huset': ('hus',),
'husagitasjon': ('husagitasjon',),
'husagitasjonen': ('husagitasjon',),
'husagitasjonene': ('husagitasjon',),
'husagitasjoner': ('husagitasjon',),
'husandakt': ('husandakt',),
'husandakta': ('husandakt',),
'husandakten': ('husandakt',),
'husandaktene': ('husandakt',),
'husandakter': ('husandakt',),
'husar': ('husar',),
'husaren': ('husar',),
'husarene': ('husar',),
'husarer': ('husar',),
'husarbeid': ('husarbeid',),
'husarbeida': ('husarbeid',),
'husarbeidene': ('husarbeid',),
'husarbeidet': ('husarbeid',),
'husarrest': ('husarrest',),
'husarresten': ('husarrest',),
'husarrestene': ('husarrest',),
'husarrester': ('husarrest',),
'husbankhus': ('husbankhus',),
'husbankhusa': ('husbankhus',),
'husbankhusene': ('husbankhus',),
'husbankhuset': ('husbankhus',),
'husbanklån': ('husbanklån',),
'husbanklåna': ('husbanklån',),
'husbanklånene': ('husbanklån',),
'husbanklånet': ('husbanklån',),
'husbesøk': ('husbesøk',),
'husbesøka': ('husbesøk',),
'husbesøkene': ('husbesøk',),
'husbesøket': ('husbesøk',),
'husbond': ('husbond',),
'husbonden': ('husbond',),
'husbondene': ('husbond',),
'husbonder': ('husbond',),
'husbondsfolk': ('husbondsfolk',),
'husbondsfolka': ('husbondsfolk',),
'husbondsfolkene': ('husbondsfolk',),
'husbondsfolket': ('husbondsfolk',),
'husbondskar': ('husbondskar',),
'husbondskaren': ('husbondskar',),
'husbondskarene': ('husbondskar',),
'husbondskarer': ('husbondskar',),
'husbruk': ('husbruk',),
'husbruka': ('husbruk',),
'husbruken': ('husbruk',),
'husbrukene': ('husbruk',),
'husbruker': ('husbruk',),
'husbruket': ('husbruk',),
'husbråk': ('husbråk',),
'husbråka': ('husbråk',),
'husbråkene': ('husbråk',),
'husbråket': ('husbråk',),
'husbukk': ('husbukk',),
'husbukken': ('husbukk',),
'husbukkene': ('husbukk',),
'husbukker': ('husbukk',),
'husbåt': ('husbåt',),
'husbåten': ('husbåt',),
'husbåtene': ('husbåt',),
'husbåter': ('husbåt',),
'husdikter': ('husdikter',),
'husdiktere': ('husdikter',),
'husdikteren': ('husdikter',),
'husdikterer': ('husdikter',),
'husdikterne': ('husdikter',),
'husdyr': ('husdyr',),
'husdyra': ('husdyr',),
'husdyrene': ('husdyr',),
'husdyret': ('husdyr',),
'husdyral': ('husdyral',),
'husdyrala': ('husdyral',),
'husdyralene': ('husdyral',),
'husdyralet': ('husdyral',),
'husdyravl': ('husdyravl',),
'husdyravlen': ('husdyravl',),
'husdyravlene': ('husdyravl',),
'husdyravler': ('husdyravl',),
'husdyrbruk': ('husdyrbruk',),
'husdyrbruka': ('husdyrbruk',),
'husdyrbrukene': ('husdyrbruk',),
'husdyrbruket': ('husdyrbruk',),
'husdyrhold': ('husdyrhold',),
'husdyrholda': ('husdyrhold',),
'husdyrholdene': ('husdyrhold',),
'husdyrholdet': ('husdyrhold',),
'husfar': ('husfar',),
'husfaren': ('husfar',),
'husfedre': ('husfar',),
'husfedrene': ('husfar',),
'husflid': ('husflid',),
'husfliden': ('husflid',),
'husflidene': ('husflid',),
'husflider': ('husflid',),
'husflidsskole': ('husflidsskole',),
'husflidsskolen': ('husflidsskole',),
'husflidsskolene': ('husflidsskole',),
'husflidsskoler': ('husflidsskole',),
'husflidsutsalg': ('husflidsutsalg',),
'husflidsutsalga': ('husflidsutsalg',),
'husflidsutsalgene': ('husflidsutsalg',),
'husflidsutsalget': ('husflidsutsalg',),
'husflua': ('husflue',),
'husflue': ('husflue',),
'husfluen': ('husflue',),
'husfluene': ('husflue',),
'husfluer': ('husflue',),
'husfred': ('husfred',),
'husfreden': ('husfred',),
'husfredene': ('husfred',),
'husfreder': ('husfred',),
'husfrua': ('husfrue',),
'husfrue': ('husfrue',),
'husfruen': ('husfrue',),
'husfruene': ('husfrue',),
'husfruer': ('husfrue',),
'husgeråd': ('husgeråd',),
'husgeråda': ('husgeråd',),
'husgerådene': ('husgeråd',),
'husgerådet': ('husgeråd',),
'husgud': ('husgud',),
'husguden': ('husgud',),
'husgudene': ('husgud',),
'husguder': ('husgud',),
'hushai': ('hushai',),
'hushaien': ('hushai',),
'hushaiene': ('hushai',),
'hushaier': ('hushai',),
'hushjelp': ('hushjelp',),
'hushjelpa': ('hushjelp',),
'hushjelpen': ('hushjelp',),
'hushjelpene': ('hushjelp',),
'hushjelper': ('hushjelp',),
'hushold': ('hushold',),
'husholda': ('hushold',),
'husholdene': ('hushold',),
'husholdet': ('hushold',),
'husholdbestyrer': ('husholdbestyrer',),
'husholdbestyrere': ('husholdbestyrer',),
'husholdbestyreren': ('husholdbestyrer',),
'husholdbestyrerer': ('husholdbestyrer',),
'husholdbestyrerne': ('husholdbestyrer',),
'husholder': ('husholder',),
'husholdere': ('husholder',),
'husholderen': ('husholder',),
'husholderer': ('husholder',),
'husholderne': ('husholder',),
'husholderska': ('husholderske',),
'husholderske': ('husholderske',),
'husholdersken': ('husholderske',),
'husholderskene': ('husholderske',),
'husholdersker': ('husholderske',),
'husholdning': ('husholdning',),
'husholdninga': ('husholdning',),
'husholdningen': ('husholdning',),
'husholdningene': ('husholdning',),
'husholdninger': ('husholdning',),
'husholdningsartikkel': ('husholdningsartikkel',),
'husholdningsartikkelen': ('husholdningsartikkel',),
'husholdningsartiklene': ('husholdningsartikkel',),
'husholdningsartikler': ('husholdningsartikkel',),
'husholdningsbudsjett': ('husholdningsbudsjett',),
'husholdningsbudsjetta': ('husholdningsbudsjett',),
'husholdningsbudsjettene': ('husholdningsbudsjett',),
'husholdningsbudsjetter': ('husholdningsbudsjett',),
'husholdningsbudsjettet': ('husholdningsbudsjett',),
'husholdningsfag': ('husholdningsfag',),
'husholdningsfaga': ('husholdningsfag',),
'husholdningsfagene': ('husholdningsfag',),
'husholdningsfaget': ('husholdningsfag',),
'husholdningspengene': ('husholdningspenger',),
'husholdningspenger': ('husholdningspenger',),
'husholdningsregnskap': ('husholdningsregnskap',),
'husholdningsregnskapa': ('husholdningsregnskap',),
'husholdningsregnskapene': ('husholdningsregnskap',),
'husholdningsregnskaper': ('husholdningsregnskap',),
'husholdningsregnskapet': ('husholdningsregnskap',),
'hushovmester': ('hushovmester',),
'hushovmestere': ('hushovmester',),
'hushovmesteren': ('hushovmester',),
'hushovmesterer': ('hushovmester',),
'hushovmesterne': ('hushovmester',),
'hushovmestre': ('hushovmester',),
'hushovmestrene': ('hushovmester',),
'hushovmestrer': ('hushovmester',),
'husitt': ('husitt',),
'husitten': ('husitt',),
'husittene': ('husitt',),
'husitter': ('husitt',),
'huskar': ('huskar',),
'huskaren': ('huskar',),
'huskarene': ('huskar',),
'huskarer': ('huskar',),
'huskatt': ('huskatt',),
'huskatten': ('huskatt',),
'huskattene': ('huskatt',),
'huskatter': ('huskatt',),
'huska': ('huske',),
'huske': ('huske',),
'husken': ('huske',),
'huskene': ('huske',),
'husker': ('huske',),
'huskelapp': ('huskelapp',),
'huskelappen': ('huskelapp',),
'huskelappene': ('huskelapp',),
'huskelapper': ('huskelapp',),
'huskeregel': ('huskeregel',),
'huskeregelen': ('huskeregel',),
'huskereglene': ('huskeregel',),
'huskeregler': ('huskeregel',),
'huskestua': ('huskestue',),
'huskestue': ('huskestue',),
'huskestuen': ('huskestue',),
'huskestuene': ('huskestue',),
'huskestuer': ('huskestue',),
'huskomhei': ('huskomhei',),
'huskomheien': ('huskomhei',),
'huskomheiene': ('huskomhei',),
'huskomheier': ('huskomhei',),
'huskors': ('huskors',),
'huskorsa': ('huskors',),
'huskorsene': ('huskors',),
'huskorset': ('huskors',),
'husky': ('husky',),
'huskyen': ('husky',),
'huskyene': ('husky',),
'huskyer': ('husky',),
'huslege': ('huslege',),
'huslegen': ('huslege',),
'huslegene': ('huslege',),
'husleger': ('huslege',),
'husleia': ('husleie',),
'husleie': ('husleie',),
'husleien': ('husleie',),
'husleiene': ('husleie',),
'husleier': ('husleie',),
'husly': ('husly',),
'huslya': ('husly',),
'huslyene': ('husly',),
'huslyet': ('husly',),
'huslyd': ('huslyd',),
'huslyden': ('huslyd',),
'huslydene': ('huslyd',),
'huslyder': ('huslyd',),
'huslærer': ('huslærer',),
'huslærere': ('huslærer',),
'huslæreren': ('huslærer',),
'huslærerer': ('huslærer',),
'huslærerne': ('huslærer',),
'husmann': ('husmann',),
'husmannen': ('husmann',),
'husmenn': ('husmann',),
'husmennene': ('husmann',),
'husmannsfolk': ('husmannsfolk',),
'husmannsfolka': ('husmannsfolk',),
'husmannsfolkene': ('husmannsfolk',),
'husmannsfolket': ('husmannsfolk',),
'husmannsgutt': ('husmannsgutt',),
'husmannsgutten': ('husmannsgutt',),
'husmannsguttene': ('husmannsgutt',),
'husmannsgutter': ('husmannsgutt',),
'husmannskost': ('husmannskost',),
'husmannskosten': ('husmannskost',),
'husmannskostene': ('husmannskost',),
'husmannskoster': ('husmannskost',),
'husmannsplass': ('husmannsplass',),
'husmannsplassen': ('husmannsplass',),
'husmannsplassene': ('husmannsplass',),
'husmannsplasser': ('husmannsplass',),
'husmannsstova': ('husmannsstove',),
'husmannsstove': ('husmannsstove',),
'husmannsstoven': ('husmannsstove',),
'husmannsstovene': ('husmannsstove',),
'husmannsstover': ('husmannsstove',),
'husmannsstua': ('husmannsstue',),
'husmannsstue': ('husmannsstue',),
'husmannsstuen': ('husmannsstue',),
'husmannsstuene': ('husmannsstue',),
'husmannsstuer': ('husmannsstue',),
'husmannsånd': ('husmannsånd',),
'husmannsånden': ('husmannsånd',),
'husmannsåndene': ('husmannsånd',),
'husmannsånder': ('husmannsånd',),
'husmidd': ('husmidd',),
'husmidden': ('husmidd',),
'husmiddene': ('husmidd',),
'husmidder': ('husmidd',),
'husmit': ('husmit',),
'husmiten': ('husmit',),
'husmitene': ('husmit',),
'husmiter': ('husmit',),
'husmorferie': ('husmorferie',),
'husmorferien': ('husmorferie',),
'husmorferiene': ('husmorferie',),
'husmorferier': ('husmorferie',),
'husmorlag': ('husmorlag',),
'husmorlaga': ('husmorlag',),
'husmorlagene': ('husmorlag',),
'husmorlaget': ('husmorlag',),
'husmorskole': ('husmorskole',),
'husmorskolen': ('husmorskole',),
'husmorskolene': ('husmorskole',),
'husmorskoler': ('husmorskole',),
'husmorvikar': ('husmorvikar',),
'husmorvikaren': ('husmorvikar',),
'husmorvikarene': ('husmorvikar',),
'husmorvikarer': ('husmorvikar',),
'husmus': ('husmus',),
'husmusa': ('husmus',),
'husmusen': ('husmus',),
'husmusene': ('husmus',),
'husmøta': ('husmøte',),
'husmøte': ('husmøte',),
'husmøtene': ('husmøte',),
'husmøter': ('husmøte',),
'husmøtet': ('husmøte',),
'husnisse': ('husnisse',),
'husnissen': ('husnisse',),
'husnissene': ('husnisse',),
'husnisser': ('husnisse',),
'husnød': ('husnød',),
'husnøda': ('husnød',),
'husnøden': ('husnød',),
'husnødene': ('husnød',),
'husnøder': ('husnød',),
'husorgan': ('husorgan',),
'husorgana': ('husorgan',),
'husorganene': ('husorgan',),
'husorganer': ('husorgan',),
'husorganet': ('husorgan',),
'huspost': ('huspost',),
'husposten': ('huspost',),
'huspostene': ('huspost',),
'husposter': ('huspost',),
'huspostill': ('huspostill',),
'huspostillen': ('huspostill',),
'huspostillene': ('huspostill',),
'huspostiller': ('huspostill',),
'husrom': ('husrom',),
'husromma': ('husrom',),
'husrommene': ('husrom',),
'husrommet': ('husrom',),
'husråd': ('husråd',),
'husråda': ('husråd',),
'husråden': ('husråd',),
'husrådene': ('husråd',),
'husråder': ('husråd',),
'husrådet': ('husråd',),
'hussopp': ('hussopp',),
'hussoppen': ('hussopp',),
'hussoppene': ('hussopp',),
'hussopper': ('hussopp',),
'husstand': ('husstand',),
'husstanden': ('husstand',),
'husstandene': ('husstand',),
'husstander': ('husstand',),
'husstell': ('husstell',),
'husstella': ('husstell',),
'husstellene': ('husstell',),
'husstellet': ('husstell',),
'husstell-læra': ('husstell-lære',),
'husstell-lære': ('husstell-lære',),
'husstell-læren': ('husstell-lære',),
'husstell-lærene': ('husstell-lære',),
'husstell-lærer': ('husstell-lære',),
'husstell-lærer': ('husstell-lærer',),
'husstell-lærere': ('husstell-lærer',),
'husstell-læreren': ('husstell-lærer',),
'husstell-lærerer': ('husstell-lærer',),
'husstell-lærerne': ('husstell-lærer',),
'husstellærer': ('husstellærer',),
'husstellærere': ('husstellærer',),
'husstellæreren': ('husstellærer',),
'husstellærerer': ('husstellærer',),
'husstellærerne': ('husstellærer',),
'hustavla': ('hustavle',),
'hustavle': ('hustavle',),
'hustavlen': ('hustavle',),
'hustavlene': ('hustavle',),
'hustavler': ('hustavle',),
'hustelefon': ('hustelefon',),
'hustelefonen': ('hustelefon',),
'hustelefonene': ('hustelefon',),
'hustelefoner': ('hustelefon',),
'hustellæra': ('hustellære',),
'hustellære': ('hustellære',),
'hustellæren': ('hustellære',),
'hustellærene': ('hustellære',),
'hustellærer': ('hustellære',),
'hustru': ('hustru',),
'hustrua': ('hustru',),
'hustruen': ('hustru',),
'hustruene': ('hustru',),
'hustruer': ('hustru',),
'hustuft': ('hustuft',),
'hustuften': ('hustuft',),
'hustuftene': ('hustuft',),
'hustufter': ('hustuft',),
'hustukt': ('hustukt',),
'hustukta': ('hustukt',),
'hustukten': ('hustukt',),
'hustuktene': ('hustukt',),
'hustukter': ('hustukt',),
'hustyrann': ('hustyrann',),
'hustyrannen': ('hustyrann',),
'hustyrannene': ('hustyrann',),
'hustyranner': ('hustyrann',),
'hustømmer': ('hustømmer',),
'hustømmera': ('hustømmer',),
'hustømmerene': ('hustømmer',),
'hustømmeret': ('hustømmer',),
'hustømra': ('hustømmer',),
'hustømre': ('hustømmer',),
'hustømrene': ('hustømmer',),
'husundersøkelse': ('husundersøkelse',),
'husundersøkelsen': ('husundersøkelse',),
'husundersøkelsene': ('husundersøkelse',),
'husundersøkelser': ('husundersøkelse',),
'husvalelse': ('husvalelse',),
'husvalelsen': ('husvalelse',),
'husvalelsene': ('husvalelse',),
'husvalelser': ('husvalelse',),
'husvenn': ('husvenn',),
'husvennen': ('husvenn',),
'husvennene': ('husvenn',),
'husvenner': ('husvenn',),
'husvert': ('husvert',),
'husverten': ('husvert',),
'husvertene': ('husvert',),
'husverter': ('husvert',),
'husvilleherberga': ('husvilleherberge',),
'husvilleherberge': ('husvilleherberge',),
'husvilleherbergene': ('husvilleherberge',),
'husvilleherberger': ('husvilleherberge',),
'husvilleherberget': ('husvilleherberge',),
'husvogn': ('husvogn',),
'husvogna': ('husvogn',),
'husvognen': ('husvogn',),
'husvognene': ('husvogn',),
'husvogner': ('husvogn',),
'husvær': ('husvær',),
'husværa': ('husvær',),
'husværene': ('husvær',),
'husværet': ('husvær',),
'husværa': ('husvære',),
'husvære': ('husvære',),
'husværene': ('husvære',),
'husværer': ('husvære',),
'husværet': ('husvære',),
'husøkonom': ('husøkonom',),
'husøkonomen': ('husøkonom',),
'husøkonomene': ('husøkonom',),
'husøkonomer': ('husøkonom',),
'hutaheiti': ('hutaheiti',),
'huva': ('huve',),
'huve': ('huve',),
'huven': ('huve',),
'huvene': ('huve',),
'huver': ('huve',),
'huva': ('huve',),
'huve': ('huve',),
'huven': ('huve',),
'huvene': ('huve',),
'huver': ('huve',),
'hval': ('hval',),
'hvalen': ('hval',),
'hvalene': ('hval',),
'hvaler': ('hval',),
'hvalbiff': ('hvalbiff',),
'hvalbiffen': ('hvalbiff',),
'hvalbiffene': ('hvalbiff',),
'hvalbiffer': ('hvalbiff',),
'hvalblåst': ('hvalblåst',),
'hvalblåsten': ('hvalblåst',),
'hvalblåstene': ('hvalblåst',),
'hvalblåster': ('hvalblåst',),
'hvalbåt': ('hvalbåt',),
'hvalbåten': ('hvalbåt',),
'hvalbåtene': ('hvalbåt',),
'hvalbåter': ('hvalbåt',),
'hvalfanger': ('hvalfanger',),
'hvalfangere': ('hvalfanger',),
'hvalfangeren': ('hvalfanger',),
'hvalfangerer': ('hvalfanger',),
'hvalfangerne': ('hvalfanger',),
'hvalfangst': ('hvalfangst',),
'hvalfangsten': ('hvalfangst',),
'hvalfangstene': ('hvalfangst',),
'hvalfangster': ('hvalfangst',),
'hvalhai': ('hvalhai',),
'hvalhaien': ('hvalhai',),
'hvalhaiene': ('hvalhai',),
'hvalhaier': ('hvalhai',),
'hvalkalv': ('hvalkalv',),
'hvalkalven': ('hvalkalv',),
'hvalkalvene': ('hvalkalv',),
'hvalkalver': ('hvalkalv',),
'hvalkanon': ('hvalkanon',),
'hvalkanonen': ('hvalkanon',),
'hvalkanonene': ('hvalkanon',),
'hvalkanoner': ('hvalkanon',),
'hvalkokeri': ('hvalkokeri',),
'hvalkokeria': ('hvalkokeri',),
'hvalkokeriene': ('hvalkokeri',),
'hvalkokerier': ('hvalkokeri',),
'hvalkokeriet': ('hvalkokeri',),
'hvalku': ('hvalku',),
'hvalkua': ('hvalku',),
'hvalkuen': ('hvalku',),
'hvalkuene': ('hvalku',),
'hvalkuer': ('hvalku',),
'hvalkyr': ('hvalku',),
'hvalkyrne': ('hvalku',),
'hvalolja': ('hvalolje',),
'hvalolje': ('hvalolje',),
'hvaloljen': ('hvalolje',),
'hvaloljene': ('hvalolje',),
'hvaloljer': ('hvalolje',),
'hvalross': ('hvalross',),
'hvalrossen': ('hvalross',),
'hvalrossene': ('hvalross',),
'hvalrosser': ('hvalross',),
'hvalrosstann': ('hvalrosstann',),
'hvalrosstanna': ('hvalrosstann',),
'hvalrosstannen': ('hvalrosstann',),
'hvalrosstennene': ('hvalrosstann',),
'hvalrosstenner': ('hvalrosstann',),
'hvalskytter': ('hvalskytter',),
'hvalskyttere': ('hvalskytter',),
'hvalskytteren': ('hvalskytter',),
'hvalskytterer': ('hvalskytter',),
'hvalskytterne': ('hvalskytter',),
'hvalstasjon': ('hvalstasjon',),
'hvalstasjonen': ('hvalstasjon',),
'hvalstasjonene': ('hvalstasjon',),
'hvalstasjoner': ('hvalstasjon',),
'hvelv': ('hvelv',),
'hvelva': ('hvelv',),
'hvelvene': ('hvelv',),
'hvelvet': ('hvelv',),
'hvelving': ('hvelving',),
'hvelvingen': ('hvelving',),
'hvelvingene': ('hvelving',),
'hvelvinger': ('hvelving',),
'hvemsomhelst': ('hvemsomhelst',),
'hvemsomhelsten': ('hvemsomhelst',),
'hvemsomhelstene': ('hvemsomhelst',),
'hvemsomhelster': ('hvemsomhelst',),
'hverdag': ('hverdag',),
'hverdagen': ('hverdag',),
'hverdagene': ('hverdag',),
'hverdager': ('hverdag',),
'hverdagsbruk': ('hverdagsbruk',),
'hverdagsbruka': ('hverdagsbruk',),
'hverdagsbruken': ('hverdagsbruk',),
'hverdagsbrukene': ('hverdagsbruk',),
'hverdagsbruker': ('hverdagsbruk',),
'hverdagsbruket': ('hverdagsbruk',),
'hverdagshistoria': ('hverdagshistorie',),
'hverdagshistorie': ('hverdagshistorie',),
'hverdagshistorien': ('hverdagshistorie',),
'hverdagshistoriene': ('hverdagshistorie',),
'hverdagshistorier': ('hverdagshistorie',),
'hverdagsklær': ('hverdagsklær',),
'hverdagsklærne': ('hverdagsklær',),
'hverdagskost': ('hverdagskost',),
'hverdagskosten': ('hverdagskost',),
'hverdagskostene': ('hverdagskost',),
'hverdagskoster': ('hverdagskost',),
'hverdagslag': ('hverdagslag',),
'hverdagslaga': ('hverdagslag',),
'hverdagslagene': ('hverdagslag',),
'hverdagslaget': ('hverdagslag',),
'hverdagsliv': ('hverdagsliv',),
'hverdagsliva': ('hverdagsliv',),
'hverdagslivene': ('hverdagsliv',),
'hverdagslivet': ('hverdagsliv',),
'hverdagsmenneska': ('hverdagsmenneske',),
'hverdagsmenneske': ('hverdagsmenneske',),
'hverdagsmenneskene': ('hverdagsmenneske',),
'hverdagsmennesker': ('hverdagsmenneske',),
'hverdagsmennesket': ('hverdagsmenneske',),
'hvermann': ('hvermann',),
'hvermannseia': ('hvermannseie',),
'hvermannseie': ('hvermannseie',),
'hvermannseiene': ('hvermannseie',),
'hvermannseier': ('hvermannseie',),
'hvermannseiet': ('hvermannseie',),
'hves': ('hves',),
'hvesa': ('hves',),
'hvesene': ('hves',),
'hveset': ('hves',),
'hvete': ('hvete',),
'hveten': ('hvete',),
'hvetene': ('hvete',),
'hveter': ('hvete',),
'hvetebolle': ('hvetebolle',),
'hvetebollen': ('hvetebolle',),
'hvetebollene': ('hvetebolle',),
'hveteboller': ('hvetebolle',),
'hvetebolle': ('hvetebolle',),
'hvetebollen': ('hvetebolle',),
'hvetebollene': ('hvetebolle',),
'hveteboller': ('hvetebolle',),
'hvetebrød': ('hvetebrød',),
'hvetebrøda': ('hvetebrød',),
'hvetebrødene': ('hvetebrød',),
'hvetebrødet': ('hvetebrød',),
'hvetebrød': ('hvetebrød',),
'hvetebrøda': ('hvetebrød',),
'hvetebrødene': ('hvetebrød',),
'hvetebrødet': ('hvetebrød',),
'hvetebrødsdag': ('hvetebrødsdag',),
'hvetebrødsdagen': ('hvetebrødsdag',),
'hvetebrødsdagene': ('hvetebrødsdag',),
'hvetebrødsdager': ('hvetebrødsdag',),
'hvetebrødsdag': ('hvetebrødsdag',),
'hvetebrødsdagen': ('hvetebrødsdag',),
'hvetebrødsdagene': ('hvetebrødsdag',),
'hvetebrødsdager': ('hvetebrødsdag',),
'hvetegrøpp': ('hvetegrøpp',),
'hvetegrøppa': ('hvetegrøpp',),
'hvetegrøppene': ('hvetegrøpp',),
'hvetegrøppet': ('hvetegrøpp',),
'hvetegrøpp': ('hvetegrøpp',),
'hvetegrøppa': ('hvetegrøpp',),
'hvetegrøppene': ('hvetegrøpp',),
'hvetegrøppet': ('hvetegrøpp',),
'hvetekaka': ('hvetekake',),
'hvetekake': ('hvetekake',),
'hvetekaken': ('hvetekake',),
'hvetekakene': ('hvetekake',),
'hvetekaker': ('hvetekake',),
'hvetekaka': ('hvetekake',),
'hvetekake': ('hvetekake',),
'hvetekaken': ('hvetekake',),
'hvetekakene': ('hvetekake',),
'hvetekaker': ('hvetekake',),
'hvetekli': ('hvetekli',),
'hveteklia': ('hvetekli',),
'hvetekliene': ('hvetekli',),
'hvetekliet': ('hvetekli',),
'hvetekli': ('hvetekli',),
'hveteklia': ('hvetekli',),
'hvetekliene': ('hvetekli',),
'hvetekliet': ('hvetekli',),
'hvetekorn': ('hvetekorn',),
'hvetekorna': ('hvetekorn',),
'hvetekornene': ('hvetekorn',),
'hvetekornet': ('hvetekorn',),
'hvetekorn': ('hvetekorn',),
'hvetekorna': ('hvetekorn',),
'hvetekornene': ('hvetekorn',),
'hvetekornet': ('hvetekorn',),
'hvetemel': ('hvetemel',),
'hvetemela': ('hvetemel',),
'hvetemelene': ('hvetemel',),
'hvetemelet': ('hvetemel',),
'hvetemel': ('hvetemel',),
'hvetemela': ('hvetemel',),
'hvetemelene': ('hvetemel',),
'hvetemelet': ('hvetemel',),
'hvetemjøl': ('hvetemjøl',),
'hvetemjøla': ('hvetemjøl',),
'hvetemjølene': ('hvetemjøl',),
'hvetemjølet': ('hvetemjøl',),
'hvetemjøl': ('hvetemjøl',),
'hvetemjøla': ('hvetemjøl',),
'hvetemjølene': ('hvetemjøl',),
'hvetemjølet': ('hvetemjøl',),
'hvil': ('hvil',),
'hvilen': ('hvil',),
'hvilene': ('hvil',),
'hviler': ('hvil',),
'hvila': ('hvile',),
'hvile': ('hvile',),
'hvilen': ('hvile',),
'hvilene': ('hvile',),
'hviler': ('hvile',),
'hvilebu': ('hvilebu',),
'hvilebua': ('hvilebu',),
'hvilebuen': ('hvilebu',),
'hvilebuene': ('hvilebu',),
'hvilebuer': ('hvilebu',),
'hviledag': ('hviledag',),
'hviledagen': ('hviledag',),
'hviledagene': ('hviledag',),
'hviledager': ('hviledag',),
'hvileheim': ('hvileheim',),
'hvileheimma': ('hvileheim',),
'hvileheimmene': ('hvileheim',),
'hvileheimmet': ('hvileheim',),
'hvilehjem': ('hvilehjem',),
'hvilehjemma': ('hvilehjem',),
'hvilehjemmene': ('hvilehjem',),
'hvilehjemmet': ('hvilehjem',),
'hvilepause': ('hvilepause',),
'hvilepausen': ('hvilepause',),
'hvilepausene': ('hvilepause',),
'hvilepauser': ('hvilepause',),
'hvileseta': ('hvilesete',),
'hvilesete': ('hvilesete',),
'hvilesetene': ('hvilesete',),
'hvileseter': ('hvilesete',),
'hvilesetet': ('hvilesete',),
'hvilested': ('hvilested',),
'hvilestedene': ('hvilested',),
'hvilesteder': ('hvilested',),
'hvilestedet': ('hvilested',),
'hvilestilling': ('hvilestilling',),
'hvilestillinga': ('hvilestilling',),
'hvilestillingen': ('hvilestilling',),
'hvilestillingene': ('hvilestilling',),
'hvilestillinger': ('hvilestilling',),
'hvilestrøm': ('hvilestrøm',),
'hvilestrømmen': ('hvilestrøm',),
'hvilestrømmene': ('hvilestrøm',),
'hvilestrømmer': ('hvilestrøm',),
'hvileår': ('hvileår',),
'hvileåra': ('hvileår',),
'hvileårene': ('hvileår',),
'hvileåret': ('hvileår',),
'hvin': ('hvin',),
'hvina': ('hvin',),
'hvinene': ('hvin',),
'hvinet': ('hvin',),
'hvisk': ('hvisk',),
'hviska': ('hvisk',),
'hviskene': ('hvisk',),
'hvisket': ('hvisk',),
'hvitbrystlo': ('hvitbrystlo',),
'hvitbrystloa': ('hvitbrystlo',),
'hvitbrystloen': ('hvitbrystlo',),
'hvitbrystloene': ('hvitbrystlo',),
'hvitbrystloer': ('hvitbrystlo',),
'hvita': ('hvite',),
'hvite': ('hvite',),
'hviten': ('hvite',),
'hvitene': ('hvite',),
'hviter': ('hvite',),
'hviterusser': ('hviterusser',),
'hviterussere': ('hviterusser',),
'hviterusseren': ('hviterusser',),
'hviterusserer': ('hviterusser',),
'hviterusserne': ('hviterusser',),
'hvitevara': ('hvitevare',),
'hvitevare': ('hvitevare',),
'hvitevaren': ('hvitevare',),
'hvitevarene': ('hvitevare',),
'hvitevarer': ('hvitevare',),
'hvitfisk': ('hvitfisk',),
'hvitfisken': ('hvitfisk',),
'hvitfiskene': ('hvitfisk',),
'hvitfisker': ('hvitfisk',),
'hvithval': ('hvithval',),
'hvithvalen': ('hvithval',),
'hvithvalene': ('hvithval',),
'hvithvaler': ('hvithval',),
'hvitkløver': ('hvitkløver',),
'hvitkløvere': ('hvitkløver',),
'hvitkløveren': ('hvitkløver',),
'hvitkløverer': ('hvitkløver',),
'hvitkløverne': ('hvitkløver',),
'hvitkval': ('hvitkval',),
'hvitkvalen': ('hvitkval',),
'hvitkvalene': ('hvitkval',),
'hvitkvaler': ('hvitkval',),
'hvitkål': ('hvitkål',),
'hvitkålen': ('hvitkål',),
'hvitkålene': ('hvitkål',),
'hvitkåler': ('hvitkål',),
'hvitløk': ('hvitløk',),
'hvitløken': ('hvitløk',),
'hvitløkene': ('hvitløk',),
'hvitløker': ('hvitløk',),
'hvitløkfedd': ('hvitløkfedd',),
'hvitløkfedda': ('hvitløkfedd',),
'hvitløkfeddene': ('hvitløkfedd',),
'hvitløkfeddet': ('hvitløkfedd',),
'hvitløkpulver': ('hvitløkpulver',),
'hvitløkpulvera': ('hvitløkpulver',),
'hvitløkpulvere': ('hvitløkpulver',),
'hvitløkpulveret': ('hvitløkpulver',),
'hvitløkpulverne': ('hvitløkpulver',),
'hvitmetall': ('hvitmetall',),
'hvitmetalla': ('hvitmetall',),
'hvitmetallene': ('hvitmetall',),
'hvitmetaller': ('hvitmetall',),
'hvitmetallet': ('hvitmetall',),
'hvitost': ('hvitost',),
'hvitosten': ('hvitost',),
'hvitostene': ('hvitost',),
'hvitoster': ('hvitost',),
'hvitrev': ('hvitrev',),
'hvitreven': ('hvitrev',),
'hvitrevene': ('hvitrev',),
'hvitrever': ('hvitrev',),
'hvitrust': ('hvitrust',),
'hvitrusta': ('hvitrust',),
'hvitrusten': ('hvitrust',),
'hvitrustene': ('hvitrust',),
'hvitruster': ('hvitrust',),
'hvitsnipp': ('hvitsnipp',),
'hvitsnippen': ('hvitsnipp',),
'hvitsnippene': ('hvitsnipp',),
'hvitsnipper': ('hvitsnipp',),
'hvitsnippforbrytelse': ('hvitsnippforbrytelse',),
'hvitsnippforbrytelsen': ('hvitsnippforbrytelse',),
'hvitsnippforbrytelsene': ('hvitsnippforbrytelse',),
'hvitsnippforbrytelser': ('hvitsnippforbrytelse',),
'hvitsnippforbryter': ('hvitsnippforbryter',),
'hvitsnippforbrytere': ('hvitsnippforbryter',),
'hvitsnippforbryteren': ('hvitsnippforbryter',),
'hvitsnippforbryterer': ('hvitsnippforbryter',),
'hvitsnippforbryterne': ('hvitsnippforbryter',),
'hvitsnippyrka': ('hvitsnippyrke',),
'hvitsnippyrke': ('hvitsnippyrke',),
'hvitsnippyrkene': ('hvitsnippyrke',),
'hvitsnippyrker': ('hvitsnippyrke',),
'hvitsnippyrket': ('hvitsnippyrke',),
'hvitt': ('hvitt',),
'hvittemiddel': ('hvittemiddel',),
'hvittemiddelet': ('hvittemiddel',),
'hvittemidla': ('hvittemiddel',),
'hvittemidlene': ('hvittemiddel',),
'hvittemidler': ('hvittemiddel',),
'hvittemidlet': ('hvittemiddel',),
'hvitting': ('hvitting',),
'hvittingen': ('hvitting',),
'hvittingene': ('hvitting',),
'hvittinger': ('hvitting',),
'hvitting': ('hvitting',),
'hvittingen': ('hvitting',),
'hvittingene': ('hvitting',),
'hvittinger': ('hvitting',),
'hvitveis': ('hvitveis',),
'hvitveisen': ('hvitveis',),
'hvitveisene': ('hvitveis',),
'hvitveiser': ('hvitveis',),
'hvitvin': ('hvitvin',),
'hvitvinen': ('hvitvin',),
'hvitvinene': ('hvitvin',),
'hvitviner': ('hvitvin',),
'hy': ('hy',),
'hya': ('hy',),
'hyene': ('hy',),
'hyet': ('hy',),
'hy': ('hy',),
'hya': ('hy',),
'hyene': ('hy',),
'hyet': ('hy',),
'hyasint': ('hyasint',),
'hyasinten': ('hyasint',),
'hyasintene': ('hyasint',),
'hyasinter': ('hyasint',),
'hyasint': ('hyasint',),
'hyasinten': ('hyasint',),
'hyasintene': ('hyasint',),
'hyasinter': ('hyasint',),
'hybel': ('hybel',),
'hybelen': ('hybel',),
'hyblene': ('hybel',),
'hybler': ('hybel',),
'hybelboer': ('hybelboer',),
'hybelboere': ('hybelboer',),
'hybelboeren': ('hybelboer',),
'hybelboerer': ('hybelboer',),
'hybelboerne': ('hybelboer',),
'hybelbuer': ('hybelbuer',),
'hybelbuere': ('hybelbuer',),
'hybelbueren': ('hybelbuer',),
'hybelbuerer': ('hybelbuer',),
'hybelbuerne': ('hybelbuer',),
'hybelhus': ('hybelhus',),
'hybelhusa': ('hybelhus',),
'hybelhusene': ('hybelhus',),
'hybelhuset': ('hybelhus',),
'hybelleilighet': ('hybelleilighet',),
'hybelleiligheta': ('hybelleilighet',),
'hybelleiligheten': ('hybelleilighet',),
'hybelleilighetene': ('hybelleilighet',),
'hybelleiligheter': ('hybelleilighet',),
'hybelliv': ('hybelliv',),
'hybelliva': ('hybelliv',),
'hybellivene': ('hybelliv',),
'hybellivet': ('hybelliv',),
'hybrid': ('hybrid',),
'hybriden': ('hybrid',),
'hybridene': ('hybrid',),
'hybrider': ('hybrid',),
'hybridord': ('hybridord',),
'hybridorda': ('hybridord',),
'hybridordene': ('hybridord',),
'hybridordet': ('hybridord',),
'hybris': ('hybris',),
'hybrisen': ('hybris',),
'hybrisene': ('hybris',),
'hybriser': ('hybris',),
'hydra': ('hydra',),
'hydraen': ('hydra',),
'hydraene': ('hydra',),
'hydraer': ('hydra',),
'hydrant': ('hydrant',),
'hydranten': ('hydrant',),
'hydrantene': ('hydrant',),
'hydranter': ('hydrant',),
'hydrat': ('hydrat',),
'hydrata': ('hydrat',),
'hydratene': ('hydrat',),
'hydrater': ('hydrat',),
'hydratet': ('hydrat',),
'hydraulikk': ('hydraulikk',),
'hydraulikken': ('hydraulikk',),
'hydraulikkene': ('hydraulikk',),
'hydraulikker': ('hydraulikk',),
'hydraulikkolja': ('hydraulikkolje',),
'hydraulikkolje': ('hydraulikkolje',),
'hydraulikkoljen': ('hydraulikkolje',),
'hydraulikkoljene': ('hydraulikkolje',),
'hydraulikkoljer': ('hydraulikkolje',),
'hydrid': ('hydrid',),
'hydrida': ('hydrid',),
'hydridene': ('hydrid',),
'hydrider': ('hydrid',),
'hydridet': ('hydrid',),
'hydrodynamikk': ('hydrodynamikk',),
'hydrodynamikken': ('hydrodynamikk',),
'hydrodynamikkene': ('hydrodynamikk',),
'hydrodynamikker': ('hydrodynamikk',),
'hydrofoil': ('hydrofoil',),
'hydrofoilen': ('hydrofoil',),
'hydrofoilene': ('hydrofoil',),
'hydrofoiler': ('hydrofoil',),
'hydrofoilbåt': ('hydrofoilbåt',),
'hydrofoilbåten': ('hydrofoilbåt',),
'hydrofoilbåtene': ('hydrofoilbåt',),
'hydrofoilbåter': ('hydrofoilbåt',),
'hydrofon': ('hydrofon',),
'hydrofonen': ('hydrofon',),
'hydrofonene': ('hydrofon',),
'hydrofoner': ('hydrofon',),
'hydrofytt': ('hydrofytt',),
'hydrofytten': ('hydrofytt',),
'hydrofyttene': ('hydrofytt',),
'hydrofytter': ('hydrofytt',),
'hydrogen': ('hydrogen',),
'hydrogena': ('hydrogen',),
'hydrogenene': ('hydrogen',),
'hydrogenet': ('hydrogen',),
'hydrogenbomba': ('hydrogenbombe',),
'hydrogenbombe': ('hydrogenbombe',),
'hydrogenbomben': ('hydrogenbombe',),
'hydrogenbombene': ('hydrogenbombe',),
'hydrogenbomber': ('hydrogenbombe',),
'hydrogenklorid': ('hydrogenklorid',),
'hydrogenklorida': ('hydrogenklorid',),
'hydrogenkloridene': ('hydrogenklorid',),
'hydrogenklorider': ('hydrogenklorid',),
'hydrogenkloridet': ('hydrogenklorid',),
'hydrogenperoksid': ('hydrogenperoksid',),
'hydrogenperoksida': ('hydrogenperoksid',),
'hydrogenperoksidene': ('hydrogenperoksid',),
'hydrogenperoksider': ('hydrogenperoksid',),
'hydrogenperoksidet': ('hydrogenperoksid',),
'hydrogensulfid': ('hydrogensulfid',),
'hydrogensulfida': ('hydrogensulfid',),
'hydrogensulfidene': ('hydrogensulfid',),
'hydrogensulfider': ('hydrogensulfid',),
'hydrogensulfidet': ('hydrogensulfid',),
'hydrograf': ('hydrograf',),
'hydrografen': ('hydrograf',),
'hydrografene': ('hydrograf',),
'hydrografer': ('hydrograf',),
'hydrografi': ('hydrografi',),
'hydrografien': ('hydrografi',),
'hydrografiene': ('hydrografi',),
'hydrografier': ('hydrografi',),
'hydrokarbon': ('hydrokarbon',),
'hydrokarbona': ('hydrokarbon',),
'hydrokarbonene': ('hydrokarbon',),
'hydrokarboner': ('hydrokarbon',),
'hydrokarbonet': ('hydrokarbon',),
'hydrolog': ('hydrolog',),
'hydrologen': ('hydrolog',),
'hydrologene': ('hydrolog',),
'hydrologer': ('hydrolog',),
'hydrologi': ('hydrologi',),
'hydrologien': ('hydrologi',),
'hydrologiene': ('hydrologi',),
'hydrologier': ('hydrologi',),
'hydrometer': ('hydrometer',),
'hydrometeret': ('hydrometer',),
'hydrometra': ('hydrometer',),
'hydrometre': ('hydrometer',),
'hydrometrene': ('hydrometer',),
'hydrometret': ('hydrometer',),
'hydroplan': ('hydroplan',),
'hydroplana': ('hydroplan',),
'hydroplanene': ('hydroplan',),
'hydroplaner': ('hydroplan',),
'hydroplanet': ('hydroplan',),
'hydroskop': ('hydroskop',),
'hydroskopa': ('hydroskop',),
'hydroskopene': ('hydroskop',),
'hydroskoper': ('hydroskop',),
'hydroskopet': ('hydroskop',),
'hydroteknikk': ('hydroteknikk',),
'hydroteknikken': ('hydroteknikk',),
'hydroteknikkene': ('hydroteknikk',),
'hydroteknikker': ('hydroteknikk',),
'hyene': ('hyene',),
'hyenen': ('hyene',),
'hyenene': ('hyene',),
'hyener': ('hyene',),
'hyenehund': ('hyenehund',),
'hyenehunden': ('hyenehund',),
'hyenehundene': ('hyenehund',),
'hyenehunder': ('hyenehund',),
'hygga': ('hygge',),
'hygge': ('hygge',),
'hyggen': ('hygge',),
'hyggene': ('hygge',),
'hygger': ('hygge',),
'hyggekveld': ('hyggekveld',),
'hyggekvelden': ('hyggekveld',),
'hyggekveldene': ('hyggekveld',),
'hyggekvelder': ('hyggekveld',),
'hyggestund': ('hyggestund',),
'hyggestunda': ('hyggestund',),
'hyggestunden': ('hyggestund',),
'hyggestundene': ('hyggestund',),
'hyggestunder': ('hyggestund',),
'hygiene': ('hygiene',),
'hygienen': ('hygiene',),
'hygienene': ('hygiene',),
'hygiener': ('hygiene',),
'hygieniker': ('hygieniker',),
'hygienikere': ('hygieniker',),
'hygienikeren': ('hygieniker',),
'hygienikerer': ('hygieniker',),
'hygienikerne': ('hygieniker',),
'hygrometer': ('hygrometer',),
'hygrometeret': ('hygrometer',),
'hygrometra': ('hygrometer',),
'hygrometre': ('hygrometer',),
'hygrometrene': ('hygrometer',),
'hygrometret': ('hygrometer',),
'hygroskop': ('hygroskop',),
'hygroskopa': ('hygroskop',),
'hygroskopene': ('hygroskop',),
'hygroskoper': ('hygroskop',),
'hygroskopet': ('hygroskop',),
'hykler': ('hykler',),
'hyklere': ('hykler',),
'hykleren': ('hykler',),
'hyklerer': ('hykler',),
'hyklerne': ('hykler',),
'hykleri': ('hykleri',),
'hykleria': ('hykleri',),
'hykleriene': ('hykleri',),
'hyklerier': ('hykleri',),
'hykleriet': ('hykleri',),
'hyl': ('hyl',),
'hyla': ('hyl',),
'hylene': ('hyl',),
'hylet': ('hyl',),
'hylekor': ('hylekor',),
'hylekora': ('hylekor',),
'hylekorene': ('hylekor',),
'hylekoret': ('hylekor',),
'hyling': ('hyling',),
'hylinga': ('hyling',),
'hylingen': ('hyling',),
'hylingene': ('hyling',),
'hylinger': ('hyling',),
'hyll': ('hyll',),
'hyllen': ('hyll',),
'hyllene': ('hyll',),
'hyller': ('hyll',),
'hylla': ('hylle',),
'hylle': ('hylle',),
'hyllen': ('hylle',),
'hyllene': ('hylle',),
'hyller': ('hylle',),
'hyllebær': ('hyllebær',),
'hyllebæra': ('hyllebær',),
'hyllebærene': ('hyllebær',),
'hyllebæret': ('hyllebær',),
'hyllebær': ('hyllebær',),
'hyllebæra': ('hyllebær',),
'hyllebærene': ('hyllebær',),
'hyllebæret': ('hyllebær',),
'hyllebærsaft': ('hyllebærsaft',),
'hyllebærsafta': ('hyllebærsaft',),
'hyllebærsaften': ('hyllebærsaft',),
'hyllebærsaftene': ('hyllebærsaft',),
'hyllebærsafter': ('hyllebærsaft',),
'hylleknekt': ('hylleknekt',),
'hylleknekten': ('hylleknekt',),
'hylleknektene': ('hylleknekt',),
'hylleknekter': ('hylleknekt',),
'hyllemeter': ('hyllemeter',),
'hyllemetere': ('hyllemeter',),
'hyllemeteren': ('hyllemeter',),
'hyllemeterer': ('hyllemeter',),
'hyllemeterne': ('hyllemeter',),
'hyllest': ('hyllest',),
'hyllesten': ('hyllest',),
'hyllestene': ('hyllest',),
'hyllester': ('hyllest',),
'hyllete': ('hyllete',),
'hylleteen': ('hyllete',),
'hylleteene': ('hyllete',),
'hylleteer': ('hyllete',),
'hylsa': ('hylse',),
'hylse': ('hylse',),
'hylsen': ('hylse',),
'hylsene': ('hylse',),
'hylser': ('hylse',),
'hylster': ('hylster',),
'hylsteret': ('hylster',),
'hylstra': ('hylster',),
'hylstre': ('hylster',),
'hylstrene': ('hylster',),
'hylstret': ('hylster',),
'hymen': ('hymen',),
'hymne': ('hymne',),
'hymnen': ('hymne',),
'hymnene': ('hymne',),
'hymner': ('hymne',),
'hynna': ('hynne',),
'hynne': ('hynne',),
'hynnen': ('hynne',),
'hynnene': ('hynne',),
'hynner': ('hynne',),
'hynnet': ('hynne',),
'hyperbel': ('hyperbel',),
'hyperbelen': ('hyperbel',),
'hyperblene': ('hyperbel',),
'hyperbler': ('hyperbel',),
'hyperbol': ('hyperbol',),
'hyperbolen': ('hyperbol',),
'hyperbolene': ('hyperbol',),
'hyperboler': ('hyperbol',),
'hyperonym': ('hyperonym',),
'hyperonyma': ('hyperonym',),
'hyperonymene': ('hyperonym',),
'hyperonymer': ('hyperonym',),
'hyperonymet': ('hyperonym',),
'hypnose': ('hypnose',),
'hypnosen': ('hypnose',),
'hypnosene': ('hypnose',),
'hypnoser': ('hypnose',),
'hypnotisme': ('hypnotisme',),
'hypnotismen': ('hypnotisme',),
'hypnotismene': ('hypnotisme',),
'hypnotismer': ('hypnotisme',),
'hypnotisør': ('hypnotisør',),
'hypnotisøren': ('hypnotisør',),
'hypnotisørene': ('hypnotisør',),
'hypnotisører': ('hypnotisør',),
'hypofyse': ('hypofyse',),
'hypofysen': ('hypofyse',),
'hypofysene': ('hypofyse',),
'hypofyser': ('hypofyse',),
'hypokonder': ('hypokonder',),
'hypokondere': ('hypokonder',),
'hypokonderen': ('hypokonder',),
'hypokonderer': ('hypokonder',),
'hypokonderne': ('hypokonder',),
'hypokondri': ('hypokondri',),
'hypokondrien': ('hypokondri',),
'hypokondriene': ('hypokondri',),
'hypokondrier': ('hypokondri',),
'hypokritt': ('hypokritt',),
'hypokritten': ('hypokritt',),
'hypokrittene': ('hypokritt',),
'hypokritter': ('hypokritt',),
'hyponym': ('hyponym',),
'hyponyma': ('hyponym',),
'hyponymene': ('hyponym',),
'hyponymer': ('hyponym',),
'hyponymet': ('hyponym',),
'hypotagma': ('hypotagme',),
'hypotagme': ('hypotagme',),
'hypotagmene': ('hypotagme',),
'hypotagmer': ('hypotagme',),
'hypotagmet': ('hypotagme',),
'hypotakse': ('hypotakse',),
'hypotaksen': ('hypotakse',),
'hypotaksene': ('hypotakse',),
'hypotakser': ('hypotakse',),
'hypotek': ('hypotek',),
'hypoteka': ('hypotek',),
'hypotekene': ('hypotek',),
'hypoteker': ('hypotek',),
'hypoteket': ('hypotek',),
'hypotekbank': ('hypotekbank',),
'hypotekbanken': ('hypotekbank',),
'hypotekbankene': ('hypotekbank',),
'hypotekbanker': ('hypotekbank',),
'hypotekforening': ('hypotekforening',),
'hypotekforeninga': ('hypotekforening',),
'hypotekforeningen': ('hypotekforening',),
'hypotekforeningene': ('hypotekforening',),
'hypotekforeninger': ('hypotekforening',),
'hypotenus': ('hypotenus',),
'hypotenusen': ('hypotenus',),
'hypotenusene': ('hypotenus',),
'hypotenuser': ('hypotenus',),
'hypotese': ('hypotese',),
'hypotesen': ('hypotese',),
'hypotesene': ('hypotese',),
'hypoteser': ('hypotese',),
'hyppighet': ('hyppighet',),
'hyppigheta': ('hyppighet',),
'hyppigheten': ('hyppighet',),
'hyppighetene': ('hyppighet',),
'hyppigheter': ('hyppighet',),
'hyrde': ('hyrde',),
'hyrden': ('hyrde',),
'hyrdene': ('hyrde',),
'hyrder': ('hyrde',),
'hyrdebrev': ('hyrdebrev',),
'hyrdebreva': ('hyrdebrev',),
'hyrdebrevene': ('hyrdebrev',),
'hyrdebrever': ('hyrdebrev',),
'hyrdebrevet': ('hyrdebrev',),
'hyrdedikting': ('hyrdedikting',),
'hyrdediktinga': ('hyrdedikting',),
'hyrdediktingen': ('hyrdedikting',),
'hyrdediktingene': ('hyrdedikting',),
'hyrdediktinger': ('hyrdedikting',),
'hyrdediktning': ('hyrdediktning',),
'hyrdediktninga': ('hyrdediktning',),
'hyrdediktningen': ('hyrdediktning',),
'hyrdediktningene': ('hyrdediktning',),
'hyrdediktninger': ('hyrdediktning',),
'hyrdestav': ('hyrdestav',),
'hyrdestaven': ('hyrdestav',),
'hyrdestavene': ('hyrdestav',),
'hyrdestaver': ('hyrdestav',),
'hyrdestund': ('hyrdestund',),
'hyrdestunda': ('hyrdestund',),
'hyrdestunden': ('hyrdestund',),
'hyrdestundene': ('hyrdestund',),
'hyrdestunder': ('hyrdestund',),
'hyrdetime': ('hyrdetime',),
'hyrdetimen': ('hyrdetime',),
'hyrdetimene': ('hyrdetime',),
'hyrdetimer': ('hyrdetime',),
'hyrdinna': ('hyrdinne',),
'hyrdinne': ('hyrdinne',),
'hyrdinnen': ('hyrdinne',),
'hyrdinnene': ('hyrdinne',),
'hyrdinner': ('hyrdinne',),
'hyra': ('hyre',),
'hyre': ('hyre',),
'hyren': ('hyre',),
'hyrene': ('hyre',),
'hyrer': ('hyre',),
'hyret': ('hyre',),
'hyra': ('hyre',),
'hyre': ('hyre',),
'hyren': ('hyre',),
'hyrene': ('hyre',),
'hyrer': ('hyre',),
'hyreagent': ('hyreagent',),
'hyreagenten': ('hyreagent',),
'hyreagentene': ('hyreagent',),
'hyreagenter': ('hyreagent',),
'hyrebas': ('hyrebas',),
'hyrebasen': ('hyrebas',),
'hyrebasene': ('hyrebas',),
'hyrebaser': ('hyrebas',),
'hyrekontor': ('hyrekontor',),
'hyrekontora': ('hyrekontor',),
'hyrekontorene': ('hyrekontor',),
'hyrekontorer': ('hyrekontor',),
'hyrekontoret': ('hyrekontor',),
'hysa': ('hyse',),
'hyse': ('hyse',),
'hysen': ('hyse',),
'hysene': ('hyse',),
'hyser': ('hyse',),
'hysj': ('hysj',),
'hysja': ('hysj',),
'hysjene': ('hysj',),
'hysjet': ('hysj',),
'hysj-hysj': ('hysj-hysj',),
'hysj-hysj-virksomhet': ('hysj-hysj-virksomhet',),
'hysj-hysj-virksomheta': ('hysj-hysj-virksomhet',),
'hysj-hysj-virksomheten': ('hysj-hysj-virksomhet',),
'hysj-hysj-virksomhetene': ('hysj-hysj-virksomhet',),
'hysj-hysj-virksomheter': ('hysj-hysj-virksomhet',),
'hyss': ('hyss',),
'hyssa': ('hyss',),
'hyssene': ('hyss',),
'hysset': ('hyss',),
'hyssing': ('hyssing',),
'hyssingen': ('hyssing',),
'hyssingene': ('hyssing',),
'hyssinger': ('hyssing',),
'hyssingstump': ('hyssingstump',),
'hyssingstumpen': ('hyssingstump',),
'hyssingstumpene': ('hyssingstump',),
'hyssingstumper': ('hyssingstump',),
'hysteri': ('hysteri',),
'hysteria': ('hysteri',),
'hysteriene': ('hysteri',),
'hysterier': ('hysteri',),
'hysteriet': ('hysteri',),
'hysteriker': ('hysteriker',),
'hysterikere': ('hysteriker',),
'hysterikeren': ('hysteriker',),
'hysterikerer': ('hysteriker',),
'hysterikerne': ('hysteriker',),
'hytt': ('hytt',),
'hytta': ('hytte',),
'hytte': ('hytte',),
'hytten': ('hytte',),
'hyttene': ('hytte',),
'hytter': ('hytte',),
'hytteby': ('hytteby',),
'hyttebyen': ('hytteby',),
'hyttebyene': ('hytteby',),
'hyttebyer': ('hytteby',),
'hyttefelt': ('hyttefelt',),
'hyttefelta': ('hyttefelt',),
'hyttefeltene': ('hyttefelt',),
'hyttefelter': ('hyttefelt',),
'hyttefeltet': ('hyttefelt',),
'hyttegrend': ('hyttegrend',),
'hyttegrenda': ('hyttegrend',),
'hyttegrenden': ('hyttegrend',),
'hyttegrendene': ('hyttegrend',),
'hyttegrender': ('hyttegrend',),
'hå': ('hå',),
'håen': ('hå',),
'håene': ('hå',),
'håer': ('hå',),
'hå': ('hå',),
'håa': ('hå',),
'håen': ('hå',),
'håene': ('hå',),
'håer': ('hå',),
'håball': ('håball',),
'håballen': ('håball',),
'håballene': ('håball',),
'håballer': ('håball',),
'håbrann': ('håbrann',),
'håbrannen': ('håbrann',),
'håbrannene': ('håbrann',),
'håbranner': ('håbrann',),
'håkjerring': ('håkjerring',),
'håkjerringa': ('håkjerring',),
'håkjerringen': ('håkjerring',),
'håkjerringene': ('håkjerring',),
'håkjerringer': ('håkjerring',),
'hålka': ('hålke',),
'hålke': ('hålke',),
'hålken': ('hålke',),
'hålkene': ('hålke',),
'hålker': ('hålke',),
'hålkeføra': ('hålkeføre',),
'hålkeføre': ('hålkeføre',),
'hålkeførene': ('hålkeføre',),
'hålkefører': ('hålkeføre',),
'hålkeføret': ('hålkeføre',),
'hån': ('hån',),
'hånen': ('hån',),
'hånene': ('hån',),
'håner': ('hån',),
'håndalfabet': ('håndalfabet',),
'håndalfabeta': ('håndalfabet',),
'håndalfabetene': ('håndalfabet',),
'håndalfabeter': ('håndalfabet',),
'håndalfabetet': ('håndalfabet',),
'håndarbeid': ('håndarbeid',),
'håndarbeida': ('håndarbeid',),
'håndarbeidene': ('håndarbeid',),
'håndarbeider': ('håndarbeid',),
'håndarbeidet': ('håndarbeid',),
'håndbagasje': ('håndbagasje',),
'håndbagasjen': ('håndbagasje',),
'håndbagasjene': ('håndbagasje',),
'håndbagasjer': ('håndbagasje',),
'håndbak': ('håndbak',),
'håndbaken': ('håndbak',),
'håndbakene': ('håndbak',),
'håndbaker': ('håndbak',),
'håndball': ('håndball',),
'håndballen': ('håndball',),
'håndballene': ('håndball',),
'håndballer': ('håndball',),
'håndballkamp': ('håndballkamp',),
'håndballkampen': ('håndballkamp',),
'håndballkampene': ('håndballkamp',),
'håndballkamper': ('håndballkamp',),
'håndballspeller': ('håndballspeller',),
'håndballspellere': ('håndballspeller',),
'håndballspelleren': ('håndballspeller',),
'håndballspellerer': ('håndballspeller',),
'håndballspellerne': ('håndballspeller',),
'håndballspiller': ('håndballspiller',),
'håndballspillere': ('håndballspiller',),
'håndballspilleren': ('håndballspiller',),
'håndballspillerer': ('håndballspiller',),
'håndballspillerne': ('håndballspiller',),
'håndbevegelse': ('håndbevegelse',),
'håndbevegelsen': ('håndbevegelse',),
'håndbevegelsene': ('håndbevegelse',),
'håndbevegelser': ('håndbevegelse',),
'håndbibliotek': ('håndbibliotek',),
'håndbiblioteka': ('håndbibliotek',),
'håndbibliotekene': ('håndbibliotek',),
'håndbiblioteker': ('håndbibliotek',),
'håndbiblioteket': ('håndbibliotek',),
'håndbrekk': ('håndbrekk',),
'håndbrekka': ('håndbrekk',),
'håndbrekkene': ('håndbrekk',),
'håndbrekket': ('håndbrekk',),
'håndbrems': ('håndbrems',),
'håndbremsen': ('håndbrems',),
'håndbremsene': ('håndbrems',),
'håndbremser': ('håndbrems',),
'håndbremsa': ('håndbremse',),
'håndbremse': ('håndbremse',),
'håndbremsen': ('håndbremse',),
'håndbremsene': ('håndbremse',),
'håndbremser': ('håndbremse',),
'håndduk': ('håndduk',),
'håndduken': ('håndduk',),
'hånddukene': ('håndduk',),
'håndduker': ('håndduk',),
'håndfestning': ('håndfestning',),
'håndfestninga': ('håndfestning',),
'håndfestningen': ('håndfestning',),
'håndfestningene': ('håndfestning',),
'håndfestninger': ('håndfestning',),
'håndflata': ('håndflate',),
'håndflate': ('håndflate',),
'håndflaten': ('håndflate',),
'håndflatene': ('håndflate',),
'håndflater': ('håndflate',),
'håndfull': ('håndfull',),
'håndfullen': ('håndfull',),
'håndfullene': ('håndfull',),
'håndfuller': ('håndfull',),
'håndgranat': ('håndgranat',),
'håndgranaten': ('håndgranat',),
'håndgranatene': ('håndgranat',),
'håndgranater': ('håndgranat',),
'håndgrep': ('håndgrep',),
'håndgrepa': ('håndgrep',),
'håndgrepene': ('håndgrep',),
'håndgrepet': ('håndgrep',),
'håndgripelighet': ('håndgripelighet',),
'håndgripeligheta': ('håndgripelighet',),
'håndgripeligheten': ('håndgripelighet',),
'håndgripelighetene': ('håndgripelighet',),
'håndgripeligheter': ('håndgripelighet',),
'håndhevelse': ('håndhevelse',),
'håndhevelsen': ('håndhevelse',),
'håndhevelsene': ('håndhevelse',),
'håndhevelser': ('håndhevelse',),
'håndhevelse': ('håndhevelse',),
'håndhevelsen': ('håndhevelse',),
'håndhevelsene': ('håndhevelse',),
'håndhevelser': ('håndhevelse',),
'håndhever': ('håndhever',),
'håndhevere': ('håndhever',),
'håndheveren': ('håndhever',),
'håndheverer': ('håndhever',),
'håndheverne': ('håndhever',),
'håndhever': ('håndhever',),
'håndhevere': ('håndhever',),
'håndheveren': ('håndhever',),
'håndheverer': ('håndhever',),
'håndheverne': ('håndhever',),
'håndheving': ('håndheving',),
'håndhevinga': ('håndheving',),
'håndhevingen': ('håndheving',),
'håndhevingene': ('håndheving',),
'håndhevinger': ('håndheving',),
'håndjern': ('håndjern',),
'håndjerna': ('håndjern',),
'håndjernene': ('håndjern',),
'håndjernet': ('håndjern',),
'håndkjerra': ('håndkjerre',),
'håndkjerre': ('håndkjerre',),
'håndkjerren': ('håndkjerre',),
'håndkjerrene': ('håndkjerre',),
'håndkjerrer': ('håndkjerre',),
'håndkjøp': ('håndkjøp',),
'håndkjøpa': ('håndkjøp',),
'håndkjøpene': ('håndkjøp',),
'håndkjøpet': ('håndkjøp',),
'håndkle': ('håndkle',),
'håndkleet': ('håndkle',),
'håndklær': ('håndkle',),
'håndklærne': ('håndkle',),
'håndkoffert': ('håndkoffert',),
'håndkofferten': ('håndkoffert',),
'håndkoffertene': ('håndkoffert',),
'håndkofferter': ('håndkoffert',),
'håndkraft': ('håndkraft',),
'håndkrafta': ('håndkraft',),
'håndkraften': ('håndkraft',),
'håndkraftene': ('håndkraft',),
'håndkrafter': ('håndkraft',),
'håndlag': ('håndlag',),
'håndlaga': ('håndlag',),
'håndlagene': ('håndlag',),
'håndlaget': ('håndlag',),
'håndlanger': ('håndlanger',),
'håndlangere': ('håndlanger',),
'håndlangeren': ('håndlanger',),
'håndlangerer': ('håndlanger',),
'håndlangerne': ('håndlanger',),
'håndledd': ('håndledd',),
'håndledda': ('håndledd',),
'håndleddene': ('håndledd',),
'håndleddet': ('håndledd',),
'håndmikser': ('håndmikser',),
'håndmiksere': ('håndmikser',),
'håndmikseren': ('håndmikser',),
'håndmikserer': ('håndmikser',),
'håndmikserne': ('håndmikser',),
'håndpant': ('håndpant',),
'håndpanta': ('håndpant',),
'håndpantene': ('håndpant',),
'håndpantet': ('håndpant',),
'håndpengene': ('håndpenger',),
'håndpenger': ('håndpenger',),
'håndpleia': ('håndpleie',),
'håndpleie': ('håndpleie',),
'håndpleien': ('håndpleie',),
'håndpleiene': ('håndpleie',),
'håndpleier': ('håndpleie',),
'håndrot': ('håndrot',),
'håndrota': ('håndrot',),
'håndroten': ('håndrot',),
'håndrøttene': ('håndrot',),
'håndrøtter': ('håndrot',),
'håndsag': ('håndsag',),
'håndsaga': ('håndsag',),
'håndsagen': ('håndsag',),
'håndsagene': ('håndsag',),
'håndsager': ('håndsag',),
'håndsbredd': ('håndsbredd',),
'håndsbredden': ('håndsbredd',),
'håndsbreddene': ('håndsbredd',),
'håndsbredder': ('håndsbredd',),
'håndsbredd': ('håndsbredd',),
'håndsbredden': ('håndsbredd',),
'håndsbreddene': ('håndsbredd',),
'håndsbredder': ('håndsbredd',),
'håndskrift': ('håndskrift',),
'håndskrifta': ('håndskrift',),
'håndskriftene': ('håndskrift',),
'håndskrifter': ('håndskrift',),
'håndskriftet': ('håndskrift',),
'håndskrift': ('håndskrift',),
'håndskrifta': ('håndskrift',),
'håndskriften': ('håndskrift',),
'håndskriftene': ('håndskrift',),
'håndskrifter': ('håndskrift',),
'håndskriftsamling': ('håndskriftsamling',),
'håndskriftsamlinga': ('håndskriftsamling',),
'håndskriftsamlingen': ('håndskriftsamling',),
'håndskriftsamlingene': ('håndskriftsamling',),
'håndskriftsamlinger': ('håndskriftsamling',),
'håndskytevåpen': ('håndskytevåpen',),
'håndskytevåpenet': ('håndskytevåpen',),
'håndskytevåpna': ('håndskytevåpen',),
'håndskytevåpnene': ('håndskytevåpen',),
'håndslag': ('håndslag',),
'håndslaga': ('håndslag',),
'håndslagene': ('håndslag',),
'håndslaget': ('håndslag',),
'håndslokkingsapparat': ('håndslokkingsapparat',),
'håndslokkingsapparata': ('håndslokkingsapparat',),
'håndslokkingsapparatene': ('håndslokkingsapparat',),
'håndslokkingsapparater': ('håndslokkingsapparat',),
'håndslokkingsapparatet': ('håndslokkingsapparat',),
'håndslokningsapparat': ('håndslokningsapparat',),
'håndslokningsapparata': ('håndslokningsapparat',),
'håndslokningsapparatene': ('håndslokningsapparat',),
'håndslokningsapparater': ('håndslokningsapparat',),
'håndslokningsapparatet': ('håndslokningsapparat',),
'håndslukkingsapparat': ('håndslukkingsapparat',),
'håndslukkingsapparata': ('håndslukkingsapparat',),
'håndslukkingsapparatene': ('håndslukkingsapparat',),
'håndslukkingsapparater': ('håndslukkingsapparat',),
'håndslukkingsapparatet': ('håndslukkingsapparat',),
'håndslukningsapparat': ('håndslukningsapparat',),
'håndslukningsapparata': ('håndslukningsapparat',),
'håndslukningsapparatene': ('håndslukningsapparat',),
'håndslukningsapparater': ('håndslukningsapparat',),
'håndslukningsapparatet': ('håndslukningsapparat',),
'håndsnøra': ('håndsnøre',),
'håndsnøre': ('håndsnøre',),
'håndsnørene': ('håndsnøre',),
'håndsnører': ('håndsnøre',),
'håndsnøret': ('håndsnøre',),
'håndsopprekking': ('håndsopprekking',),
'håndsopprekkinga': ('håndsopprekking',),
'håndsopprekkingen': ('håndsopprekking',),
'håndsopprekkingene': ('håndsopprekking',),
'håndsopprekkinger': ('håndsopprekking',),
'håndsopprekning': ('håndsopprekning',),
'håndsopprekninga': ('håndsopprekning',),
'håndsopprekningen': ('håndsopprekning',),
'håndsopprekningene': ('håndsopprekning',),
'håndsopprekninger': ('håndsopprekning',),
'håndspåleggelse': ('håndspåleggelse',),
'håndspåleggelsen': ('håndspåleggelse',),
'håndspåleggelsene': ('håndspåleggelse',),
'håndspåleggelser': ('håndspåleggelse',),
'håndspålegging': ('håndspålegging',),
'håndspålegginga': ('håndspålegging',),
'håndspåleggingen': ('håndspålegging',),
'håndspåleggingene': ('håndspålegging',),
'håndspålegginger': ('håndspålegging',),
'håndsrekning': ('håndsrekning',),
'håndsrekninga': ('håndsrekning',),
'håndsrekningen': ('håndsrekning',),
'håndsrekningene': ('håndsrekning',),
'håndsrekninger': ('håndsrekning',),
'håndsrett': ('håndsrett',),
'håndsretten': ('håndsrett',),
'håndsrettene': ('håndsrett',),
'håndsretter': ('håndsrett',),
'håndtak': ('håndtak',),
'håndtaka': ('håndtak',),
'håndtakene': ('håndtak',),
'håndtaket': ('håndtak',),
'håndtein': ('håndtein',),
'håndteinen': ('håndtein',),
'håndteinene': ('håndtein',),
'håndteiner': ('håndtein',),
'håndtering': ('håndtering',),
'håndteringa': ('håndtering',),
'håndteringen': ('håndtering',),
'håndteringene': ('håndtering',),
'håndteringer': ('håndtering',),
'håndtrykk': ('håndtrykk',),
'håndtrykka': ('håndtrykk',),
'håndtrykkene': ('håndtrykk',),
'håndtrykket': ('håndtrykk',),
'håndvask': ('håndvask',),
'håndvasken': ('håndvask',),
'håndvaskene': ('håndvask',),
'håndvasker': ('håndvask',),
'håndvekt': ('håndvekt',),
'håndvekta': ('håndvekt',),
'håndvekten': ('håndvekt',),
'håndvektene': ('håndvekt',),
'håndvekter': ('håndvekt',),
'håndvending': ('håndvending',),
'håndvendinga': ('håndvending',),
'håndvendingen': ('håndvending',),
'håndvendingene': ('håndvending',),
'håndvendinger': ('håndvending',),
'håndverk': ('håndverk',),
'håndverka': ('håndverk',),
'håndverkene': ('håndverk',),
'håndverket': ('håndverk',),
'håndverker': ('håndverker',),
'håndverkere': ('håndverker',),
'håndverkeren': ('håndverker',),
'håndverkerer': ('håndverker',),
'håndverkerne': ('håndverker',),
'håndverkerforening': ('håndverkerforening',),
'håndverkerforeninga': ('håndverkerforening',),
'håndverkerforeningen': ('håndverkerforening',),
'håndverkerforeningene': ('håndverkerforening',),
'håndverkerforeninger': ('håndverkerforening',),
'håndverkerlaug': ('håndverkerlaug',),
'håndverkerlauga': ('håndverkerlaug',),
'håndverkerlaugene': ('håndverkerlaug',),
'håndverkerlauget': ('håndverkerlaug',),
'håndverkerlæra': ('håndverkerlære',),
'håndverkerlære': ('håndverkerlære',),
'håndverkerlæren': ('håndverkerlære',),
'håndverkerlærene': ('håndverkerlære',),
'håndverkerlærer': ('håndverkerlære',),
'håndverkerlærling': ('håndverkerlærling',),
'håndverkerlærlingen': ('håndverkerlærling',),
'håndverkerlærlingene': ('håndverkerlærling',),
'håndverkerlærlinger': ('håndverkerlærling',),
'håndverkersvenn': ('håndverkersvenn',),
'håndverkersvennen': ('håndverkersvenn',),
'håndverkersvennene': ('håndverkersvenn',),
'håndverkersvenner': ('håndverkersvenn',),
'håndverksbrev': ('håndverksbrev',),
'håndverksbreva': ('håndverksbrev',),
'håndverksbrevene': ('håndverksbrev',),
'håndverksbrever': ('håndverksbrev',),
'håndverksbrevet': ('håndverksbrev',),
'håndverkslaug': ('håndverkslaug',),
'håndverkslauga': ('håndverkslaug',),
'håndverkslaugene': ('håndverkslaug',),
'håndverkslauget': ('håndverkslaug',),
'håndverkslærling': ('håndverkslærling',),
'håndverkslærlingen': ('håndverkslærling',),
'håndverkslærlingene': ('håndverkslærling',),
'håndverkslærlinger': ('håndverkslærling',),
'håndverksmester': ('håndverksmester',),
'håndverksmestere': ('håndverksmester',),
'håndverksmesteren': ('håndverksmester',),
'håndverksmesterer': ('håndverksmester',),
'håndverksmesterne': ('håndverksmester',),
'håndverksmestre': ('håndverksmester',),
'håndverksmestrene': ('håndverksmester',),
'håndverksmestrer': ('håndverksmester',),
'håndverkssvenn': ('håndverkssvenn',),
'håndverkssvennen': ('håndverkssvenn',),
'håndverkssvennene': ('håndverkssvenn',),
'håndverkssvenner': ('håndverkssvenn',),
'håndveska': ('håndveske',),
'håndveske': ('håndveske',),
'håndvesken': ('håndveske',),
'håndveskene': ('håndveske',),
'håndvesker': ('håndveske',),
'håndvåpen': ('håndvåpen',),
'håndvåpenet': ('håndvåpen',),
'håndvåpna': ('håndvåpen',),
'håndvåpnene': ('håndvåpen',),
'hånflir': ('hånflir',),
'hånflira': ('hånflir',),
'hånfliren': ('hånflir',),
'hånflirene': ('hånflir',),
'hånfliret': ('hånflir',),
'hånlatrene': ('hånlatter',),
'hånlatrer': ('hånlatter',),
'hånlatter': ('hånlatter',),
'hånlattere': ('hånlatter',),
'hånlatteren': ('hånlatter',),
'hånlatterer': ('hånlatter',),
'hånlatterne': ('hånlatter',),
'hånsord': ('hånsord',),
'hånsorda': ('hånsord',),
'hånsordene': ('hånsord',),
'hånsordet': ('hånsord',),
'håp': ('håp',),
'håpa': ('håp',),
'håpene': ('håp',),
'håpet': ('håp',),
'håpløshet': ('håpløshet',),
'håpløsheta': ('håpløshet',),
'håpløsheten': ('håpløshet',),
'håpløshetene': ('håpløshet',),
'håpløsheter': ('håpløshet',),
'hår': ('hår',),
'håra': ('hår',),
'hårene': ('hår',),
'håret': ('hår',),
'hårbolle': ('hårbolle',),
'hårbollen': ('hårbolle',),
'hårbollene': ('hårbolle',),
'hårboller': ('hårbolle',),
'hårfelling': ('hårfelling',),
'hårfellinga': ('hårfelling',),
'hårfellingen': ('hårfelling',),
'hårfellingene': ('hårfelling',),
'hårfellinger': ('hårfelling',),
'hårfesta': ('hårfeste',),
'hårfeste': ('hårfeste',),
'hårfestene': ('hårfeste',),
'hårfester': ('hårfeste',),
'hårfestet': ('hårfeste',),
'hårkar': ('hårkar',),
'hårkara': ('hårkar',),
'hårkarene': ('hårkar',),
'hårkaret': ('hårkar',),
'hårklipp': ('hårklipp',),
'hårklippen': ('hårklipp',),
'hårklippene': ('hårklipp',),
'hårklipper': ('hårklipp',),
'hårkløveri': ('hårkløveri',),
'hårkløveria': ('hårkløveri',),
'hårkløveriene': ('hårkløveri',),
'hårkløverier': ('hårkløveri',),
'hårkløveriet': ('hårkløveri',),
'hårkløyver': ('hårkløyver',),
'hårkløyvere': ('hårkløyver',),
'hårkløyveren': ('hårkløyver',),
'hårkløyverer': ('hårkløyver',),
'hårkløyverne': ('hårkløyver',),
'hårkløyveri': ('hårkløyveri',),
'hårkløyveria': ('hårkløyveri',),
'hårkløyveriene': ('hårkløyveri',),
'hårkløyverier': ('hårkløyveri',),
'hårkløyveriet': ('hårkløyveri',),
'hårknute': ('hårknute',),
'hårknuten': ('hårknute',),
'hårknutene': ('hårknute',),
'hårknuter': ('hårknute',),
'hårlakk': ('hårlakk',),
'hårlakken': ('hårlakk',),
'hårlakkene': ('hårlakk',),
'hårlakker': ('hårlakk',),
'hårlokk': ('hårlokk',),
'hårlokken': ('hårlokk',),
'hårlokkene': ('hårlokk',),
'hårlokker': ('hårlokk',),
'hårlugg': ('hårlugg',),
'hårluggen': ('hårlugg',),
'hårluggene': ('hårlugg',),
'hårlugger': ('hårlugg',),
'hårnålssving': ('hårnålssving',),
'hårnålssvingen': ('hårnålssving',),
'hårnålssvingene': ('hårnålssving',),
'hårnålssvinger': ('hårnålssving',),
'hårpisk': ('hårpisk',),
'hårpisken': ('hårpisk',),
'hårpiskene': ('hårpisk',),
'hårpisker': ('hårpisk',),
'hårrør': ('hårrør',),
'hårrøra': ('hårrør',),
'hårrørene': ('hårrør',),
'hårrøret': ('hårrør',),
'hårrørsvirkning': ('hårrørsvirkning',),
'hårrørsvirkninga': ('hårrørsvirkning',),
'hårrørsvirkningen': ('hårrørsvirkning',),
'hårrørsvirkningene': ('hårrørsvirkning',),
'hårrørsvirkninger': ('hårrørsvirkning',),
'hårrørsåra': ('hårrørsåre',),
'hårrørsåre': ('hårrørsåre',),
'hårrørsåren': ('hårrørsåre',),
'hårrørsårene': ('hårrørsåre',),
'hårrørsårer': ('hårrørsåre',),
'hårsbredd': ('hårsbredd',),
'hårsbredden': ('hårsbredd',),
'hårsbreddene': ('hårsbredd',),
'hårsbredder': ('hårsbredd',),
'hårsekk': ('hårsekk',),
'hårsekken': ('hårsekk',),
'hårsekkene': ('hårsekk',),
'hårsekker': ('hårsekk',),
'hårskjede': ('hårskjede',),
'hårskjeden': ('hårskjede',),
'hårskjedene': ('hårskjede',),
'hårskjeder': ('hårskjede',),
'hårspray': ('hårspray',),
'hårsprayen': ('hårspray',),
'hårsprayene': ('hårspray',),
'hårsprayer': ('hårspray',),
'hårstrå': ('hårstrå',),
'hårstråa': ('hårstrå',),
'hårstråene': ('hårstrå',),
'hårstrået': ('hårstrå',),
'hårtørkeapparat': ('hårtørkeapparat',),
'hårtørkeapparata': ('hårtørkeapparat',),
'hårtørkeapparatene': ('hårtørkeapparat',),
'hårtørkeapparater': ('hårtørkeapparat',),
'hårtørkeapparatet': ('hårtørkeapparat',),
'hårtørkehjelm': ('hårtørkehjelm',),
'hårtørkehjelmen': ('hårtørkehjelm',),
'hårtørkehjelmene': ('hårtørkehjelm',),
'hårtørkehjelmer': ('hårtørkehjelm',),
'hårtørker': ('hårtørker',),
'hårtørkere': ('hårtørker',),
'hårtørkeren': ('hårtørker',),
'hårtørkerer': ('hårtørker',),
'hårtørkerne': ('hårtørker',),
'hårtørreapparat': ('hårtørreapparat',),
'hårtørreapparata': ('hårtørreapparat',),
'hårtørreapparatene': ('hårtørreapparat',),
'hårtørreapparater': ('hårtørreapparat',),
'hårtørreapparatet': ('hårtørreapparat',),
'hårtørrehjelm': ('hårtørrehjelm',),
'hårtørrehjelmen': ('hårtørrehjelm',),
'hårtørrehjelmene': ('hårtørrehjelm',),
'hårtørrehjelmer': ('hårtørrehjelm',),
'hårtørrer': ('hårtørrer',),
'hårtørrere': ('hårtørrer',),
'hårtørreren': ('hårtørrer',),
'hårtørrerer': ('hårtørrer',),
'hårtørrerne': ('hårtørrer',),
'hårvann': ('hårvann',),
'hårvanna': ('hårvann',),
'hårvannene': ('hårvann',),
'hårvannet': ('hårvann',),
'hårvatn': ('hårvatn',),
'hårvatna': ('hårvatn',),
'hårvatnene': ('hårvatn',),
'hårvatnet': ('hårvatn',),
'hårvekst': ('hårvekst',),
'hårveksten': ('hårvekst',),
'hårvekstene': ('hårvekst',),
'hårvekster': ('hårvekst',),
'håshet': ('håshet',),
'håsheta': ('håshet',),
'håsheten': ('håshet',),
'håshetene': ('håshet',),
'håsheter': ('håshet',),
'håslått': ('håslått',),
'håslåtten': ('håslått',),
'håslåttene': ('håslått',),
'håslåtter': ('håslått',),
'hått': ('hått',),
'håtten': ('hått',),
'håttene': ('hått',),
'håtter': ('hått',),
'håv': ('håv',),
'håven': ('håv',),
'håvene': ('håv',),
'håver': ('håv',),
'hæl': ('hæl',),
'hælen': ('hæl',),
'hælene': ('hæl',),
'hæler': ('hæl',),
'hæljern': ('hæljern',),
'hæljerna': ('hæljern',),
'hæljernene': ('hæljern',),
'hæljernet': ('hæljern',),
'hælkappa': ('hælkappe',),
'hælkappe': ('hælkappe',),
'hælkappen': ('hælkappe',),
'hælkappene': ('hælkappe',),
'hælkapper': ('hælkappe',),
'hælspark': ('hælspark',),
'hælsparka': ('hælspark',),
'hælsparkene': ('hælspark',),
'hælsparket': ('hælspark',),
'hær': ('hær',),
'hæren': ('hær',),
'hærene': ('hær',),
'hærer': ('hær',),
'hærferd': ('hærferd',),
'hærferda': ('hærferd',),
'hærferden': ('hærferd',),
'hærferdene': ('hærferd',),
'hærferder': ('hærferd',),
'hærfører': ('hærfører',),
'hærførere': ('hærfører',),
'hærføreren': ('hærfører',),
'hærførerer': ('hærfører',),
'hærførerne': ('hærfører',),
'hærmerka': ('hærmerke',),
'hærmerke': ('hærmerke',),
'hærmerkene': ('hærmerke',),
'hærmerker': ('hærmerke',),
'hærmerket': ('hærmerke',),
'hærskare': ('hærskare',),
'hærskaren': ('hærskare',),
'hærskarene': ('hærskare',),
'hærskarer': ('hærskare',),
'hærverk': ('hærverk',),
'hærverka': ('hærverk',),
'hærverkene': ('hærverk',),
'hærverker': ('hærverk',),
'hærverket': ('hærverk',),
'hø': ('hø',),
'høa': ('hø',),
'høen': ('hø',),
'høene': ('hø',),
'høer': ('hø',),
'høflighet': ('høflighet',),
'høfligheta': ('høflighet',),
'høfligheten': ('høflighet',),
'høflighetene': ('høflighet',),
'høfligheter': ('høflighet',),
'høflighetsfrase': ('høflighetsfrase',),
'høflighetsfrasen': ('høflighetsfrase',),
'høflighetsfrasene': ('høflighetsfrase',),
'høflighetsfraser': ('høflighetsfrase',),
'høflighetsvisitt': ('høflighetsvisitt',),
'høflighetsvisitten': ('høflighetsvisitt',),
'høflighetsvisittene': ('høflighetsvisitt',),
'høflighetsvisitter': ('høflighetsvisitt',),
'høgadel': ('høgadel',),
'høgadelen': ('høgadel',),
'høgadlene': ('høgadel',),
'høgadler': ('høgadel',),
'høgblad': ('høgblad',),
'høgblada': ('høgblad',),
'høgbladene': ('høgblad',),
'høgblader': ('høgblad',),
'høgbladet': ('høgblad',),
'høgblokk': ('høgblokk',),
'høgblokka': ('høgblokk',),
'høgblokken': ('høgblokk',),
'høgblokkene': ('høgblokk',),
'høgblokker': ('høgblokk',),
'høgborg': ('høgborg',),
'høgborga': ('høgborg',),
'høgborgen': ('høgborg',),
'høgborgene': ('høgborg',),
'høgborger': ('høgborg',),
'høgbygg': ('høgbygg',),
'høgbygga': ('høgbygg',),
'høgbyggene': ('høgbygg',),
'høgbygget': ('høgbygg',),
'høgd': ('høgd',),
'høgda': ('høgd',),
'høgden': ('høgd',),
'høgdene': ('høgd',),
'høgder': ('høgd',),
'høgd': ('høgd',),
'høgda': ('høgd',),
'høgden': ('høgd',),
'høgdene': ('høgd',),
'høgder': ('høgd',),
'høgd': ('høgd',),
'høgda': ('høgd',),
'høgden': ('høgd',),
'høgdene': ('høgd',),
'høgder': ('høgd',),
'høgda': ('høgde',),
'høgde': ('høgde',),
'høgden': ('høgde',),
'høgdene': ('høgde',),
'høgder': ('høgde',),
'høgdebasseng': ('høgdebasseng',),
'høgdebassenga': ('høgdebasseng',),
'høgdebassengene': ('høgdebasseng',),
'høgdebassenger': ('høgdebasseng',),
'høgdebassenget': ('høgdebasseng',),
'høgdedrag': ('høgdedrag',),
'høgdedraga': ('høgdedrag',),
'høgdedragene': ('høgdedrag',),
'høgdedraget': ('høgdedrag',),
'høgdehopp': ('høgdehopp',),
'høgdehoppa': ('høgdehopp',),
'høgdehoppene': ('høgdehopp',),
'høgdehoppet': ('høgdehopp',),
'høgdemåler': ('høgdemåler',),
'høgdemålere': ('høgdemåler',),
'høgdemåleren': ('høgdemåler',),
'høgdemålerer': ('høgdemåler',),
'høgdemålerne': ('høgdemåler',),
'høgdepunkt': ('høgdepunkt',),
'høgdepunkta': ('høgdepunkt',),
'høgdepunktene': ('høgdepunkt',),
'høgdepunkter': ('høgdepunkt',),
'høgdepunktet': ('høgdepunkt',),
'høgderor': ('høgderor',),
'høgderora': ('høgderor',),
'høgderorene': ('høgderor',),
'høgderoret': ('høgderor',),
'høgdesjuka': ('høgdesjuke',),
'høgdesjuke': ('høgdesjuke',),
'høgdesjuken': ('høgdesjuke',),
'høgdesjukene': ('høgdesjuke',),
'høgdesjuker': ('høgdesjuke',),
'høgdeskrekk': ('høgdeskrekk',),
'høgdeskrekken': ('høgdeskrekk',),
'høgdeskrekkene': ('høgdeskrekk',),
'høgdeskrekker': ('høgdeskrekk',),
'høgdesyka': ('høgdesyke',),
'høgdesyke': ('høgdesyke',),
'høgdesyken': ('høgdesyke',),
'høgdesykene': ('høgdesyke',),
'høgdesyker': ('høgdesyke',),
'høgfjell': ('høgfjell',),
'høgfjella': ('høgfjell',),
'høgfjellene': ('høgfjell',),
'høgfjellet': ('høgfjell',),
'høgfjellssol': ('høgfjellssol',),
'høgfjellssola': ('høgfjellssol',),
'høgfjellssolen': ('høgfjellssol',),
'høgfjellssolene': ('høgfjellssol',),
'høgfjellssoler': ('høgfjellssol',),
'høgforræderi': ('høgforræderi',),
'høgforræderia': ('høgforræderi',),
'høgforræderiene': ('høgforræderi',),
'høgforræderier': ('høgforræderi',),
'høgforræderiet': ('høgforræderi',),
'høgfrekvens': ('høgfrekvens',),
'høgfrekvensen': ('høgfrekvens',),
'høgfrekvensene': ('høgfrekvens',),
'høgfrekvenser': ('høgfrekvens',),
'høggir': ('høggir',),
'høggira': ('høggir',),
'høggirene': ('høggir',),
'høggiret': ('høggir',),
'høghus': ('høghus',),
'høghusa': ('høghus',),
'høghusene': ('høghus',),
'høghuset': ('høghus',),
'høgkant': ('høgkant',),
'høgkanten': ('høgkant',),
'høgkantene': ('høgkant',),
'høgkanter': ('høgkant',),
'høgkonjunktur': ('høgkonjunktur',),
'høgkonjunkturen': ('høgkonjunktur',),
'høgkonjunkturene': ('høgkonjunktur',),
'høgkonjunkturer': ('høgkonjunktur',),
'høgkostland': ('høgkostland',),
'høgkostlanda': ('høgkostland',),
'høgkostlandene': ('høgkostland',),
'høgkostlandet': ('høgkostland',),
'høgland': ('høgland',),
'høglanda': ('høgland',),
'høglandene': ('høgland',),
'høglandet': ('høgland',),
'høglender': ('høglender',),
'høglendere': ('høglender',),
'høglenderen': ('høglender',),
'høglenderer': ('høglender',),
'høglenderne': ('høglender',),
'høglending': ('høglending',),
'høglendingen': ('høglending',),
'høglendingene': ('høglending',),
'høglendinger': ('høglending',),
'høglytt': ('høglytt',),
'høglytten': ('høglytt',),
'høglyttene': ('høglytt',),
'høglytter': ('høglytt',),
'høglønnsgruppa': ('høglønnsgruppe',),
'høglønnsgruppe': ('høglønnsgruppe',),
'høglønnsgruppen': ('høglønnsgruppe',),
'høglønnsgruppene': ('høglønnsgruppe',),
'høglønnsgrupper': ('høglønnsgruppe',),
'høglønnsyrka': ('høglønnsyrke',),
'høglønnsyrke': ('høglønnsyrke',),
'høglønnsyrkene': ('høglønnsyrke',),
'høglønnsyrker': ('høglønnsyrke',),
'høglønnsyrket': ('høglønnsyrke',),
'høgmessa': ('høgmesse',),
'høgmesse': ('høgmesse',),
'høgmessen': ('høgmesse',),
'høgmessene': ('høgmesse',),
'høgmesser': ('høgmesse',),
'høgnivåspråk': ('høgnivåspråk',),
'høgnivåspråka': ('høgnivåspråk',),
'høgnivåspråkene': ('høgnivåspråk',),
'høgnivåspråket': ('høgnivåspråk',),
'høgoktan': ('høgoktan',),
'høgoktanen': ('høgoktan',),
'høgoktanene': ('høgoktan',),
'høgoktaner': ('høgoktan',),
'høgoktan': ('høgoktan',),
'høgoktana': ('høgoktan',),
'høgoktanene': ('høgoktan',),
'høgoktaner': ('høgoktan',),
'høgoktanet': ('høgoktan',),
'høgoktanbensin': ('høgoktanbensin',),
'høgoktanbensinen': ('høgoktanbensin',),
'høgoktanbensinene': ('høgoktanbensin',),
'høgoktanbensiner': ('høgoktanbensin',),
'høgprosa': ('høgprosa',),
'høgprosaen': ('høgprosa',),
'høgprosaene': ('høgprosa',),
'høgprosaer': ('høgprosa',),
'høgre': ('høgre',),
'høgrearm': ('høgrearm',),
'høgrearmen': ('høgrearm',),
'høgrearmene': ('høgrearm',),
'høgrearmer': ('høgrearm',),
'høgreavis': ('høgreavis',),
'høgreavisa': ('høgreavis',),
'høgreavisen': ('høgreavis',),
'høgreavisene': ('høgreavis',),
'høgreaviser': ('høgreavis',),
'høgrebein': ('høgrebein',),
'høgrebeina': ('høgrebein',),
'høgrebeinene': ('høgrebein',),
'høgrebeinet': ('høgrebein',),
'høgreben': ('høgreben',),
'høgrebena': ('høgreben',),
'høgrebenene': ('høgreben',),
'høgrebenet': ('høgreben',),
'høgrebølga': ('høgrebølge',),
'høgrebølge': ('høgrebølge',),
'høgrebølgen': ('høgrebølge',),
'høgrebølgene': ('høgrebølge',),
'høgrebølger': ('høgrebølge',),
'høgrebølgja': ('høgrebølgje',),
'høgrebølgje': ('høgrebølgje',),
'høgrebølgjen': ('høgrebølgje',),
'høgrebølgjene': ('høgrebølgje',),
'høgrebølgjer': ('høgrebølgje',),
'høgredreiing': ('høgredreiing',),
'høgredreiinga': ('høgredreiing',),
'høgredreiingen': ('høgredreiing',),
'høgredreiingene': ('høgredreiing',),
'høgredreiinger': ('høgredreiing',),
'høgredreining': ('høgredreining',),
'høgredreininga': ('høgredreining',),
'høgredreiningen': ('høgredreining',),
'høgredreiningene': ('høgredreining',),
'høgredreininger': ('høgredreining',),
'høgreekstremist': ('høgreekstremist',),
'høgreekstremisten': ('høgreekstremist',),
'høgreekstremistene': ('høgreekstremist',),
'høgreekstremister': ('høgreekstremist',),
'høgrefløy': ('høgrefløy',),
'høgrefløya': ('høgrefløy',),
'høgrefløyen': ('høgrefløy',),
'høgrefløyene': ('høgrefløy',),
'høgrefløyer': ('høgrefløy',),
'høgrekvinna': ('høgrekvinne',),
'høgrekvinne': ('høgrekvinne',),
'høgrekvinnen': ('høgrekvinne',),
'høgrekvinnene': ('høgrekvinne',),
'høgrekvinner': ('høgrekvinne',),
'høgremann': ('høgremann',),
'høgremannen': ('høgremann',),
'høgremenn': ('høgremann',),
'høgremennene': ('høgremann',),
'høgrepolitikk': ('høgrepolitikk',),
'høgrepolitikken': ('høgrepolitikk',),
'høgrepolitikkene': ('høgrepolitikk',),
'høgrepolitikker': ('høgrepolitikk',),
'høgresida': ('høgreside',),
'høgreside': ('høgreside',),
'høgresiden': ('høgreside',),
'høgresidene': ('høgreside',),
'høgresider': ('høgreside',),
'høgreving': ('høgreving',),
'høgrevingen': ('høgreving',),
'høgrevingene': ('høgreving',),
'høgrevinger': ('høgreving',),
'høgrygg': ('høgrygg',),
'høgryggen': ('høgrygg',),
'høgryggene': ('høgrygg',),
'høgrygger': ('høgrygg',),
'høgsang': ('høgsang',),
'høgsangen': ('høgsang',),
'høgsangene': ('høgsang',),
'høgsanger': ('høgsang',),
'høgsesong': ('høgsesong',),
'høgsesongen': ('høgsesong',),
'høgsesongene': ('høgsesong',),
'høgsesonger': ('høgsesong',),
'høgseta': ('høgsete',),
'høgsete': ('høgsete',),
'høgsetene': ('høgsete',),
'høgseter': ('høgsete',),
'høgsetet': ('høgsete',),
'høgskole': ('høgskole',),
'høgskolen': ('høgskole',),
'høgskolene': ('høgskole',),
'høgskoler': ('høgskole',),
'høgsommer': ('høgsommer',),
'høgsommere': ('høgsommer',),
'høgsommeren': ('høgsommer',),
'høgsommerne': ('høgsommer',),
'høgsomre': ('høgsommer',),
'høgsomrene': ('høgsommer',),
'høgsomrer': ('høgsommer',),
'høgspenning': ('høgspenning',),
'høgspenninga': ('høgspenning',),
'høgspenningen': ('høgspenning',),
'høgspenningene': ('høgspenning',),
'høgspenninger': ('høgspenning',),
'høgspentledning': ('høgspentledning',),
'høgspentledninga': ('høgspentledning',),
'høgspentledningen': ('høgspentledning',),
'høgspentledningene': ('høgspentledning',),
'høgspentledninger': ('høgspentledning',),
'høgspentmast': ('høgspentmast',),
'høgspentmasta': ('høgspentmast',),
'høgspentmasten': ('høgspentmast',),
'høgspentmastene': ('høgspentmast',),
'høgspentmaster': ('høgspentmast',),
'høgstatusyrka': ('høgstatusyrke',),
'høgstatusyrke': ('høgstatusyrke',),
'høgstatusyrkene': ('høgstatusyrke',),
'høgstatusyrker': ('høgstatusyrke',),
'høgstatusyrket': ('høgstatusyrke',),
'høgsterett': ('høgsterett',),
'høgsteretten': ('høgsterett',),
'høgsterettene': ('høgsterett',),
'høgsteretter': ('høgsterett',),
'høgsterettsadvokat': ('høgsterettsadvokat',),
'høgsterettsadvokaten': ('høgsterettsadvokat',),
'høgsterettsadvokatene': ('høgsterettsadvokat',),
'høgsterettsadvokater': ('høgsterettsadvokat',),
'høgsterettsjustitiarien': ('høgsterettsjustitiarius',),
'høgsterettsjustitiariene': ('høgsterettsjustitiarius',),
'høgsterettsjustitiarier': ('høgsterettsjustitiarius',),
'høgsterettsjustitiarius': ('høgsterettsjustitiarius',),
'høgtaler': ('høgtaler',),
'høgtalere': ('høgtaler',),
'høgtaleren': ('høgtaler',),
'høgtalerer': ('høgtaler',),
'høgtalerne': ('høgtaler',),
'høgtaleranlegg': ('høgtaleranlegg',),
'høgtaleranlegga': ('høgtaleranlegg',),
'høgtaleranleggene': ('høgtaleranlegg',),
'høgtaleranlegget': ('høgtaleranlegg',),
'høgtid': ('høgtid',),
'høgtida': ('høgtid',),
'høgtiden': ('høgtid',),
'høgtidene': ('høgtid',),
'høgtider': ('høgtid',),
'høgtidelighet': ('høgtidelighet',),
'høgtideligheta': ('høgtidelighet',),
'høgtideligheten': ('høgtidelighet',),
'høgtidelighetene': ('høgtidelighet',),
'høgtideligheter': ('høgtidelighet',),
'høgtidsdag': ('høgtidsdag',),
'høgtidsdagen': ('høgtidsdag',),
'høgtidsdagene': ('høgtidsdag',),
'høgtidsdager': ('høgtidsdag',),
'høgtidsstemning': ('høgtidsstemning',),
'høgtidsstemninga': ('høgtidsstemning',),
'høgtidsstemningen': ('høgtidsstemning',),
'høgtidsstemningene': ('høgtidsstemning',),
'høgtidsstemninger': ('høgtidsstemning',),
'høgtidsstund': ('høgtidsstund',),
'høgtidsstunda': ('høgtidsstund',),
'høgtidsstunden': ('høgtidsstund',),
'høgtidsstundene': ('høgtidsstund',),
'høgtidsstunder': ('høgtidsstund',),
'høgtlesing': ('høgtlesing',),
'høgtlesinga': ('høgtlesing',),
'høgtlesingen': ('høgtlesing',),
'høgtlesingene': ('høgtlesing',),
'høgtlesinger': ('høgtlesing',),
'høgtlesning': ('høgtlesning',),
'høgtlesninga': ('høgtlesning',),
'høgtlesningen': ('høgtlesning',),
'høgtlesningene': ('høgtlesning',),
'høgtlesninger': ('høgtlesning',),
'høgtrykkssprøyta': ('høgtrykkssprøyte',),
'høgtrykkssprøyte': ('høgtrykkssprøyte',),
'høgtrykkssprøyten': ('høgtrykkssprøyte',),
'høgtrykkssprøytene': ('høgtrykkssprøyte',),
'høgtrykkssprøyter': ('høgtrykkssprøyte',),
'høgtrykk': ('høgtrykk',),
'høgtrykka': ('høgtrykk',),
'høgtrykkene': ('høgtrykk',),
'høgtrykket': ('høgtrykk',),
'høgtrykksområda': ('høgtrykksområde',),
'høgtrykksområde': ('høgtrykksområde',),
'høgtrykksområdene': ('høgtrykksområde',),
'høgtrykksområder': ('høgtrykksområde',),
'høgtrykksområdet': ('høgtrykksområde',),
'høgtrykksrygg': ('høgtrykksrygg',),
'høgtrykksryggen': ('høgtrykksrygg',),
'høgtrykksryggene': ('høgtrykksrygg',),
'høgtrykksrygger': ('høgtrykksrygg',),
'høgtrykkssprøyta': ('høgtrykkssprøyte',),
'høgtrykkssprøyte': ('høgtrykkssprøyte',),
'høgtrykkssprøyten': ('høgtrykkssprøyte',),
'høgtrykkssprøytene': ('høgtrykkssprøyte',),
'høgtrykkssprøyter': ('høgtrykkssprøyte',),
'høgtysk': ('høgtysk',),
'høgtysken': ('høgtysk',),
'høgtyskene': ('høgtysk',),
'høgtysker': ('høgtysk',),
'høgvann': ('høgvann',),
'høgvanna': ('høgvann',),
'høgvannene': ('høgvann',),
'høgvannet': ('høgvann',),
'høgvannslinja': ('høgvannslinje',),
'høgvannslinje': ('høgvannslinje',),
'høgvannslinjen': ('høgvannslinje',),
'høgvannslinjene': ('høgvannslinje',),
'høgvannslinjer': ('høgvannslinje',),
'høgvasslinja': ('høgvasslinje',),
'høgvasslinje': ('høgvasslinje',),
'høgvasslinjen': ('høgvasslinje',),
'høgvasslinjene': ('høgvasslinje',),
'høgvasslinjer': ('høgvasslinje',),
'høgvatn': ('høgvatn',),
'høgvatna': ('høgvatn',),
'høgvatnene': ('høgvatn',),
'høgvatnet': ('høgvatn',),
'høgvelbårenhet': ('høgvelbårenhet',),
'høgvelbårenheta': ('høgvelbårenhet',),
'høgvelbårenheten': ('høgvelbårenhet',),
'høgvelbårenhetene': ('høgvelbårenhet',),
'høgvelbårenheter': ('høgvelbårenhet',),
'høker': ('høker',),
'høkere': ('høker',),
'høkeren': ('høker',),
'høkerer': ('høker',),
'høkerne': ('høker',),
'høl': ('høl',),
'hølen': ('høl',),
'hølene': ('høl',),
'høler': ('høl',),
'høljeregn': ('høljeregn',),
'høljeregna': ('høljeregn',),
'høljeregnene': ('høljeregn',),
'høljeregnet': ('høljeregn',),
'høljregn': ('høljregn',),
'høljregna': ('høljregn',),
'høljregnene': ('høljregn',),
'høljregnet': ('høljregn',),
'hølka': ('hølke',),
'hølke': ('hølke',),
'hølkene': ('hølke',),
'hølker': ('hølke',),
'hølket': ('hølke',),
'høna': ('høne',),
'høne': ('høne',),
'hønen': ('høne',),
'hønene': ('høne',),
'høner': ('høne',),
'høneblund': ('høneblund',),
'høneblunden': ('høneblund',),
'høneblundene': ('høneblund',),
'høneblunder': ('høneblund',),
'hønekjukling': ('hønekjukling',),
'hønekjuklingen': ('hønekjukling',),
'hønekjuklingene': ('hønekjukling',),
'hønekjuklinger': ('hønekjukling',),
'hønekylling': ('hønekylling',),
'hønekyllingen': ('hønekylling',),
'hønekyllingene': ('hønekylling',),
'hønekyllinger': ('hønekylling',),
'høns': ('høns',),
'hønsa': ('høns',),
'hønsene': ('høns',),
'hønset': ('høns',),
'hønsefugl': ('hønsefugl',),
'hønsefuglen': ('hønsefugl',),
'hønsefuglene': ('hønsefugl',),
'hønsefugler': ('hønsefugl',),
'hønsegard': ('hønsegard',),
'hønsegarden': ('hønsegard',),
'hønsegardene': ('hønsegard',),
'hønsegarder': ('hønsegard',),
'hønsegård': ('hønsegård',),
'hønsegården': ('hønsegård',),
'hønsegårdene': ('hønsegård',),
'hønsegårder': ('hønsegård',),
'hønsehauk': ('hønsehauk',),
'hønsehauken': ('hønsehauk',),
'hønsehaukene': ('hønsehauk',),
'hønsehauker': ('hønsehauk',),
'hønsehjerne': ('hønsehjerne',),
'hønsehjernen': ('hønsehjerne',),
'hønsehjernene': ('hønsehjerne',),
'hønsehjerner': ('hønsehjerne',),
'hønsenetting': ('hønsenetting',),
'hønsenettingen': ('hønsenetting',),
'hønsenettingene': ('hønsenetting',),
'hønsenettinger': ('hønsenetting',),
'hønseri': ('hønseri',),
'hønseria': ('hønseri',),
'hønseriene': ('hønseri',),
'hønserier': ('hønseri',),
'hønseriet': ('hønseri',),
'hønsestige': ('hønsestige',),
'hønsestigen': ('hønsestige',),
'hønsestigene': ('hønsestige',),
'hønsestiger': ('hønsestige',),
'hør': ('hør',),
'høreapparat': ('høreapparat',),
'høreapparata': ('høreapparat',),
'høreapparatene': ('høreapparat',),
'høreapparater': ('høreapparat',),
'høreapparatet': ('høreapparat',),
'hørebrilla': ('hørebrille',),
'hørebrille': ('hørebrille',),
'hørebrillen': ('hørebrille',),
'hørebrillene': ('hørebrille',),
'hørebriller': ('hørebrille',),
'hørenerve': ('hørenerve',),
'hørenerven': ('hørenerve',),
'hørenervene': ('hørenerve',),
'hørenerver': ('hørenerve',),
'hørerør': ('hørerør',),
'hørerøra': ('hørerør',),
'hørerørene': ('hørerør',),
'hørerøret': ('hørerør',),
'høresans': ('høresans',),
'høresansen': ('høresans',),
'høresansene': ('høresans',),
'høresanser': ('høresans',),
'hørespell': ('hørespell',),
'hørespella': ('hørespell',),
'hørespellene': ('hørespell',),
'hørespellet': ('hørespell',),
'hørespill': ('hørespill',),
'hørespilla': ('hørespill',),
'hørespillene': ('hørespill',),
'hørespillet': ('hørespill',),
'høretelefon': ('høretelefon',),
'høretelefonen': ('høretelefon',),
'høretelefonene': ('høretelefon',),
'høretelefoner': ('høretelefon',),
'hørevidda': ('hørevidde',),
'hørevidde': ('hørevidde',),
'hørevidden': ('hørevidde',),
'høreviddene': ('hørevidde',),
'hørevidder': ('hørevidde',),
'høring': ('høring',),
'høringen': ('høring',),
'høringene': ('høring',),
'høringer': ('høring',),
'hørkløver': ('hørkløver',),
'hørkløvere': ('hørkløver',),
'hørkløveren': ('hørkløver',),
'hørkløverer': ('hørkløver',),
'hørkløverne': ('hørkløver',),
'hørsel': ('hørsel',),
'hørselen': ('hørsel',),
'hørsla': ('hørsel',),
'hørslene': ('hørsel',),
'hørsler': ('hørsel',),
'hørselsevna': ('hørselsevne',),
'hørselsevne': ('hørselsevne',),
'hørselsevnen': ('hørselsevne',),
'hørselsevnene': ('hørselsevne',),
'hørselsevner': ('hørselsevne',),
'hørselsinntrykk': ('hørselsinntrykk',),
'hørselsinntrykka': ('hørselsinntrykk',),
'hørselsinntrykkene': ('hørselsinntrykk',),
'hørselsinntrykket': ('hørselsinntrykk',),
'hørselsnerve': ('hørselsnerve',),
'hørselsnerven': ('hørselsnerve',),
'hørselsnervene': ('hørselsnerve',),
'hørselsnerver': ('hørselsnerve',),
'hørselssans': ('hørselssans',),
'hørselssansen': ('hørselssans',),
'hørselssansene': ('hørselssans',),
'hørselssanser': ('hørselssans',),
'hørselssentra': ('hørselssentrum',),
'hørselssentraene': ('hørselssentrum',),
'hørselssentre': ('hørselssentrum',),
'hørselssentrene': ('hørselssentrum',),
'hørselssentret': ('hørselssentrum',),
'hørselssentrum': ('hørselssentrum',),
'hørselssentrumet': ('hørselssentrum',),
'hørselsskade': ('hørselsskade',),
'hørselsskaden': ('hørselsskade',),
'hørselsskadene': ('hørselsskade',),
'hørselsskader': ('hørselsskade',),
'hørselsvern': ('hørselsvern',),
'hørselsverna': ('hørselsvern',),
'hørselsvernene': ('hørselsvern',),
'hørselsvernet': ('hørselsvern',),
'høst': ('høst',),
'høsten': ('høst',),
'høstene': ('høst',),
'høster': ('høst',),
'høster': ('høster',),
'høstere': ('høster',),
'høsteren': ('høster',),
'høsterer': ('høster',),
'høsterne': ('høster',),
'høstfarge': ('høstfarge',),
'høstfargen': ('høstfarge',),
'høstfargene': ('høstfarge',),
'høstfarger': ('høstfarge',),
'høstingsbruk': ('høstingsbruk',),
'høstingsbruka': ('høstingsbruk',),
'høstingsbrukene': ('høstingsbruk',),
'høstingsbruket': ('høstingsbruk',),
'høstjamdøgn': ('høstjamdøgn',),
'høstjamdøgna': ('høstjamdøgn',),
'høstjamdøgnene': ('høstjamdøgn',),
'høstjamdøgnet': ('høstjamdøgn',),
'høstjevndøgn': ('høstjevndøgn',),
'høstjevndøgna': ('høstjevndøgn',),
'høstjevndøgnene': ('høstjevndøgn',),
'høstjevndøgnet': ('høstjevndøgn',),
'høstmåned': ('høstmåned',),
'høstmåneden': ('høstmåned',),
'høstmånedene': ('høstmåned',),
'høstmåneder': ('høstmåned',),
'høstpart': ('høstpart',),
'høstparten': ('høstpart',),
'høstpartene': ('høstpart',),
'høstparter': ('høstpart',),
'høstrug': ('høstrug',),
'høstrugen': ('høstrug',),
'høstrugene': ('høstrug',),
'høstruger': ('høstrug',),
'høststorm': ('høststorm',),
'høststormen': ('høststorm',),
'høststormene': ('høststorm',),
'høststormer': ('høststorm',),
'høsttakkefest': ('høsttakkefest',),
'høsttakkefesten': ('høsttakkefest',),
'høsttakkefestene': ('høsttakkefest',),
'høsttakkefester': ('høsttakkefest',),
'høstull': ('høstull',),
'høstulla': ('høstull',),
'høstullen': ('høstull',),
'høstullene': ('høstull',),
'høstuller': ('høstull',),
'høvding': ('høvding',),
'høvdingen': ('høvding',),
'høvdingene': ('høvding',),
'høvdinger': ('høvding',),
'høvdingemna': ('høvdingemne',),
'høvdingemne': ('høvdingemne',),
'høvdingemnene': ('høvdingemne',),
'høvdingemner': ('høvdingemne',),
'høvdingemnet': ('høvdingemne',),
'høvdingskikkelse': ('høvdingskikkelse',),
'høvdingskikkelsen': ('høvdingskikkelse',),
'høvdingskikkelsene': ('høvdingskikkelse',),
'høvdingskikkelser': ('høvdingskikkelse',),
'høvdingætt': ('høvdingætt',),
'høvdingætta': ('høvdingætt',),
'høvdingætten': ('høvdingætt',),
'høvdingættene': ('høvdingætt',),
'høvdingætter': ('høvdingætt',),
'høva': ('høve',),
'høve': ('høve',),
'høvene': ('høve',),
'høver': ('høve',),
'høvet': ('høve',),
'høvedsmann': ('høvedsmann',),
'høvedsmannen': ('høvedsmann',),
'høvedsmenn': ('høvedsmann',),
'høvedsmennene': ('høvedsmann',),
'høvel': ('høvel',),
'høvelen': ('høvel',),
'høvlene': ('høvel',),
'høvler': ('høvel',),
'høvelbenk': ('høvelbenk',),
'høvelbenken': ('høvelbenk',),
'høvelbenkene': ('høvelbenk',),
'høvelbenker': ('høvelbenk',),
'høvelmaskin': ('høvelmaskin',),
'høvelmaskina': ('høvelmaskin',),
'høvelmaskinen': ('høvelmaskin',),
'høvelmaskinene': ('høvelmaskin',),
'høvelmaskiner': ('høvelmaskin',),
'høvelspon': ('høvelspon',),
'høvelsponen': ('høvelspon',),
'høvelsponene': ('høvelspon',),
'høvelsponer': ('høvelspon',),
'høvleri': ('høvleri',),
'høvleria': ('høvleri',),
'høvleriene': ('høvleri',),
'høvlerier': ('høvleri',),
'høvleriet': ('høvleri',),
'høy': ('høy',),
'høya': ('høy',),
'høyene': ('høy',),
'høyet': ('høy',),
'høyadel': ('høyadel',),
'høyadelen': ('høyadel',),
'høyadlene': ('høyadel',),
'høyadler': ('høyadel',),
'høyblad': ('høyblad',),
'høyblada': ('høyblad',),
'høybladene': ('høyblad',),
'høyblader': ('høyblad',),
'høybladet': ('høyblad',),
'høyblokk': ('høyblokk',),
'høyblokka': ('høyblokk',),
'høyblokken': ('høyblokk',),
'høyblokkene': ('høyblokk',),
'høyblokker': ('høyblokk',),
'høyborg': ('høyborg',),
'høyborga': ('høyborg',),
'høyborgen': ('høyborg',),
'høyborgene': ('høyborg',),
'høyborger': ('høyborg',),
'høybygg': ('høybygg',),
'høybygga': ('høybygg',),
'høybyggene': ('høybygg',),
'høybygget': ('høybygg',),
'høyde': ('høyde',),
'høyden': ('høyde',),
'høydene': ('høyde',),
'høyder': ('høyde',),
'høyde': ('høyde',),
'høydebasseng': ('høydebasseng',),
'høydebassenga': ('høydebasseng',),
'høydebassengene': ('høydebasseng',),
'høydebassenger': ('høydebasseng',),
'høydebassenget': ('høydebasseng',),
'høydedrag': ('høydedrag',),
'høydedraga': ('høydedrag',),
'høydedragene': ('høydedrag',),
'høydedraget': ('høydedrag',),
'høydehopp': ('høydehopp',),
'høydehoppa': ('høydehopp',),
'høydehoppene': ('høydehopp',),
'høydehoppet': ('høydehopp',),
'høydemåler': ('høydemåler',),
'høydemålere': ('høydemåler',),
'høydemåleren': ('høydemåler',),
'høydemålerer': ('høydemåler',),
'høydemålerne': ('høydemåler',),
'høydepunkt': ('høydepunkt',),
'høydepunkta': ('høydepunkt',),
'høydepunktene': ('høydepunkt',),
'høydepunkter': ('høydepunkt',),
'høydepunktet': ('høydepunkt',),
'høyderor': ('høyderor',),
'høyderora': ('høyderor',),
'høyderorene': ('høyderor',),
'høyderoret': ('høyderor',),
'høydesjuka': ('høydesjuke',),
'høydesjuke': ('høydesjuke',),
'høydesjuken': ('høydesjuke',),
'høydesjukene': ('høydesjuke',),
'høydesjuker': ('høydesjuke',),
'høydeskrekk': ('høydeskrekk',),
'høydeskrekken': ('høydeskrekk',),
'høydeskrekkene': ('høydeskrekk',),
'høydeskrekker': ('høydeskrekk',),
'høydesyka': ('høydesyke',),
'høydesyke': ('høydesyke',),
'høydesyken': ('høydesyke',),
'høydesykene': ('høydesyke',),
'høydesyker': ('høydesyke',),
'høyesterett': ('høyesterett',),
'høyesteretten': ('høyesterett',),
'høyesterettene': ('høyesterett',),
'høyesteretter': ('høyesterett',),
'høyesterettsadvokat': ('høyesterettsadvokat',),
'høyesterettsadvokaten': ('høyesterettsadvokat',),
'høyesterettsadvokatene': ('høyesterettsadvokat',),
'høyesterettsadvokater': ('høyesterettsadvokat',),
'høyesterettsjustitiarien': ('høyesterettsjustitiarius',),
'høyesterettsjustitiariene': ('høyesterettsjustitiarius',),
'høyesterettsjustitiarier': ('høyesterettsjustitiarius',),
'høyesterettsjustitiarius': ('høyesterettsjustitiarius',),
'høyfeber': ('høyfeber',),
'høyfebere': ('høyfeber',),
'høyfeberen': ('høyfeber',),
'høyfeberer': ('høyfeber',),
'høyfeberne': ('høyfeber',),
'høyfebre': ('høyfeber',),
'høyfebrene': ('høyfeber',),
'høyfebrer': ('høyfeber',),
'høyfjell': ('høyfjell',),
'høyfjella': ('høyfjell',),
'høyfjellene': ('høyfjell',),
'høyfjellet': ('høyfjell',),
'høyfjellshotell': ('høyfjellshotell',),
'høyfjellshotella': ('høyfjellshotell',),
'høyfjellshotellene': ('høyfjellshotell',),
'høyfjellshoteller': ('høyfjellshotell',),
'høyfjellshotellet': ('høyfjellshotell',),
'høyfjellssol': ('høyfjellssol',),
'høyfjellssola': ('høyfjellssol',),
'høyfjellssolen': ('høyfjellssol',),
'høyfjellssolene': ('høyfjellssol',),
'høyfjellssoler': ('høyfjellssol',),
'høyforræderi': ('høyforræderi',),
'høyforræderia': ('høyforræderi',),
'høyforræderiene': ('høyforræderi',),
'høyforræderier': ('høyforræderi',),
'høyforræderiet': ('høyforræderi',),
'høyfrekvens': ('høyfrekvens',),
'høyfrekvensen': ('høyfrekvens',),
'høyfrekvensene': ('høyfrekvens',),
'høyfrekvenser': ('høyfrekvens',),
'høygaffel': ('høygaffel',),
'høygaffelen': ('høygaffel',),
'høygaflene': ('høygaffel',),
'høygafler': ('høygaffel',),
'høygir': ('høygir',),
'høygira': ('høygir',),
'høygirene': ('høygir',),
'høygiret': ('høygir',),
'høyhet': ('høyhet',),
'høyheta': ('høyhet',),
'høyheten': ('høyhet',),
'høyhetene': ('høyhet',),
'høyheter': ('høyhet',),
'høyhus': ('høyhus',),
'høyhusa': ('høyhus',),
'høyhusene': ('høyhus',),
'høyhuset': ('høyhus',),
'høykanon': ('høykanon',),
'høykanonen': ('høykanon',),
'høykanonene': ('høykanon',),
'høykanoner': ('høykanon',),
'høykant': ('høykant',),
'høykanten': ('høykant',),
'høykantene': ('høykant',),
'høykanter': ('høykant',),
'høykonjunktur': ('høykonjunktur',),
'høykonjunkturen': ('høykonjunktur',),
'høykonjunkturene': ('høykonjunktur',),
'høykonjunkturer': ('høykonjunktur',),
'høykostland': ('høykostland',),
'høykostlanda': ('høykostland',),
'høykostlandene': ('høykostland',),
'høykostlandet': ('høykostland',),
'høyland': ('høyland',),
'høylanda': ('høyland',),
'høylandene': ('høyland',),
'høylandet': ('høyland',),
'høylender': ('høylender',),
'høylendere': ('høylender',),
'høylenderen': ('høylender',),
'høylenderer': ('høylender',),
'høylenderne': ('høylender',),
'høylending': ('høylending',),
'høylendingen': ('høylending',),
'høylendingene': ('høylending',),
'høylendinger': ('høylending',),
'høylytt': ('høylytt',),
'høylytten': ('høylytt',),
'høylyttene': ('høylytt',),
'høylytter': ('høylytt',),
'høyløa': ('høyløe',),
'høyløe': ('høyløe',),
'høyløen': ('høyløe',),
'høyløene': ('høyløe',),
'høyløer': ('høyløe',),
'høylønnsgruppa': ('høylønnsgruppe',),
'høylønnsgruppe': ('høylønnsgruppe',),
'høylønnsgruppen': ('høylønnsgruppe',),
'høylønnsgruppene': ('høylønnsgruppe',),
'høylønnsgrupper': ('høylønnsgruppe',),
'høylønnsyrka': ('høylønnsyrke',),
'høylønnsyrke': ('høylønnsyrke',),
'høylønnsyrkene': ('høylønnsyrke',),
'høylønnsyrker': ('høylønnsyrke',),
'høylønnsyrket': ('høylønnsyrke',),
'høymessa': ('høymesse',),
'høymesse': ('høymesse',),
'høymessen': ('høymesse',),
'høymessene': ('høymesse',),
'høymesser': ('høymesse',),
'høymo': ('høymo',),
'høymoa': ('høymo',),
'høymoene': ('høymo',),
'høymoet': ('høymo',),
'høynivåspråk': ('høynivåspråk',),
'høynivåspråka': ('høynivåspråk',),
'høynivåspråkene': ('høynivåspråk',),
'høynivåspråket': ('høynivåspråk',),
'høyoktan': ('høyoktan',),
'høyoktanen': ('høyoktan',),
'høyoktanene': ('høyoktan',),
'høyoktaner': ('høyoktan',),
'høyoktan': ('høyoktan',),
'høyoktana': ('høyoktan',),
'høyoktanene': ('høyoktan',),
'høyoktaner': ('høyoktan',),
'høyoktanet': ('høyoktan',),
'høyoktanbensin': ('høyoktanbensin',),
'høyoktanbensinen': ('høyoktanbensin',),
'høyoktanbensinene': ('høyoktanbensin',),
'høyoktanbensiner': ('høyoktanbensin',),
'høypressa': ('høypresse',),
'høypresse': ('høypresse',),
'høypressen': ('høypresse',),
'høypressene': ('høypresse',),
'høypresser': ('høypresse',),
'høyprosa': ('høyprosa',),
'høyprosaen': ('høyprosa',),
'høyprosaene': ('høyprosa',),
'høyprosaer': ('høyprosa',),
'høyre': ('høyre',),
'høyrearm': ('høyrearm',),
'høyrearmen': ('høyrearm',),
'høyrearmene': ('høyrearm',),
'høyrearmer': ('høyrearm',),
'høyreavis': ('høyreavis',),
'høyreavisa': ('høyreavis',),
'høyreavisen': ('høyreavis',),
'høyreavisene': ('høyreavis',),
'høyreaviser': ('høyreavis',),
'høyrebein': ('høyrebein',),
'høyrebeina': ('høyrebein',),
'høyrebeinene': ('høyrebein',),
'høyrebeinet': ('høyrebein',),
'høyreben': ('høyreben',),
'høyrebena': ('høyreben',),
'høyrebenene': ('høyreben',),
'høyrebenet': ('høyreben',),
'høyrebølga': ('høyrebølge',),
'høyrebølge': ('høyrebølge',),
'høyrebølgen': ('høyrebølge',),
'høyrebølgene': ('høyrebølge',),
'høyrebølger': ('høyrebølge',),
'høyrebølgja': ('høyrebølgje',),
'høyrebølgje': ('høyrebølgje',),
'høyrebølgjen': ('høyrebølgje',),
'høyrebølgjene': ('høyrebølgje',),
'høyrebølgjer': ('høyrebølgje',),
'høyredreiing': ('høyredreiing',),
'høyredreiinga': ('høyredreiing',),
'høyredreiingen': ('høyredreiing',),
'høyredreiingene': ('høyredreiing',),
'høyredreiinger': ('høyredreiing',),
'høyredreining': ('høyredreining',),
'høyredreininga': ('høyredreining',),
'høyredreiningen': ('høyredreining',),
'høyredreiningene': ('høyredreining',),
'høyredreininger': ('høyredreining',),
'høyreekstremist': ('høyreekstremist',),
'høyreekstremisten': ('høyreekstremist',),
'høyreekstremistene': ('høyreekstremist',),
'høyreekstremister': ('høyreekstremist',),
'høyrefløy': ('høyrefløy',),
'høyrefløya': ('høyrefløy',),
'høyrefløyen': ('høyrefløy',),
'høyrefløyene': ('høyrefløy',),
'høyrefløyer': ('høyrefløy',),
'høyrekvinna': ('høyrekvinne',),
'høyrekvinne': ('høyrekvinne',),
'høyrekvinnen': ('høyrekvinne',),
'høyrekvinnene': ('høyrekvinne',),
'høyrekvinner': ('høyrekvinne',),
'høyremann': ('høyremann',),
'høyremannen': ('høyremann',),
'høyremenn': ('høyremann',),
'høyremennene': ('høyremann',),
'høyrepolitikk': ('høyrepolitikk',),
'høyrepolitikken': ('høyrepolitikk',),
'høyrepolitikkene': ('høyrepolitikk',),
'høyrepolitikker': ('høyrepolitikk',),
'høyresida': ('høyreside',),
'høyreside': ('høyreside',),
'høyresiden': ('høyreside',),
'høyresidene': ('høyreside',),
'høyresider': ('høyreside',),
'høyreving': ('høyreving',),
'høyrevingen': ('høyreving',),
'høyrevingene': ('høyreving',),
'høyrevinger': ('høyreving',),
'høyrygg': ('høyrygg',),
'høyryggen': ('høyrygg',),
'høyryggene': ('høyrygg',),
'høyrygger': ('høyrygg',),
'høysang': ('høysang',),
'høysangen': ('høysang',),
'høysangene': ('høysang',),
'høysanger': ('høysang',),
'høysesong': ('høysesong',),
'høysesongen': ('høysesong',),
'høysesongene': ('høysesong',),
'høysesonger': ('høysesong',),
'høyseta': ('høysete',),
'høysete': ('høysete',),
'høysetene': ('høysete',),
'høyseter': ('høysete',),
'høysetet': ('høysete',),
'høyskole': ('høyskole',),
'høyskolen': ('høyskole',),
'høyskolene': ('høyskole',),
'høyskoler': ('høyskole',),
'høysnue': ('høysnue',),
'høysnuen': ('høysnue',),
'høysnuene': ('høysnue',),
'høysnuer': ('høysnue',),
'høysommer': ('høysommer',),
'høysommere': ('høysommer',),
'høysommeren': ('høysommer',),
'høysommerne': ('høysommer',),
'høysomre': ('høysommer',),
'høysomrene': ('høysommer',),
'høysomrer': ('høysommer',),
'høyspenning': ('høyspenning',),
'høyspenninga': ('høyspenning',),
'høyspenningen': ('høyspenning',),
'høyspenningene': ('høyspenning',),
'høyspenninger': ('høyspenning',),
'høyspentledning': ('høyspentledning',),
'høyspentledninga': ('høyspentledning',),
'høyspentledningen': ('høyspentledning',),
'høyspentledningene': ('høyspentledning',),
'høyspentledninger': ('høyspentledning',),
'høyspentmast': ('høyspentmast',),
'høyspentmasta': ('høyspentmast',),
'høyspentmasten': ('høyspentmast',),
'høyspentmastene': ('høyspentmast',),
'høyspentmaster': ('høyspentmast',),
'høystakk': ('høystakk',),
'høystakken': ('høystakk',),
'høystakkene': ('høystakk',),
'høystakker': ('høystakk',),
'høystatusyrka': ('høystatusyrke',),
'høystatusyrke': ('høystatusyrke',),
'høystatusyrkene': ('høystatusyrke',),
'høystatusyrker': ('høystatusyrke',),
'høystatusyrket': ('høystatusyrke',),
'høysvans': ('høysvans',),
'høysvansen': ('høysvans',),
'høysvansene': ('høysvans',),
'høysvanser': ('høysvans',),
'høysåta': ('høysåte',),
'høysåte': ('høysåte',),
'høysåten': ('høysåte',),
'høysåtene': ('høysåte',),
'høysåter': ('høysåte',),
'høytid': ('høytid',),
'høytida': ('høytid',),
'høytiden': ('høytid',),
'høytidene': ('høytid',),
'høytider': ('høytid',),
'høytidelighet': ('høytidelighet',),
'høytideligheta': ('høytidelighet',),
'høytideligheten': ('høytidelighet',),
'høytidelighetene': ('høytidelighet',),
'høytideligheter': ('høytidelighet',),
'høytidsdag': ('høytidsdag',),
'høytidsdagen': ('høytidsdag',),
'høytidsdagene': ('høytidsdag',),
'høytidsdager': ('høytidsdag',),
'høytidsstemning': ('høytidsstemning',),
'høytidsstemninga': ('høytidsstemning',),
'høytidsstemningen': ('høytidsstemning',),
'høytidsstemningene': ('høytidsstemning',),
'høytidsstemninger': ('høytidsstemning',),
'høytidsstund': ('høytidsstund',),
'høytidsstunda': ('høytidsstund',),
'høytidsstunden': ('høytidsstund',),
'høytidsstundene': ('høytidsstund',),
'høytidsstunder': ('høytidsstund',),
'høytlesing': ('høytlesing',),
'høytlesinga': ('høytlesing',),
'høytlesingen': ('høytlesing',),
'høytlesingene': ('høytlesing',),
'høytlesinger': ('høytlesing',),
'høytlesning': ('høytlesning',),
'høytlesninga': ('høytlesning',),
'høytlesningen': ('høytlesning',),
'høytlesningene': ('høytlesning',),
'høytlesninger': ('høytlesning',),
'høytrykk': ('høytrykk',),
'høytrykka': ('høytrykk',),
'høytrykkene': ('høytrykk',),
'høytrykket': ('høytrykk',),
'høytrykksområda': ('høytrykksområde',),
'høytrykksområde': ('høytrykksområde',),
'høytrykksområdene': ('høytrykksområde',),
'høytrykksområder': ('høytrykksområde',),
'høytrykksområdet': ('høytrykksområde',),
'høytrykksrygg': ('høytrykksrygg',),
'høytrykksryggen': ('høytrykksrygg',),
'høytrykksryggene': ('høytrykksrygg',),
'høytrykksrygger': ('høytrykksrygg',),
'høytrykkssprøyta': ('høytrykkssprøyte',),
'høytrykkssprøyte': ('høytrykkssprøyte',),
'høytrykkssprøyten': ('høytrykkssprøyte',),
'høytrykkssprøytene': ('høytrykkssprøyte',),
'høytrykkssprøyter': ('høytrykkssprøyte',),
'høyttaler': ('høyttaler',),
'høyttalere': ('høyttaler',),
'høyttaleren': ('høyttaler',),
'høyttalerer': ('høyttaler',),
'høyttalerne': ('høyttaler',),
'høyttaleranlegg': ('høyttaleranlegg',),
'høyttaleranlegga': ('høyttaleranlegg',),
'høyttaleranleggene': ('høyttaleranlegg',),
'høyttaleranlegget': ('høyttaleranlegg',),
'høytysk': ('høytysk',),
'høytysken': ('høytysk',),
'høytyskene': ('høytysk',),
'høytysker': ('høytysk',),
'høytørka': ('høytørke',),
'høytørke': ('høytørke',),
'høytørken': ('høytørke',),
'høytørkene': ('høytørke',),
'høytørker': ('høytørke',),
'høyvann': ('høyvann',),
'høyvanna': ('høyvann',),
'høyvannene': ('høyvann',),
'høyvannet': ('høyvann',),
'høyvannslinja': ('høyvannslinje',),
'høyvannslinje': ('høyvannslinje',),
'høyvannslinjen': ('høyvannslinje',),
'høyvannslinjene': ('høyvannslinje',),
'høyvannslinjer': ('høyvannslinje',),
'høyvasslinja': ('høyvasslinje',),
'høyvasslinje': ('høyvasslinje',),
'høyvasslinjen': ('høyvasslinje',),
'høyvasslinjene': ('høyvasslinje',),
'høyvasslinjer': ('høyvasslinje',),
'høyvatn': ('høyvatn',),
'høyvatna': ('høyvatn',),
'høyvatnene': ('høyvatn',),
'høyvatnet': ('høyvatn',),
'høyvelbårenhet': ('høyvelbårenhet',),
'høyvelbårenheta': ('høyvelbårenhet',),
'høyvelbårenheten': ('høyvelbårenhet',),
'høyvelbårenhetene': ('høyvelbårenhet',),
'høyvelbårenheter': ('høyvelbårenhet',),
'høyvender': ('høyvender',),
'høyvendere': ('høyvender',),
'høyvenderen': ('høyvender',),
'høyvenderer': ('høyvender',),
'høyvenderne': ('høyvender',),
'i': ('i',),
'i\'en': ('i',),
'i-en': ('i',),
'i-ene': ('i',),
'i-er': ('i',),
'i-land': ('i-land',),
'i-landa': ('i-land',),
'i-landene': ('i-land',),
'i-landet': ('i-land',),
'i-mål': ('i-mål',),
'i-måla': ('i-mål',),
'i-målene': ('i-mål',),
'i-målet': ('i-mål',),
'iakttakelse': ('iakttakelse',),
'iakttakelsen': ('iakttakelse',),
'iakttakelsene': ('iakttakelse',),
'iakttakelser': ('iakttakelse',),
'iakttakelsesevna': ('iakttakelsesevne',),
'iakttakelsesevne': ('iakttakelsesevne',),
'iakttakelsesevnen': ('iakttakelsesevne',),
'iakttakelsesevnene': ('iakttakelsesevne',),
'iakttakelsesevner': ('iakttakelsesevne',),
'iakttaker': ('iakttaker',),
'iakttakere': ('iakttaker',),
'iakttakeren': ('iakttaker',),
'iakttakerer': ('iakttaker',),
'iakttakerne': ('iakttaker',),
'ibenholt': ('ibenholt',),
'ibenholta': ('ibenholt',),
'ibenholten': ('ibenholt',),
'ibenholtene': ('ibenholt',),
'ibenholter': ('ibenholt',),
'ibenholtet': ('ibenholt',),
'ibenholttre': ('ibenholttre',),
'ibenholttrea': ('ibenholttre',),
'ibenholttreet': ('ibenholttre',),
'ibenholttrær': ('ibenholttre',),
'ibenholttrærne': ('ibenholttre',),
'iberer': ('iberer',),
'iberere': ('iberer',),
'ibereren': ('iberer',),
'ibererer': ('iberer',),
'ibererne': ('iberer',),
'ibis': ('ibis',),
'ibisen': ('ibis',),
'ibisene': ('ibis',),
'ibiser': ('ibis',),
'ibo': ('ibo',),
'iboen': ('ibo',),
'iboene': ('ibo',),
'iboer': ('ibo',),
'icing': ('icing',),
'icingen': ('icing',),
'icingene': ('icing',),
'icinger': ('icing',),
'id': ('id',),
'ida': ('id',),
'iden': ('id',),
'idene': ('id',),
'ider': ('id',),
'ideen': ('idé',),
'ideene': ('idé',),
'ideer': ('idé',),
'idé': ('idé',),
'idéen': ('idé',),
'idéene': ('idé',),
'idéer': ('idé',),
'idéassosiasjon': ('idéassosiasjon',),
'idéassosiasjonen': ('idéassosiasjon',),
'idéassosiasjonene': ('idéassosiasjon',),
'idéassosiasjoner': ('idéassosiasjon',),
'idédebatt': ('idédebatt',),
'idédebatten': ('idédebatt',),
'idédebattene': ('idédebatt',),
'idédebatter': ('idédebatt',),
'idédugnad': ('idédugnad',),
'idédugnaden': ('idédugnad',),
'idédugnadene': ('idédugnad',),
'idédugnader': ('idédugnad',),
'idégrunnlag': ('idégrunnlag',),
'idégrunnlaga': ('idégrunnlag',),
'idégrunnlagene': ('idégrunnlag',),
'idégrunnlaget': ('idégrunnlag',),
'idéhistoria': ('idéhistorie',),
'idéhistorie': ('idéhistorie',),
'idéhistorien': ('idéhistorie',),
'idéhistoriene': ('idéhistorie',),
'idéhistorier': ('idéhistorie',),
'idékonkurranse': ('idékonkurranse',),
'idékonkurransen': ('idékonkurranse',),
'idékonkurransene': ('idékonkurranse',),
'idékonkurranser': ('idékonkurranse',),
'idélæra': ('idélære',),
'idélære': ('idélære',),
'idélæren': ('idélære',),
'idélærene': ('idélære',),
'idélærer': ('idélære',),
'idéskissa': ('idéskisse',),
'idéskisse': ('idéskisse',),
'idéskissen': ('idéskisse',),
'idéskissene': ('idéskisse',),
'idéskisser': ('idéskisse',),
'ideal': ('ideal',),
'ideala': ('ideal',),
'idealene': ('ideal',),
'idealer': ('ideal',),
'idealet': ('ideal',),
'idealbilda': ('idealbilde',),
'idealbilde': ('idealbilde',),
'idealbildene': ('idealbilde',),
'idealbilder': ('idealbilde',),
'idealbildet': ('idealbilde',),
'idealisme': ('idealisme',),
'idealismen': ('idealisme',),
'idealismene': ('idealisme',),
'idealismer': ('idealisme',),
'idealist': ('idealist',),
'idealisten': ('idealist',),
'idealistene': ('idealist',),
'idealister': ('idealist',),
'idealitet': ('idealitet',),
'idealiteten': ('idealitet',),
'idealitetene': ('idealitet',),
'idealiteter': ('idealitet',),
'idealsamfunn': ('idealsamfunn',),
'idealsamfunna': ('idealsamfunn',),
'idealsamfunnene': ('idealsamfunn',),
'idealsamfunnet': ('idealsamfunn',),
'idealtid': ('idealtid',),
'idealtida': ('idealtid',),
'idealtiden': ('idealtid',),
'idealtidene': ('idealtid',),
'idealtider': ('idealtid',),
'idealtilstand': ('idealtilstand',),
'idealtilstanden': ('idealtilstand',),
'idealtilstandene': ('idealtilstand',),
'idealtilstander': ('idealtilstand',),
'identifikasjon': ('identifikasjon',),
'identifikasjonen': ('identifikasjon',),
'identifikasjonene': ('identifikasjon',),
'identifikasjoner': ('identifikasjon',),
'identitet': ('identitet',),
'identiteten': ('identitet',),
'identitetene': ('identitet',),
'identiteter': ('identitet',),
'identitetskort': ('identitetskort',),
'identitetskorta': ('identitetskort',),
'identitetskortene': ('identitetskort',),
'identitetskortet': ('identitetskort',),
'identitetskrisa': ('identitetskrise',),
'identitetskrise': ('identitetskrise',),
'identitetskrisen': ('identitetskrise',),
'identitetskrisene': ('identitetskrise',),
'identitetskriser': ('identitetskrise',),
'ideografi': ('ideografi',),
'ideografien': ('ideografi',),
'ideografiene': ('ideografi',),
'ideografier': ('ideografi',),
'ideogram': ('ideogram',),
'ideogramma': ('ideogram',),
'ideogrammene': ('ideogram',),
'ideogrammer': ('ideogram',),
'ideogrammet': ('ideogram',),
'ideolog': ('ideolog',),
'ideologen': ('ideolog',),
'ideologene': ('ideolog',),
'ideologer': ('ideolog',),
'ideologi': ('ideologi',),
'ideologien': ('ideologi',),
'ideologiene': ('ideologi',),
'ideologier': ('ideologi',),
'idiolekt': ('idiolekt',),
'idiolekten': ('idiolekt',),
'idiolektene': ('idiolekt',),
'idiolekter': ('idiolekt',),
'idiom': ('idiom',),
'idioma': ('idiom',),
'idiomene': ('idiom',),
'idiomer': ('idiom',),
'idiomet': ('idiom',),
'idiosynkrasi': ('idiosynkrasi',),
'idiosynkrasien': ('idiosynkrasi',),
'idiosynkrasiene': ('idiosynkrasi',),
'idiosynkrasier': ('idiosynkrasi',),
'idiot': ('idiot',),
'idioten': ('idiot',),
'idiotene': ('idiot',),
'idioter': ('idiot',),
'idioti': ('idioti',),
'idiotien': ('idioti',),
'idiotiene': ('idioti',),
'idiotier': ('idioti',),
'idiotika': ('idiotikon',),
'idiotikaene': ('idiotikon',),
'idiotikon': ('idiotikon',),
'idiotikonet': ('idiotikon',),
'idiotisme': ('idiotisme',),
'idiotismen': ('idiotisme',),
'idiotismene': ('idiotisme',),
'idiotismer': ('idiotisme',),
'idka': ('idke',),
'idke': ('idke',),
'idken': ('idke',),
'idkene': ('idke',),
'idker': ('idke',),
'ido': ('ido',),
'idoen': ('ido',),
'idoene': ('ido',),
'idoer': ('ido',),
'idol': ('idol',),
'idola': ('idol',),
'idolene': ('idol',),
'idoler': ('idol',),
'idolet': ('idol',),
'idrett': ('idrett',),
'idretten': ('idrett',),
'idrettene': ('idrett',),
'idretter': ('idrett',),
'idrettsanlegg': ('idrettsanlegg',),
'idrettsanlegga': ('idrettsanlegg',),
'idrettsanleggene': ('idrettsanlegg',),
'idrettsanlegget': ('idrettsanlegg',),
'idrettsbragd': ('idrettsbragd',),
'idrettsbragda': ('idrettsbragd',),
'idrettsbragden': ('idrettsbragd',),
'idrettsbragdene': ('idrettsbragd',),
'idrettsbragder': ('idrettsbragd',),
'idrettsenka': ('idrettsenke',),
'idrettsenke': ('idrettsenke',),
'idrettsenken': ('idrettsenke',),
'idrettsenkene': ('idrettsenke',),
'idrettsenker': ('idrettsenke',),
'idrettsgrein': ('idrettsgrein',),
'idrettsgreina': ('idrettsgrein',),
'idrettsgreinen': ('idrettsgrein',),
'idrettsgreinene': ('idrettsgrein',),
'idrettsgreiner': ('idrettsgrein',),
'idrettsgren': ('idrettsgren',),
'idrettsgrena': ('idrettsgren',),
'idrettsgrenen': ('idrettsgren',),
'idrettsgrenene': ('idrettsgren',),
'idrettsgrener': ('idrettsgren',),
'idrettshall': ('idrettshall',),
'idrettshallen': ('idrettshall',),
'idrettshallene': ('idrettshall',),
'idrettshaller': ('idrettshall',),
'idrettskandidat': ('idrettskandidat',),
'idrettskandidaten': ('idrettskandidat',),
'idrettskandidatene': ('idrettskandidat',),
'idrettskandidater': ('idrettskandidat',),
'idrettskvinna': ('idrettskvinne',),
'idrettskvinne': ('idrettskvinne',),
'idrettskvinnen': ('idrettskvinne',),
'idrettskvinnene': ('idrettskvinne',),
'idrettskvinner': ('idrettskvinne',),
'idrettslag': ('idrettslag',),
'idrettslaga': ('idrettslag',),
'idrettslagene': ('idrettslag',),
'idrettslaget': ('idrettslag',),
'idrettsmann': ('idrettsmann',),
'idrettsmannen': ('idrettsmann',),
'idrettsmenn': ('idrettsmann',),
'idrettsmennene': ('idrettsmann',),
'idrettsmerka': ('idrettsmerke',),
'idrettsmerke': ('idrettsmerke',),
'idrettsmerkene': ('idrettsmerke',),
'idrettsmerker': ('idrettsmerke',),
'idrettsmerket': ('idrettsmerke',),
'idrettsplass': ('idrettsplass',),
'idrettsplassen': ('idrettsplass',),
'idrettsplassene': ('idrettsplass',),
'idrettsplasser': ('idrettsplass',),
'idrettsstjerna': ('idrettsstjerne',),
'idrettsstjerne': ('idrettsstjerne',),
'idrettsstjernen': ('idrettsstjerne',),
'idrettsstjernene': ('idrettsstjerne',),
'idrettsstjerner': ('idrettsstjerne',),
'idrettsstudent': ('idrettsstudent',),
'idrettsstudenten': ('idrettsstudent',),
'idrettsstudentene': ('idrettsstudent',),
'idrettsstudenter': ('idrettsstudent',),
'idrettsutøver': ('idrettsutøver',),
'idrettsutøvere': ('idrettsutøver',),
'idrettsutøveren': ('idrettsutøver',),
'idrettsutøverer': ('idrettsutøver',),
'idrettsutøverne': ('idrettsutøver',),
'idyll': ('idyll',),
'idyllen': ('idyll',),
'idyllene': ('idyll',),
'idyller': ('idyll',),
'idylliker': ('idylliker',),
'idyllikere': ('idylliker',),
'idyllikeren': ('idylliker',),
'idyllikerer': ('idylliker',),
'idyllikerne': ('idylliker',),
'ifelling': ('ifelling',),
'ifellinga': ('ifelling',),
'ifellingen': ('ifelling',),
'ifellingene': ('ifelling',),
'ifellinger': ('ifelling',),
'ifylling': ('ifylling',),
'ifyllinga': ('ifylling',),
'ifyllingen': ('ifylling',),
'ifyllingene': ('ifylling',),
'ifyllinger': ('ifylling',),
'igda': ('igde',),
'igde': ('igde',),
'igden': ('igde',),
'igdene': ('igde',),
'igder': ('igde',),
'igla': ('igle',),
'igle': ('igle',),
'iglen': ('igle',),
'iglene': ('igle',),
'igler': ('igle',),
'iglekjerring': ('iglekjerring',),
'iglekjerringa': ('iglekjerring',),
'iglekjerringen': ('iglekjerring',),
'iglekjerringene': ('iglekjerring',),
'iglekjerringer': ('iglekjerring',),
'iglekona': ('iglekone',),
'iglekone': ('iglekone',),
'iglekonen': ('iglekone',),
'iglekonene': ('iglekone',),
'iglekoner': ('iglekone',),
'iglo': ('iglo',),
'igloen': ('iglo',),
'igloene': ('iglo',),
'igloer': ('iglo',),
'ignoranse': ('ignoranse',),
'ignoransen': ('ignoranse',),
'ignoransene': ('ignoranse',),
'ignoranser': ('ignoranse',),
'ignorant': ('ignorant',),
'ignoranten': ('ignorant',),
'ignorantene': ('ignorant',),
'ignoranter': ('ignorant',),
'iguan': ('iguan',),
'iguanen': ('iguan',),
'iguanene': ('iguan',),
'iguaner': ('iguan',),
'ihendehaver': ('ihendehaver',),
'ihendehavere': ('ihendehaver',),
'ihendehaveren': ('ihendehaver',),
'ihendehaverer': ('ihendehaver',),
'ihendehaverne': ('ihendehaver',),
'ihendehaveraksje': ('ihendehaveraksje',),
'ihendehaveraksjen': ('ihendehaveraksje',),
'ihendehaveraksjene': ('ihendehaveraksje',),
'ihendehaveraksjer': ('ihendehaveraksje',),
'ihendehaverobligasjon': ('ihendehaverobligasjon',),
'ihendehaverobligasjonen': ('ihendehaverobligasjon',),
'ihendehaverobligasjonene': ('ihendehaverobligasjon',),
'ihendehaverobligasjoner': ('ihendehaverobligasjon',),
'ihendehaverpapir': ('ihendehaverpapir',),
'ihendehaverpapira': ('ihendehaverpapir',),
'ihendehaverpapirene': ('ihendehaverpapir',),
'ihendehaverpapirer': ('ihendehaverpapir',),
'ihendehaverpapiret': ('ihendehaverpapir',),
'ihukommelse': ('ihukommelse',),
'ihukommelsen': ('ihukommelse',),
'ihukommelsene': ('ihukommelse',),
'ihukommelser': ('ihukommelse',),
'ikke': ('ikke',),
'ikken': ('ikke',),
'ikkene': ('ikke',),
'ikker': ('ikke',),
'ikke-fagmann': ('ikke-fagmann',),
'ikke-fagmannen': ('ikke-fagmann',),
'ikke-fagmenn': ('ikke-fagmann',),
'ikke-fagmennene': ('ikke-fagmann',),
'ikke-innblanding': ('ikke-innblanding',),
'ikke-innblandinga': ('ikke-innblanding',),
'ikke-innblandingen': ('ikke-innblanding',),
'ikke-innblandingene': ('ikke-innblanding',),
'ikke-innblandinger': ('ikke-innblanding',),
'ikke-intervensjon': ('ikke-intervensjon',),
'ikke-intervensjonen': ('ikke-intervensjon',),
'ikke-intervensjonene': ('ikke-intervensjon',),
'ikke-intervensjoner': ('ikke-intervensjon',),
'ikke-leder': ('ikke-leder',),
'ikke-ledere': ('ikke-leder',),
'ikke-lederen': ('ikke-leder',),
'ikke-lederer': ('ikke-leder',),
'ikke-lederne': ('ikke-leder',),
'ikke-metall': ('ikke-metall',),
'ikke-metalla': ('ikke-metall',),
'ikke-metallene': ('ikke-metall',),
'ikke-metaller': ('ikke-metall',),
'ikke-metallet': ('ikke-metall',),
'ikke-røyker': ('ikke-røyker',),
'ikke-røykere': ('ikke-røyker',),
'ikke-røykeren': ('ikke-røyker',),
'ikke-røykerer': ('ikke-røyker',),
'ikke-røykerne': ('ikke-røyker',),
'ikke-spredning': ('ikke-spredning',),
'ikke-spredninga': ('ikke-spredning',),
'ikke-spredningen': ('ikke-spredning',),
'ikke-spredningene': ('ikke-spredning',),
'ikke-spredninger': ('ikke-spredning',),
'ikkeangrepspakt': ('ikkeangrepspakt',),
'ikkeangrepspakta': ('ikkeangrepspakt',),
'ikkeangrepspakten': ('ikkeangrepspakt',),
'ikkeangrepspaktene': ('ikkeangrepspakt',),
'ikkeangrepspakter': ('ikkeangrepspakt',),
'ikkeinnblandingspolitikk': ('ikkeinnblandingspolitikk',),
'ikkeinnblandingspolitikken': ('ikkeinnblandingspolitikk',),
'ikkeinnblandingspolitikkene': ('ikkeinnblandingspolitikk',),
'ikkeinnblandingspolitikker': ('ikkeinnblandingspolitikk',),
'ikkespredningsavtale': ('ikkespredningsavtale',),
'ikkespredningsavtalen': ('ikkespredningsavtale',),
'ikkespredningsavtalene': ('ikkespredningsavtale',),
'ikkespredningsavtaler': ('ikkespredningsavtale',),
'ikkevold': ('ikkevold',),
'ikkevolden': ('ikkevold',),
'ikkevoldene': ('ikkevold',),
'ikkevolder': ('ikkevold',),
'ikkevoldsprinsipp': ('ikkevoldsprinsipp',),
'ikkevoldsprinsippa': ('ikkevoldsprinsipp',),
'ikkevoldsprinsippene': ('ikkevoldsprinsipp',),
'ikkevoldsprinsipper': ('ikkevoldsprinsipp',),
'ikkevoldsprinsippet': ('ikkevoldsprinsipp',),
'ikon': ('ikon',),
'ikona': ('ikon',),
'ikonen': ('ikon',),
'ikonene': ('ikon',),
'ikoner': ('ikon',),
'ikonet': ('ikon',),
'ikonografi': ('ikonografi',),
'ikonografien': ('ikonografi',),
'ikonografiene': ('ikonografi',),
'ikonografier': ('ikonografi',),
'ikonoklasme': ('ikonoklasme',),
'ikonoklasmen': ('ikonoklasme',),
'ikonoklasmene': ('ikonoklasme',),
'ikonoklasmer': ('ikonoklasme',),
'ikonoklast': ('ikonoklast',),
'ikonoklasten': ('ikonoklast',),
'ikonoklastene': ('ikonoklast',),
'ikonoklaster': ('ikonoklast',),
'ikonologi': ('ikonologi',),
'ikonologien': ('ikonologi',),
'ikonologiene': ('ikonologi',),
'ikonologier': ('ikonologi',),
'ikornhale': ('ikornhale',),
'ikornhalen': ('ikornhale',),
'ikornhalene': ('ikornhale',),
'ikornhaler': ('ikornhale',),
'ikornhale': ('ikornhale',),
'ikornhalen': ('ikornhale',),
'ikornhalene': ('ikornhale',),
'ikornhaler': ('ikornhale',),
'ikornreda': ('ikornrede',),
'ikornrede': ('ikornrede',),
'ikornredene': ('ikornrede',),
'ikornreder': ('ikornrede',),
'ikornredet': ('ikornrede',),
'ikornreda': ('ikornrede',),
'ikornrede': ('ikornrede',),
'ikornredene': ('ikornrede',),
'ikornreder': ('ikornrede',),
'ikornredet': ('ikornrede',),
'ikornreir': ('ikornreir',),
'ikornreira': ('ikornreir',),
'ikornreirene': ('ikornreir',),
'ikornreiret': ('ikornreir',),
'ikornreir': ('ikornreir',),
'ikornreira': ('ikornreir',),
'ikornreirene': ('ikornreir',),
'ikornreiret': ('ikornreir',),
'ikraftsettelse': ('ikraftsettelse',),
'ikraftsettelsen': ('ikraftsettelse',),
'ikraftsettelsene': ('ikraftsettelse',),
'ikraftsettelser': ('ikraftsettelse',),
'ikraftsetting': ('ikraftsetting',),
'ikraftsettinga': ('ikraftsetting',),
'ikraftsettingen': ('ikraftsetting',),
'ikraftsettingene': ('ikraftsetting',),
'ikraftsettinger': ('ikraftsetting',),
'ikrafttredelse': ('ikrafttredelse',),
'ikrafttredelsen': ('ikrafttredelse',),
'ikrafttredelsene': ('ikrafttredelse',),
'ikrafttredelser': ('ikrafttredelse',),
'ikrafttreden': ('ikrafttreden',),
'ikrafttredenen': ('ikrafttreden',),
'ikrafttredenene': ('ikrafttreden',),
'ikrafttredener': ('ikrafttreden',),
'ikte': ('ikte',),
'ikten': ('ikte',),
'iktene': ('ikte',),
'ikter': ('ikte',),
'iktus': ('iktus',),
'iktusen': ('iktus',),
'iktusene': ('iktus',),
'iktuser': ('iktus',),
'iktyolog': ('iktyolog',),
'iktyologen': ('iktyolog',),
'iktyologene': ('iktyolog',),
'iktyologer': ('iktyolog',),
'iktyologi': ('iktyologi',),
'iktyologien': ('iktyologi',),
'iktyologiene': ('iktyologi',),
'iktyologier': ('iktyologi',),
'ilandføring': ('ilandføring',),
'ilandføringa': ('ilandføring',),
'ilandføringen': ('ilandføring',),
'ilandføringene': ('ilandføring',),
'ilandføringer': ('ilandføring',),
'ilbud': ('ilbud',),
'ilbuda': ('ilbud',),
'ilbudene': ('ilbud',),
'ilbudet': ('ilbud',),
'ild': ('ild',),
'ilden': ('ild',),
'ildene': ('ild',),
'ilder': ('ild',),
'ild': ('ild',),
'ilden': ('ild',),
'ildene': ('ild',),
'ilder': ('ild',),
'ilddåp': ('ilddåp',),
'ilddåpen': ('ilddåp',),
'ilddåpene': ('ilddåp',),
'ilddåper': ('ilddåp',),
'ildebrann': ('ildebrann',),
'ildebrannen': ('ildebrann',),
'ildebrannene': ('ildebrann',),
'ildebranner': ('ildebrann',),
'ilder': ('ilder',),
'ildere': ('ilder',),
'ilderen': ('ilder',),
'ilderne': ('ilder',),
'ildre': ('ilder',),
'ildrene': ('ilder',),
'ildrer': ('ilder',),
'ildflua': ('ildflue',),
'ildflue': ('ildflue',),
'ildfluen': ('ildflue',),
'ildfluene': ('ildflue',),
'ildfluer': ('ildflue',),
'ildflua': ('ildflue',),
'ildflue': ('ildflue',),
'ildfluen': ('ildflue',),
'ildfluene': ('ildflue',),
'ildfluer': ('ildflue',),
'ildgiing': ('ildgiing',),
'ildgiinga': ('ildgiing',),
'ildgiingen': ('ildgiing',),
'ildgiingene': ('ildgiing',),
'ildgiinger': ('ildgiing',),
'ildgiing': ('ildgiing',),
'ildgiinga': ('ildgiing',),
'ildgiingen': ('ildgiing',),
'ildgiingene': ('ildgiing',),
'ildgiinger': ('ildgiing',),
'ildgiving': ('ildgiving',),
'ildgivinga': ('ildgiving',),
'ildgivingen': ('ildgiving',),
'ildgivingene': ('ildgiving',),
'ildgivinger': ('ildgiving',),
'ildgiving': ('ildgiving',),
'ildgivinga': ('ildgiving',),
'ildgivingen': ('ildgiving',),
'ildgivingene': ('ildgiving',),
'ildgivinger': ('ildgiving',),
'ildgivning': ('ildgivning',),
'ildgivninga': ('ildgivning',),
'ildgivningen': ('ildgivning',),
'ildgivningene': ('ildgivning',),
'ildgivninger': ('ildgivning',),
'ildgivning': ('ildgivning',),
'ildgivninga': ('ildgivning',),
'ildgivningen': ('ildgivning',),
'ildgivningene': ('ildgivning',),
'ildgivninger': ('ildgivning',),
'ildgud': ('ildgud',),
'ildguden': ('ildgud',),
'ildgudene': ('ildgud',),
'ildguder': ('ildgud',),
'ildgud': ('ildgud',),
'ildguden': ('ildgud',),
'ildgudene': ('ildgud',),
'ildguder': ('ildgud',),
'ildhav': ('ildhav',),
'ildhava': ('ildhav',),
'ildhavene': ('ildhav',),
'ildhavet': ('ildhav',),
'ildhav': ('ildhav',),
'ildhava': ('ildhav',),
'ildhavene': ('ildhav',),
'ildhavet': ('ildhav',),
'ildkraft': ('ildkraft',),
'ildkrafta': ('ildkraft',),
'ildkraften': ('ildkraft',),
'ildkreftene': ('ildkraft',),
'ildkrefter': ('ildkraft',),
'ildkraft': ('ildkraft',),
'ildkrafta': ('ildkraft',),
'ildkraften': ('ildkraft',),
'ildkreftene': ('ildkraft',),
'ildkrefter': ('ildkraft',),
'ildkula': ('ildkule',),
'ildkule': ('ildkule',),
'ildkulen': ('ildkule',),
'ildkulene': ('ildkule',),
'ildkuler': ('ildkule',),
'ildkula': ('ildkule',),
'ildkule': ('ildkule',),
'ildkulen': ('ildkule',),
'ildkulene': ('ildkule',),
'ildkuler': ('ildkule',),
'ildkvede': ('ildkvede',),
'ildkveden': ('ildkvede',),
'ildkvedene': ('ildkvede',),
'ildkveder': ('ildkvede',),
'ildkvede': ('ildkvede',),
'ildkveden': ('ildkvede',),
'ildkvedene': ('ildkvede',),
'ildkveder': ('ildkvede',),
'ildlinja': ('ildlinje',),
'ildlinje': ('ildlinje',),
'ildlinjen': ('ildlinje',),
'ildlinjene': ('ildlinje',),
'ildlinjer': ('ildlinje',),
'ildlinja': ('ildlinje',),
'ildlinje': ('ildlinje',),
'ildlinjen': ('ildlinje',),
'ildlinjene': ('ildlinje',),
'ildlinjer': ('ildlinje',),
'ildmørja': ('ildmørje',),
'ildmørje': ('ildmørje',),
'ildmørjen': ('ildmørje',),
'ildmørjene': ('ildmørje',),
'ildmørjer': ('ildmørje',),
'ildmørja': ('ildmørje',),
'ildmørje': ('ildmørje',),
'ildmørjen': ('ildmørje',),
'ildmørjene': ('ildmørje',),
'ildmørjer': ('ildmørje',),
'ildprøva': ('ildprøve',),
'ildprøve': ('ildprøve',),
'ildprøven': ('ildprøve',),
'ildprøvene': ('ildprøve',),
'ildprøver': ('ildprøve',),
'ildprøva': ('ildprøve',),
'ildprøve': ('ildprøve',),
'ildprøven': ('ildprøve',),
'ildprøvene': ('ildprøve',),
'ildprøver': ('ildprøve',),
'ildraka': ('ildrake',),
'ildrake': ('ildrake',),
'ildraken': ('ildrake',),
'ildrakene': ('ildrake',),
'ildraker': ('ildrake',),
'ildraka': ('ildrake',),
'ildrake': ('ildrake',),
'ildraken': ('ildrake',),
'ildrakene': ('ildrake',),
'ildraker': ('ildrake',),
'ildregn': ('ildregn',),
'ildregna': ('ildregn',),
'ildregnene': ('ildregn',),
'ildregnet': ('ildregn',),
'ildregn': ('ildregn',),
'ildregna': ('ildregn',),
'ildregnene': ('ildregn',),
'ildregnet': ('ildregn',),
'ildsfare': ('ildsfare',),
'ildsfaren': ('ildsfare',),
'ildsfarene': ('ildsfare',),
'ildsfarer': ('ildsfare',),
'ildsfare': ('ildsfare',),
'ildsfaren': ('ildsfare',),
'ildsfarene': ('ildsfare',),
'ildsfarer': ('ildsfare',),
'ildsjel': ('ildsjel',),
'ildsjela': ('ildsjel',),
'ildsjelen': ('ildsjel',),
'ildsjelene': ('ildsjel',),
'ildsjeler': ('ildsjel',),
'ildsjel': ('ildsjel',),
'ildsjela': ('ildsjel',),
'ildsjelen': ('ildsjel',),
'ildsjelene': ('ildsjel',),
'ildsjeler': ('ildsjel',),
'ildskrift': ('ildskrift',),
'ildskrifta': ('ildskrift',),
'ildskriften': ('ildskrift',),
'ildskriftene': ('ildskrift',),
'ildskrifter': ('ildskrift',),
'ildspåsetter': ('ildspåsetter',),
'ildspåsettere': ('ildspåsetter',),
'ildspåsetteren': ('ildspåsetter',),
'ildspåsetterer': ('ildspåsetter',),
'ildspåsetterne': ('ildspåsetter',),
'ildspåsetter': ('ildspåsetter',),
'ildspåsettere': ('ildspåsetter',),
'ildspåsetteren': ('ildspåsetter',),
'ildspåsetterer': ('ildspåsetter',),
'ildspåsetterne': ('ildspåsetter',),
'ildsted': ('ildsted',),
'ildstedene': ('ildsted',),
'ildsteder': ('ildsted',),
'ildstedet': ('ildsted',),
'ildsted': ('ildsted',),
'ildstedene': ('ildsted',),
'ildsteder': ('ildsted',),
'ildstedet': ('ildsted',),
'ildtunga': ('ildtunge',),
'ildtunge': ('ildtunge',),
'ildtungen': ('ildtunge',),
'ildtungene': ('ildtunge',),
'ildtunger': ('ildtunge',),
'ildtunga': ('ildtunge',),
'ildtunge': ('ildtunge',),
'ildtungen': ('ildtunge',),
'ildtungene': ('ildtunge',),
'ildtunger': ('ildtunge',),
'ildvann': ('ildvann',),
'ildvanna': ('ildvann',),
'ildvannene': ('ildvann',),
'ildvannet': ('ildvann',),
'ildvann': ('ildvann',),
'ildvanna': ('ildvann',),
'ildvannene': ('ildvann',),
'ildvannet': ('ildvann',),
'ildvatn': ('ildvatn',),
'ildvatna': ('ildvatn',),
'ildvatnene': ('ildvatn',),
'ildvatnet': ('ildvatn',),
'ildvogn': ('ildvogn',),
'ildvogna': ('ildvogn',),
'ildvognen': ('ildvogn',),
'ildvognene': ('ildvogn',),
'ildvogner': ('ildvogn',),
'ildvåpen': ('ildvåpen',),
'ildvåpenet': ('ildvåpen',),
'ildvåpna': ('ildvåpen',),
'ildvåpnene': ('ildvåpen',),
'ildvåpen': ('ildvåpen',),
'ildvåpenet': ('ildvåpen',),
'ildvåpna': ('ildvåpen',),
'ildvåpnene': ('ildvåpen',),
'ile': ('ile',),
'ilen': ('ile',),
'ilene': ('ile',),
'iler': ('ile',),
'ila': ('ile',),
'ile': ('ile',),
'ilen': ('ile',),
'ilene': ('ile',),
'iler': ('ile',),
'ilegg': ('ilegg',),
'ilegga': ('ilegg',),
'ileggene': ('ilegg',),
'ilegget': ('ilegg',),
'ilgods': ('ilgods',),
'ilgodsa': ('ilgods',),
'ilgodsene': ('ilgods',),
'ilgodset': ('ilgods',),
'iling': ('iling',),
'ilingen': ('iling',),
'ilingene': ('iling',),
'ilinger': ('iling',),
'ilk': ('ilk',),
'ilken': ('ilk',),
'ilkene': ('ilk',),
'ilker': ('ilk',),
'ilke': ('ilke',),
'ilken': ('ilke',),
'ilkene': ('ilke',),
'ilker': ('ilke',),
'illaudabilis': ('illaudabilis',),
'illaudabilisen': ('illaudabilis',),
'illaudabilisene': ('illaudabilis',),
'illaudabiliser': ('illaudabilis',),
'illebefinnende': ('illebefinnende',),
'illebefinnendene': ('illebefinnende',),
'illebefinnender': ('illebefinnende',),
'illebefinnendet': ('illebefinnende',),
'illegalitet': ('illegalitet',),
'illegaliteten': ('illegalitet',),
'illegalitetene': ('illegalitet',),
'illegaliteter': ('illegalitet',),
'illegitimitet': ('illegitimitet',),
'illegitimiteten': ('illegitimitet',),
'illegitimitetene': ('illegitimitet',),
'illegitimiteter': ('illegitimitet',),
'illgjerning': ('illgjerning',),
'illgjerninga': ('illgjerning',),
'illgjerningen': ('illgjerning',),
'illgjerningene': ('illgjerning',),
'illgjerninger': ('illgjerning',),
'illgjerningsmann': ('illgjerningsmann',),
'illgjerningsmannen': ('illgjerningsmann',),
'illgjerningsmenn': ('illgjerningsmann',),
'illgjerningsmennene': ('illgjerningsmann',),
'illhug': ('illhug',),
'illhugen': ('illhug',),
'illhugene': ('illhug',),
'illhuger': ('illhug',),
'illiberalitet': ('illiberalitet',),
'illiberaliteten': ('illiberalitet',),
'illiberalitetene': ('illiberalitet',),
'illiberaliteter': ('illiberalitet',),
'illojalitet': ('illojalitet',),
'illojaliteten': ('illojalitet',),
'illojalitetene': ('illojalitet',),
'illojaliteter': ('illojalitet',),
'illsinna': ('illsinne',),
'illsinne': ('illsinne',),
'illsinnene': ('illsinne',),
'illsinner': ('illsinne',),
'illsinnet': ('illsinne',),
'illuminasjon': ('illuminasjon',),
'illuminasjonen': ('illuminasjon',),
'illuminasjonene': ('illuminasjon',),
'illuminasjoner': ('illuminasjon',),
'illusjon': ('illusjon',),
'illusjonen': ('illusjon',),
'illusjonene': ('illusjon',),
'illusjoner': ('illusjon',),
'illusjonisme': ('illusjonisme',),
'illusjonismen': ('illusjonisme',),
'illusjonismene': ('illusjonisme',),
'illusjonismer': ('illusjonisme',),
'illusjonist': ('illusjonist',),
'illusjonisten': ('illusjonist',),
'illusjonistene': ('illusjonist',),
'illusjonister': ('illusjonist',),
'illustrasjon': ('illustrasjon',),
'illustrasjonen': ('illustrasjon',),
'illustrasjonene': ('illustrasjon',),
'illustrasjoner': ('illustrasjon',),
'illustratør': ('illustratør',),
'illustratøren': ('illustratør',),
'illustratørene': ('illustratør',),
'illustratører': ('illustratør',),
'ilmarsj': ('ilmarsj',),
'ilmarsjen': ('ilmarsj',),
'ilmarsjene': ('ilmarsj',),
'ilmarsjer': ('ilmarsj',),
'ilmenitt': ('ilmenitt',),
'ilmenitten': ('ilmenitt',),
'ilmenittene': ('ilmenitt',),
'ilmenitter': ('ilmenitt',),
'ilpakka': ('ilpakke',),
'ilpakke': ('ilpakke',),
'ilpakken': ('ilpakke',),
'ilpakkene': ('ilpakke',),
'ilpakker': ('ilpakke',),
'ilsamtale': ('ilsamtale',),
'ilsamtalen': ('ilsamtale',),
'ilsamtalene': ('ilsamtale',),
'ilsamtaler': ('ilsamtale',),
'ilska': ('ilske',),
'ilske': ('ilske',),
'ilsken': ('ilske',),
'ilskene': ('ilske',),
'ilsker': ('ilske',),
'iltakst': ('iltakst',),
'iltaksten': ('iltakst',),
'iltakstene': ('iltakst',),
'iltakster': ('iltakst',),
'iltelegram': ('iltelegram',),
'iltelegramma': ('iltelegram',),
'iltelegrammene': ('iltelegram',),
'iltelegrammer': ('iltelegram',),
'iltelegrammet': ('iltelegram',),
'image': ('image',),
'imagen': ('image',),
'imagene': ('image',),
'imager': ('image',),
'imaginasjon': ('imaginasjon',),
'imaginasjonen': ('imaginasjon',),
'imaginasjonene': ('imaginasjon',),
'imaginasjoner': ('imaginasjon',),
'imagines': ('imagines',),
'imago': ('imago',),
'imagoen': ('imago',),
'imagoene': ('imago',),
'imagoer': ('imago',),
'imago': ('imago',),
'imagoa': ('imago',),
'imagoene': ('imago',),
'imagoer': ('imago',),
'imagoet': ('imago',),
'imam': ('imam',),
'imamen': ('imam',),
'imamene': ('imam',),
'imamer': ('imam',),
'imamat': ('imamat',),
'imamata': ('imamat',),
'imamatene': ('imamat',),
'imamater': ('imamat',),
'imamatet': ('imamat',),
'imbesillitet': ('imbesillitet',),
'imbesilliteten': ('imbesillitet',),
'imbesillitetene': ('imbesillitet',),
'imbesilliteter': ('imbesillitet',),
'imitasjon': ('imitasjon',),
'imitasjonen': ('imitasjon',),
'imitasjonene': ('imitasjon',),
'imitasjoner': ('imitasjon',),
'imitator': ('imitator',),
'imitatoren': ('imitator',),
'imitatorene': ('imitator',),
'imitatorer': ('imitator',),
'immanens': ('immanens',),
'immanensen': ('immanens',),
'immanensene': ('immanens',),
'immanenser': ('immanens',),
'immaterialisme': ('immaterialisme',),
'immaterialismen': ('immaterialisme',),
'immaterialismene': ('immaterialisme',),
'immaterialismer': ('immaterialisme',),
'immaturus': ('immaturus',),
'immaturusen': ('immaturus',),
'immaturusene': ('immaturus',),
'immaturuser': ('immaturus',),
'immigrant': ('immigrant',),
'immigranten': ('immigrant',),
'immigrantene': ('immigrant',),
'immigranter': ('immigrant',),
'immigrasjon': ('immigrasjon',),
'immigrasjonen': ('immigrasjon',),
'immigrasjonene': ('immigrasjon',),
'immigrasjoner': ('immigrasjon',),
'immobilia': ('immobilia',),
'immobiliene': ('immobilia',),
'immobiliene': ('immobilier',),
'immobilier': ('immobilier',),
'immobilitet': ('immobilitet',),
'immobiliteten': ('immobilitet',),
'immobilitetene': ('immobilitet',),
'immobiliteter': ('immobilitet',),
'immortalitet': ('immortalitet',),
'immortaliteten': ('immortalitet',),
'immortalitetene': ('immortalitet',),
'immortaliteter': ('immortalitet',),
'immortell': ('immortell',),
'immortellen': ('immortell',),
'immortellene': ('immortell',),
'immorteller': ('immortell',),
'immunitet': ('immunitet',),
'immuniteten': ('immunitet',),
'immunitetene': ('immunitet',),
'immuniteter': ('immunitet',),
'immunologi': ('immunologi',),
'immunologien': ('immunologi',),
'immunologiene': ('immunologi',),
'immunologier': ('immunologi',),
'immunsvikt': ('immunsvikt',),
'immunsvikten': ('immunsvikt',),
'immunsviktene': ('immunsvikt',),
'immunsvikter': ('immunsvikt',),
'impala': ('impala',),
'impalaen': ('impala',),
'impalaene': ('impala',),
'impalaer': ('impala',),
'impedans': ('impedans',),
'impedansen': ('impedans',),
'impedansene': ('impedans',),
'impedanser': ('impedans',),
'impediment': ('impediment',),
'impedimenta': ('impediment',),
'impedimentene': ('impediment',),
'impedimenter': ('impediment',),
'impedimentet': ('impediment',),
'imperativ': ('imperativ',),
'imperativen': ('imperativ',),
'imperativene': ('imperativ',),
'imperativer': ('imperativ',),
'imperativ': ('imperativ',),
'imperativa': ('imperativ',),
'imperativene': ('imperativ',),
'imperativer': ('imperativ',),
'imperativet': ('imperativ',),
'imperativform': ('imperativform',),
'imperativforma': ('imperativform',),
'imperativformen': ('imperativform',),
'imperativformene': ('imperativform',),
'imperativformer': ('imperativform',),
'imperativsform': ('imperativsform',),
'imperativsforma': ('imperativsform',),
'imperativsformen': ('imperativsform',),
'imperativsformene': ('imperativsform',),
'imperativsformer': ('imperativsform',),
'imperator': ('imperator',),
'imperatoren': ('imperator',),
'imperatorene': ('imperator',),
'imperatorer': ('imperator',),
'imperfekta': ('imperfektum',),
'imperfektaene': ('imperfektum',),
'imperfektene': ('imperfektum',),
'imperfekter': ('imperfektum',),
'imperfektum': ('imperfektum',),
'imperfektumet': ('imperfektum',),
'imperial': ('imperial',),
'imperialen': ('imperial',),
'imperialene': ('imperial',),
'imperialer': ('imperial',),
'imperialisme': ('imperialisme',),
'imperialismen': ('imperialisme',),
'imperialismene': ('imperialisme',),
'imperialismer': ('imperialisme',),
'imperialist': ('imperialist',),
'imperialisten': ('imperialist',),
'imperialistene': ('imperialist',),
'imperialister': ('imperialist',),
'imperia': ('imperium',),
'imperiene': ('imperium',),
'imperier': ('imperium',),
'imperiet': ('imperium',),
'imperium': ('imperium',),
'impertinens': ('impertinens',),
'impertinensen': ('impertinens',),
'impertinensene': ('impertinens',),
'impertinenser': ('impertinens',),
'implantasjon': ('implantasjon',),
'implantasjonen': ('implantasjon',),
'implantasjonene': ('implantasjon',),
'implantasjoner': ('implantasjon',),
'implantat': ('implantat',),
'implantata': ('implantat',),
'implantatene': ('implantat',),
'implantater': ('implantat',),
'implantatet': ('implantat',),
'implikasjon': ('implikasjon',),
'implikasjonen': ('implikasjon',),
'implikasjonene': ('implikasjon',),
'implikasjoner': ('implikasjon',),
'implosjon': ('implosjon',),
'implosjonen': ('implosjon',),
'implosjonene': ('implosjon',),
'implosjoner': ('implosjon',),
'import': ('import',),
'importen': ('import',),
'importene': ('import',),
'importer': ('import',),
'importør': ('importør',),
'importøren': ('importør',),
'importørene': ('importør',),
'importører': ('importør',),
'impotens': ('impotens',),
'impotensen': ('impotens',),
'impotensene': ('impotens',),
'impotenser': ('impotens',),
'impregnering': ('impregnering',),
'impregneringa': ('impregnering',),
'impregneringen': ('impregnering',),
'impregneringene': ('impregnering',),
'impregneringer': ('impregnering',),
'impresariene': ('impresario',),
'impresarier': ('impresario',),
'impresario': ('impresario',),
'impresarioen': ('impresario',),
'impresarioene': ('impresario',),
'impresarioer': ('impresario',),
'impresjonisme': ('impresjonisme',),
'impresjonismen': ('impresjonisme',),
'impresjonismene': ('impresjonisme',),
'impresjonismer': ('impresjonisme',),
'impresjonist': ('impresjonist',),
'impresjonisten': ('impresjonist',),
'impresjonistene': ('impresjonist',),
'impresjonister': ('impresjonist',),
'imprimatur': ('imprimatur',),
'impromptu': ('impromptu',),
'impromptua': ('impromptu',),
'impromptuene': ('impromptu',),
'impromptuer': ('impromptu',),
'impromptuet': ('impromptu',),
'improvisasjon': ('improvisasjon',),
'improvisasjonen': ('improvisasjon',),
'improvisasjonene': ('improvisasjon',),
'improvisasjoner': ('improvisasjon',),
'improvisator': ('improvisator',),
'improvisatoren': ('improvisator',),
'improvisatorene': ('improvisator',),
'improvisatorer': ('improvisator',),
'impuls': ('impuls',),
'impulsen': ('impuls',),
'impulsene': ('impuls',),
'impulser': ('impuls',),
'impulshandling': ('impulshandling',),
'impulshandlinga': ('impulshandling',),
'impulshandlingen': ('impulshandling',),
'impulshandlingene': ('impulshandling',),
'impulshandlinger': ('impulshandling',),
'impulsivitet': ('impulsivitet',),
'impulsiviteten': ('impulsivitet',),
'impulsivitetene': ('impulsivitet',),
'impulsiviteter': ('impulsivitet',),
'impulskjøp': ('impulskjøp',),
'impulskjøpa': ('impulskjøp',),
'impulskjøpene': ('impulskjøp',),
'impulskjøpet': ('impulskjøp',),
'inaugurasjon': ('inaugurasjon',),
'inaugurasjonen': ('inaugurasjon',),
'inaugurasjonene': ('inaugurasjon',),
'inaugurasjoner': ('inaugurasjon',),
'incentiv': ('incentiv',),
'incentiva': ('incentiv',),
'incentivene': ('incentiv',),
'incentiver': ('incentiv',),
'incentivet': ('incentiv',),
'incest': ('incest',),
'incesten': ('incest',),
'incestene': ('incest',),
'incester': ('incest',),
'incitament': ('incitament',),
'incitamenta': ('incitament',),
'incitamentene': ('incitament',),
'incitamenter': ('incitament',),
'incitamentet': ('incitament',),
'indamin': ('indamin',),
'indamina': ('indamin',),
'indaminene': ('indamin',),
'indaminer': ('indamin',),
'indaminet': ('indamin',),
'indeks': ('indeks',),
'indeksen': ('indeks',),
'indeksene': ('indeks',),
'indekser': ('indeks',),
'indeksfamilie': ('indeksfamilie',),
'indeksfamilien': ('indeksfamilie',),
'indeksfamiliene': ('indeksfamilie',),
'indeksfamilier': ('indeksfamilie',),
'indeksregulering': ('indeksregulering',),
'indeksreguleringa': ('indeksregulering',),
'indeksreguleringen': ('indeksregulering',),
'indeksreguleringene': ('indeksregulering',),
'indeksreguleringer': ('indeksregulering',),
'indekstal': ('indekstal',),
'indekstala': ('indekstal',),
'indekstalene': ('indekstal',),
'indekstalet': ('indekstal',),
'indekstall': ('indekstall',),
'indekstalla': ('indekstall',),
'indekstallene': ('indekstall',),
'indekstallet': ('indekstall',),
'indekstillegg': ('indekstillegg',),
'indekstillegga': ('indekstillegg',),
'indekstilleggene': ('indekstillegg',),
'indekstillegget': ('indekstillegg',),
'inder': ('inder',),
'indere': ('inder',),
'inderen': ('inder',),
'inderer': ('inder',),
'inderne': ('inder',),
'indeterminisme': ('indeterminisme',),
'indeterminismen': ('indeterminisme',),
'indeterminismene': ('indeterminisme',),
'indeterminismer': ('indeterminisme',),
'indeterminist': ('indeterminist',),
'indeterministen': ('indeterminist',),
'indeterministene': ('indeterminist',),
'indeterminister': ('indeterminist',),
'indian summer': ('indian summer',),
'indianer': ('indianer',),
'indianere': ('indianer',),
'indianeren': ('indianer',),
'indianerer': ('indianer',),
'indianerne': ('indianer',),
'indianerfortelling': ('indianerfortelling',),
'indianerfortellinga': ('indianerfortelling',),
'indianerfortellingen': ('indianerfortelling',),
'indianerfortellingene': ('indianerfortelling',),
'indianerfortellinger': ('indianerfortelling',),
'indianerhøvding': ('indianerhøvding',),
'indianerhøvdingen': ('indianerhøvding',),
'indianerhøvdingene': ('indianerhøvding',),
'indianerhøvdinger': ('indianerhøvding',),
'indianerreservat': ('indianerreservat',),
'indianerreservata': ('indianerreservat',),
'indianerreservatene': ('indianerreservat',),
'indianerreservater': ('indianerreservat',),
'indianerreservatet': ('indianerreservat',),
'indianerstamme': ('indianerstamme',),
'indianerstammen': ('indianerstamme',),
'indianerstammene': ('indianerstamme',),
'indianerstammer': ('indianerstamme',),
'indifferens': ('indifferens',),
'indifferensen': ('indifferens',),
'indifferensene': ('indifferens',),
'indifferenser': ('indifferens',),
'indifferentisme': ('indifferentisme',),
'indifferentismen': ('indifferentisme',),
'indifferentismene': ('indifferentisme',),
'indifferentismer': ('indifferentisme',),
'indignasjon': ('indignasjon',),
'indignasjonen': ('indignasjon',),
'indignasjonene': ('indignasjon',),
'indignasjoner': ('indignasjon',),
'indigo': ('indigo',),
'indigoen': ('indigo',),
'indigoene': ('indigo',),
'indigoer': ('indigo',),
'indigoblått': ('indigoblått',),
'indikasjon': ('indikasjon',),
'indikasjonen': ('indikasjon',),
'indikasjonene': ('indikasjon',),
'indikasjoner': ('indikasjon',),
'indikativ': ('indikativ',),
'indikativen': ('indikativ',),
'indikativene': ('indikativ',),
'indikativer': ('indikativ',),
'indikator': ('indikator',),
'indikatoren': ('indikator',),
'indikatorene': ('indikator',),
'indikatorer': ('indikator',),
'indisiebevis': ('indisiebevis',),
'indisiebevisa': ('indisiebevis',),
'indisiebevisene': ('indisiebevis',),
'indisiebeviser': ('indisiebevis',),
'indisiebeviset': ('indisiebevis',),
'indisia': ('indisium',),
'indisiene': ('indisium',),
'indisier': ('indisium',),
'indisiet': ('indisium',),
'indisium': ('indisium',),
'indisk': ('indisk',),
'indisken': ('indisk',),
'indiskene': ('indisk',),
'indisker': ('indisk',),
'indiskresjon': ('indiskresjon',),
'indiskresjonen': ('indiskresjon',),
'indiskresjonene': ('indiskresjon',),
'indiskresjoner': ('indiskresjon',),
'indisposisjon': ('indisposisjon',),
'indisposisjonen': ('indisposisjon',),
'indisposisjonene': ('indisposisjon',),
'indisposisjoner': ('indisposisjon',),
'indium': ('indium',),
'indiuma': ('indium',),
'indiumene': ('indium',),
'indiumet': ('indium',),
'individ': ('individ',),
'individa': ('individ',),
'individene': ('individ',),
'individer': ('individ',),
'individet': ('individ',),
'individualisme': ('individualisme',),
'individualismen': ('individualisme',),
'individualismene': ('individualisme',),
'individualismer': ('individualisme',),
'individualist': ('individualist',),
'individualisten': ('individualist',),
'individualistene': ('individualist',),
'individualister': ('individualist',),
'individualitet': ('individualitet',),
'individualiteten': ('individualitet',),
'individualitetene': ('individualitet',),
'individualiteter': ('individualitet',),
'individualpsykologi': ('individualpsykologi',),
'individualpsykologien': ('individualpsykologi',),
'individualpsykologiene': ('individualpsykologi',),
'individualpsykologier': ('individualpsykologi',),
'individuasjon': ('individuasjon',),
'individuasjonen': ('individuasjon',),
'individuasjonene': ('individuasjon',),
'individuasjoner': ('individuasjon',),
'indoeuropeer': ('indoeuropeer',),
'indoeuropeere': ('indoeuropeer',),
'indoeuropeeren': ('indoeuropeer',),
'indoeuropeerer': ('indoeuropeer',),
'indoeuropeerne': ('indoeuropeer',),
'indoeuropeisk': ('indoeuropeisk',),
'indoeuropeisken': ('indoeuropeisk',),
'indoeuropeiskene': ('indoeuropeisk',),
'indoeuropeisker': ('indoeuropeisk',),
'indokineser': ('indokineser',),
'indokinesere': ('indokineser',),
'indokineseren': ('indokineser',),
'indokineserer': ('indokineser',),
'indokineserne': ('indokineser',),
'indolens': ('indolens',),
'indolensen': ('indolens',),
'indolensene': ('indolens',),
'indolenser': ('indolens',),
'indolog': ('indolog',),
'indologen': ('indolog',),
'indologene': ('indolog',),
'indologer': ('indolog',),
'indologi': ('indologi',),
'indologien': ('indologi',),
'indologiene': ('indologi',),
'indologier': ('indologi',),
'indonesier': ('indonesier',),
'indonesiere': ('indonesier',),
'indonesieren': ('indonesier',),
'indonesierer': ('indonesier',),
'indonesierne': ('indonesier',),
'indre': ('indre',),
'indrefilet': ('indrefilet',),
'indrefileten': ('indrefilet',),
'indrefiletene': ('indrefilet',),
'indrefileter': ('indrefilet',),
'indremedisin': ('indremedisin',),
'indremedisinen': ('indremedisin',),
'indremedisinene': ('indremedisin',),
'indremedisiner': ('indremedisin',),
'indremisjon': ('indremisjon',),
'indremisjonen': ('indremisjon',),
'indremisjonene': ('indremisjon',),
'indremisjoner': ('indremisjon',),
'indresekresjon': ('indresekresjon',),
'indresekresjonen': ('indresekresjon',),
'indresekresjonene': ('indresekresjon',),
'indresekresjoner': ('indresekresjon',),
'indretjeneste': ('indretjeneste',),
'indretjenesten': ('indretjeneste',),
'indretjenestene': ('indretjeneste',),
'indretjenester': ('indretjeneste',),
'induksjon': ('induksjon',),
'induksjonen': ('induksjon',),
'induksjonene': ('induksjon',),
'induksjoner': ('induksjon',),
'induksjonsapparat': ('induksjonsapparat',),
'induksjonsapparata': ('induksjonsapparat',),
'induksjonsapparatene': ('induksjonsapparat',),
'induksjonsapparater': ('induksjonsapparat',),
'induksjonsapparatet': ('induksjonsapparat',),
'induksjonsbevis': ('induksjonsbevis',),
'induksjonsbevisa': ('induksjonsbevis',),
'induksjonsbevisene': ('induksjonsbevis',),
'induksjonsbeviser': ('induksjonsbevis',),
'induksjonsbeviset': ('induksjonsbevis',),
'induksjonsmotor': ('induksjonsmotor',),
'induksjonsmotoren': ('induksjonsmotor',),
'induksjonsmotorene': ('induksjonsmotor',),
'induksjonsmotorer': ('induksjonsmotor',),
'induksjonsspole': ('induksjonsspole',),
'induksjonsspolen': ('induksjonsspole',),
'induksjonsspolene': ('induksjonsspole',),
'induksjonsspoler': ('induksjonsspole',),
'induksjonsstrøm': ('induksjonsstrøm',),
'induksjonsstrømmen': ('induksjonsstrøm',),
'induksjonsstrømmene': ('induksjonsstrøm',),
'induksjonsstrømmer': ('induksjonsstrøm',),
'induktans': ('induktans',),
'induktansen': ('induktans',),
'induktansene': ('induktans',),
'induktanser': ('induktans',),
'induktor': ('induktor',),
'induktoren': ('induktor',),
'induktorene': ('induktor',),
'induktorer': ('induktor',),
'indulgens': ('indulgens',),
'indulgensen': ('indulgens',),
'indulgensene': ('indulgens',),
'indulgenser': ('indulgens',),
'industri': ('industri',),
'industrien': ('industri',),
'industriene': ('industri',),
'industrier': ('industri',),
'industrialisme': ('industrialisme',),
'industrialismen': ('industrialisme',),
'industrialismene': ('industrialisme',),
'industrialismer': ('industrialisme',),
'industriarbeider': ('industriarbeider',),
'industriarbeidere': ('industriarbeider',),
'industriarbeideren': ('industriarbeider',),
'industriarbeiderer': ('industriarbeider',),
'industriarbeiderne': ('industriarbeider',),
'industribedrift': ('industribedrift',),
'industribedriften': ('industribedrift',),
'industribedriftene': ('industribedrift',),
'industribedrifter': ('industribedrift',),
'industribygg': ('industribygg',),
'industribygga': ('industribygg',),
'industribyggene': ('industribygg',),
'industribygget': ('industribygg',),
'industridepartement': ('industridepartement',),
'industridepartementa': ('industridepartement',),
'industridepartementene': ('industridepartement',),
'industridepartementer': ('industridepartement',),
'industridepartementet': ('industridepartement',),
'industrifiska': ('industrifiske',),
'industrifiske': ('industrifiske',),
'industrifiskene': ('industrifiske',),
'industrifisker': ('industrifiske',),
'industrifisket': ('industrifiske',),
'industriforbund': ('industriforbund',),
'industriforbunda': ('industriforbund',),
'industriforbundene': ('industriforbund',),
'industriforbundet': ('industriforbund',),
'industriherre': ('industriherre',),
'industriherren': ('industriherre',),
'industriherrene': ('industriherre',),
'industriherrer': ('industriherre',),
'industriland': ('industriland',),
'industrilanda': ('industriland',),
'industrilandene': ('industriland',),
'industrilandet': ('industriland',),
'industrimagnat': ('industrimagnat',),
'industrimagnaten': ('industrimagnat',),
'industrimagnatene': ('industrimagnat',),
'industrimagnater': ('industrimagnat',),
'industrimekaniker': ('industrimekaniker',),
'industrimekanikere': ('industrimekaniker',),
'industrimekanikeren': ('industrimekaniker',),
'industrimekanikerer': ('industrimekaniker',),
'industrimekanikerne': ('industrimekaniker',),
'industriminister': ('industriminister',),
'industriministere': ('industriminister',),
'industriministeren': ('industriminister',),
'industriministerer': ('industriminister',),
'industriministerne': ('industriminister',),
'industriministre': ('industriminister',),
'industriministrene': ('industriminister',),
'industriministrer': ('industriminister',),
'industriskole': ('industriskole',),
'industriskolen': ('industriskole',),
'industriskolene': ('industriskole',),
'industriskoler': ('industriskole',),
'industrispionasje': ('industrispionasje',),
'industrispionasjen': ('industrispionasje',),
'industrispionasjene': ('industrispionasje',),
'industrispionasjer': ('industrispionasje',),
'industrispor': ('industrispor',),
'industrispora': ('industrispor',),
'industrisporene': ('industrispor',),
'industrisporet': ('industrispor',),
'industristed': ('industristed',),
'industristedene': ('industristed',),
'industristeder': ('industristed',),
'industristedet': ('industristed',),
'industritåka': ('industritåke',),
'industritåke': ('industritåke',),
'industritåken': ('industritåke',),
'industritåkene': ('industritåke',),
'industritåker': ('industritåke',),
'industriutslepp': ('industriutslepp',),
'industriutsleppa': ('industriutslepp',),
'industriutsleppene': ('industriutslepp',),
'industriutsleppet': ('industriutslepp',),
'industriutslipp': ('industriutslipp',),
'industriutslippa': ('industriutslipp',),
'industriutslippene': ('industriutslipp',),
'industriutslippet': ('industriutslipp',),
'industrivekstanlegg': ('industrivekstanlegg',),
'industrivekstanlegga': ('industrivekstanlegg',),
'industrivekstanleggene': ('industrivekstanlegg',),
'industrivekstanlegget': ('industrivekstanlegg',),
'ineffektivitet': ('ineffektivitet',),
'ineffektiviteten': ('ineffektivitet',),
'ineffektivitetene': ('ineffektivitet',),
'ineffektiviteter': ('ineffektivitet',),
'inerti': ('inerti',),
'inertien': ('inerti',),
'inertiene': ('inerti',),
'inertier': ('inerti',),
'inertialsystem': ('inertialsystem',),
'inertialsystema': ('inertialsystem',),
'inertialsystemene': ('inertialsystem',),
'inertialsystemer': ('inertialsystem',),
'inertialsystemet': ('inertialsystem',),
'infami': ('infami',),
'infamien': ('infami',),
'infamiene': ('infami',),
'infamier': ('infami',),
'infamitet': ('infamitet',),
'infamiteten': ('infamitet',),
'infamitetene': ('infamitet',),
'infamiteter': ('infamitet',),
'infanteri': ('infanteri',),
'infanteria': ('infanteri',),
'infanteriene': ('infanteri',),
'infanterier': ('infanteri',),
'infanteriet': ('infanteri',),
'infanteribataljon': ('infanteribataljon',),
'infanteribataljonen': ('infanteribataljon',),
'infanteribataljonene': ('infanteribataljon',),
'infanteribataljoner': ('infanteribataljon',),
'infanteriknapp': ('infanteriknapp',),
'infanteriknappen': ('infanteriknapp',),
'infanteriknappene': ('infanteriknapp',),
'infanteriknapper': ('infanteriknapp',),
'infanteriregiment': ('infanteriregiment',),
'infanteriregimenta': ('infanteriregiment',),
'infanteriregimentene': ('infanteriregiment',),
'infanteriregimenter': ('infanteriregiment',),
'infanteriregimentet': ('infanteriregiment',),
'infanterist': ('infanterist',),
'infanteristen': ('infanterist',),
'infanteristene': ('infanterist',),
'infanterister': ('infanterist',),
'infanterivåpen': ('infanterivåpen',),
'infanterivåpenet': ('infanterivåpen',),
'infanterivåpna': ('infanterivåpen',),
'infanterivåpnene': ('infanterivåpen',),
'infantilisme': ('infantilisme',),
'infantilismen': ('infantilisme',),
'infantilismene': ('infantilisme',),
'infantilismer': ('infantilisme',),
'infarkt': ('infarkt',),
'infarkta': ('infarkt',),
'infarktene': ('infarkt',),
'infarkter': ('infarkt',),
'infarktet': ('infarkt',),
'infeksjon': ('infeksjon',),
'infeksjonen': ('infeksjon',),
'infeksjonene': ('infeksjon',),
'infeksjoner': ('infeksjon',),
'infeksjonssjukdom': ('infeksjonssjukdom',),
'infeksjonssjukdommen': ('infeksjonssjukdom',),
'infeksjonssjukdommene': ('infeksjonssjukdom',),
'infeksjonssjukdommer': ('infeksjonssjukdom',),
'infeksjonssykdom': ('infeksjonssykdom',),
'infeksjonssykdommen': ('infeksjonssykdom',),
'infeksjonssykdommene': ('infeksjonssykdom',),
'infeksjonssykdommer': ('infeksjonssykdom',),
'inferno': ('inferno',),
'infernoa': ('inferno',),
'infernoene': ('inferno',),
'infernoer': ('inferno',),
'infernoet': ('inferno',),
'infiks': ('infiks',),
'infiksa': ('infiks',),
'infiksene': ('infiks',),
'infikser': ('infiks',),
'infikset': ('infiks',),
'infiltrasjon': ('infiltrasjon',),
'infiltrasjonen': ('infiltrasjon',),
'infiltrasjonene': ('infiltrasjon',),
'infiltrasjoner': ('infiltrasjon',),
'infiltrasjonsanlegg': ('infiltrasjonsanlegg',),
'infiltrasjonsanlegga': ('infiltrasjonsanlegg',),
'infiltrasjonsanleggene': ('infiltrasjonsanlegg',),
'infiltrasjonsanlegget': ('infiltrasjonsanlegg',),
'infiltrat': ('infiltrat',),
'infiltrata': ('infiltrat',),
'infiltratene': ('infiltrat',),
'infiltrater': ('infiltrat',),
'infiltratet': ('infiltrat',),
'infiltratør': ('infiltratør',),
'infiltratøren': ('infiltratør',),
'infiltratørene': ('infiltratør',),
'infiltratører': ('infiltratør',),
'infinitesimalregning': ('infinitesimalregning',),
'infinitesimalregninga': ('infinitesimalregning',),
'infinitesimalregningen': ('infinitesimalregning',),
'infinitesimalregningene': ('infinitesimalregning',),
'infinitesimalregninger': ('infinitesimalregning',),
'infinitesimalrekning': ('infinitesimalrekning',),
'infinitesimalrekninga': ('infinitesimalrekning',),
'infinitesimalrekningen': ('infinitesimalrekning',),
'infinitesimalrekningene': ('infinitesimalrekning',),
'infinitesimalrekninger': ('infinitesimalrekning',),
'infinitiv': ('infinitiv',),
'infinitiven': ('infinitiv',),
'infinitivene': ('infinitiv',),
'infinitiver': ('infinitiv',),
'infinitivsmerka': ('infinitivsmerke',),
'infinitivsmerke': ('infinitivsmerke',),
'infinitivsmerkene': ('infinitivsmerke',),
'infinitivsmerker': ('infinitivsmerke',),
'infinitivsmerket': ('infinitivsmerke',),
'infinitt': ('infinitt',),
'infinitta': ('infinitt',),
'infinittene': ('infinitt',),
'infinitter': ('infinitt',),
'infinittet': ('infinitt',),
'inflammasjon': ('inflammasjon',),
'inflammasjonen': ('inflammasjon',),
'inflammasjonene': ('inflammasjon',),
'inflammasjoner': ('inflammasjon',),
'inflasjon': ('inflasjon',),
'inflasjonen': ('inflasjon',),
'inflasjonene': ('inflasjon',),
'inflasjoner': ('inflasjon',),
'infleksibel': ('infleksibel',),
'infleksibela': ('infleksibel',),
'infleksibelene': ('infleksibel',),
'infleksibelet': ('infleksibel',),
'infleksibilitet': ('infleksibilitet',),
'infleksibiliteten': ('infleksibilitet',),
'infleksibilitetene': ('infleksibilitet',),
'infleksibiliteter': ('infleksibilitet',),
'influens': ('influens',),
'influensen': ('influens',),
'influensene': ('influens',),
'influenser': ('influens',),
'influensa': ('influensa',),
'influensaen': ('influensa',),
'influensaene': ('influensa',),
'influensaer': ('influensa',),
'influensområda': ('influensområde',),
'influensområde': ('influensområde',),
'influensområdene': ('influensområde',),
'influensområder': ('influensområde',),
'influensområdet': ('influensområde',),
'info': ('info',),
'infoen': ('info',),
'infoene': ('info',),
'infoer': ('info',),
'informant': ('informant',),
'informanten': ('informant',),
'informantene': ('informant',),
'informanter': ('informant',),
'informasjon': ('informasjon',),
'informasjonen': ('informasjon',),
'informasjonene': ('informasjon',),
'informasjoner': ('informasjon',),
'informasjonskonsulent': ('informasjonskonsulent',),
'informasjonskonsulenten': ('informasjonskonsulent',),
'informasjonskonsulentene': ('informasjonskonsulent',),
'informasjonskonsulenter': ('informasjonskonsulent',),
'informasjonsmateriell': ('informasjonsmateriell',),
'informasjonsmateriella': ('informasjonsmateriell',),
'informasjonsmateriellene': ('informasjonsmateriell',),
'informasjonsmateriellet': ('informasjonsmateriell',),
'informasjonssjef': ('informasjonssjef',),
'informasjonssjefen': ('informasjonssjef',),
'informasjonssjefene': ('informasjonssjef',),
'informasjonssjefer': ('informasjonssjef',),
'informasjonsverdi': ('informasjonsverdi',),
'informasjonsverdien': ('informasjonsverdi',),
'informasjonsverdiene': ('informasjonsverdi',),
'informasjonsverdier': ('informasjonsverdi',),
'informasjonsvitenskap': ('informasjonsvitenskap',),
'informasjonsvitenskapen': ('informasjonsvitenskap',),
'informasjonsvitenskapene': ('informasjonsvitenskap',),
'informasjonsvitenskaper': ('informasjonsvitenskap',),
'informatiker': ('informatiker',),
'informatikere': ('informatiker',),
'informatikeren': ('informatiker',),
'informatikerer': ('informatiker',),
'informatikerne': ('informatiker',),
'informatikk': ('informatikk',),
'informatikken': ('informatikk',),
'informatikkene': ('informatikk',),
'informatikker': ('informatikk',),
'informator': ('informator',),
'informatoren': ('informator',),
'informatorene': ('informator',),
'informatorer': ('informator',),
'informatør': ('informatør',),
'informatøren': ('informatør',),
'informatørene': ('informatør',),
'informatører': ('informatør',),
'infralyd': ('infralyd',),
'infralyden': ('infralyd',),
'infralydene': ('infralyd',),
'infralyder': ('infralyd',),
'infrastruktur': ('infrastruktur',),
'infrastrukturen': ('infrastruktur',),
'infrastrukturene': ('infrastruktur',),
'infrastrukturer': ('infrastruktur',),
'infrastrukturprogram': ('infrastrukturprogram',),
'infrastrukturprogramma': ('infrastrukturprogram',),
'infrastrukturprogrammene': ('infrastrukturprogram',),
'infrastrukturprogrammer': ('infrastrukturprogram',),
'infrastrukturprogrammet': ('infrastrukturprogram',),
'infus': ('infus',),
'infusa': ('infus',),
'infusene': ('infus',),
'infuser': ('infus',),
'infuset': ('infus',),
'infusjon': ('infusjon',),
'infusjonen': ('infusjon',),
'infusjonene': ('infusjon',),
'infusjoner': ('infusjon',),
'infusjonsdyr': ('infusjonsdyr',),
'infusjonsdyra': ('infusjonsdyr',),
'infusjonsdyrene': ('infusjonsdyr',),
'infusjonsdyret': ('infusjonsdyr',),
'infusorie': ('infusorie',),
'infusorien': ('infusorie',),
'infusoriene': ('infusorie',),
'infusorier': ('infusorie',),
'ingefær': ('ingefær',),
'ingefæren': ('ingefær',),
'ingefærene': ('ingefær',),
'ingefærer': ('ingefær',),
'ingefærfamilie': ('ingefærfamilie',),
'ingefærfamilien': ('ingefærfamilie',),
'ingefærfamiliene': ('ingefærfamilie',),
'ingefærfamilier': ('ingefærfamilie',),
'ingefærolja': ('ingefærolje',),
'ingefærolje': ('ingefærolje',),
'ingefæroljen': ('ingefærolje',),
'ingefæroljene': ('ingefærolje',),
'ingefæroljer': ('ingefærolje',),
'ingefærplanta': ('ingefærplante',),
'ingefærplante': ('ingefærplante',),
'ingefærplanten': ('ingefærplante',),
'ingefærplantene': ('ingefærplante',),
'ingefærplanter': ('ingefærplante',),
'ingeniør': ('ingeniør',),
'ingeniøren': ('ingeniør',),
'ingeniørene': ('ingeniør',),
'ingeniører': ('ingeniør',),
'ingeniørhøgskole': ('ingeniørhøgskole',),
'ingeniørhøgskolen': ('ingeniørhøgskole',),
'ingeniørhøgskolene': ('ingeniørhøgskole',),
'ingeniørhøgskoler': ('ingeniørhøgskole',),
'ingeniørhøyskole': ('ingeniørhøyskole',),
'ingeniørhøyskolen': ('ingeniørhøyskole',),
'ingeniørhøyskolene': ('ingeniørhøyskole',),
'ingeniørhøyskoler': ('ingeniørhøyskole',),
'ingeniørvåpen': ('ingeniørvåpen',),
'ingeniørvåpenet': ('ingeniørvåpen',),
'ingeniørvåpna': ('ingeniørvåpen',),
'ingeniørvåpnene': ('ingeniørvåpen',),
'ingenmannsland': ('ingenmannsland',),
'ingenmannslanda': ('ingenmannsland',),
'ingenmannslandene': ('ingenmannsland',),
'ingenmannslandet': ('ingenmannsland',),
'ingenting': ('ingenting',),
'ingenue': ('ingenue',),
'ingenuen': ('ingenue',),
'ingenuene': ('ingenue',),
'ingenuer': ('ingenue',),
'ingrediens': ('ingrediens',),
'ingrediensen': ('ingrediens',),
'ingrediensene': ('ingrediens',),
'ingredienser': ('ingrediens',),
'ingress': ('ingress',),
'ingressen': ('ingress',),
'ingressene': ('ingress',),
'ingresser': ('ingress',),
'inhabilitet': ('inhabilitet',),
'inhabiliteten': ('inhabilitet',),
'inhabilitetene': ('inhabilitet',),
'inhabiliteter': ('inhabilitet',),
'inhalasjon': ('inhalasjon',),
'inhalasjonen': ('inhalasjon',),
'inhalasjonene': ('inhalasjon',),
'inhalasjoner': ('inhalasjon',),
'inhalator': ('inhalator',),
'inhalatoren': ('inhalator',),
'inhalatorene': ('inhalator',),
'inhalatorer': ('inhalator',),
'inherens': ('inherens',),
'inherensen': ('inherens',),
'inherensene': ('inherens',),
'inherenser': ('inherens',),
'inhibisjon': ('inhibisjon',),
'inhibisjonen': ('inhibisjon',),
'inhibisjonene': ('inhibisjon',),
'inhibisjoner': ('inhibisjon',),
'inhibitor': ('inhibitor',),
'inhibitoren': ('inhibitor',),
'inhibitorene': ('inhibitor',),
'inhibitorer': ('inhibitor',),
'inhumanitet': ('inhumanitet',),
'inhumaniteten': ('inhumanitet',),
'inhumanitetene': ('inhumanitet',),
'inhumaniteter': ('inhumanitet',),
'initial': ('initial',),
'initialen': ('initial',),
'initialene': ('initial',),
'initialer': ('initial',),
'initialord': ('initialord',),
'initialorda': ('initialord',),
'initialordene': ('initialord',),
'initialordet': ('initialord',),
'initiativ': ('initiativ',),
'initiativa': ('initiativ',),
'initiativene': ('initiativ',),
'initiativer': ('initiativ',),
'initiativet': ('initiativ',),
'initiativtaker': ('initiativtaker',),
'initiativtakere': ('initiativtaker',),
'initiativtakeren': ('initiativtaker',),
'initiativtakerer': ('initiativtaker',),
'initiativtakerne': ('initiativtaker',),
'injeksjon': ('injeksjon',),
'injeksjonen': ('injeksjon',),
'injeksjonene': ('injeksjon',),
'injeksjoner': ('injeksjon',),
'injektor': ('injektor',),
'injektoren': ('injektor',),
'injektorene': ('injektor',),
'injektorer': ('injektor',),
'injuriant': ('injuriant',),
'injurianten': ('injuriant',),
'injuriantene': ('injuriant',),
'injurianter': ('injuriant',),
'injuriat': ('injuriat',),
'injuriaten': ('injuriat',),
'injuriatene': ('injuriat',),
'injuriater': ('injuriat',),
'injurie': ('injurie',),
'injurien': ('injurie',),
'injuriene': ('injurie',),
'injurier': ('injurie',),
'injuriesak': ('injuriesak',),
'injuriesaka': ('injuriesak',),
'injuriesaken': ('injuriesak',),
'injuriesakene': ('injuriesak',),
'injuriesaker': ('injuriesak',),
'injuriesøksmål': ('injuriesøksmål',),
'injuriesøksmåla': ('injuriesøksmål',),
'injuriesøksmålene': ('injuriesøksmål',),
'injuriesøksmålet': ('injuriesøksmål',),
'inka': ('inka',),
'inkaen': ('inka',),
'inkaene': ('inka',),
'inkaer': ('inka',),
'inkarnasjon': ('inkarnasjon',),
'inkarnasjonen': ('inkarnasjon',),
'inkarnasjonene': ('inkarnasjon',),
'inkarnasjoner': ('inkarnasjon',),
'inkassasjon': ('inkassasjon',),
'inkassasjonen': ('inkassasjon',),
'inkassasjonene': ('inkassasjon',),
'inkassasjoner': ('inkassasjon',),
'inkassator': ('inkassator',),
'inkassatoren': ('inkassator',),
'inkassatorene': ('inkassator',),
'inkassatorer': ('inkassator',),
'inkasso': ('inkasso',),
'inkassoen': ('inkasso',),
'inkassoene': ('inkasso',),
'inkassoer': ('inkasso',),
'inkassobyrå': ('inkassobyrå',),
'inkassobyråa': ('inkassobyrå',),
'inkassobyråene': ('inkassobyrå',),
'inkassobyråer': ('inkassobyrå',),
'inkassobyrået': ('inkassobyrå',),
'inklinasjon': ('inklinasjon',),
'inklinasjonen': ('inklinasjon',),
'inklinasjonene': ('inklinasjon',),
'inklinasjoner': ('inklinasjon',),
'inklinasjonsparti': ('inklinasjonsparti',),
'inklinasjonspartia': ('inklinasjonsparti',),
'inklinasjonspartiene': ('inklinasjonsparti',),
'inklinasjonspartier': ('inklinasjonsparti',),
'inklinasjonspartiet': ('inklinasjonsparti',),
'inkoativ': ('inkoativ',),
'inkoativa': ('inkoativ',),
'inkoativene': ('inkoativ',),
'inkoativer': ('inkoativ',),
'inkoativet': ('inkoativ',),
'inkognito': ('inkognito',),
'inkognitoa': ('inkognito',),
'inkognitoene': ('inkognito',),
'inkognitoer': ('inkognito',),
'inkognitoet': ('inkognito',),
'inkolentnavn': ('inkolentnavn',),
'inkolentnavna': ('inkolentnavn',),
'inkolentnavnene': ('inkolentnavn',),
'inkolentnavnet': ('inkolentnavn',),
'inkompetanse': ('inkompetanse',),
'inkompetansen': ('inkompetanse',),
'inkompetansene': ('inkompetanse',),
'inkompetanser': ('inkompetanse',),
'inkongruens': ('inkongruens',),
'inkongruensen': ('inkongruens',),
'inkongruensene': ('inkongruens',),
'inkongruenser': ('inkongruens',),
'inkonsekvens': ('inkonsekvens',),
'inkonsekvensen': ('inkonsekvens',),
'inkonsekvensene': ('inkonsekvens',),
'inkonsekvenser': ('inkonsekvens',),
'inkontinens': ('inkontinens',),
'inkontinensen': ('inkontinens',),
'inkontinensene': ('inkontinens',),
'inkontinenser': ('inkontinens',),
'inkorporasjon': ('inkorporasjon',),
'inkorporasjonen': ('inkorporasjon',),
'inkorporasjonene': ('inkorporasjon',),
'inkorporasjoner': ('inkorporasjon',),
'inkubasjon': ('inkubasjon',),
'inkubasjonen': ('inkubasjon',),
'inkubasjonene': ('inkubasjon',),
'inkubasjoner': ('inkubasjon',),
'inkubasjonstid': ('inkubasjonstid',),
'inkubasjonstida': ('inkubasjonstid',),
'inkubasjonstiden': ('inkubasjonstid',),
'inkubasjonstidene': ('inkubasjonstid',),
'inkubasjonstider': ('inkubasjonstid',),
'inkubator': ('inkubator',),
'inkubatoren': ('inkubator',),
'inkubatorene': ('inkubator',),
'inkubatorer': ('inkubator',),
'inkunabel': ('inkunabel',),
'inkunabelen': ('inkunabel',),
'inkunablene': ('inkunabel',),
'inkunabler': ('inkunabel',),
'inkurie': ('inkurie',),
'inkurien': ('inkurie',),
'inkuriene': ('inkurie',),
'inkurier': ('inkurie',),
'inkvisisjon': ('inkvisisjon',),
'inkvisisjonen': ('inkvisisjon',),
'inkvisisjonene': ('inkvisisjon',),
'inkvisisjoner': ('inkvisisjon',),
'inkvisitor': ('inkvisitor',),
'inkvisitoren': ('inkvisitor',),
'inkvisitorene': ('inkvisitor',),
'inkvisitorer': ('inkvisitor',),
'innadørsidrett': ('innadørsidrett',),
'innadørsidretten': ('innadørsidrett',),
'innadørsidrettene': ('innadørsidrett',),
'innadørsidretter': ('innadørsidrett',),
'innadørstrening': ('innadørstrening',),
'innadørstreninga': ('innadørstrening',),
'innadørstreningen': ('innadørstrening',),
'innadørstreningene': ('innadørstrening',),
'innadørstreninger': ('innadørstrening',),
'innariksdepartement': ('innariksdepartement',),
'innariksdepartementa': ('innariksdepartement',),
'innariksdepartementene': ('innariksdepartement',),
'innariksdepartementer': ('innariksdepartement',),
'innariksdepartementet': ('innariksdepartement',),
'innariksfart': ('innariksfart',),
'innariksfarten': ('innariksfart',),
'innariksfartene': ('innariksfart',),
'innariksfarter': ('innariksfart',),
'innarikspolitikk': ('innarikspolitikk',),
'innarikspolitikken': ('innarikspolitikk',),
'innarikspolitikkene': ('innarikspolitikk',),
'innarikspolitikker': ('innarikspolitikk',),
'innavl': ('innavl',),
'innavlen': ('innavl',),
'innavlene': ('innavl',),
'innavler': ('innavl',),
'innbegrep': ('innbegrep',),
'innbegrepa': ('innbegrep',),
'innbegrepene': ('innbegrep',),
'innbegreper': ('innbegrep',),
'innbegrepet': ('innbegrep',),
'innberetning': ('innberetning',),
'innberetninga': ('innberetning',),
'innberetningen': ('innberetning',),
'innberetningene': ('innberetning',),
'innberetninger': ('innberetning',),
'innbetalingskort': ('innbetalingskort',),
'innbetalingskorta': ('innbetalingskort',),
'innbetalingskortene': ('innbetalingskort',),
'innbetalingskortet': ('innbetalingskort',),
'innbilning': ('innbilning',),
'innbilninga': ('innbilning',),
'innbilningen': ('innbilning',),
'innbilningene': ('innbilning',),
'innbilninger': ('innbilning',),
'innbilningskraft': ('innbilningskraft',),
'innbilningskrafta': ('innbilningskraft',),
'innbilningskraften': ('innbilningskraft',),
'innbilningskreftene': ('innbilningskraft',),
'innbilningskrefter': ('innbilningskraft',),
'innbinding': ('innbinding',),
'innbindinga': ('innbinding',),
'innbindingen': ('innbinding',),
'innbindingene': ('innbinding',),
'innbindinger': ('innbinding',),
'innblanding': ('innblanding',),
'innblandinga': ('innblanding',),
'innblandingen': ('innblanding',),
'innblandingene': ('innblanding',),
'innblandinger': ('innblanding',),
'innblikk': ('innblikk',),
'innblikka': ('innblikk',),
'innblikkene': ('innblikk',),
'innblikket': ('innblikk',),
'innbo': ('innbo',),
'innboa': ('innbo',),
'innboene': ('innbo',),
'innboer': ('innbo',),
'innboet': ('innbo',),
'innbrott': ('innbrott',),
'innbrotta': ('innbrott',),
'innbrottene': ('innbrott',),
'innbrottet': ('innbrott',),
'innbrottsforsikring': ('innbrottsforsikring',),
'innbrottsforsikringa': ('innbrottsforsikring',),
'innbrottsforsikringen': ('innbrottsforsikring',),
'innbrottsforsikringene': ('innbrottsforsikring',),
'innbrottsforsikringer': ('innbrottsforsikring',),
'innbrottstjuv': ('innbrottstjuv',),
'innbrottstjuven': ('innbrottstjuv',),
'innbrottstjuvene': ('innbrottstjuv',),
'innbrottstjuver': ('innbrottstjuv',),
'innbrottstjuveri': ('innbrottstjuveri',),
'innbrottstjuveria': ('innbrottstjuveri',),
'innbrottstjuveriene': ('innbrottstjuveri',),
'innbrottstjuverier': ('innbrottstjuveri',),
'innbrottstjuveriet': ('innbrottstjuveri',),
'innbrottstyv': ('innbrottstyv',),
'innbrottstyven': ('innbrottstyv',),
'innbrottstyvene': ('innbrottstyv',),
'innbrottstyver': ('innbrottstyv',),
'innbrottstyveri': ('innbrottstyveri',),
'innbrottstyveria': ('innbrottstyveri',),
'innbrottstyveriene': ('innbrottstyveri',),
'innbrottstyverier': ('innbrottstyveri',),
'innbrottstyveriet': ('innbrottstyveri',),
'innbrudd': ('innbrudd',),
'innbrudda': ('innbrudd',),
'innbruddene': ('innbrudd',),
'innbruddet': ('innbrudd',),
'innbruddsforsikring': ('innbruddsforsikring',),
'innbruddsforsikringa': ('innbruddsforsikring',),
'innbruddsforsikringen': ('innbruddsforsikring',),
'innbruddsforsikringene': ('innbruddsforsikring',),
'innbruddsforsikringer': ('innbruddsforsikring',),
'innbruddstjuv': ('innbruddstjuv',),
'innbruddstjuven': ('innbruddstjuv',),
'innbruddstjuvene': ('innbruddstjuv',),
'innbruddstjuver': ('innbruddstjuv',),
'innbruddstjuveri': ('innbruddstjuveri',),
'innbruddstjuveria': ('innbruddstjuveri',),
'innbruddstjuveriene': ('innbruddstjuveri',),
'innbruddstjuverier': ('innbruddstjuveri',),
'innbruddstjuveriet': ('innbruddstjuveri',),
'innbruddstyv': ('innbruddstyv',),
'innbruddstyven': ('innbruddstyv',),
'innbruddstyvene': ('innbruddstyv',),
'innbruddstyver': ('innbruddstyv',),
'innbruddstyveri': ('innbruddstyveri',),
'innbruddstyveria': ('innbruddstyveri',),
'innbruddstyveriene': ('innbruddstyveri',),
'innbruddstyverier': ('innbruddstyveri',),
'innbruddstyveriet': ('innbruddstyveri',),
'innbryter': ('innbryter',),
'innbrytere': ('innbryter',),
'innbryteren': ('innbryter',),
'innbryterer': ('innbryter',),
'innbryterne': ('innbryter',),
'innbu': ('innbu',),
'innbua': ('innbu',),
'innbuene': ('innbu',),
'innbuer': ('innbu',),
'innbuet': ('innbu',),
'innbydelse': ('innbydelse',),
'innbydelsen': ('innbydelse',),
'innbydelsene': ('innbydelse',),
'innbydelser': ('innbydelse',),
'innbydelseskort': ('innbydelseskort',),
'innbydelseskorta': ('innbydelseskort',),
'innbydelseskortene': ('innbydelseskort',),
'innbydelseskortet': ('innbydelseskort',),
'innbyder': ('innbyder',),
'innbydere': ('innbyder',),
'innbyderen': ('innbyder',),
'innbyderer': ('innbyder',),
'innbyderne': ('innbyder',),
'innbygger': ('innbygger',),
'innbyggere': ('innbygger',),
'innbyggeren': ('innbygger',),
'innbyggerer': ('innbygger',),
'innbyggerne': ('innbygger',),
'innbytta': ('innbytte',),
'innbytte': ('innbytte',),
'innbyttene': ('innbytte',),
'innbytter': ('innbytte',),
'innbyttet': ('innbytte',),
'innbyttepris': ('innbyttepris',),
'innbytteprisen': ('innbyttepris',),
'innbytteprisene': ('innbyttepris',),
'innbyttepriser': ('innbyttepris',),
'innbytter': ('innbytter',),
'innbyttere': ('innbytter',),
'innbytteren': ('innbytter',),
'innbytterer': ('innbytter',),
'innbytterne': ('innbytter',),
'inndata': ('inndata',),
'inndataen': ('inndata',),
'inndataene': ('inndata',),
'inndataet': ('inndata',),
'inndeling': ('inndeling',),
'inndelinga': ('inndeling',),
'inndelingen': ('inndeling',),
'inndelingene': ('inndeling',),
'inndelinger': ('inndeling',),
'inndraging': ('inndraging',),
'inndraginga': ('inndraging',),
'inndragingen': ('inndraging',),
'inndragingene': ('inndraging',),
'inndraginger': ('inndraging',),
'inndragning': ('inndragning',),
'inndragninga': ('inndragning',),
'inndragningen': ('inndragning',),
'inndragningene': ('inndragning',),
'inndragninger': ('inndragning',),
'inndraing': ('inndraing',),
'inndrainga': ('inndraing',),
'inndraingen': ('inndraing',),
'inndraingene': ('inndraing',),
'inndrainger': ('inndraing',),
'innearbeid': ('innearbeid',),
'innearbeida': ('innearbeid',),
'innearbeidene': ('innearbeid',),
'innearbeider': ('innearbeid',),
'innearbeidet': ('innearbeid',),
'innebruk': ('innebruk',),
'innebruka': ('innebruk',),
'innebruken': ('innebruk',),
'innebrukene': ('innebruk',),
'innebruker': ('innebruk',),
'innebruket': ('innebruk',),
'innehaver': ('innehaver',),
'innehavere': ('innehaver',),
'innehaveren': ('innehaver',),
'innehaverer': ('innehaver',),
'innehaverne': ('innehaver',),
'inneklima': ('inneklima',),
'inneklimaene': ('inneklima',),
'inneklimaer': ('inneklima',),
'inneklimaet': ('inneklima',),
'inneklær': ('inneklær',),
'inneklærne': ('inneklær',),
'innelukka': ('innelukke',),
'innelukke': ('innelukke',),
'innelukkene': ('innelukke',),
'innelukker': ('innelukke',),
'innelukket': ('innelukke',),
'innendørsidrett': ('innendørsidrett',),
'innendørsidretten': ('innendørsidrett',),
'innendørsidrettene': ('innendørsidrett',),
'innendørsidretter': ('innendørsidrett',),
'innendørstrening': ('innendørstrening',),
'innendørstreninga': ('innendørstrening',),
'innendørstreningen': ('innendørstrening',),
'innendørstreningene': ('innendørstrening',),
'innendørstreninger': ('innendørstrening',),
'innenriksdepartement': ('innenriksdepartement',),
'innenriksdepartementa': ('innenriksdepartement',),
'innenriksdepartementene': ('innenriksdepartement',),
'innenriksdepartementer': ('innenriksdepartement',),
'innenriksdepartementet': ('innenriksdepartement',),
'innenriksfart': ('innenriksfart',),
'innenriksfarten': ('innenriksfart',),
'innenriksfartene': ('innenriksfart',),
'innenriksfarter': ('innenriksfart',),
'innenrikspolitikk': ('innenrikspolitikk',),
'innenrikspolitikken': ('innenrikspolitikk',),
'innenrikspolitikkene': ('innenrikspolitikk',),
'innenrikspolitikker': ('innenrikspolitikk',),
'innerblink': ('innerblink',),
'innerblinken': ('innerblink',),
'innerblinkene': ('innerblink',),
'innerblinker': ('innerblink',),
'innerdør': ('innerdør',),
'innerdøra': ('innerdør',),
'innerdøren': ('innerdør',),
'innerdørene': ('innerdør',),
'innerdører': ('innerdør',),
'innerlomma': ('innerlomme',),
'innerlomme': ('innerlomme',),
'innerlommen': ('innerlomme',),
'innerlommene': ('innerlomme',),
'innerlommer': ('innerlomme',),
'innersida': ('innerside',),
'innerside': ('innerside',),
'innersiden': ('innerside',),
'innersidene': ('innerside',),
'innersider': ('innerside',),
'innerskjerm': ('innerskjerm',),
'innerskjermen': ('innerskjerm',),
'innerskjermene': ('innerskjerm',),
'innerskjermer': ('innerskjerm',),
'innerst': ('innerst',),
'innersten': ('innerst',),
'innerstene': ('innerst',),
'innerster': ('innerst',),
'innerste': ('innerste',),
'innersving': ('innersving',),
'innersvingen': ('innersving',),
'innersvingene': ('innersving',),
'innersvinger': ('innersving',),
'innertelt': ('innertelt',),
'innertelta': ('innertelt',),
'innerteltene': ('innertelt',),
'innertelter': ('innertelt',),
'innerteltet': ('innertelt',),
'innertier': ('innertier',),
'innertiere': ('innertier',),
'innertieren': ('innertier',),
'innertierer': ('innertier',),
'innertierne': ('innertier',),
'innervegg': ('innervegg',),
'innerveggen': ('innervegg',),
'innerveggene': ('innervegg',),
'innervegger': ('innervegg',),
'innervindu': ('innervindu',),
'innervindua': ('innervindu',),
'innervinduene': ('innervindu',),
'innervinduer': ('innervindu',),
'innervinduet': ('innervindu',),
'innesitter': ('innesitter',),
'innesittere': ('innesitter',),
'innesitteren': ('innesitter',),
'innesitterer': ('innesitter',),
'innesitterne': ('innesitter',),
'innesluttethet': ('innesluttethet',),
'innesluttetheta': ('innesluttethet',),
'innesluttetheten': ('innesluttethet',),
'innesluttethetene': ('innesluttethet',),
'innesluttetheter': ('innesluttethet',),
'inneståenda': ('innestående',),
'innestående': ('innestående',),
'inneståendene': ('innestående',),
'inneståender': ('innestående',),
'inneståendet': ('innestående',),
'innfall': ('innfall',),
'innfalla': ('innfall',),
'innfallene': ('innfall',),
'innfallet': ('innfall',),
'innfallslodd': ('innfallslodd',),
'innfallslodda': ('innfallslodd',),
'innfallsloddene': ('innfallslodd',),
'innfallslodder': ('innfallslodd',),
'innfallsloddet': ('innfallslodd',),
'innfallsport': ('innfallsport',),
'innfallsporten': ('innfallsport',),
'innfallsportene': ('innfallsport',),
'innfallsporter': ('innfallsport',),
'innfallsvinkel': ('innfallsvinkel',),
'innfallsvinkelen': ('innfallsvinkel',),
'innfallsvinklene': ('innfallsvinkel',),
'innfallsvinkler': ('innfallsvinkel',),
'innfart': ('innfart',),
'innfarten': ('innfart',),
'innfartene': ('innfart',),
'innfarter': ('innfart',),
'innfartsparkering': ('innfartsparkering',),
'innfartsparkeringa': ('innfartsparkering',),
'innfartsparkeringen': ('innfartsparkering',),
'innfartsparkeringene': ('innfartsparkering',),
'innfartsparkeringer': ('innfartsparkering',),
'innfartsveg': ('innfartsveg',),
'innfartsvegen': ('innfartsveg',),
'innfartsvegene': ('innfartsveg',),
'innfartsveger': ('innfartsveg',),
'innfartsvei': ('innfartsvei',),
'innfartsveien': ('innfartsvei',),
'innfartsveiene': ('innfartsvei',),
'innfartsveier': ('innfartsvei',),
'innfatning': ('innfatning',),
'innfatninga': ('innfatning',),
'innfatningen': ('innfatning',),
'innfatningene': ('innfatning',),
'innfatninger': ('innfatning',),
'innfelling': ('innfelling',),
'innfellinga': ('innfelling',),
'innfellingen': ('innfelling',),
'innfellingene': ('innfelling',),
'innfellinger': ('innfelling',),
'innflyging': ('innflyging',),
'innflyginga': ('innflyging',),
'innflygingen': ('innflyging',),
'innflygingene': ('innflyging',),
'innflyginger': ('innflyging',),
'innflying': ('innflying',),
'innflyinga': ('innflying',),
'innflyingen': ('innflying',),
'innflyingene': ('innflying',),
'innflyinger': ('innflying',),
'innflytelse': ('innflytelse',),
'innflytelsen': ('innflytelse',),
'innflytelsene': ('innflytelse',),
'innflytelser': ('innflytelse',),
'innflytning': ('innflytning',),
'innflytninga': ('innflytning',),
'innflytningen': ('innflytning',),
'innflytningene': ('innflytning',),
'innflytninger': ('innflytning',),
'innflytter': ('innflytter',),
'innflyttere': ('innflytter',),
'innflytteren': ('innflytter',),
'innflytterer': ('innflytter',),
'innflytterne': ('innflytter',),
'innflytterungdom': ('innflytterungdom',),
'innflytterungdommen': ('innflytterungdom',),
'innflytterungdommene': ('innflytterungdom',),
'innflytterungdommer': ('innflytterungdom',),
'innflytting': ('innflytting',),
'innflyttinga': ('innflytting',),
'innflyttingen': ('innflytting',),
'innflyttingene': ('innflytting',),
'innflyttinger': ('innflytting',),
'innforlivelse': ('innforlivelse',),
'innforlivelsen': ('innforlivelse',),
'innforlivelsene': ('innforlivelse',),
'innforlivelser': ('innforlivelse',),
'innfrysing': ('innfrysing',),
'innfrysinga': ('innfrysing',),
'innfrysingen': ('innfrysing',),
'innfrysingene': ('innfrysing',),
'innfrysinger': ('innfrysing',),
'innfødsrett': ('innfødsrett',),
'innfødsretten': ('innfødsrett',),
'innfødsrettene': ('innfødsrett',),
'innfødsretter': ('innfødsrett',),
'innføring': ('innføring',),
'innføringa': ('innføring',),
'innføringen': ('innføring',),
'innføringene': ('innføring',),
'innføringer': ('innføring',),
'innførsel': ('innførsel',),
'innførselen': ('innførsel',),
'innførslene': ('innførsel',),
'innførsler': ('innførsel',),
'innførselsregulering': ('innførselsregulering',),
'innførselsreguleringa': ('innførselsregulering',),
'innførselsreguleringen': ('innførselsregulering',),
'innførselsreguleringene': ('innførselsregulering',),
'innførselsreguleringer': ('innførselsregulering',),
'innførselstoll': ('innførselstoll',),
'innførselstollen': ('innførselstoll',),
'innførselstollene': ('innførselstoll',),
'innførselstoller': ('innførselstoll',),
'innførselsvara': ('innførselsvare',),
'innførselsvare': ('innførselsvare',),
'innførselsvaren': ('innførselsvare',),
'innførselsvarene': ('innførselsvare',),
'innførselsvarer': ('innførselsvare',),
'inngang': ('inngang',),
'inngangen': ('inngang',),
'inngangene': ('inngang',),
'innganger': ('inngang',),
'inngangsbillett': ('inngangsbillett',),
'inngangsbilletten': ('inngangsbillett',),
'inngangsbillettene': ('inngangsbillett',),
'inngangsbilletter': ('inngangsbillett',),
'inngangsbønn': ('inngangsbønn',),
'inngangsbønna': ('inngangsbønn',),
'inngangsbønnen': ('inngangsbønn',),
'inngangsbønnene': ('inngangsbønn',),
'inngangsbønner': ('inngangsbønn',),
'inngangsdør': ('inngangsdør',),
'inngangsdøra': ('inngangsdør',),
'inngangsdøren': ('inngangsdør',),
'inngangsdørene': ('inngangsdør',),
'inngangsdører': ('inngangsdør',),
'inngangspengene': ('inngangspenger',),
'inngangspenger': ('inngangspenger',),
'inngjerding': ('inngjerding',),
'inngjerdinga': ('inngjerding',),
'inngjerdingen': ('inngjerding',),
'inngjerdingene': ('inngjerding',),
'inngjerdinger': ('inngjerding',),
'inngrep': ('inngrep',),
'inngrepa': ('inngrep',),
'inngrepene': ('inngrep',),
'inngrepet': ('inngrep',),
'inngripen': ('inngripen',),
'inngripenen': ('inngripen',),
'inngripenene': ('inngripen',),
'inngripener': ('inngripen',),
'inngåelse': ('inngåelse',),
'inngåelsen': ('inngåelse',),
'inngåelsene': ('inngåelse',),
'inngåelser': ('inngåelse',),
'inngående': ('inngående',),
'innhakk': ('innhakk',),
'innhakka': ('innhakk',),
'innhakkene': ('innhakk',),
'innhakket': ('innhakk',),
'innhav': ('innhav',),
'innhava': ('innhav',),
'innhavene': ('innhav',),
'innhavet': ('innhav',),
'innhegning': ('innhegning',),
'innhegninga': ('innhegning',),
'innhegningen': ('innhegning',),
'innhegningene': ('innhegning',),
'innhegninger': ('innhegning',),
'innhogg': ('innhogg',),
'innhogga': ('innhogg',),
'innhoggene': ('innhogg',),
'innhogget': ('innhogg',),
'innhold': ('innhold',),
'innholda': ('innhold',),
'innholdene': ('innhold',),
'innholdet': ('innhold',),
'innholdsfortegnelse': ('innholdsfortegnelse',),
'innholdsfortegnelsen': ('innholdsfortegnelse',),
'innholdsfortegnelsene': ('innholdsfortegnelse',),
'innholdsfortegnelser': ('innholdsfortegnelse',),
'innholdslista': ('innholdsliste',),
'innholdsliste': ('innholdsliste',),
'innholdslisten': ('innholdsliste',),
'innholdslistene': ('innholdsliste',),
'innholdslister': ('innholdsliste',),
'innhukk': ('innhukk',),
'innhukka': ('innhukk',),
'innhukkene': ('innhukk',),
'innhukket': ('innhukk',),
'innhøsting': ('innhøsting',),
'innhøstinga': ('innhøsting',),
'innhøstingen': ('innhøsting',),
'innhøstingene': ('innhøsting',),
'innhøstinger': ('innhøsting',),
'innhøstning': ('innhøstning',),
'innhøstninga': ('innhøstning',),
'innhøstningen': ('innhøstning',),
'innhøstningene': ('innhøstning',),
'innhøstninger': ('innhøstning',),
'innkallelse': ('innkallelse',),
'innkallelsen': ('innkallelse',),
'innkallelsene': ('innkallelse',),
'innkallelser': ('innkallelse',),
'innkalling': ('innkalling',),
'innkallinga': ('innkalling',),
'innkallingen': ('innkalling',),
'innkallingene': ('innkalling',),
'innkallinger': ('innkalling',),
'innkallingsordre': ('innkallingsordre',),
'innkallingsordren': ('innkallingsordre',),
'innkallingsordrene': ('innkallingsordre',),
'innkallingsordrer': ('innkallingsordre',),
'innkast': ('innkast',),
'innkasta': ('innkast',),
'innkastene': ('innkast',),
'innkastet': ('innkast',),
'innkik': ('innkik',),
'innkika': ('innkik',),
'innkiken': ('innkik',),
'innkikene': ('innkik',),
'innkiket': ('innkik',),
'innkikk': ('innkikk',),
'innkikka': ('innkikk',),
'innkikken': ('innkikk',),
'innkikkene': ('innkikk',),
'innkikket': ('innkikk',),
'innkjøp': ('innkjøp',),
'innkjøpa': ('innkjøp',),
'innkjøpene': ('innkjøp',),
'innkjøpet': ('innkjøp',),
'innkjøper': ('innkjøper',),
'innkjøpere': ('innkjøper',),
'innkjøperen': ('innkjøper',),
'innkjøperer': ('innkjøper',),
'innkjøperne': ('innkjøper',),
'innkjøpslag': ('innkjøpslag',),
'innkjøpslaga': ('innkjøpslag',),
'innkjøpslagene': ('innkjøpslag',),
'innkjøpslaget': ('innkjøpslag',),
'innkjøpspris': ('innkjøpspris',),
'innkjøpsprisen': ('innkjøpspris',),
'innkjøpsprisene': ('innkjøpspris',),
'innkjøpspriser': ('innkjøpspris',),
'innkjøpssjef': ('innkjøpssjef',),
'innkjøpssjefen': ('innkjøpssjef',),
'innkjøpssjefene': ('innkjøpssjef',),
'innkjøpssjefer': ('innkjøpssjef',),
'innkjøring': ('innkjøring',),
'innkjøringa': ('innkjøring',),
'innkjøringen': ('innkjøring',),
'innkjøringene': ('innkjøring',),
'innkjøringer': ('innkjøring',),
'innkjøringsperiode': ('innkjøringsperiode',),
'innkjøringsperioden': ('innkjøringsperiode',),
'innkjøringsperiodene': ('innkjøringsperiode',),
'innkjøringsperioder': ('innkjøringsperiode',),
'innkjørsel': ('innkjørsel',),
'innkjørselen': ('innkjørsel',),
'innkjørsla': ('innkjørsel',),
'innkjørslene': ('innkjørsel',),
'innkjørsler': ('innkjørsel',),
'innkoking': ('innkoking',),
'innkokinga': ('innkoking',),
'innkokingen': ('innkoking',),
'innkokingene': ('innkoking',),
'innkokinger': ('innkoking',),
'innkommanderingstillegg': ('innkommanderingstillegg',),
'innkommanderingstillegga': ('innkommanderingstillegg',),
'innkommanderingstilleggene': ('innkommanderingstillegg',),
'innkommanderingstillegget': ('innkommanderingstillegg',),
'innkomst': ('innkomst',),
'innkomsten': ('innkomst',),
'innkomstene': ('innkomst',),
'innkomster': ('innkomst',),
'innland': ('innland',),
'innlanda': ('innland',),
'innlandene': ('innland',),
'innlandet': ('innland',),
'innlandsbygd': ('innlandsbygd',),
'innlandsbygda': ('innlandsbygd',),
'innlandsbygden': ('innlandsbygd',),
'innlandsbygdene': ('innlandsbygd',),
'innlandsbygder': ('innlandsbygd',),
'innlandsfiska': ('innlandsfiske',),
'innlandsfiske': ('innlandsfiske',),
'innlandsfiskene': ('innlandsfiske',),
'innlandsfisker': ('innlandsfiske',),
'innlandsfisket': ('innlandsfiske',),
'innlandsis': ('innlandsis',),
'innlandsisen': ('innlandsis',),
'innlandsisene': ('innlandsis',),
'innlandsiser': ('innlandsis',),
'innlandsklima': ('innlandsklima',),
'innlandsklimaene': ('innlandsklima',),
'innlandsklimaer': ('innlandsklima',),
'innlandsklimaet': ('innlandsklima',),
'innlasting': ('innlasting',),
'innlastinga': ('innlasting',),
'innlastingen': ('innlasting',),
'innlastingene': ('innlasting',),
'innlastinger': ('innlasting',),
'innleder': ('innleder',),
'innledere': ('innleder',),
'innlederen': ('innleder',),
'innlederer': ('innleder',),
'innlederne': ('innleder',),
'innledning': ('innledning',),
'innledninga': ('innledning',),
'innledningen': ('innledning',),
'innledningene': ('innledning',),
'innledninger': ('innledning',),
'innledningsforedrag': ('innledningsforedrag',),
'innledningsforedraga': ('innledningsforedrag',),
'innledningsforedragene': ('innledningsforedrag',),
'innledningsforedraget': ('innledningsforedrag',),
'innlegg': ('innlegg',),
'innlegga': ('innlegg',),
'innleggene': ('innlegg',),
'innlegget': ('innlegg',),
'innleggelse': ('innleggelse',),
'innleggelsen': ('innleggelse',),
'innleggelsene': ('innleggelse',),
'innleggelser': ('innleggelse',),
'innlegging': ('innlegging',),
'innlegginga': ('innlegging',),
'innleggingen': ('innlegging',),
'innleggingene': ('innlegging',),
'innlegginger': ('innlegging',),
'innleggssåle': ('innleggssåle',),
'innleggssålen': ('innleggssåle',),
'innleggssålene': ('innleggssåle',),
'innleggssåler': ('innleggssåle',),
'innlegningsarbeid': ('innlegningsarbeid',),
'innlegningsarbeida': ('innlegningsarbeid',),
'innlegningsarbeidene': ('innlegningsarbeid',),
'innlegningsarbeider': ('innlegningsarbeid',),
'innlegningsarbeidet': ('innlegningsarbeid',),
'innleiing': ('innleiing',),
'innleiinga': ('innleiing',),
'innleiingen': ('innleiing',),
'innleiingene': ('innleiing',),
'innleiinger': ('innleiing',),
'innleiingsforedrag': ('innleiingsforedrag',),
'innleiingsforedraga': ('innleiingsforedrag',),
'innleiingsforedragene': ('innleiingsforedrag',),
'innleiingsforedraget': ('innleiingsforedrag',),
'innleiring': ('innleiring',),
'innleiringen': ('innleiring',),
'innleiringene': ('innleiring',),
'innleiringer': ('innleiring',),
'innleiring': ('innleiring',),
'innleiringa': ('innleiring',),
'innleiringen': ('innleiring',),
'innleiringene': ('innleiring',),
'innleiringer': ('innleiring',),
'innlemmelse': ('innlemmelse',),
'innlemmelsen': ('innlemmelse',),
'innlemmelsene': ('innlemmelse',),
'innlemmelser': ('innlemmelse',),
'innlemming': ('innlemming',),
'innlemminga': ('innlemming',),
'innlemmingen': ('innlemming',),
'innlemmingene': ('innlemming',),
'innlemminger': ('innlemming',),
'innlending': ('innlending',),
'innlendingen': ('innlending',),
'innlendingene': ('innlending',),
'innlendinger': ('innlending',),
'innlevelse': ('innlevelse',),
'innlevelsen': ('innlevelse',),
'innlevelsene': ('innlevelse',),
'innlevelser': ('innlevelse',),
'innlevelsesevna': ('innlevelsesevne',),
'innlevelsesevne': ('innlevelsesevne',),
'innlevelsesevnen': ('innlevelsesevne',),
'innlevelsesevnene': ('innlevelsesevne',),
'innlevelsesevner': ('innlevelsesevne',),
'innlevering': ('innlevering',),
'innleveringa': ('innlevering',),
'innleveringen': ('innlevering',),
'innleveringene': ('innlevering',),
'innleveringer': ('innlevering',),
'innleving': ('innleving',),
'innlevinga': ('innleving',),
'innlevingen': ('innleving',),
'innlevingene': ('innleving',),
'innlevinger': ('innleving',),
'innlevingsevna': ('innlevingsevne',),
'innlevingsevne': ('innlevingsevne',),
'innlevingsevnen': ('innlevingsevne',),
'innlevingsevnene': ('innlevingsevne',),
'innlevingsevner': ('innlevingsevne',),
'innlyd': ('innlyd',),
'innlyden': ('innlyd',),
'innlydene': ('innlyd',),
'innlyder': ('innlyd',),
'innlån': ('innlån',),
'innlåna': ('innlån',),
'innlånene': ('innlån',),
'innlånet': ('innlån',),
'innlånsrenta': ('innlånsrente',),
'innlånsrente': ('innlånsrente',),
'innlånsrenten': ('innlånsrente',),
'innlånsrentene': ('innlånsrente',),
'innlånsrenter': ('innlånsrente',),
'innlåsingstjuveri': ('innlåsingstjuveri',),
'innlåsingstjuveria': ('innlåsingstjuveri',),
'innlåsingstjuveriene': ('innlåsingstjuveri',),
'innlåsingstjuverier': ('innlåsingstjuveri',),
'innlåsingstjuveriet': ('innlåsingstjuveri',),
'innlåsingstyveri': ('innlåsingstyveri',),
'innlåsingstyveria': ('innlåsingstyveri',),
'innlåsingstyveriene': ('innlåsingstyveri',),
'innlåsingstyverier': ('innlåsingstyveri',),
'innlåsingstyveriet': ('innlåsingstyveri',),
'innlæring': ('innlæring',),
'innlæringa': ('innlæring',),
'innlæringen': ('innlæring',),
'innlæringene': ('innlæring',),
'innlæringer': ('innlæring',),
'innlæringsprosess': ('innlæringsprosess',),
'innlæringsprosessen': ('innlæringsprosess',),
'innlæringsprosessene': ('innlæringsprosess',),
'innlæringsprosesser': ('innlæringsprosess',),
'innløp': ('innløp',),
'innløpa': ('innløp',),
'innløpene': ('innløp',),
'innløpet': ('innløp',),
'innmark': ('innmark',),
'innmarka': ('innmark',),
'innmarken': ('innmark',),
'innmarkene': ('innmark',),
'innmarker': ('innmark',),
'innmarsj': ('innmarsj',),
'innmarsjen': ('innmarsj',),
'innmarsjene': ('innmarsj',),
'innmarsjer': ('innmarsj',),
'innmat': ('innmat',),
'innmaten': ('innmat',),
'innmatene': ('innmat',),
'innmater': ('innmat',),
'innmater': ('innmater',),
'innmatere': ('innmater',),
'innmateren': ('innmater',),
'innmaterer': ('innmater',),
'innmaterne': ('innmater',),
'innmating': ('innmating',),
'innmatinga': ('innmating',),
'innmatingen': ('innmating',),
'innmatingene': ('innmating',),
'innmatinger': ('innmating',),
'innmeldelse': ('innmeldelse',),
'innmeldelsen': ('innmeldelse',),
'innmeldelsene': ('innmeldelse',),
'innmeldelser': ('innmeldelse',),
'innmelding': ('innmelding',),
'innmeldinga': ('innmelding',),
'innmeldingen': ('innmelding',),
'innmeldingene': ('innmelding',),
'innmeldinger': ('innmelding',),
'innmeldingsskjema': ('innmeldingsskjema',),
'innmeldingsskjemaene': ('innmeldingsskjema',),
'innmeldingsskjemaer': ('innmeldingsskjema',),
'innmeldingsskjemaet': ('innmeldingsskjema',),
'innovasjon': ('innovasjon',),
'innovasjonen': ('innovasjon',),
'innovasjonene': ('innovasjon',),
'innovasjoner': ('innovasjon',),
'innovasjonsforsking': ('innovasjonsforsking',),
'innovasjonsforskinga': ('innovasjonsforsking',),
'innovasjonsforskingen': ('innovasjonsforsking',),
'innovasjonsforskingene': ('innovasjonsforsking',),
'innovasjonsforskinger': ('innovasjonsforsking',),
'innovasjonsforskning': ('innovasjonsforskning',),
'innovasjonsforskninga': ('innovasjonsforskning',),
'innovasjonsforskningen': ('innovasjonsforskning',),
'innovasjonsforskningene': ('innovasjonsforskning',),
'innovasjonsforskninger': ('innovasjonsforskning',),
'innovatør': ('innovatør',),
'innovatøren': ('innovatør',),
'innovatørene': ('innovatør',),
'innovatører': ('innovatør',),
'innpakning': ('innpakning',),
'innpakninga': ('innpakning',),
'innpakningen': ('innpakning',),
'innpakningene': ('innpakning',),
'innpakninger': ('innpakning',),
'innpakningspapir': ('innpakningspapir',),
'innpakningspapira': ('innpakningspapir',),
'innpakningspapirene': ('innpakningspapir',),
'innpakningspapirer': ('innpakningspapir',),
'innpakningspapiret': ('innpakningspapir',),
'innpass': ('innpass',),
'innpassa': ('innpass',),
'innpassene': ('innpass',),
'innpasset': ('innpass',),
'innpisker': ('innpisker',),
'innpiskere': ('innpisker',),
'innpiskeren': ('innpisker',),
'innpiskerer': ('innpisker',),
'innpiskerne': ('innpisker',),
'innpodning': ('innpodning',),
'innpodninga': ('innpodning',),
'innpodningen': ('innpodning',),
'innpodningene': ('innpodning',),
'innpodninger': ('innpodning',),
'innpotning': ('innpotning',),
'innpotninga': ('innpotning',),
'innpotningen': ('innpotning',),
'innpotningene': ('innpotning',),
'innpotninger': ('innpotning',),
'innramming': ('innramming',),
'innramminga': ('innramming',),
'innrammingen': ('innramming',),
'innrammingene': ('innramming',),
'innramminger': ('innramming',),
'innramning': ('innramning',),
'innramninga': ('innramning',),
'innramningen': ('innramning',),
'innramningene': ('innramning',),
'innramninger': ('innramning',),
'innredning': ('innredning',),
'innredninga': ('innredning',),
'innredningen': ('innredning',),
'innredningene': ('innredning',),
'innredninger': ('innredning',),
'innredningsarbeid': ('innredningsarbeid',),
'innredningsarbeida': ('innredningsarbeid',),
'innredningsarbeidene': ('innredningsarbeid',),
'innredningsarbeider': ('innredningsarbeid',),
'innredningsarbeidet': ('innredningsarbeid',),
'innreisa': ('innreise',),
'innreise': ('innreise',),
'innreisen': ('innreise',),
'innreisene': ('innreise',),
'innreiser': ('innreise',),
'innreisetillatelse': ('innreisetillatelse',),
'innreisetillatelsen': ('innreisetillatelse',),
'innreisetillatelsene': ('innreisetillatelse',),
'innreisetillatelser': ('innreisetillatelse',),
'innretning': ('innretning',),
'innretninga': ('innretning',),
'innretningen': ('innretning',),
'innretningene': ('innretning',),
'innretninger': ('innretning',),
'innrigger': ('innrigger',),
'innriggere': ('innrigger',),
'innriggeren': ('innrigger',),
'innriggerer': ('innrigger',),
'innriggerne': ('innrigger',),
'innrim': ('innrim',),
'innrima': ('innrim',),
'innrimene': ('innrim',),
'innrimet': ('innrim',),
'innror': ('innror',),
'innroren': ('innror',),
'innrorene': ('innror',),
'innrorer': ('innror',),
'innrykk': ('innrykk',),
'innrykka': ('innrykk',),
'innrykken': ('innrykk',),
'innrykkene': ('innrykk',),
'innrykket': ('innrykk',),
'innrømmelse': ('innrømmelse',),
'innrømmelsen': ('innrømmelse',),
'innrømmelsene': ('innrømmelse',),
'innrømmelser': ('innrømmelse',),
'innrømmelseskonjunksjon': ('innrømmelseskonjunksjon',),
'innrømmelseskonjunksjonen': ('innrømmelseskonjunksjon',),
'innrømmelseskonjunksjonene': ('innrømmelseskonjunksjon',),
'innrømmelseskonjunksjoner': ('innrømmelseskonjunksjon',),
'innrømmelsessetning': ('innrømmelsessetning',),
'innrømmelsessetninga': ('innrømmelsessetning',),
'innrømmelsessetningen': ('innrømmelsessetning',),
'innrømmelsessetningene': ('innrømmelsessetning',),
'innrømmelsessetninger': ('innrømmelsessetning',),
'innsamling': ('innsamling',),
'innsamlinga': ('innsamling',),
'innsamlingen': ('innsamling',),
'innsamlingene': ('innsamling',),
'innsamlinger': ('innsamling',),
'innsamlingsaksjon': ('innsamlingsaksjon',),
'innsamlingsaksjonen': ('innsamlingsaksjon',),
'innsamlingsaksjonene': ('innsamlingsaksjon',),
'innsamlingsaksjoner': ('innsamlingsaksjon',),
'innsats': ('innsats',),
'innsatsen': ('innsats',),
'innsatsene': ('innsats',),
'innsatser': ('innsats',),
'innsatsvilje': ('innsatsvilje',),
'innsatsviljen': ('innsatsvilje',),
'innsatsviljene': ('innsatsvilje',),
'innsatsviljer': ('innsatsvilje',),
'innsegl': ('innsegl',),
'innsegla': ('innsegl',),
'innseglene': ('innsegl',),
'innseglet': ('innsegl',),
'innsegl': ('innsegl',),
'innsegla': ('innsegl',),
'innseglene': ('innsegl',),
'innseglet': ('innsegl',),
'innsegling': ('innsegling',),
'innseglinga': ('innsegling',),
'innseglingen': ('innsegling',),
'innseglingene': ('innsegling',),
'innseglinger': ('innsegling',),
'innseiling': ('innseiling',),
'innseilinga': ('innseiling',),
'innseilingen': ('innseiling',),
'innseilingene': ('innseiling',),
'innseilinger': ('innseiling',),
'innsender': ('innsender',),
'innsendere': ('innsender',),
'innsenderen': ('innsender',),
'innsenderer': ('innsender',),
'innsenderne': ('innsender',),
'innsettelse': ('innsettelse',),
'innsettelsen': ('innsettelse',),
'innsettelsene': ('innsettelse',),
'innsettelser': ('innsettelse',),
'innsetting': ('innsetting',),
'innsettinga': ('innsetting',),
'innsettingen': ('innsetting',),
'innsettingene': ('innsetting',),
'innsettinger': ('innsetting',),
'innsida': ('innside',),
'innside': ('innside',),
'innsiden': ('innside',),
'innsidene': ('innside',),
'innsider': ('innside',),
'innsidehandel': ('innsidehandel',),
'innsidehandelen': ('innsidehandel',),
'innsidehandlene': ('innsidehandel',),
'innsidehandler': ('innsidehandel',),
'innsig': ('innsig',),
'innsiga': ('innsig',),
'innsigene': ('innsig',),
'innsiget': ('innsig',),
'innsigelse': ('innsigelse',),
'innsigelsen': ('innsigelse',),
'innsigelsene': ('innsigelse',),
'innsigelser': ('innsigelse',),
'innsikt': ('innsikt',),
'innsikta': ('innsikt',),
'innsikten': ('innsikt',),
'innsiktene': ('innsikt',),
'innsikter': ('innsikt',),
'innsjekking': ('innsjekking',),
'innsjekkinga': ('innsjekking',),
'innsjekkingen': ('innsjekking',),
'innsjekkingene': ('innsjekking',),
'innsjekkinger': ('innsjekking',),
'innsjekkingsskranke': ('innsjekkingsskranke',),
'innsjekkingsskranken': ('innsjekkingsskranke',),
'innsjekkingsskrankene': ('innsjekkingsskranke',),
'innsjekkingsskranker': ('innsjekkingsskranke',),
'innsjø': ('innsjø',),
'innsjøen': ('innsjø',),
'innsjøene': ('innsjø',),
'innsjøer': ('innsjø',),
'innskjæring': ('innskjæring',),
'innskjæringa': ('innskjæring',),
'innskjæringen': ('innskjæring',),
'innskjæringene': ('innskjæring',),
'innskjæringer': ('innskjæring',),
'innskott': ('innskott',),
'innskotta': ('innskott',),
'innskottene': ('innskott',),
'innskottet': ('innskott',),
'innskottsleilighet': ('innskottsleilighet',),
'innskottsleiligheta': ('innskottsleilighet',),
'innskottsleiligheten': ('innskottsleilighet',),
'innskottsleilighetene': ('innskottsleilighet',),
'innskottsleiligheter': ('innskottsleilighet',),
'innskottsrenta': ('innskottsrente',),
'innskottsrente': ('innskottsrente',),
'innskottsrenten': ('innskottsrente',),
'innskottsrentene': ('innskottsrente',),
'innskottsrenter': ('innskottsrente',),
'innskrenkethet': ('innskrenkethet',),
'innskrenketheta': ('innskrenkethet',),
'innskrenketheten': ('innskrenkethet',),
'innskrenkethetene': ('innskrenkethet',),
'innskrenketheter': ('innskrenkethet',),
'innskrenkning': ('innskrenkning',),
'innskrenkninga': ('innskrenkning',),
'innskrenkningen': ('innskrenkning',),
'innskrenkningene': ('innskrenkning',),
'innskrenkninger': ('innskrenkning',),
'innskrift': ('innskrift',),
'innskrifta': ('innskrift',),
'innskriften': ('innskrift',),
'innskriftene': ('innskrift',),
'innskrifter': ('innskrift',),
'innskudd': ('innskudd',),
'innskudda': ('innskudd',),
'innskuddene': ('innskudd',),
'innskuddet': ('innskudd',),
'innskuddsleilighet': ('innskuddsleilighet',),
'innskuddsleiligheta': ('innskuddsleilighet',),
'innskuddsleiligheten': ('innskuddsleilighet',),
'innskuddsleilighetene': ('innskuddsleilighet',),
'innskuddsleiligheter': ('innskuddsleilighet',),
'innskuddsrenta': ('innskuddsrente',),
'innskuddsrente': ('innskuddsrente',),
'innskuddsrenten': ('innskuddsrente',),
'innskuddsrentene': ('innskuddsrente',),
'innskuddsrenter': ('innskuddsrente',),
'innskytelse': ('innskytelse',),
'innskytelsen': ('innskytelse',),
'innskytelsene': ('innskytelse',),
'innskytelser': ('innskytelse',),
'innskyter': ('innskyter',),
'innskytere': ('innskyter',),
'innskyteren': ('innskyter',),
'innskyterer': ('innskyter',),
'innskyterne': ('innskyter',),
'innslag': ('innslag',),
'innslaga': ('innslag',),
'innslagene': ('innslag',),
'innslaget': ('innslag',),
'innsmett': ('innsmett',),
'innsmetta': ('innsmett',),
'innsmettene': ('innsmett',),
'innsmettet': ('innsmett',),
'innsnevring': ('innsnevring',),
'innsnevringa': ('innsnevring',),
'innsnevringen': ('innsnevring',),
'innsnevringene': ('innsnevring',),
'innsnevringer': ('innsnevring',),
'innsnitt': ('innsnitt',),
'innsnitta': ('innsnitt',),
'innsnittene': ('innsnitt',),
'innsnittet': ('innsnitt',),
'innsnøring': ('innsnøring',),
'innsnøringa': ('innsnøring',),
'innsnøringen': ('innsnøring',),
'innsnøringene': ('innsnøring',),
'innsnøringer': ('innsnøring',),
'innsovningstablett': ('innsovningstablett',),
'innsovningstabletten': ('innsovningstablett',),
'innsovningstablettene': ('innsovningstablett',),
'innsovningstabletter': ('innsovningstablett',),
'innsparing': ('innsparing',),
'innsparinga': ('innsparing',),
'innsparingen': ('innsparing',),
'innsparingene': ('innsparing',),
'innsparinger': ('innsparing',),
'innspill': ('innspill',),
'innspilla': ('innspill',),
'innspillene': ('innspill',),
'innspillet': ('innspill',),
'innspilling': ('innspilling',),
'innspillinga': ('innspilling',),
'innspillingen': ('innspilling',),
'innspillingene': ('innspilling',),
'innspillinger': ('innspilling',),
'innsprøyting': ('innsprøyting',),
'innsprøytinga': ('innsprøyting',),
'innsprøytingen': ('innsprøyting',),
'innsprøytingene': ('innsprøyting',),
'innsprøytinger': ('innsprøyting',),
'innsprøytning': ('innsprøytning',),
'innsprøytninga': ('innsprøytning',),
'innsprøytningen': ('innsprøytning',),
'innsprøytningene': ('innsprøytning',),
'innsprøytninger': ('innsprøytning',),
'innspurt': ('innspurt',),
'innspurten': ('innspurt',),
'innspurtene': ('innspurt',),
'innspurter': ('innspurt',),
'innstigingstjuv': ('innstigingstjuv',),
'innstigingstjuven': ('innstigingstjuv',),
'innstigingstjuvene': ('innstigingstjuv',),
'innstigingstjuver': ('innstigingstjuv',),
'innstigingstjuveri': ('innstigingstjuveri',),
'innstigingstjuveria': ('innstigingstjuveri',),
'innstigingstjuveriene': ('innstigingstjuveri',),
'innstigingstjuverier': ('innstigingstjuveri',),
'innstigingstjuveriet': ('innstigingstjuveri',),
'innstigingstyv': ('innstigingstyv',),
'innstigingstyven': ('innstigingstyv',),
'innstigingstyvene': ('innstigingstyv',),
'innstigingstyver': ('innstigingstyv',),
'innstigingstyveri': ('innstigingstyveri',),
'innstigingstyveria': ('innstigingstyveri',),
'innstigingstyveriene': ('innstigingstyveri',),
'innstigingstyverier': ('innstigingstyveri',),
'innstigingstyveriet': ('innstigingstyveri',),
'innstigningstjuv': ('innstigningstjuv',),
'innstigningstjuven': ('innstigningstjuv',),
'innstigningstjuvene': ('innstigningstjuv',),
'innstigningstjuver': ('innstigningstjuv',),
'innstigningstjuveri': ('innstigningstjuveri',),
'innstigningstjuveria': ('innstigningstjuveri',),
'innstigningstjuveriene': ('innstigningstjuveri',),
'innstigningstjuverier': ('innstigningstjuveri',),
'innstigningstjuveriet': ('innstigningstjuveri',),
'innstigningstyv': ('innstigningstyv',),
'innstigningstyven': ('innstigningstyv',),
'innstigningstyvene': ('innstigningstyv',),
'innstigningstyver': ('innstigningstyv',),
'innstigningstyveri': ('innstigningstyveri',),
'innstigningstyveria': ('innstigningstyveri',),
'innstigningstyveriene': ('innstigningstyveri',),
'innstigningstyverier': ('innstigningstyveri',),
'innstigningstyveriet': ('innstigningstyveri',),
'innstilling': ('innstilling',),
'innstillinga': ('innstilling',),
'innstillingen': ('innstilling',),
'innstillingene': ('innstilling',),
'innstillinger': ('innstilling',),
'innstramming': ('innstramming',),
'innstramminga': ('innstramming',),
'innstrammingen': ('innstramming',),
'innstrammingene': ('innstramming',),
'innstramminger': ('innstramming',),
'innstrammingstiltak': ('innstrammingstiltak',),
'innstrammingstiltaka': ('innstrammingstiltak',),
'innstrammingstiltakene': ('innstrammingstiltak',),
'innstrammingstiltaket': ('innstrammingstiltak',),
'innstramning': ('innstramning',),
'innstramninga': ('innstramning',),
'innstramningen': ('innstramning',),
'innstramningene': ('innstramning',),
'innstramninger': ('innstramning',),
'innstramningstiltak': ('innstramningstiltak',),
'innstramningstiltaka': ('innstramningstiltak',),
'innstramningstiltakene': ('innstramningstiltak',),
'innstramningstiltaket': ('innstramningstiltak',),
'innstrømming': ('innstrømming',),
'innstrømminga': ('innstrømming',),
'innstrømmingen': ('innstrømming',),
'innstrømmingene': ('innstrømming',),
'innstrømminger': ('innstrømming',),
'innstrømning': ('innstrømning',),
'innstrømninga': ('innstrømning',),
'innstrømningen': ('innstrømning',),
'innstrømningene': ('innstrømning',),
'innstrømninger': ('innstrømning',),
'innsug': ('innsug',),
'innsuga': ('innsug',),
'innsugene': ('innsug',),
'innsuget': ('innsug',),
'innsugingsrør': ('innsugingsrør',),
'innsugingsrøra': ('innsugingsrør',),
'innsugingsrørene': ('innsugingsrør',),
'innsugingsrøret': ('innsugingsrør',),
'innsugingsventil': ('innsugingsventil',),
'innsugingsventilen': ('innsugingsventil',),
'innsugingsventilene': ('innsugingsventil',),
'innsugingsventiler': ('innsugingsventil',),
'innsugningsrør': ('innsugningsrør',),
'innsugningsrøra': ('innsugningsrør',),
'innsugningsrørene': ('innsugningsrør',),
'innsugningsrøret': ('innsugningsrør',),
'innsugningsventil': ('innsugningsventil',),
'innsugningsventilen': ('innsugningsventil',),
'innsugningsventilene': ('innsugningsventil',),
'innsugningsventiler': ('innsugningsventil',),
'innsyn': ('innsyn',),
'innsyna': ('innsyn',),
'innsynene': ('innsyn',),
'innsynet': ('innsyn',),
'innsynsrett': ('innsynsrett',),
'innsynsretten': ('innsynsrett',),
'innsynsrettene': ('innsynsrett',),
'innsynsretter': ('innsynsrett',),
'innsøkk': ('innsøkk',),
'innsøkka': ('innsøkk',),
'innsøkkene': ('innsøkk',),
'innsøkket': ('innsøkk',),
'inntak': ('inntak',),
'inntaka': ('inntak',),
'inntakene': ('inntak',),
'inntaket': ('inntak',),
'inntaksdam': ('inntaksdam',),
'inntaksdammen': ('inntaksdam',),
'inntaksdammene': ('inntaksdam',),
'inntaksdammer': ('inntaksdam',),
'inntakskost': ('inntakskost',),
'inntakskosta': ('inntakskost',),
'inntakskostene': ('inntakskost',),
'inntakskostet': ('inntakskost',),
'inntaksprøva': ('inntaksprøve',),
'inntaksprøve': ('inntaksprøve',),
'inntaksprøven': ('inntaksprøve',),
'inntaksprøvene': ('inntaksprøve',),
'inntaksprøver': ('inntaksprøve',),
'inntekt': ('inntekt',),
'inntekta': ('inntekt',),
'inntekten': ('inntekt',),
'inntektene': ('inntekt',),
'inntekter': ('inntekt',),
'inntektsbeskatning': ('inntektsbeskatning',),
'inntektsbeskatninga': ('inntektsbeskatning',),
'inntektsbeskatningen': ('inntektsbeskatning',),
'inntektsbeskatningene': ('inntektsbeskatning',),
'inntektsbeskatninger': ('inntektsbeskatning',),
'inntektsfordeling': ('inntektsfordeling',),
'inntektsfordelinga': ('inntektsfordeling',),
'inntektsfordelingen': ('inntektsfordeling',),
'inntektsfordelingene': ('inntektsfordeling',),
'inntektsfordelinger': ('inntektsfordeling',),
'inntektskilde': ('inntektskilde',),
'inntektskilden': ('inntektskilde',),
'inntektskildene': ('inntektskilde',),
'inntektskilder': ('inntektskilde',),
'inntektskjelda': ('inntektskjelde',),
'inntektskjelde': ('inntektskjelde',),
'inntektskjelden': ('inntektskjelde',),
'inntektskjeldene': ('inntektskjelde',),
'inntektskjelder': ('inntektskjelde',),
'inntektsoppgjør': ('inntektsoppgjør',),
'inntektsoppgjøra': ('inntektsoppgjør',),
'inntektsoppgjørene': ('inntektsoppgjør',),
'inntektsoppgjøret': ('inntektsoppgjør',),
'inntektsoverføring': ('inntektsoverføring',),
'inntektsoverføringa': ('inntektsoverføring',),
'inntektsoverføringen': ('inntektsoverføring',),
'inntektsoverføringene': ('inntektsoverføring',),
'inntektsoverføringer': ('inntektsoverføring',),
'inntektssida': ('inntektsside',),
'inntektsside': ('inntektsside',),
'inntektssiden': ('inntektsside',),
'inntektssidene': ('inntektsside',),
'inntektssider': ('inntektsside',),
'inntektsskatt': ('inntektsskatt',),
'inntektsskatten': ('inntektsskatt',),
'inntektsskattene': ('inntektsskatt',),
'inntektsskatter': ('inntektsskatt',),
'inntektsutjamning': ('inntektsutjamning',),
'inntektsutjamninga': ('inntektsutjamning',),
'inntektsutjamningen': ('inntektsutjamning',),
'inntektsutjamningene': ('inntektsutjamning',),
'inntektsutjamninger': ('inntektsutjamning',),
'inntektsutjevning': ('inntektsutjevning',),
'inntektsutjevninga': ('inntektsutjevning',),
'inntektsutjevningen': ('inntektsutjevning',),
'inntektsutjevningene': ('inntektsutjevning',),
'inntektsutjevninger': ('inntektsutjevning',),
'inntjeningsevna': ('inntjeningsevne',),
'inntjeningsevne': ('inntjeningsevne',),
'inntjeningsevnen': ('inntjeningsevne',),
'inntjeningsevnene': ('inntjeningsevne',),
'inntjeningsevner': ('inntjeningsevne',),
'inntog': ('inntog',),
'inntoga': ('inntog',),
'inntogene': ('inntog',),
'inntoget': ('inntog',),
'inntreden': ('inntreden',),
'inntredenen': ('inntreden',),
'inntredenene': ('inntreden',),
'inntredener': ('inntreden',),
'inntrengen': ('inntrengen',),
'inntrenger': ('inntrenger',),
'inntrengere': ('inntrenger',),
'inntrengeren': ('inntrenger',),
'inntrengerer': ('inntrenger',),
'inntrengerne': ('inntrenger',),
'inntrenging': ('inntrenging',),
'inntrenginga': ('inntrenging',),
'inntrengingen': ('inntrenging',),
'inntrengingene': ('inntrenging',),
'inntrenginger': ('inntrenging',),
'inntrinn': ('inntrinn',),
'inntrinna': ('inntrinn',),
'inntrinnene': ('inntrinn',),
'inntrinnet': ('inntrinn',),
'inntrykk': ('inntrykk',),
'inntrykka': ('inntrykk',),
'inntrykkene': ('inntrykk',),
'inntrykket': ('inntrykk',),
'inntur': ('inntur',),
'innturen': ('inntur',),
'innturene': ('inntur',),
'innturer': ('inntur',),
'innvalgsnummer': ('innvalgsnummer',),
'innvalgsnummeret': ('innvalgsnummer',),
'innvalgsnumra': ('innvalgsnummer',),
'innvalgsnumre': ('innvalgsnummer',),
'innvalgsnumrene': ('innvalgsnummer',),
'innvandrer': ('innvandrer',),
'innvandrere': ('innvandrer',),
'innvandreren': ('innvandrer',),
'innvandrerer': ('innvandrer',),
'innvandrerne': ('innvandrer',),
'innvandring': ('innvandring',),
'innvandringa': ('innvandring',),
'innvandringen': ('innvandring',),
'innvandringene': ('innvandring',),
'innvandringer': ('innvandring',),
'innvandringsstopp': ('innvandringsstopp',),
'innvandringsstoppa': ('innvandringsstopp',),
'innvandringsstoppen': ('innvandringsstopp',),
'innvandringsstoppene': ('innvandringsstopp',),
'innvandringsstoppet': ('innvandringsstopp',),
'innveg': ('innveg',),
'innvegen': ('innveg',),
'innvegene': ('innveg',),
'innveger': ('innveg',),
'innvei': ('innvei',),
'innveien': ('innvei',),
'innveiene': ('innvei',),
'innveier': ('innvei',),
'innvending': ('innvending',),
'innvendinga': ('innvending',),
'innvendingen': ('innvending',),
'innvendingene': ('innvending',),
'innvendinger': ('innvending',),
'innvielse': ('innvielse',),
'innvielsen': ('innvielse',),
'innvielsene': ('innvielse',),
'innvielser': ('innvielse',),
'innvielsesfest': ('innvielsesfest',),
'innvielsesfesten': ('innvielsesfest',),
'innvielsesfestene': ('innvielsesfest',),
'innvielsesfester': ('innvielsesfest',),
'innviing': ('innviing',),
'innviinga': ('innviing',),
'innviingen': ('innviing',),
'innviingene': ('innviing',),
'innviinger': ('innviing',),
'innviingsfest': ('innviingsfest',),
'innviingsfesten': ('innviingsfest',),
'innviingsfestene': ('innviingsfest',),
'innviingsfester': ('innviingsfest',),
'innvirkning': ('innvirkning',),
'innvirkninga': ('innvirkning',),
'innvirkningen': ('innvirkning',),
'innvirkningene': ('innvirkning',),
'innvirkninger': ('innvirkning',),
'innvoll': ('innvoll',),
'innvollen': ('innvoll',),
'innvollene': ('innvoll',),
'innvoller': ('innvoll',),
'innvollsorm': ('innvollsorm',),
'innvollsormen': ('innvollsorm',),
'innvollsormene': ('innvollsorm',),
'innvollsormer': ('innvollsorm',),
'innvortes': ('innvortes',),
'innvåner': ('innvåner',),
'innvånere': ('innvåner',),
'innvåneren': ('innvåner',),
'innvånerer': ('innvåner',),
'innvånerne': ('innvåner',),
'innånding': ('innånding',),
'innåndinga': ('innånding',),
'innåndingen': ('innånding',),
'innåndingene': ('innånding',),
'innåndinger': ('innånding',),
'inokulasjon': ('inokulasjon',),
'inokulasjonen': ('inokulasjon',),
'inokulasjonene': ('inokulasjon',),
'inokulasjoner': ('inokulasjon',),
'input': ('input',),
'inputen': ('input',),
'inputene': ('input',),
'inputer': ('input',),
'insekt': ('insekt',),
'insekta': ('insekt',),
'insektene': ('insekt',),
'insekter': ('insekt',),
'insektet': ('insekt',),
'insektbestøvning': ('insektbestøvning',),
'insektbestøvninga': ('insektbestøvning',),
'insektbestøvningen': ('insektbestøvning',),
'insektbestøvningene': ('insektbestøvning',),
'insektbestøvninger': ('insektbestøvning',),
'insekteter': ('insekteter',),
'insektetere': ('insekteter',),
'insekteteren': ('insekteter',),
'insekteterer': ('insekteter',),
'insekteterne': ('insekteter',),
'insekticid': ('insekticid',),
'insekticida': ('insekticid',),
'insekticidene': ('insekticid',),
'insekticider': ('insekticid',),
'insekticidet': ('insekticid',),
'insektlim': ('insektlim',),
'insektlima': ('insektlim',),
'insektlimene': ('insektlim',),
'insektlimet': ('insektlim',),
'insektmiddel': ('insektmiddel',),
'insektmiddelet': ('insektmiddel',),
'insektmidla': ('insektmiddel',),
'insektmidlene': ('insektmiddel',),
'insektmidler': ('insektmiddel',),
'insektmidlet': ('insektmiddel',),
'inseminant': ('inseminant',),
'inseminanten': ('inseminant',),
'inseminantene': ('inseminant',),
'inseminanter': ('inseminant',),
'inseminasjon': ('inseminasjon',),
'inseminasjonen': ('inseminasjon',),
'inseminasjonene': ('inseminasjon',),
'inseminasjoner': ('inseminasjon',),
'inseminør': ('inseminør',),
'inseminøren': ('inseminør',),
'inseminørene': ('inseminør',),
'inseminører': ('inseminør',),
'inserat': ('inserat',),
'inserata': ('inserat',),
'inseratene': ('inserat',),
'inserater': ('inserat',),
'inseratet': ('inserat',),
'inside information': ('inside information',),
'insider': ('insider',),
'insidere': ('insider',),
'insideren': ('insider',),
'insiderer': ('insider',),
'insiderne': ('insider',),
'insignia': ('insignium',),
'insigniene': ('insignium',),
'insignier': ('insignium',),
'insigniet': ('insignium',),
'insignium': ('insignium',),
'insinuant': ('insinuant',),
'insinuanten': ('insinuant',),
'insinuantene': ('insinuant',),
'insinuanter': ('insinuant',),
'insinuasjon': ('insinuasjon',),
'insinuasjonen': ('insinuasjon',),
'insinuasjonene': ('insinuasjon',),
'insinuasjoner': ('insinuasjon',),
'inskripsjon': ('inskripsjon',),
'inskripsjonen': ('inskripsjon',),
'inskripsjonene': ('inskripsjon',),
'inskripsjoner': ('inskripsjon',),
'insolvens': ('insolvens',),
'insolvensen': ('insolvens',),
'insolvensene': ('insolvens',),
'insolvenser': ('insolvens',),
'inspeksjon': ('inspeksjon',),
'inspeksjonen': ('inspeksjon',),
'inspeksjonene': ('inspeksjon',),
'inspeksjoner': ('inspeksjon',),
'inspektør': ('inspektør',),
'inspektøren': ('inspektør',),
'inspektørene': ('inspektør',),
'inspektører': ('inspektør',),
'inspirasjon': ('inspirasjon',),
'inspirasjonen': ('inspirasjon',),
'inspirasjonene': ('inspirasjon',),
'inspirasjoner': ('inspirasjon',),
'inspirasjonskilde': ('inspirasjonskilde',),
'inspirasjonskilden': ('inspirasjonskilde',),
'inspirasjonskildene': ('inspirasjonskilde',),
'inspirasjonskilder': ('inspirasjonskilde',),
'inspirasjonskjelda': ('inspirasjonskjelde',),
'inspirasjonskjelde': ('inspirasjonskjelde',),
'inspirasjonskjelden': ('inspirasjonskjelde',),
'inspirasjonskjeldene': ('inspirasjonskjelde',),
'inspirasjonskjelder': ('inspirasjonskjelde',),
'inspirator': ('inspirator',),
'inspiratoren': ('inspirator',),
'inspiratorene': ('inspirator',),
'inspiratorer': ('inspirator',),
'inspisient': ('inspisient',),
'inspisienten': ('inspisient',),
'inspisientene': ('inspisient',),
'inspisienter': ('inspisient',),
'installasjon': ('installasjon',),
'installasjonen': ('installasjon',),
'installasjonene': ('installasjon',),
'installasjoner': ('installasjon',),
'installatør': ('installatør',),
'installatøren': ('installatør',),
'installatørene': ('installatør',),
'installatører': ('installatør',),
'instans': ('instans',),
'instansen': ('instans',),
'instansene': ('instans',),
'instanser': ('instans',),
'instinkt': ('instinkt',),
'instinkta': ('instinkt',),
'instinktene': ('instinkt',),
'instinkter': ('instinkt',),
'instinktet': ('instinkt',),
'instinkthandling': ('instinkthandling',),
'instinkthandlinga': ('instinkthandling',),
'instinkthandlingen': ('instinkthandling',),
'instinkthandlingene': ('instinkthandling',),
'instinkthandlinger': ('instinkthandling',),
'institusjon': ('institusjon',),
'institusjonen': ('institusjon',),
'institusjonene': ('institusjon',),
'institusjoner': ('institusjon',),
'institusjonsteater': ('institusjonsteater',),
'institusjonsteateret': ('institusjonsteater',),
'institusjonsteatra': ('institusjonsteater',),
'institusjonsteatre': ('institusjonsteater',),
'institusjonsteatrene': ('institusjonsteater',),
'institusjonsteatret': ('institusjonsteater',),
'institutt': ('institutt',),
'institutta': ('institutt',),
'instituttene': ('institutt',),
'institutter': ('institutt',),
'instituttet': ('institutt',),
'instituttbestyrer': ('instituttbestyrer',),
'instituttbestyrere': ('instituttbestyrer',),
'instituttbestyreren': ('instituttbestyrer',),
'instituttbestyrerer': ('instituttbestyrer',),
'instituttbestyrerne': ('instituttbestyrer',),
'instruks': ('instruks',),
'instruksen': ('instruks',),
'instruksene': ('instruks',),
'instrukser': ('instruks',),
'instruksjon': ('instruksjon',),
'instruksjonen': ('instruksjon',),
'instruksjonene': ('instruksjon',),
'instruksjoner': ('instruksjon',),
'instruktør': ('instruktør',),
'instruktøren': ('instruktør',),
'instruktørene': ('instruktør',),
'instruktører': ('instruktør',),
'instrument': ('instrument',),
'instrumenta': ('instrument',),
'instrumentene': ('instrument',),
'instrumenter': ('instrument',),
'instrumentet': ('instrument',),
'instrumentalis': ('instrumentalis',),
'instrumentalisen': ('instrumentalis',),
'instrumentalisene': ('instrumentalis',),
'instrumentaliser': ('instrumentalis',),
'instrumentalisme': ('instrumentalisme',),
'instrumentalismen': ('instrumentalisme',),
'instrumentalismene': ('instrumentalisme',),
'instrumentalismer': ('instrumentalisme',),
'instrumentalist': ('instrumentalist',),
'instrumentalisten': ('instrumentalist',),
'instrumentalistene': ('instrumentalist',),
'instrumentalister': ('instrumentalist',),
'instrumentalmusikk': ('instrumentalmusikk',),
'instrumentalmusikken': ('instrumentalmusikk',),
'instrumentalmusikkene': ('instrumentalmusikk',),
'instrumentalmusikker': ('instrumentalmusikk',),
'instrumentasjon': ('instrumentasjon',),
'instrumentasjonen': ('instrumentasjon',),
'instrumentasjonene': ('instrumentasjon',),
'instrumentasjoner': ('instrumentasjon',),
'instrumentflyging': ('instrumentflyging',),
'instrumentflyginga': ('instrumentflyging',),
'instrumentflygingen': ('instrumentflyging',),
'instrumentflygingene': ('instrumentflyging',),
'instrumentflyginger': ('instrumentflyging',),
'instrumentflying': ('instrumentflying',),
'instrumentflyinga': ('instrumentflying',),
'instrumentflyingen': ('instrumentflying',),
'instrumentflyingene': ('instrumentflying',),
'instrumentflyinger': ('instrumentflying',),
'instrumentmaker': ('instrumentmaker',),
'instrumentmakere': ('instrumentmaker',),
'instrumentmakeren': ('instrumentmaker',),
'instrumentmakerer': ('instrumentmaker',),
'instrumentmakerne': ('instrumentmaker',),
'instrumentpanel': ('instrumentpanel',),
'instrumentpanela': ('instrumentpanel',),
'instrumentpanelene': ('instrumentpanel',),
'instrumentpaneler': ('instrumentpanel',),
'instrumentpanelet': ('instrumentpanel',),
'instrumenttavla': ('instrumenttavle',),
'instrumenttavle': ('instrumenttavle',),
'instrumenttavlen': ('instrumenttavle',),
'instrumenttavlene': ('instrumenttavle',),
'instrumenttavler': ('instrumenttavle',),
'insubordinasjon': ('insubordinasjon',),
'insubordinasjonen': ('insubordinasjon',),
'insubordinasjonene': ('insubordinasjon',),
'insubordinasjoner': ('insubordinasjon',),
'insuffisiens': ('insuffisiens',),
'insuffisiensen': ('insuffisiens',),
'insuffisiensene': ('insuffisiens',),
'insuffisienser': ('insuffisiens',),
'insulaner': ('insulaner',),
'insulanere': ('insulaner',),
'insulaneren': ('insulaner',),
'insulanerer': ('insulaner',),
'insulanerne': ('insulaner',),
'insularskrift': ('insularskrift',),
'insularskrifta': ('insularskrift',),
'insularskriften': ('insularskrift',),
'insularskriftene': ('insularskrift',),
'insularskrifter': ('insularskrift',),
'insulin': ('insulin',),
'insulina': ('insulin',),
'insulinene': ('insulin',),
'insulinet': ('insulin',),
'insulinkur': ('insulinkur',),
'insulinkuren': ('insulinkur',),
'insulinkurene': ('insulinkur',),
'insulinkurer': ('insulinkur',),
'insulinsjokk': ('insulinsjokk',),
'insulinsjokka': ('insulinsjokk',),
'insulinsjokkene': ('insulinsjokk',),
'insulinsjokket': ('insulinsjokk',),
'intaglio': ('intaglio',),
'intaglioen': ('intaglio',),
'intaglioene': ('intaglio',),
'intaglioer': ('intaglio',),
'intarsia': ('intarsia',),
'intarsiaen': ('intarsia',),
'intarsiene': ('intarsia',),
'intarsier': ('intarsia',),
'integral': ('integral',),
'integrala': ('integral',),
'integralene': ('integral',),
'integraler': ('integral',),
'integralet': ('integral',),
'integralregning': ('integralregning',),
'integralregninga': ('integralregning',),
'integralregningen': ('integralregning',),
'integralregningene': ('integralregning',),
'integralregninger': ('integralregning',),
'integralrekning': ('integralrekning',),
'integralrekninga': ('integralrekning',),
'integralrekningen': ('integralrekning',),
'integralrekningene': ('integralrekning',),
'integralrekninger': ('integralrekning',),
'integrasjon': ('integrasjon',),
'integrasjonen': ('integrasjon',),
'integrasjonene': ('integrasjon',),
'integrasjoner': ('integrasjon',),
'integrasjonspolitikk': ('integrasjonspolitikk',),
'integrasjonspolitikken': ('integrasjonspolitikk',),
'integrasjonspolitikkene': ('integrasjonspolitikk',),
'integrasjonspolitikker': ('integrasjonspolitikk',),
'integrasjonsprosess': ('integrasjonsprosess',),
'integrasjonsprosessen': ('integrasjonsprosess',),
'integrasjonsprosessene': ('integrasjonsprosess',),
'integrasjonsprosesser': ('integrasjonsprosess',),
'integritet': ('integritet',),
'integriteten': ('integritet',),
'integritetene': ('integritet',),
'integriteter': ('integritet',),
'intellekt': ('intellekt',),
'intellekta': ('intellekt',),
'intellektene': ('intellekt',),
'intellekter': ('intellekt',),
'intellektet': ('intellekt',),
'intellektualisme': ('intellektualisme',),
'intellektualismen': ('intellektualisme',),
'intellektualismene': ('intellektualisme',),
'intellektualismer': ('intellektualisme',),
'intellektualist': ('intellektualist',),
'intellektualisten': ('intellektualist',),
'intellektualistene': ('intellektualist',),
'intellektualister': ('intellektualist',),
'intelligens': ('intelligens',),
'intelligensen': ('intelligens',),
'intelligensene': ('intelligens',),
'intelligenser': ('intelligens',),
'intelligensalder': ('intelligensalder',),
'intelligensaldere': ('intelligensalder',),
'intelligensalderen': ('intelligensalder',),
'intelligensalderer': ('intelligensalder',),
'intelligensalderne': ('intelligensalder',),
'intelligensaldre': ('intelligensalder',),
'intelligensaldrene': ('intelligensalder',),
'intelligensaldrer': ('intelligensalder',),
'intelligensindustri': ('intelligensindustri',),
'intelligensindustrien': ('intelligensindustri',),
'intelligensindustriene': ('intelligensindustri',),
'intelligensindustrier': ('intelligensindustri',),
'intelligenskvotient': ('intelligenskvotient',),
'intelligenskvotienten': ('intelligenskvotient',),
'intelligenskvotientene': ('intelligenskvotient',),
'intelligenskvotienter': ('intelligenskvotient',),
'intelligensmåling': ('intelligensmåling',),
'intelligensmålinga': ('intelligensmåling',),
'intelligensmålingen': ('intelligensmåling',),
'intelligensmålingene': ('intelligensmåling',),
'intelligensmålinger': ('intelligensmåling',),
'intelligensprøva': ('intelligensprøve',),
'intelligensprøve': ('intelligensprøve',),
'intelligensprøven': ('intelligensprøve',),
'intelligensprøvene': ('intelligensprøve',),
'intelligensprøver': ('intelligensprøve',),
'intelligentsia': ('intelligentsia',),
'intelligentsiaen': ('intelligentsia',),
'intelligentsiaene': ('intelligentsia',),
'intelligentsiaer': ('intelligentsia',),
'intendant': ('intendant',),
'intendanten': ('intendant',),
'intendantene': ('intendant',),
'intendanter': ('intendant',),
'intendantur': ('intendantur',),
'intendanturen': ('intendantur',),
'intendanturene': ('intendantur',),
'intendanturer': ('intendantur',),
'intendanturavdeling': ('intendanturavdeling',),
'intendanturavdelinga': ('intendanturavdeling',),
'intendanturavdelingen': ('intendanturavdeling',),
'intendanturavdelingene': ('intendanturavdeling',),
'intendanturavdelinger': ('intendanturavdeling',),
'intendanturmateriell': ('intendanturmateriell',),
'intendanturmateriella': ('intendanturmateriell',),
'intendanturmateriellene': ('intendanturmateriell',),
'intendanturmateriellet': ('intendanturmateriell',),
'intensitet': ('intensitet',),
'intensiteten': ('intensitet',),
'intensitetene': ('intensitet',),
'intensiteter': ('intensitet',),
'intensivavdeling': ('intensivavdeling',),
'intensivavdelinga': ('intensivavdeling',),
'intensivavdelingen': ('intensivavdeling',),
'intensivavdelingene': ('intensivavdeling',),
'intensivavdelinger': ('intensivavdeling',),
'intensjon': ('intensjon',),
'intensjonen': ('intensjon',),
'intensjonene': ('intensjon',),
'intensjoner': ('intensjon',),
'interaksjon': ('interaksjon',),
'interaksjonen': ('interaksjon',),
'interaksjonene': ('interaksjon',),
'interaksjoner': ('interaksjon',),
'intercitytog': ('intercitytog',),
'intercitytoga': ('intercitytog',),
'intercitytogene': ('intercitytog',),
'intercitytoget': ('intercitytog',),
'intercom': ('intercom',),
'intercomen': ('intercom',),
'intercomene': ('intercom',),
'intercomer': ('intercom',),
'interdikt': ('interdikt',),
'interdikta': ('interdikt',),
'interdiktene': ('interdikt',),
'interdikter': ('interdikt',),
'interdiktet': ('interdikt',),
'interesse': ('interesse',),
'interessen': ('interesse',),
'interessene': ('interesse',),
'interesser': ('interesse',),
'interessefellesskap': ('interessefellesskap',),
'interessefellesskapa': ('interessefellesskap',),
'interessefellesskapene': ('interessefellesskap',),
'interessefellesskaper': ('interessefellesskap',),
'interessefellesskapet': ('interessefellesskap',),
'interessefelt': ('interessefelt',),
'interessefelta': ('interessefelt',),
'interessefeltene': ('interessefelt',),
'interessefelter': ('interessefelt',),
'interessefeltet': ('interessefelt',),
'interessegruppa': ('interessegruppe',),
'interessegruppe': ('interessegruppe',),
'interessegruppen': ('interessegruppe',),
'interessegruppene': ('interessegruppe',),
'interessegrupper': ('interessegruppe',),
'interessekamp': ('interessekamp',),
'interessekampen': ('interessekamp',),
'interessekampene': ('interessekamp',),
'interessekamper': ('interessekamp',),
'interessekonflikt': ('interessekonflikt',),
'interessekonflikten': ('interessekonflikt',),
'interessekonfliktene': ('interessekonflikt',),
'interessekonflikter': ('interessekonflikt',),
'interessekontor': ('interessekontor',),
'interessekontora': ('interessekontor',),
'interessekontorene': ('interessekontor',),
'interessekontorer': ('interessekontor',),
'interessekontoret': ('interessekontor',),
'interessent': ('interessent',),
'interessenten': ('interessent',),
'interessentene': ('interessent',),
'interessenter': ('interessent',),
'interessentskap': ('interessentskap',),
'interessentskapa': ('interessentskap',),
'interessentskapene': ('interessentskap',),
'interessentskapet': ('interessentskap',),
'interesseområda': ('interesseområde',),
'interesseområde': ('interesseområde',),
'interesseområdene': ('interesseområde',),
'interesseområder': ('interesseområde',),
'interesseområdet': ('interesseområde',),
'interesseorganisasjon': ('interesseorganisasjon',),
'interesseorganisasjonen': ('interesseorganisasjon',),
'interesseorganisasjonene': ('interesseorganisasjon',),
'interesseorganisasjoner': ('interesseorganisasjon',),
'interessesfære': ('interessesfære',),
'interessesfæren': ('interessesfære',),
'interessesfærene': ('interessesfære',),
'interessesfærer': ('interessesfære',),
'interferens': ('interferens',),
'interferensen': ('interferens',),
'interferensene': ('interferens',),
'interferenser': ('interferens',),
'interferometer': ('interferometer',),
'interferometeret': ('interferometer',),
'interferometra': ('interferometer',),
'interferometre': ('interferometer',),
'interferometrene': ('interferometer',),
'interferometret': ('interferometer',),
'interglasialtid': ('interglasialtid',),
'interglasialtida': ('interglasialtid',),
'interglasialtiden': ('interglasialtid',),
'interglasialtidene': ('interglasialtid',),
'interglasialtider': ('interglasialtid',),
'interim': ('interim',),
'interima': ('interim',),
'interimene': ('interim',),
'interimet': ('interim',),
'interimskvittering': ('interimskvittering',),
'interimskvitteringa': ('interimskvittering',),
'interimskvitteringen': ('interimskvittering',),
'interimskvitteringene': ('interimskvittering',),
'interimskvitteringer': ('interimskvittering',),
'interimsregjering': ('interimsregjering',),
'interimsregjeringa': ('interimsregjering',),
'interimsregjeringen': ('interimsregjering',),
'interimsregjeringene': ('interimsregjering',),
'interimsregjeringer': ('interimsregjering',),
'interimsstyra': ('interimsstyre',),
'interimsstyre': ('interimsstyre',),
'interimsstyrene': ('interimsstyre',),
'interimsstyrer': ('interimsstyre',),
'interimsstyret': ('interimsstyre',),
'interiør': ('interiør',),
'interiøra': ('interiør',),
'interiørene': ('interiør',),
'interiører': ('interiør',),
'interiøret': ('interiør',),
'interiørarkitekt': ('interiørarkitekt',),
'interiørarkitekten': ('interiørarkitekt',),
'interiørarkitektene': ('interiørarkitekt',),
'interiørarkitekter': ('interiørarkitekt',),
'interiørmaling': ('interiørmaling',),
'interiørmalinga': ('interiørmaling',),
'interiørmalingen': ('interiørmaling',),
'interiørmalingene': ('interiørmaling',),
'interiørmalinger': ('interiørmaling',),
'interjeksjon': ('interjeksjon',),
'interjeksjonen': ('interjeksjon',),
'interjeksjonene': ('interjeksjon',),
'interjeksjoner': ('interjeksjon',),
'interludia': ('interludium',),
'interludiene': ('interludium',),
'interludier': ('interludium',),
'interludiet': ('interludium',),
'interludium': ('interludium',),
'intermesso': ('intermesso',),
'intermessoa': ('intermesso',),
'intermessoene': ('intermesso',),
'intermessoer': ('intermesso',),
'intermessoet': ('intermesso',),
'internasjonale': ('internasjonale',),
'internasjonalen': ('internasjonale',),
'internasjonalene': ('internasjonale',),
'internasjonaler': ('internasjonale',),
'internasjonalisme': ('internasjonalisme',),
'internasjonalismen': ('internasjonalisme',),
'internasjonalismene': ('internasjonalisme',),
'internasjonalismer': ('internasjonalisme',),
'internasjonalist': ('internasjonalist',),
'internasjonalisten': ('internasjonalist',),
'internasjonalistene': ('internasjonalist',),
'internasjonalister': ('internasjonalist',),
'internat': ('internat',),
'internata': ('internat',),
'internatene': ('internat',),
'internater': ('internat',),
'internatet': ('internat',),
'internatskole': ('internatskole',),
'internatskolen': ('internatskole',),
'internatskolene': ('internatskole',),
'internatskoler': ('internatskole',),
'interneringsleir': ('interneringsleir',),
'interneringsleiren': ('interneringsleir',),
'interneringsleirene': ('interneringsleir',),
'interneringsleirer': ('interneringsleir',),
'internist': ('internist',),
'internisten': ('internist',),
'internistene': ('internist',),
'internister': ('internist',),
'interpellant': ('interpellant',),
'interpellanten': ('interpellant',),
'interpellantene': ('interpellant',),
'interpellanter': ('interpellant',),
'interpellasjon': ('interpellasjon',),
'interpellasjonen': ('interpellasjon',),
'interpellasjonene': ('interpellasjon',),
'interpellasjoner': ('interpellasjon',),
'interpolasjon': ('interpolasjon',),
'interpolasjonen': ('interpolasjon',),
'interpolasjonene': ('interpolasjon',),
'interpolasjoner': ('interpolasjon',),
'interpret': ('interpret',),
'interpreten': ('interpret',),
'interpretene': ('interpret',),
'interpreter': ('interpret',),
'interpretasjon': ('interpretasjon',),
'interpretasjonen': ('interpretasjon',),
'interpretasjonene': ('interpretasjon',),
'interpretasjoner': ('interpretasjon',),
'interpunksjon': ('interpunksjon',),
'interpunksjonen': ('interpunksjon',),
'interpunksjonene': ('interpunksjon',),
'interpunksjoner': ('interpunksjon',),
'interrail': ('interrail',),
'interrailen': ('interrail',),
'interrailene': ('interrail',),
'interrailer': ('interrail',),
'interrailer': ('interrailer',),
'interrailere': ('interrailer',),
'interraileren': ('interrailer',),
'interrailerer': ('interrailer',),
'interrailerne': ('interrailer',),
'interregna': ('interregnum',),
'interregnaene': ('interregnum',),
'interregnene': ('interregnum',),
'interregner': ('interregnum',),
'interregnet': ('interregnum',),
'interregnum': ('interregnum',),
'interregnumet': ('interregnum',),
'interrogativ': ('interrogativ',),
'interrogativa': ('interrogativ',),
'interrogativene': ('interrogativ',),
'interrogativer': ('interrogativ',),
'interrogativet': ('interrogativ',),
'interseksualitet': ('interseksualitet',),
'interseksualiteten': ('interseksualitet',),
'interseksualitetene': ('interseksualitet',),
'interseksualiteter': ('interseksualitet',),
'intervall': ('intervall',),
'intervalla': ('intervall',),
'intervallene': ('intervall',),
'intervaller': ('intervall',),
'intervallet': ('intervall',),
'intervallbryter': ('intervallbryter',),
'intervallbrytere': ('intervallbryter',),
'intervallbryteren': ('intervallbryter',),
'intervallbryterer': ('intervallbryter',),
'intervallbryterne': ('intervallbryter',),
'intervallsprengning': ('intervallsprengning',),
'intervallsprengninga': ('intervallsprengning',),
'intervallsprengningen': ('intervallsprengning',),
'intervallsprengningene': ('intervallsprengning',),
'intervallsprengninger': ('intervallsprengning',),
'intervalltrening': ('intervalltrening',),
'intervalltreninga': ('intervalltrening',),
'intervalltreningen': ('intervalltrening',),
'intervalltreningene': ('intervalltrening',),
'intervalltreninger': ('intervalltrening',),
'intervenient': ('intervenient',),
'intervenienten': ('intervenient',),
'intervenientene': ('intervenient',),
'intervenienter': ('intervenient',),
'intervensjon': ('intervensjon',),
'intervensjonen': ('intervensjon',),
'intervensjonene': ('intervensjon',),
'intervensjoner': ('intervensjon',),
'intervju': ('intervju',),
'intervjua': ('intervju',),
'intervjuene': ('intervju',),
'intervjuer': ('intervju',),
'intervjuet': ('intervju',),
'intervjuer': ('intervjuer',),
'intervjuere': ('intervjuer',),
'intervjueren': ('intervjuer',),
'intervjuerer': ('intervjuer',),
'intervjuerne': ('intervjuer',),
'intervjuobjekt': ('intervjuobjekt',),
'intervjuobjekta': ('intervjuobjekt',),
'intervjuobjektene': ('intervjuobjekt',),
'intervjuobjekter': ('intervjuobjekt',),
'intervjuobjektet': ('intervjuobjekt',),
'intervjuundersøkelse': ('intervjuundersøkelse',),
'intervjuundersøkelsen': ('intervjuundersøkelse',),
'intervjuundersøkelsene': ('intervjuundersøkelse',),
'intervjuundersøkelser': ('intervjuundersøkelse',),
'intervjuundersøking': ('intervjuundersøking',),
'intervjuundersøkinga': ('intervjuundersøking',),
'intervjuundersøkingen': ('intervjuundersøking',),
'intervjuundersøkingene': ('intervjuundersøking',),
'intervjuundersøkinger': ('intervjuundersøking',),
'intestatarv': ('intestatarv',),
'intestatarven': ('intestatarv',),
'intestatarvene': ('intestatarv',),
'intestatarver': ('intestatarv',),
'intet': ('intet',),
'intetkjønn': ('intetkjønn',),
'intetkjønna': ('intetkjønn',),
'intetkjønnene': ('intetkjønn',),
'intetkjønnet': ('intetkjønn',),
'intetkjønnsord': ('intetkjønnsord',),
'intetkjønnsorda': ('intetkjønnsord',),
'intetkjønnsordene': ('intetkjønnsord',),
'intetkjønnsordet': ('intetkjønnsord',),
'intifada': ('intifada',),
'intifadaen': ('intifada',),
'intifadaene': ('intifada',),
'intifadaer': ('intifada',),
'intimasjon': ('intimasjon',),
'intimasjonen': ('intimasjon',),
'intimasjonene': ('intimasjon',),
'intimasjoner': ('intimasjon',),
'intimdeodorant': ('intimdeodorant',),
'intimdeodoranten': ('intimdeodorant',),
'intimdeodorantene': ('intimdeodorant',),
'intimdeodoranter': ('intimdeodorant',),
'intimidasjon': ('intimidasjon',),
'intimidasjonen': ('intimidasjon',),
'intimidasjonene': ('intimidasjon',),
'intimidasjoner': ('intimidasjon',),
'intimitet': ('intimitet',),
'intimiteten': ('intimitet',),
'intimitetene': ('intimitet',),
'intimiteter': ('intimitet',),
'intimkino': ('intimkino',),
'intimkinoen': ('intimkino',),
'intimkinoene': ('intimkino',),
'intimkinoer': ('intimkino',),
'intimkonsert': ('intimkonsert',),
'intimkonserten': ('intimkonsert',),
'intimkonsertene': ('intimkonsert',),
'intimkonserter': ('intimkonsert',),
'intimspray': ('intimspray',),
'intimsprayen': ('intimspray',),
'intimsprayene': ('intimspray',),
'intimsprayer': ('intimspray',),
'intimteater': ('intimteater',),
'intimteateret': ('intimteater',),
'intimteatra': ('intimteater',),
'intimteatre': ('intimteater',),
'intimteatrene': ('intimteater',),
'intimteatret': ('intimteater',),
'intoksikasjon': ('intoksikasjon',),
'intoksikasjonen': ('intoksikasjon',),
'intoksikasjonene': ('intoksikasjon',),
'intoksikasjoner': ('intoksikasjon',),
'intoleranse': ('intoleranse',),
'intoleransen': ('intoleranse',),
'intoleransene': ('intoleranse',),
'intoleranser': ('intoleranse',),
'intonasjon': ('intonasjon',),
'intonasjonen': ('intonasjon',),
'intonasjonene': ('intonasjon',),
'intonasjoner': ('intonasjon',),
'intrada': ('intrada',),
'intradaen': ('intrada',),
'intradaene': ('intrada',),
'intradaer': ('intrada',),
'intrade': ('intrade',),
'intraden': ('intrade',),
'intradene': ('intrade',),
'intrader': ('intrade',),
'intransitiv': ('intransitiv',),
'intransitiva': ('intransitiv',),
'intransitivene': ('intransitiv',),
'intransitiver': ('intransitiv',),
'intransitivet': ('intransitiv',),
'intrigant': ('intrigant',),
'intriganten': ('intrigant',),
'intrigantene': ('intrigant',),
'intriganter': ('intrigant',),
'intrige': ('intrige',),
'intrigen': ('intrige',),
'intrigene': ('intrige',),
'intriger': ('intrige',),
'intrigemaker': ('intrigemaker',),
'intrigemakere': ('intrigemaker',),
'intrigemakeren': ('intrigemaker',),
'intrigemakerer': ('intrigemaker',),
'intrigemakerne': ('intrigemaker',),
'intrigespill': ('intrigespill',),
'intrigespilla': ('intrigespill',),
'intrigespillene': ('intrigespill',),
'intrigespillet': ('intrigespill',),
'intrigestykka': ('intrigestykke',),
'intrigestykke': ('intrigestykke',),
'intrigestykkene': ('intrigestykke',),
'intrigestykker': ('intrigestykke',),
'intrigestykket': ('intrigestykke',),
'introduksjon': ('introduksjon',),
'introduksjonen': ('introduksjon',),
'introduksjonene': ('introduksjon',),
'introduksjoner': ('introduksjon',),
'introduksjonsbrev': ('introduksjonsbrev',),
'introduksjonsbreva': ('introduksjonsbrev',),
'introduksjonsbrevene': ('introduksjonsbrev',),
'introduksjonsbrever': ('introduksjonsbrev',),
'introduksjonsbrevet': ('introduksjonsbrev',),
'introduksjonsskriv': ('introduksjonsskriv',),
'introduksjonsskriva': ('introduksjonsskriv',),
'introduksjonsskrivene': ('introduksjonsskriv',),
'introduksjonsskrivet': ('introduksjonsskriv',),
'introduksjonstilbud': ('introduksjonstilbud',),
'introduksjonstilbuda': ('introduksjonstilbud',),
'introduksjonstilbudene': ('introduksjonstilbud',),
'introduksjonstilbudet': ('introduksjonstilbud',),
'introspeksjon': ('introspeksjon',),
'introspeksjonen': ('introspeksjon',),
'introspeksjonene': ('introspeksjon',),
'introspeksjoner': ('introspeksjon',),
'introversjon': ('introversjon',),
'introversjonen': ('introversjon',),
'introversjonene': ('introversjon',),
'introversjoner': ('introversjon',),
'intuisjon': ('intuisjon',),
'intuisjonen': ('intuisjon',),
'intuisjonene': ('intuisjon',),
'intuisjoner': ('intuisjon',),
'inuit': ('inuit',),
'inuiten': ('inuit',),
'inuitene': ('inuit',),
'inuiter': ('inuit',),
'inuitt': ('inuitt',),
'inuitten': ('inuitt',),
'inuittene': ('inuitt',),
'inuitter': ('inuitt',),
'invalid': ('invalid',),
'invaliden': ('invalid',),
'invalidene': ('invalid',),
'invalider': ('invalid',),
'invalidebil': ('invalidebil',),
'invalidebilen': ('invalidebil',),
'invalidebilene': ('invalidebil',),
'invalidebiler': ('invalidebil',),
'invaliderenta': ('invaliderente',),
'invaliderente': ('invaliderente',),
'invaliderenten': ('invaliderente',),
'invaliderentene': ('invaliderente',),
'invaliderenter': ('invaliderente',),
'invaliditet': ('invaliditet',),
'invaliditeten': ('invaliditet',),
'invaliditetene': ('invaliditet',),
'invaliditeter': ('invaliditet',),
'invaliditetsforsikring': ('invaliditetsforsikring',),
'invaliditetsforsikringa': ('invaliditetsforsikring',),
'invaliditetsforsikringen': ('invaliditetsforsikring',),
'invaliditetsforsikringene': ('invaliditetsforsikring',),
'invaliditetsforsikringer': ('invaliditetsforsikring',),
'invaliditetsgrad': ('invaliditetsgrad',),
'invaliditetsgraden': ('invaliditetsgrad',),
'invaliditetsgradene': ('invaliditetsgrad',),
'invaliditetsgrader': ('invaliditetsgrad',),
'invarians': ('invarians',),
'invariansen': ('invarians',),
'invariansene': ('invarians',),
'invarianser': ('invarians',),
'invasjon': ('invasjon',),
'invasjonen': ('invasjon',),
'invasjonene': ('invasjon',),
'invasjoner': ('invasjon',),
'invasjonsstyrke': ('invasjonsstyrke',),
'invasjonsstyrken': ('invasjonsstyrke',),
'invasjonsstyrkene': ('invasjonsstyrke',),
'invasjonsstyrker': ('invasjonsstyrke',),
'invektiv': ('invektiv',),
'invektiva': ('invektiv',),
'invektivene': ('invektiv',),
'invektiver': ('invektiv',),
'invektivet': ('invektiv',),
'invensjon': ('invensjon',),
'invensjonen': ('invensjon',),
'invensjonene': ('invensjon',),
'invensjoner': ('invensjon',),
'inventar': ('inventar',),
'inventara': ('inventar',),
'inventarene': ('inventar',),
'inventarer': ('inventar',),
'inventaret': ('inventar',),
'inventaria': ('inventarium',),
'inventariene': ('inventarium',),
'inventarier': ('inventarium',),
'inventariet': ('inventarium',),
'inventarium': ('inventarium',),
'inventarlista': ('inventarliste',),
'inventarliste': ('inventarliste',),
'inventarlisten': ('inventarliste',),
'inventarlistene': ('inventarliste',),
'inventarlister': ('inventarliste',),
'inventering': ('inventering',),
'inventeringa': ('inventering',),
'inventeringen': ('inventering',),
'inventeringene': ('inventering',),
'inventeringer': ('inventering',),
'inversjon': ('inversjon',),
'inversjonen': ('inversjon',),
'inversjonene': ('inversjon',),
'inversjoner': ('inversjon',),
'invertebrat': ('invertebrat',),
'invertebraten': ('invertebrat',),
'invertebratene': ('invertebrat',),
'invertebrater': ('invertebrat',),
'investering': ('investering',),
'investeringa': ('investering',),
'investeringen': ('investering',),
'investeringene': ('investering',),
'investeringer': ('investering',),
'investeringsavgift': ('investeringsavgift',),
'investeringsavgifta': ('investeringsavgift',),
'investeringsavgiften': ('investeringsavgift',),
'investeringsavgiftene': ('investeringsavgift',),
'investeringsavgifter': ('investeringsavgift',),
'investeringskontroll': ('investeringskontroll',),
'investeringskontrollen': ('investeringskontroll',),
'investeringskontrollene': ('investeringskontroll',),
'investeringskontroller': ('investeringskontroll',),
'investeringsobjekt': ('investeringsobjekt',),
'investeringsobjekta': ('investeringsobjekt',),
'investeringsobjektene': ('investeringsobjekt',),
'investeringsobjekter': ('investeringsobjekt',),
'investeringsobjektet': ('investeringsobjekt',),
'investeringsselskap': ('investeringsselskap',),
'investeringsselskapa': ('investeringsselskap',),
'investeringsselskapene': ('investeringsselskap',),
'investeringsselskaper': ('investeringsselskap',),
'investeringsselskapet': ('investeringsselskap',),
'investitur': ('investitur',),
'investituren': ('investitur',),
'investiturene': ('investitur',),
'investiturer': ('investitur',),
'investiturstrid': ('investiturstrid',),
'investiturstriden': ('investiturstrid',),
'investiturstridene': ('investiturstrid',),
'investiturstrider': ('investiturstrid',),
'investor': ('investor',),
'investoren': ('investor',),
'investorene': ('investor',),
'investorer': ('investor',),
'invitasjon': ('invitasjon',),
'invitasjonen': ('invitasjon',),
'invitasjonene': ('invitasjon',),
'invitasjoner': ('invitasjon',),
'invitt': ('invitt',),
'invitten': ('invitt',),
'invittene': ('invitt',),
'invitter': ('invitt',),
'ion': ('ion',),
'iona': ('ion',),
'ionene': ('ion',),
'ioner': ('ion',),
'ionet': ('ion',),
'ionisasjon': ('ionisasjon',),
'ionisasjonen': ('ionisasjon',),
'ionisasjonene': ('ionisasjon',),
'ionisasjoner': ('ionisasjon',),
'ionium': ('ionium',),
'ioniuma': ('ionium',),
'ioniumene': ('ionium',),
'ioniumet': ('ionium',),
'ionometer': ('ionometer',),
'ionometeret': ('ionometer',),
'ionometra': ('ionometer',),
'ionometre': ('ionometer',),
'ionometrene': ('ionometer',),
'ionometret': ('ionometer',),
'ionosfære': ('ionosfære',),
'ionosfæren': ('ionosfære',),
'ionosfærene': ('ionosfære',),
'ionosfærer': ('ionosfære',),
'ir': ('ir',),
'iren': ('ir',),
'irene': ('ir',),
'irer': ('ir',),
'iraker': ('iraker',),
'irakere': ('iraker',),
'irakeren': ('iraker',),
'irakerer': ('iraker',),
'irakerne': ('iraker',),
'iraner': ('iraner',),
'iranere': ('iraner',),
'iraneren': ('iraner',),
'iranerer': ('iraner',),
'iranerne': ('iraner',),
'ire': ('ire',),
'iren': ('ire',),
'irene': ('ire',),
'irer': ('ire',),
'irettesettelse': ('irettesettelse',),
'irettesettelsen': ('irettesettelse',),
'irettesettelsene': ('irettesettelse',),
'irettesettelser': ('irettesettelse',),
'irettesetting': ('irettesetting',),
'irettesettinga': ('irettesetting',),
'irettesettingen': ('irettesetting',),
'irettesettingene': ('irettesetting',),
'irettesettinger': ('irettesetting',),
'iridium': ('iridium',),
'iridiuma': ('iridium',),
'iridiumene': ('iridium',),
'iridiumet': ('iridium',),
'iris': ('iris',),
'irisen': ('iris',),
'irisene': ('iris',),
'iriser': ('iris',),
'irisblender': ('irisblender',),
'irisblendere': ('irisblender',),
'irisblenderen': ('irisblender',),
'irisblenderer': ('irisblender',),
'irisblenderne': ('irisblender',),
'irish coffee': ('irish coffee',),
'irisk': ('irisk',),
'irisken': ('irisk',),
'iriskene': ('irisk',),
'irisker': ('irisk',),
'irlender': ('irlender',),
'irlendere': ('irlender',),
'irlenderen': ('irlender',),
'irlenderer': ('irlender',),
'irlenderne': ('irlender',),
'irlending': ('irlending',),
'irlendingen': ('irlending',),
'irlendingene': ('irlending',),
'irlendinger': ('irlending',),
'irokeser': ('irokeser',),
'irokesere': ('irokeser',),
'irokeseren': ('irokeser',),
'irokeserer': ('irokeser',),
'irokeserne': ('irokeser',),
'ironi': ('ironi',),
'ironien': ('ironi',),
'ironiene': ('ironi',),
'ironier': ('ironi',),
'ironiker': ('ironiker',),
'ironikere': ('ironiker',),
'ironikeren': ('ironiker',),
'ironikerer': ('ironiker',),
'ironikerne': ('ironiker',),
'irr': ('irr',),
'irra': ('irr',),
'irrene': ('irr',),
'irret': ('irr',),
'irrasjonalitet': ('irrasjonalitet',),
'irrasjonaliteten': ('irrasjonalitet',),
'irrasjonalitetene': ('irrasjonalitet',),
'irrasjonaliteter': ('irrasjonalitet',),
'irredenta': ('irredenta',),
'irredentaene': ('irredenta',),
'irredentaer': ('irredenta',),
'irredentaet': ('irredenta',),
'irredentisme': ('irredentisme',),
'irredentismen': ('irredentisme',),
'irredentismene': ('irredentisme',),
'irredentismer': ('irredentisme',),
'irregularitet': ('irregularitet',),
'irregulariteten': ('irregularitet',),
'irregularitetene': ('irregularitet',),
'irregulariteter': ('irregularitet',),
'irregulær': ('irregulær',),
'irregulæra': ('irregulær',),
'irregulæren': ('irregulær',),
'irregulærene': ('irregulær',),
'irregulærer': ('irregulær',),
'irrelevans': ('irrelevans',),
'irrelevansen': ('irrelevans',),
'irrelevansene': ('irrelevans',),
'irrelevanser': ('irrelevans',),
'irreligiøsitet': ('irreligiøsitet',),
'irreligiøsiteten': ('irreligiøsitet',),
'irreligiøsitetene': ('irreligiøsitet',),
'irreligiøsiteter': ('irreligiøsitet',),
'irrgang': ('irrgang',),
'irrgangen': ('irrgang',),
'irrgangene': ('irrgang',),
'irrganger': ('irrgang',),
'irrigasjon': ('irrigasjon',),
'irrigasjonen': ('irrigasjon',),
'irrigasjonene': ('irrigasjon',),
'irrigasjoner': ('irrigasjon',),
'irrigasjonsanlegg': ('irrigasjonsanlegg',),
'irrigasjonsanlegga': ('irrigasjonsanlegg',),
'irrigasjonsanleggene': ('irrigasjonsanlegg',),
'irrigasjonsanlegget': ('irrigasjonsanlegg',),
'irritabilitet': ('irritabilitet',),
'irritabiliteten': ('irritabilitet',),
'irritabilitetene': ('irritabilitet',),
'irritabiliteter': ('irritabilitet',),
'irritament': ('irritament',),
'irritamenta': ('irritament',),
'irritamentene': ('irritament',),
'irritamenter': ('irritament',),
'irritamentet': ('irritament',),
'irritasjon': ('irritasjon',),
'irritasjonen': ('irritasjon',),
'irritasjonene': ('irritasjon',),
'irritasjoner': ('irritasjon',),
'irritasjonsmoment': ('irritasjonsmoment',),
'irritasjonsmomenta': ('irritasjonsmoment',),
'irritasjonsmomentene': ('irritasjonsmoment',),
'irritasjonsmomenter': ('irritasjonsmoment',),
'irritasjonsmomentet': ('irritasjonsmoment',),
'irsk': ('irsk',),
'irsken': ('irsk',),
'irskene': ('irsk',),
'irsker': ('irsk',),
'is': ('is',),
'isen': ('is',),
'isene': ('is',),
'iser': ('is',),
'isand': ('isand',),
'isanda': ('isand',),
'isanden': ('isand',),
'isendene': ('isand',),
'isender': ('isand',),
'isbader': ('isbader',),
'isbadere': ('isbader',),
'isbaderen': ('isbader',),
'isbaderer': ('isbader',),
'isbaderne': ('isbader',),
'isbading': ('isbading',),
'isbadinga': ('isbading',),
'isbadingen': ('isbading',),
'isbadingene': ('isbading',),
'isbadinger': ('isbading',),
'isbaks': ('isbaks',),
'isbaksen': ('isbaks',),
'isbaksene': ('isbaks',),
'isbakser': ('isbaks',),
'isbar': ('isbar',),
'isbaren': ('isbar',),
'isbarene': ('isbar',),
'isbarer': ('isbar',),
'isbarriere': ('isbarriere',),
'isbarrieren': ('isbarriere',),
'isbarrierene': ('isbarriere',),
'isbarrierer': ('isbarriere',),
'isberg': ('isberg',),
'isberga': ('isberg',),
'isbergene': ('isberg',),
'isberget': ('isberg',),
'isbit': ('isbit',),
'isbiten': ('isbit',),
'isbitene': ('isbit',),
'isbiter': ('isbit',),
'isbjørn': ('isbjørn',),
'isbjørnen': ('isbjørn',),
'isbjørnene': ('isbjørn',),
'isbjørner': ('isbjørn',),
'isblokk': ('isblokk',),
'isblokka': ('isblokk',),
'isblokken': ('isblokk',),
'isblokkene': ('isblokk',),
'isblokker': ('isblokk',),
'isblomst': ('isblomst',),
'isblomsten': ('isblomst',),
'isblomstene': ('isblomst',),
'isblomster': ('isblomst',),
'isbor': ('isbor',),
'isbora': ('isbor',),
'isboren': ('isbor',),
'isborene': ('isbor',),
'isboret': ('isbor',),
'isbrann': ('isbrann',),
'isbrannen': ('isbrann',),
'isbrannene': ('isbrann',),
'isbranner': ('isbrann',),
'isbre': ('isbre',),
'isbreen': ('isbre',),
'isbreene': ('isbre',),
'isbreer': ('isbre',),
'isbryter': ('isbryter',),
'isbrytere': ('isbryter',),
'isbryteren': ('isbryter',),
'isbryterer': ('isbryter',),
'isbryterne': ('isbryter',),
'iscenesettelse': ('iscenesettelse',),
'iscenesettelsen': ('iscenesettelse',),
'iscenesettelsene': ('iscenesettelse',),
'iscenesettelser': ('iscenesettelse',),
'iscenesetter': ('iscenesetter',),
'iscenesettere': ('iscenesetter',),
'iscenesetteren': ('iscenesetter',),
'iscenesetterer': ('iscenesetter',),
'iscenesetterne': ('iscenesetter',),
'iscenesetting': ('iscenesetting',),
'iscenesettinga': ('iscenesetting',),
'iscenesettingen': ('iscenesetting',),
'iscenesettingene': ('iscenesetting',),
'iscenesettinger': ('iscenesetting',),
'isdannelse': ('isdannelse',),
'isdannelsen': ('isdannelse',),
'isdannelsene': ('isdannelse',),
'isdannelser': ('isdannelse',),
'isdanning': ('isdanning',),
'isdanninga': ('isdanning',),
'isdanningen': ('isdanning',),
'isdanningene': ('isdanning',),
'isdanninger': ('isdanning',),
'isdans': ('isdans',),
'isdansen': ('isdans',),
'isdansene': ('isdans',),
'isdanser': ('isdans',),
'iseddik': ('iseddik',),
'iseddiken': ('iseddik',),
'iseddikene': ('iseddik',),
'iseddiker': ('iseddik',),
'isenkram': ('isenkram',),
'isenkramma': ('isenkram',),
'isenkrammene': ('isenkram',),
'isenkrammet': ('isenkram',),
'isenkramforretning': ('isenkramforretning',),
'isenkramforretninga': ('isenkramforretning',),
'isenkramforretningen': ('isenkramforretning',),
'isenkramforretningene': ('isenkramforretning',),
'isenkramforretninger': ('isenkramforretning',),
'isfiska': ('isfiske',),
'isfiske': ('isfiske',),
'isfiskene': ('isfiske',),
'isfisker': ('isfiske',),
'isfisket': ('isfiske',),
'isfjell': ('isfjell',),
'isfjella': ('isfjell',),
'isfjellene': ('isfjell',),
'isfjellet': ('isfjell',),
'isflak': ('isflak',),
'isflaka': ('isflak',),
'isflakene': ('isflak',),
'isflaket': ('isflak',),
'isforhold': ('isforhold',),
'isforholda': ('isforhold',),
'isforholdene': ('isforhold',),
'isforholdet': ('isforhold',),
'isfront': ('isfront',),
'isfronten': ('isfront',),
'isfrontene': ('isfront',),
'isfronter': ('isfront',),
'isfugl': ('isfugl',),
'isfuglen': ('isfugl',),
'isfuglene': ('isfugl',),
'isfugler': ('isfugl',),
'isgalt': ('isgalt',),
'isgalten': ('isgalt',),
'isgaltene': ('isgalt',),
'isgalter': ('isgalt',),
'isgang': ('isgang',),
'isgangen': ('isgang',),
'isgangene': ('isgang',),
'isganger': ('isgang',),
'isgard': ('isgard',),
'isgarden': ('isgard',),
'isgardene': ('isgard',),
'isgarder': ('isgard',),
'isgrind': ('isgrind',),
'isgrinda': ('isgrind',),
'isgrinden': ('isgrind',),
'isgrindene': ('isgrind',),
'isgrinder': ('isgrind',),
'isgufs': ('isgufs',),
'isgufsa': ('isgufs',),
'isgufsen': ('isgufs',),
'isgufsene': ('isgufs',),
'isgufser': ('isgufs',),
'isgufset': ('isgufs',),
'ishall': ('ishall',),
'ishallen': ('ishall',),
'ishallene': ('ishall',),
'ishaller': ('ishall',),
'ishav': ('ishav',),
'ishava': ('ishav',),
'ishavene': ('ishav',),
'ishavet': ('ishav',),
'ishavsfangst': ('ishavsfangst',),
'ishavsfangsten': ('ishavsfangst',),
'ishavsfangstene': ('ishavsfangst',),
'ishavsfangster': ('ishavsfangst',),
'ishavsgast': ('ishavsgast',),
'ishavsgasten': ('ishavsgast',),
'ishavsgastene': ('ishavsgast',),
'ishavsgaster': ('ishavsgast',),
'ishavsskuta': ('ishavsskute',),
'ishavsskute': ('ishavsskute',),
'ishavsskuten': ('ishavsskute',),
'ishavsskutene': ('ishavsskute',),
'ishavsskuter': ('ishavsskute',),
'ishockey': ('ishockey',),
'ishockeyen': ('ishockey',),
'ishockeyene': ('ishockey',),
'ishockeyer': ('ishockey',),
'ishud': ('ishud',),
'ishuda': ('ishud',),
'ishuden': ('ishud',),
'ishudene': ('ishud',),
'ishuder': ('ishud',),
'ishus': ('ishus',),
'ishusa': ('ishus',),
'ishusene': ('ishus',),
'ishuset': ('ishus',),
'ising': ('ising',),
'isinga': ('ising',),
'isingen': ('ising',),
'isingene': ('ising',),
'isinger': ('ising',),
'isjias': ('isjias',),
'isjiasen': ('isjias',),
'isjiasene': ('isjias',),
'isjiaser': ('isjias',),
'isjiasnerve': ('isjiasnerve',),
'isjiasnerven': ('isjiasnerve',),
'isjiasnervene': ('isjiasnerve',),
'isjiasnerver': ('isjiasnerve',),
'isjøkel': ('isjøkel',),
'isjøkelen': ('isjøkel',),
'isjøklene': ('isjøkel',),
'isjøkler': ('isjøkel',),
'iskoss': ('iskoss',),
'iskossa': ('iskoss',),
'iskossen': ('iskoss',),
'iskossene': ('iskoss',),
'iskosser': ('iskoss',),
'iskosset': ('iskoss',),
'iskrav': ('iskrav',),
'iskrava': ('iskrav',),
'iskravene': ('iskrav',),
'iskravet': ('iskrav',),
'iskrave': ('iskrave',),
'iskraven': ('iskrave',),
'iskravene': ('iskrave',),
'iskraver': ('iskrave',),
'iskrem': ('iskrem',),
'iskremen': ('iskrem',),
'iskremene': ('iskrem',),
'iskremer': ('iskrem',),
'iskrystall': ('iskrystall',),
'iskrystalla': ('iskrystall',),
'iskrystallen': ('iskrystall',),
'iskrystallene': ('iskrystall',),
'iskrystaller': ('iskrystall',),
'iskrystallet': ('iskrystall',),
'iskulda': ('iskulde',),
'iskulde': ('iskulde',),
'iskulden': ('iskulde',),
'iskuldene': ('iskulde',),
'iskulder': ('iskulde',),
'islag': ('islag',),
'islaga': ('islag',),
'islagene': ('islag',),
'islaget': ('islag',),
'islag': ('islag',),
'islaga': ('islag',),
'islagene': ('islag',),
'islaget': ('islag',),
'islam': ('islam',),
'islandshest': ('islandshest',),
'islandshesten': ('islandshest',),
'islandshestene': ('islandshest',),
'islandshester': ('islandshest',),
'islandsk': ('islandsk',),
'islandsken': ('islandsk',),
'islandskene': ('islandsk',),
'islandsker': ('islandsk',),
'islandslav': ('islandslav',),
'islandslava': ('islandslav',),
'islandslavene': ('islandslav',),
'islandslavet': ('islandslav',),
'islandssild': ('islandssild',),
'islandssilda': ('islandssild',),
'islandssilden': ('islandssild',),
'islandssildene': ('islandssild',),
'islandssilder': ('islandssild',),
'islandstrøya': ('islandstrøye',),
'islandstrøye': ('islandstrøye',),
'islandstrøyen': ('islandstrøye',),
'islandstrøyene': ('islandstrøye',),
'islandstrøyer': ('islandstrøye',),
'islegg': ('islegg',),
'isleggen': ('islegg',),
'isleggene': ('islegg',),
'islegger': ('islegg',),
'islender': ('islender',),
'islendere': ('islender',),
'islenderen': ('islender',),
'islenderer': ('islender',),
'islenderne': ('islender',),
'islending': ('islending',),
'islendingen': ('islending',),
'islendingene': ('islending',),
'islendinger': ('islending',),
'islendingesaga': ('islendingesaga',),
'islendingesagaen': ('islendingesaga',),
'islendingesagaene': ('islendingesaga',),
'islendingesagaer': ('islendingesaga',),
'islett': ('islett',),
'isletta': ('islett',),
'islettene': ('islett',),
'islettet': ('islett',),
'islom': ('islom',),
'islommen': ('islom',),
'islommene': ('islom',),
'islommer': ('islom',),
'isløsning': ('isløsning',),
'isløsninga': ('isløsning',),
'isløsningen': ('isløsning',),
'isløsningene': ('isløsning',),
'isløsninger': ('isløsning',),
'isløysing': ('isløysing',),
'isløysinga': ('isløysing',),
'isløysingen': ('isløysing',),
'isløysingene': ('isløysing',),
'isløysinger': ('isløysing',),
'ismaskin': ('ismaskin',),
'ismaskina': ('ismaskin',),
'ismaskinen': ('ismaskin',),
'ismaskinene': ('ismaskin',),
'ismaskiner': ('ismaskin',),
'isme': ('isme',),
'ismen': ('isme',),
'ismene': ('isme',),
'ismer': ('isme',),
'ismåka': ('ismåke',),
'ismåke': ('ismåke',),
'ismåken': ('ismåke',),
'ismåkene': ('ismåke',),
'ismåker': ('ismåke',),
'ismåse': ('ismåse',),
'ismåsen': ('ismåse',),
'ismåsene': ('ismåse',),
'ismåser': ('ismåse',),
'isning': ('isning',),
'isninga': ('isning',),
'isningen': ('isning',),
'isningene': ('isning',),
'isninger': ('isning',),
'isnål': ('isnål',),
'isnåla': ('isnål',),
'isnålen': ('isnål',),
'isnålene': ('isnål',),
'isnåler': ('isnål',),
'isobar': ('isobar',),
'isobaren': ('isobar',),
'isobarene': ('isobar',),
'isobarer': ('isobar',),
'isobat': ('isobat',),
'isobaten': ('isobat',),
'isobatene': ('isobat',),
'isobater': ('isobat',),
'isodynam': ('isodynam',),
'isodynamen': ('isodynam',),
'isodynamene': ('isodynam',),
'isodynamer': ('isodynam',),
'isofon': ('isofon',),
'isofonen': ('isofon',),
'isofonene': ('isofon',),
'isofoner': ('isofon',),
'isogloss': ('isogloss',),
'isoglossen': ('isogloss',),
'isoglossene': ('isogloss',),
'isoglosser': ('isogloss',),
'isokron': ('isokron',),
'isokronen': ('isokron',),
'isokronene': ('isokron',),
'isokroner': ('isokron',),
'isolasjon': ('isolasjon',),
'isolasjonen': ('isolasjon',),
'isolasjonene': ('isolasjon',),
'isolasjoner': ('isolasjon',),
'isolasjonisme': ('isolasjonisme',),
'isolasjonismen': ('isolasjonisme',),
'isolasjonismene': ('isolasjonisme',),
'isolasjonismer': ('isolasjonisme',),
'isolasjonist': ('isolasjonist',),
'isolasjonisten': ('isolasjonist',),
'isolasjonistene': ('isolasjonist',),
'isolasjonister': ('isolasjonist',),
'isolasjonsmateriala': ('isolasjonsmateriale',),
'isolasjonsmateriale': ('isolasjonsmateriale',),
'isolasjonsmaterialene': ('isolasjonsmateriale',),
'isolasjonsmaterialer': ('isolasjonsmateriale',),
'isolasjonsmaterialet': ('isolasjonsmateriale',),
'isolasjonsmatta': ('isolasjonsmatte',),
'isolasjonsmatte': ('isolasjonsmatte',),
'isolasjonsmatten': ('isolasjonsmatte',),
'isolasjonsmattene': ('isolasjonsmatte',),
'isolasjonsmatter': ('isolasjonsmatte',),
'isolasjonsmotstand': ('isolasjonsmotstand',),
'isolasjonsmotstanden': ('isolasjonsmotstand',),
'isolasjonsmotstandene': ('isolasjonsmotstand',),
'isolasjonsmotstander': ('isolasjonsmotstand',),
'isolasjonsplata': ('isolasjonsplate',),
'isolasjonsplate': ('isolasjonsplate',),
'isolasjonsplaten': ('isolasjonsplate',),
'isolasjonsplatene': ('isolasjonsplate',),
'isolasjonsplater': ('isolasjonsplate',),
'isolat': ('isolat',),
'isolata': ('isolat',),
'isolatene': ('isolat',),
'isolater': ('isolat',),
'isolatet': ('isolat',),
'isolator': ('isolator',),
'isolatoren': ('isolator',),
'isolatorene': ('isolator',),
'isolatorer': ('isolator',),
'isolerglass': ('isolerglass',),
'isolerglassa': ('isolerglass',),
'isolerglassene': ('isolerglass',),
'isolerglasset': ('isolerglass',),
'isolering': ('isolering',),
'isoleringa': ('isolering',),
'isoleringen': ('isolering',),
'isoleringene': ('isolering',),
'isoleringer': ('isolering',),
'isomorfi': ('isomorfi',),
'isomorfien': ('isomorfi',),
'isomorfiene': ('isomorfi',),
'isomorfier': ('isomorfi',),
'isomorfisme': ('isomorfisme',),
'isomorfismen': ('isomorfisme',),
'isomorfismene': ('isomorfisme',),
'isomorfismer': ('isomorfisme',),
'isoterm': ('isoterm',),
'isotermen': ('isoterm',),
'isotermene': ('isoterm',),
'isotermer': ('isoterm',),
'isotop': ('isotop',),
'isotopen': ('isotop',),
'isotopene': ('isotop',),
'isotoper': ('isotop',),
'ispil': ('ispil',),
'ispila': ('ispil',),
'ispilen': ('ispil',),
'ispilene': ('ispil',),
'ispiler': ('ispil',),
'ispinne': ('ispinne',),
'ispinnen': ('ispinne',),
'ispinnene': ('ispinne',),
'ispinner': ('ispinne',),
'ispose': ('ispose',),
'isposen': ('ispose',),
'isposene': ('ispose',),
'isposer': ('ispose',),
'israca': ('israce',),
'israce': ('israce',),
'isracene': ('israce',),
'isracet': ('israce',),
'israeler': ('israeler',),
'israelere': ('israeler',),
'israeleren': ('israeler',),
'israelerer': ('israeler',),
'israelerne': ('israeler',),
'israelitt': ('israelitt',),
'israelitten': ('israelitt',),
'israelittene': ('israelitt',),
'israelitter': ('israelitt',),
'isranunkel': ('isranunkel',),
'isranunkelen': ('isranunkel',),
'isranunklene': ('isranunkel',),
'isranunkler': ('isranunkel',),
'isrosa': ('isrose',),
'isrose': ('isrose',),
'isrosen': ('isrose',),
'isrosene': ('isrose',),
'isroser': ('isrose',),
'issalat': ('issalat',),
'issalaten': ('issalat',),
'issalatene': ('issalat',),
'issalater': ('issalat',),
'isse': ('isse',),
'issen': ('isse',),
'issene': ('isse',),
'isser': ('isse',),
'issebein': ('issebein',),
'issebeina': ('issebein',),
'issebeinene': ('issebein',),
'issebeinet': ('issebein',),
'isseben': ('isseben',),
'issebena': ('isseben',),
'issebenene': ('isseben',),
'issebenet': ('isseben',),
'isshelf': ('isshelf',),
'isshelfen': ('isshelf',),
'isshelfene': ('isshelf',),
'isshelfer': ('isshelf',),
'isshow': ('isshow',),
'isshowa': ('isshow',),
'isshowene': ('isshow',),
'isshowet': ('isshow',),
'isskruing': ('isskruing',),
'isskruinga': ('isskruing',),
'isskruingen': ('isskruing',),
'isskruingene': ('isskruing',),
'isskruinger': ('isskruing',),
'isskuring': ('isskuring',),
'isskuringa': ('isskuring',),
'isskuringen': ('isskuring',),
'isskuringene': ('isskuring',),
'isskuringer': ('isskuring',),
'isslag': ('isslag',),
'isslaga': ('isslag',),
'isslagene': ('isslag',),
'isslaget': ('isslag',),
'issoleia': ('issoleie',),
'issoleie': ('issoleie',),
'issoleien': ('issoleie',),
'issoleiene': ('issoleie',),
'issoleier': ('issoleie',),
'issvull': ('issvull',),
'issvullen': ('issvull',),
'issvullene': ('issvull',),
'issvuller': ('issvull',),
'istandsettelse': ('istandsettelse',),
'istandsettelsen': ('istandsettelse',),
'istandsettelsene': ('istandsettelse',),
'istandsettelser': ('istandsettelse',),
'istandsetting': ('istandsetting',),
'istandsettinga': ('istandsetting',),
'istandsettingen': ('istandsetting',),
'istandsettingene': ('istandsetting',),
'istandsettinger': ('istandsetting',),
'istapp': ('istapp',),
'istappen': ('istapp',),
'istappene': ('istapp',),
'istapper': ('istapp',),
'ister': ('ister',),
'isteret': ('ister',),
'istra': ('ister',),
'istre': ('ister',),
'istrene': ('ister',),
'istret': ('ister',),
'ister': ('ister',),
'istere': ('ister',),
'isteren': ('ister',),
'isterne': ('ister',),
'istra': ('ister',),
'istre': ('ister',),
'istrene': ('ister',),
'istrer': ('ister',),
'istermage': ('istermage',),
'istermagen': ('istermage',),
'istermagene': ('istermage',),
'istermager': ('istermage',),
'istermave': ('istermave',),
'istermaven': ('istermave',),
'istermavene': ('istermave',),
'istermaver': ('istermave',),
'istersild': ('istersild',),
'istersilda': ('istersild',),
'istersilden': ('istersild',),
'istersildene': ('istersild',),
'istersilder': ('istersild',),
'istervom': ('istervom',),
'istervomma': ('istervom',),
'istervommen': ('istervom',),
'istervommene': ('istervom',),
'istervommer': ('istervom',),
'istid': ('istid',),
'istida': ('istid',),
'istiden': ('istid',),
'istidene': ('istid',),
'istider': ('istid',),
'isvann': ('isvann',),
'isvanna': ('isvann',),
'isvannene': ('isvann',),
'isvannet': ('isvann',),
'isvatn': ('isvatn',),
'isvatna': ('isvatn',),
'isvatnene': ('isvatn',),
'isvatnet': ('isvatn',),
'isvind': ('isvind',),
'isvinden': ('isvind',),
'isvindene': ('isvind',),
'isvinder': ('isvind',),
'isøda': ('isøde',),
'isøde': ('isøde',),
'isødene': ('isøde',),
'isøder': ('isøde',),
'isødet': ('isøde',),
'isøks': ('isøks',),
'isøksa': ('isøks',),
'isøksen': ('isøks',),
'isøksene': ('isøks',),
'isøkser': ('isøks',),
'isørken': ('isørken',),
'isørkenen': ('isørken',),
'isørkenene': ('isørken',),
'isørkener': ('isørken',),
'it': ('it',),
'itakisme': ('itakisme',),
'itakismen': ('itakisme',),
'itakismene': ('itakisme',),
'itakismer': ('itakisme',),
'italiener': ('italiener',),
'italienere': ('italiener',),
'italieneren': ('italiener',),
'italienerer': ('italiener',),
'italienerne': ('italiener',),
'italiensk': ('italiensk',),
'italiensken': ('italiensk',),
'italienskene': ('italiensk',),
'italiensker': ('italiensk',),
'italiker': ('italiker',),
'italikere': ('italiker',),
'italikeren': ('italiker',),
'italikerer': ('italiker',),
'italikerne': ('italiker',),
'iterant': ('iterant',),
'iteranten': ('iterant',),
'iterantene': ('iterant',),
'iteranter': ('iterant',),
'iterasjon': ('iterasjon',),
'iterasjonen': ('iterasjon',),
'iterasjonene': ('iterasjon',),
'iterasjoner': ('iterasjon',),
'iterativ': ('iterativ',),
'iterativa': ('iterativ',),
'iterativene': ('iterativ',),
'iterativer': ('iterativ',),
'iterativet': ('iterativ',),
'itle': ('itle',),
'itlen': ('itle',),
'itlene': ('itle',),
'itler': ('itle',),
'iver': ('iver',),
'ivere': ('iver',),
'iveren': ('iver',),
'iverer': ('iver',),
'iverne': ('iver',),
'ivre': ('iver',),
'ivrene': ('iver',),
'ivrer': ('iver',),
'iverksettelse': ('iverksettelse',),
'iverksettelsen': ('iverksettelse',),
'iverksettelsene': ('iverksettelse',),
'iverksettelser': ('iverksettelse',),
'iverksetting': ('iverksetting',),
'iverksettinga': ('iverksetting',),
'iverksettingen': ('iverksetting',),
'iverksettingene': ('iverksetting',),
'iverksettinger': ('iverksetting',),
'ivorianer': ('ivorianer',),
'ivorianere': ('ivorianer',),
'ivorianeren': ('ivorianer',),
'ivorianerer': ('ivorianer',),
'ivorianerne': ('ivorianer',),
'j': ('j',),
'j\'en': ('j',),
'j-en': ('j',),
'j-ene': ('j',),
'j-er': ('j',),
'ja': ('ja',),
'jaa': ('ja',),
'jaene': ('ja',),
'jaer': ('ja',),
'jaet': ('ja',),
'jabb': ('jabb',),
'jabba': ('jabb',),
'jabbene': ('jabb',),
'jabbet': ('jabb',),
'jabb': ('jabb',),
'jabba': ('jabb',),
'jabbene': ('jabb',),
'jabbet': ('jabb',),
'jacket': ('jacket',),
'jacketen': ('jacket',),
'jacketene': ('jacket',),
'jacketer': ('jacket',),
'jackets': ('jacket',),
'jacketkrona': ('jacketkrone',),
'jacketkrone': ('jacketkrone',),
'jacketkronen': ('jacketkrone',),
'jacketkronene': ('jacketkrone',),
'jacketkroner': ('jacketkrone',),
'jacquardmaskin': ('jacquardmaskin',),
'jacquardmaskina': ('jacquardmaskin',),
'jacquardmaskinen': ('jacquardmaskin',),
'jacquardmaskinene': ('jacquardmaskin',),
'jacquardmaskiner': ('jacquardmaskin',),
'jacquardmønster': ('jacquardmønster',),
'jacquardmønsteret': ('jacquardmønster',),
'jacquardmønstra': ('jacquardmønster',),
'jacquardmønstre': ('jacquardmønster',),
'jacquardmønstrene': ('jacquardmønster',),
'jacquardmønstret': ('jacquardmønster',),
'jacquardvevnad': ('jacquardvevnad',),
'jacquardvevnaden': ('jacquardvevnad',),
'jacquardvevnadene': ('jacquardvevnad',),
'jacquardvevnader': ('jacquardvevnad',),
'jade': ('jade',),
'jaden': ('jade',),
'jadene': ('jade',),
'jader': ('jade',),
'jafs': ('jafs',),
'jafsa': ('jafs',),
'jafsen': ('jafs',),
'jafsene': ('jafs',),
'jafser': ('jafs',),
'jafset': ('jafs',),
'jag': ('jag',),
'jaga': ('jag',),
'jagene': ('jag',),
'jaget': ('jag',),
'jager': ('jager',),
'jagere': ('jager',),
'jageren': ('jager',),
'jagerer': ('jager',),
'jagerne': ('jager',),
'jagerbom': ('jagerbom',),
'jagerbommen': ('jagerbom',),
'jagerbommene': ('jagerbom',),
'jagerbommer': ('jagerbom',),
'jagerbomber': ('jagerbomber',),
'jagerbombere': ('jagerbomber',),
'jagerbomberen': ('jagerbomber',),
'jagerbomberer': ('jagerbomber',),
'jagerbomberne': ('jagerbomber',),
'jagerfly': ('jagerfly',),
'jagerflya': ('jagerfly',),
'jagerflyene': ('jagerfly',),
'jagerflyet': ('jagerfly',),
'jaguar': ('jaguar',),
'jaguaren': ('jaguar',),
'jaguarene': ('jaguar',),
'jaguarer': ('jaguar',),
'jak': ('jak',),
'jaken': ('jak',),
'jakene': ('jak',),
'jaker': ('jak',),
'jakaranda': ('jakaranda',),
'jakarandaen': ('jakaranda',),
'jakarandaene': ('jakaranda',),
'jakarandaer': ('jakaranda',),
'jakka': ('jakke',),
'jakke': ('jakke',),
'jakken': ('jakke',),
'jakkene': ('jakke',),
'jakker': ('jakke',),
'jakku': ('jakku',),
'jakkua': ('jakku',),
'jakkuen': ('jakku',),
'jakkuene': ('jakku',),
'jakkuer': ('jakku',),
'jakkyr': ('jakku',),
'jakkyrne': ('jakku',),
'jakobiner': ('jakobiner',),
'jakobinere': ('jakobiner',),
'jakobineren': ('jakobiner',),
'jakobinerer': ('jakobiner',),
'jakobinerne': ('jakobiner',),
'jakobinerkloster': ('jakobinerkloster',),
'jakobinerklosteret': ('jakobinerkloster',),
'jakobinerklostra': ('jakobinerkloster',),
'jakobinerklostre': ('jakobinerkloster',),
'jakobinerklostrene': ('jakobinerkloster',),
'jakobinerklostret': ('jakobinerkloster',),
'jakobinerklubb': ('jakobinerklubb',),
'jakobinerklubben': ('jakobinerklubb',),
'jakobinerklubbene': ('jakobinerklubb',),
'jakobinerklubber': ('jakobinerklubb',),
'jakobsmess': ('jakobsmess',),
'jakobsmesse': ('jakobsmesse',),
'jakobsstav': ('jakobsstav',),
'jakobsstaven': ('jakobsstav',),
'jakobsstavene': ('jakobsstav',),
'jakobsstaver': ('jakobsstav',),
'jakobsstige': ('jakobsstige',),
'jakobsstigen': ('jakobsstige',),
'jakobsstigene': ('jakobsstige',),
'jakobsstiger': ('jakobsstige',),
'jakokse': ('jakokse',),
'jakoksen': ('jakokse',),
'jakoksene': ('jakokse',),
'jakokser': ('jakokse',),
'jakt': ('jakt',),
'jakta': ('jakt',),
'jakten': ('jakt',),
'jaktene': ('jakt',),
'jakter': ('jakt',),
'jakt': ('jakt',),
'jakta': ('jakt',),
'jakten': ('jakt',),
'jaktene': ('jakt',),
'jakter': ('jakt',),
'jaktfalk': ('jaktfalk',),
'jaktfalken': ('jaktfalk',),
'jaktfalkene': ('jaktfalk',),
'jaktfalker': ('jaktfalk',),
'jaktfelt': ('jaktfelt',),
'jaktfelta': ('jaktfelt',),
'jaktfeltene': ('jaktfelt',),
'jaktfelter': ('jaktfelt',),
'jaktfeltet': ('jaktfelt',),
'jaktgevær': ('jaktgevær',),
'jaktgeværa': ('jaktgevær',),
'jaktgeværene': ('jaktgevær',),
'jaktgeværer': ('jaktgevær',),
'jaktgeværet': ('jaktgevær',),
'jakthorn': ('jakthorn',),
'jakthorna': ('jakthorn',),
'jakthornene': ('jakthorn',),
'jakthornet': ('jakthorn',),
'jakthund': ('jakthund',),
'jakthunden': ('jakthund',),
'jakthundene': ('jakthund',),
'jakthunder': ('jakthund',),
'jakthytta': ('jakthytte',),
'jakthytte': ('jakthytte',),
'jakthytten': ('jakthytte',),
'jakthyttene': ('jakthytte',),
'jakthytter': ('jakthytte',),
'jaktkniv': ('jaktkniv',),
'jaktkniven': ('jaktkniv',),
'jaktknivene': ('jaktkniv',),
'jaktkniver': ('jaktkniv',),
'jaktkort': ('jaktkort',),
'jaktkorta': ('jaktkort',),
'jaktkortene': ('jaktkort',),
'jaktkortet': ('jaktkort',),
'jaktlag': ('jaktlag',),
'jaktlaga': ('jaktlag',),
'jaktlagene': ('jaktlag',),
'jaktlaget': ('jaktlag',),
'jaktmark': ('jaktmark',),
'jaktmarka': ('jaktmark',),
'jaktmarken': ('jaktmark',),
'jaktmarkene': ('jaktmark',),
'jaktmarker': ('jaktmark',),
'jaktoppsyn': ('jaktoppsyn',),
'jaktoppsyna': ('jaktoppsyn',),
'jaktoppsynene': ('jaktoppsyn',),
'jaktoppsynet': ('jaktoppsyn',),
'jaktpoliti': ('jaktpoliti',),
'jaktpolitia': ('jaktpoliti',),
'jaktpolitiene': ('jaktpoliti',),
'jaktpolitier': ('jaktpoliti',),
'jaktpolitiet': ('jaktpoliti',),
'jaktprøva': ('jaktprøve',),
'jaktprøve': ('jaktprøve',),
'jaktprøven': ('jaktprøve',),
'jaktprøvene': ('jaktprøve',),
'jaktprøver': ('jaktprøve',),
'jaktrett': ('jaktrett',),
'jaktretten': ('jaktrett',),
'jaktrettene': ('jaktrett',),
'jaktretter': ('jaktrett',),
'jaktstart': ('jaktstart',),
'jaktstarten': ('jaktstart',),
'jaktstartene': ('jaktstart',),
'jaktstarter': ('jaktstart',),
'jaktsti': ('jaktsti',),
'jaktstien': ('jaktsti',),
'jaktstiene': ('jaktsti',),
'jaktstier': ('jaktsti',),
'jaktterreng': ('jaktterreng',),
'jaktterrenga': ('jaktterreng',),
'jaktterrengene': ('jaktterreng',),
'jaktterrenget': ('jaktterreng',),
'jakttid': ('jakttid',),
'jakttida': ('jakttid',),
'jakttiden': ('jakttid',),
'jakttidene': ('jakttid',),
'jakttider': ('jakttid',),
'jakuter': ('jakuter',),
'jakutere': ('jakuter',),
'jakuteren': ('jakuter',),
'jakuterer': ('jakuter',),
'jakuterne': ('jakuter',),
'jalm': ('jalm',),
'jalmen': ('jalm',),
'jalmene': ('jalm',),
'jalmer': ('jalm',),
'jam': ('jam',),
'jammen': ('jam',),
'jammene': ('jam',),
'jammer': ('jam',),
'jam session': ('jam session',),
'jamaicaner': ('jamaicaner',),
'jamaicanere': ('jamaicaner',),
'jamaicaneren': ('jamaicaner',),
'jamaicanerer': ('jamaicaner',),
'jamaicanerne': ('jamaicaner',),
'jamaicaner': ('jamaicaner',),
'jamaicanere': ('jamaicaner',),
'jamaicaneren': ('jamaicaner',),
'jamaicanerer': ('jamaicaner',),
'jamaicanerne': ('jamaicaner',),
'jamaikaner': ('jamaikaner',),
'jamaikanere': ('jamaikaner',),
'jamaikaneren': ('jamaikaner',),
'jamaikanerer': ('jamaikaner',),
'jamaikanerne': ('jamaikaner',),
'jamaikaner': ('jamaikaner',),
'jamaikanere': ('jamaikaner',),
'jamaikaneren': ('jamaikaner',),
'jamaikanerer': ('jamaikaner',),
'jamaikanerne': ('jamaikaner',),
'jamaikarom': ('jamaikarom',),
'jamaikarommen': ('jamaikarom',),
'jamaikarommene': ('jamaikarom',),
'jamaikarommer': ('jamaikarom',),
'jamaldring': ('jamaldring',),
'jamaldringen': ('jamaldring',),
'jamaldringene': ('jamaldring',),
'jamaldringer': ('jamaldring',),
'jamann': ('jamann',),
'jamannen': ('jamann',),
'jamenn': ('jamann',),
'jamennene': ('jamann',),
'jambe': ('jambe',),
'jamben': ('jambe',),
'jambene': ('jambe',),
'jamber': ('jambe',),
'jamboree': ('jamboree',),
'jamboreen': ('jamboree',),
'jamboreene': ('jamboree',),
'jamboreer': ('jamboree',),
'jamdøger': ('jamdøger',),
'jamdøgeret': ('jamdøger',),
'jamdøgerne': ('jamdøger',),
'jamdøgn': ('jamdøgn',),
'jamdøgna': ('jamdøgn',),
'jamdøgnene': ('jamdøgn',),
'jamdøgnet': ('jamdøgn',),
'jamenneska': ('jamenneske',),
'jamenneske': ('jamenneske',),
'jamenneskene': ('jamenneske',),
'jamennesker': ('jamenneske',),
'jamennesket': ('jamenneske',),
'jamføring': ('jamføring',),
'jamføringa': ('jamføring',),
'jamføringen': ('jamføring',),
'jamføringene': ('jamføring',),
'jamføringer': ('jamføring',),
'jamlike': ('jamlike',),
'jamliken': ('jamlike',),
'jamlikene': ('jamlike',),
'jamliker': ('jamlike',),
'jammer': ('jammer',),
'jammere': ('jammer',),
'jammeren': ('jammer',),
'jammerer': ('jammer',),
'jammerne': ('jammer',),
'jamrene': ('jammer',),
'jamrer': ('jammer',),
'jammerdal': ('jammerdal',),
'jammerdalen': ('jammerdal',),
'jammerdalene': ('jammerdal',),
'jammerdaler': ('jammerdal',),
'jammerrop': ('jammerrop',),
'jammerropa': ('jammerrop',),
'jammerropene': ('jammerrop',),
'jammerropet': ('jammerrop',),
'jamnad': ('jamnad',),
'jamnaden': ('jamnad',),
'jamnadene': ('jamnad',),
'jamnader': ('jamnad',),
'jamnhet': ('jamnhet',),
'jamnheta': ('jamnhet',),
'jamnheten': ('jamnhet',),
'jamnhetene': ('jamnhet',),
'jamnheter': ('jamnhet',),
'jamning': ('jamning',),
'jamninga': ('jamning',),
'jamningen': ('jamning',),
'jamningene': ('jamning',),
'jamninger': ('jamning',),
'jamning': ('jamning',),
'jamninga': ('jamning',),
'jamningen': ('jamning',),
'jamningene': ('jamning',),
'jamninger': ('jamning',),
'jams': ('jams',),
'jamsen': ('jams',),
'jamsene': ('jams',),
'jamser': ('jams',),
'jamstilling': ('jamstilling',),
'jamstillinga': ('jamstilling',),
'jamstillingen': ('jamstilling',),
'jamstillingene': ('jamstilling',),
'jamstillinger': ('jamstilling',),
'jamte': ('jamte',),
'jamten': ('jamte',),
'jamtene': ('jamte',),
'jamter': ('jamte',),
'jamvekt': ('jamvekt',),
'jamvekta': ('jamvekt',),
'jamvekten': ('jamvekt',),
'jamvektene': ('jamvekt',),
'jamvekter': ('jamvekt',),
'jan': ('jan',),
'janen': ('jan',),
'janene': ('jan',),
'janer': ('jan',),
'janitsjar': ('janitsjar',),
'janitsjaren': ('janitsjar',),
'janitsjarene': ('janitsjar',),
'janitsjarer': ('janitsjar',),
'janitsjarmusikk': ('janitsjarmusikk',),
'janitsjarmusikken': ('janitsjarmusikk',),
'janitsjarmusikkene': ('janitsjarmusikk',),
'janitsjarmusikker': ('janitsjarmusikk',),
'janitsjarorkester': ('janitsjarorkester',),
'janitsjarorkesteret': ('janitsjarorkester',),
'janitsjarorkestra': ('janitsjarorkester',),
'janitsjarorkestre': ('janitsjarorkester',),
'janitsjarorkestrene': ('janitsjarorkester',),
'janitsjarorkestret': ('janitsjarorkester',),
'jantelov': ('jantelov',),
'janteloven': ('jantelov',),
'jantelovene': ('jantelov',),
'jantelover': ('jantelov',),
'januar': ('januar',),
'janusansikt': ('janusansikt',),
'janusansikta': ('janusansikt',),
'janusansiktene': ('janusansikt',),
'janusansikter': ('janusansikt',),
'janusansiktet': ('janusansikt',),
'jaord': ('jaord',),
'jaorda': ('jaord',),
'jaordene': ('jaord',),
'jaordet': ('jaord',),
'japaner': ('japaner',),
'japanere': ('japaner',),
'japaneren': ('japaner',),
'japanerer': ('japaner',),
'japanerne': ('japaner',),
'japansk': ('japansk',),
'japansken': ('japansk',),
'japanskene': ('japansk',),
'japansker': ('japansk',),
'japp': ('japp',),
'jappen': ('japp',),
'jappene': ('japp',),
'japper': ('japp',),
'japs': ('japs',),
'japsen': ('japs',),
'japsene': ('japs',),
'japser': ('japs',),
'jar': ('jar',),
'jaren': ('jar',),
'jarene': ('jar',),
'jarer': ('jar',),
'jar': ('jar',),
'jaren': ('jar',),
'jarene': ('jar',),
'jarer': ('jar',),
'jardiniere': ('jardiniere',),
'jardinieren': ('jardiniere',),
'jardinierene': ('jardiniere',),
'jardinierer': ('jardiniere',),
'jare': ('jare',),
'jaren': ('jare',),
'jarene': ('jare',),
'jarer': ('jare',),
'jare': ('jare',),
'jaren': ('jare',),
'jarene': ('jare',),
'jarer': ('jare',),
'jarl': ('jarl',),
'jarlen': ('jarl',),
'jarlene': ('jarl',),
'jarler': ('jarl',),
'jarledømma': ('jarledømme',),
'jarledømme': ('jarledømme',),
'jarledømmene': ('jarledømme',),
'jarledømmer': ('jarledømme',),
'jarledømmet': ('jarledømme',),
'jarlenavn': ('jarlenavn',),
'jarlenavna': ('jarlenavn',),
'jarlenavnene': ('jarlenavn',),
'jarlenavnet': ('jarlenavn',),
'jarleætt': ('jarleætt',),
'jarleætta': ('jarleætt',),
'jarleætten': ('jarleætt',),
'jarleættene': ('jarleætt',),
'jarleætter': ('jarleætt',),
'jarlsdømma': ('jarlsdømme',),
'jarlsdømme': ('jarlsdømme',),
'jarlsdømmene': ('jarlsdømme',),
'jarlsdømmer': ('jarlsdømme',),
'jarlsdømmet': ('jarlsdømme',),
'jarlsnavn': ('jarlsnavn',),
'jarlsnavna': ('jarlsnavn',),
'jarlsnavnene': ('jarlsnavn',),
'jarlsnavnet': ('jarlsnavn',),
'jarlsætt': ('jarlsætt',),
'jarlsætta': ('jarlsætt',),
'jarlsætten': ('jarlsætt',),
'jarlsættene': ('jarlsætt',),
'jarlsætter': ('jarlsætt',),
'jask': ('jask',),
'jaska': ('jask',),
'jaskene': ('jask',),
'jasket': ('jask',),
'jaspis': ('jaspis',),
'jaspisen': ('jaspis',),
'jaspisene': ('jaspis',),
'jaspiser': ('jaspis',),
'jass': ('jass',),
'jassen': ('jass',),
'jassene': ('jass',),
'jasser': ('jass',),
'jassballett': ('jassballett',),
'jassballetten': ('jassballett',),
'jassballettene': ('jassballett',),
'jassballetter': ('jassballett',),
'jassband': ('jassband',),
'jassbanda': ('jassband',),
'jassbandene': ('jassband',),
'jassbandet': ('jassband',),
'jassmusiker': ('jassmusiker',),
'jassmusikere': ('jassmusiker',),
'jassmusikeren': ('jassmusiker',),
'jassmusikerer': ('jassmusiker',),
'jassmusikerne': ('jassmusiker',),
'jassmusikk': ('jassmusikk',),
'jassmusikken': ('jassmusikk',),
'jassmusikkene': ('jassmusikk',),
'jassmusikker': ('jassmusikk',),
'jassorkester': ('jassorkester',),
'jassorkesteret': ('jassorkester',),
'jassorkestra': ('jassorkester',),
'jassorkestre': ('jassorkester',),
'jassorkestrene': ('jassorkester',),
'jassorkestret': ('jassorkester',),
'jastemme': ('jastemme',),
'jastemmen': ('jastemme',),
'jastemmene': ('jastemme',),
'jastemmer': ('jastemme',),
'javakaffe': ('javakaffe',),
'javakaffen': ('javakaffe',),
'javakaffene': ('javakaffe',),
'javakaffer': ('javakaffe',),
'javaneser': ('javaneser',),
'javanesere': ('javaneser',),
'javaneseren': ('javaneser',),
'javaneserer': ('javaneser',),
'javaneserne': ('javaneser',),
'jazz': ('jazz',),
'jazzen': ('jazz',),
'jazzene': ('jazz',),
'jazzer': ('jazz',),
'jazzballett': ('jazzballett',),
'jazzballetten': ('jazzballett',),
'jazzballettene': ('jazzballett',),
'jazzballetter': ('jazzballett',),
'jazzband': ('jazzband',),
'jazzbanda': ('jazzband',),
'jazzbandene': ('jazzband',),
'jazzbandet': ('jazzband',),
'jazzmusiker': ('jazzmusiker',),
'jazzmusikere': ('jazzmusiker',),
'jazzmusikeren': ('jazzmusiker',),
'jazzmusikerer': ('jazzmusiker',),
'jazzmusikerne': ('jazzmusiker',),
'jazzmusikk': ('jazzmusikk',),
'jazzmusikken': ('jazzmusikk',),
'jazzmusikkene': ('jazzmusikk',),
'jazzmusikker': ('jazzmusikk',),
'jazzorkester': ('jazzorkester',),
'jazzorkesteret': ('jazzorkester',),
'jazzorkestra': ('jazzorkester',),
'jazzorkestre': ('jazzorkester',),
'jazzorkestrene': ('jazzorkester',),
'jazzorkestret': ('jazzorkester',),
'jeans': ('jeans',),
'jeansen': ('jeans',),
'jeansene': ('jeans',),
'jeep': ('jeep',),
'jeepen': ('jeep',),
'jeepene': ('jeep',),
'jeeper': ('jeep',),
'jeg': ('jeg',),
'jega': ('jeg',),
'jegene': ('jeg',),
'jeger': ('jeg',),
'jeget': ('jeg',),
'jeger': ('jeger',),
'jegere': ('jeger',),
'jegeren': ('jeger',),
'jegerer': ('jeger',),
'jegerne': ('jeger',),
'jegerhest': ('jegerhest',),
'jegerhesten': ('jegerhest',),
'jegerhestene': ('jegerhest',),
'jegerhester': ('jegerhest',),
'jegerkorps': ('jegerkorps',),
'jegerkorpsa': ('jegerkorps',),
'jegerkorpsene': ('jegerkorps',),
'jegerkorpset': ('jegerkorps',),
'jegertropp': ('jegertropp',),
'jegertroppen': ('jegertropp',),
'jegertroppene': ('jegertropp',),
'jegertropper': ('jegertropp',),
'jegform': ('jegform',),
'jegforma': ('jegform',),
'jegformen': ('jegform',),
'jegformene': ('jegform',),
'jegformer': ('jegform',),
'jegroman': ('jegroman',),
'jegromanen': ('jegroman',),
'jegromanene': ('jegroman',),
'jegromaner': ('jegroman',),
'jekk': ('jekk',),
'jekken': ('jekk',),
'jekkene': ('jekk',),
'jekker': ('jekk',),
'jekkpott': ('jekkpott',),
'jekkpotten': ('jekkpott',),
'jekkpottene': ('jekkpott',),
'jekkpotter': ('jekkpott',),
'jeksel': ('jeksel',),
'jekselen': ('jeksel',),
'jekslene': ('jeksel',),
'jeksler': ('jeksel',),
'jekt': ('jekt',),
'jekta': ('jekt',),
'jekten': ('jekt',),
'jektene': ('jekt',),
'jekter': ('jekt',),
'jektebruk': ('jektebruk',),
'jektebruka': ('jektebruk',),
'jektebrukene': ('jektebruk',),
'jektebruket': ('jektebruk',),
'jekteskipper': ('jekteskipper',),
'jekteskippere': ('jekteskipper',),
'jekteskipperen': ('jekteskipper',),
'jekteskipperer': ('jekteskipper',),
'jekteskipperne': ('jekteskipper',),
'jelk': ('jelk',),
'jelken': ('jelk',),
'jelkene': ('jelk',),
'jelker': ('jelk',),
'jemenitt': ('jemenitt',),
'jemenitten': ('jemenitt',),
'jemenittene': ('jemenitt',),
'jemenitter': ('jemenitt',),
'jemenitt': ('jemenitt',),
'jemenitten': ('jemenitt',),
'jemenittene': ('jemenitt',),
'jemenitter': ('jemenitt',),
'jemte': ('jemte',),
'jemten': ('jemte',),
'jemtene': ('jemte',),
'jemter': ('jemte',),
'jemtlending': ('jemtlending',),
'jemtlendingen': ('jemtlending',),
'jemtlendingene': ('jemtlending',),
'jemtlendinger': ('jemtlending',),
'jenka': ('jenka',),
'jenkaen': ('jenka',),
'jenkaene': ('jenka',),
'jenkaer': ('jenka',),
'jens': ('jens',),
'jensen': ('jens',),
'jensene': ('jens',),
'jenser': ('jens',),
'jenta': ('jente',),
'jente': ('jente',),
'jenten': ('jente',),
'jentene': ('jente',),
'jenter': ('jente',),
'jentedalt': ('jentedalt',),
'jentedalten': ('jentedalt',),
'jentedaltene': ('jentedalt',),
'jentedalter': ('jentedalt',),
'jentefut': ('jentefut',),
'jentefuten': ('jentefut',),
'jentefutene': ('jentefut',),
'jentefuter': ('jentefut',),
'jentenavn': ('jentenavn',),
'jentenavna': ('jentenavn',),
'jentenavnene': ('jentenavn',),
'jentenavnet': ('jentenavn',),
'jentetekka': ('jentetekke',),
'jentetekke': ('jentetekke',),
'jentetekkene': ('jentetekke',),
'jentetekker': ('jentetekke',),
'jentetekket': ('jentetekke',),
'jentunge': ('jentunge',),
'jentungen': ('jentunge',),
'jentungene': ('jentunge',),
'jentunger': ('jentunge',),
'jeremiade': ('jeremiade',),
'jeremiaden': ('jeremiade',),
'jeremiadene': ('jeremiade',),
'jeremiader': ('jeremiade',),
'jerikorosa': ('jerikorose',),
'jerikorose': ('jerikorose',),
'jerikorosen': ('jerikorose',),
'jerikorosene': ('jerikorose',),
'jerikoroser': ('jerikorose',),
'jern': ('jern',),
'jerna': ('jern',),
'jernene': ('jern',),
'jernet': ('jern',),
'jern- og metallarbeider': ('jern- og metallarbeider',),
'jern- og metallarbeidere': ('jern- og metallarbeider',),
'jern- og metallarbeideren': ('jern- og metallarbeider',),
'jern- og metallarbeiderer': ('jern- og metallarbeider',),
'jern- og metallarbeiderne': ('jern- og metallarbeider',),
'jernalder': ('jernalder',),
'jernaldere': ('jernalder',),
'jernalderen': ('jernalder',),
'jernalderer': ('jernalder',),
'jernalderne': ('jernalder',),
'jernaldre': ('jernalder',),
'jernaldrene': ('jernalder',),
'jernaldrer': ('jernalder',),
'jernarbeider': ('jernarbeider',),
'jernarbeidere': ('jernarbeider',),
'jernarbeideren': ('jernarbeider',),
'jernarbeiderer': ('jernarbeider',),
'jernarbeiderne': ('jernarbeider',),
'jernbane': ('jernbane',),
'jernbanen': ('jernbane',),
'jernbanene': ('jernbane',),
'jernbaner': ('jernbane',),
'jernbanedirektør': ('jernbanedirektør',),
'jernbanedirektøren': ('jernbanedirektør',),
'jernbanedirektørene': ('jernbanedirektør',),
'jernbanedirektører': ('jernbanedirektør',),
'jernbaneferga': ('jernbaneferge',),
'jernbaneferge': ('jernbaneferge',),
'jernbanefergen': ('jernbaneferge',),
'jernbanefergene': ('jernbaneferge',),
'jernbaneferger': ('jernbaneferge',),
'jernbaneinspektør': ('jernbaneinspektør',),
'jernbaneinspektøren': ('jernbaneinspektør',),
'jernbaneinspektørene': ('jernbaneinspektør',),
'jernbaneinspektører': ('jernbaneinspektør',),
'jernbanelinja': ('jernbanelinje',),
'jernbanelinje': ('jernbanelinje',),
'jernbanelinjen': ('jernbanelinje',),
'jernbanelinjene': ('jernbanelinje',),
'jernbanelinjer': ('jernbanelinje',),
'jernbanenett': ('jernbanenett',),
'jernbanenetta': ('jernbanenett',),
'jernbanenettene': ('jernbanenett',),
'jernbanenettet': ('jernbanenett',),
'jernbaneovergang': ('jernbaneovergang',),
'jernbaneovergangen': ('jernbaneovergang',),
'jernbaneovergangene': ('jernbaneovergang',),
'jernbaneoverganger': ('jernbaneovergang',),
'jernbanerestaurant': ('jernbanerestaurant',),
'jernbanerestauranten': ('jernbanerestaurant',),
'jernbanerestaurantene': ('jernbanerestaurant',),
'jernbanerestauranter': ('jernbanerestaurant',),
'jernbaneskinna': ('jernbaneskinne',),
'jernbaneskinne': ('jernbaneskinne',),
'jernbaneskinnen': ('jernbaneskinne',),
'jernbaneskinnene': ('jernbaneskinne',),
'jernbaneskinner': ('jernbaneskinne',),
'jernbanespor': ('jernbanespor',),
'jernbanespora': ('jernbanespor',),
'jernbanesporene': ('jernbanespor',),
'jernbanesporet': ('jernbanespor',),
'jernbanestasjon': ('jernbanestasjon',),
'jernbanestasjonen': ('jernbanestasjon',),
'jernbanestasjonene': ('jernbanestasjon',),
'jernbanestasjoner': ('jernbanestasjon',),
'jernbaneundergang': ('jernbaneundergang',),
'jernbaneundergangen': ('jernbaneundergang',),
'jernbaneundergangene': ('jernbaneundergang',),
'jernbaneunderganger': ('jernbaneundergang',),
'jernbanevogn': ('jernbanevogn',),
'jernbanevogna': ('jernbanevogn',),
'jernbanevognen': ('jernbanevogn',),
'jernbanevognene': ('jernbanevogn',),
'jernbanevogner': ('jernbanevogn',),
'jernbetong': ('jernbetong',),
'jernbetongen': ('jernbetong',),
'jernbetongene': ('jernbetong',),
'jernbetonger': ('jernbetong',),
'jernbinder': ('jernbinder',),
'jernbindere': ('jernbinder',),
'jernbinderen': ('jernbinder',),
'jernbinderer': ('jernbinder',),
'jernbinderne': ('jernbinder',),
'jernbryllup': ('jernbryllup',),
'jernbryllupa': ('jernbryllup',),
'jernbryllupene': ('jernbryllup',),
'jernbrylluper': ('jernbryllup',),
'jernbryllupet': ('jernbryllup',),
'jernbyrd': ('jernbyrd',),
'jernbyrden': ('jernbyrd',),
'jernbyrdene': ('jernbyrd',),
'jernbyrder': ('jernbyrd',),
'jerndisiplin': ('jerndisiplin',),
'jerndisiplinen': ('jerndisiplin',),
'jerndisiplinene': ('jerndisiplin',),
'jerndisipliner': ('jerndisiplin',),
'jernglans': ('jernglans',),
'jernglansen': ('jernglans',),
'jernglansene': ('jernglans',),
'jernglanser': ('jernglans',),
'jerngrep': ('jerngrep',),
'jerngrepa': ('jerngrep',),
'jerngrepene': ('jerngrep',),
'jerngrepet': ('jerngrep',),
'jernhand': ('jernhand',),
'jernhanda': ('jernhand',),
'jernhanden': ('jernhand',),
'jernhendene': ('jernhand',),
'jernhender': ('jernhand',),
'jernhelsa': ('jernhelse',),
'jernhelse': ('jernhelse',),
'jernhelsen': ('jernhelse',),
'jernhelsene': ('jernhelse',),
'jernhelser': ('jernhelse',),
'jernhæl': ('jernhæl',),
'jernhælen': ('jernhæl',),
'jernhælene': ('jernhæl',),
'jernhæler': ('jernhæl',),
'jernkors': ('jernkors',),
'jernkorsa': ('jernkors',),
'jernkorsene': ('jernkors',),
'jernkorset': ('jernkors',),
'jernkorsett': ('jernkorsett',),
'jernkorsetta': ('jernkorsett',),
'jernkorsettene': ('jernkorsett',),
'jernkorsetter': ('jernkorsett',),
'jernkorsettet': ('jernkorsett',),
'jernku': ('jernku',),
'jernkua': ('jernku',),
'jernkuen': ('jernku',),
'jernkuene': ('jernku',),
'jernkuer': ('jernku',),
'jernkyr': ('jernku',),
'jernkyrne': ('jernku',),
'jernkvinna': ('jernkvinne',),
'jernkvinne': ('jernkvinne',),
'jernkvinnen': ('jernkvinne',),
'jernkvinnene': ('jernkvinne',),
'jernkvinner': ('jernkvinne',),
'jernlunga': ('jernlunge',),
'jernlunge': ('jernlunge',),
'jernlungen': ('jernlunge',),
'jernlungene': ('jernlunge',),
'jernlunger': ('jernlunge',),
'jernmalm': ('jernmalm',),
'jernmalmen': ('jernmalm',),
'jernmalmene': ('jernmalm',),
'jernmalmer': ('jernmalm',),
'jernmann': ('jernmann',),
'jernmannen': ('jernmann',),
'jernmenn': ('jernmann',),
'jernmennene': ('jernmann',),
'jernnatt': ('jernnatt',),
'jernnatta': ('jernnatt',),
'jernnatten': ('jernnatt',),
'jernnettene': ('jernnatt',),
'jernnetter': ('jernnatt',),
'jernoksid': ('jernoksid',),
'jernoksida': ('jernoksid',),
'jernoksidene': ('jernoksid',),
'jernoksider': ('jernoksid',),
'jernoksidet': ('jernoksid',),
'jernpreparat': ('jernpreparat',),
'jernpreparata': ('jernpreparat',),
'jernpreparatene': ('jernpreparat',),
'jernpreparater': ('jernpreparat',),
'jernpreparatet': ('jernpreparat',),
'jernring': ('jernring',),
'jernringen': ('jernring',),
'jernringene': ('jernring',),
'jernringer': ('jernring',),
'jernspat': ('jernspat',),
'jernspaten': ('jernspat',),
'jernspatene': ('jernspat',),
'jernspater': ('jernspat',),
'jernspurv': ('jernspurv',),
'jernspurven': ('jernspurv',),
'jernspurvene': ('jernspurv',),
'jernspurver': ('jernspurv',),
'jernstøperi': ('jernstøperi',),
'jernstøperia': ('jernstøperi',),
'jernstøperiene': ('jernstøperi',),
'jernstøperier': ('jernstøperi',),
'jernstøperiet': ('jernstøperi',),
'jernstøyperi': ('jernstøyperi',),
'jernstøyperia': ('jernstøyperi',),
'jernstøyperiene': ('jernstøyperi',),
'jernstøyperier': ('jernstøyperi',),
'jernstøyperiet': ('jernstøyperi',),
'jernteppa': ('jernteppe',),
'jernteppe': ('jernteppe',),
'jernteppene': ('jernteppe',),
'jerntepper': ('jernteppe',),
'jernteppet': ('jernteppe',),
'jernteppeland': ('jernteppeland',),
'jernteppelanda': ('jernteppeland',),
'jernteppelandene': ('jernteppeland',),
'jernteppelandet': ('jernteppeland',),
'jernvara': ('jernvare',),
'jernvare': ('jernvare',),
'jernvaren': ('jernvare',),
'jernvarene': ('jernvare',),
'jernvarer': ('jernvare',),
'jernvarehandel': ('jernvarehandel',),
'jernvarehandelen': ('jernvarehandel',),
'jernvarehandlene': ('jernvarehandel',),
'jernvarehandler': ('jernvarehandel',),
'jernverk': ('jernverk',),
'jernverka': ('jernverk',),
'jernverkene': ('jernverk',),
'jernverker': ('jernverk',),
'jernverket': ('jernverk',),
'jernvilje': ('jernvilje',),
'jernviljen': ('jernvilje',),
'jernviljene': ('jernvilje',),
'jernviljer': ('jernvilje',),
'jernvinna': ('jernvinne',),
'jernvinne': ('jernvinne',),
'jernvinnen': ('jernvinne',),
'jernvinnene': ('jernvinne',),
'jernvinner': ('jernvinne',),
'jeronimus': ('jeronimus',),
'jeronimusen': ('jeronimus',),
'jeronimusene': ('jeronimus',),
'jeronimuser': ('jeronimus',),
'jerpa': ('jerpe',),
'jerpe': ('jerpe',),
'jerpen': ('jerpe',),
'jerpene': ('jerpe',),
'jerper': ('jerpe',),
'jerrykanna': ('jerrykanne',),
'jerrykanne': ('jerrykanne',),
'jerrykannen': ('jerrykanne',),
'jerrykannene': ('jerrykanne',),
'jerrykanner': ('jerrykanne',),
'jersey': ('jersey',),
'jerseyen': ('jersey',),
'jerseyene': ('jersey',),
'jerseyer': ('jersey',),
'jerseyfe': ('jerseyfe',),
'jerseyfea': ('jerseyfe',),
'jerseyfeene': ('jerseyfe',),
'jerseyfeet': ('jerseyfe',),
'jerseykjole': ('jerseykjole',),
'jerseykjolen': ('jerseykjole',),
'jerseykjolene': ('jerseykjole',),
'jerseykjoler': ('jerseykjole',),
'jerv': ('jerv',),
'jerven': ('jerv',),
'jervene': ('jerv',),
'jerver': ('jerv',),
'jest': ('jest',),
'jesten': ('jest',),
'jestene': ('jest',),
'jester': ('jest',),
'jester': ('jester',),
'jestere': ('jester',),
'jesteren': ('jester',),
'jesterer': ('jester',),
'jesterne': ('jester',),
'jestre': ('jester',),
'jestrene': ('jester',),
'jestrer': ('jester',),
'jesuitt': ('jesuitt',),
'jesuitten': ('jesuitt',),
'jesuittene': ('jesuitt',),
'jesuitter': ('jesuitt',),
'jesuittorden': ('jesuittorden',),
'jesuittordenen': ('jesuittorden',),
'jesuittordenene': ('jesuittorden',),
'jesuittordener': ('jesuittorden',),
'jet': ('jet',),
'jeten': ('jet',),
'jetene': ('jet',),
'jeter': ('jet',),
'jetalder': ('jetalder',),
'jetaldere': ('jetalder',),
'jetalderen': ('jetalder',),
'jetalderer': ('jetalder',),
'jetalderne': ('jetalder',),
'jetaldre': ('jetalder',),
'jetaldrene': ('jetalder',),
'jetaldrer': ('jetalder',),
'jetfart': ('jetfart',),
'jetfarten': ('jetfart',),
'jetfartene': ('jetfart',),
'jetfarter': ('jetfart',),
'jetfly': ('jetfly',),
'jetflya': ('jetfly',),
'jetflyene': ('jetfly',),
'jetflyet': ('jetfly',),
'jetjager': ('jetjager',),
'jetjagere': ('jetjager',),
'jetjageren': ('jetjager',),
'jetjagerer': ('jetjager',),
'jetjagerne': ('jetjager',),
'jetmaskin': ('jetmaskin',),
'jetmaskina': ('jetmaskin',),
'jetmaskinen': ('jetmaskin',),
'jetmaskinene': ('jetmaskin',),
'jetmaskiner': ('jetmaskin',),
'jetmotor': ('jetmotor',),
'jetmotoren': ('jetmotor',),
'jetmotorene': ('jetmotor',),
'jetmotorer': ('jetmotor',),
'jetsett': ('jetsett',),
'jetsetta': ('jetsett',),
'jetsettene': ('jetsett',),
'jetsettet': ('jetsett',),
'jetsetter': ('jetsetter',),
'jetsettere': ('jetsetter',),
'jetsetteren': ('jetsetter',),
'jetsetterer': ('jetsetter',),
'jetsetterne': ('jetsetter',),
'jetski': ('jetski',),
'jetskia': ('jetski',),
'jetskien': ('jetski',),
'jetskiene': ('jetski',),
'jetskier': ('jetski',),
'jetstrøm': ('jetstrøm',),
'jetstrømmen': ('jetstrøm',),
'jetstrømmene': ('jetstrøm',),
'jetstrømmer': ('jetstrøm',),
'jette': ('jette',),
'jetten': ('jette',),
'jettene': ('jette',),
'jetter': ('jette',),
'jettegryta': ('jettegryte',),
'jettegryte': ('jettegryte',),
'jettegryten': ('jettegryte',),
'jettegrytene': ('jettegryte',),
'jettegryter': ('jettegryte',),
'jevndøgn': ('jevndøgn',),
'jevndøgna': ('jevndøgn',),
'jevndøgnene': ('jevndøgn',),
'jevndøgnet': ('jevndøgn',),
'jevnføring': ('jevnføring',),
'jevnføringa': ('jevnføring',),
'jevnføringen': ('jevnføring',),
'jevnføringene': ('jevnføring',),
'jevnføringer': ('jevnføring',),
'jevnhet': ('jevnhet',),
'jevnheta': ('jevnhet',),
'jevnheten': ('jevnhet',),
'jevnhetene': ('jevnhet',),
'jevnheter': ('jevnhet',),
'jevning': ('jevning',),
'jevninga': ('jevning',),
'jevningen': ('jevning',),
'jevningene': ('jevning',),
'jevninger': ('jevning',),
'jevning': ('jevning',),
'jevninga': ('jevning',),
'jevningen': ('jevning',),
'jevningene': ('jevning',),
'jevninger': ('jevning',),
'jevnlike': ('jevnlike',),
'jevnliken': ('jevnlike',),
'jevnlikene': ('jevnlike',),
'jevnliker': ('jevnlike',),
'jibb': ('jibb',),
'jibben': ('jibb',),
'jibbene': ('jibb',),
'jibber': ('jibb',),
'jiddisch': ('jiddisch',),
'jiddischen': ('jiddisch',),
'jiddischene': ('jiddisch',),
'jiddischer': ('jiddisch',),
'jiddisk': ('jiddisk',),
'jiddisken': ('jiddisk',),
'jiddiskene': ('jiddisk',),
'jiddisker': ('jiddisk',),
'jigg': ('jigg',),
'jiggen': ('jigg',),
'jiggene': ('jigg',),
'jigger': ('jigg',),
'jiggermast': ('jiggermast',),
'jiggermasta': ('jiggermast',),
'jiggermasten': ('jiggermast',),
'jiggermastene': ('jiggermast',),
'jiggermaster': ('jiggermast',),
'jingo': ('jingo',),
'jingoen': ('jingo',),
'jingoene': ('jingo',),
'jingoer': ('jingo',),
'jingoisme': ('jingoisme',),
'jingoismen': ('jingoisme',),
'jingoismene': ('jingoisme',),
'jingoismer': ('jingoisme',),
'jippo': ('jippo',),
'jippoa': ('jippo',),
'jippoene': ('jippo',),
'jippoer': ('jippo',),
'jippoet': ('jippo',),
'jitterbug': ('jitterbug',),
'jitterbugen': ('jitterbug',),
'jitterbugene': ('jitterbug',),
'jitterbuger': ('jitterbug',),
'jiu-jitsu': ('jiu-jitsu',),
'jiu-jitsuen': ('jiu-jitsu',),
'jiu-jitsuene': ('jiu-jitsu',),
'jiu-jitsuer': ('jiu-jitsu',),
'jive': ('jive',),
'jiven': ('jive',),
'jivene': ('jive',),
'jiver': ('jive',),
'jo': ('jo',),
'joen': ('jo',),
'joene': ('jo',),
'joer': ('jo',),
'jobb': ('jobb',),
'jobben': ('jobb',),
'jobbene': ('jobb',),
'jobber': ('jobb',),
'jobber': ('jobber',),
'jobbere': ('jobber',),
'jobberen': ('jobber',),
'jobberer': ('jobber',),
'jobberne': ('jobber',),
'jobbetid': ('jobbetid',),
'jobbetida': ('jobbetid',),
'jobbetiden': ('jobbetid',),
'jobbetidene': ('jobbetid',),
'jobbetider': ('jobbetid',),
'jobspost': ('jobspost',),
'jobsposten': ('jobspost',),
'jobspostene': ('jobspost',),
'jobsposter': ('jobspost',),
'jobståra': ('jobståre',),
'jobståre': ('jobståre',),
'jobståren': ('jobståre',),
'jobstårene': ('jobståre',),
'jobstårer': ('jobståre',),
'jockey': ('jockey',),
'jockeyen': ('jockey',),
'jockeyene': ('jockey',),
'jockeyer': ('jockey',),
'jod': ('jod',),
'joda': ('jod',),
'joden': ('jod',),
'jodene': ('jod',),
'joder': ('jod',),
'jodet': ('jod',),
'jodbensin': ('jodbensin',),
'jodbensinen': ('jodbensin',),
'jodbensinene': ('jodbensin',),
'jodbensiner': ('jodbensin',),
'jodd': ('jodd',),
'jodden': ('jodd',),
'joddene': ('jodd',),
'jodder': ('jodd',),
'jodid': ('jodid',),
'jodida': ('jodid',),
'jodidene': ('jodid',),
'jodider': ('jodid',),
'jodidet': ('jodid',),
'jodlampa': ('jodlampe',),
'jodlampe': ('jodlampe',),
'jodlampen': ('jodlampe',),
'jodlampene': ('jodlampe',),
'jodlamper': ('jodlampe',),
'jodmangel': ('jodmangel',),
'jodmangelen': ('jodmangel',),
'jodmanglene': ('jodmangel',),
'jodmangler': ('jodmangel',),
'jodpreparat': ('jodpreparat',),
'jodpreparata': ('jodpreparat',),
'jodpreparatene': ('jodpreparat',),
'jodpreparater': ('jodpreparat',),
'jodpreparatet': ('jodpreparat',),
'jodtinktur': ('jodtinktur',),
'jodtinkturen': ('jodtinktur',),
'jodtinkturene': ('jodtinktur',),
'jodtinkturer': ('jodtinktur',),
'jogg': ('jogg',),
'joggen': ('jogg',),
'joggene': ('jogg',),
'jogger': ('jogg',),
'jogger': ('jogger',),
'joggere': ('jogger',),
'joggeren': ('jogger',),
'joggerer': ('jogger',),
'joggerne': ('jogger',),
'joggesko': ('joggesko',),
'joggeskoa': ('joggesko',),
'joggeskoen': ('joggesko',),
'joggeskoene': ('joggesko',),
'joggeskor': ('joggesko',),
'joggeskorne': ('joggesko',),
'joggetur': ('joggetur',),
'joggeturen': ('joggetur',),
'joggeturene': ('joggetur',),
'joggeturer': ('joggetur',),
'jogurt': ('jogurt',),
'jogurten': ('jogurt',),
'jogurtene': ('jogurt',),
'jogurter': ('jogurt',),
'jogurt': ('jogurt',),
'jogurten': ('jogurt',),
'jogurtene': ('jogurt',),
'jogurter': ('jogurt',),
'johannesbrød': ('johannesbrød',),
'johannesbrøda': ('johannesbrød',),
'johannesbrødene': ('johannesbrød',),
'johannesbrødet': ('johannesbrød',),
'johannesbrødtre': ('johannesbrødtre',),
'johannesbrødtrea': ('johannesbrødtre',),
'johannesbrødtreet': ('johannesbrødtre',),
'johannesbrødtrær': ('johannesbrødtre',),
'johannesbrødtrærne': ('johannesbrødtre',),
'johannitt': ('johannitt',),
'johannitten': ('johannitt',),
'johannittene': ('johannitt',),
'johannitter': ('johannitt',),
'johannitter': ('johannitter',),
'johannittere': ('johannitter',),
'johannitteren': ('johannitter',),
'johannitterer': ('johannitter',),
'johannitterne': ('johannitter',),
'johannitterorden': ('johannitterorden',),
'johannitterordenen': ('johannitterorden',),
'johannitterordenene': ('johannitterorden',),
'johannitterordener': ('johannitterorden',),
'johannittorden': ('johannittorden',),
'johannittordenen': ('johannittorden',),
'johannittordenene': ('johannittorden',),
'johannittordener': ('johannittorden',),
'joik': ('joik',),
'joiken': ('joik',),
'joikene': ('joik',),
'joiker': ('joik',),
'jojo': ('jojo',),
'jojoen': ('jojo',),
'jojoene': ('jojo',),
'jojoer': ('jojo',),
'joker': ('joker',),
'jokere': ('joker',),
'jokeren': ('joker',),
'jokerer': ('joker',),
'jokerne': ('joker',),
'jol': ('jol',),
'jolen': ('jol',),
'jolene': ('jol',),
'joler': ('jol',),
'jolla': ('jolle',),
'jolle': ('jolle',),
'jollen': ('jolle',),
'jollene': ('jolle',),
'joller': ('jolle',),
'jomfru': ('jomfru',),
'jomfrua': ('jomfru',),
'jomfruen': ('jomfru',),
'jomfruene': ('jomfru',),
'jomfruer': ('jomfru',),
'jomfrubur': ('jomfrubur',),
'jomfrubura': ('jomfrubur',),
'jomfruburene': ('jomfrubur',),
'jomfruburet': ('jomfrubur',),
'jomfrudom': ('jomfrudom',),
'jomfrudommen': ('jomfrudom',),
'jomfrudommene': ('jomfrudom',),
'jomfrudommer': ('jomfrudom',),
'jomfrufødsel': ('jomfrufødsel',),
'jomfrufødselen': ('jomfrufødsel',),
'jomfrufødslene': ('jomfrufødsel',),
'jomfrufødsler': ('jomfrufødsel',),
'jomfruhinna': ('jomfruhinne',),
'jomfruhinne': ('jomfruhinne',),
'jomfruhinnen': ('jomfruhinne',),
'jomfruhinnene': ('jomfruhinne',),
'jomfruhinner': ('jomfruhinne',),
'jomfruskott': ('jomfruskott',),
'jomfruskotta': ('jomfruskott',),
'jomfruskottene': ('jomfruskott',),
'jomfruskottet': ('jomfruskott',),
'jomfruskudd': ('jomfruskudd',),
'jomfruskudda': ('jomfruskudd',),
'jomfruskuddene': ('jomfruskudd',),
'jomfruskuddet': ('jomfruskudd',),
'jomfrutale': ('jomfrutale',),
'jomfrutalen': ('jomfrutale',),
'jomfrutalene': ('jomfrutale',),
'jomfrutaler': ('jomfrutale',),
'jomfrutrana': ('jomfrutrane',),
'jomfrutrane': ('jomfrutrane',),
'jomfrutranen': ('jomfrutrane',),
'jomfrutranene': ('jomfrutrane',),
'jomfrutraner': ('jomfrutrane',),
'jomfrutur': ('jomfrutur',),
'jomfruturen': ('jomfrutur',),
'jomfruturene': ('jomfrutur',),
'jomfruturer': ('jomfrutur',),
'jomsviking': ('jomsviking',),
'jomsvikingen': ('jomsviking',),
'jomsvikingene': ('jomsviking',),
'jomsvikinger': ('jomsviking',),
'joner': ('joner',),
'jonere': ('joner',),
'joneren': ('joner',),
'jonerer': ('joner',),
'jonerne': ('joner',),
'jonsok': ('jonsok',),
'jonsoken': ('jonsok',),
'jonsokene': ('jonsok',),
'jonsoker': ('jonsok',),
'jonsokaften': ('jonsokaften',),
'jonsokaftenen': ('jonsokaften',),
'jonsokaftenene': ('jonsokaften',),
'jonsokaftener': ('jonsokaften',),
'jonsokblom': ('jonsokblom',),
'jonsokblommen': ('jonsokblom',),
'jonsokblommene': ('jonsokblom',),
'jonsokblommer': ('jonsokblom',),
'jonsokbål': ('jonsokbål',),
'jonsokbåla': ('jonsokbål',),
'jonsokbålene': ('jonsokbål',),
'jonsokbålet': ('jonsokbål',),
'jonsokkoll': ('jonsokkoll',),
'jonsokkollen': ('jonsokkoll',),
'jonsokkollene': ('jonsokkoll',),
'jonsokkoller': ('jonsokkoll',),
'jonsokkveld': ('jonsokkveld',),
'jonsokkvelden': ('jonsokkveld',),
'jonsokkveldene': ('jonsokkveld',),
'jonsokkvelder': ('jonsokkveld',),
'jord': ('jord',),
'jorda': ('jord',),
'jorden': ('jord',),
'jordene': ('jord',),
'jorder': ('jord',),
'jordakse': ('jordakse',),
'jordaksen': ('jordakse',),
'jordaksene': ('jordakse',),
'jordakser': ('jordakse',),
'jordaner': ('jordaner',),
'jordanere': ('jordaner',),
'jordaneren': ('jordaner',),
'jordanerer': ('jordaner',),
'jordanerne': ('jordaner',),
'jordarbeiding': ('jordarbeiding',),
'jordarbeidinga': ('jordarbeiding',),
'jordarbeidingen': ('jordarbeiding',),
'jordarbeidingene': ('jordarbeiding',),
'jordarbeidinger': ('jordarbeiding',),
'jordbane': ('jordbane',),
'jordbanen': ('jordbane',),
'jordbanene': ('jordbane',),
'jordbaner': ('jordbane',),
'jordboer': ('jordboer',),
'jordboere': ('jordboer',),
'jordboeren': ('jordboer',),
'jordboerer': ('jordboer',),
'jordboerne': ('jordboer',),
'jordbruk': ('jordbruk',),
'jordbruka': ('jordbruk',),
'jordbrukene': ('jordbruk',),
'jordbruket': ('jordbruk',),
'jordbruker': ('jordbruker',),
'jordbrukere': ('jordbruker',),
'jordbrukeren': ('jordbruker',),
'jordbrukerer': ('jordbruker',),
'jordbrukerne': ('jordbruker',),
'jordbruksavtale': ('jordbruksavtale',),
'jordbruksavtalen': ('jordbruksavtale',),
'jordbruksavtalene': ('jordbruksavtale',),
'jordbruksavtaler': ('jordbruksavtale',),
'jordbruksbygd': ('jordbruksbygd',),
'jordbruksbygda': ('jordbruksbygd',),
'jordbruksbygden': ('jordbruksbygd',),
'jordbruksbygdene': ('jordbruksbygd',),
'jordbruksbygder': ('jordbruksbygd',),
'jordbruksferie': ('jordbruksferie',),
'jordbruksferien': ('jordbruksferie',),
'jordbruksferiene': ('jordbruksferie',),
'jordbruksferier': ('jordbruksferie',),
'jordbruksskole': ('jordbruksskole',),
'jordbruksskolen': ('jordbruksskole',),
'jordbruksskolene': ('jordbruksskole',),
'jordbruksskoler': ('jordbruksskole',),
'jordbrukstelling': ('jordbrukstelling',),
'jordbrukstellinga': ('jordbrukstelling',),
'jordbrukstellingen': ('jordbrukstelling',),
'jordbrukstellingene': ('jordbrukstelling',),
'jordbrukstellinger': ('jordbrukstelling',),
'jordbuer': ('jordbuer',),
'jordbuere': ('jordbuer',),
'jordbueren': ('jordbuer',),
'jordbuerer': ('jordbuer',),
'jordbuerne': ('jordbuer',),
'jordbær': ('jordbær',),
'jordbæra': ('jordbær',),
'jordbærene': ('jordbær',),
'jordbæret': ('jordbær',),
'jordbær': ('jordbær',),
'jordbæra': ('jordbær',),
'jordbærene': ('jordbær',),
'jordbæret': ('jordbær',),
'jordbæris': ('jordbæris',),
'jordbærisen': ('jordbæris',),
'jordbærisene': ('jordbæris',),
'jordbæriser': ('jordbæris',),
'jordbærsyltetøy': ('jordbærsyltetøy',),
'jordbærsyltetøya': ('jordbærsyltetøy',),
'jordbærsyltetøyene': ('jordbærsyltetøy',),
'jordbærsyltetøyer': ('jordbærsyltetøy',),
'jordbærsyltetøyet': ('jordbærsyltetøy',),
'jordbæråker': ('jordbæråker',),
'jordbæråkere': ('jordbæråker',),
'jordbæråkeren': ('jordbæråker',),
'jordbæråkerne': ('jordbæråker',),
'jordbæråkre': ('jordbæråker',),
'jordbæråkrene': ('jordbæråker',),
'jordbæråkrer': ('jordbæråker',),
'jorddrott': ('jorddrott',),
'jorddrotten': ('jorddrott',),
'jorddrottene': ('jorddrott',),
'jorddrotter': ('jorddrott',),
'jorddyrking': ('jorddyrking',),
'jorddyrkinga': ('jorddyrking',),
'jorddyrkingen': ('jorddyrking',),
'jorddyrkingene': ('jorddyrking',),
'jorddyrkinger': ('jorddyrking',),
'jorddyrkning': ('jorddyrkning',),
'jorddyrkninga': ('jorddyrkning',),
'jorddyrkningen': ('jorddyrkning',),
'jorddyrkningene': ('jorddyrkning',),
'jorddyrkninger': ('jorddyrkning',),
'jorda': ('jorde',),
'jorde': ('jorde',),
'jordene': ('jorde',),
'jorder': ('jorde',),
'jordet': ('jorde',),
'jordebok': ('jordebok',),
'jordeboka': ('jordebok',),
'jordeboken': ('jordebok',),
'jordebøkene': ('jordebok',),
'jordebøker': ('jordebok',),
'jordeferd': ('jordeferd',),
'jordeferda': ('jordeferd',),
'jordeferden': ('jordeferd',),
'jordeferdene': ('jordeferd',),
'jordeferder': ('jordeferd',),
'jordegods': ('jordegods',),
'jordegodsa': ('jordegods',),
'jordegodsene': ('jordegods',),
'jordegodser': ('jordegods',),
'jordegodset': ('jordegods',),
'jordeiendom': ('jordeiendom',),
'jordeiendommen': ('jordeiendom',),
'jordeiendommene': ('jordeiendom',),
'jordeiendommer': ('jordeiendom',),
'jordeier': ('jordeier',),
'jordeiere': ('jordeier',),
'jordeieren': ('jordeier',),
'jordeierer': ('jordeier',),
'jordeierne': ('jordeier',),
'jordekorn': ('jordekorn',),
'jordekorna': ('jordekorn',),
'jordekornen': ('jordekorn',),
'jordekornene': ('jordekorn',),
'jordekorner': ('jordekorn',),
'jordekornet': ('jordekorn',),
'jordekorn': ('jordekorn',),
'jordekorna': ('jordekorn',),
'jordekornen': ('jordekorn',),
'jordekornene': ('jordekorn',),
'jordekorner': ('jordekorn',),
'jordekornet': ('jordekorn',),
'jordeliv': ('jordeliv',),
'jordeliva': ('jordeliv',),
'jordelivene': ('jordeliv',),
'jordelivet': ('jordeliv',),
'jordepla': ('jordeple',),
'jordeple': ('jordeple',),
'jordeplene': ('jordeple',),
'jordepler': ('jordeple',),
'jordeplet': ('jordeple',),
'jorderika': ('jorderike',),
'jorderike': ('jorderike',),
'jorderikene': ('jorderike',),
'jorderiker': ('jorderike',),
'jorderiket': ('jorderike',),
'jordferd': ('jordferd',),
'jordferda': ('jordferd',),
'jordferden': ('jordferd',),
'jordferdene': ('jordferd',),
'jordferder': ('jordferd',),
'jordfestelse': ('jordfestelse',),
'jordfestelsen': ('jordfestelse',),
'jordfestelsene': ('jordfestelse',),
'jordfestelser': ('jordfestelse',),
'jordfesting': ('jordfesting',),
'jordfestinga': ('jordfesting',),
'jordfestingen': ('jordfesting',),
'jordfestingene': ('jordfesting',),
'jordfestinger': ('jordfesting',),
'jordfjerna': ('jordfjerne',),
'jordfjerne': ('jordfjerne',),
'jordfjernene': ('jordfjerne',),
'jordfjerner': ('jordfjerne',),
'jordfjernet': ('jordfjerne',),
'jordfokk': ('jordfokk',),
'jordfokka': ('jordfokk',),
'jordfokkene': ('jordfokk',),
'jordfokket': ('jordfokk',),
'jordforbedring': ('jordforbedring',),
'jordforbedringa': ('jordforbedring',),
'jordforbedringen': ('jordforbedring',),
'jordforbedringene': ('jordforbedring',),
'jordforbedringer': ('jordforbedring',),
'jordforbedringsmiddel': ('jordforbedringsmiddel',),
'jordforbedringsmiddelet': ('jordforbedringsmiddel',),
'jordforbedringsmidla': ('jordforbedringsmiddel',),
'jordforbedringsmidlene': ('jordforbedringsmiddel',),
'jordforbedringsmidler': ('jordforbedringsmiddel',),
'jordforbedringsmidlet': ('jordforbedringsmiddel',),
'jordfreser': ('jordfreser',),
'jordfresere': ('jordfreser',),
'jordfreseren': ('jordfreser',),
'jordfreserer': ('jordfreser',),
'jordfreserne': ('jordfreser',),
'jordgamma': ('jordgamme',),
'jordgamme': ('jordgamme',),
'jordgammen': ('jordgamme',),
'jordgammene': ('jordgamme',),
'jordgammer': ('jordgamme',),
'jordgolv': ('jordgolv',),
'jordgolva': ('jordgolv',),
'jordgolvene': ('jordgolv',),
'jordgolvet': ('jordgolv',),
'jordgulv': ('jordgulv',),
'jordgulva': ('jordgulv',),
'jordgulvene': ('jordgulv',),
'jordgulvet': ('jordgulv',),
'jordikorn': ('jordikorn',),
'jordikorna': ('jordikorn',),
'jordikornen': ('jordikorn',),
'jordikornene': ('jordikorn',),
'jordikorner': ('jordikorn',),
'jordikornet': ('jordikorn',),
'jordikorn': ('jordikorn',),
'jordikorna': ('jordikorn',),
'jordikornen': ('jordikorn',),
'jordikornene': ('jordikorn',),
'jordikorner': ('jordikorn',),
'jordikornet': ('jordikorn',),
'jording': ('jording',),
'jordinga': ('jording',),
'jordingen': ('jording',),
'jordingene': ('jording',),
'jordinger': ('jording',),
'jordingsklemma': ('jordingsklemme',),
'jordingsklemme': ('jordingsklemme',),
'jordingsklemmen': ('jordingsklemme',),
'jordingsklemmene': ('jordingsklemme',),
'jordingsklemmer': ('jordingsklemme',),
'jordingskontakt': ('jordingskontakt',),
'jordingskontakten': ('jordingskontakt',),
'jordingskontaktene': ('jordingskontakt',),
'jordingskontakter': ('jordingskontakt',),
'jordkabel': ('jordkabel',),
'jordkabelen': ('jordkabel',),
'jordkablene': ('jordkabel',),
'jordkabler': ('jordkabel',),
'jordkjeller': ('jordkjeller',),
'jordkjellere': ('jordkjeller',),
'jordkjelleren': ('jordkjeller',),
'jordkjellerer': ('jordkjeller',),
'jordkjellerne': ('jordkjeller',),
'jordklode': ('jordklode',),
'jordkloden': ('jordklode',),
'jordklodene': ('jordklode',),
'jordkloder': ('jordklode',),
'jordkultur': ('jordkultur',),
'jordkulturen': ('jordkultur',),
'jordkulturene': ('jordkultur',),
'jordkulturer': ('jordkultur',),
'jordledning': ('jordledning',),
'jordledninga': ('jordledning',),
'jordledningen': ('jordledning',),
'jordledningene': ('jordledning',),
'jordledninger': ('jordledning',),
'jordliv': ('jordliv',),
'jordliva': ('jordliv',),
'jordlivene': ('jordliv',),
'jordlivet': ('jordliv',),
'jordloppa': ('jordloppe',),
'jordloppe': ('jordloppe',),
'jordloppen': ('jordloppe',),
'jordloppene': ('jordloppe',),
'jordlopper': ('jordloppe',),
'jordlov': ('jordlov',),
'jordloven': ('jordlov',),
'jordlovene': ('jordlov',),
'jordlover': ('jordlov',),
'jordmagnetisme': ('jordmagnetisme',),
'jordmagnetismen': ('jordmagnetisme',),
'jordmagnetismene': ('jordmagnetisme',),
'jordmagnetismer': ('jordmagnetisme',),
'jordmaur': ('jordmaur',),
'jordmauren': ('jordmaur',),
'jordmaurene': ('jordmaur',),
'jordmor': ('jordmor',),
'jordmora': ('jordmor',),
'jordmoren': ('jordmor',),
'jordmødre': ('jordmor',),
'jordmødrene': ('jordmor',),
'jordmødrer': ('jordmor',),
'jordmorkaffe': ('jordmorkaffe',),
'jordmorkaffen': ('jordmorkaffe',),
'jordmorkaffene': ('jordmorkaffe',),
'jordmorkaffer': ('jordmorkaffe',),
'jordmorskyss': ('jordmorskyss',),
'jordmorskyssen': ('jordmorskyss',),
'jordmorskyssene': ('jordmorskyss',),
'jordmorskysser': ('jordmorskyss',),
'jordnæra': ('jordnære',),
'jordnære': ('jordnære',),
'jordnærene': ('jordnære',),
'jordnærer': ('jordnære',),
'jordnæret': ('jordnære',),
'jordnøtt': ('jordnøtt',),
'jordnøtta': ('jordnøtt',),
'jordnøtten': ('jordnøtt',),
'jordnøttene': ('jordnøtt',),
'jordnøtter': ('jordnøtt',),
'jordnøttolja': ('jordnøttolje',),
'jordnøttolje': ('jordnøttolje',),
'jordnøttoljen': ('jordnøttolje',),
'jordnøttoljene': ('jordnøttolje',),
'jordnøttoljer': ('jordnøttolje',),
'jordolja': ('jordolje',),
'jordolje': ('jordolje',),
'jordoljen': ('jordolje',),
'jordoljene': ('jordolje',),
'jordoljer': ('jordolje',),
'jordomsegler': ('jordomsegler',),
'jordomseglere': ('jordomsegler',),
'jordomsegleren': ('jordomsegler',),
'jordomseglerer': ('jordomsegler',),
'jordomseglerne': ('jordomsegler',),
'jordomsegling': ('jordomsegling',),
'jordomseglinga': ('jordomsegling',),
'jordomseglingen': ('jordomsegling',),
'jordomseglingene': ('jordomsegling',),
'jordomseglinger': ('jordomsegling',),
'jordomseiler': ('jordomseiler',),
'jordomseilere': ('jordomseiler',),
'jordomseileren': ('jordomseiler',),
'jordomseilerer': ('jordomseiler',),
'jordomseilerne': ('jordomseiler',),
'jordomseiling': ('jordomseiling',),
'jordomseilinga': ('jordomseiling',),
'jordomseilingen': ('jordomseiling',),
'jordomseilingene': ('jordomseiling',),
'jordomseilinger': ('jordomseiling',),
'jordplata': ('jordplate',),
'jordplate': ('jordplate',),
'jordplaten': ('jordplate',),
'jordplatene': ('jordplate',),
'jordplater': ('jordplate',),
'jordpåkastelse': ('jordpåkastelse',),
'jordpåkastelsen': ('jordpåkastelse',),
'jordpåkastelsene': ('jordpåkastelse',),
'jordpåkastelser': ('jordpåkastelse',),
'jordpåkasting': ('jordpåkasting',),
'jordpåkastinga': ('jordpåkasting',),
'jordpåkastingen': ('jordpåkasting',),
'jordpåkastingene': ('jordpåkasting',),
'jordpåkastinger': ('jordpåkasting',),
'jordreform': ('jordreform',),
'jordreformen': ('jordreform',),
'jordreformene': ('jordreform',),
'jordreformer': ('jordreform',),
'jordregister': ('jordregister',),
'jordregisteret': ('jordregister',),
'jordregistra': ('jordregister',),
'jordregistre': ('jordregister',),
'jordregistrene': ('jordregister',),
'jordregistret': ('jordregister',),
'jordrotasjon': ('jordrotasjon',),
'jordrotasjonen': ('jordrotasjon',),
'jordrotasjonene': ('jordrotasjon',),
'jordrotasjoner': ('jordrotasjon',),
'jordrotta': ('jordrotte',),
'jordrotte': ('jordrotte',),
'jordrotten': ('jordrotte',),
'jordrottene': ('jordrotte',),
'jordrotter': ('jordrotte',),
'jordråme': ('jordråme',),
'jordråmen': ('jordråme',),
'jordråmene': ('jordråme',),
'jordråmer': ('jordråme',),
'jordrøyk': ('jordrøyk',),
'jordrøyken': ('jordrøyk',),
'jordrøykene': ('jordrøyk',),
'jordrøyker': ('jordrøyk',),
'jordskifta': ('jordskifte',),
'jordskifte': ('jordskifte',),
'jordskiftene': ('jordskifte',),
'jordskifter': ('jordskifte',),
'jordskiftet': ('jordskifte',),
'jordskiftedommer': ('jordskiftedommer',),
'jordskiftedommere': ('jordskiftedommer',),
'jordskiftedommeren': ('jordskiftedommer',),
'jordskiftedommerer': ('jordskiftedommer',),
'jordskiftedommerne': ('jordskiftedommer',),
'jordskifterett': ('jordskifterett',),
'jordskifteretten': ('jordskifterett',),
'jordskifterettene': ('jordskifterett',),
'jordskifteretter': ('jordskifterett',),
'jordskjelv': ('jordskjelv',),
'jordskjelva': ('jordskjelv',),
'jordskjelvene': ('jordskjelv',),
'jordskjelvet': ('jordskjelv',),
'jordskjelv': ('jordskjelv',),
'jordskjelva': ('jordskjelv',),
'jordskjelvene': ('jordskjelv',),
'jordskjelvet': ('jordskjelv',),
'jordskjelvstasjon': ('jordskjelvstasjon',),
'jordskjelvstasjonen': ('jordskjelvstasjon',),
'jordskjelvstasjonene': ('jordskjelvstasjon',),
'jordskjelvstasjoner': ('jordskjelvstasjon',),
'jordskokk': ('jordskokk',),
'jordskokken': ('jordskokk',),
'jordskokkene': ('jordskokk',),
'jordskokker': ('jordskokk',),
'jordskorpa': ('jordskorpe',),
'jordskorpe': ('jordskorpe',),
'jordskorpen': ('jordskorpe',),
'jordskorpene': ('jordskorpe',),
'jordskorper': ('jordskorpe',),
'jordslag': ('jordslag',),
'jordslaga': ('jordslag',),
'jordslagene': ('jordslag',),
'jordslaget': ('jordslag',),
'jordslag': ('jordslag',),
'jordslaga': ('jordslag',),
'jordslagene': ('jordslag',),
'jordslaget': ('jordslag',),
'jordsmonn': ('jordsmonn',),
'jordsmonna': ('jordsmonn',),
'jordsmonnene': ('jordsmonn',),
'jordsmonnet': ('jordsmonn',),
'jordstasjon': ('jordstasjon',),
'jordstasjonen': ('jordstasjon',),
'jordstasjonene': ('jordstasjon',),
'jordstasjoner': ('jordstasjon',),
'jordstyra': ('jordstyre',),
'jordstyre': ('jordstyre',),
'jordstyrene': ('jordstyre',),
'jordstyrer': ('jordstyre',),
'jordstyret': ('jordstyre',),
'jordtrell': ('jordtrell',),
'jordtrellen': ('jordtrell',),
'jordtrellene': ('jordtrell',),
'jordtreller': ('jordtrell',),
'jordugla': ('jordugle',),
'jordugle': ('jordugle',),
'jorduglen': ('jordugle',),
'jorduglene': ('jordugle',),
'jordugler': ('jordugle',),
'jordveg': ('jordveg',),
'jordvegen': ('jordveg',),
'jordvegene': ('jordveg',),
'jordveger': ('jordveg',),
'jordvei': ('jordvei',),
'jordveien': ('jordvei',),
'jordveiene': ('jordvei',),
'jordveier': ('jordvei',),
'jordveps': ('jordveps',),
'jordvepsen': ('jordveps',),
'jordvepsene': ('jordveps',),
'jordvepser': ('jordveps',),
'jordvern': ('jordvern',),
'jordverna': ('jordvern',),
'jordvernene': ('jordvern',),
'jordvernet': ('jordvern',),
'jorter': ('jorter',),
'jortere': ('jorter',),
'jorteren': ('jorter',),
'jorterer': ('jorter',),
'jorterne': ('jorter',),
'joruba': ('joruba',),
'jorubaen': ('joruba',),
'jorubaene': ('joruba',),
'jorubaer': ('joruba',),
'joruba': ('joruba',),
'jorubaen': ('joruba',),
'jorubaene': ('joruba',),
'jorubaer': ('joruba',),
'jota': ('jota',),
'jotaen': ('jota',),
'jotaene': ('jota',),
'jotaer': ('jota',),
'jotnen': ('jotun',),
'jotnene': ('jotun',),
'jotner': ('jotun',),
'jotun': ('jotun',),
'jotunen': ('jotun',),
'jotunkvinna': ('jotunkvinne',),
'jotunkvinne': ('jotunkvinne',),
'jotunkvinnen': ('jotunkvinne',),
'jotunkvinnene': ('jotunkvinne',),
'jotunkvinner': ('jotunkvinne',),
'jotunætt': ('jotunætt',),
'jotunætta': ('jotunætt',),
'jotunætten': ('jotunætt',),
'jotunættene': ('jotunætt',),
'jotunætter': ('jotunætt',),
'joule': ('joule',),
'joulen': ('joule',),
'joulene': ('joule',),
'jour': ('jour',),
'journal': ('journal',),
'journalen': ('journal',),
'journalene': ('journal',),
'journaler': ('journal',),
'journalist': ('journalist',),
'journalisten': ('journalist',),
'journalistene': ('journalist',),
'journalister': ('journalist',),
'journalistikk': ('journalistikk',),
'journalistikken': ('journalistikk',),
'journalistikkene': ('journalistikk',),
'journalistikker': ('journalistikk',),
'jovialitet': ('jovialitet',),
'jovialiteten': ('jovialitet',),
'jovialitetene': ('jovialitet',),
'jovialiteter': ('jovialitet',),
'joystick': ('joystick',),
'joysticken': ('joystick',),
'joystickene': ('joystick',),
'joysticker': ('joystick',),
'jubalon': ('jubalon',),
'jubalonen': ('jubalon',),
'jubalonene': ('jubalon',),
'jubaloner': ('jubalon',),
'jubalong': ('jubalong',),
'jubalongen': ('jubalong',),
'jubalongene': ('jubalong',),
'jubalonger': ('jubalong',),
'jubel': ('jubel',),
'jubelen': ('jubel',),
'jublene': ('jubel',),
'jubler': ('jubel',),
'jubelbrus': ('jubelbrus',),
'jubelbrusa': ('jubelbrus',),
'jubelbrusene': ('jubelbrus',),
'jubelbruset': ('jubelbrus',),
'jubelidiot': ('jubelidiot',),
'jubelidioten': ('jubelidiot',),
'jubelidiotene': ('jubelidiot',),
'jubelidioter': ('jubelidiot',),
'jubelrop': ('jubelrop',),
'jubelropa': ('jubelrop',),
'jubelropene': ('jubelrop',),
'jubelropet': ('jubelrop',),
'jubelsesong': ('jubelsesong',),
'jubelsesongen': ('jubelsesong',),
'jubelsesongene': ('jubelsesong',),
'jubelsesonger': ('jubelsesong',),
'jubelår': ('jubelår',),
'jubelåra': ('jubelår',),
'jubelårene': ('jubelår',),
'jubelåret': ('jubelår',),
'jubilea': ('jubilé',),
'jubileene': ('jubilé',),
'jubileer': ('jubilé',),
'jubileet': ('jubilé',),
'jubilé': ('jubilé',),
'jubiléa': ('jubilé',),
'jubiléene': ('jubilé',),
'jubiléer': ('jubilé',),
'jubiléet': ('jubilé',),
'jubilant': ('jubilant',),
'jubilanten': ('jubilant',),
'jubilantene': ('jubilant',),
'jubilanter': ('jubilant',),
'jubilea': ('jubileum',),
'jubileene': ('jubileum',),
'jubileer': ('jubileum',),
'jubileet': ('jubileum',),
'jubileum': ('jubileum',),
'jubileumsfest': ('jubileumsfest',),
'jubileumsfesten': ('jubileumsfest',),
'jubileumsfestene': ('jubileumsfest',),
'jubileumsfester': ('jubileumsfest',),
'jubileumsutgava': ('jubileumsutgave',),
'jubileumsutgave': ('jubileumsutgave',),
'jubileumsutgaven': ('jubileumsutgave',),
'jubileumsutgavene': ('jubileumsutgave',),
'jubileumsutgaver': ('jubileumsutgave',),
'judaisme': ('judaisme',),
'judaismen': ('judaisme',),
'judaismene': ('judaisme',),
'judaismer': ('judaisme',),
'judas': ('judas',),
'judasen': ('judas',),
'judasene': ('judas',),
'judaser': ('judas',),
'judaskyss': ('judaskyss',),
'judaskyssa': ('judaskyss',),
'judaskyssen': ('judaskyss',),
'judaskyssene': ('judaskyss',),
'judaskysset': ('judaskyss',),
'judaspenge': ('judaspenge',),
'judaspengen': ('judaspenge',),
'judaspengene': ('judaspenge',),
'judaspenger': ('judaspenge',),
'judeer': ('judeer',),
'judeere': ('judeer',),
'judeeren': ('judeer',),
'judeerer': ('judeer',),
'judeerne': ('judeer',),
'judisia': ('judisium',),
'judisiene': ('judisium',),
'judisier': ('judisium',),
'judisiet': ('judisium',),
'judisium': ('judisium',),
'judo': ('judo',),
'judoen': ('judo',),
'judoene': ('judo',),
'judoer': ('judo',),
'jugendstil': ('jugendstil',),
'jugendstilen': ('jugendstil',),
'jugendstilene': ('jugendstil',),
'jugendstiler': ('jugendstil',),
'jugl': ('jugl',),
'jugla': ('jugl',),
'juglene': ('jugl',),
'juglet': ('jugl',),
'jugoslav': ('jugoslav',),
'jugoslaven': ('jugoslav',),
'jugoslavene': ('jugoslav',),
'jugoslaver': ('jugoslav',),
'juice': ('juice',),
'juicen': ('juice',),
'juicene': ('juice',),
'juicer': ('juice',),
'jukeboks': ('jukeboks',),
'jukeboksen': ('jukeboks',),
'jukeboksene': ('jukeboks',),
'jukebokser': ('jukeboks',),
'juks': ('juks',),
'juksa': ('juks',),
'juksene': ('juks',),
'jukset': ('juks',),
'juksa': ('jukse',),
'jukse': ('jukse',),
'juksen': ('jukse',),
'juksene': ('jukse',),
'jukser': ('jukse',),
'juksebåt': ('juksebåt',),
'juksebåten': ('juksebåt',),
'juksebåtene': ('juksebåt',),
'juksebåter': ('juksebåt',),
'juksefiska': ('juksefiske',),
'juksefiske': ('juksefiske',),
'juksefiskene': ('juksefiske',),
'juksefisker': ('juksefiske',),
'juksefisket': ('juksefiske',),
'juksefisker': ('juksefisker',),
'juksefiskere': ('juksefisker',),
'juksefiskeren': ('juksefisker',),
'juksefiskerer': ('juksefisker',),
'juksefiskerne': ('juksefisker',),
'juksemaker': ('juksemaker',),
'juksemakere': ('juksemaker',),
'juksemakeren': ('juksemaker',),
'juksemakerer': ('juksemaker',),
'juksemakerne': ('juksemaker',),
'jukser': ('jukser',),
'juksere': ('jukser',),
'jukseren': ('jukser',),
'jukserer': ('jukser',),
'jukserne': ('jukser',),
'jul': ('jul',),
'jula': ('jul',),
'julen': ('jul',),
'julene': ('jul',),
'juler': ('jul',),
'julaften': ('julaften',),
'julaftenen': ('julaften',),
'julaftenene': ('julaften',),
'julaftener': ('julaften',),
'julebakst': ('julebakst',),
'julebaksten': ('julebakst',),
'julebakstene': ('julebakst',),
'julebakster': ('julebakst',),
'julebord': ('julebord',),
'juleborda': ('julebord',),
'julebordene': ('julebord',),
'juleborder': ('julebord',),
'julebordet': ('julebord',),
'julebordsweekend': ('julebordsweekend',),
'julebordsweekenden': ('julebordsweekend',),
'julebordsweekendene': ('julebordsweekend',),
'julebordsweekender': ('julebordsweekend',),
'julebordweekend': ('julebordweekend',),
'julebordweekenden': ('julebordweekend',),
'julebordweekendene': ('julebordweekend',),
'julebordweekender': ('julebordweekend',),
'julebukk': ('julebukk',),
'julebukken': ('julebukk',),
'julebukkene': ('julebukk',),
'julebukker': ('julebukk',),
'juledag': ('juledag',),
'juledagen': ('juledag',),
'juledagene': ('juledag',),
'juledager': ('juledag',),
'juleevangelia': ('juleevangelium',),
'juleevangeliene': ('juleevangelium',),
'juleevangelier': ('juleevangelium',),
'juleevangeliet': ('juleevangelium',),
'juleevangelium': ('juleevangelium',),
'juleferie': ('juleferie',),
'juleferien': ('juleferie',),
'juleferiene': ('juleferie',),
'juleferier': ('juleferie',),
'julegata': ('julegate',),
'julegate': ('julegate',),
'julegaten': ('julegate',),
'julegatene': ('julegate',),
'julegater': ('julegate',),
'julegava': ('julegave',),
'julegave': ('julegave',),
'julegaven': ('julegave',),
'julegavene': ('julegave',),
'julegaver': ('julegave',),
'julegjestebud': ('julegjestebud',),
'julegjestebuda': ('julegjestebud',),
'julegjestebudene': ('julegjestebud',),
'julegjestebudet': ('julegjestebud',),
'julegleda': ('juleglede',),
'juleglede': ('juleglede',),
'julegleden': ('juleglede',),
'julegledene': ('juleglede',),
'julegleder': ('juleglede',),
'julegran': ('julegran',),
'julegrana': ('julegran',),
'julegranen': ('julegran',),
'julegranene': ('julegran',),
'julegraner': ('julegran',),
'julegraut': ('julegraut',),
'julegrauten': ('julegraut',),
'julegrautene': ('julegraut',),
'julegrauter': ('julegraut',),
'julegris': ('julegris',),
'julegrisen': ('julegris',),
'julegrisene': ('julegris',),
'julegriser': ('julegris',),
'julegryta': ('julegryte',),
'julegryte': ('julegryte',),
'julegryten': ('julegryte',),
'julegrytene': ('julegryte',),
'julegryter': ('julegryte',),
'julegrøt': ('julegrøt',),
'julegrøten': ('julegrøt',),
'julegrøtene': ('julegrøt',),
'julegrøter': ('julegrøt',),
'julehandel': ('julehandel',),
'julehandelen': ('julehandel',),
'julehandlene': ('julehandel',),
'julehandler': ('julehandel',),
'julehefta': ('julehefte',),
'julehefte': ('julehefte',),
'juleheftene': ('julehefte',),
'julehefter': ('julehefte',),
'juleheftet': ('julehefte',),
'julehelg': ('julehelg',),
'julehelga': ('julehelg',),
'julehelgen': ('julehelg',),
'julehelgene': ('julehelg',),
'julehelger': ('julehelg',),
'julehelsing': ('julehelsing',),
'julehelsinga': ('julehelsing',),
'julehelsingen': ('julehelsing',),
'julehelsingene': ('julehelsing',),
'julehelsinger': ('julehelsing',),
'julehilsen': ('julehilsen',),
'julehilsenen': ('julehilsen',),
'julehilsenene': ('julehilsen',),
'julehilsener': ('julehilsen',),
'julehøgtid': ('julehøgtid',),
'julehøgtida': ('julehøgtid',),
'julehøgtiden': ('julehøgtid',),
'julehøgtidene': ('julehøgtid',),
'julehøgtider': ('julehøgtid',),
'julehøytid': ('julehøytid',),
'julehøytida': ('julehøytid',),
'julehøytiden': ('julehøytid',),
'julehøytidene': ('julehøytid',),
'julehøytider': ('julehøytid',),
'julekaka': ('julekake',),
'julekake': ('julekake',),
'julekaken': ('julekake',),
'julekakene': ('julekake',),
'julekaker': ('julekake',),
'julekort': ('julekort',),
'julekorta': ('julekort',),
'julekortene': ('julekort',),
'julekortet': ('julekort',),
'julekrybba': ('julekrybbe',),
'julekrybbe': ('julekrybbe',),
'julekrybben': ('julekrybbe',),
'julekrybbene': ('julekrybbe',),
'julekrybber': ('julekrybbe',),
'julekveld': ('julekveld',),
'julekvelden': ('julekveld',),
'julekveldene': ('julekveld',),
'julekvelder': ('julekveld',),
'julemaska': ('julemaske',),
'julemaske': ('julemaske',),
'julemasken': ('julemaske',),
'julemaskene': ('julemaske',),
'julemasker': ('julemaske',),
'julemat': ('julemat',),
'julematen': ('julemat',),
'julematene': ('julemat',),
'julemater': ('julemat',),
'julemerka': ('julemerke',),
'julemerke': ('julemerke',),
'julemerkene': ('julemerke',),
'julemerker': ('julemerke',),
'julemerket': ('julemerke',),
'julemessa': ('julemesse',),
'julemesse': ('julemesse',),
'julemessen': ('julemesse',),
'julemessene': ('julemesse',),
'julemesser': ('julemesse',),
'julemessa': ('julemesse',),
'julemesse': ('julemesse',),
'julemessen': ('julemesse',),
'julemessene': ('julemesse',),
'julemesser': ('julemesse',),
'julemorgen': ('julemorgen',),
'julemorgenen': ('julemorgen',),
'julemorgenene': ('julemorgen',),
'julemorgener': ('julemorgen',),
'julemorgnene': ('julemorgen',),
'julemorgner': ('julemorgen',),
'julemåned': ('julemåned',),
'julemåneden': ('julemåned',),
'julemånedene': ('julemåned',),
'julemåneder': ('julemåned',),
'julenatt': ('julenatt',),
'julenatta': ('julenatt',),
'julenatten': ('julenatt',),
'julenettene': ('julenatt',),
'julenetter': ('julenatt',),
'julenek': ('julenek',),
'juleneka': ('julenek',),
'julenekene': ('julenek',),
'juleneket': ('julenek',),
'julenisse': ('julenisse',),
'julenissen': ('julenisse',),
'julenissene': ('julenisse',),
'julenisser': ('julenisse',),
'julenummer': ('julenummer',),
'julenummeret': ('julenummer',),
'julenumra': ('julenummer',),
'julenumre': ('julenummer',),
'julenumrene': ('julenummer',),
'julepresang': ('julepresang',),
'julepresangen': ('julepresang',),
'julepresangene': ('julepresang',),
'julepresanger': ('julepresang',),
'julerei': ('julerei',),
'julereia': ('julerei',),
'julereien': ('julerei',),
'julereiene': ('julerei',),
'julereier': ('julerei',),
'julesalme': ('julesalme',),
'julesalmen': ('julesalme',),
'julesalmene': ('julesalme',),
'julesalmer': ('julesalme',),
'julesang': ('julesang',),
'julesangen': ('julesang',),
'julesangene': ('julesang',),
'julesanger': ('julesang',),
'juleselskap': ('juleselskap',),
'juleselskapa': ('juleselskap',),
'juleselskapene': ('juleselskap',),
'juleselskaper': ('juleselskap',),
'juleselskapet': ('juleselskap',),
'juleskikk': ('juleskikk',),
'juleskikken': ('juleskikk',),
'juleskikkene': ('juleskikk',),
'juleskikker': ('juleskikk',),
'juleskrei': ('juleskrei',),
'juleskreien': ('juleskrei',),
'juleskreiene': ('juleskrei',),
'juleskreier': ('juleskrei',),
'julesnø': ('julesnø',),
'julesnøen': ('julesnø',),
'julesnøene': ('julesnø',),
'julesnøer': ('julesnø',),
'julestjerna': ('julestjerne',),
'julestjerne': ('julestjerne',),
'julestjernen': ('julestjerne',),
'julestjernene': ('julestjerne',),
'julestjerner': ('julestjerne',),
'julestri': ('julestri',),
'julestria': ('julestri',),
'julestrien': ('julestri',),
'julestriene': ('julestri',),
'julestrier': ('julestri',),
'juletrefest': ('juletrefest',),
'juletrefesten': ('juletrefest',),
'juletrefestene': ('juletrefest',),
'juletrefester': ('juletrefest',),
'juletrefot': ('juletrefot',),
'juletrefoten': ('juletrefot',),
'juletreføttene': ('juletrefot',),
'juletreføtter': ('juletrefot',),
'juleuka': ('juleuke',),
'juleuke': ('juleuke',),
'juleuken': ('juleuke',),
'juleukene': ('juleuke',),
'juleuker': ('juleuke',),
'juleveka': ('juleveke',),
'juleveke': ('juleveke',),
'juleveken': ('juleveke',),
'julevekene': ('juleveke',),
'juleveker': ('juleveke',),
'juli': ('juli',),
'juling': ('juling',),
'julinga': ('juling',),
'julingen': ('juling',),
'julingene': ('juling',),
'julinger': ('juling',),
'jumbo': ('jumbo',),
'jumboen': ('jumbo',),
'jumboene': ('jumbo',),
'jumboer': ('jumbo',),
'jumbojet': ('jumbojet',),
'jumbojeten': ('jumbojet',),
'jumbojetene': ('jumbojet',),
'jumbojeter': ('jumbojet',),
'jumboplass': ('jumboplass',),
'jumboplassen': ('jumboplass',),
'jumboplassene': ('jumboplass',),
'jumboplasser': ('jumboplass',),
'jump': ('jump',),
'jumpa': ('jump',),
'jumpene': ('jump',),
'jumpet': ('jump',),
'jumper': ('jumper',),
'jumpere': ('jumper',),
'jumperen': ('jumper',),
'jumperer': ('jumper',),
'jumperne': ('jumper',),
'junge': ('junge',),
'jungen': ('junge',),
'jungene': ('junge',),
'junger': ('junge',),
'jungekniv': ('jungekniv',),
'jungekniven': ('jungekniv',),
'jungeknivene': ('jungekniv',),
'jungekniver': ('jungekniv',),
'jungel': ('jungel',),
'jungelen': ('jungel',),
'junglene': ('jungel',),
'jungler': ('jungel',),
'jungellov': ('jungellov',),
'jungelloven': ('jungellov',),
'jungellovene': ('jungellov',),
'jungellover': ('jungellov',),
'jungeltelegraf': ('jungeltelegraf',),
'jungeltelegrafen': ('jungeltelegraf',),
'jungeltelegrafene': ('jungeltelegraf',),
'jungeltelegrafer': ('jungeltelegraf',),
'jungmann': ('jungmann',),
'jungmannen': ('jungmann',),
'jungmenn': ('jungmann',),
'jungmennene': ('jungmann',),
'juni': ('juni',),
'junior': ('junior',),
'junioren': ('junior',),
'juniorene': ('junior',),
'juniorer': ('junior',),
'juniorklassa': ('juniorklasse',),
'juniorklasse': ('juniorklasse',),
'juniorklassen': ('juniorklasse',),
'juniorklassene': ('juniorklasse',),
'juniorklasser': ('juniorklasse',),
'juniorlag': ('juniorlag',),
'juniorlaga': ('juniorlag',),
'juniorlagene': ('juniorlag',),
'juniorlaget': ('juniorlag',),
'juniorløper': ('juniorløper',),
'juniorløpere': ('juniorløper',),
'juniorløperen': ('juniorløper',),
'juniorløperer': ('juniorløper',),
'juniorløperne': ('juniorløper',),
'juniorsjef': ('juniorsjef',),
'juniorsjefen': ('juniorsjef',),
'juniorsjefene': ('juniorsjef',),
'juniorsjefer': ('juniorsjef',),
'junk': ('junk',),
'junken': ('junk',),
'junkene': ('junk',),
'junker': ('junk',),
'junker': ('junker',),
'junkere': ('junker',),
'junkeren': ('junker',),
'junkerer': ('junker',),
'junkerne': ('junker',),
'junker': ('junker',),
'junkere': ('junker',),
'junkeren': ('junker',),
'junkerer': ('junker',),
'junkerne': ('junker',),
'junkie': ('junkie',),
'junkien': ('junkie',),
'junkiene': ('junkie',),
'junkier': ('junkie',),
'junksjon': ('junksjon',),
'junksjonen': ('junksjon',),
'junksjonene': ('junksjon',),
'junksjoner': ('junksjon',),
'junta': ('junta',),
'juntaen': ('junta',),
'juntaene': ('junta',),
'juntaer': ('junta',),
'juntastyra': ('juntastyre',),
'juntastyre': ('juntastyre',),
'juntastyrene': ('juntastyre',),
'juntastyrer': ('juntastyre',),
'juntastyret': ('juntastyre',),
'jur': ('jur',),
'jura': ('jur',),
'jurene': ('jur',),
'juret': ('jur',),
'juraformasjon': ('juraformasjon',),
'juraformasjonen': ('juraformasjon',),
'juraformasjonene': ('juraformasjon',),
'juraformasjoner': ('juraformasjon',),
'juraperiode': ('juraperiode',),
'juraperioden': ('juraperiode',),
'juraperiodene': ('juraperiode',),
'juraperioder': ('juraperiode',),
'jurasystem': ('jurasystem',),
'jurasystema': ('jurasystem',),
'jurasystemene': ('jurasystem',),
'jurasystemer': ('jurasystem',),
'jurasystemet': ('jurasystem',),
'juridikum': ('juridikum',),
'juridikumen': ('juridikum',),
'juridikumene': ('juridikum',),
'juridikumer': ('juridikum',),
'jurisdiksjon': ('jurisdiksjon',),
'jurisdiksjonen': ('jurisdiksjon',),
'jurisdiksjonene': ('jurisdiksjon',),
'jurisdiksjoner': ('jurisdiksjon',),
'jurist': ('jurist',),
'juristen': ('jurist',),
'juristene': ('jurist',),
'jurister': ('jurist',),
'juristeri': ('juristeri',),
'juristeria': ('juristeri',),
'juristeriene': ('juristeri',),
'juristerier': ('juristeri',),
'juristeriet': ('juristeri',),
'jury': ('jury',),
'juryen': ('jury',),
'juryene': ('jury',),
'juryer': ('jury',),
'juss': ('juss',),
'jussen': ('juss',),
'jussene': ('juss',),
'jusser': ('juss',),
'justerdirektør': ('justerdirektør',),
'justerdirektøren': ('justerdirektør',),
'justerdirektørene': ('justerdirektør',),
'justerdirektører': ('justerdirektør',),
'justerer': ('justerer',),
'justerere': ('justerer',),
'justereren': ('justerer',),
'justererer': ('justerer',),
'justererne': ('justerer',),
'justerkammer': ('justerkammer',),
'justerkammeret': ('justerkammer',),
'justerkamra': ('justerkammer',),
'justerkamre': ('justerkammer',),
'justerkamrene': ('justerkammer',),
'justermester': ('justermester',),
'justermestere': ('justermester',),
'justermesteren': ('justermester',),
'justermesterer': ('justermester',),
'justermesterne': ('justermester',),
'justermestre': ('justermester',),
'justermestrene': ('justermester',),
'justermestrer': ('justermester',),
'justerstempel': ('justerstempel',),
'justerstempelet': ('justerstempel',),
'justerstempla': ('justerstempel',),
'justerstemplene': ('justerstempel',),
'justerstempler': ('justerstempel',),
'justerstemplet': ('justerstempel',),
'justervesen': ('justervesen',),
'justervesena': ('justervesen',),
'justervesenene': ('justervesen',),
'justervesener': ('justervesen',),
'justervesenet': ('justervesen',),
'justifikasjon': ('justifikasjon',),
'justifikasjonen': ('justifikasjon',),
'justifikasjonene': ('justifikasjon',),
'justifikasjoner': ('justifikasjon',),
'justis': ('justis',),
'justisen': ('justis',),
'justisene': ('justis',),
'justiser': ('justis',),
'justisdepartement': ('justisdepartement',),
'justisdepartementa': ('justisdepartement',),
'justisdepartementene': ('justisdepartement',),
'justisdepartementer': ('justisdepartement',),
'justisdepartementet': ('justisdepartement',),
'justisminister': ('justisminister',),
'justisministere': ('justisminister',),
'justisministeren': ('justisminister',),
'justisministerer': ('justisminister',),
'justisministerne': ('justisminister',),
'justisministre': ('justisminister',),
'justisministrene': ('justisminister',),
'justisministrer': ('justisminister',),
'justismord': ('justismord',),
'justismorda': ('justismord',),
'justismordene': ('justismord',),
'justismordet': ('justismord',),
'justitia': ('justitia',),
'justitiarien': ('justitiarius',),
'justitiariene': ('justitiarius',),
'justitiarier': ('justitiarius',),
'justitiarius': ('justitiarius',),
'jute': ('jute',),
'juten': ('jute',),
'jutene': ('jute',),
'juter': ('jute',),
'jutehamp': ('jutehamp',),
'jutehampen': ('jutehamp',),
'jutehampene': ('jutehamp',),
'jutehamper': ('jutehamp',),
'jutul': ('jutul',),
'jutulen': ('jutul',),
'jutulene': ('jutul',),
'jutuler': ('jutul',),
'juv': ('juv',),
'juva': ('juv',),
'juvene': ('juv',),
'juvet': ('juv',),
'juvel': ('juvel',),
'juvelen': ('juvel',),
'juvelene': ('juvel',),
'juveler': ('juvel',),
'juveler': ('juveler',),
'juveleren': ('juveler',),
'juvelerene': ('juveler',),
'juvelerer': ('juveler',),
'jyde': ('jyde',),
'jyden': ('jyde',),
'jydene': ('jyde',),
'jyder': ('jyde',),
'jypling': ('jypling',),
'jyplingen': ('jypling',),
'jyplingene': ('jypling',),
'jyplinger': ('jypling',),
'jysk': ('jysk',),
'jysken': ('jysk',),
'jyskene': ('jysk',),
'jysker': ('jysk',),
'jåblom': ('jåblom',),
'jåblommen': ('jåblom',),
'jåblommene': ('jåblom',),
'jåblommer': ('jåblom',),
'jål': ('jål',),
'jåla': ('jål',),
'jålene': ('jål',),
'jålet': ('jål',),
'jåle': ('jåle',),
'jålen': ('jåle',),
'jålene': ('jåle',),
'jåler': ('jåle',),
'jåla': ('jåle',),
'jåle': ('jåle',),
'jålen': ('jåle',),
'jålene': ('jåle',),
'jåler': ('jåle',),
'jålebukk': ('jålebukk',),
'jålebukken': ('jålebukk',),
'jålebukkene': ('jålebukk',),
'jålebukker': ('jålebukk',),
'jåleportrett': ('jåleportrett',),
'jåleportretta': ('jåleportrett',),
'jåleportrettene': ('jåleportrett',),
'jåleportretter': ('jåleportrett',),
'jåleportrettet': ('jåleportrett',),
'jåleri': ('jåleri',),
'jåleria': ('jåleri',),
'jåleriene': ('jåleri',),
'jålerier': ('jåleri',),
'jåleriet': ('jåleri',),
'jækel': ('jækel',),
'jækelen': ('jækel',),
'jæklene': ('jækel',),
'jækler': ('jækel',),
'jærbu': ('jærbu',),
'jærbuen': ('jærbu',),
'jærbuene': ('jærbu',),
'jærbuer': ('jærbu',),
'jærtegn': ('jærtegn',),
'jærtegna': ('jærtegn',),
'jærtegnene': ('jærtegn',),
'jærtegnet': ('jærtegn',),
'jævel': ('jævel',),
'jævelen': ('jævel',),
'jævlene': ('jævel',),
'jævler': ('jævel',),
'jævelskap': ('jævelskap',),
'jævelskapa': ('jævelskap',),
'jævelskapen': ('jævelskap',),
'jævelskapene': ('jævelskap',),
'jævelskaper': ('jævelskap',),
'jævelskapet': ('jævelskap',),
'jøde': ('jøde',),
'jøden': ('jøde',),
'jødene': ('jøde',),
'jøder': ('jøde',),
'jødedom': ('jødedom',),
'jødedommen': ('jødedom',),
'jødedommene': ('jødedom',),
'jødedommer': ('jødedom',),
'jødeforfølgelse': ('jødeforfølgelse',),
'jødeforfølgelsen': ('jødeforfølgelse',),
'jødeforfølgelsene': ('jødeforfølgelse',),
'jødeforfølgelser': ('jødeforfølgelse',),
'jødehat': ('jødehat',),
'jødehata': ('jødehat',),
'jødehatene': ('jødehat',),
'jødehatet': ('jødehat',),
'jødekvarter': ('jødekvarter',),
'jødekvartera': ('jødekvarter',),
'jødekvarterene': ('jødekvarter',),
'jødekvarterer': ('jødekvarter',),
'jødekvarteret': ('jødekvarter',),
'jøkel': ('jøkel',),
'jøkelen': ('jøkel',),
'jøklene': ('jøkel',),
'jøkler': ('jøkel',),
'jøssing': ('jøssing',),
'jøssingen': ('jøssing',),
'jøssingene': ('jøssing',),
'jøssinger': ('jøssing',),
'k': ('k',),
'k\'en': ('k',),
'k-en': ('k',),
'k-ene': ('k',),
'k-er': ('k',),
'k-soldat': ('k-soldat',),
'k-soldaten': ('k-soldat',),
'k-soldatene': ('k-soldat',),
'k-soldater': ('k-soldat',),
'k-verdi': ('k-verdi',),
'k-verdien': ('k-verdi',),
'k-verdiene': ('k-verdi',),
'k-verdier': ('k-verdi',),
'kabal': ('kabal',),
'kabalen': ('kabal',),
'kabalene': ('kabal',),
'kabaler': ('kabal',),
'kabaret': ('kabaret',),
'kabareten': ('kabaret',),
'kabaretene': ('kabaret',),
'kabareter': ('kabaret',),
'kabaretfat': ('kabaretfat',),
'kabaretfata': ('kabaretfat',),
'kabaretfatene': ('kabaretfat',),
'kabaretfater': ('kabaretfat',),
'kabaretfatet': ('kabaretfat',),
'kabaretkunstner': ('kabaretkunstner',),
'kabaretkunstnere': ('kabaretkunstner',),
'kabaretkunstneren': ('kabaretkunstner',),
'kabaretkunstnerer': ('kabaretkunstner',),
'kabaretkunstnerne': ('kabaretkunstner',),
'kabb': ('kabb',),
'kabben': ('kabb',),
'kabbene': ('kabb',),
'kabber': ('kabb',),
'kabbala': ('kabbala',),
'kabbalaen': ('kabbala',),
'kabbalaene': ('kabbala',),
'kabbalaer': ('kabbala',),
'kabbalisme': ('kabbalisme',),
'kabbalismen': ('kabbalisme',),
'kabbalismene': ('kabbalisme',),
'kabbalismer': ('kabbalisme',),
'kabbalist': ('kabbalist',),
'kabbalisten': ('kabbalist',),
'kabbalistene': ('kabbalist',),
'kabbalister': ('kabbalist',),
'kabbe': ('kabbe',),
'kabben': ('kabbe',),
'kabbene': ('kabbe',),
'kabber': ('kabbe',),
'kabel': ('kabel',),
'kabelen': ('kabel',),
'kablene': ('kabel',),
'kabler': ('kabel',),
'kabelbane': ('kabelbane',),
'kabelbanen': ('kabelbane',),
'kabelbanene': ('kabelbane',),
'kabelbaner': ('kabelbane',),
'kabelfartøy': ('kabelfartøy',),
'kabelfartøya': ('kabelfartøy',),
'kabelfartøyene': ('kabelfartøy',),
'kabelfartøyer': ('kabelfartøy',),
'kabelfartøyet': ('kabelfartøy',),
'kabelfjernsyn': ('kabelfjernsyn',),
'kabelfjernsyna': ('kabelfjernsyn',),
'kabelfjernsynene': ('kabelfjernsyn',),
'kabelfjernsynet': ('kabelfjernsyn',),
'kabelgatt': ('kabelgatt',),
'kabelgatta': ('kabelgatt',),
'kabelgattene': ('kabelgatt',),
'kabelgattet': ('kabelgatt',),
'kabellengd': ('kabellengd',),
'kabellengda': ('kabellengd',),
'kabellengden': ('kabellengd',),
'kabellengdene': ('kabellengd',),
'kabellengder': ('kabellengd',),
'kabellengde': ('kabellengde',),
'kabellengden': ('kabellengde',),
'kabellengdene': ('kabellengde',),
'kabellengder': ('kabellengde',),
'kabin': ('kabin',),
'kabinen': ('kabin',),
'kabinene': ('kabin',),
'kabiner': ('kabin',),
'kabinett': ('kabinett',),
'kabinetta': ('kabinett',),
'kabinettene': ('kabinett',),
'kabinetter': ('kabinett',),
'kabinettet': ('kabinett',),
'kabinettssekretær': ('kabinettssekretær',),
'kabinettssekretæren': ('kabinettssekretær',),
'kabinettssekretærene': ('kabinettssekretær',),
'kabinettssekretærer': ('kabinettssekretær',),
'kabinettsspørsmål': ('kabinettsspørsmål',),
'kabinettsspørsmåla': ('kabinettsspørsmål',),
'kabinettsspørsmålene': ('kabinettsspørsmål',),
'kabinettsspørsmålet': ('kabinettsspørsmål',),
'kabinkrysser': ('kabinkrysser',),
'kabinkryssere': ('kabinkrysser',),
'kabinkrysseren': ('kabinkrysser',),
'kabinkrysserer': ('kabinkrysser',),
'kabinkrysserne': ('kabinkrysser',),
'kabinkrysser': ('kabinkrysser',),
'kabinkryssere': ('kabinkrysser',),
'kabinkrysseren': ('kabinkrysser',),
'kabinkrysserer': ('kabinkrysser',),
'kabinkrysserne': ('kabinkrysser',),
'kabinpersonala': ('kabinpersonale',),
'kabinpersonale': ('kabinpersonale',),
'kabinpersonalene': ('kabinpersonale',),
'kabinpersonaler': ('kabinpersonale',),
'kabinpersonalet': ('kabinpersonale',),
'kabotasje': ('kabotasje',),
'kabotasjen': ('kabotasje',),
'kabotasjene': ('kabotasje',),
'kabotasjer': ('kabotasje',),
'kabriolet': ('kabriolet',),
'kabrioleten': ('kabriolet',),
'kabrioletene': ('kabriolet',),
'kabrioleter': ('kabriolet',),
'kabyl': ('kabyl',),
'kabylen': ('kabyl',),
'kabylene': ('kabyl',),
'kabyler': ('kabyl',),
'kabyss': ('kabyss',),
'kabyssa': ('kabyss',),
'kabyssen': ('kabyss',),
'kabyssene': ('kabyss',),
'kabysser': ('kabyss',),
'kabyssa': ('kabysse',),
'kabysse': ('kabysse',),
'kabyssen': ('kabysse',),
'kabyssene': ('kabysse',),
'kabysser': ('kabysse',),
'kadaver': ('kadaver',),
'kadaveret': ('kadaver',),
'kadavra': ('kadaver',),
'kadavre': ('kadaver',),
'kadavrene': ('kadaver',),
'kadaverdisiplin': ('kadaverdisiplin',),
'kadaverdisiplinen': ('kadaverdisiplin',),
'kadaverdisiplinene': ('kadaverdisiplin',),
'kadaverdisipliner': ('kadaverdisiplin',),
'kadens': ('kadens',),
'kadensen': ('kadens',),
'kadensene': ('kadens',),
'kadenser': ('kadens',),
'kader': ('kader',),
'kadere': ('kader',),
'kaderen': ('kader',),
'kaderne': ('kader',),
'kadre': ('kader',),
'kadrene': ('kader',),
'kadrer': ('kader',),
'kaderparti': ('kaderparti',),
'kaderpartia': ('kaderparti',),
'kaderpartiene': ('kaderparti',),
'kaderpartier': ('kaderparti',),
'kaderpartiet': ('kaderparti',),
'kadett': ('kadett',),
'kadetten': ('kadett',),
'kadettene': ('kadett',),
'kadetter': ('kadett',),
'kadett-tøy': ('kadett-tøy',),
'kadett-tøya': ('kadett-tøy',),
'kadett-tøyene': ('kadett-tøy',),
'kadett-tøyer': ('kadett-tøy',),
'kadett-tøyet': ('kadett-tøy',),
'kadettøy': ('kadettøy',),
'kadettøya': ('kadettøy',),
'kadettøyene': ('kadettøy',),
'kadettøyer': ('kadettøy',),
'kadettøyet': ('kadettøy',),
'kadi': ('kadi',),
'kadien': ('kadi',),
'kadiene': ('kadi',),
'kadier': ('kadi',),
'kadmium': ('kadmium',),
'kadmiuma': ('kadmium',),
'kadmiumene': ('kadmium',),
'kadmiumet': ('kadmium',),
'kadreier': ('kadreier',),
'kadreiere': ('kadreier',),
'kadreieren': ('kadreier',),
'kadreierer': ('kadreier',),
'kadreierne': ('kadreier',),
'kafeen': ('kafé',),
'kafeene': ('kafé',),
'kafeer': ('kafé',),
'kafé': ('kafé',),
'kaféen': ('kafé',),
'kaféene': ('kafé',),
'kaféer': ('kafé',),
'kafeteria': ('kafeteria',),
'kafeteriaen': ('kafeteria',),
'kafeteriaene': ('kafeteria',),
'kafeteriaer': ('kafeteria',),
'kafeteriasystem': ('kafeteriasystem',),
'kafeteriasystema': ('kafeteriasystem',),
'kafeteriasystemene': ('kafeteriasystem',),
'kafeteriasystemer': ('kafeteriasystem',),
'kafeteriasystemet': ('kafeteriasystem',),
'kaffe': ('kaffe',),
'kaffen': ('kaffe',),
'kaffene': ('kaffe',),
'kaffer': ('kaffe',),
'kaffebrød': ('kaffebrød',),
'kaffebrøda': ('kaffebrød',),
'kaffebrødene': ('kaffebrød',),
'kaffebrødet': ('kaffebrød',),
'kaffebønna': ('kaffebønne',),
'kaffebønne': ('kaffebønne',),
'kaffebønnen': ('kaffebønne',),
'kaffebønnene': ('kaffebønne',),
'kaffebønner': ('kaffebønne',),
'kaffedokter': ('kaffedokter',),
'kaffedoktere': ('kaffedokter',),
'kaffedokteren': ('kaffedokter',),
'kaffedokterer': ('kaffedokter',),
'kaffedokterne': ('kaffedokter',),
'kaffefløte': ('kaffefløte',),
'kaffefløten': ('kaffefløte',),
'kaffefløtene': ('kaffefløte',),
'kaffefløter': ('kaffefløte',),
'kaffegrut': ('kaffegrut',),
'kaffegruta': ('kaffegrut',),
'kaffegruten': ('kaffegrut',),
'kaffegrutene': ('kaffegrut',),
'kaffegruter': ('kaffegrut',),
'kaffegrutet': ('kaffegrut',),
'kaffein': ('kaffein',),
'kaffeina': ('kaffein',),
'kaffeinen': ('kaffein',),
'kaffeinene': ('kaffein',),
'kaffeiner': ('kaffein',),
'kaffeinet': ('kaffein',),
'kaffein': ('kaffein',),
'kaffeina': ('kaffein',),
'kaffeinen': ('kaffein',),
'kaffeinene': ('kaffein',),
'kaffeiner': ('kaffein',),
'kaffeinet': ('kaffein',),
'kaffekanna': ('kaffekanne',),
'kaffekanne': ('kaffekanne',),
'kaffekannen': ('kaffekanne',),
'kaffekannene': ('kaffekanne',),
'kaffekanner': ('kaffekanne',),
'kaffekjel': ('kaffekjel',),
'kaffekjelen': ('kaffekjel',),
'kaffekjelene': ('kaffekjel',),
'kaffekjeler': ('kaffekjel',),
'kaffekjele': ('kaffekjele',),
'kaffekjelen': ('kaffekjele',),
'kaffekjelene': ('kaffekjele',),
'kaffekjeler': ('kaffekjele',),
'kaffekjerring': ('kaffekjerring',),
'kaffekjerringa': ('kaffekjerring',),
'kaffekjerringen': ('kaffekjerring',),
'kaffekjerringene': ('kaffekjerring',),
'kaffekjerringer': ('kaffekjerring',),
'kaffekoker': ('kaffekoker',),
'kaffekokere': ('kaffekoker',),
'kaffekokeren': ('kaffekoker',),
'kaffekokerer': ('kaffekoker',),
'kaffekokerne': ('kaffekoker',),
'kaffekopp': ('kaffekopp',),
'kaffekoppen': ('kaffekopp',),
'kaffekoppene': ('kaffekopp',),
'kaffekopper': ('kaffekopp',),
'kaffelars': ('kaffelars',),
'kaffelarsen': ('kaffelars',),
'kaffelarsene': ('kaffelars',),
'kaffelarser': ('kaffelars',),
'kaffepause': ('kaffepause',),
'kaffepausen': ('kaffepause',),
'kaffepausene': ('kaffepause',),
'kaffepauser': ('kaffepause',),
'kaffer': ('kaffer',),
'kaffere': ('kaffer',),
'kafferen': ('kaffer',),
'kafferer': ('kaffer',),
'kafferne': ('kaffer',),
'kaffeservisa': ('kaffeservise',),
'kaffeservise': ('kaffeservise',),
'kaffeservisene': ('kaffeservise',),
'kaffeserviser': ('kaffeservise',),
'kaffeserviset': ('kaffeservise',),
'kaffeslabberas': ('kaffeslabberas',),
'kaffeslabberasa': ('kaffeslabberas',),
'kaffeslabberasene': ('kaffeslabberas',),
'kaffeslabberaset': ('kaffeslabberas',),
'kaffestova': ('kaffestove',),
'kaffestove': ('kaffestove',),
'kaffestoven': ('kaffestove',),
'kaffestovene': ('kaffestove',),
'kaffestover': ('kaffestove',),
'kaffestua': ('kaffestue',),
'kaffestue': ('kaffestue',),
'kaffestuen': ('kaffestue',),
'kaffestuene': ('kaffestue',),
'kaffestuer': ('kaffestue',),
'kaffetrakter': ('kaffetrakter',),
'kaffetraktere': ('kaffetrakter',),
'kaffetrakteren': ('kaffetrakter',),
'kaffetrakterer': ('kaffetrakter',),
'kaffetrakterne': ('kaffetrakter',),
'kaffetre': ('kaffetre',),
'kaffetrea': ('kaffetre',),
'kaffetreet': ('kaffetre',),
'kaffetrær': ('kaffetre',),
'kaffetrærne': ('kaffetre',),
'kaffetår': ('kaffetår',),
'kaffetåren': ('kaffetår',),
'kaffetårene': ('kaffetår',),
'kaffetårer': ('kaffetår',),
'kaftan': ('kaftan',),
'kaftanen': ('kaftan',),
'kaftanene': ('kaftan',),
'kaftaner': ('kaftan',),
'kagg': ('kagg',),
'kaggen': ('kagg',),
'kaggene': ('kagg',),
'kagger': ('kagg',),
'kagga': ('kagge',),
'kagge': ('kagge',),
'kaggen': ('kagge',),
'kaggene': ('kagge',),
'kagger': ('kagge',),
'kaggesetning': ('kaggesetning',),
'kaggesetninga': ('kaggesetning',),
'kaggesetningen': ('kaggesetning',),
'kaggesetningene': ('kaggesetning',),
'kaggesetninger': ('kaggesetning',),
'kahytt': ('kahytt',),
'kahytta': ('kahytt',),
'kahytten': ('kahytt',),
'kahyttene': ('kahytt',),
'kahytter': ('kahytt',),
'kahyttdør': ('kahyttdør',),
'kahyttdøra': ('kahyttdør',),
'kahyttdøren': ('kahyttdør',),
'kahyttdørene': ('kahyttdør',),
'kahyttdører': ('kahyttdør',),
'kahytta': ('kahytte',),
'kahytte': ('kahytte',),
'kahytten': ('kahytte',),
'kahyttene': ('kahytte',),
'kahytter': ('kahytte',),
'kahyttsdør': ('kahyttsdør',),
'kahyttsdøra': ('kahyttsdør',),
'kahyttsdøren': ('kahyttsdør',),
'kahyttsdørene': ('kahyttsdør',),
'kahyttsdører': ('kahyttsdør',),
'kai': ('kai',),
'kaia': ('kai',),
'kaien': ('kai',),
'kaiene': ('kai',),
'kaier': ('kai',),
'kaia': ('kaie',),
'kaie': ('kaie',),
'kaien': ('kaie',),
'kaiene': ('kaie',),
'kaier': ('kaie',),
'kaiman': ('kaiman',),
'kaimanen': ('kaiman',),
'kaimanene': ('kaiman',),
'kaimaner': ('kaiman',),
'kainitt': ('kainitt',),
'kainitten': ('kainitt',),
'kainittene': ('kainitt',),
'kainitter': ('kainitt',),
'kainsmerka': ('kainsmerke',),
'kainsmerke': ('kainsmerke',),
'kainsmerkene': ('kainsmerke',),
'kainsmerker': ('kainsmerke',),
'kainsmerket': ('kainsmerke',),
'kajakk': ('kajakk',),
'kajakken': ('kajakk',),
'kajakkene': ('kajakk',),
'kajakker': ('kajakk',),
'kajakkpadling': ('kajakkpadling',),
'kajakkpadlinga': ('kajakkpadling',),
'kajakkpadlingen': ('kajakkpadling',),
'kajakkpadlingene': ('kajakkpadling',),
'kajakkpadlinger': ('kajakkpadling',),
'kajakksport': ('kajakksport',),
'kajakksporten': ('kajakksport',),
'kajakksportene': ('kajakksport',),
'kajakksporter': ('kajakksport',),
'kajennepepper': ('kajennepepper',),
'kajennepeppere': ('kajennepepper',),
'kajennepepperen': ('kajennepepper',),
'kajennepepperer': ('kajennepepper',),
'kajennepepperne': ('kajennepepper',),
'kajennepeprene': ('kajennepepper',),
'kajennepeprer': ('kajennepepper',),
'kak': ('kak',),
'kaken': ('kak',),
'kakene': ('kak',),
'kaker': ('kak',),
'kakadu': ('kakadu',),
'kakadua': ('kakadu',),
'kakaduen': ('kakadu',),
'kakaduene': ('kakadu',),
'kakaduer': ('kakadu',),
'kakadua': ('kakadue',),
'kakadue': ('kakadue',),
'kakaduen': ('kakadue',),
'kakaduene': ('kakadue',),
'kakaduer': ('kakadue',),
'kakao': ('kakao',),
'kakaoen': ('kakao',),
'kakaoene': ('kakao',),
'kakaoer': ('kakao',),
'kakaobønna': ('kakaobønne',),
'kakaobønne': ('kakaobønne',),
'kakaobønnen': ('kakaobønne',),
'kakaobønnene': ('kakaobønne',),
'kakaobønner': ('kakaobønne',),
'kakaomøll': ('kakaomøll',),
'kakaomølla': ('kakaomøll',),
'kakaomøllen': ('kakaomøll',),
'kakaomøllene': ('kakaomøll',),
'kakaomøllet': ('kakaomøll',),
'kakaopulver': ('kakaopulver',),
'kakaopulvera': ('kakaopulver',),
'kakaopulvere': ('kakaopulver',),
'kakaopulveret': ('kakaopulver',),
'kakaopulverne': ('kakaopulver',),
'kakaotre': ('kakaotre',),
'kakaotrea': ('kakaotre',),
'kakaotreet': ('kakaotre',),
'kakaotrær': ('kakaotre',),
'kakaotrærne': ('kakaotre',),
'kaka': ('kake',),
'kake': ('kake',),
'kaken': ('kake',),
'kakene': ('kake',),
'kaker': ('kake',),
'kakebotn': ('kakebotn',),
'kakebotnen': ('kakebotn',),
'kakebotnene': ('kakebotn',),
'kakebotner': ('kakebotn',),
'kakebu': ('kakebu',),
'kakebua': ('kakebu',),
'kakebuen': ('kakebu',),
'kakebuene': ('kakebu',),
'kakebuer': ('kakebu',),
'kakebunn': ('kakebunn',),
'kakebunnen': ('kakebunn',),
'kakebunnene': ('kakebunn',),
'kakebunner': ('kakebunn',),
'kakelinna': ('kakelinne',),
'kakelinne': ('kakelinne',),
'kakelinnen': ('kakelinne',),
'kakelinnene': ('kakelinne',),
'kakelinner': ('kakelinne',),
'kakemann': ('kakemann',),
'kakemannen': ('kakemann',),
'kakemenn': ('kakemann',),
'kakemennene': ('kakemann',),
'kakemons': ('kakemons',),
'kakemonsen': ('kakemons',),
'kakemonsene': ('kakemons',),
'kakemonser': ('kakemons',),
'kakerlakk': ('kakerlakk',),
'kakerlakken': ('kakerlakk',),
'kakerlakkene': ('kakerlakk',),
'kakerlakker': ('kakerlakk',),
'kakespade': ('kakespade',),
'kakespaden': ('kakespade',),
'kakespadene': ('kakespade',),
'kakespader': ('kakespade',),
'kaki': ('kaki',),
'kakien': ('kaki',),
'kakiene': ('kaki',),
'kakier': ('kaki',),
'kakibuksa': ('kakibukse',),
'kakibukse': ('kakibukse',),
'kakibuksen': ('kakibukse',),
'kakibuksene': ('kakibukse',),
'kakibukser': ('kakibukse',),
'kakiskjorta': ('kakiskjorte',),
'kakiskjorte': ('kakiskjorte',),
'kakiskjorten': ('kakiskjorte',),
'kakiskjortene': ('kakiskjorte',),
'kakiskjorter': ('kakiskjorte',),
'kakk': ('kakk',),
'kakken': ('kakk',),
'kakkene': ('kakk',),
'kakker': ('kakk',),
'kakk': ('kakk',),
'kakka': ('kakk',),
'kakken': ('kakk',),
'kakkene': ('kakk',),
'kakket': ('kakk',),
'kakkel': ('kakkel',),
'kakkelen': ('kakkel',),
'kaklene': ('kakkel',),
'kakler': ('kakkel',),
'kakkelomn': ('kakkelomn',),
'kakkelomnen': ('kakkelomn',),
'kakkelomnene': ('kakkelomn',),
'kakkelomner': ('kakkelomn',),
'kakkelovn': ('kakkelovn',),
'kakkelovnen': ('kakkelovn',),
'kakkelovnene': ('kakkelovn',),
'kakkelovner': ('kakkelovn',),
'kakl': ('kakl',),
'kakla': ('kakl',),
'kaklene': ('kakl',),
'kaklet': ('kakl',),
'kakofoni': ('kakofoni',),
'kakofonien': ('kakofoni',),
'kakofoniene': ('kakofoni',),
'kakofonier': ('kakofoni',),
'kakse': ('kakse',),
'kaksen': ('kakse',),
'kaksene': ('kakse',),
'kakser': ('kakse',),
'kaktus': ('kaktus',),
'kaktusen': ('kaktus',),
'kaktusene': ('kaktus',),
'kaktuser': ('kaktus',),
'kakuminal': ('kakuminal',),
'kakuminalen': ('kakuminal',),
'kakuminalene': ('kakuminal',),
'kakuminaler': ('kakuminal',),
'kal': ('kal',),
'kalen': ('kal',),
'kalene': ('kal',),
'kaler': ('kal',),
'kala': ('kala',),
'kalaen': ('kala',),
'kalaene': ('kala',),
'kalaer': ('kala',),
'kalamitet': ('kalamitet',),
'kalamiteten': ('kalamitet',),
'kalamitetene': ('kalamitet',),
'kalamiteter': ('kalamitet',),
'kalander': ('kalander',),
'kalandere': ('kalander',),
'kalanderen': ('kalander',),
'kalanderne': ('kalander',),
'kalandre': ('kalander',),
'kalandrene': ('kalander',),
'kalandrer': ('kalander',),
'kalas': ('kalas',),
'kalasa': ('kalas',),
'kalasene': ('kalas',),
'kalaser': ('kalas',),
'kalaset': ('kalas',),
'kalasseier': ('kalasseier',),
'kalasseiere': ('kalasseier',),
'kalasseieren': ('kalasseier',),
'kalasseierne': ('kalasseier',),
'kalasseire': ('kalasseier',),
'kalasseirene': ('kalasseier',),
'kalasseirer': ('kalasseier',),
'kalassiffer': ('kalassiffer',),
'kalassifferet': ('kalassiffer',),
'kalassifra': ('kalassiffer',),
'kalassifre': ('kalassiffer',),
'kalassifrene': ('kalassiffer',),
'kaldbenk': ('kaldbenk',),
'kaldbenken': ('kaldbenk',),
'kaldbenkene': ('kaldbenk',),
'kaldbenker': ('kaldbenk',),
'kaldblodshest': ('kaldblodshest',),
'kaldblodshesten': ('kaldblodshest',),
'kaldblodshestene': ('kaldblodshest',),
'kaldblodshester': ('kaldblodshest',),
'kaldblodsløp': ('kaldblodsløp',),
'kaldblodsløpa': ('kaldblodsløp',),
'kaldblodsløpene': ('kaldblodsløp',),
'kaldblodsløpet': ('kaldblodsløp',),
'kalddusj': ('kalddusj',),
'kalddusjen': ('kalddusj',),
'kalddusjene': ('kalddusj',),
'kalddusjer': ('kalddusj',),
'kaldeer': ('kaldeer',),
'kaldeere': ('kaldeer',),
'kaldeeren': ('kaldeer',),
'kaldeerer': ('kaldeer',),
'kaldeerne': ('kaldeer',),
'kaldfeber': ('kaldfeber',),
'kaldfebere': ('kaldfeber',),
'kaldfeberen': ('kaldfeber',),
'kaldfeberne': ('kaldfeber',),
'kaldfebre': ('kaldfeber',),
'kaldfebrene': ('kaldfeber',),
'kaldfebrer': ('kaldfeber',),
'kaldflir': ('kaldflir',),
'kaldflira': ('kaldflir',),
'kaldfliren': ('kaldflir',),
'kaldflirene': ('kaldflir',),
'kaldfliret': ('kaldflir',),
'kaldfront': ('kaldfront',),
'kaldfronten': ('kaldfront',),
'kaldfrontene': ('kaldfront',),
'kaldfronter': ('kaldfront',),
'kaldgraut': ('kaldgraut',),
'kaldgrauten': ('kaldgraut',),
'kaldgrautene': ('kaldgraut',),
'kaldgrauter': ('kaldgraut',),
'kaldgrøt': ('kaldgrøt',),
'kaldgrøten': ('kaldgrøt',),
'kaldgrøtene': ('kaldgrøt',),
'kaldgrøter': ('kaldgrøt',),
'kaldgufs': ('kaldgufs',),
'kaldgufsa': ('kaldgufs',),
'kaldgufsen': ('kaldgufs',),
'kaldgufsene': ('kaldgufs',),
'kaldgufser': ('kaldgufs',),
'kaldgufset': ('kaldgufs',),
'kaldjomfru': ('kaldjomfru',),
'kaldjomfrua': ('kaldjomfru',),
'kaldjomfruen': ('kaldjomfru',),
'kaldjomfruene': ('kaldjomfru',),
'kaldjomfruer': ('kaldjomfru',),
'kaldjomfru': ('kaldjomfru',),
'kaldjomfrua': ('kaldjomfru',),
'kaldjomfruen': ('kaldjomfru',),
'kaldjomfruene': ('kaldjomfru',),
'kaldjomfruer': ('kaldjomfru',),
'kaldluft': ('kaldluft',),
'kaldlufta': ('kaldluft',),
'kaldluften': ('kaldluft',),
'kaldluftene': ('kaldluft',),
'kaldlufter': ('kaldluft',),
'kaldnål': ('kaldnål',),
'kaldnåla': ('kaldnål',),
'kaldnålen': ('kaldnål',),
'kaldnålene': ('kaldnål',),
'kaldnåler': ('kaldnål',),
'kaldnålsradering': ('kaldnålsradering',),
'kaldnålsraderinga': ('kaldnålsradering',),
'kaldnålsraderingen': ('kaldnålsradering',),
'kaldnålsraderingene': ('kaldnålsradering',),
'kaldnålsraderinger': ('kaldnålsradering',),
'kaldprat': ('kaldprat',),
'kaldprata': ('kaldprat',),
'kaldpraten': ('kaldprat',),
'kaldpratene': ('kaldprat',),
'kaldprater': ('kaldprat',),
'kaldpratet': ('kaldprat',),
'kaldskratt': ('kaldskratt',),
'kaldskratta': ('kaldskratt',),
'kaldskratten': ('kaldskratt',),
'kaldskrattene': ('kaldskratt',),
'kaldskrattet': ('kaldskratt',),
'kaldstart': ('kaldstart',),
'kaldstarten': ('kaldstart',),
'kaldstartene': ('kaldstart',),
'kaldstarter': ('kaldstart',),
'kaldtbord': ('kaldtbord',),
'kaldtborda': ('kaldtbord',),
'kaldtbordene': ('kaldtbord',),
'kaldtborder': ('kaldtbord',),
'kaldtbordet': ('kaldtbord',),
'kaldtbord': ('kaldtbord',),
'kaldtborda': ('kaldtbord',),
'kaldtbordene': ('kaldtbord',),
'kaldtborder': ('kaldtbord',),
'kaldtbordet': ('kaldtbord',),
'kaldtkjøkken': ('kaldtkjøkken',),
'kaldtkjøkkena': ('kaldtkjøkken',),
'kaldtkjøkkenene': ('kaldtkjøkken',),
'kaldtkjøkkener': ('kaldtkjøkken',),
'kaldtkjøkkenet': ('kaldtkjøkken',),
'kaldtkjøkken': ('kaldtkjøkken',),
'kaldtkjøkkena': ('kaldtkjøkken',),
'kaldtkjøkkenene': ('kaldtkjøkken',),
'kaldtkjøkkener': ('kaldtkjøkken',),
'kaldtkjøkkenet': ('kaldtkjøkken',),
'kaldtvann': ('kaldtvann',),
'kaldtvanna': ('kaldtvann',),
'kaldtvannene': ('kaldtvann',),
'kaldtvannet': ('kaldtvann',),
'kaldtvannsomslag': ('kaldtvannsomslag',),
'kaldtvannsomslaga': ('kaldtvannsomslag',),
'kaldtvannsomslagene': ('kaldtvannsomslag',),
'kaldtvannsomslaget': ('kaldtvannsomslag',),
'kaldtvassomslag': ('kaldtvassomslag',),
'kaldtvassomslaga': ('kaldtvassomslag',),
'kaldtvassomslagene': ('kaldtvassomslag',),
'kaldtvassomslaget': ('kaldtvassomslag',),
'kaldtvatn': ('kaldtvatn',),
'kaldtvatna': ('kaldtvatn',),
'kaldtvatnene': ('kaldtvatn',),
'kaldtvatnet': ('kaldtvatn',),
'kaldvatn': ('kaldvatn',),
'kaldvatna': ('kaldvatn',),
'kaldvatnene': ('kaldvatn',),
'kaldvatnet': ('kaldvatn',),
'kalebass': ('kalebass',),
'kalebassen': ('kalebass',),
'kalebassene': ('kalebass',),
'kalebasser': ('kalebass',),
'kalebasstre': ('kalebasstre',),
'kalebasstrea': ('kalebasstre',),
'kalebasstreet': ('kalebasstre',),
'kalebasstrær': ('kalebasstre',),
'kalebasstrærne': ('kalebasstre',),
'kaledonier': ('kaledonier',),
'kaledoniere': ('kaledonier',),
'kaledonieren': ('kaledonier',),
'kaledonierer': ('kaledonier',),
'kaledonierne': ('kaledonier',),
'kaleidoskop': ('kaleidoskop',),
'kaleidoskopa': ('kaleidoskop',),
'kaleidoskopene': ('kaleidoskop',),
'kaleidoskoper': ('kaleidoskop',),
'kaleidoskopet': ('kaleidoskop',),
'kalendaria': ('kalendarium',),
'kalendariene': ('kalendarium',),
'kalendarier': ('kalendarium',),
'kalendariet': ('kalendarium',),
'kalendarium': ('kalendarium',),
'kalender': ('kalender',),
'kalendere': ('kalender',),
'kalenderen': ('kalender',),
'kalenderer': ('kalender',),
'kalenderne': ('kalender',),
'kalendre': ('kalender',),
'kalendrene': ('kalender',),
'kalendrer': ('kalender',),
'kalenderdag': ('kalenderdag',),
'kalenderdagen': ('kalenderdag',),
'kalenderdagene': ('kalenderdag',),
'kalenderdager': ('kalenderdag',),
'kalendermåned': ('kalendermåned',),
'kalendermåneden': ('kalendermåned',),
'kalendermånedene': ('kalendermåned',),
'kalendermåneder': ('kalendermåned',),
'kalenderstav': ('kalenderstav',),
'kalenderstaven': ('kalenderstav',),
'kalenderstavene': ('kalenderstav',),
'kalenderstaver': ('kalenderstav',),
'kalendertegn': ('kalendertegn',),
'kalendertegna': ('kalendertegn',),
'kalendertegnene': ('kalendertegn',),
'kalendertegnet': ('kalendertegn',),
'kalenderår': ('kalenderår',),
'kalenderåra': ('kalenderår',),
'kalenderårene': ('kalenderår',),
'kalenderåret': ('kalenderår',),
'kalesje': ('kalesje',),
'kalesjen': ('kalesje',),
'kalesjene': ('kalesje',),
'kalesjer': ('kalesje',),
'kalesjevogn': ('kalesjevogn',),
'kalesjevogna': ('kalesjevogn',),
'kalesjevognen': ('kalesjevogn',),
'kalesjevognene': ('kalesjevogn',),
'kalesjevogner': ('kalesjevogn',),
'kali': ('kali',),
'kalia': ('kali',),
'kalien': ('kali',),
'kaliene': ('kali',),
'kalier': ('kali',),
'kaliet': ('kali',),
'kaliber': ('kaliber',),
'kalibere': ('kaliber',),
'kaliberen': ('kaliber',),
'kaliberer': ('kaliber',),
'kaliberet': ('kaliber',),
'kaliberne': ('kaliber',),
'kalibra': ('kaliber',),
'kalibre': ('kaliber',),
'kalibrene': ('kaliber',),
'kalibrer': ('kaliber',),
'kalif': ('kalif',),
'kalifen': ('kalif',),
'kalifene': ('kalif',),
'kalifer': ('kalif',),
'kalifat': ('kalifat',),
'kalifata': ('kalifat',),
'kalifatene': ('kalifat',),
'kalifater': ('kalifat',),
'kalifatet': ('kalifat',),
'kalifornier': ('kalifornier',),
'kaliforniere': ('kalifornier',),
'kalifornieren': ('kalifornier',),
'kalifornierer': ('kalifornier',),
'kalifornierne': ('kalifornier',),
'kaligjødsel': ('kaligjødsel',),
'kaligjødselen': ('kaligjødsel',),
'kaligjødsla': ('kaligjødsel',),
'kaligjødslene': ('kaligjødsel',),
'kaligjødsler': ('kaligjødsel',),
'kaliko': ('kaliko',),
'kalikoa': ('kaliko',),
'kalikoene': ('kaliko',),
'kalikoet': ('kaliko',),
'kalilut': ('kalilut',),
'kaliluta': ('kalilut',),
'kaliluten': ('kalilut',),
'kalilutene': ('kalilut',),
'kaliluter': ('kalilut',),
'kalisalpeter': ('kalisalpeter',),
'kalisalpetere': ('kalisalpeter',),
'kalisalpeteren': ('kalisalpeter',),
'kalisalpeterer': ('kalisalpeter',),
'kalisalpeterne': ('kalisalpeter',),
'kalisalpetre': ('kalisalpeter',),
'kalisalpetrene': ('kalisalpeter',),
'kalisalpetrer': ('kalisalpeter',),
'kalium': ('kalium',),
'kaliuma': ('kalium',),
'kaliumene': ('kalium',),
'kaliumet': ('kalium',),
'kaliumbromid': ('kaliumbromid',),
'kaliumbromida': ('kaliumbromid',),
'kaliumbromidene': ('kaliumbromid',),
'kaliumbromider': ('kaliumbromid',),
'kaliumbromidet': ('kaliumbromid',),
'kaliumgjødsel': ('kaliumgjødsel',),
'kaliumgjødselen': ('kaliumgjødsel',),
'kaliumgjødsla': ('kaliumgjødsel',),
'kaliumgjødslene': ('kaliumgjødsel',),
'kaliumgjødsler': ('kaliumgjødsel',),
'kaliumhydroksid': ('kaliumhydroksid',),
'kaliumhydroksida': ('kaliumhydroksid',),
'kaliumhydroksidene': ('kaliumhydroksid',),
'kaliumhydroksider': ('kaliumhydroksid',),
'kaliumhydroksidet': ('kaliumhydroksid',),
'kaliumkarbonat': ('kaliumkarbonat',),
'kaliumkarbonata': ('kaliumkarbonat',),
'kaliumkarbonatene': ('kaliumkarbonat',),
'kaliumkarbonater': ('kaliumkarbonat',),
'kaliumkarbonatet': ('kaliumkarbonat',),
'kaliumklorid': ('kaliumklorid',),
'kaliumklorida': ('kaliumklorid',),
'kaliumkloridene': ('kaliumklorid',),
'kaliumklorider': ('kaliumklorid',),
'kaliumkloridet': ('kaliumklorid',),
'kaliumnitrat': ('kaliumnitrat',),
'kaliumnitrata': ('kaliumnitrat',),
'kaliumnitratene': ('kaliumnitrat',),
'kaliumnitrater': ('kaliumnitrat',),
'kaliumnitratet': ('kaliumnitrat',),
'kalkalge': ('kalkalge',),
'kalkalgen': ('kalkalge',),
'kalkalgene': ('kalkalge',),
'kalkalger': ('kalkalge',),
'kalkbrenning': ('kalkbrenning',),
'kalkbrenninga': ('kalkbrenning',),
'kalkbrenningen': ('kalkbrenning',),
'kalkbrenningene': ('kalkbrenning',),
'kalkbrenninger': ('kalkbrenning',),
'kalkbrott': ('kalkbrott',),
'kalkbrotta': ('kalkbrott',),
'kalkbrottene': ('kalkbrott',),
'kalkbrottet': ('kalkbrott',),
'kalkbrudd': ('kalkbrudd',),
'kalkbrudda': ('kalkbrudd',),
'kalkbruddene': ('kalkbrudd',),
'kalkbruddet': ('kalkbrudd',),
'kalkerlerret': ('kalkerlerret',),
'kalkerlerreta': ('kalkerlerret',),
'kalkerlerretene': ('kalkerlerret',),
'kalkerlerreter': ('kalkerlerret',),
'kalkerlerretet': ('kalkerlerret',),
'kalkerpapir': ('kalkerpapir',),
'kalkerpapira': ('kalkerpapir',),
'kalkerpapirene': ('kalkerpapir',),
'kalkerpapirer': ('kalkerpapir',),
'kalkerpapiret': ('kalkerpapir',),
'kalkhydrat': ('kalkhydrat',),
'kalkhydrata': ('kalkhydrat',),
'kalkhydratene': ('kalkhydrat',),
'kalkhydrater': ('kalkhydrat',),
'kalkhydratet': ('kalkhydrat',),
'kalkmaleri': ('kalkmaleri',),
'kalkmaleria': ('kalkmaleri',),
'kalkmaleriene': ('kalkmaleri',),
'kalkmalerier': ('kalkmaleri',),
'kalkmaleriet': ('kalkmaleri',),
'kalkmel': ('kalkmel',),
'kalkmela': ('kalkmel',),
'kalkmelene': ('kalkmel',),
'kalkmelet': ('kalkmel',),
'kalkmelk': ('kalkmelk',),
'kalkmelka': ('kalkmelk',),
'kalkmelken': ('kalkmelk',),
'kalkmelkene': ('kalkmelk',),
'kalkmelker': ('kalkmelk',),
'kalkmjøl': ('kalkmjøl',),
'kalkmjøla': ('kalkmjøl',),
'kalkmjølene': ('kalkmjøl',),
'kalkmjølet': ('kalkmjøl',),
'kalkmjølk': ('kalkmjølk',),
'kalkmjølka': ('kalkmjølk',),
'kalkmjølken': ('kalkmjølk',),
'kalkmjølkene': ('kalkmjølk',),
'kalkmjølker': ('kalkmjølk',),
'kalkmørtel': ('kalkmørtel',),
'kalkmørtelen': ('kalkmørtel',),
'kalkmørtlene': ('kalkmørtel',),
'kalkmørtler': ('kalkmørtel',),
'kalkomn': ('kalkomn',),
'kalkomnen': ('kalkomn',),
'kalkomnene': ('kalkomn',),
'kalkomner': ('kalkomn',),
'kalkovn': ('kalkovn',),
'kalkovnen': ('kalkovn',),
'kalkovnene': ('kalkovn',),
'kalkovner': ('kalkovn',),
'kalkpuss': ('kalkpuss',),
'kalkpussen': ('kalkpuss',),
'kalkpussene': ('kalkpuss',),
'kalkpusser': ('kalkpuss',),
'kalksalpeter': ('kalksalpeter',),
'kalksalpetere': ('kalksalpeter',),
'kalksalpeteren': ('kalksalpeter',),
'kalksalpeterer': ('kalksalpeter',),
'kalksalpeterne': ('kalksalpeter',),
'kalksalpetre': ('kalksalpeter',),
'kalksalpetrene': ('kalksalpeter',),
'kalksalpetrer': ('kalksalpeter',),
'kalkspat': ('kalkspat',),
'kalkspaten': ('kalkspat',),
'kalkspatene': ('kalkspat',),
'kalkspater': ('kalkspat',),
'kalkstein': ('kalkstein',),
'kalksteinen': ('kalkstein',),
'kalksteinene': ('kalkstein',),
'kalksteiner': ('kalkstein',),
'kalkulasjon': ('kalkulasjon',),
'kalkulasjonen': ('kalkulasjon',),
'kalkulasjonene': ('kalkulasjon',),
'kalkulasjoner': ('kalkulasjon',),
'kalkulator': ('kalkulator',),
'kalkulatoren': ('kalkulator',),
'kalkulatorene': ('kalkulator',),
'kalkulatorer': ('kalkulator',),
'kalkulatør': ('kalkulatør',),
'kalkulatøren': ('kalkulatør',),
'kalkulatørene': ('kalkulatør',),
'kalkulatører': ('kalkulatør',),
'kalkun': ('kalkun',),
'kalkunen': ('kalkun',),
'kalkunene': ('kalkun',),
'kalkuner': ('kalkun',),
'kalkvann': ('kalkvann',),
'kalkvanna': ('kalkvann',),
'kalkvannene': ('kalkvann',),
'kalkvannet': ('kalkvann',),
'kalkvatn': ('kalkvatn',),
'kalkvatna': ('kalkvatn',),
'kalkvatnene': ('kalkvatn',),
'kalkvatnet': ('kalkvatn',),
'kalkverk': ('kalkverk',),
'kalkverka': ('kalkverk',),
'kalkverkene': ('kalkverk',),
'kalkverker': ('kalkverk',),
'kalkverket': ('kalkverk',),
'kalkyle': ('kalkyle',),
'kalkylen': ('kalkyle',),
'kalkylene': ('kalkyle',),
'kalkyler': ('kalkyle',),
'kall': ('kall',),
'kallen': ('kall',),
'kallene': ('kall',),
'kaller': ('kall',),
'kall': ('kall',),
'kalla': ('kall',),
'kallene': ('kall',),
'kallet': ('kall',),
'kallelse': ('kallelse',),
'kallelsen': ('kallelse',),
'kallelsene': ('kallelse',),
'kallelser': ('kallelse',),
'kallenavn': ('kallenavn',),
'kallenavna': ('kallenavn',),
'kallenavnene': ('kallenavn',),
'kallenavnet': ('kallenavn',),
'kallesignal': ('kallesignal',),
'kallesignala': ('kallesignal',),
'kallesignalene': ('kallesignal',),
'kallesignaler': ('kallesignal',),
'kallesignalet': ('kallesignal',),
'kalligraf': ('kalligraf',),
'kalligrafen': ('kalligraf',),
'kalligrafene': ('kalligraf',),
'kalligrafer': ('kalligraf',),
'kalligrafi': ('kalligrafi',),
'kalligrafien': ('kalligrafi',),
'kalligrafiene': ('kalligrafi',),
'kalligrafier': ('kalligrafi',),
'kallipasta': ('kallipasta',),
'kallipastaen': ('kallipasta',),
'kallipastaene': ('kallipasta',),
'kallipastaer': ('kallipasta',),
'kallsbok': ('kallsbok',),
'kallsboka': ('kallsbok',),
'kallsboken': ('kallsbok',),
'kallsbøkene': ('kallsbok',),
'kallsbøker': ('kallsbok',),
'kallsbrev': ('kallsbrev',),
'kallsbreva': ('kallsbrev',),
'kallsbrevene': ('kallsbrev',),
'kallsbrever': ('kallsbrev',),
'kallsbrevet': ('kallsbrev',),
'kallsbror': ('kallsbror',),
'kallsbroren': ('kallsbror',),
'kallsbrødre': ('kallsbror',),
'kallsbrødrene': ('kallsbror',),
'kallskapellan': ('kallskapellan',),
'kallskapellanen': ('kallskapellan',),
'kallskapellanene': ('kallskapellan',),
'kallskapellaner': ('kallskapellan',),
'kallsrett': ('kallsrett',),
'kallsretten': ('kallsrett',),
'kallsrettene': ('kallsrett',),
'kallsretter': ('kallsrett',),
'kallsyrka': ('kallsyrke',),
'kallsyrke': ('kallsyrke',),
'kallsyrkene': ('kallsyrke',),
'kallsyrker': ('kallsyrke',),
'kallsyrket': ('kallsyrke',),
'kalmukk': ('kalmukk',),
'kalmukken': ('kalmukk',),
'kalmukkene': ('kalmukk',),
'kalmukker': ('kalmukk',),
'kalmus': ('kalmus',),
'kalmusen': ('kalmus',),
'kalmusene': ('kalmus',),
'kalmuser': ('kalmus',),
'kalmusolja': ('kalmusolje',),
'kalmusolje': ('kalmusolje',),
'kalmusoljen': ('kalmusolje',),
'kalmusoljene': ('kalmusolje',),
'kalmusoljer': ('kalmusolje',),
'kalmusrot': ('kalmusrot',),
'kalmusrota': ('kalmusrot',),
'kalmusroten': ('kalmusrot',),
'kalmusrøttene': ('kalmusrot',),
'kalmusrøtter': ('kalmusrot',),
'kalori': ('kalori',),
'kalorien': ('kalori',),
'kaloriene': ('kalori',),
'kalorier': ('kalori',),
'kalorimeter': ('kalorimeter',),
'kalorimeteret': ('kalorimeter',),
'kalorimetra': ('kalorimeter',),
'kalorimetre': ('kalorimeter',),
'kalorimetrene': ('kalorimeter',),
'kalorimetret': ('kalorimeter',),
'kaloritabell': ('kaloritabell',),
'kaloritabellen': ('kaloritabell',),
'kaloritabellene': ('kaloritabell',),
'kaloritabeller': ('kaloritabell',),
'kalosje': ('kalosje',),
'kalosjen': ('kalosje',),
'kalosjene': ('kalosje',),
'kalosjer': ('kalosje',),
'kalott': ('kalott',),
'kalotten': ('kalott',),
'kalottene': ('kalott',),
'kalotter': ('kalott',),
'kalsium': ('kalsium',),
'kalsiuma': ('kalsium',),
'kalsiumene': ('kalsium',),
'kalsiumet': ('kalsium',),
'kalsiumhydroksid': ('kalsiumhydroksid',),
'kalsiumhydroksida': ('kalsiumhydroksid',),
'kalsiumhydroksidene': ('kalsiumhydroksid',),
'kalsiumhydroksider': ('kalsiumhydroksid',),
'kalsiumhydroksidet': ('kalsiumhydroksid',),
'kalsiumkarbonat': ('kalsiumkarbonat',),
'kalsiumkarbonata': ('kalsiumkarbonat',),
'kalsiumkarbonatene': ('kalsiumkarbonat',),
'kalsiumkarbonater': ('kalsiumkarbonat',),
'kalsiumkarbonatet': ('kalsiumkarbonat',),
'kalsiumklorid': ('kalsiumklorid',),
'kalsiumklorida': ('kalsiumklorid',),
'kalsiumkloridene': ('kalsiumklorid',),
'kalsiumklorider': ('kalsiumklorid',),
'kalsiumkloridet': ('kalsiumklorid',),
'kalsiumoksid': ('kalsiumoksid',),
'kalsiumoksida': ('kalsiumoksid',),
'kalsiumoksidene': ('kalsiumoksid',),
'kalsiumoksider': ('kalsiumoksid',),
'kalsiumoksidet': ('kalsiumoksid',),
'kaltopp': ('kaltopp',),
'kaltoppen': ('kaltopp',),
'kaltoppene': ('kaltopp',),
'kaltopper': ('kaltopp',),
'kalun': ('kalun',),
'kaluna': ('kalun',),
'kalunene': ('kalun',),
'kaluner': ('kalun',),
'kalunet': ('kalun',),
'kalv': ('kalv',),
'kalven': ('kalv',),
'kalvene': ('kalv',),
'kalver': ('kalv',),
'kalvbot': ('kalvbot',),
'kalvbota': ('kalvbot',),
'kalvboten': ('kalvbot',),
'kalvbøtene': ('kalvbot',),
'kalvbøter': ('kalvbot',),
'kalve': ('kalve',),
'kalven': ('kalve',),
'kalvene': ('kalve',),
'kalver': ('kalve',),
'kalvebrislene': ('kalvebrissel',),
'kalvebrisler': ('kalvebrissel',),
'kalvebrissel': ('kalvebrissel',),
'kalvebrisselen': ('kalvebrissel',),
'kalvedans': ('kalvedans',),
'kalvedansen': ('kalvedans',),
'kalvedansene': ('kalvedans',),
'kalvedanser': ('kalvedans',),
'kalvekasting': ('kalvekasting',),
'kalvekastinga': ('kalvekasting',),
'kalvekastingen': ('kalvekasting',),
'kalvekastingene': ('kalvekasting',),
'kalvekastinger': ('kalvekasting',),
'kalvekryss': ('kalvekryss',),
'kalvekryssa': ('kalvekryss',),
'kalvekryssene': ('kalvekryss',),
'kalvekrysset': ('kalvekryss',),
'kalvingsfeber': ('kalvingsfeber',),
'kalvingsfebere': ('kalvingsfeber',),
'kalvingsfeberen': ('kalvingsfeber',),
'kalvingsfeberne': ('kalvingsfeber',),
'kalvingsfebre': ('kalvingsfeber',),
'kalvingsfebrene': ('kalvingsfeber',),
'kalvingsfebrer': ('kalvingsfeber',),
'kalvinisme': ('kalvinisme',),
'kalvinismen': ('kalvinisme',),
'kalvinismene': ('kalvinisme',),
'kalvinismer': ('kalvinisme',),
'kalvinist': ('kalvinist',),
'kalvinisten': ('kalvinist',),
'kalvinistene': ('kalvinist',),
'kalvinister': ('kalvinist',),
'kalvis': ('kalvis',),
'kalvisen': ('kalvis',),
'kalvisene': ('kalvis',),
'kalviser': ('kalvis',),
'kam': ('kam',),
'kammen': ('kam',),
'kammene': ('kam',),
'kammer': ('kam',),
'kameen': ('kamé',),
'kameene': ('kamé',),
'kameer': ('kamé',),
'kamé': ('kamé',),
'kaméen': ('kamé',),
'kaméene': ('kamé',),
'kaméer': ('kamé',),
'kaménål': ('kaménål',),
'kaménåla': ('kaménål',),
'kaménålen': ('kaménål',),
'kaménålene': ('kaménål',),
'kaménåler': ('kaménål',),
'kamaksel': ('kamaksel',),
'kamakselen': ('kamaksel',),
'kamakslene': ('kamaksel',),
'kamaksler': ('kamaksel',),
'kamarilja': ('kamarilja',),
'kamariljan': ('kamarilja',),
'kamariljane': ('kamarilja',),
'kamariljar': ('kamarilja',),
'kambia': ('kambium',),
'kambiene': ('kambium',),
'kambier': ('kambium',),
'kambiet': ('kambium',),
'kambium': ('kambium',),
'kambodsjaner': ('kambodsjaner',),
'kambodsjanere': ('kambodsjaner',),
'kambodsjaneren': ('kambodsjaner',),
'kambodsjanerer': ('kambodsjaner',),
'kambodsjanerne': ('kambodsjaner',),
'kambrium': ('kambrium',),
'kambriumen': ('kambrium',),
'kambriumene': ('kambrium',),
'kambriumer': ('kambrium',),
'kambriumformasjon': ('kambriumformasjon',),
'kambriumformasjonen': ('kambriumformasjon',),
'kambriumformasjonene': ('kambriumformasjon',),
'kambriumformasjoner': ('kambriumformasjon',),
'kambriumperiode': ('kambriumperiode',),
'kambriumperioden': ('kambriumperiode',),
'kambriumperiodene': ('kambriumperiode',),
'kambriumperioder': ('kambriumperiode',),
'kambriumsystem': ('kambriumsystem',),
'kambriumsystema': ('kambriumsystem',),
'kambriumsystemene': ('kambriumsystem',),
'kambriumsystemer': ('kambriumsystem',),
'kambriumsystemet': ('kambriumsystem',),
'kambrosilur': ('kambrosilur',),
'kambrosiluren': ('kambrosilur',),
'kambrosilurene': ('kambrosilur',),
'kambrosilurer': ('kambrosilur',),
'kamel': ('kamel',),
'kamelen': ('kamel',),
'kamelene': ('kamel',),
'kameler': ('kamel',),
'kameleon': ('kameleon',),
'kameleonen': ('kameleon',),
'kameleonene': ('kameleon',),
'kameleoner': ('kameleon',),
'kamelhår': ('kamelhår',),
'kamelhåra': ('kamelhår',),
'kamelhårene': ('kamelhår',),
'kamelhåret': ('kamelhår',),
'kamelhårsfrakk': ('kamelhårsfrakk',),
'kamelhårsfrakken': ('kamelhårsfrakk',),
'kamelhårsfrakkene': ('kamelhårsfrakk',),
'kamelhårsfrakker': ('kamelhårsfrakk',),
'kamelia': ('kamelia',),
'kameliaen': ('kamelia',),
'kameliaene': ('kamelia',),
'kameliaer': ('kamelia',),
'kameliadama': ('kameliadame',),
'kameliadame': ('kameliadame',),
'kameliadamen': ('kameliadame',),
'kameliadamene': ('kameliadame',),
'kameliadamer': ('kameliadame',),
'kamelott': ('kamelott',),
'kamelotten': ('kamelott',),
'kamelottene': ('kamelott',),
'kamelotter': ('kamelott',),
'kamera': ('kamera',),
'kameraene': ('kamera',),
'kameraer': ('kamera',),
'kameraet': ('kamera',),
'kameraderi': ('kameraderi',),
'kameraderia': ('kameraderi',),
'kameraderiene': ('kameraderi',),
'kameraderier': ('kameraderi',),
'kameraderiet': ('kameraderi',),
'kamerajakt': ('kamerajakt',),
'kamerajakta': ('kamerajakt',),
'kamerajakten': ('kamerajakt',),
'kamerajaktene': ('kamerajakt',),
'kamerajakter': ('kamerajakt',),
'kameraklubb': ('kameraklubb',),
'kameraklubben': ('kameraklubb',),
'kameraklubbene': ('kameraklubb',),
'kameraklubber': ('kameraklubb',),
'kameramann': ('kameramann',),
'kameramannen': ('kameramann',),
'kameramenn': ('kameramann',),
'kameramennene': ('kameramann',),
'kamerat': ('kamerat',),
'kameraten': ('kamerat',),
'kameratene': ('kamerat',),
'kamerater': ('kamerat',),
'kameratbåt': ('kameratbåt',),
'kameratbåten': ('kameratbåt',),
'kameratbåtene': ('kameratbåt',),
'kameratbåter': ('kameratbåt',),
'kameratekteskap': ('kameratekteskap',),
'kameratekteskapa': ('kameratekteskap',),
'kameratekteskapene': ('kameratekteskap',),
'kameratekteskaper': ('kameratekteskap',),
'kameratekteskapet': ('kameratekteskap',),
'kameratskap': ('kameratskap',),
'kameratskapa': ('kameratskap',),
'kameratskapene': ('kameratskap',),
'kameratskapet': ('kameratskap',),
'kameravinkel': ('kameravinkel',),
'kameravinkelen': ('kameravinkel',),
'kameravinklene': ('kameravinkel',),
'kameravinkler': ('kameravinkel',),
'kameruner': ('kameruner',),
'kamerunere': ('kameruner',),
'kameruneren': ('kameruner',),
'kamerunerer': ('kameruner',),
'kamerunerne': ('kameruner',),
'kamfer': ('kamfer',),
'kamfera': ('kamfer',),
'kamfere': ('kamfer',),
'kamferen': ('kamfer',),
'kamferene': ('kamfer',),
'kamferer': ('kamfer',),
'kamferet': ('kamfer',),
'kamferne': ('kamfer',),
'kamfre': ('kamfer',),
'kamfrene': ('kamfer',),
'kamfrer': ('kamfer',),
'kamferdrops': ('kamferdrops',),
'kamferdropsa': ('kamferdrops',),
'kamferdropsen': ('kamferdrops',),
'kamferdropsene': ('kamferdrops',),
'kamferdropset': ('kamferdrops',),
'kamferdråpe': ('kamferdråpe',),
'kamferdråpen': ('kamferdråpe',),
'kamferdråpene': ('kamferdråpe',),
'kamferdråper': ('kamferdråpe',),
'kamferkista': ('kamferkiste',),
'kamferkiste': ('kamferkiste',),
'kamferkisten': ('kamferkiste',),
'kamferkistene': ('kamferkiste',),
'kamferkister': ('kamferkiste',),
'kamferolja': ('kamferolje',),
'kamferolje': ('kamferolje',),
'kamferoljen': ('kamferolje',),
'kamferoljene': ('kamferolje',),
'kamferoljer': ('kamferolje',),
'kamfertrekista': ('kamfertrekiste',),
'kamfertrekiste': ('kamfertrekiste',),
'kamfertrekisten': ('kamfertrekiste',),
'kamfertrekistene': ('kamfertrekiste',),
'kamfertrekister': ('kamfertrekiste',),
'kamfertreskista': ('kamfertreskiste',),
'kamfertreskiste': ('kamfertreskiste',),
'kamfertreskisten': ('kamfertreskiste',),
'kamfertreskistene': ('kamfertreskiste',),
'kamfertreskister': ('kamfertreskiste',),
'kamgarn': ('kamgarn',),
'kamgarna': ('kamgarn',),
'kamgarnene': ('kamgarn',),
'kamgarnet': ('kamgarn',),
'kamgarnsdress': ('kamgarnsdress',),
'kamgarnsdressen': ('kamgarnsdress',),
'kamgarnsdressene': ('kamgarnsdress',),
'kamgarnsdresser': ('kamgarnsdress',),
'kamgarnsstoff': ('kamgarnsstoff',),
'kamgarnsstoffa': ('kamgarnsstoff',),
'kamgarnsstoffene': ('kamgarnsstoff',),
'kamgarnsstoffer': ('kamgarnsstoff',),
'kamgarnsstoffet': ('kamgarnsstoff',),
'kamgras': ('kamgras',),
'kamgrasa': ('kamgras',),
'kamgrasene': ('kamgras',),
'kamgraset': ('kamgras',),
'kamgress': ('kamgress',),
'kamgressa': ('kamgress',),
'kamgressene': ('kamgress',),
'kamgresset': ('kamgress',),
'kamhjul': ('kamhjul',),
'kamhjula': ('kamhjul',),
'kamhjulene': ('kamhjul',),
'kamhjulet': ('kamhjul',),
'kamille': ('kamille',),
'kamillen': ('kamille',),
'kamillene': ('kamille',),
'kamiller': ('kamille',),
'kamilleblomst': ('kamilleblomst',),
'kamilleblomsten': ('kamilleblomst',),
'kamilleblomstene': ('kamilleblomst',),
'kamilleblomster': ('kamilleblomst',),
'kamillete': ('kamillete',),
'kamilleten': ('kamillete',),
'kamilletene': ('kamillete',),
'kamilleter': ('kamillete',),
'kamin': ('kamin',),
'kaminen': ('kamin',),
'kaminene': ('kamin',),
'kaminer': ('kamin',),
'kammer': ('kammer',),
'kammeret': ('kammer',),
'kamra': ('kammer',),
'kamre': ('kammer',),
'kamrene': ('kammer',),
'kammerduk': ('kammerduk',),
'kammerduken': ('kammerduk',),
'kammerdukene': ('kammerduk',),
'kammerduker': ('kammerduk',),
'kammerherre': ('kammerherre',),
'kammerherren': ('kammerherre',),
'kammerherrene': ('kammerherre',),
'kammerherrer': ('kammerherre',),
'kammermusiker': ('kammermusiker',),
'kammermusikere': ('kammermusiker',),
'kammermusikeren': ('kammermusiker',),
'kammermusikerer': ('kammermusiker',),
'kammermusikerne': ('kammermusiker',),
'kammermusikk': ('kammermusikk',),
'kammermusikken': ('kammermusikk',),
'kammermusikkene': ('kammermusikk',),
'kammermusikker': ('kammermusikk',),
'kammers': ('kammers',),
'kammersa': ('kammers',),
'kammersene': ('kammers',),
'kammerser': ('kammers',),
'kammerset': ('kammers',),
'kammertjener': ('kammertjener',),
'kammertjenere': ('kammertjener',),
'kammertjeneren': ('kammertjener',),
'kammertjenerer': ('kammertjener',),
'kammertjenerne': ('kammertjener',),
'kammertone': ('kammertone',),
'kammertonen': ('kammertone',),
'kammertonene': ('kammertone',),
'kammertoner': ('kammertone',),
'kammusling': ('kammusling',),
'kammuslingen': ('kammusling',),
'kammuslingene': ('kammusling',),
'kammuslinger': ('kammusling',),
'kamp': ('kamp',),
'kampen': ('kamp',),
'kampene': ('kamp',),
'kamper': ('kamp',),
'kamp': ('kamp',),
'kampen': ('kamp',),
'kampene': ('kamp',),
'kamper': ('kamp',),
'kampanile': ('kampanile',),
'kampanilen': ('kampanile',),
'kampanilene': ('kampanile',),
'kampaniler': ('kampanile',),
'kampanje': ('kampanje',),
'kampanjen': ('kampanje',),
'kampanjene': ('kampanje',),
'kampanjer': ('kampanje',),
'kampdiktning': ('kampdiktning',),
'kampdiktninga': ('kampdiktning',),
'kampdiktningen': ('kampdiktning',),
'kampdiktningene': ('kampdiktning',),
'kampdiktninger': ('kampdiktning',),
'kampdommer': ('kampdommer',),
'kampdommere': ('kampdommer',),
'kampdommeren': ('kampdommer',),
'kampdommerer': ('kampdommer',),
'kampdommerne': ('kampdommer',),
'kampenhet': ('kampenhet',),
'kampenheten': ('kampenhet',),
'kampenhetene': ('kampenhet',),
'kampenheter': ('kampenhet',),
'kampestein': ('kampestein',),
'kampesteinen': ('kampestein',),
'kampesteinene': ('kampestein',),
'kampesteiner': ('kampestein',),
'kampfelle': ('kampfelle',),
'kampfellen': ('kampfelle',),
'kampfellene': ('kampfelle',),
'kampfeller': ('kampfelle',),
'kampfly': ('kampfly',),
'kampflya': ('kampfly',),
'kampflyene': ('kampfly',),
'kampflyet': ('kampfly',),
'kampflyger': ('kampflyger',),
'kampflygere': ('kampflyger',),
'kampflygeren': ('kampflyger',),
'kampflygerer': ('kampflyger',),
'kampflygerne': ('kampflyger',),
'kampgny': ('kampgny',),
'kampgnya': ('kampgny',),
'kampgnyene': ('kampgny',),
'kampgnyet': ('kampgny',),
'kamphane': ('kamphane',),
'kamphanen': ('kamphane',),
'kamphanene': ('kamphane',),
'kamphaner': ('kamphane',),
'kampleder': ('kampleder',),
'kampledere': ('kampleder',),
'kamplederen': ('kampleder',),
'kamplederer': ('kampleder',),
'kamplederne': ('kampleder',),
'kampmoral': ('kampmoral',),
'kampmoralen': ('kampmoral',),
'kampmoralene': ('kampmoral',),
'kampmoraler': ('kampmoral',),
'kamporganisasjon': ('kamporganisasjon',),
'kamporganisasjonen': ('kamporganisasjon',),
'kamporganisasjonene': ('kamporganisasjon',),
'kamporganisasjoner': ('kamporganisasjon',),
'kampplass': ('kampplass',),
'kampplassen': ('kampplass',),
'kampplassene': ('kampplass',),
'kampplasser': ('kampplass',),
'kamprop': ('kamprop',),
'kampropa': ('kamprop',),
'kampropene': ('kamprop',),
'kampropet': ('kamprop',),
'kamptid': ('kamptid',),
'kamptida': ('kamptid',),
'kamptiden': ('kamptid',),
'kamptidene': ('kamptid',),
'kamptider': ('kamptid',),
'kamptrening': ('kamptrening',),
'kamptreninga': ('kamptrening',),
'kamptreningen': ('kamptrening',),
'kamptreningene': ('kamptrening',),
'kamptreninger': ('kamptrening',),
'kams': ('kams',),
'kamsen': ('kams',),
'kamsene': ('kams',),
'kamser': ('kams',),
'kamshoda': ('kamshode',),
'kamshode': ('kamshode',),
'kamshodene': ('kamshode',),
'kamshoder': ('kamshode',),
'kamshodet': ('kamshode',),
'kamskjell': ('kamskjell',),
'kamskjella': ('kamskjell',),
'kamskjellen': ('kamskjell',),
'kamskjellene': ('kamskjell',),
'kamskjellet': ('kamskjell',),
'kamstål': ('kamstål',),
'kamståla': ('kamstål',),
'kamstålene': ('kamstål',),
'kamstålet': ('kamstål',),
'kamuflasje': ('kamuflasje',),
'kamuflasjen': ('kamuflasje',),
'kamuflasjene': ('kamuflasje',),
'kamuflasjer': ('kamuflasje',),
'kamuflasjedrakt': ('kamuflasjedrakt',),
'kamuflasjedrakta': ('kamuflasjedrakt',),
'kamuflasjedrakten': ('kamuflasjedrakt',),
'kamuflasjedraktene': ('kamuflasjedrakt',),
'kamuflasjedrakter': ('kamuflasjedrakt',),
'kamull': ('kamull',),
'kamulla': ('kamull',),
'kamullen': ('kamull',),
'kamullene': ('kamull',),
'kamuller': ('kamull',),
'kan': ('kan',),
'kanen': ('kan',),
'kanene': ('kan',),
'kaner': ('kan',),
'kan': ('kan',),
'kanen': ('kan',),
'kanene': ('kan',),
'kaner': ('kan',),
'kanaaneer': ('kanaaneer',),
'kanaaneere': ('kanaaneer',),
'kanaaneeren': ('kanaaneer',),
'kanaaneerer': ('kanaaneer',),
'kanaaneerne': ('kanaaneer',),
'kanaanitt': ('kanaanitt',),
'kanaanitten': ('kanaanitt',),
'kanaanittene': ('kanaanitt',),
'kanaanitter': ('kanaanitt',),
'kanadabalsam': ('kanadabalsam',),
'kanadabalsamen': ('kanadabalsam',),
'kanadabalsamene': ('kanadabalsam',),
'kanadabalsamer': ('kanadabalsam',),
'kanadagjess': ('kanadagås',),
'kanadagjessene': ('kanadagås',),
'kanadagjæsene': ('kanadagås',),
'kanadagjæser': ('kanadagås',),
'kanadagås': ('kanadagås',),
'kanadagåsa': ('kanadagås',),
'kanadagåsen': ('kanadagås',),
'kanadier': ('kanadier',),
'kanadiere': ('kanadier',),
'kanadieren': ('kanadier',),
'kanadierer': ('kanadier',),
'kanadierne': ('kanadier',),
'kanak': ('kanak',),
'kanaken': ('kanak',),
'kanakene': ('kanak',),
'kanaker': ('kanak',),
'kanal': ('kanal',),
'kanalen': ('kanal',),
'kanalene': ('kanal',),
'kanaler': ('kanal',),
'kanalje': ('kanalje',),
'kanaljen': ('kanalje',),
'kanaljene': ('kanalje',),
'kanaljer': ('kanalje',),
'kanalsvømmer': ('kanalsvømmer',),
'kanalsvømmere': ('kanalsvømmer',),
'kanalsvømmeren': ('kanalsvømmer',),
'kanalsvømmerer': ('kanalsvømmer',),
'kanalsvømmerne': ('kanalsvømmer',),
'kanalvelger': ('kanalvelger',),
'kanalvelgere': ('kanalvelger',),
'kanalvelgeren': ('kanalvelger',),
'kanalvelgerer': ('kanalvelger',),
'kanalvelgerne': ('kanalvelger',),
'kanapeen': ('kanapé',),
'kanapeene': ('kanapé',),
'kanapeer': ('kanapé',),
'kanapé': ('kanapé',),
'kanapéen': ('kanapé',),
'kanapéene': ('kanapé',),
'kanapéer': ('kanapé',),
'kanari': ('kanari',),
'kanarier': ('kanarier',),
'kanariere': ('kanarier',),
'kanarieren': ('kanarier',),
'kanarierer': ('kanarier',),
'kanarierne': ('kanarier',),
'kanarifugl': ('kanarifugl',),
'kanarifuglen': ('kanarifugl',),
'kanarifuglene': ('kanarifugl',),
'kanarifugler': ('kanarifugl',),
'kanaster': ('kanaster',),
'kanastere': ('kanaster',),
'kanasteren': ('kanaster',),
'kanasterer': ('kanaster',),
'kanasterne': ('kanaster',),
'kanastre': ('kanaster',),
'kanastrene': ('kanaster',),
'kanastrer': ('kanaster',),
'kanat': ('kanat',),
'kanata': ('kanat',),
'kanatene': ('kanat',),
'kanater': ('kanat',),
'kanatet': ('kanat',),
'kanat': ('kanat',),
'kanata': ('kanat',),
'kanatene': ('kanat',),
'kanater': ('kanat',),
'kanatet': ('kanat',),
'kandaharbinding': ('kandaharbinding',),
'kandaharbindinga': ('kandaharbinding',),
'kandaharbindingen': ('kandaharbinding',),
'kandaharbindingene': ('kandaharbinding',),
'kandaharbindinger': ('kandaharbinding',),
'kandelaber': ('kandelaber',),
'kandelabere': ('kandelaber',),
'kandelaberen': ('kandelaber',),
'kandelaberer': ('kandelaber',),
'kandelaberne': ('kandelaber',),
'kandelabre': ('kandelaber',),
'kandelabrene': ('kandelaber',),
'kandelabrer': ('kandelaber',),
'kandidat': ('kandidat',),
'kandidaten': ('kandidat',),
'kandidatene': ('kandidat',),
'kandidater': ('kandidat',),
'kandidattjeneste': ('kandidattjeneste',),
'kandidattjenesten': ('kandidattjeneste',),
'kandidattjenestene': ('kandidattjeneste',),
'kandidattjenester': ('kandidattjeneste',),
'kandidatur': ('kandidatur',),
'kandidatura': ('kandidatur',),
'kandidaturen': ('kandidatur',),
'kandidaturene': ('kandidatur',),
'kandidaturer': ('kandidatur',),
'kandidaturet': ('kandidatur',),
'kandidatår': ('kandidatår',),
'kandidatåra': ('kandidatår',),
'kandidatårene': ('kandidatår',),
'kandidatåret': ('kandidatår',),
'kandis': ('kandis',),
'kandisen': ('kandis',),
'kandisene': ('kandis',),
'kandiser': ('kandis',),
'kandissukker': ('kandissukker',),
'kandissukkera': ('kandissukker',),
'kandissukkere': ('kandissukker',),
'kandissukkerene': ('kandissukker',),
'kandissukkeret': ('kandissukker',),
'kandissukkerne': ('kandissukker',),
'kane': ('kane',),
'kanen': ('kane',),
'kanene': ('kane',),
'kaner': ('kane',),
'kanefart': ('kanefart',),
'kanefarten': ('kanefart',),
'kanefartene': ('kanefart',),
'kanefarter': ('kanefart',),
'kanel': ('kanel',),
'kanelen': ('kanel',),
'kanelene': ('kanel',),
'kaneler': ('kanel',),
'kanelbark': ('kanelbark',),
'kanelbarken': ('kanelbark',),
'kanelbarkene': ('kanelbark',),
'kanelbarker': ('kanelbark',),
'kanelstang': ('kanelstang',),
'kanelstanga': ('kanelstang',),
'kanelstangen': ('kanelstang',),
'kanelstengene': ('kanelstang',),
'kanelstenger': ('kanelstang',),
'kaneltre': ('kaneltre',),
'kaneltrea': ('kaneltre',),
'kaneltreet': ('kaneltre',),
'kaneltrær': ('kaneltre',),
'kaneltrærne': ('kaneltre',),
'kanevas': ('kanevas',),
'kanevasa': ('kanevas',),
'kanevasen': ('kanevas',),
'kanevasene': ('kanevas',),
'kanevaser': ('kanevas',),
'kanevaset': ('kanevas',),
'kanin': ('kanin',),
'kaninen': ('kanin',),
'kaninene': ('kanin',),
'kaniner': ('kanin',),
'kanna': ('kanne',),
'kanne': ('kanne',),
'kannen': ('kanne',),
'kannene': ('kanne',),
'kanner': ('kanne',),
'kannebærer': ('kannebærer',),
'kannebærere': ('kannebærer',),
'kannebæreren': ('kannebærer',),
'kannebærerer': ('kannebærer',),
'kannebærerne': ('kannebærer',),
'kannelyre': ('kannelyre',),
'kannelyren': ('kannelyre',),
'kannelyrene': ('kannelyre',),
'kannelyrer': ('kannelyre',),
'kannestøper': ('kannestøper',),
'kannestøpere': ('kannestøper',),
'kannestøperen': ('kannestøper',),
'kannestøperer': ('kannestøper',),
'kannestøperne': ('kannestøper',),
'kannestøperi': ('kannestøperi',),
'kannestøperia': ('kannestøperi',),
'kannestøperiene': ('kannestøperi',),
'kannestøperier': ('kannestøperi',),
'kannestøperiet': ('kannestøperi',),
'kannestøyper': ('kannestøyper',),
'kannestøypere': ('kannestøyper',),
'kannestøyperen': ('kannestøyper',),
'kannestøyperer': ('kannestøyper',),
'kannestøyperne': ('kannestøyper',),
'kannestøyperi': ('kannestøyperi',),
'kannestøyperia': ('kannestøyperi',),
'kannestøyperiene': ('kannestøyperi',),
'kannestøyperier': ('kannestøyperi',),
'kannestøyperiet': ('kannestøyperi',),
'kannibal': ('kannibal',),
'kannibalen': ('kannibal',),
'kannibalene': ('kannibal',),
'kannibaler': ('kannibal',),
'kannibalisme': ('kannibalisme',),
'kannibalismen': ('kannibalisme',),
'kannibalismene': ('kannibalisme',),
'kannibalismer': ('kannibalisme',),
'kannik': ('kannik',),
'kanniken': ('kannik',),
'kannikene': ('kannik',),
'kanniker': ('kannik',),
'kano': ('kano',),
'kanoen': ('kano',),
'kanoene': ('kano',),
'kanoer': ('kano',),
'kanon': ('kanon',),
'kanonen': ('kanon',),
'kanonene': ('kanon',),
'kanoner': ('kanon',),
'kanon': ('kanon',),
'kanonen': ('kanon',),
'kanonene': ('kanon',),
'kanoner': ('kanon',),
'kanoneren': ('kanonér',),
'kanonerene': ('kanonér',),
'kanonerer': ('kanonér',),
'kanonér': ('kanonér',),
'kanonéren': ('kanonér',),
'kanonérene': ('kanonér',),
'kanonérer': ('kanonér',),
'kanonade': ('kanonade',),
'kanonaden': ('kanonade',),
'kanonadene': ('kanonade',),
'kanonader': ('kanonade',),
'kanonball': ('kanonball',),
'kanonballen': ('kanonball',),
'kanonballene': ('kanonball',),
'kanonballer': ('kanonball',),
'kanonbåt': ('kanonbåt',),
'kanonbåten': ('kanonbåt',),
'kanonbåtene': ('kanonbåt',),
'kanonbåter': ('kanonbåt',),
'kanonform': ('kanonform',),
'kanonforma': ('kanonform',),
'kanonformen': ('kanonform',),
'kanonformene': ('kanonform',),
'kanonformer': ('kanonform',),
'kanonfotograf': ('kanonfotograf',),
'kanonfotografen': ('kanonfotograf',),
'kanonfotografene': ('kanonfotograf',),
'kanonfotografer': ('kanonfotograf',),
'kanonføda': ('kanonføde',),
'kanonføde': ('kanonføde',),
'kanonføden': ('kanonføde',),
'kanonfødene': ('kanonføde',),
'kanonføder': ('kanonføde',),
'kanonkula': ('kanonkule',),
'kanonkule': ('kanonkule',),
'kanonkulen': ('kanonkule',),
'kanonkulene': ('kanonkule',),
'kanonkuler': ('kanonkule',),
'kanonlag': ('kanonlag',),
'kanonlaga': ('kanonlag',),
'kanonlagene': ('kanonlag',),
'kanonlaget': ('kanonlag',),
'kanonløp': ('kanonløp',),
'kanonløpa': ('kanonløp',),
'kanonløpene': ('kanonløp',),
'kanonløpet': ('kanonløp',),
'kanonskott': ('kanonskott',),
'kanonskotta': ('kanonskott',),
'kanonskottene': ('kanonskott',),
'kanonskottet': ('kanonskott',),
'kanonskudd': ('kanonskudd',),
'kanonskudda': ('kanonskudd',),
'kanonskuddene': ('kanonskudd',),
'kanonskuddet': ('kanonskudd',),
'kanossagang': ('kanossagang',),
'kanossagangen': ('kanossagang',),
'kanossagangene': ('kanossagang',),
'kanossaganger': ('kanossagang',),
'kanselli': ('kanselli',),
'kansellia': ('kanselli',),
'kanselliene': ('kanselli',),
'kansellier': ('kanselli',),
'kanselliet': ('kanselli',),
'kanselliråd': ('kanselliråd',),
'kanselliråden': ('kanselliråd',),
'kansellirådene': ('kanselliråd',),
'kanselliråder': ('kanselliråd',),
'kansellispråk': ('kansellispråk',),
'kansellispråka': ('kansellispråk',),
'kansellispråkene': ('kansellispråk',),
'kansellispråket': ('kansellispråk',),
'kansellistil': ('kansellistil',),
'kansellistilen': ('kansellistil',),
'kansellistilene': ('kansellistil',),
'kansellistiler': ('kansellistil',),
'kansler': ('kansler',),
'kanslere': ('kansler',),
'kansleren': ('kansler',),
'kanslerer': ('kansler',),
'kanslerne': ('kansler',),
'kantarell': ('kantarell',),
'kantarellen': ('kantarell',),
'kantarellene': ('kantarell',),
'kantareller': ('kantarell',),
'kantate': ('kantate',),
'kantaten': ('kantate',),
'kantatene': ('kantate',),
'kantater': ('kantate',),
'kanteband': ('kanteband',),
'kantebanda': ('kanteband',),
'kantebandene': ('kanteband',),
'kantebandet': ('kanteband',),
'kantebånd': ('kantebånd',),
'kantebånda': ('kantebånd',),
'kantebåndene': ('kantebånd',),
'kantebåndet': ('kantebånd',),
'kantele': ('kantele',),
'kantelen': ('kantele',),
'kantelene': ('kantele',),
'kanteler': ('kantele',),
'kantfil': ('kantfil',),
'kantfila': ('kantfil',),
'kantfilen': ('kantfil',),
'kantfilene': ('kantfil',),
'kantfiler': ('kantfil',),
'kantianer': ('kantianer',),
'kantianere': ('kantianer',),
'kantianeren': ('kantianer',),
'kantianerer': ('kantianer',),
'kantianerne': ('kantianer',),
'kantianisme': ('kantianisme',),
'kantianismen': ('kantianisme',),
'kantianismene': ('kantianisme',),
'kantianismer': ('kantianisme',),
'kantilene': ('kantilene',),
'kantilenen': ('kantilene',),
'kantilenene': ('kantilene',),
'kantilener': ('kantilene',),
'kantina': ('kantine',),
'kantine': ('kantine',),
'kantinen': ('kantine',),
'kantinene': ('kantine',),
'kantiner': ('kantine',),
'kantinekassa': ('kantinekasse',),
'kantinekasse': ('kantinekasse',),
'kantinekassen': ('kantinekasse',),
'kantinekassene': ('kantinekasse',),
'kantinekasser': ('kantinekasse',),
'kantkonvall': ('kantkonvall',),
'kantkonvallen': ('kantkonvall',),
'kantkonvallene': ('kantkonvall',),
'kantkonvaller': ('kantkonvall',),
'kantlyng': ('kantlyng',),
'kantlynga': ('kantlyng',),
'kantlyngen': ('kantlyng',),
'kantlyngene': ('kantlyng',),
'kantlynger': ('kantlyng',),
'kantlynget': ('kantlyng',),
'kanton': ('kanton',),
'kantonen': ('kanton',),
'kantonene': ('kanton',),
'kantoner': ('kanton',),
'kantor': ('kantor',),
'kantoren': ('kantor',),
'kantorene': ('kantor',),
'kantorer': ('kantor',),
'kantspeller': ('kantspeller',),
'kantspellere': ('kantspeller',),
'kantspelleren': ('kantspeller',),
'kantspellerer': ('kantspeller',),
'kantspellerne': ('kantspeller',),
'kantspiller': ('kantspiller',),
'kantspillere': ('kantspiller',),
'kantspilleren': ('kantspiller',),
'kantspillerer': ('kantspiller',),
'kantspillerne': ('kantspiller',),
'kanvas': ('kanvas',),
'kanvasa': ('kanvas',),
'kanvasen': ('kanvas',),
'kanvasene': ('kanvas',),
'kanvaser': ('kanvas',),
'kanvaset': ('kanvas',),
'kanyle': ('kanyle',),
'kanylen': ('kanyle',),
'kanylene': ('kanyle',),
'kanyler': ('kanyle',),
'kaolin': ('kaolin',),
'kaolina': ('kaolin',),
'kaolinene': ('kaolin',),
'kaolinet': ('kaolin',),
'kaolinitt': ('kaolinitt',),
'kaolinitten': ('kaolinitt',),
'kaolinittene': ('kaolinitt',),
'kaolinitter': ('kaolinitt',),
'kaos': ('kaos',),
'kaosa': ('kaos',),
'kaosene': ('kaos',),
'kaoser': ('kaos',),
'kaoset': ('kaos',),
'kapasistans': ('kapasistans',),
'kapasistansen': ('kapasistans',),
'kapasistansene': ('kapasistans',),
'kapasistanser': ('kapasistans',),
'kapasitet': ('kapasitet',),
'kapasiteten': ('kapasitet',),
'kapasitetene': ('kapasitet',),
'kapasiteter': ('kapasitet',),
'kapell': ('kapell',),
'kapella': ('kapell',),
'kapellene': ('kapell',),
'kapeller': ('kapell',),
'kapellet': ('kapell',),
'kapellan': ('kapellan',),
'kapellanen': ('kapellan',),
'kapellanene': ('kapellan',),
'kapellaner': ('kapellan',),
'kapellani': ('kapellani',),
'kapellania': ('kapellani',),
'kapellaniene': ('kapellani',),
'kapellanier': ('kapellani',),
'kapellaniet': ('kapellani',),
'kapellmester': ('kapellmester',),
'kapellmestere': ('kapellmester',),
'kapellmesteren': ('kapellmester',),
'kapellmesterer': ('kapellmester',),
'kapellmesterne': ('kapellmester',),
'kapellmestre': ('kapellmester',),
'kapellmestrene': ('kapellmester',),
'kapellmestrer': ('kapellmester',),
'kaper': ('kaper',),
'kapere': ('kaper',),
'kaperen': ('kaper',),
'kaperer': ('kaper',),
'kaperne': ('kaper',),
'kaperbrev': ('kaperbrev',),
'kaperbreva': ('kaperbrev',),
'kaperbrevene': ('kaperbrev',),
'kaperbrever': ('kaperbrev',),
'kaperbrevet': ('kaperbrev',),
'kaperfart': ('kaperfart',),
'kaperfarten': ('kaperfart',),
'kaperfartene': ('kaperfart',),
'kaperfarter': ('kaperfart',),
'kaperkrig': ('kaperkrig',),
'kaperkrigen': ('kaperkrig',),
'kaperkrigene': ('kaperkrig',),
'kaperkriger': ('kaperkrig',),
'kapers': ('kapers',),
'kapersen': ('kapers',),
'kapersene': ('kapers',),
'kaperser': ('kapers',),
'kapersbusk': ('kapersbusk',),
'kapersbusken': ('kapersbusk',),
'kapersbuskene': ('kapersbusk',),
'kapersbusker': ('kapersbusk',),
'kapillar': ('kapillar',),
'kapillara': ('kapillar',),
'kapillarene': ('kapillar',),
'kapillarer': ('kapillar',),
'kapillaret': ('kapillar',),
'kapillaritet': ('kapillaritet',),
'kapillariteten': ('kapillaritet',),
'kapillaritetene': ('kapillaritet',),
'kapillariteter': ('kapillaritet',),
'kapillarrør': ('kapillarrør',),
'kapillarrøra': ('kapillarrør',),
'kapillarrørene': ('kapillarrør',),
'kapillarrøret': ('kapillarrør',),
'kapillær': ('kapillær',),
'kapillæra': ('kapillær',),
'kapillærene': ('kapillær',),
'kapillærer': ('kapillær',),
'kapillæret': ('kapillær',),
'kapitél': ('kapitél',),
'kapitéla': ('kapitél',),
'kapitélene': ('kapitél',),
'kapitéler': ('kapitél',),
'kapitélet': ('kapitél',),
'kapital': ('kapital',),
'kapitalen': ('kapital',),
'kapitalene': ('kapital',),
'kapitaler': ('kapital',),
'kapitaleksport': ('kapitaleksport',),
'kapitaleksporten': ('kapitaleksport',),
'kapitaleksportene': ('kapitaleksport',),
'kapitaleksporter': ('kapitaleksport',),
'kapitalflukt': ('kapitalflukt',),
'kapitalflukta': ('kapitalflukt',),
'kapitalflukten': ('kapitalflukt',),
'kapitalfluktene': ('kapitalflukt',),
'kapitalflukter': ('kapitalflukt',),
'kapitalisme': ('kapitalisme',),
'kapitalismen': ('kapitalisme',),
'kapitalismene': ('kapitalisme',),
'kapitalismer': ('kapitalisme',),
'kapitalist': ('kapitalist',),
'kapitalisten': ('kapitalist',),
'kapitalistene': ('kapitalist',),
'kapitalister': ('kapitalist',),
'kapitalsynd': ('kapitalsynd',),
'kapitalsynda': ('kapitalsynd',),
'kapitalsynden': ('kapitalsynd',),
'kapitalsyndene': ('kapitalsynd',),
'kapitalsynder': ('kapitalsynd',),
'kapitla': ('kapittel',),
'kapitlene': ('kapittel',),
'kapitler': ('kapittel',),
'kapitlet': ('kapittel',),
'kapittel': ('kapittel',),
'kapittelet': ('kapittel',),
'kapittelsgods': ('kapittelsgods',),
'kapittelsgodsa': ('kapittelsgods',),
'kapittelsgodsene': ('kapittelsgods',),
'kapittelsgodset': ('kapittelsgods',),
'kapittelstav': ('kapittelstav',),
'kapittelstaven': ('kapittelstav',),
'kapittelstavene': ('kapittelstav',),
'kapittelstaver': ('kapittelstav',),
'kapitulasjon': ('kapitulasjon',),
'kapitulasjonen': ('kapitulasjon',),
'kapitulasjonene': ('kapitulasjon',),
'kapitulasjoner': ('kapitulasjon',),
'kaplak': ('kaplak',),
'kaplaken': ('kaplak',),
'kaplakene': ('kaplak',),
'kaplaker': ('kaplak',),
'kapo': ('kapo',),
'kapoen': ('kapo',),
'kapoene': ('kapo',),
'kapoer': ('kapo',),
'kapok': ('kapok',),
'kapoken': ('kapok',),
'kapokene': ('kapok',),
'kapoker': ('kapok',),
'kapoktre': ('kapoktre',),
'kapoktrea': ('kapoktre',),
'kapoktreet': ('kapoktre',),
'kapoktrær': ('kapoktre',),
'kapoktrærne': ('kapoktre',),
'kapokull': ('kapokull',),
'kapokulla': ('kapokull',),
'kapokullen': ('kapokull',),
'kapokullene': ('kapokull',),
'kapokuller': ('kapokull',),
'kapotast': ('kapotast',),
'kapotasten': ('kapotast',),
'kapotastene': ('kapotast',),
'kapotaster': ('kapotast',),
'kapp': ('kapp',),
'kappen': ('kapp',),
'kappene': ('kapp',),
'kapper': ('kapp',),
'kapp': ('kapp',),
'kappa': ('kapp',),
'kappene': ('kapp',),
'kappet': ('kapp',),
'kapp': ('kapp',),
'kappa': ('kappe',),
'kappe': ('kappe',),
'kappen': ('kappe',),
'kappene': ('kappe',),
'kapper': ('kappe',),
'kappedyr': ('kappedyr',),
'kappedyra': ('kappedyr',),
'kappedyrene': ('kappedyr',),
'kappedyret': ('kappedyr',),
'kappestrid': ('kappestrid',),
'kappestriden': ('kappestrid',),
'kappestridene': ('kappestrid',),
'kappestrider': ('kappestrid',),
'kappgang': ('kappgang',),
'kappgangen': ('kappgang',),
'kappgangene': ('kappgang',),
'kappganger': ('kappgang',),
'kappleik': ('kappleik',),
'kappleiken': ('kappleik',),
'kappleikene': ('kappleik',),
'kappleiker': ('kappleik',),
'kappløp': ('kappløp',),
'kappløpa': ('kappløp',),
'kappløpene': ('kappløp',),
'kappløpet': ('kappløp',),
'kappsag': ('kappsag',),
'kappsaga': ('kappsag',),
'kappsagen': ('kappsag',),
'kappsagene': ('kappsag',),
'kappsager': ('kappsag',),
'kappverder': ('kappverder',),
'kappverdere': ('kappverder',),
'kappverderen': ('kappverder',),
'kappverderer': ('kappverder',),
'kappverderne': ('kappverder',),
'kaprer': ('kaprer',),
'kaprere': ('kaprer',),
'kapreren': ('kaprer',),
'kaprerer': ('kaprer',),
'kaprerne': ('kaprer',),
'kaprifol': ('kaprifol',),
'kaprifolen': ('kaprifol',),
'kaprifolene': ('kaprifol',),
'kaprifoler': ('kaprifol',),
'kaprifolfamilie': ('kaprifolfamilie',),
'kaprifolfamilien': ('kaprifolfamilie',),
'kaprifolfamiliene': ('kaprifolfamilie',),
'kaprifolfamilier': ('kaprifolfamilie',),
'kaprifolien': ('kaprifolium',),
'kaprifoliene': ('kaprifolium',),
'kaprifolier': ('kaprifolium',),
'kaprifolium': ('kaprifolium',),
'kaprifoliumen': ('kaprifolium',),
'kaprifoliumfamilie': ('kaprifoliumfamilie',),
'kaprifoliumfamilien': ('kaprifoliumfamilie',),
'kaprifoliumfamiliene': ('kaprifoliumfamilie',),
'kaprifoliumfamilier': ('kaprifoliumfamilie',),
'kapriol': ('kapriol',),
'kapriolen': ('kapriol',),
'kapriolene': ('kapriol',),
'kaprioler': ('kapriol',),
'kaprise': ('kaprise',),
'kaprisen': ('kaprise',),
'kaprisene': ('kaprise',),
'kapriser': ('kaprise',),
'kapsel': ('kapsel',),
'kapselen': ('kapsel',),
'kapslene': ('kapsel',),
'kapsler': ('kapsel',),
'kapselfrukt': ('kapselfrukt',),
'kapselfrukta': ('kapselfrukt',),
'kapselfrukten': ('kapselfrukt',),
'kapselfruktene': ('kapselfrukt',),
'kapselfrukter': ('kapselfrukt',),
'kaptein': ('kaptein',),
'kapteinen': ('kaptein',),
'kapteinene': ('kaptein',),
'kapteiner': ('kaptein',),
'kapteinløytnant': ('kapteinløytnant',),
'kapteinløytnanten': ('kapteinløytnant',),
'kapteinløytnantene': ('kapteinløytnant',),
'kapteinløytnanter': ('kapteinløytnant',),
'kapteinsgard': ('kapteinsgard',),
'kapteinsgarden': ('kapteinsgard',),
'kapteinsgardene': ('kapteinsgard',),
'kapteinsgarder': ('kapteinsgard',),
'kapteinsgård': ('kapteinsgård',),
'kapteinsgården': ('kapteinsgård',),
'kapteinsgårdene': ('kapteinsgård',),
'kapteinsgårder': ('kapteinsgård',),
'kapun': ('kapun',),
'kapunen': ('kapun',),
'kapunene': ('kapun',),
'kapuner': ('kapun',),
'kapusiner': ('kapusiner',),
'kapusinere': ('kapusiner',),
'kapusineren': ('kapusiner',),
'kapusinerer': ('kapusiner',),
'kapusinerne': ('kapusiner',),
'kapusinerapa': ('kapusinerape',),
'kapusinerape': ('kapusinerape',),
'kapusinerapen': ('kapusinerape',),
'kapusinerapene': ('kapusinerape',),
'kapusineraper': ('kapusinerape',),
'kapusinerorden': ('kapusinerorden',),
'kapusinerordenen': ('kapusinerorden',),
'kapusinerordenene': ('kapusinerorden',),
'kapusinerordener': ('kapusinerorden',),
'kar': ('kar',),
'karen': ('kar',),
'karene': ('kar',),
'karer': ('kar',),
'kar': ('kar',),
'kara': ('kar',),
'karene': ('kar',),
'karet': ('kar',),
'karabin': ('karabin',),
'karabinen': ('karabin',),
'karabinene': ('karabin',),
'karabiner': ('karabin',),
'karabiner': ('karabiner',),
'karabinere': ('karabiner',),
'karabineren': ('karabiner',),
'karabinerer': ('karabiner',),
'karabinerne': ('karabiner',),
'karabinier': ('karabinier',),
'karabinieren': ('karabinier',),
'karabinierene': ('karabinier',),
'karabinierer': ('karabinier',),
'karabinkrok': ('karabinkrok',),
'karabinkroken': ('karabinkrok',),
'karabinkrokene': ('karabinkrok',),
'karabinkroker': ('karabinkrok',),
'karaffel': ('karaffel',),
'karaffelen': ('karaffel',),
'karaflene': ('karaffel',),
'karafler': ('karaffel',),
'karakal': ('karakal',),
'karakalen': ('karakal',),
'karakalene': ('karakal',),
'karakaler': ('karakal',),
'karakter': ('karakter',),
'karakteren': ('karakter',),
'karakterene': ('karakter',),
'karakterer': ('karakter',),
'karakteregenskap': ('karakteregenskap',),
'karakteregenskapen': ('karakteregenskap',),
'karakteregenskapene': ('karakteregenskap',),
'karakteregenskaper': ('karakteregenskap',),
'karakteristikk': ('karakteristikk',),
'karakteristikken': ('karakteristikk',),
'karakteristikkene': ('karakteristikk',),
'karakteristikker': ('karakteristikk',),
'karakteristika': ('karakteristikon',),
'karakteristikaene': ('karakteristikon',),
'karakteristikon': ('karakteristikon',),
'karakteristikonet': ('karakteristikon',),
'karakteristika': ('karakteristikum',),
'karakteristikaene': ('karakteristikum',),
'karakteristikum': ('karakteristikum',),
'karakteristikumet': ('karakteristikum',),
'karakterjag': ('karakterjag',),
'karakterjaga': ('karakterjag',),
'karakterjagene': ('karakterjag',),
'karakterjaget': ('karakterjag',),
'karakterrolla': ('karakterrolle',),
'karakterrolle': ('karakterrolle',),
'karakterrollen': ('karakterrolle',),
'karakterrollene': ('karakterrolle',),
'karakterroller': ('karakterrolle',),
'karakterskuespiller': ('karakterskuespiller',),
'karakterskuespillere': ('karakterskuespiller',),
'karakterskuespilleren': ('karakterskuespiller',),
'karakterskuespillerer': ('karakterskuespiller',),
'karakterskuespillerne': ('karakterskuespiller',),
'karakulsau': ('karakulsau',),
'karakulsauen': ('karakulsau',),
'karakulsauene': ('karakulsau',),
'karakulsauer': ('karakulsau',),
'karamell': ('karamell',),
'karamellen': ('karamell',),
'karamellene': ('karamell',),
'karameller': ('karamell',),
'karamellpudding': ('karamellpudding',),
'karamellpuddingen': ('karamellpudding',),
'karamellpuddingene': ('karamellpudding',),
'karamellpuddinger': ('karamellpudding',),
'karantene': ('karantene',),
'karantenen': ('karantene',),
'karantenene': ('karantene',),
'karantener': ('karantene',),
'karaoke': ('karaoke',),
'karaoken': ('karaoke',),
'karaokene': ('karaoke',),
'karaoker': ('karaoke',),
'karat': ('karat',),
'karaten': ('karat',),
'karatene': ('karat',),
'karate': ('karate',),
'karaten': ('karate',),
'karatene': ('karate',),
'karater': ('karate',),
'karateslag': ('karateslag',),
'karateslaga': ('karateslag',),
'karateslagene': ('karateslag',),
'karateslaget': ('karateslag',),
'karavane': ('karavane',),
'karavanen': ('karavane',),
'karavanene': ('karavane',),
'karavaner': ('karavane',),
'karavell': ('karavell',),
'karavellen': ('karavell',),
'karavellene': ('karavell',),
'karaveller': ('karavell',),
'karbamid': ('karbamid',),
'karbamida': ('karbamid',),
'karbamidene': ('karbamid',),
'karbamidet': ('karbamid',),
'karbamidsyra': ('karbamidsyre',),
'karbamidsyre': ('karbamidsyre',),
'karbamidsyren': ('karbamidsyre',),
'karbamidsyrene': ('karbamidsyre',),
'karbamidsyrer': ('karbamidsyre',),
'karbaminsyra': ('karbaminsyre',),
'karbaminsyre': ('karbaminsyre',),
'karbaminsyren': ('karbaminsyre',),
'karbaminsyrene': ('karbaminsyre',),
'karbaminsyrer': ('karbaminsyre',),
'karbid': ('karbid',),
'karbida': ('karbid',),
'karbiden': ('karbid',),
'karbidene': ('karbid',),
'karbider': ('karbid',),
'karbidet': ('karbid',),
'karbidlampa': ('karbidlampe',),
'karbidlampe': ('karbidlampe',),
'karbidlampen': ('karbidlampe',),
'karbidlampene': ('karbidlampe',),
'karbidlamper': ('karbidlampe',),
'karbohydrat': ('karbohydrat',),
'karbohydrata': ('karbohydrat',),
'karbohydratene': ('karbohydrat',),
'karbohydrater': ('karbohydrat',),
'karbohydratet': ('karbohydrat',),
'karboksyl': ('karboksyl',),
'karboksyla': ('karboksyl',),
'karboksylene': ('karboksyl',),
'karboksylet': ('karboksyl',),
'karbol': ('karbol',),
'karbolen': ('karbol',),
'karbolene': ('karbol',),
'karboler': ('karbol',),
'karbolineum': ('karbolineum',),
'karbolineuma': ('karbolineum',),
'karbolineumen': ('karbolineum',),
'karbolineumene': ('karbolineum',),
'karbolineumer': ('karbolineum',),
'karbolineumet': ('karbolineum',),
'karbolsyra': ('karbolsyre',),
'karbolsyre': ('karbolsyre',),
'karbolsyren': ('karbolsyre',),
'karbolsyrene': ('karbolsyre',),
'karbolsyrer': ('karbolsyre',),
'karbolvann': ('karbolvann',),
'karbolvanna': ('karbolvann',),
'karbolvannene': ('karbolvann',),
'karbolvannet': ('karbolvann',),
'karbolvatn': ('karbolvatn',),
'karbolvatna': ('karbolvatn',),
'karbolvatnene': ('karbolvatn',),
'karbolvatnet': ('karbolvatn',),
'karbon': ('karbon',),
'karbon': ('karbon',),
'karbona': ('karbon',),
'karbonene': ('karbon',),
'karboner': ('karbon',),
'karbonet': ('karbon',),
'karbonade': ('karbonade',),
'karbonaden': ('karbonade',),
'karbonadene': ('karbonade',),
'karbonader': ('karbonade',),
'karbonadedeig': ('karbonadedeig',),
'karbonadedeigen': ('karbonadedeig',),
'karbonadedeigene': ('karbonadedeig',),
'karbonadedeiger': ('karbonadedeig',),
'karbonadekaka': ('karbonadekake',),
'karbonadekake': ('karbonadekake',),
'karbonadekaken': ('karbonadekake',),
'karbonadekakene': ('karbonadekake',),
'karbonadekaker': ('karbonadekake',),
'karbonat': ('karbonat',),
'karbonata': ('karbonat',),
'karbonatene': ('karbonat',),
'karbonater': ('karbonat',),
'karbonatet': ('karbonat',),
'karbondioksid': ('karbondioksid',),
'karbondioksida': ('karbondioksid',),
'karbondioksidene': ('karbondioksid',),
'karbondioksider': ('karbondioksid',),
'karbondioksidet': ('karbondioksid',),
'karbondioksidassimilasjon': ('karbondioksidassimilasjon',),
'karbondioksidassimilasjonen': ('karbondioksidassimilasjon',),
'karbondioksidassimilasjonene': ('karbondioksidassimilasjon',),
'karbondioksidassimilasjoner': ('karbondioksidassimilasjon',),
'karbonformasjon': ('karbonformasjon',),
'karbonformasjonen': ('karbonformasjon',),
'karbonformasjonene': ('karbonformasjon',),
'karbonformasjoner': ('karbonformasjon',),
'karbonmonoksid': ('karbonmonoksid',),
'karbonmonoksida': ('karbonmonoksid',),
'karbonmonoksidene': ('karbonmonoksid',),
'karbonmonoksider': ('karbonmonoksid',),
'karbonmonoksidet': ('karbonmonoksid',),
'karbonoksid': ('karbonoksid',),
'karbonoksida': ('karbonoksid',),
'karbonoksidene': ('karbonoksid',),
'karbonoksider': ('karbonoksid',),
'karbonoksidet': ('karbonoksid',),
'karbonpapir': ('karbonpapir',),
'karbonpapira': ('karbonpapir',),
'karbonpapirene': ('karbonpapir',),
'karbonpapirer': ('karbonpapir',),
'karbonpapiret': ('karbonpapir',),
'karbonperiode': ('karbonperiode',),
'karbonperioden': ('karbonperiode',),
'karbonperiodene': ('karbonperiode',),
'karbonperioder': ('karbonperiode',),
'karbonsyra': ('karbonsyre',),
'karbonsyre': ('karbonsyre',),
'karbonsyren': ('karbonsyre',),
'karbonsyrene': ('karbonsyre',),
'karbonsyrer': ('karbonsyre',),
'karbonsystem': ('karbonsystem',),
'karbonsystema': ('karbonsystem',),
'karbonsystemene': ('karbonsystem',),
'karbonsystemer': ('karbonsystem',),
'karbonsystemet': ('karbonsystem',),
'karbonyl': ('karbonyl',),
'karbonyla': ('karbonyl',),
'karbonylene': ('karbonyl',),
'karbonylet': ('karbonyl',),
'karborundum': ('karborundum',),
'karborunduma': ('karborundum',),
'karborundumene': ('karborundum',),
'karborundumet': ('karborundum',),
'karburator': ('karburator',),
'karburatoren': ('karburator',),
'karburatorene': ('karburator',),
'karburatorer': ('karburator',),
'kardang': ('kardang',),
'kardangen': ('kardang',),
'kardangene': ('kardang',),
'kardanger': ('kardang',),
'kardask': ('kardask',),
'kardasken': ('kardask',),
'kardaskene': ('kardask',),
'kardasker': ('kardask',),
'karda': ('karde',),
'karde': ('karde',),
'karden': ('karde',),
'kardene': ('karde',),
'karder': ('karde',),
'kardeborre': ('kardeborre',),
'kardeborren': ('kardeborre',),
'kardeborrene': ('kardeborre',),
'kardeborrer': ('kardeborre',),
'kardemomme': ('kardemomme',),
'kardemommen': ('kardemomme',),
'kardemommene': ('kardemomme',),
'kardemommer': ('kardemomme',),
'kardemommeplanta': ('kardemommeplante',),
'kardemommeplante': ('kardemommeplante',),
'kardemommeplanten': ('kardemommeplante',),
'kardemommeplantene': ('kardemommeplante',),
'kardemommeplanter': ('kardemommeplante',),
'kardesk': ('kardesk',),
'kardesken': ('kardesk',),
'kardeskene': ('kardesk',),
'kardesker': ('kardesk',),
'kardialgi': ('kardialgi',),
'kardialgien': ('kardialgi',),
'kardialgiene': ('kardialgi',),
'kardialgier': ('kardialgi',),
'kardigan': ('kardigan',),
'kardiganen': ('kardigan',),
'kardiganene': ('kardigan',),
'kardiganer': ('kardigan',),
'kardiganjakka': ('kardiganjakke',),
'kardiganjakke': ('kardiganjakke',),
'kardiganjakken': ('kardiganjakke',),
'kardiganjakkene': ('kardiganjakke',),
'kardiganjakker': ('kardiganjakke',),
'kardigansett': ('kardigansett',),
'kardigansetta': ('kardigansett',),
'kardigansettene': ('kardigansett',),
'kardigansettet': ('kardigansett',),
'kardinal': ('kardinal',),
'kardinalen': ('kardinal',),
'kardinalene': ('kardinal',),
'kardinaler': ('kardinal',),
'kardinaldyd': ('kardinaldyd',),
'kardinaldyden': ('kardinaldyd',),
'kardinaldydene': ('kardinaldyd',),
'kardinaldyder': ('kardinaldyd',),
'kardinalfarge': ('kardinalfarge',),
'kardinalfargen': ('kardinalfarge',),
'kardinalfargene': ('kardinalfarge',),
'kardinalfarger': ('kardinalfarge',),
'kardinalfeil': ('kardinalfeil',),
'kardinalfeilen': ('kardinalfeil',),
'kardinalfeilene': ('kardinalfeil',),
'kardinalkollegia': ('kardinalkollegium',),
'kardinalkollegiene': ('kardinalkollegium',),
'kardinalkollegier': ('kardinalkollegium',),
'kardinalkollegiet': ('kardinalkollegium',),
'kardinalkollegium': ('kardinalkollegium',),
'kardinalpunkt': ('kardinalpunkt',),
'kardinalpunkta': ('kardinalpunkt',),
'kardinalpunktene': ('kardinalpunkt',),
'kardinalpunkter': ('kardinalpunkt',),
'kardinalpunktet': ('kardinalpunkt',),
'kardinalvokal': ('kardinalvokal',),
'kardinalvokalen': ('kardinalvokal',),
'kardinalvokalene': ('kardinalvokal',),
'kardinalvokaler': ('kardinalvokal',),
'kardiograf': ('kardiograf',),
'kardiografen': ('kardiograf',),
'kardiografene': ('kardiograf',),
'kardiografer': ('kardiograf',),
'kardiogram': ('kardiogram',),
'kardiogramma': ('kardiogram',),
'kardiogrammene': ('kardiogram',),
'kardiogrammer': ('kardiogram',),
'kardiogrammet': ('kardiogram',),
'kardiologi': ('kardiologi',),
'kardiologien': ('kardiologi',),
'kardiologiene': ('kardiologi',),
'kardiologier': ('kardiologi',),
'kardus': ('kardus',),
'kardusa': ('kardus',),
'kardusen': ('kardus',),
'kardusene': ('kardus',),
'karduser': ('kardus',),
'karduspapir': ('karduspapir',),
'karduspapira': ('karduspapir',),
'karduspapirene': ('karduspapir',),
'karduspapirer': ('karduspapir',),
'karduspapiret': ('karduspapir',),
'kara': ('kare',),
'kare': ('kare',),
'karen': ('kare',),
'karene': ('kare',),
'karer': ('kare',),
'kareler': ('kareler',),
'karelere': ('kareler',),
'kareleren': ('kareler',),
'karelerer': ('kareler',),
'karelerne': ('kareler',),
'karens': ('karens',),
'karensen': ('karens',),
'karensene': ('karens',),
'karenser': ('karens',),
'karensdag': ('karensdag',),
'karensdagen': ('karensdag',),
'karensdagene': ('karensdag',),
'karensdager': ('karensdag',),
'karensforsikring': ('karensforsikring',),
'karensforsikringa': ('karensforsikring',),
'karensforsikringen': ('karensforsikring',),
'karensforsikringene': ('karensforsikring',),
'karensforsikringer': ('karensforsikring',),
'karenstid': ('karenstid',),
'karenstida': ('karenstid',),
'karenstiden': ('karenstid',),
'karenstidene': ('karenstid',),
'karenstider': ('karenstid',),
'karet': ('karet',),
'kareten': ('karet',),
'karetene': ('karet',),
'kareter': ('karet',),
'karfolk': ('karfolk',),
'karfolka': ('karfolk',),
'karfolkene': ('karfolk',),
'karfolket': ('karfolk',),
'karfunkel': ('karfunkel',),
'karfunkelen': ('karfunkel',),
'karfunklene': ('karfunkel',),
'karfunkler': ('karfunkel',),
'kargadør': ('kargadør',),
'kargadøren': ('kargadør',),
'kargadørene': ('kargadør',),
'kargadører': ('kargadør',),
'kargo': ('kargo',),
'kargoen': ('kargo',),
'kargoene': ('kargo',),
'kargoer': ('kargo',),
'karib': ('karib',),
'kariben': ('karib',),
'karibene': ('karib',),
'kariber': ('karib',),
'karibier': ('karibier',),
'karibiere': ('karibier',),
'karibieren': ('karibier',),
'karibierer': ('karibier',),
'karibierne': ('karibier',),
'karibu': ('karibu',),
'karibuen': ('karibu',),
'karibuene': ('karibu',),
'karibuer': ('karibu',),
'karies': ('karies',),
'kariesen': ('karies',),
'kariesene': ('karies',),
'karieser': ('karies',),
'karikatur': ('karikatur',),
'karikaturen': ('karikatur',),
'karikaturene': ('karikatur',),
'karikaturer': ('karikatur',),
'karikaturtegner': ('karikaturtegner',),
'karikaturtegnere': ('karikaturtegner',),
'karikaturtegneren': ('karikaturtegner',),
'karikaturtegnerer': ('karikaturtegner',),
'karikaturtegnerne': ('karikaturtegner',),
'karikaturtegning': ('karikaturtegning',),
'karikaturtegninga': ('karikaturtegning',),
'karikaturtegningen': ('karikaturtegning',),
'karikaturtegningene': ('karikaturtegning',),
'karikaturtegninger': ('karikaturtegning',),
'karimess': ('karimess',),
'karimess': ('karimess',),
'karimesse': ('karimesse',),
'karisma': ('karisma',),
'karismaen': ('karisma',),
'karismaene': ('karisma',),
'karismaer': ('karisma',),
'karjol': ('karjol',),
'karjolen': ('karjol',),
'karjolene': ('karjol',),
'karjoler': ('karjol',),
'karm': ('karm',),
'karmen': ('karm',),
'karmene': ('karm',),
'karmer': ('karm',),
'karma': ('karma',),
'karmelitt': ('karmelitt',),
'karmelitten': ('karmelitt',),
'karmelittene': ('karmelitt',),
'karmelitter': ('karmelitt',),
'karmelittmunk': ('karmelittmunk',),
'karmelittmunken': ('karmelittmunk',),
'karmelittmunkene': ('karmelittmunk',),
'karmelittmunker': ('karmelittmunk',),
'karmin': ('karmin',),
'karmina': ('karmin',),
'karminen': ('karmin',),
'karminene': ('karmin',),
'karminer': ('karmin',),
'karminet': ('karmin',),
'karminsyra': ('karminsyre',),
'karminsyre': ('karminsyre',),
'karminsyren': ('karminsyre',),
'karminsyrene': ('karminsyre',),
'karminsyrer': ('karminsyre',),
'karmosin': ('karmosin',),
'karmosinen': ('karmosin',),
'karmosinene': ('karmosin',),
'karmosiner': ('karmosin',),
'karnapp': ('karnapp',),
'karnappa': ('karnapp',),
'karnappene': ('karnapp',),
'karnapper': ('karnapp',),
'karnappet': ('karnapp',),
'karneval': ('karneval',),
'karnevala': ('karneval',),
'karnevalene': ('karneval',),
'karnevaler': ('karneval',),
'karnevalet': ('karneval',),
'karnevalsdrakt': ('karnevalsdrakt',),
'karnevalsdrakta': ('karnevalsdrakt',),
'karnevalsdrakten': ('karnevalsdrakt',),
'karnevalsdraktene': ('karnevalsdrakt',),
'karnevalsdrakter': ('karnevalsdrakt',),
'karnevalsopptog': ('karnevalsopptog',),
'karnevalsopptoga': ('karnevalsopptog',),
'karnevalsopptogene': ('karnevalsopptog',),
'karnevalsopptoget': ('karnevalsopptog',),
'karniss': ('karniss',),
'karnissa': ('karniss',),
'karnissene': ('karniss',),
'karnisser': ('karniss',),
'karnisset': ('karniss',),
'karnøffel': ('karnøffel',),
'karnøffelen': ('karnøffel',),
'karnøflene': ('karnøffel',),
'karnøfler': ('karnøffel',),
'karolin': ('karolin',),
'karolinen': ('karolin',),
'karolinene': ('karolin',),
'karoliner': ('karolin',),
'karoliner': ('karoliner',),
'karolinere': ('karoliner',),
'karolineren': ('karoliner',),
'karolinerer': ('karoliner',),
'karolinerne': ('karoliner',),
'karolinger': ('karolinger',),
'karolingeren': ('karolinger',),
'karolingerene': ('karolinger',),
'karolingerer': ('karolinger',),
'karosseri': ('karosseri',),
'karosseria': ('karosseri',),
'karosseriene': ('karosseri',),
'karosserier': ('karosseri',),
'karosseriet': ('karosseri',),
'karosserimaker': ('karosserimaker',),
'karosserimakere': ('karosserimaker',),
'karosserimakeren': ('karosserimaker',),
'karosserimakerer': ('karosserimaker',),
'karosserimakerne': ('karosserimaker',),
'karoten': ('karoten',),
'karotena': ('karoten',),
'karotenene': ('karoten',),
'karotenet': ('karoten',),
'karotenoid': ('karotenoid',),
'karotenoida': ('karotenoid',),
'karotenoidene': ('karotenoid',),
'karotenoider': ('karotenoid',),
'karotenoidet': ('karotenoid',),
'karpe': ('karpe',),
'karpen': ('karpe',),
'karpene': ('karpe',),
'karper': ('karpe',),
'karpefisk': ('karpefisk',),
'karpefisken': ('karpefisk',),
'karpefiskene': ('karpefisk',),
'karpefisker': ('karpefisk',),
'karplanta': ('karplante',),
'karplante': ('karplante',),
'karplanten': ('karplante',),
'karplantene': ('karplante',),
'karplanter': ('karplante',),
'karreen': ('karré',),
'karreene': ('karré',),
'karreer': ('karré',),
'karré': ('karré',),
'karréen': ('karré',),
'karréene': ('karré',),
'karréer': ('karré',),
'karri': ('karri',),
'karrien': ('karri',),
'karriene': ('karri',),
'karrier': ('karri',),
'karriera': ('karriere',),
'karriere': ('karriere',),
'karrieren': ('karriere',),
'karrierene': ('karriere',),
'karrierer': ('karriere',),
'karrierediplomat': ('karrierediplomat',),
'karrierediplomaten': ('karrierediplomat',),
'karrierediplomatene': ('karrierediplomat',),
'karrierediplomater': ('karrierediplomat',),
'karrierejag': ('karrierejag',),
'karrierejaga': ('karrierejag',),
'karrierejagene': ('karrierejag',),
'karrierejaget': ('karrierejag',),
'karrierejeger': ('karrierejeger',),
'karrierejegere': ('karrierejeger',),
'karrierejegeren': ('karrierejeger',),
'karrierejegerer': ('karrierejeger',),
'karrierejegerne': ('karrierejeger',),
'karrierementalitet': ('karrierementalitet',),
'karrierementaliteten': ('karrierementalitet',),
'karrierementalitetene': ('karrierementalitet',),
'karrierementaliteter': ('karrierementalitet',),
'karrieresamfunn': ('karrieresamfunn',),
'karrieresamfunna': ('karrieresamfunn',),
'karrieresamfunnene': ('karrieresamfunn',),
'karrieresamfunnet': ('karrieresamfunn',),
'karrierist': ('karrierist',),
'karrieristen': ('karrierist',),
'karrieristene': ('karrierist',),
'karrierister': ('karrierist',),
'karse': ('karse',),
'karsen': ('karse',),
'karsene': ('karse',),
'karser': ('karse',),
'karsjukdom': ('karsjukdom',),
'karsjukdommen': ('karsjukdom',),
'karsjukdommene': ('karsjukdom',),
'karsjukdommer': ('karsjukdom',),
'karsk': ('karsk',),
'karsken': ('karsk',),
'karskene': ('karsk',),
'karsker': ('karsk',),
'karsporeplanta': ('karsporeplante',),
'karsporeplante': ('karsporeplante',),
'karsporeplanten': ('karsporeplante',),
'karsporeplantene': ('karsporeplante',),
'karsporeplanter': ('karsporeplante',),
'karsstykka': ('karsstykke',),
'karsstykke': ('karsstykke',),
'karsstykkene': ('karsstykke',),
'karsstykker': ('karsstykke',),
'karsstykket': ('karsstykke',),
'karstlandskap': ('karstlandskap',),
'karstlandskapa': ('karstlandskap',),
'karstlandskapene': ('karstlandskap',),
'karstlandskaper': ('karstlandskap',),
'karstlandskapet': ('karstlandskap',),
'karsverk': ('karsverk',),
'karsverka': ('karsverk',),
'karsverkene': ('karsverk',),
'karsverker': ('karsverk',),
'karsverket': ('karsverk',),
'karsykdom': ('karsykdom',),
'karsykdommen': ('karsykdom',),
'karsykdommene': ('karsykdom',),
'karsykdommer': ('karsykdom',),
'kart': ('kart',),
'karten': ('kart',),
'kartene': ('kart',),
'karter': ('kart',),
'kart': ('kart',),
'karta': ('kart',),
'kartene': ('kart',),
'karter': ('kart',),
'kartet': ('kart',),
'kartblad': ('kartblad',),
'kartblada': ('kartblad',),
'kartbladene': ('kartblad',),
'kartblader': ('kartblad',),
'kartbladet': ('kartblad',),
'kartell': ('kartell',),
'kartella': ('kartell',),
'kartellene': ('kartell',),
'karteller': ('kartell',),
'kartellet': ('kartell',),
'kartesianer': ('kartesianer',),
'kartesianere': ('kartesianer',),
'kartesianeren': ('kartesianer',),
'kartesianerer': ('kartesianer',),
'kartesianerne': ('kartesianer',),
'kartleser': ('kartleser',),
'kartlesere': ('kartleser',),
'kartleseren': ('kartleser',),
'kartleserer': ('kartleser',),
'kartleserne': ('kartleser',),
'kartlomma': ('kartlomme',),
'kartlomme': ('kartlomme',),
'kartlommen': ('kartlomme',),
'kartlommene': ('kartlomme',),
'kartlommer': ('kartlomme',),
'kartmappa': ('kartmappe',),
'kartmappe': ('kartmappe',),
'kartmappen': ('kartmappe',),
'kartmappene': ('kartmappe',),
'kartmapper': ('kartmappe',),
'kartograf': ('kartograf',),
'kartografen': ('kartograf',),
'kartografene': ('kartograf',),
'kartografer': ('kartograf',),
'kartografi': ('kartografi',),
'kartografien': ('kartografi',),
'kartografiene': ('kartografi',),
'kartografier': ('kartografi',),
'kartogram': ('kartogram',),
'kartogramma': ('kartogram',),
'kartogrammene': ('kartogram',),
'kartogrammer': ('kartogram',),
'kartogrammet': ('kartogram',),
'kartonasje': ('kartonasje',),
'kartonasjen': ('kartonasje',),
'kartonasjene': ('kartonasje',),
'kartonasjer': ('kartonasje',),
'kartong': ('kartong',),
'kartongen': ('kartong',),
'kartongene': ('kartong',),
'kartonger': ('kartong',),
'kartotek': ('kartotek',),
'kartoteka': ('kartotek',),
'kartotekene': ('kartotek',),
'kartoteker': ('kartotek',),
'kartoteket': ('kartotek',),
'kartotekkort': ('kartotekkort',),
'kartotekkorta': ('kartotekkort',),
'kartotekkortene': ('kartotekkort',),
'kartotekkortet': ('kartotekkort',),
'kartotekskap': ('kartotekskap',),
'kartotekskapa': ('kartotekskap',),
'kartotekskapene': ('kartotekskap',),
'kartotekskapet': ('kartotekskap',),
'kartprojeksjon': ('kartprojeksjon',),
'kartprojeksjonen': ('kartprojeksjon',),
'kartprojeksjonene': ('kartprojeksjon',),
'kartprojeksjoner': ('kartprojeksjon',),
'kartverk': ('kartverk',),
'kartverka': ('kartverk',),
'kartverkene': ('kartverk',),
'kartverker': ('kartverk',),
'kartverket': ('kartverk',),
'karusell': ('karusell',),
'karusellen': ('karusell',),
'karusellene': ('karusell',),
'karuseller': ('karusell',),
'karuss': ('karuss',),
'karussen': ('karuss',),
'karussene': ('karuss',),
'karusser': ('karuss',),
'karve': ('karve',),
'karven': ('karve',),
'karvene': ('karve',),
'karver': ('karve',),
'karve': ('karve',),
'karven': ('karve',),
'karvene': ('karve',),
'karver': ('karve',),
'karveakevitt': ('karveakevitt',),
'karveakevitten': ('karveakevitt',),
'karveakevittene': ('karveakevitt',),
'karveakevitter': ('karveakevitt',),
'karvekål': ('karvekål',),
'karvekålen': ('karvekål',),
'karvekålene': ('karvekål',),
'karvekåler': ('karvekål',),
'karyatide': ('karyatide',),
'karyatiden': ('karyatide',),
'karyatidene': ('karyatide',),
'karyatider': ('karyatide',),
'kas': ('kas',),
'kasa': ('kas',),
'kasen': ('kas',),
'kasene': ('kas',),
'kaser': ('kas',),
'kasakh': ('kasakh',),
'kasakhen': ('kasakh',),
'kasakhene': ('kasakh',),
'kasakher': ('kasakh',),
'kasakher': ('kasakher',),
'kasakhere': ('kasakher',),
'kasakheren': ('kasakher',),
'kasakherer': ('kasakher',),
'kasakherne': ('kasakher',),
'kasakk': ('kasakk',),
'kasakken': ('kasakk',),
'kasakkene': ('kasakk',),
'kasakker': ('kasakk',),
'kasein': ('kasein',),
'kaseina': ('kasein',),
'kaseinene': ('kasein',),
'kaseinet': ('kasein',),
'kasematt': ('kasematt',),
'kasematten': ('kasematt',),
'kasemattene': ('kasematt',),
'kasematter': ('kasematt',),
'kaserna': ('kaserne',),
'kaserne': ('kaserne',),
'kasernen': ('kaserne',),
'kasernene': ('kaserne',),
'kaserner': ('kaserne',),
'kasino': ('kasino',),
'kasinoa': ('kasino',),
'kasinoene': ('kasino',),
'kasinoer': ('kasino',),
'kasinoet': ('kasino',),
'kasjmir': ('kasjmir',),
'kasjmiren': ('kasjmir',),
'kasjmirene': ('kasjmir',),
'kasjmirer': ('kasjmir',),
'kasjmirer': ('kasjmirer',),
'kasjmirere': ('kasjmirer',),
'kasjmireren': ('kasjmirer',),
'kasjmirerer': ('kasjmirer',),
'kasjmirerne': ('kasjmirer',),
'kasjmirgarn': ('kasjmirgarn',),
'kasjmirgarna': ('kasjmirgarn',),
'kasjmirgarnene': ('kasjmirgarn',),
'kasjmirgarnet': ('kasjmirgarn',),
'kasjmirgeit': ('kasjmirgeit',),
'kasjmirgeita': ('kasjmirgeit',),
'kasjmirgeiten': ('kasjmirgeit',),
'kasjmirgeitene': ('kasjmirgeit',),
'kasjmirgeiter': ('kasjmirgeit',),
'kasjmiri': ('kasjmiri',),
'kasjmirien': ('kasjmiri',),
'kasjmiriene': ('kasjmiri',),
'kasjmirier': ('kasjmiri',),
'kasjmirsjal': ('kasjmirsjal',),
'kasjmirsjala': ('kasjmirsjal',),
'kasjmirsjalene': ('kasjmirsjal',),
'kasjmirsjalet': ('kasjmirsjal',),
'kasjmirull': ('kasjmirull',),
'kasjmirulla': ('kasjmirull',),
'kasjmirullen': ('kasjmirull',),
'kasjmirullene': ('kasjmirull',),
'kasjmiruller': ('kasjmirull',),
'kasjott': ('kasjott',),
'kasjotten': ('kasjott',),
'kasjottene': ('kasjott',),
'kasjotter': ('kasjott',),
'kasjunøtt': ('kasjunøtt',),
'kasjunøtta': ('kasjunøtt',),
'kasjunøtten': ('kasjunøtt',),
'kasjunøttene': ('kasjunøtt',),
'kasjunøtter': ('kasjunøtt',),
'kasjutre': ('kasjutre',),
'kasjutrea': ('kasjutre',),
'kasjutreet': ('kasjutre',),
'kasjutrær': ('kasjutre',),
'kasjutrærne': ('kasjutre',),
'kaskade': ('kaskade',),
'kaskaden': ('kaskade',),
'kaskadene': ('kaskade',),
'kaskader': ('kaskade',),
'kaskelott': ('kaskelott',),
'kaskelotten': ('kaskelott',),
'kaskelottene': ('kaskelott',),
'kaskelotter': ('kaskelott',),
'kaskjett': ('kaskjett',),
'kaskjetten': ('kaskjett',),
'kaskjettene': ('kaskjett',),
'kaskjetter': ('kaskjett',),
'kasko': ('kasko',),
'kaskoen': ('kasko',),
'kaskoene': ('kasko',),
'kaskoer': ('kasko',),
'kaskoforsikring': ('kaskoforsikring',),
'kaskoforsikringa': ('kaskoforsikring',),
'kaskoforsikringen': ('kaskoforsikring',),
'kaskoforsikringene': ('kaskoforsikring',),
'kaskoforsikringer': ('kaskoforsikring',),
'kaskopolise': ('kaskopolise',),
'kaskopolisen': ('kaskopolise',),
'kaskopolisene': ('kaskopolise',),
'kaskopoliser': ('kaskopolise',),
'kaskopremie': ('kaskopremie',),
'kaskopremien': ('kaskopremie',),
'kaskopremiene': ('kaskopremie',),
'kaskopremier': ('kaskopremie',),
'kass': ('kass',),
'kassen': ('kass',),
'kassene': ('kass',),
'kasser': ('kass',),
'kassa': ('kassa',),
'kassaen': ('kassa',),
'kassaene': ('kassa',),
'kassaer': ('kassa',),
'kassaapparat': ('kassaapparat',),
'kassaapparata': ('kassaapparat',),
'kassaapparatene': ('kassaapparat',),
'kassaapparater': ('kassaapparat',),
'kassaapparatet': ('kassaapparat',),
'kassadama': ('kassadame',),
'kassadame': ('kassadame',),
'kassadamen': ('kassadame',),
'kassadamene': ('kassadame',),
'kassadamer': ('kassadame',),
'kassakreditt': ('kassakreditt',),
'kassakreditten': ('kassakreditt',),
'kassakredittene': ('kassakreditt',),
'kassakreditter': ('kassakreditt',),
'kassalapp': ('kassalapp',),
'kassalappen': ('kassalapp',),
'kassalappene': ('kassalapp',),
'kassalapper': ('kassalapp',),
'kassamangel': ('kassamangel',),
'kassamangelen': ('kassamangel',),
'kassamanglene': ('kassamangel',),
'kassamangler': ('kassamangel',),
'kassarabatt': ('kassarabatt',),
'kassarabatten': ('kassarabatt',),
'kassarabattene': ('kassarabatt',),
'kassarabatter': ('kassarabatt',),
'kassaregister': ('kassaregister',),
'kassaregisteret': ('kassaregister',),
'kassaregistra': ('kassaregister',),
'kassaregistre': ('kassaregister',),
'kassaregistrene': ('kassaregister',),
'kassaregistret': ('kassaregister',),
'kassasjon': ('kassasjon',),
'kassasjonen': ('kassasjon',),
'kassasjonene': ('kassasjon',),
'kassasjoner': ('kassasjon',),
'kassastykka': ('kassastykke',),
'kassastykke': ('kassastykke',),
'kassastykkene': ('kassastykke',),
'kassastykker': ('kassastykke',),
'kassastykket': ('kassastykke',),
'kassasuksess': ('kassasuksess',),
'kassasuksessen': ('kassasuksess',),
'kassasuksessene': ('kassasuksess',),
'kassasuksesser': ('kassasuksess',),
'kassasvik': ('kassasvik',),
'kassasvika': ('kassasvik',),
'kassasvikene': ('kassasvik',),
'kassasviket': ('kassasvik',),
'kassa': ('kasse',),
'kasse': ('kasse',),
'kassen': ('kasse',),
'kassene': ('kasse',),
'kasser': ('kasse',),
'kasseapparat': ('kasseapparat',),
'kasseapparata': ('kasseapparat',),
'kasseapparatene': ('kasseapparat',),
'kasseapparater': ('kasseapparat',),
'kasseapparatet': ('kasseapparat',),
'kassedama': ('kassedame',),
'kassedame': ('kassedame',),
'kassedamen': ('kassedame',),
'kassedamene': ('kassedame',),
'kassedamer': ('kassedame',),
'kassegitar': ('kassegitar',),
'kassegitaren': ('kassegitar',),
'kassegitarene': ('kassegitar',),
'kassegitarer': ('kassegitar',),
'kassekreditt': ('kassekreditt',),
'kassekreditten': ('kassekreditt',),
'kassekredittene': ('kassekreditt',),
'kassekreditter': ('kassekreditt',),
'kasselapp': ('kasselapp',),
'kasselappen': ('kasselapp',),
'kasselappene': ('kasselapp',),
'kasselapper': ('kasselapp',),
'kassemangel': ('kassemangel',),
'kassemangelen': ('kassemangel',),
'kassemanglene': ('kassemangel',),
'kassemangler': ('kassemangel',),
'kasserabatt': ('kasserabatt',),
'kasserabatten': ('kasserabatt',),
'kasserabattene': ('kasserabatt',),
'kasserabatter': ('kasserabatt',),
'kasseregister': ('kasseregister',),
'kasseregisteret': ('kasseregister',),
'kasseregistra': ('kasseregister',),
'kasseregistre': ('kasseregister',),
'kasseregistrene': ('kasseregister',),
'kasseregistret': ('kasseregister',),
'kasserer': ('kasserer',),
'kasserere': ('kasserer',),
'kassereren': ('kasserer',),
'kassererer': ('kasserer',),
'kassererne': ('kasserer',),
'kasseroll': ('kasseroll',),
'kasserollen': ('kasseroll',),
'kasserollene': ('kasseroll',),
'kasseroller': ('kasseroll',),
'kasserolle': ('kasserolle',),
'kasserollen': ('kasserolle',),
'kasserollene': ('kasserolle',),
'kasseroller': ('kasserolle',),
'kassestykka': ('kassestykke',),
'kassestykke': ('kassestykke',),
'kassestykkene': ('kassestykke',),
'kassestykker': ('kassestykke',),
'kassestykket': ('kassestykke',),
'kassesuksess': ('kassesuksess',),
'kassesuksessen': ('kassesuksess',),
'kassesuksessene': ('kassesuksess',),
'kassesuksesser': ('kassesuksess',),
'kassesvik': ('kassesvik',),
'kassesvika': ('kassesvik',),
'kassesvikene': ('kassesvik',),
'kassesviket': ('kassesvik',),
'kassett': ('kassett',),
'kassetten': ('kassett',),
'kassettene': ('kassett',),
'kassetter': ('kassett',),
'kassettband': ('kassettband',),
'kassettbanda': ('kassettband',),
'kassettbandene': ('kassettband',),
'kassettbandet': ('kassettband',),
'kassettbånd': ('kassettbånd',),
'kassettbånda': ('kassettbånd',),
'kassettbåndene': ('kassettbånd',),
'kassettbåndet': ('kassettbånd',),
'kassettdekk': ('kassettdekk',),
'kassettdekka': ('kassettdekk',),
'kassettdekkene': ('kassettdekk',),
'kassettdekket': ('kassettdekk',),
'kassettprogram': ('kassettprogram',),
'kassettprogramma': ('kassettprogram',),
'kassettprogrammene': ('kassettprogram',),
'kassettprogrammer': ('kassettprogram',),
'kassettprogrammet': ('kassettprogram',),
'kassettspeller': ('kassettspeller',),
'kassettspellere': ('kassettspeller',),
'kassettspelleren': ('kassettspeller',),
'kassettspellerer': ('kassettspeller',),
'kassettspellerne': ('kassettspeller',),
'kassettspiller': ('kassettspiller',),
'kassettspillere': ('kassettspiller',),
'kassettspilleren': ('kassettspiller',),
'kassettspillerer': ('kassettspiller',),
'kassettspillerne': ('kassettspiller',),
'kast': ('kast',),
'kasta': ('kast',),
'kastene': ('kast',),
'kastet': ('kast',),
'kastanje': ('kastanje',),
'kastanjen': ('kastanje',),
'kastanjene': ('kastanje',),
'kastanjer': ('kastanje',),
'kastanjett': ('kastanjett',),
'kastanjetten': ('kastanjett',),
'kastanjettene': ('kastanjett',),
'kastanjetter': ('kastanjett',),
'kaste': ('kaste',),
'kasten': ('kaste',),
'kastene': ('kaste',),
'kaster': ('kaste',),
'kasteball': ('kasteball',),
'kasteballen': ('kasteball',),
'kasteballene': ('kasteball',),
'kasteballer': ('kasteball',),
'kastekalv': ('kastekalv',),
'kastekalven': ('kastekalv',),
'kastekalvene': ('kastekalv',),
'kastekalver': ('kastekalv',),
'kastekjepp': ('kastekjepp',),
'kastekjeppen': ('kastekjepp',),
'kastekjeppene': ('kastekjepp',),
'kastekjepper': ('kastekjepp',),
'kastelag': ('kastelag',),
'kastelaga': ('kastelag',),
'kastelagene': ('kastelag',),
'kastelaget': ('kastelag',),
'kastell': ('kastell',),
'kastella': ('kastell',),
'kastellene': ('kastell',),
'kasteller': ('kastell',),
'kastellet': ('kastell',),
'kastenot': ('kastenot',),
'kastenota': ('kastenot',),
'kastenoten': ('kastenot',),
'kastenøtene': ('kastenot',),
'kastenøter': ('kastenot',),
'kaster': ('kaster',),
'kastere': ('kaster',),
'kasteren': ('kaster',),
'kasterer': ('kaster',),
'kasterne': ('kaster',),
'kasteskyts': ('kasteskyts',),
'kasteskytsa': ('kasteskyts',),
'kasteskytsene': ('kasteskyts',),
'kasteskytset': ('kasteskyts',),
'kastesluk': ('kastesluk',),
'kastesluken': ('kastesluk',),
'kasteslukene': ('kastesluk',),
'kastesluker': ('kastesluk',),
'kastesting': ('kastesting',),
'kastestinga': ('kastesting',),
'kastestingene': ('kastesting',),
'kastestinget': ('kastesting',),
'kastesøm': ('kastesøm',),
'kastesømmen': ('kastesøm',),
'kastesømmene': ('kastesøm',),
'kastesømmer': ('kastesøm',),
'kastetørkle': ('kastetørkle',),
'kastetørkleet': ('kastetørkle',),
'kastetørklær': ('kastetørkle',),
'kastetørklærne': ('kastetørkle',),
'kastevesen': ('kastevesen',),
'kastevesena': ('kastevesen',),
'kastevesenene': ('kastevesen',),
'kastevesener': ('kastevesen',),
'kastevesenet': ('kastevesen',),
'kastevind': ('kastevind',),
'kastevinden': ('kastevind',),
'kastevindene': ('kastevind',),
'kastevinder': ('kastevind',),
'kastevåpen': ('kastevåpen',),
'kastevåpenet': ('kastevåpen',),
'kastevåpna': ('kastevåpen',),
'kastevåpnene': ('kastevåpen',),
'kastiljaner': ('kastiljaner',),
'kastiljanere': ('kastiljaner',),
'kastiljaneren': ('kastiljaner',),
'kastiljanerer': ('kastiljaner',),
'kastiljanerne': ('kastiljaner',),
'kastiljansk': ('kastiljansk',),
'kastiljansken': ('kastiljansk',),
'kastiljanskene': ('kastiljansk',),
'kastiljansker': ('kastiljansk',),
'kastrasjon': ('kastrasjon',),
'kastrasjonen': ('kastrasjon',),
'kastrasjonene': ('kastrasjon',),
'kastrasjoner': ('kastrasjon',),
'kastrat': ('kastrat',),
'kastraten': ('kastrat',),
'kastratene': ('kastrat',),
'kastrater': ('kastrat',),
'kastratsanger': ('kastratsanger',),
'kastratsangere': ('kastratsanger',),
'kastratsangeren': ('kastratsanger',),
'kastratsangerer': ('kastratsanger',),
'kastratsangerne': ('kastratsanger',),
'kasuist': ('kasuist',),
'kasuisten': ('kasuist',),
'kasuistene': ('kasuist',),
'kasuister': ('kasuist',),
'kasuistikk': ('kasuistikk',),
'kasuistikken': ('kasuistikk',),
'kasuistikkene': ('kasuistikk',),
'kasuistikker': ('kasuistikk',),
'kasus': ('kasus',),
'kasusen': ('kasus',),
'kasusene': ('kasus',),
'kasuser': ('kasus',),
'kasus': ('kasus',),
'kasusa': ('kasus',),
'kasusene': ('kasus',),
'kasuset': ('kasus',),
'kasusbøying': ('kasusbøying',),
'kasusbøyinga': ('kasusbøying',),
'kasusbøyingen': ('kasusbøying',),
'kasusbøyingene': ('kasusbøying',),
'kasusbøyinger': ('kasusbøying',),
'kasusbøyning': ('kasusbøyning',),
'kasusbøyninga': ('kasusbøyning',),
'kasusbøyningen': ('kasusbøyning',),
'kasusbøyningene': ('kasusbøyning',),
'kasusbøyninger': ('kasusbøyning',),
'kasusform': ('kasusform',),
'kasusforma': ('kasusform',),
'kasusformen': ('kasusform',),
'kasusformene': ('kasusform',),
'kasusformer': ('kasusform',),
'kasusspråk': ('kasusspråk',),
'kasusspråka': ('kasusspråk',),
'kasusspråkene': ('kasusspråk',),
'kasusspråket': ('kasusspråk',),
'kat': ('kat',),
'katen': ('kat',),
'katene': ('kat',),
'kater': ('kat',),
'katafalk': ('katafalk',),
'katafalken': ('katafalk',),
'katafalkene': ('katafalk',),
'katafalker': ('katafalk',),
'katakombe': ('katakombe',),
'katakomben': ('katakombe',),
'katakombene': ('katakombe',),
'katakomber': ('katakombe',),
'katakrese': ('katakrese',),
'katakresen': ('katakrese',),
'katakresene': ('katakrese',),
'katakreser': ('katakrese',),
'katalaner': ('katalaner',),
'katalanere': ('katalaner',),
'katalaneren': ('katalaner',),
'katalanerer': ('katalaner',),
'katalanerne': ('katalaner',),
'katalansk': ('katalansk',),
'katalansken': ('katalansk',),
'katalanskene': ('katalansk',),
'katalansker': ('katalansk',),
'katalepsi': ('katalepsi',),
'katalepsien': ('katalepsi',),
'katalepsiene': ('katalepsi',),
'katalepsier': ('katalepsi',),
'katalog': ('katalog',),
'katalogen': ('katalog',),
'katalogene': ('katalog',),
'kataloger': ('katalog',),
'katalysator': ('katalysator',),
'katalysatoren': ('katalysator',),
'katalysatorene': ('katalysator',),
'katalysatorer': ('katalysator',),
'katalyse': ('katalyse',),
'katalysen': ('katalyse',),
'katalysene': ('katalyse',),
'katalyser': ('katalyse',),
'katamaran': ('katamaran',),
'katamaranen': ('katamaran',),
'katamaranene': ('katamaran',),
'katamaraner': ('katamaran',),
'katapult': ('katapult',),
'katapulten': ('katapult',),
'katapultene': ('katapult',),
'katapulter': ('katapult',),
'katapultseta': ('katapultsete',),
'katapultsete': ('katapultsete',),
'katapultsetene': ('katapultsete',),
'katapultseter': ('katapultsete',),
'katapultsetet': ('katapultsete',),
'katarakt': ('katarakt',),
'katarakten': ('katarakt',),
'kataraktene': ('katarakt',),
'katarakter': ('katarakt',),
'katarr': ('katarr',),
'katarren': ('katarr',),
'katarrene': ('katarr',),
'katarrer': ('katarr',),
'katarsis': ('katarsis',),
'katarsisen': ('katarsis',),
'katarsisene': ('katarsis',),
'katarsiser': ('katarsis',),
'katastrofa': ('katastrofe',),
'katastrofe': ('katastrofe',),
'katastrofen': ('katastrofe',),
'katastrofene': ('katastrofe',),
'katastrofer': ('katastrofe',),
'katastrofeområda': ('katastrofeområde',),
'katastrofeområde': ('katastrofeområde',),
'katastrofeområdene': ('katastrofeområde',),
'katastrofeområder': ('katastrofeområde',),
'katastrofeområdet': ('katastrofeområde',),
'katastrofeteori': ('katastrofeteori',),
'katastrofeteorien': ('katastrofeteori',),
'katastrofeteoriene': ('katastrofeteori',),
'katastrofeteorier': ('katastrofeteori',),
'katatagma': ('katatagme',),
'katatagme': ('katatagme',),
'katatagmene': ('katatagme',),
'katatagmer': ('katatagme',),
'katatagmet': ('katatagme',),
'katatakse': ('katatakse',),
'katataksen': ('katatakse',),
'katataksene': ('katatakse',),
'katatakser': ('katatakse',),
'katedral': ('katedral',),
'katedralen': ('katedral',),
'katedralene': ('katedral',),
'katedraler': ('katedral',),
'katedralskole': ('katedralskole',),
'katedralskolen': ('katedralskole',),
'katedralskolene': ('katedralskole',),
'katedralskoler': ('katedralskole',),
'kategori': ('kategori',),
'kategorien': ('kategori',),
'kategoriene': ('kategori',),
'kategorier': ('kategori',),
'katekese': ('katekese',),
'katekesen': ('katekese',),
'katekesene': ('katekese',),
'katekeser': ('katekese',),
'kateket': ('kateket',),
'kateketen': ('kateket',),
'kateketene': ('kateket',),
'kateketer': ('kateket',),
'kateketikk': ('kateketikk',),
'kateketikken': ('kateketikk',),
'kateketikkene': ('kateketikk',),
'kateketikker': ('kateketikk',),
'katekisasjon': ('katekisasjon',),
'katekisasjonen': ('katekisasjon',),
'katekisasjonene': ('katekisasjon',),
'katekisasjoner': ('katekisasjon',),
'katekisma': ('katekisme',),
'katekisme': ('katekisme',),
'katekismen': ('katekisme',),
'katekismene': ('katekisme',),
'katekismer': ('katekisme',),
'katekismen': ('katekismus',),
'katekismene': ('katekismus',),
'katekismer': ('katekismus',),
'katekismus': ('katekismus',),
'katekismusen': ('katekismus',),
'kateku': ('kateku',),
'katekuen': ('kateku',),
'katekuene': ('kateku',),
'katekuer': ('kateku',),
'katekumen': ('katekumen',),
'katekumenen': ('katekumen',),
'katekumenene': ('katekumen',),
'katekumener': ('katekumen',),
'katekumenat': ('katekumenat',),
'katekumenata': ('katekumenat',),
'katekumenatene': ('katekumenat',),
'katekumenatet': ('katekumenat',),
'katet': ('katet',),
'kateten': ('katet',),
'katetene': ('katet',),
'kateter': ('katet',),
'kateter': ('kateter',),
'kateteret': ('kateter',),
'katetra': ('kateter',),
'katetre': ('kateter',),
'katetrene': ('kateter',),
'katetret': ('kateter',),
'kateter': ('kateter',),
'kateteret': ('kateter',),
'katetra': ('kateter',),
'katetre': ('kateter',),
'katetrene': ('kateter',),
'katetret': ('kateter',),
'katgut': ('katgut',),
'katguten': ('katgut',),
'katgutene': ('katgut',),
'katguter': ('katgut',),
'kation': ('kation',),
'kationa': ('kation',),
'kationene': ('kation',),
'kationer': ('kation',),
'kationet': ('kation',),
'katode': ('katode',),
'katoden': ('katode',),
'katodene': ('katode',),
'katoder': ('katode',),
'katodestråle': ('katodestråle',),
'katodestrålen': ('katodestråle',),
'katodestrålene': ('katodestråle',),
'katodestråler': ('katodestråle',),
'katodestrålerør': ('katodestrålerør',),
'katodestrålerøra': ('katodestrålerør',),
'katodestrålerørene': ('katodestrålerør',),
'katodestrålerøret': ('katodestrålerør',),
'katolikk': ('katolikk',),
'katolikken': ('katolikk',),
'katolikkene': ('katolikk',),
'katolikker': ('katolikk',),
'katolisisme': ('katolisisme',),
'katolisismen': ('katolisisme',),
'katolisismene': ('katolisisme',),
'katolisismer': ('katolisisme',),
'katt': ('katt',),
'katten': ('katt',),
'kattene': ('katt',),
'katter': ('katt',),
'katta': ('katte',),
'katte': ('katte',),
'katten': ('katte',),
'kattene': ('katte',),
'katter': ('katte',),
'kattebjørn': ('kattebjørn',),
'kattebjørnen': ('kattebjørn',),
'kattebjørnene': ('kattebjørn',),
'kattebjørner': ('kattebjørn',),
'kattedyr': ('kattedyr',),
'kattedyra': ('kattedyr',),
'kattedyrene': ('kattedyr',),
'kattedyret': ('kattedyr',),
'kattefamilie': ('kattefamilie',),
'kattefamilien': ('kattefamilie',),
'kattefamiliene': ('kattefamilie',),
'kattefamilier': ('kattefamilie',),
'kattefot': ('kattefot',),
'kattefoten': ('kattefot',),
'katteføttene': ('kattefot',),
'katteføtter': ('kattefot',),
'kattehale': ('kattehale',),
'kattehalen': ('kattehale',),
'kattehalene': ('kattehale',),
'kattehaler': ('kattehale',),
'kattemusikk': ('kattemusikk',),
'kattemusikken': ('kattemusikk',),
'kattemusikkene': ('kattemusikk',),
'kattemusikker': ('kattemusikk',),
'kattepest': ('kattepest',),
'kattepesta': ('kattepest',),
'kattepesten': ('kattepest',),
'kattepestene': ('kattepest',),
'kattepester': ('kattepest',),
'kattepina': ('kattepine',),
'kattepine': ('kattepine',),
'kattepinen': ('kattepine',),
'kattepinene': ('kattepine',),
'kattepiner': ('kattepine',),
'kattepus': ('kattepus',),
'kattepusen': ('kattepus',),
'kattepusene': ('kattepus',),
'kattepuser': ('kattepus',),
'kattesjuka': ('kattesjuke',),
'kattesjuke': ('kattesjuke',),
'kattesjuken': ('kattesjuke',),
'kattesjukene': ('kattesjuke',),
'kattesjuker': ('kattesjuke',),
'katteslekt': ('katteslekt',),
'katteslekta': ('katteslekt',),
'katteslekten': ('katteslekt',),
'katteslektene': ('katteslekt',),
'katteslekter': ('katteslekt',),
'kattesyka': ('kattesyke',),
'kattesyke': ('kattesyke',),
'kattesyken': ('kattesyke',),
'kattesykene': ('kattesyke',),
'kattesyker': ('kattesyke',),
'kattevask': ('kattevask',),
'kattevasken': ('kattevask',),
'kattevaskene': ('kattevask',),
'kattevasker': ('kattevask',),
'kattost': ('kattost',),
'kattosten': ('kattost',),
'kattostene': ('kattost',),
'kattoster': ('kattost',),
'kattugla': ('kattugle',),
'kattugle': ('kattugle',),
'kattuglen': ('kattugle',),
'kattuglene': ('kattugle',),
'kattugler': ('kattugle',),
'kattun': ('kattun',),
'kattuna': ('kattun',),
'kattunene': ('kattun',),
'kattunet': ('kattun',),
'kattunge': ('kattunge',),
'kattungen': ('kattunge',),
'kattungene': ('kattunge',),
'kattunger': ('kattunge',),
'katzenjammer': ('katzenjammer',),
'katzenjammere': ('katzenjammer',),
'katzenjammeren': ('katzenjammer',),
'katzenjammerer': ('katzenjammer',),
'katzenjammerne': ('katzenjammer',),
'katzenjamrene': ('katzenjammer',),
'katzenjamrer': ('katzenjammer',),
'kaudervelsk': ('kaudervelsk',),
'kaudervelsken': ('kaudervelsk',),
'kaudervelskene': ('kaudervelsk',),
'kaudervelsker': ('kaudervelsk',),
'kaukasier': ('kaukasier',),
'kaukasiere': ('kaukasier',),
'kaukasieren': ('kaukasier',),
'kaukasierer': ('kaukasier',),
'kaukasierne': ('kaukasier',),
'kaup': ('kaup',),
'kaupa': ('kaup',),
'kaupene': ('kaup',),
'kaupet': ('kaup',),
'kaupang': ('kaupang',),
'kaupangen': ('kaupang',),
'kaupangene': ('kaupang',),
'kaupanger': ('kaupang',),
'kausalitet': ('kausalitet',),
'kausaliteten': ('kausalitet',),
'kausalitetene': ('kausalitet',),
'kausaliteter': ('kausalitet',),
'kausallov': ('kausallov',),
'kausalloven': ('kausallov',),
'kausallovene': ('kausallov',),
'kausallover': ('kausallov',),
'kausativ': ('kausativ',),
'kausativa': ('kausativ',),
'kausativene': ('kausativ',),
'kausativer': ('kausativ',),
'kausativet': ('kausativ',),
'kausjon': ('kausjon',),
'kausjonen': ('kausjon',),
'kausjonene': ('kausjon',),
'kausjoner': ('kausjon',),
'kausjonist': ('kausjonist',),
'kausjonisten': ('kausjonist',),
'kausjonistene': ('kausjonist',),
'kausjonister': ('kausjonist',),
'kautel': ('kautel',),
'kautela': ('kautel',),
'kautelen': ('kautel',),
'kautelene': ('kautel',),
'kauteler': ('kautel',),
'kautelet': ('kautel',),
'kautsjuk': ('kautsjuk',),
'kautsjuken': ('kautsjuk',),
'kautsjukene': ('kautsjuk',),
'kautsjuker': ('kautsjuk',),
'kautsjukplanta': ('kautsjukplante',),
'kautsjukplante': ('kautsjukplante',),
'kautsjukplanten': ('kautsjukplante',),
'kautsjukplantene': ('kautsjukplante',),
'kautsjukplanter': ('kautsjukplante',),
'kautsjuktre': ('kautsjuktre',),
'kautsjuktrea': ('kautsjuktre',),
'kautsjuktreet': ('kautsjuktre',),
'kautsjuktrær': ('kautsjuktre',),
'kautsjuktrærne': ('kautsjuktre',),
'kav': ('kav',),
'kava': ('kav',),
'kavene': ('kav',),
'kavet': ('kav',),
'kav': ('kav',),
'kava': ('kav',),
'kavene': ('kav',),
'kavet': ('kav',),
'kav': ('kav',),
'kava': ('kav',),
'kavene': ('kav',),
'kavet': ('kav',),
'kavai': ('kavai',),
'kavaien': ('kavai',),
'kavaiene': ('kavai',),
'kavaier': ('kavai',),
'kavaler': ('kavaler',),
'kavaleren': ('kavaler',),
'kavalerene': ('kavaler',),
'kavalerer': ('kavaler',),
'kavaleri': ('kavaleri',),
'kavaleria': ('kavaleri',),
'kavaleriene': ('kavaleri',),
'kavalerier': ('kavaleri',),
'kavaleriet': ('kavaleri',),
'kavalerisjokk': ('kavalerisjokk',),
'kavalerisjokka': ('kavalerisjokk',),
'kavalerisjokkene': ('kavalerisjokk',),
'kavalerisjokket': ('kavalerisjokk',),
'kavalerist': ('kavalerist',),
'kavaleristen': ('kavalerist',),
'kavaleristene': ('kavalerist',),
'kavalerister': ('kavalerist',),
'kavalett': ('kavalett',),
'kavaletten': ('kavalett',),
'kavalettene': ('kavalett',),
'kavaletter': ('kavalett',),
'kavalkade': ('kavalkade',),
'kavalkaden': ('kavalkade',),
'kavalkadene': ('kavalkade',),
'kavalkader': ('kavalkade',),
'kave': ('kave',),
'kaven': ('kave',),
'kavene': ('kave',),
'kaver': ('kave',),
'kaverne': ('kaverne',),
'kavernen': ('kaverne',),
'kavernene': ('kaverne',),
'kaverner': ('kaverne',),
'kaviar': ('kaviar',),
'kaviaren': ('kaviar',),
'kaviarene': ('kaviar',),
'kaviarer': ('kaviar',),
'kavl': ('kavl',),
'kavlen': ('kavl',),
'kavlene': ('kavl',),
'kavler': ('kavl',),
'kavle': ('kavle',),
'kavlen': ('kavle',),
'kavlene': ('kavle',),
'kavler': ('kavle',),
'kavlebro': ('kavlebro',),
'kavlebroa': ('kavlebro',),
'kavlebroen': ('kavlebro',),
'kavlebroene': ('kavlebro',),
'kavlebroer': ('kavlebro',),
'kavlebru': ('kavlebru',),
'kavlebrua': ('kavlebru',),
'kavlebruen': ('kavlebru',),
'kavlebruene': ('kavlebru',),
'kavlebruer': ('kavlebru',),
'kavring': ('kavring',),
'kavringen': ('kavring',),
'kavringene': ('kavring',),
'kavringer': ('kavring',),
'kebab': ('kebab',),
'kebaben': ('kebab',),
'kebabene': ('kebab',),
'kebaber': ('kebab',),
'kediv': ('kediv',),
'kediven': ('kediv',),
'kedivene': ('kediv',),
'kediver': ('kediv',),
'keeper': ('keeper',),
'keepere': ('keeper',),
'keeperen': ('keeper',),
'keeperer': ('keeper',),
'keeperne': ('keeper',),
'kefir': ('kefir',),
'kefiren': ('kefir',),
'kefirene': ('kefir',),
'kefirer': ('kefir',),
'kefirkorn': ('kefirkorn',),
'kefirkorna': ('kefirkorn',),
'kefirkornene': ('kefirkorn',),
'kefirkornet': ('kefirkorn',),
'kefirmelk': ('kefirmelk',),
'kefirmelka': ('kefirmelk',),
'kefirmelken': ('kefirmelk',),
'kefirmelkene': ('kefirmelk',),
'kefirmelker': ('kefirmelk',),
'kefirmjølk': ('kefirmjølk',),
'kefirmjølka': ('kefirmjølk',),
'kefirmjølken': ('kefirmjølk',),
'kefirmjølkene': ('kefirmjølk',),
'kefirmjølker': ('kefirmjølk',),
'kei': ('kei',),
'keia': ('kei',),
'keiene': ('kei',),
'keiet': ('kei',),
'keik': ('keik',),
'keiken': ('keik',),
'keikene': ('keik',),
'keiker': ('keik',),
'keim': ('keim',),
'keimen': ('keim',),
'keimene': ('keim',),
'keimer': ('keim',),
'keip': ('keip',),
'keipen': ('keip',),
'keipene': ('keip',),
'keiper': ('keip',),
'keipa': ('keipe',),
'keipe': ('keipe',),
'keipen': ('keipe',),
'keipene': ('keipe',),
'keiper': ('keipe',),
'keiser': ('keiser',),
'keisere': ('keiser',),
'keiseren': ('keiser',),
'keiserer': ('keiser',),
'keiserne': ('keiser',),
'keiserdyrkelse': ('keiserdyrkelse',),
'keiserdyrkelsen': ('keiserdyrkelse',),
'keiserdyrkelsene': ('keiserdyrkelse',),
'keiserdyrkelser': ('keiserdyrkelse',),
'keiserdyrking': ('keiserdyrking',),
'keiserdyrkinga': ('keiserdyrking',),
'keiserdyrkingen': ('keiserdyrking',),
'keiserdyrkingene': ('keiserdyrking',),
'keiserdyrkinger': ('keiserdyrking',),
'keiserdømma': ('keiserdømme',),
'keiserdømme': ('keiserdømme',),
'keiserdømmene': ('keiserdømme',),
'keiserdømmer': ('keiserdømme',),
'keiserdømmet': ('keiserdømme',),
'keiserinna': ('keiserinne',),
'keiserinne': ('keiserinne',),
'keiserinnen': ('keiserinne',),
'keiserinnene': ('keiserinne',),
'keiserinner': ('keiserinne',),
'keiserkrona': ('keiserkrone',),
'keiserkrone': ('keiserkrone',),
'keiserkronen': ('keiserkrone',),
'keiserkronene': ('keiserkrone',),
'keiserkroner': ('keiserkrone',),
'keiserpingvin': ('keiserpingvin',),
'keiserpingvinen': ('keiserpingvin',),
'keiserpingvinene': ('keiserpingvin',),
'keiserpingviner': ('keiserpingvin',),
'keiserrika': ('keiserrike',),
'keiserrike': ('keiserrike',),
'keiserrikene': ('keiserrike',),
'keiserriker': ('keiserrike',),
'keiserriket': ('keiserrike',),
'keisersnitt': ('keisersnitt',),
'keisersnitta': ('keisersnitt',),
'keisersnittene': ('keisersnitt',),
'keisersnittet': ('keisersnitt',),
'keiva': ('keive',),
'keive': ('keive',),
'keiven': ('keive',),
'keivene': ('keive',),
'keiver': ('keive',),
'kelner': ('kelner',),
'kelnere': ('kelner',),
'kelneren': ('kelner',),
'kelnerer': ('kelner',),
'kelnerne': ('kelner',),
'kelter': ('kelter',),
'keltere': ('kelter',),
'kelteren': ('kelter',),
'kelterer': ('kelter',),
'kelterne': ('kelter',),
'keltisk': ('keltisk',),
'keltisken': ('keltisk',),
'keltiskene': ('keltisk',),
'keltisker': ('keltisk',),
'kelvin': ('kelvin',),
'kelvinen': ('kelvin',),
'kelvinene': ('kelvin',),
'kelvingrad': ('kelvingrad',),
'kelvingraden': ('kelvingrad',),
'kelvingradene': ('kelvingrad',),
'kelvingrader': ('kelvingrad',),
'kelvinskala': ('kelvinskala',),
'kelvinskalaen': ('kelvinskala',),
'kelvinskalaene': ('kelvinskala',),
'kelvinskalaer': ('kelvinskala',),
'kemner': ('kemner',),
'kemnere': ('kemner',),
'kemneren': ('kemner',),
'kemnerer': ('kemner',),
'kemnerne': ('kemner',),
'kemnerkontor': ('kemnerkontor',),
'kemnerkontora': ('kemnerkontor',),
'kemnerkontorene': ('kemnerkontor',),
'kemnerkontorer': ('kemnerkontor',),
'kemnerkontoret': ('kemnerkontor',),
'kenguru': ('kenguru',),
'kenguruen': ('kenguru',),
'kenguruene': ('kenguru',),
'kenguruer': ('kenguru',),
'kengururotta': ('kengururotte',),
'kengururotte': ('kengururotte',),
'kengururotten': ('kengururotte',),
'kengururottene': ('kengururotte',),
'kengururotter': ('kengururotte',),
'kennel': ('kennel',),
'kennelen': ('kennel',),
'kennelene': ('kennel',),
'kenneler': ('kennel',),
'kennelklubb': ('kennelklubb',),
'kennelklubben': ('kennelklubb',),
'kennelklubbene': ('kennelklubb',),
'kennelklubber': ('kennelklubb',),
'kenning': ('kenning',),
'kenningen': ('kenning',),
'kenningene': ('kenning',),
'kenninger': ('kenning',),
'kenozoikum': ('kenozoikum',),
'kentaur': ('kentaur',),
'kentauren': ('kentaur',),
'kentaurene': ('kentaur',),
'kentaurer': ('kentaur',),
'kentumspråk': ('kentumspråk',),
'kentumspråka': ('kentumspråk',),
'kentumspråkene': ('kentumspråk',),
'kentumspråket': ('kentumspråk',),
'kenyaner': ('kenyaner',),
'kenyanere': ('kenyaner',),
'kenyaneren': ('kenyaner',),
'kenyanerer': ('kenyaner',),
'kenyanerne': ('kenyaner',),
'kepaløk': ('kepaløk',),
'kepaløken': ('kepaløk',),
'kepaløkene': ('kepaløk',),
'kepaløker': ('kepaløk',),
'keram': ('keram',),
'kerama': ('keram',),
'keramene': ('keram',),
'keramet': ('keram',),
'keramiker': ('keramiker',),
'keramikere': ('keramiker',),
'keramikeren': ('keramiker',),
'keramikerer': ('keramiker',),
'keramikerne': ('keramiker',),
'keramikk': ('keramikk',),
'keramikken': ('keramikk',),
'keramikkene': ('keramikk',),
'keramikker': ('keramikk',),
'keratin': ('keratin',),
'keratina': ('keratin',),
'keratinene': ('keratin',),
'keratinet': ('keratin',),
'keratitt': ('keratitt',),
'keratitten': ('keratitt',),
'keratittene': ('keratitt',),
'keratitter': ('keratitt',),
'kermessa': ('kermesse',),
'kermesse': ('kermesse',),
'kermessen': ('kermesse',),
'kermessene': ('kermesse',),
'kermesser': ('kermesse',),
'kerrs pink': ('kerrs pink',),
'ketchup': ('ketchup',),
'ketchupen': ('ketchup',),
'ketchupene': ('ketchup',),
'ketchuper': ('ketchup',),
'khan': ('khan',),
'khanen': ('khan',),
'khanene': ('khan',),
'khaner': ('khan',),
'khan': ('khan',),
'khanen': ('khan',),
'khanene': ('khan',),
'khaner': ('khan',),
'khanat': ('khanat',),
'khanata': ('khanat',),
'khanatene': ('khanat',),
'khanater': ('khanat',),
'khanatet': ('khanat',),
'khanat': ('khanat',),
'khanata': ('khanat',),
'khanatene': ('khanat',),
'khanater': ('khanat',),
'khanatet': ('khanat',),
'khmer': ('khmer',),
'khmeren': ('khmer',),
'khmerene': ('khmer',),
'khmerer': ('khmer',),
'kiasme': ('kiasme',),
'kiasmen': ('kiasme',),
'kiasmene': ('kiasme',),
'kiasmer': ('kiasme',),
'kibb': ('kibb',),
'kibben': ('kibb',),
'kibbene': ('kibb',),
'kibber': ('kibb',),
'kibbutz': ('kibbutz',),
'kibbutzen': ('kibbutz',),
'kibbutzene': ('kibbutz',),
'kibbutzer': ('kibbutz',),
'kick': ('kick',),
'kicken': ('kick',),
'kickene': ('kick',),
'kicker': ('kick',),
'kickstarter': ('kickstarter',),
'kickstartere': ('kickstarter',),
'kickstarteren': ('kickstarter',),
'kickstarterer': ('kickstarter',),
'kickstarterne': ('kickstarter',),
'kidnapper': ('kidnapper',),
'kidnappere': ('kidnapper',),
'kidnapperen': ('kidnapper',),
'kidnapperer': ('kidnapper',),
'kidnapperne': ('kidnapper',),
'kik': ('kik',),
'kiken': ('kik',),
'kikene': ('kik',),
'kiker': ('kik',),
'kik': ('kik',),
'kika': ('kik',),
'kiken': ('kik',),
'kikene': ('kik',),
'kiket': ('kik',),
'kik': ('kik',),
'kika': ('kik',),
'kiken': ('kik',),
'kikene': ('kik',),
'kiket': ('kik',),
'kikador': ('kikador',),
'kikadoren': ('kikador',),
'kikadorene': ('kikador',),
'kikadorer': ('kikador',),
'kikador': ('kikador',),
'kikadoren': ('kikador',),
'kikadorene': ('kikador',),
'kikadorer': ('kikador',),
'kikador': ('kikador',),
'kikadoren': ('kikador',),
'kikadorene': ('kikador',),
'kikadorer': ('kikador',),
'kiker': ('kiker',),
'kikere': ('kiker',),
'kikeren': ('kiker',),
'kikerer': ('kiker',),
'kikerne': ('kiker',),
'kikhol': ('kikhol',),
'kikhola': ('kikhol',),
'kikholene': ('kikhol',),
'kikholet': ('kikhol',),
'kikhoste': ('kikhoste',),
'kikhosten': ('kikhoste',),
'kikhostene': ('kikhoste',),
'kikhoster': ('kikhoste',),
'kikhull': ('kikhull',),
'kikhulla': ('kikhull',),
'kikhullene': ('kikhull',),
'kikhuller': ('kikhull',),
'kikhullet': ('kikhull',),
'kikidor': ('kikidor',),
'kikidoren': ('kikidor',),
'kikidorene': ('kikidor',),
'kikidorer': ('kikidor',),
'kikidor': ('kikidor',),
'kikidoren': ('kikidor',),
'kikidorene': ('kikidor',),
'kikidorer': ('kikidor',),
'kikidor': ('kikidor',),
'kikidoren': ('kikidor',),
'kikidorene': ('kikidor',),
'kikidorer': ('kikidor',),
'kikidorian': ('kikidorian',),
'kikidorianen': ('kikidorian',),
'kikidorianene': ('kikidorian',),
'kikidorianer': ('kikidorian',),
'kikidorian': ('kikidorian',),
'kikidorianen': ('kikidorian',),
'kikidorianene': ('kikidorian',),
'kikidorianer': ('kikidorian',),
'kikk': ('kikk',),
'kikka': ('kikk',),
'kikken': ('kikk',),
'kikkene': ('kikk',),
'kikket': ('kikk',),
'kikkador': ('kikkador',),
'kikkadoren': ('kikkador',),
'kikkadorene': ('kikkador',),
'kikkadorer': ('kikkador',),
'kikkador': ('kikkador',),
'kikkadoren': ('kikkador',),
'kikkadorene': ('kikkador',),
'kikkadorer': ('kikkador',),
'kikkador': ('kikkador',),
'kikkadoren': ('kikkador',),
'kikkadorene': ('kikkador',),
'kikkadorer': ('kikkador',),
'kikker': ('kikker',),
'kikkere': ('kikker',),
'kikkeren': ('kikker',),
'kikkerer': ('kikker',),
'kikkerne': ('kikker',),
'kikkert': ('kikkert',),
'kikkerten': ('kikkert',),
'kikkertene': ('kikkert',),
'kikkerter': ('kikkert',),
'kikkertsikta': ('kikkertsikte',),
'kikkertsikte': ('kikkertsikte',),
'kikkertsiktene': ('kikkertsikte',),
'kikkertsikter': ('kikkertsikte',),
'kikkertsiktet': ('kikkertsikte',),
'kikkertøya': ('kikkertøye',),
'kikkertøye': ('kikkertøye',),
'kikkertøyene': ('kikkertøye',),
'kikkertøyer': ('kikkertøye',),
'kikkertøyet': ('kikkertøye',),
'kikkertøyne': ('kikkertøye',),
'kikkertøynene': ('kikkertøye',),
'kikkhol': ('kikkhol',),
'kikkhola': ('kikkhol',),
'kikkholene': ('kikkhol',),
'kikkholet': ('kikkhol',),
'kikkhull': ('kikkhull',),
'kikkhulla': ('kikkhull',),
'kikkhullene': ('kikkhull',),
'kikkhuller': ('kikkhull',),
'kikkhullet': ('kikkhull',),
'kikkidor': ('kikkidor',),
'kikkidoren': ('kikkidor',),
'kikkidorene': ('kikkidor',),
'kikkidorer': ('kikkidor',),
'kikkidor': ('kikkidor',),
'kikkidoren': ('kikkidor',),
'kikkidorene': ('kikkidor',),
'kikkidorer': ('kikkidor',),
'kikkidor': ('kikkidor',),
'kikkidoren': ('kikkidor',),
'kikkidorene': ('kikkidor',),
'kikkidorer': ('kikkidor',),
'kikkidorian': ('kikkidorian',),
'kikkidorianen': ('kikkidorian',),
'kikkidorianene': ('kikkidorian',),
'kikkidorianer': ('kikkidorian',),
'kikkidorian': ('kikkidorian',),
'kikkidorianen': ('kikkidorian',),
'kikkidorianene': ('kikkidorian',),
'kikkidorianer': ('kikkidorian',),
'kiks': ('kiks',),
'kiksen': ('kiks',),
'kiksene': ('kiks',),
'kikser': ('kiks',),
'kiksekula': ('kiksekule',),
'kiksekule': ('kiksekule',),
'kiksekulen': ('kiksekule',),
'kiksekulene': ('kiksekule',),
'kiksekuler': ('kiksekule',),
'kikuyu': ('kikuyu',),
'kikuyuen': ('kikuyu',),
'kikuyuene': ('kikuyu',),
'kikuyuer': ('kikuyu',),
'kil': ('kil',),
'kilen': ('kil',),
'kilene': ('kil',),
'kiler': ('kil',),
'kilde': ('kilde',),
'kilden': ('kilde',),
'kildene': ('kilde',),
'kilder': ('kilde',),
'kildegransking': ('kildegransking',),
'kildegranskinga': ('kildegransking',),
'kildegranskingen': ('kildegransking',),
'kildegranskingene': ('kildegransking',),
'kildegranskinger': ('kildegransking',),
'kildegras': ('kildegras',),
'kildegrasa': ('kildegras',),
'kildegrasene': ('kildegras',),
'kildegraset': ('kildegras',),
'kildegress': ('kildegress',),
'kildegressa': ('kildegress',),
'kildegressene': ('kildegress',),
'kildegresset': ('kildegress',),
'kildekritikk': ('kildekritikk',),
'kildekritikken': ('kildekritikk',),
'kildekritikkene': ('kildekritikk',),
'kildekritikker': ('kildekritikk',),
'kildeplikt': ('kildeplikt',),
'kildeplikta': ('kildeplikt',),
'kildeplikten': ('kildeplikt',),
'kildepliktene': ('kildeplikt',),
'kildeplikter': ('kildeplikt',),
'kildeskrift': ('kildeskrift',),
'kildeskrifta': ('kildeskrift',),
'kildeskriftene': ('kildeskrift',),
'kildeskrifter': ('kildeskrift',),
'kildeskriftet': ('kildeskrift',),
'kildevann': ('kildevann',),
'kildevanna': ('kildevann',),
'kildevannene': ('kildevann',),
'kildevannet': ('kildevann',),
'kildevatn': ('kildevatn',),
'kildevatna': ('kildevatn',),
'kildevatnene': ('kildevatn',),
'kildevatnet': ('kildevatn',),
'kildrer': ('kildrer',),
'kildrere': ('kildrer',),
'kildreren': ('kildrer',),
'kildrerer': ('kildrer',),
'kildrerne': ('kildrer',),
'kile': ('kile',),
'kilen': ('kile',),
'kilene': ('kile',),
'kiler': ('kile',),
'kilebein': ('kilebein',),
'kilebeina': ('kilebein',),
'kilebeinene': ('kilebein',),
'kilebeinet': ('kilebein',),
'kileben': ('kileben',),
'kilebena': ('kileben',),
'kilebenene': ('kileben',),
'kilebenet': ('kileben',),
'kileben': ('kileben',),
'kilebena': ('kileben',),
'kilebenene': ('kileben',),
'kilebenet': ('kileben',),
'kilenot': ('kilenot',),
'kilenota': ('kilenot',),
'kilenoten': ('kilenot',),
'kilenøtene': ('kilenot',),
'kilenøter': ('kilenot',),
'kiler': ('kiler',),
'kilere': ('kiler',),
'kileren': ('kiler',),
'kilerer': ('kiler',),
'kilerne': ('kiler',),
'kilereim': ('kilereim',),
'kilereima': ('kilereim',),
'kilereimen': ('kilereim',),
'kilereimene': ('kilereim',),
'kilereimer': ('kilereim',),
'kileskrift': ('kileskrift',),
'kileskrifta': ('kileskrift',),
'kileskriften': ('kileskrift',),
'kileskriftene': ('kileskrift',),
'kileskrifter': ('kileskrift',),
'kilevink': ('kilevink',),
'kilevinken': ('kilevink',),
'kilevinkene': ('kilevink',),
'kilevinker': ('kilevink',),
'killing': ('killing',),
'killingen': ('killing',),
'killingene': ('killing',),
'killinger': ('killing',),
'kilo': ('kilo',),
'kiloa': ('kilo',),
'kiloen': ('kilo',),
'kiloene': ('kilo',),
'kiloet': ('kilo',),
'kilobyte': ('kilobyte',),
'kilobyten': ('kilobyte',),
'kilobytene': ('kilobyte',),
'kilocykel': ('kilocykel',),
'kilocykelen': ('kilocykel',),
'kilocyklene': ('kilocykel',),
'kilocykler': ('kilocykel',),
'kilogram': ('kilogram',),
'kilogramma': ('kilogram',),
'kilogrammene': ('kilogram',),
'kilogrammet': ('kilogram',),
'kilohertz': ('kilohertz',),
'kilohertzen': ('kilohertz',),
'kilohertzene': ('kilohertz',),
'kilojoule': ('kilojoule',),
'kilojoulen': ('kilojoule',),
'kilojoulene': ('kilojoule',),
'kilokalori': ('kilokalori',),
'kilokalorien': ('kilokalori',),
'kilokaloriene': ('kilokalori',),
'kilokalorier': ('kilokalori',),
'kilometeravgift': ('kilometeravgift',),
'kilometeravgifta': ('kilometeravgift',),
'kilometeravgiften': ('kilometeravgift',),
'kilometeravgiftene': ('kilometeravgift',),
'kilometeravgifter': ('kilometeravgift',),
'kilometerstand': ('kilometerstand',),
'kilometerstanden': ('kilometerstand',),
'kilometerstandene': ('kilometerstand',),
'kilometerstander': ('kilometerstand',),
'kilometerteller': ('kilometerteller',),
'kilometertellere': ('kilometerteller',),
'kilometertelleren': ('kilometerteller',),
'kilometertellerer': ('kilometerteller',),
'kilometertellerne': ('kilometerteller',),
'kilopond': ('kilopond',),
'kiloponda': ('kilopond',),
'kilopondene': ('kilopond',),
'kilopondet': ('kilopond',),
'kilopondmeter': ('kilopondmeter',),
'kilopondmeteren': ('kilopondmeter',),
'kilopondmeterne': ('kilopondmeter',),
'kilopris': ('kilopris',),
'kiloprisen': ('kilopris',),
'kiloprisene': ('kilopris',),
'kilopriser': ('kilopris',),
'kilorens': ('kilorens',),
'kilorensen': ('kilorens',),
'kilorensene': ('kilorens',),
'kilorenser': ('kilorens',),
'kilotonn': ('kilotonn',),
'kilotonna': ('kilotonn',),
'kilotonnene': ('kilotonn',),
'kilotonnet': ('kilotonn',),
'kilovolt': ('kilovolt',),
'kilovolten': ('kilovolt',),
'kilovoltene': ('kilovolt',),
'kilowatt': ('kilowatt',),
'kilowatten': ('kilowatt',),
'kilowattene': ('kilowatt',),
'kilowatt-time': ('kilowatt-time',),
'kilowatt-timen': ('kilowatt-time',),
'kilowatt-timene': ('kilowatt-time',),
'kilowatt-timer': ('kilowatt-time',),
'kilowattime': ('kilowattime',),
'kilowattimen': ('kilowattime',),
'kilowattimene': ('kilowattime',),
'kilowattimer': ('kilowattime',),
'kilt': ('kilt',),
'kilten': ('kilt',),
'kiltene': ('kilt',),
'kilter': ('kilt',),
'kim': ('kim',),
'kimen': ('kim',),
'kimene': ('kim',),
'kimer': ('kim',),
'kimblad': ('kimblad',),
'kimblada': ('kimblad',),
'kimbladene': ('kimblad',),
'kimblader': ('kimblad',),
'kimbladet': ('kimblad',),
'kimbrer': ('kimbrer',),
'kimbrere': ('kimbrer',),
'kimbreren': ('kimbrer',),
'kimbrerer': ('kimbrer',),
'kimbrerne': ('kimbrer',),
'kimcella': ('kimcelle',),
'kimcelle': ('kimcelle',),
'kimcellen': ('kimcelle',),
'kimcellene': ('kimcelle',),
'kimceller': ('kimcelle',),
'kime': ('kime',),
'kimen': ('kime',),
'kimene': ('kime',),
'kimer': ('kime',),
'kiming': ('kiming',),
'kiminga': ('kiming',),
'kimingen': ('kiming',),
'kimingene': ('kiming',),
'kiminger': ('kiming',),
'kimknopp': ('kimknopp',),
'kimknoppen': ('kimknopp',),
'kimknoppene': ('kimknopp',),
'kimknopper': ('kimknopp',),
'kimming': ('kimming',),
'kimminga': ('kimming',),
'kimmingen': ('kimming',),
'kimmingene': ('kimming',),
'kimminger': ('kimming',),
'kimono': ('kimono',),
'kimonoen': ('kimono',),
'kimonoene': ('kimono',),
'kimonoer': ('kimono',),
'kimplanta': ('kimplante',),
'kimplante': ('kimplante',),
'kimplanten': ('kimplante',),
'kimplantene': ('kimplante',),
'kimplanter': ('kimplante',),
'kimsekk': ('kimsekk',),
'kimsekken': ('kimsekk',),
'kimsekkene': ('kimsekk',),
'kimsekker': ('kimsekk',),
'kimstengel': ('kimstengel',),
'kimstengelen': ('kimstengel',),
'kimstenglene': ('kimstengel',),
'kimstengler': ('kimstengel',),
'kimære': ('kimære',),
'kimæren': ('kimære',),
'kimærene': ('kimære',),
'kimærer': ('kimære',),
'kinabark': ('kinabark',),
'kinabarken': ('kinabark',),
'kinabarkene': ('kinabark',),
'kinabarker': ('kinabark',),
'kinabarktre': ('kinabarktre',),
'kinabarktrea': ('kinabarktre',),
'kinabarktreet': ('kinabarktre',),
'kinabarktrær': ('kinabarktre',),
'kinabarktrærne': ('kinabarktre',),
'kinakål': ('kinakål',),
'kinakålen': ('kinakål',),
'kinakålene': ('kinakål',),
'kinakåler': ('kinakål',),
'kinamann': ('kinamann',),
'kinamannen': ('kinamann',),
'kinamenn': ('kinamann',),
'kinamennene': ('kinamann',),
'kinaputt': ('kinaputt',),
'kinaputten': ('kinaputt',),
'kinaputtene': ('kinaputt',),
'kinaputter': ('kinaputt',),
'kinasjakk': ('kinasjakk',),
'kinasjakken': ('kinasjakk',),
'kinasjakkene': ('kinasjakk',),
'kinasjakker': ('kinasjakk',),
'kinatre': ('kinatre',),
'kinatrea': ('kinatre',),
'kinatreet': ('kinatre',),
'kinatrær': ('kinatre',),
'kinatrærne': ('kinatre',),
'kinematek': ('kinematek',),
'kinemateka': ('kinematek',),
'kinematekene': ('kinematek',),
'kinemateker': ('kinematek',),
'kinemateket': ('kinematek',),
'kinematikk': ('kinematikk',),
'kinematikken': ('kinematikk',),
'kinematikkene': ('kinematikk',),
'kinematikker': ('kinematikk',),
'kinematograf': ('kinematograf',),
'kinematografen': ('kinematograf',),
'kinematografene': ('kinematograf',),
'kinematografer': ('kinematograf',),
'kineser': ('kineser',),
'kinesere': ('kineser',),
'kineseren': ('kineser',),
'kineserer': ('kineser',),
'kineserne': ('kineser',),
'kineseri': ('kineseri',),
'kineseria': ('kineseri',),
'kineseriene': ('kineseri',),
'kineserier': ('kineseri',),
'kineseriet': ('kineseri',),
'kinesiologi': ('kinesiologi',),
'kinesiologien': ('kinesiologi',),
'kinesiologiene': ('kinesiologi',),
'kinesiologier': ('kinesiologi',),
'kinesisk': ('kinesisk',),
'kinesisken': ('kinesisk',),
'kinesiskene': ('kinesisk',),
'kinesisker': ('kinesisk',),
'kinetikk': ('kinetikk',),
'kinetikken': ('kinetikk',),
'kinetikkene': ('kinetikk',),
'kinetikker': ('kinetikk',),
'kingbolt': ('kingbolt',),
'kingbolten': ('kingbolt',),
'kingboltene': ('kingbolt',),
'kingbolter': ('kingbolt',),
'kingel': ('kingel',),
'kingelen': ('kingel',),
'kinglene': ('kingel',),
'kingler': ('kingel',),
'kingelvev': ('kingelvev',),
'kingelveva': ('kingelvev',),
'kingelveven': ('kingelvev',),
'kingelvevene': ('kingelvev',),
'kingelvever': ('kingelvev',),
'kingelvevet': ('kingelvev',),
'kinin': ('kinin',),
'kinina': ('kinin',),
'kininen': ('kinin',),
'kininene': ('kinin',),
'kininer': ('kinin',),
'kininet': ('kinin',),
'kink': ('kink',),
'kinka': ('kink',),
'kinken': ('kink',),
'kinkene': ('kink',),
'kinker': ('kink',),
'kinket': ('kink',),
'kinks': ('kinks',),
'kinksa': ('kinks',),
'kinksen': ('kinks',),
'kinksene': ('kinks',),
'kinkser': ('kinks',),
'kinkset': ('kinks',),
'kinn': ('kinn',),
'kinna': ('kinn',),
'kinnene': ('kinn',),
'kinner': ('kinn',),
'kinnet': ('kinn',),
'kinnbein': ('kinnbein',),
'kinnbeina': ('kinnbein',),
'kinnbeinene': ('kinnbein',),
'kinnbeinet': ('kinnbein',),
'kinnben': ('kinnben',),
'kinnbena': ('kinnben',),
'kinnbenene': ('kinnben',),
'kinnbenet': ('kinnben',),
'kinna': ('kinne',),
'kinne': ('kinne',),
'kinnen': ('kinne',),
'kinnene': ('kinne',),
'kinner': ('kinne',),
'kinnekling': ('kinnekling',),
'kinneklingen': ('kinnekling',),
'kinneklingene': ('kinnekling',),
'kinneklinger': ('kinnekling',),
'kinnemelk': ('kinnemelk',),
'kinnemelka': ('kinnemelk',),
'kinnemelken': ('kinnemelk',),
'kinnemelkene': ('kinnemelk',),
'kinnemelker': ('kinnemelk',),
'kinnemjølk': ('kinnemjølk',),
'kinnemjølka': ('kinnemjølk',),
'kinnemjølken': ('kinnemjølk',),
'kinnemjølkene': ('kinnemjølk',),
'kinnemjølker': ('kinnemjølk',),
'kinnhest': ('kinnhest',),
'kinnhesten': ('kinnhest',),
'kinnhestene': ('kinnhest',),
'kinnhester': ('kinnhest',),
'kinnskjegg': ('kinnskjegg',),
'kinnskjegga': ('kinnskjegg',),
'kinnskjeggene': ('kinnskjegg',),
'kinnskjegget': ('kinnskjegg',),
'kino': ('kino',),
'kinoen': ('kino',),
'kinoene': ('kino',),
'kinoer': ('kino',),
'kinogjenger': ('kinogjenger',),
'kinogjengere': ('kinogjenger',),
'kinogjengeren': ('kinogjenger',),
'kinogjengerer': ('kinogjenger',),
'kinogjengerne': ('kinogjenger',),
'kinoorgel': ('kinoorgel',),
'kinoorgelet': ('kinoorgel',),
'kinoorgla': ('kinoorgel',),
'kinoorglene': ('kinoorgel',),
'kinoorgler': ('kinoorgel',),
'kinoorglet': ('kinoorgel',),
'kinoreklame': ('kinoreklame',),
'kinoreklamen': ('kinoreklame',),
'kinoreklamene': ('kinoreklame',),
'kinoreklamer': ('kinoreklame',),
'kinostykka': ('kinostykke',),
'kinostykke': ('kinostykke',),
'kinostykkene': ('kinostykke',),
'kinostykker': ('kinostykke',),
'kinostykket': ('kinostykke',),
'kinotek': ('kinotek',),
'kinoteka': ('kinotek',),
'kinotekene': ('kinotek',),
'kinoteker': ('kinotek',),
'kinoteket': ('kinotek',),
'kiosk': ('kiosk',),
'kiosken': ('kiosk',),
'kioskene': ('kiosk',),
'kiosker': ('kiosk',),
'kiosklitteratur': ('kiosklitteratur',),
'kiosklitteraturen': ('kiosklitteratur',),
'kiosklitteraturene': ('kiosklitteratur',),
'kiosklitteraturer': ('kiosklitteratur',),
'kipa': ('kipe',),
'kipe': ('kipe',),
'kipen': ('kipe',),
'kipene': ('kipe',),
'kiper': ('kipe',),
'kiper': ('kiper',),
'kipere': ('kiper',),
'kiperen': ('kiper',),
'kiperer': ('kiper',),
'kiperne': ('kiper',),
'kipp': ('kipp',),
'kippa': ('kipp',),
'kippen': ('kipp',),
'kippene': ('kipp',),
'kippet': ('kipp',),
'kippa': ('kippe',),
'kippe': ('kippe',),
'kippene': ('kippe',),
'kipper': ('kippe',),
'kippet': ('kippe',),
'kippers': ('kippers',),
'kippersen': ('kippers',),
'kippersene': ('kippers',),
'kipperser': ('kippers',),
'kippkjøring': ('kippkjøring',),
'kippkjøringa': ('kippkjøring',),
'kippkjøringen': ('kippkjøring',),
'kippkjøringene': ('kippkjøring',),
'kippkjøringer': ('kippkjøring',),
'kirgiser': ('kirgiser',),
'kirgisere': ('kirgiser',),
'kirgiseren': ('kirgiser',),
'kirgiserer': ('kirgiser',),
'kirgiserne': ('kirgiser',),
'kiribatier': ('kiribatier',),
'kiribatiere': ('kiribatier',),
'kiribatieren': ('kiribatier',),
'kiribatierer': ('kiribatier',),
'kiribatierne': ('kiribatier',),
'kirka': ('kirke',),
'kirke': ('kirke',),
'kirken': ('kirke',),
'kirkene': ('kirke',),
'kirker': ('kirke',),
'kirkebakke': ('kirkebakke',),
'kirkebakken': ('kirkebakke',),
'kirkebakkene': ('kirkebakke',),
'kirkebakker': ('kirkebakke',),
'kirkebrus': ('kirkebrus',),
'kirkebrusen': ('kirkebrus',),
'kirkebrusene': ('kirkebrus',),
'kirkebryllup': ('kirkebryllup',),
'kirkebryllupa': ('kirkebryllup',),
'kirkebryllupene': ('kirkebryllup',),
'kirkebrylluper': ('kirkebryllup',),
'kirkebryllupet': ('kirkebryllup',),
'kirkebygd': ('kirkebygd',),
'kirkebygda': ('kirkebygd',),
'kirkebygden': ('kirkebygd',),
'kirkebygdene': ('kirkebygd',),
'kirkebygder': ('kirkebygd',),
'kirkebåt': ('kirkebåt',),
'kirkebåten': ('kirkebåt',),
'kirkebåtene': ('kirkebåt',),
'kirkebåter': ('kirkebåt',),
'kirkebønn': ('kirkebønn',),
'kirkebønna': ('kirkebønn',),
'kirkebønnen': ('kirkebønn',),
'kirkebønnene': ('kirkebønn',),
'kirkebønner': ('kirkebønn',),
'kirkedepartement': ('kirkedepartement',),
'kirkedepartementa': ('kirkedepartement',),
'kirkedepartementene': ('kirkedepartement',),
'kirkedepartementer': ('kirkedepartement',),
'kirkedepartementet': ('kirkedepartement',),
'kirkefar': ('kirkefar',),
'kirkefaren': ('kirkefar',),
'kirkefedre': ('kirkefar',),
'kirkefedrene': ('kirkefar',),
'kirkefolk': ('kirkefolk',),
'kirkefolka': ('kirkefolk',),
'kirkefolkene': ('kirkefolk',),
'kirkefolket': ('kirkefolk',),
'kirkefred': ('kirkefred',),
'kirkefreden': ('kirkefred',),
'kirkefredene': ('kirkefred',),
'kirkefreder': ('kirkefred',),
'kirkegang': ('kirkegang',),
'kirkegangen': ('kirkegang',),
'kirkegangene': ('kirkegang',),
'kirkeganger': ('kirkegang',),
'kirkegard': ('kirkegard',),
'kirkegarden': ('kirkegard',),
'kirkegardene': ('kirkegard',),
'kirkegarder': ('kirkegard',),
'kirkegardsport': ('kirkegardsport',),
'kirkegardsporten': ('kirkegardsport',),
'kirkegardsportene': ('kirkegardsport',),
'kirkegardsporter': ('kirkegardsport',),
'kirkegjenger': ('kirkegjenger',),
'kirkegjengere': ('kirkegjenger',),
'kirkegjengeren': ('kirkegjenger',),
'kirkegjengerer': ('kirkegjenger',),
'kirkegjengerne': ('kirkegjenger',),
'kirkegods': ('kirkegods',),
'kirkegodsa': ('kirkegods',),
'kirkegodsene': ('kirkegods',),
'kirkegodser': ('kirkegods',),
'kirkegodset': ('kirkegods',),
'kirkegolv': ('kirkegolv',),
'kirkegolva': ('kirkegolv',),
'kirkegolvene': ('kirkegolv',),
'kirkegolvet': ('kirkegolv',),
'kirkegulv': ('kirkegulv',),
'kirkegulva': ('kirkegulv',),
'kirkegulvene': ('kirkegulv',),
'kirkegulvet': ('kirkegulv',),
'kirkegård': ('kirkegård',),
'kirkegården': ('kirkegård',),
'kirkegårdene': ('kirkegård',),
'kirkegårder': ('kirkegård',),
'kirkegårdsport': ('kirkegårdsport',),
'kirkegårdsporten': ('kirkegårdsport',),
'kirkegårdsportene': ('kirkegårdsport',),
'kirkegårdsporter': ('kirkegårdsport',),
'kirkehistoria': ('kirkehistorie',),
'kirkehistorie': ('kirkehistorie',),
'kirkehistorien': ('kirkehistorie',),
'kirkehistoriene': ('kirkehistorie',),
'kirkehistorier': ('kirkehistorie',),
'kirkejord': ('kirkejord',),
'kirkejorda': ('kirkejord',),
'kirkejorden': ('kirkejord',),
'kirkejordene': ('kirkejord',),
'kirkejorder': ('kirkejord',),
'kirkekaffe': ('kirkekaffe',),
'kirkekaffen': ('kirkekaffe',),
'kirkekaffene': ('kirkekaffe',),
'kirkekaffer': ('kirkekaffe',),
'kirkeklokka': ('kirkeklokke',),
'kirkeklokke': ('kirkeklokke',),
'kirkeklokken': ('kirkeklokke',),
'kirkeklokkene': ('kirkeklokke',),
'kirkeklokker': ('kirkeklokke',),
'kirkeklær': ('kirkeklær',),
'kirkeklærne': ('kirkeklær',),
'kirkekor': ('kirkekor',),
'kirkekora': ('kirkekor',),
'kirkekorene': ('kirkekor',),
'kirkekoret': ('kirkekor',),
'kirkelyd': ('kirkelyd',),
'kirkelyden': ('kirkelyd',),
'kirkelydene': ('kirkelyd',),
'kirkelyder': ('kirkelyd',),
'kirkeminister': ('kirkeminister',),
'kirkeministere': ('kirkeminister',),
'kirkeministeren': ('kirkeminister',),
'kirkeministerer': ('kirkeminister',),
'kirkeministerne': ('kirkeminister',),
'kirkeministre': ('kirkeminister',),
'kirkeministrene': ('kirkeminister',),
'kirkeministrer': ('kirkeminister',),
'kirkemusikk': ('kirkemusikk',),
'kirkemusikken': ('kirkemusikk',),
'kirkemusikkene': ('kirkemusikk',),
'kirkemusikker': ('kirkemusikk',),
'kirkemøta': ('kirkemøte',),
'kirkemøte': ('kirkemøte',),
'kirkemøtene': ('kirkemøte',),
'kirkemøter': ('kirkemøte',),
'kirkemøtet': ('kirkemøte',),
'kirkesamfunn': ('kirkesamfunn',),
'kirkesamfunna': ('kirkesamfunn',),
'kirkesamfunnene': ('kirkesamfunn',),
'kirkesamfunnet': ('kirkesamfunn',),
'kirkesanger': ('kirkesanger',),
'kirkesangere': ('kirkesanger',),
'kirkesangeren': ('kirkesanger',),
'kirkesangerer': ('kirkesanger',),
'kirkesangerne': ('kirkesanger',),
'kirkeskip': ('kirkeskip',),
'kirkeskipa': ('kirkeskip',),
'kirkeskipene': ('kirkeskip',),
'kirkeskipet': ('kirkeskip',),
'kirkesogn': ('kirkesogn',),
'kirkesogna': ('kirkesogn',),
'kirkesognene': ('kirkesogn',),
'kirkesognet': ('kirkesogn',),
'kirkestat': ('kirkestat',),
'kirkestaten': ('kirkestat',),
'kirkestatene': ('kirkestat',),
'kirkestater': ('kirkestat',),
'kirkestatsråd': ('kirkestatsråd',),
'kirkestatsråden': ('kirkestatsråd',),
'kirkestatsrådene': ('kirkestatsråd',),
'kirkestatsråder': ('kirkestatsråd',),
'kirkested': ('kirkested',),
'kirkestedene': ('kirkested',),
'kirkesteder': ('kirkested',),
'kirkestedet': ('kirkested',),
'kirkesøndag': ('kirkesøndag',),
'kirkesøndagen': ('kirkesøndag',),
'kirkesøndagene': ('kirkesøndag',),
'kirkesøndager': ('kirkesøndag',),
'kirketjener': ('kirketjener',),
'kirketjenere': ('kirketjener',),
'kirketjeneren': ('kirketjener',),
'kirketjenerer': ('kirketjener',),
'kirketjenerne': ('kirketjener',),
'kirketoneart': ('kirketoneart',),
'kirketonearta': ('kirketoneart',),
'kirketonearten': ('kirketoneart',),
'kirketoneartene': ('kirketoneart',),
'kirketonearter': ('kirketoneart',),
'kirketukt': ('kirketukt',),
'kirketukta': ('kirketukt',),
'kirketukten': ('kirketukt',),
'kirketuktene': ('kirketukt',),
'kirketukter': ('kirketukt',),
'kirketårn': ('kirketårn',),
'kirketårna': ('kirketårn',),
'kirketårnene': ('kirketårn',),
'kirketårnet': ('kirketårn',),
'kirkeveg': ('kirkeveg',),
'kirkevegen': ('kirkeveg',),
'kirkevegene': ('kirkeveg',),
'kirkeveger': ('kirkeveg',),
'kirkevei': ('kirkevei',),
'kirkeveien': ('kirkevei',),
'kirkeveiene': ('kirkevei',),
'kirkeveier': ('kirkevei',),
'kirkeverge': ('kirkeverge',),
'kirkevergen': ('kirkeverge',),
'kirkevergene': ('kirkeverge',),
'kirkeverger': ('kirkeverge',),
'kirkeverje': ('kirkeverje',),
'kirkeverjen': ('kirkeverje',),
'kirkeverjene': ('kirkeverje',),
'kirkeverjer': ('kirkeverje',),
'kirkeår': ('kirkeår',),
'kirkeåra': ('kirkeår',),
'kirkeårene': ('kirkeår',),
'kirkeåret': ('kirkeår',),
'kirografi': ('kirografi',),
'kirografien': ('kirografi',),
'kirografiene': ('kirografi',),
'kirografier': ('kirografi',),
'kirologi': ('kirologi',),
'kirologien': ('kirologi',),
'kirologiene': ('kirologi',),
'kirologier': ('kirologi',),
'kiromant': ('kiromant',),
'kiromanten': ('kiromant',),
'kiromantene': ('kiromant',),
'kiromanter': ('kiromant',),
'kiromantikk': ('kiromantikk',),
'kiromantikken': ('kiromantikk',),
'kiromantikkene': ('kiromantikk',),
'kiromantikker': ('kiromantikk',),
'kiropraktiker': ('kiropraktiker',),
'kiropraktikere': ('kiropraktiker',),
'kiropraktikeren': ('kiropraktiker',),
'kiropraktikerer': ('kiropraktiker',),
'kiropraktikerne': ('kiropraktiker',),
'kiropraktikk': ('kiropraktikk',),
'kiropraktikken': ('kiropraktikk',),
'kiropraktikkene': ('kiropraktikk',),
'kiropraktikker': ('kiropraktikk',),
'kiropraktor': ('kiropraktor',),
'kiropraktoren': ('kiropraktor',),
'kiropraktorene': ('kiropraktor',),
'kiropraktorer': ('kiropraktor',),
'kirsch': ('kirsch',),
'kirschen': ('kirsch',),
'kirschene': ('kirsch',),
'kirscher': ('kirsch',),
'kirschstang': ('kirschstang',),
'kirschstanga': ('kirschstang',),
'kirschstangen': ('kirschstang',),
'kirschstengene': ('kirschstang',),
'kirschstenger': ('kirschstang',),
'kirsebær': ('kirsebær',),
'kirsebæra': ('kirsebær',),
'kirsebærene': ('kirsebær',),
'kirsebæret': ('kirsebær',),
'kirsebær': ('kirsebær',),
'kirsebæra': ('kirsebær',),
'kirsebærene': ('kirsebær',),
'kirsebæret': ('kirsebær',),
'kirsebærlikør': ('kirsebærlikør',),
'kirsebærlikøren': ('kirsebærlikør',),
'kirsebærlikørene': ('kirsebærlikør',),
'kirsebærlikører': ('kirsebærlikør',),
'kirurg': ('kirurg',),
'kirurgen': ('kirurg',),
'kirurgene': ('kirurg',),
'kirurger': ('kirurg',),
'kirurgi': ('kirurgi',),
'kirurgien': ('kirurgi',),
'kirurgiene': ('kirurgi',),
'kirurgier': ('kirurgi',),
'kisel': ('kisel',),
'kiselen': ('kisel',),
'kislene': ('kisel',),
'kisler': ('kisel',),
'kiselalge': ('kiselalge',),
'kiselalgen': ('kiselalge',),
'kiselalgene': ('kiselalge',),
'kiselalger': ('kiselalge',),
'kiselgur': ('kiselgur',),
'kiselguren': ('kiselgur',),
'kiselgurene': ('kiselgur',),
'kiselgurer': ('kiselgur',),
'kiselstein': ('kiselstein',),
'kiselsteinen': ('kiselstein',),
'kiselsteinene': ('kiselstein',),
'kiselsteiner': ('kiselstein',),
'kiselsyra': ('kiselsyre',),
'kiselsyre': ('kiselsyre',),
'kiselsyren': ('kiselsyre',),
'kiselsyrene': ('kiselsyre',),
'kiselsyrer': ('kiselsyre',),
'kista': ('kiste',),
'kiste': ('kiste',),
'kisten': ('kiste',),
'kistene': ('kiste',),
'kister': ('kiste',),
'kistebotn': ('kistebotn',),
'kistebotnen': ('kistebotn',),
'kistebotnene': ('kistebotn',),
'kistebotner': ('kistebotn',),
'kistebunn': ('kistebunn',),
'kistebunnen': ('kistebunn',),
'kistebunnene': ('kistebunn',),
'kistebunner': ('kistebunn',),
'kisteklær': ('kisteklær',),
'kisteklærne': ('kisteklær',),
'kitin': ('kitin',),
'kitina': ('kitin',),
'kitinene': ('kitin',),
'kitinet': ('kitin',),
'kitt': ('kitt',),
'kitta': ('kitt',),
'kittene': ('kitt',),
'kittet': ('kitt',),
'kitlene': ('kittel',),
'kitler': ('kittel',),
'kittel': ('kittel',),
'kittelen': ('kittel',),
'kiv': ('kiv',),
'kiva': ('kiv',),
'kivene': ('kiv',),
'kivet': ('kiv',),
'kivi': ('kivi',),
'kivien': ('kivi',),
'kiviene': ('kivi',),
'kivier': ('kivi',),
'kiwi': ('kiwi',),
'kiwien': ('kiwi',),
'kiwiene': ('kiwi',),
'kiwier': ('kiwi',),
'kjake': ('kjake',),
'kjaken': ('kjake',),
'kjakene': ('kjake',),
'kjaker': ('kjake',),
'kjakebein': ('kjakebein',),
'kjakebeina': ('kjakebein',),
'kjakebeinene': ('kjakebein',),
'kjakebeinet': ('kjakebein',),
'kjakeben': ('kjakeben',),
'kjakebena': ('kjakeben',),
'kjakebenene': ('kjakeben',),
'kjakebenet': ('kjakeben',),
'kjaks': ('kjaks',),
'kjaksa': ('kjaks',),
'kjaksene': ('kjaks',),
'kjakset': ('kjaks',),
'kjangs': ('kjangs',),
'kjangsen': ('kjangs',),
'kjangsene': ('kjangs',),
'kjangser': ('kjangs',),
'kjas': ('kjas',),
'kjasa': ('kjas',),
'kjasene': ('kjas',),
'kjaset': ('kjas',),
'kjav': ('kjav',),
'kjava': ('kjav',),
'kjavene': ('kjav',),
'kjavet': ('kjav',),
'kje': ('kje',),
'kjea': ('kje',),
'kjeene': ('kje',),
'kjeet': ('kje',),
'kjeda': ('kjede',),
'kjede': ('kjede',),
'kjeden': ('kjede',),
'kjedene': ('kjede',),
'kjeder': ('kjede',),
'kjedet': ('kjede',),
'kjedebrev': ('kjedebrev',),
'kjedebreva': ('kjedebrev',),
'kjedebrevene': ('kjedebrev',),
'kjedebrever': ('kjedebrev',),
'kjedebrevet': ('kjedebrev',),
'kjedeforretning': ('kjedeforretning',),
'kjedeforretninga': ('kjedeforretning',),
'kjedeforretningen': ('kjedeforretning',),
'kjedeforretningene': ('kjedeforretning',),
'kjedeforretninger': ('kjedeforretning',),
'kjedekassa': ('kjedekasse',),
'kjedekasse': ('kjedekasse',),
'kjedekassen': ('kjedekasse',),
'kjedekassene': ('kjedekasse',),
'kjedekasser': ('kjedekasse',),
'kjedekollisjon': ('kjedekollisjon',),
'kjedekollisjonen': ('kjedekollisjon',),
'kjedekollisjonene': ('kjedekollisjon',),
'kjedekollisjoner': ('kjedekollisjon',),
'kjedelighet': ('kjedelighet',),
'kjedeligheta': ('kjedelighet',),
'kjedeligheten': ('kjedelighet',),
'kjedelighetene': ('kjedelighet',),
'kjedeligheter': ('kjedelighet',),
'kjedereaksjon': ('kjedereaksjon',),
'kjedereaksjonen': ('kjedereaksjon',),
'kjedereaksjonene': ('kjedereaksjon',),
'kjedereaksjoner': ('kjedereaksjon',),
'kjederøyker': ('kjederøyker',),
'kjederøykere': ('kjederøyker',),
'kjederøykeren': ('kjederøyker',),
'kjederøykerer': ('kjederøyker',),
'kjederøykerne': ('kjederøyker',),
'kjedesag': ('kjedesag',),
'kjedesaga': ('kjedesag',),
'kjedesagen': ('kjedesag',),
'kjedesagene': ('kjedesag',),
'kjedesager': ('kjedesag',),
'kjedsomhet': ('kjedsomhet',),
'kjedsomheta': ('kjedsomhet',),
'kjedsomheten': ('kjedsomhet',),
'kjedsomhetene': ('kjedsomhet',),
'kjedsomheter': ('kjedsomhet',),
'kjedsommelighet': ('kjedsommelighet',),
'kjedsommeligheta': ('kjedsommelighet',),
'kjedsommeligheten': ('kjedsommelighet',),
'kjedsommelighetene': ('kjedsommelighet',),
'kjedsommeligheter': ('kjedsommelighet',),
'kjeft': ('kjeft',),
'kjeften': ('kjeft',),
'kjeftene': ('kjeft',),
'kjefter': ('kjeft',),
'kjeftament': ('kjeftament',),
'kjeftamenta': ('kjeftament',),
'kjeftamentene': ('kjeftament',),
'kjeftamenter': ('kjeftament',),
'kjeftamentet': ('kjeftament',),
'kjeftausa': ('kjeftause',),
'kjeftause': ('kjeftause',),
'kjeftausen': ('kjeftause',),
'kjeftausene': ('kjeftause',),
'kjeftauser': ('kjeftause',),
'kjeftbruk': ('kjeftbruk',),
'kjeftbruka': ('kjeftbruk',),
'kjeftbruken': ('kjeftbruk',),
'kjeftbrukene': ('kjeftbruk',),
'kjeftbruker': ('kjeftbruk',),
'kjeftbruket': ('kjeftbruk',),
'kjeftesmella': ('kjeftesmelle',),
'kjeftesmelle': ('kjeftesmelle',),
'kjeftesmellen': ('kjeftesmelle',),
'kjeftesmellene': ('kjeftesmelle',),
'kjeftesmeller': ('kjeftesmelle',),
'kjegla': ('kjegle',),
'kjegle': ('kjegle',),
'kjeglen': ('kjegle',),
'kjeglene': ('kjegle',),
'kjegler': ('kjegle',),
'kjeglebane': ('kjeglebane',),
'kjeglebanen': ('kjeglebane',),
'kjeglebanene': ('kjeglebane',),
'kjeglebaner': ('kjeglebane',),
'kjeglesnitt': ('kjeglesnitt',),
'kjeglesnitta': ('kjeglesnitt',),
'kjeglesnittene': ('kjeglesnitt',),
'kjeglesnittet': ('kjeglesnitt',),
'kjeglespell': ('kjeglespell',),
'kjeglespella': ('kjeglespell',),
'kjeglespellene': ('kjeglespell',),
'kjeglespellet': ('kjeglespell',),
'kjeglespill': ('kjeglespill',),
'kjeglespilla': ('kjeglespill',),
'kjeglespillene': ('kjeglespill',),
'kjeglespillet': ('kjeglespill',),
'kjei': ('kjei',),
'kjeia': ('kjei',),
'kjeiene': ('kjei',),
'kjeiet': ('kjei',),
'kjekkas': ('kjekkas',),
'kjekkasen': ('kjekkas',),
'kjekkasene': ('kjekkas',),
'kjekkaser': ('kjekkas',),
'kjekkaseri': ('kjekkaseri',),
'kjekkaseria': ('kjekkaseri',),
'kjekkaseriene': ('kjekkaseri',),
'kjekkaserier': ('kjekkaseri',),
'kjekkaseriet': ('kjekkaseri',),
'kjekl': ('kjekl',),
'kjekla': ('kjekl',),
'kjeklene': ('kjekl',),
'kjeklet': ('kjekl',),
'kjeks': ('kjeks',),
'kjeksen': ('kjeks',),
'kjeksene': ('kjeks',),
'kjekser': ('kjeks',),
'kjeks': ('kjeks',),
'kjeksen': ('kjeks',),
'kjeksene': ('kjeks',),
'kjekser': ('kjeks',),
'kjeks': ('kjeks',),
'kjeksen': ('kjeks',),
'kjeksene': ('kjeks',),
'kjel': ('kjel',),
'kjelen': ('kjel',),
'kjelene': ('kjel',),
'kjeler': ('kjel',),
'kjelda': ('kjelde',),
'kjelde': ('kjelde',),
'kjelden': ('kjelde',),
'kjeldene': ('kjelde',),
'kjelder': ('kjelde',),
'kjeldegransking': ('kjeldegransking',),
'kjeldegranskinga': ('kjeldegransking',),
'kjeldegranskingen': ('kjeldegransking',),
'kjeldegranskingene': ('kjeldegransking',),
'kjeldegranskinger': ('kjeldegransking',),
'kjeldegras': ('kjeldegras',),
'kjeldegrasa': ('kjeldegras',),
'kjeldegrasene': ('kjeldegras',),
'kjeldegraset': ('kjeldegras',),
'kjeldegress': ('kjeldegress',),
'kjeldegressa': ('kjeldegress',),
'kjeldegressene': ('kjeldegress',),
'kjeldegresset': ('kjeldegress',),
'kjeldekritikk': ('kjeldekritikk',),
'kjeldekritikken': ('kjeldekritikk',),
'kjeldekritikkene': ('kjeldekritikk',),
'kjeldekritikker': ('kjeldekritikk',),
'kjeldeplikt': ('kjeldeplikt',),
'kjeldeplikta': ('kjeldeplikt',),
'kjeldeplikten': ('kjeldeplikt',),
'kjeldepliktene': ('kjeldeplikt',),
'kjeldeplikter': ('kjeldeplikt',),
'kjeldeskrift': ('kjeldeskrift',),
'kjeldeskrifta': ('kjeldeskrift',),
'kjeldeskriftene': ('kjeldeskrift',),
'kjeldeskrifter': ('kjeldeskrift',),
'kjeldeskriftet': ('kjeldeskrift',),
'kjeldevann': ('kjeldevann',),
'kjeldevanna': ('kjeldevann',),
'kjeldevannene': ('kjeldevann',),
'kjeldevannet': ('kjeldevann',),
'kjeldevatn': ('kjeldevatn',),
'kjeldevatna': ('kjeldevatn',),
'kjeldevatnene': ('kjeldevatn',),
'kjeldevatnet': ('kjeldevatn',),
'kjeldress': ('kjeldress',),
'kjeldressen': ('kjeldress',),
'kjeldressene': ('kjeldress',),
'kjeldresser': ('kjeldress',),
'kjele': ('kjele',),
'kjelen': ('kjele',),
'kjelene': ('kjele',),
'kjeler': ('kjele',),
'kjeledress': ('kjeledress',),
'kjeledressen': ('kjeledress',),
'kjeledressene': ('kjeledress',),
'kjeledresser': ('kjeledress',),
'kjelesjau': ('kjelesjau',),
'kjelesjauen': ('kjelesjau',),
'kjelesjauene': ('kjelesjau',),
'kjelesjauer': ('kjelesjau',),
'kjelke': ('kjelke',),
'kjelken': ('kjelke',),
'kjelkene': ('kjelke',),
'kjelker': ('kjelke',),
'kjelkebakke': ('kjelkebakke',),
'kjelkebakken': ('kjelkebakke',),
'kjelkebakkene': ('kjelkebakke',),
'kjelkebakker': ('kjelkebakke',),
'kjeller': ('kjeller',),
'kjellere': ('kjeller',),
'kjelleren': ('kjeller',),
'kjellerer': ('kjeller',),
'kjellerne': ('kjeller',),
'kjellerhals': ('kjellerhals',),
'kjellerhalsen': ('kjellerhals',),
'kjellerhalsene': ('kjellerhals',),
'kjellerhalser': ('kjellerhals',),
'kjellerlem': ('kjellerlem',),
'kjellerlemmen': ('kjellerlem',),
'kjellerlemmene': ('kjellerlem',),
'kjellerlemmer': ('kjellerlem',),
'kjellermelk': ('kjellermelk',),
'kjellermelka': ('kjellermelk',),
'kjellermelken': ('kjellermelk',),
'kjellermelkene': ('kjellermelk',),
'kjellermelker': ('kjellermelk',),
'kjellermjølk': ('kjellermjølk',),
'kjellermjølka': ('kjellermjølk',),
'kjellermjølken': ('kjellermjølk',),
'kjellermjølkene': ('kjellermjølk',),
'kjellermjølker': ('kjellermjølk',),
'kjellerstova': ('kjellerstove',),
'kjellerstove': ('kjellerstove',),
'kjellerstoven': ('kjellerstove',),
'kjellerstovene': ('kjellerstove',),
'kjellerstover': ('kjellerstove',),
'kjellerstua': ('kjellerstue',),
'kjellerstue': ('kjellerstue',),
'kjellerstuen': ('kjellerstue',),
'kjellerstuene': ('kjellerstue',),
'kjellerstuer': ('kjellerstue',),
'kjellertemperatur': ('kjellertemperatur',),
'kjellertemperaturen': ('kjellertemperatur',),
'kjellertemperaturene': ('kjellertemperatur',),
'kjellertemperaturer': ('kjellertemperatur',),
'kjelsjau': ('kjelsjau',),
'kjelsjauen': ('kjelsjau',),
'kjelsjauene': ('kjelsjau',),
'kjelsjauer': ('kjelsjau',),
'kjeltring': ('kjeltring',),
'kjeltringen': ('kjeltring',),
'kjeltringene': ('kjeltring',),
'kjeltringer': ('kjeltring',),
'kjeltringpakk': ('kjeltringpakk',),
'kjeltringpakka': ('kjeltringpakk',),
'kjeltringpakkene': ('kjeltringpakk',),
'kjeltringpakket': ('kjeltringpakk',),
'kjeltringstrek': ('kjeltringstrek',),
'kjeltringstreken': ('kjeltringstrek',),
'kjeltringstrekene': ('kjeltringstrek',),
'kjeltringstreker': ('kjeltringstrek',),
'kjemi': ('kjemi',),
'kjemien': ('kjemi',),
'kjemiene': ('kjemi',),
'kjemier': ('kjemi',),
'kjemigraf': ('kjemigraf',),
'kjemigrafen': ('kjemigraf',),
'kjemigrafene': ('kjemigraf',),
'kjemigrafer': ('kjemigraf',),
'kjemigrafi': ('kjemigrafi',),
'kjemigrafien': ('kjemigrafi',),
'kjemigrafiene': ('kjemigrafi',),
'kjemigrafier': ('kjemigrafi',),
'kjemiingeniør': ('kjemiingeniør',),
'kjemiingeniøren': ('kjemiingeniør',),
'kjemiingeniørene': ('kjemiingeniør',),
'kjemiingeniører': ('kjemiingeniør',),
'kjemikal': ('kjemikal',),
'kjemikala': ('kjemikal',),
'kjemikalene': ('kjemikal',),
'kjemikaler': ('kjemikal',),
'kjemikalet': ('kjemikal',),
'kjemikalia': ('kjemikalie',),
'kjemikalie': ('kjemikalie',),
'kjemikalien': ('kjemikalie',),
'kjemikaliene': ('kjemikalie',),
'kjemikalier': ('kjemikalie',),
'kjemikaliet': ('kjemikalie',),
'kjemikalieklosett': ('kjemikalieklosett',),
'kjemikalieklosetta': ('kjemikalieklosett',),
'kjemikalieklosettene': ('kjemikalieklosett',),
'kjemikalieklosetter': ('kjemikalieklosett',),
'kjemikalieklosettet': ('kjemikalieklosett',),
'kjemikalklosett': ('kjemikalklosett',),
'kjemikalklosetta': ('kjemikalklosett',),
'kjemikalklosettene': ('kjemikalklosett',),
'kjemikalklosetter': ('kjemikalklosett',),
'kjemikalklosettet': ('kjemikalklosett',),
'kjemiker': ('kjemiker',),
'kjemikere': ('kjemiker',),
'kjemikeren': ('kjemiker',),
'kjemikerer': ('kjemiker',),
'kjemikerne': ('kjemiker',),
'kjemilinja': ('kjemilinje',),
'kjemilinje': ('kjemilinje',),
'kjemilinjen': ('kjemilinje',),
'kjemilinjene': ('kjemilinje',),
'kjemilinjer': ('kjemilinje',),
'kjemma': ('kjemme',),
'kjemme': ('kjemme',),
'kjemmen': ('kjemme',),
'kjemmene': ('kjemme',),
'kjemmer': ('kjemme',),
'kjemotaksis': ('kjemotaksis',),
'kjemotaksisen': ('kjemotaksis',),
'kjemotaksisene': ('kjemotaksis',),
'kjemotaksiser': ('kjemotaksis',),
'kjempa': ('kjempe',),
'kjempe': ('kjempe',),
'kjempen': ('kjempe',),
'kjempene': ('kjempe',),
'kjemper': ('kjempe',),
'kjempebaby': ('kjempebaby',),
'kjempebabyen': ('kjempebaby',),
'kjempebabyene': ('kjempebaby',),
'kjempebabyer': ('kjempebaby',),
'kjempeblekksprut': ('kjempeblekksprut',),
'kjempeblekkspruten': ('kjempeblekksprut',),
'kjempeblekksprutene': ('kjempeblekksprut',),
'kjempeblekkspruter': ('kjempeblekksprut',),
'kjempefamilie': ('kjempefamilie',),
'kjempefamilien': ('kjempefamilie',),
'kjempefamiliene': ('kjempefamilie',),
'kjempefamilier': ('kjempefamilie',),
'kjempekaktus': ('kjempekaktus',),
'kjempekaktusen': ('kjempekaktus',),
'kjempekaktusene': ('kjempekaktus',),
'kjempekaktuser': ('kjempekaktus',),
'kjempekenguru': ('kjempekenguru',),
'kjempekenguruen': ('kjempekenguru',),
'kjempekenguruene': ('kjempekenguru',),
'kjempekenguruer': ('kjempekenguru',),
'kjempemusling': ('kjempemusling',),
'kjempemuslingen': ('kjempemusling',),
'kjempemuslingene': ('kjempemusling',),
'kjempemuslinger': ('kjempemusling',),
'kjempepanda': ('kjempepanda',),
'kjempepandaen': ('kjempepanda',),
'kjempepandaene': ('kjempepanda',),
'kjempepandaer': ('kjempepanda',),
'kjemper': ('kjemper',),
'kjempere': ('kjemper',),
'kjemperen': ('kjemper',),
'kjemperer': ('kjemper',),
'kjemperne': ('kjemper',),
'kjempeskilpadda': ('kjempeskilpadde',),
'kjempeskilpadde': ('kjempeskilpadde',),
'kjempeskilpadden': ('kjempeskilpadde',),
'kjempeskilpaddene': ('kjempeskilpadde',),
'kjempeskilpadder': ('kjempeskilpadde',),
'kjempesleng': ('kjempesleng',),
'kjempeslengen': ('kjempesleng',),
'kjempeslengene': ('kjempesleng',),
'kjempeslenger': ('kjempesleng',),
'kjempestjerna': ('kjempestjerne',),
'kjempestjerne': ('kjempestjerne',),
'kjempestjernen': ('kjempestjerne',),
'kjempestjernene': ('kjempestjerne',),
'kjempestjerner': ('kjempestjerne',),
'kjempesving': ('kjempesving',),
'kjempesvingen': ('kjempesving',),
'kjempesvingene': ('kjempesving',),
'kjempesvinger': ('kjempesving',),
'kjempevekst': ('kjempevekst',),
'kjempeveksten': ('kjempevekst',),
'kjempevekstene': ('kjempevekst',),
'kjempevekster': ('kjempevekst',),
'kjempevisa': ('kjempevise',),
'kjempevise': ('kjempevise',),
'kjempevisen': ('kjempevise',),
'kjempevisene': ('kjempevise',),
'kjempeviser': ('kjempevise',),
'kjempeøgla': ('kjempeøgle',),
'kjempeøgle': ('kjempeøgle',),
'kjempeøglen': ('kjempeøgle',),
'kjempeøglene': ('kjempeøgle',),
'kjempeøgler': ('kjempeøgle',),
'kjendis': ('kjendis',),
'kjendisen': ('kjendis',),
'kjendisene': ('kjendis',),
'kjendiser': ('kjendis',),
'kjendiseri': ('kjendiseri',),
'kjendiseria': ('kjendiseri',),
'kjendiseriene': ('kjendiseri',),
'kjendiserier': ('kjendiseri',),
'kjendiseriet': ('kjendiseri',),
'kjeng': ('kjeng',),
'kjengen': ('kjeng',),
'kjengene': ('kjeng',),
'kjenger': ('kjeng',),
'kjenga': ('kjenge',),
'kjenge': ('kjenge',),
'kjengen': ('kjenge',),
'kjengene': ('kjenge',),
'kjenger': ('kjenge',),
'kjenna': ('kjenne',),
'kjenne': ('kjenne',),
'kjennene': ('kjenne',),
'kjenner': ('kjenne',),
'kjennet': ('kjenne',),
'kjennelse': ('kjennelse',),
'kjennelsen': ('kjennelse',),
'kjennelsene': ('kjennelse',),
'kjennelser': ('kjennelse',),
'kjennemerka': ('kjennemerke',),
'kjennemerke': ('kjennemerke',),
'kjennemerkene': ('kjennemerke',),
'kjennemerker': ('kjennemerke',),
'kjennemerket': ('kjennemerke',),
'kjenner': ('kjenner',),
'kjennere': ('kjenner',),
'kjenneren': ('kjenner',),
'kjennerer': ('kjenner',),
'kjennerne': ('kjenner',),
'kjennetegn': ('kjennetegn',),
'kjennetegna': ('kjennetegn',),
'kjennetegnene': ('kjennetegn',),
'kjennetegnet': ('kjennetegn',),
'kjenning': ('kjenning',),
'kjenninga': ('kjenning',),
'kjenningen': ('kjenning',),
'kjenningene': ('kjenning',),
'kjenninger': ('kjenning',),
'kjenning': ('kjenning',),
'kjenninga': ('kjenning',),
'kjenningen': ('kjenning',),
'kjenningene': ('kjenning',),
'kjenninger': ('kjenning',),
'kjenning': ('kjenning',),
'kjenninga': ('kjenning',),
'kjenningen': ('kjenning',),
'kjenningene': ('kjenning',),
'kjenninger': ('kjenning',),
'kjenningsbokstav': ('kjenningsbokstav',),
'kjenningsbokstaven': ('kjenningsbokstav',),
'kjenningsbokstavene': ('kjenningsbokstav',),
'kjenningsbokstaver': ('kjenningsbokstav',),
'kjenningsmelodi': ('kjenningsmelodi',),
'kjenningsmelodien': ('kjenningsmelodi',),
'kjenningsmelodiene': ('kjenningsmelodi',),
'kjenningsmelodier': ('kjenningsmelodi',),
'kjenningsnummer': ('kjenningsnummer',),
'kjenningsnummeret': ('kjenningsnummer',),
'kjenningsnumra': ('kjenningsnummer',),
'kjenningsnumre': ('kjenningsnummer',),
'kjenningsnumrene': ('kjenningsnummer',),
'kjenningssignal': ('kjenningssignal',),
'kjenningssignala': ('kjenningssignal',),
'kjenningssignalene': ('kjenningssignal',),
'kjenningssignaler': ('kjenningssignal',),
'kjenningssignalet': ('kjenningssignal',),
'kjennskap': ('kjennskap',),
'kjennskapa': ('kjennskap',),
'kjennskapen': ('kjennskap',),
'kjennskapene': ('kjennskap',),
'kjennskaper': ('kjennskap',),
'kjennskapet': ('kjennskap',),
'kjensel': ('kjensel',),
'kjenselen': ('kjensel',),
'kjenslene': ('kjensel',),
'kjensler': ('kjensel',),
'kjensfolk': ('kjensfolk',),
'kjensfolka': ('kjensfolk',),
'kjensfolkene': ('kjensfolk',),
'kjensfolket': ('kjensfolk',),
'kjensgjerning': ('kjensgjerning',),
'kjensgjerninga': ('kjensgjerning',),
'kjensgjerningen': ('kjensgjerning',),
'kjensgjerningene': ('kjensgjerning',),
'kjensgjerninger': ('kjensgjerning',),
'kjensla': ('kjensle',),
'kjensle': ('kjensle',),
'kjenslen': ('kjensle',),
'kjenslene': ('kjensle',),
'kjensler': ('kjensle',),
'kjentfolk': ('kjentfolk',),
'kjentfolka': ('kjentfolk',),
'kjentfolkene': ('kjentfolk',),
'kjentfolket': ('kjentfolk',),
'kjentmann': ('kjentmann',),
'kjentmannen': ('kjentmann',),
'kjentmenn': ('kjentmann',),
'kjentmennene': ('kjentmann',),
'kjepp': ('kjepp',),
'kjeppen': ('kjepp',),
'kjeppene': ('kjepp',),
'kjepper': ('kjepp',),
'kjepphest': ('kjepphest',),
'kjepphesten': ('kjepphest',),
'kjepphestene': ('kjepphest',),
'kjepphester': ('kjepphest',),
'kjer': ('kjer',),
'kjera': ('kjer',),
'kjerene': ('kjer',),
'kjeret': ('kjer',),
'kjerald': ('kjerald',),
'kjeralda': ('kjerald',),
'kjeraldene': ('kjerald',),
'kjeraldet': ('kjerald',),
'kjerald': ('kjerald',),
'kjeralda': ('kjerald',),
'kjeraldene': ('kjerald',),
'kjeraldet': ('kjerald',),
'kjerka': ('kjerke',),
'kjerke': ('kjerke',),
'kjerken': ('kjerke',),
'kjerkene': ('kjerke',),
'kjerker': ('kjerke',),
'kjerkebakke': ('kjerkebakke',),
'kjerkebakken': ('kjerkebakke',),
'kjerkebakkene': ('kjerkebakke',),
'kjerkebakker': ('kjerkebakke',),
'kjerkebryllup': ('kjerkebryllup',),
'kjerkebryllupa': ('kjerkebryllup',),
'kjerkebryllupene': ('kjerkebryllup',),
'kjerkebrylluper': ('kjerkebryllup',),
'kjerkebryllupet': ('kjerkebryllup',),
'kjerkebygd': ('kjerkebygd',),
'kjerkebygda': ('kjerkebygd',),
'kjerkebygdene': ('kjerkebygd',),
'kjerkebygder': ('kjerkebygd',),
'kjerkebåt': ('kjerkebåt',),
'kjerkebåten': ('kjerkebåt',),
'kjerkebåtene': ('kjerkebåt',),
'kjerkebåter': ('kjerkebåt',),
'kjerkebønn': ('kjerkebønn',),
'kjerkebønna': ('kjerkebønn',),
'kjerkebønnen': ('kjerkebønn',),
'kjerkebønnene': ('kjerkebønn',),
'kjerkebønner': ('kjerkebønn',),
'kjerkefolk': ('kjerkefolk',),
'kjerkefolka': ('kjerkefolk',),
'kjerkefolkene': ('kjerkefolk',),
'kjerkefolket': ('kjerkefolk',),
'kjerkefred': ('kjerkefred',),
'kjerkefreden': ('kjerkefred',),
'kjerkefredene': ('kjerkefred',),
'kjerkefreder': ('kjerkefred',),
'kjerkegang': ('kjerkegang',),
'kjerkegangen': ('kjerkegang',),
'kjerkegangene': ('kjerkegang',),
'kjerkeganger': ('kjerkegang',),
'kjerkegard': ('kjerkegard',),
'kjerkegarden': ('kjerkegard',),
'kjerkegardene': ('kjerkegard',),
'kjerkegarder': ('kjerkegard',),
'kjerkegard': ('kjerkegard',),
'kjerkegarden': ('kjerkegard',),
'kjerkegardene': ('kjerkegard',),
'kjerkegarder': ('kjerkegard',),
'kjerkegardsport': ('kjerkegardsport',),
'kjerkegardsporten': ('kjerkegardsport',),
'kjerkegardsportene': ('kjerkegardsport',),
'kjerkegardsporter': ('kjerkegardsport',),
'kjerkegardsport': ('kjerkegardsport',),
'kjerkegardsporten': ('kjerkegardsport',),
'kjerkegardsportene': ('kjerkegardsport',),
'kjerkegardsporter': ('kjerkegardsport',),
'kjerkegjenger': ('kjerkegjenger',),
'kjerkegjengere': ('kjerkegjenger',),
'kjerkegjengeren': ('kjerkegjenger',),
'kjerkegjengerer': ('kjerkegjenger',),
'kjerkegjengerne': ('kjerkegjenger',),
'kjerkegods': ('kjerkegods',),
'kjerkegodsa': ('kjerkegods',),
'kjerkegodsene': ('kjerkegods',),
'kjerkegodset': ('kjerkegods',),
'kjerkegolv': ('kjerkegolv',),
'kjerkegolva': ('kjerkegolv',),
'kjerkegolvene': ('kjerkegolv',),
'kjerkegolvet': ('kjerkegolv',),
'kjerkegulv': ('kjerkegulv',),
'kjerkegulva': ('kjerkegulv',),
'kjerkegulvene': ('kjerkegulv',),
'kjerkegulvet': ('kjerkegulv',),
'kjerkegård': ('kjerkegård',),
'kjerkegården': ('kjerkegård',),
'kjerkegårdene': ('kjerkegård',),
'kjerkegårder': ('kjerkegård',),
'kjerkegård': ('kjerkegård',),
'kjerkegården': ('kjerkegård',),
'kjerkegårdene': ('kjerkegård',),
'kjerkegårder': ('kjerkegård',),
'kjerkegårdsport': ('kjerkegårdsport',),
'kjerkegårdsporten': ('kjerkegårdsport',),
'kjerkegårdsportene': ('kjerkegårdsport',),
'kjerkegårdsporter': ('kjerkegårdsport',),
'kjerkegårdsport': ('kjerkegårdsport',),
'kjerkegårdsporten': ('kjerkegårdsport',),
'kjerkegårdsportene': ('kjerkegårdsport',),
'kjerkegårdsporter': ('kjerkegårdsport',),
'kjerkejord': ('kjerkejord',),
'kjerkejorda': ('kjerkejord',),
'kjerkejorden': ('kjerkejord',),
'kjerkejordene': ('kjerkejord',),
'kjerkejorder': ('kjerkejord',),
'kjerkekaffe': ('kjerkekaffe',),
'kjerkekaffen': ('kjerkekaffe',),
'kjerkekaffene': ('kjerkekaffe',),
'kjerkekaffer': ('kjerkekaffe',),
'kjerkeklokka': ('kjerkeklokke',),
'kjerkeklokke': ('kjerkeklokke',),
'kjerkeklokken': ('kjerkeklokke',),
'kjerkeklokkene': ('kjerkeklokke',),
'kjerkeklokker': ('kjerkeklokke',),
'kjerkeklær': ('kjerkeklær',),
'kjerkeklærne': ('kjerkeklær',),
'kjerkekor': ('kjerkekor',),
'kjerkekora': ('kjerkekor',),
'kjerkekorene': ('kjerkekor',),
'kjerkekoret': ('kjerkekor',),
'kjerkelyd': ('kjerkelyd',),
'kjerkelyden': ('kjerkelyd',),
'kjerkelydene': ('kjerkelyd',),
'kjerkelyder': ('kjerkelyd',),
'kjerkemusikk': ('kjerkemusikk',),
'kjerkemusikken': ('kjerkemusikk',),
'kjerkemusikkene': ('kjerkemusikk',),
'kjerkemusikker': ('kjerkemusikk',),
'kjerkemøta': ('kjerkemøte',),
'kjerkemøte': ('kjerkemøte',),
'kjerkemøtene': ('kjerkemøte',),
'kjerkemøter': ('kjerkemøte',),
'kjerkemøtet': ('kjerkemøte',),
'kjerkesamfunn': ('kjerkesamfunn',),
'kjerkesamfunna': ('kjerkesamfunn',),
'kjerkesamfunnene': ('kjerkesamfunn',),
'kjerkesamfunnet': ('kjerkesamfunn',),
'kjerkesanger': ('kjerkesanger',),
'kjerkesangere': ('kjerkesanger',),
'kjerkesangeren': ('kjerkesanger',),
'kjerkesangerer': ('kjerkesanger',),
'kjerkesangerne': ('kjerkesanger',),
'kjerkeskip': ('kjerkeskip',),
'kjerkeskipa': ('kjerkeskip',),
'kjerkeskipene': ('kjerkeskip',),
'kjerkeskipet': ('kjerkeskip',),
'kjerkesogn': ('kjerkesogn',),
'kjerkesogna': ('kjerkesogn',),
'kjerkesognene': ('kjerkesogn',),
'kjerkesognet': ('kjerkesogn',),
'kjerkesokn': ('kjerkesokn',),
'kjerkesokna': ('kjerkesokn',),
'kjerkesoknen': ('kjerkesokn',),
'kjerkesoknene': ('kjerkesokn',),
'kjerkesokner': ('kjerkesokn',),
'kjerkesoknet': ('kjerkesokn',),
'kjerkested': ('kjerkested',),
'kjerkestedene': ('kjerkested',),
'kjerkesteder': ('kjerkested',),
'kjerkestedet': ('kjerkested',),
'kjerkesøndag': ('kjerkesøndag',),
'kjerkesøndagen': ('kjerkesøndag',),
'kjerkesøndagene': ('kjerkesøndag',),
'kjerkesøndager': ('kjerkesøndag',),
'kjerketjener': ('kjerketjener',),
'kjerketjenere': ('kjerketjener',),
'kjerketjeneren': ('kjerketjener',),
'kjerketjenerer': ('kjerketjener',),
'kjerketjenerne': ('kjerketjener',),
'kjerketukt': ('kjerketukt',),
'kjerketukta': ('kjerketukt',),
'kjerketukten': ('kjerketukt',),
'kjerketuktene': ('kjerketukt',),
'kjerketukter': ('kjerketukt',),
'kjerketårn': ('kjerketårn',),
'kjerketårna': ('kjerketårn',),
'kjerketårnene': ('kjerketårn',),
'kjerketårnet': ('kjerketårn',),
'kjerkeveg': ('kjerkeveg',),
'kjerkevegen': ('kjerkeveg',),
'kjerkevegene': ('kjerkeveg',),
'kjerkeveger': ('kjerkeveg',),
'kjerkevei': ('kjerkevei',),
'kjerkeveien': ('kjerkevei',),
'kjerkeveiene': ('kjerkevei',),
'kjerkeveier': ('kjerkevei',),
'kjerkeverge': ('kjerkeverge',),
'kjerkevergen': ('kjerkeverge',),
'kjerkevergene': ('kjerkeverge',),
'kjerkeverger': ('kjerkeverge',),
'kjerkeverje': ('kjerkeverje',),
'kjerkeverjen': ('kjerkeverje',),
'kjerkeverjene': ('kjerkeverje',),
'kjerkeverjer': ('kjerkeverje',),
'kjerkeår': ('kjerkeår',),
'kjerkeåra': ('kjerkeår',),
'kjerkeårene': ('kjerkeår',),
'kjerkeåret': ('kjerkeår',),
'kjerne': ('kjerne',),
'kjernen': ('kjerne',),
'kjernene': ('kjerne',),
'kjerner': ('kjerne',),
'kjerna': ('kjerne',),
'kjerne': ('kjerne',),
'kjernen': ('kjerne',),
'kjernene': ('kjerne',),
'kjerner': ('kjerne',),
'kjerneenergi': ('kjerneenergi',),
'kjerneenergien': ('kjerneenergi',),
'kjerneenergiene': ('kjerneenergi',),
'kjerneenergier': ('kjerneenergi',),
'kjernefag': ('kjernefag',),
'kjernefaga': ('kjernefag',),
'kjernefagene': ('kjernefag',),
'kjernefaget': ('kjernefag',),
'kjernefamilie': ('kjernefamilie',),
'kjernefamilien': ('kjernefamilie',),
'kjernefamiliene': ('kjernefamilie',),
'kjernefamilier': ('kjernefamilie',),
'kjernefisjon': ('kjernefisjon',),
'kjernefisjonen': ('kjernefisjon',),
'kjernefisjonene': ('kjernefisjon',),
'kjernefisjoner': ('kjernefisjon',),
'kjernefrukt': ('kjernefrukt',),
'kjernefrukta': ('kjernefrukt',),
'kjernefrukten': ('kjernefrukt',),
'kjernefruktene': ('kjernefrukt',),
'kjernefrukter': ('kjernefrukt',),
'kjernefusjon': ('kjernefusjon',),
'kjernefusjonen': ('kjernefusjon',),
'kjernefusjonene': ('kjernefusjon',),
'kjernefusjoner': ('kjernefusjon',),
'kjernefysikk': ('kjernefysikk',),
'kjernefysikken': ('kjernefysikk',),
'kjernefysikkene': ('kjernefysikk',),
'kjernefysikker': ('kjernefysikk',),
'kjernehus': ('kjernehus',),
'kjernehusa': ('kjernehus',),
'kjernehusene': ('kjernehus',),
'kjernehuset': ('kjernehus',),
'kjernekar': ('kjernekar',),
'kjernekaren': ('kjernekar',),
'kjernekarene': ('kjernekar',),
'kjernekarer': ('kjernekar',),
'kjernekjemi': ('kjernekjemi',),
'kjernekjemien': ('kjernekjemi',),
'kjernekjemiene': ('kjernekjemi',),
'kjernekjemier': ('kjernekjemi',),
'kjernekraft': ('kjernekraft',),
'kjernekrafta': ('kjernekraft',),
'kjernekraften': ('kjernekraft',),
'kjernekreftene': ('kjernekraft',),
'kjernekrefter': ('kjernekraft',),
'kjernekraftverk': ('kjernekraftverk',),
'kjernekraftverka': ('kjernekraftverk',),
'kjernekraftverkene': ('kjernekraftverk',),
'kjernekraftverker': ('kjernekraftverk',),
'kjernekraftverket': ('kjernekraftverk',),
'kjernemelk': ('kjernemelk',),
'kjernemelka': ('kjernemelk',),
'kjernemelken': ('kjernemelk',),
'kjernemelkene': ('kjernemelk',),
'kjernemelker': ('kjernemelk',),
'kjernemjølk': ('kjernemjølk',),
'kjernemjølka': ('kjernemjølk',),
'kjernemjølken': ('kjernemjølk',),
'kjernemjølkene': ('kjernemjølk',),
'kjernemjølker': ('kjernemjølk',),
'kjerneområda': ('kjerneområde',),
'kjerneområde': ('kjerneområde',),
'kjerneområdene': ('kjerneområde',),
'kjerneområder': ('kjerneområde',),
'kjerneområdet': ('kjerneområde',),
'kjerneprøva': ('kjerneprøve',),
'kjerneprøve': ('kjerneprøve',),
'kjerneprøven': ('kjerneprøve',),
'kjerneprøvene': ('kjerneprøve',),
'kjerneprøver': ('kjerneprøve',),
'kjernepunkt': ('kjernepunkt',),
'kjernepunkta': ('kjernepunkt',),
'kjernepunktene': ('kjernepunkt',),
'kjernepunkter': ('kjernepunkt',),
'kjernepunktet': ('kjernepunkt',),
'kjernereaksjon': ('kjernereaksjon',),
'kjernereaksjonen': ('kjernereaksjon',),
'kjernereaksjonene': ('kjernereaksjon',),
'kjernereaksjoner': ('kjernereaksjon',),
'kjernereaktor': ('kjernereaktor',),
'kjernereaktoren': ('kjernereaktor',),
'kjernereaktorene': ('kjernereaktor',),
'kjernereaktorer': ('kjernereaktor',),
'kjernespørsmål': ('kjernespørsmål',),
'kjernespørsmåla': ('kjernespørsmål',),
'kjernespørsmålene': ('kjernespørsmål',),
'kjernespørsmålet': ('kjernespørsmål',),
'kjerneved': ('kjerneved',),
'kjerneveden': ('kjerneved',),
'kjernevedene': ('kjerneved',),
'kjerneveder': ('kjerneved',),
'kjernevåpen': ('kjernevåpen',),
'kjernevåpenet': ('kjernevåpen',),
'kjernevåpna': ('kjernevåpen',),
'kjernevåpnene': ('kjernevåpen',),
'kjerr': ('kjerr',),
'kjerra': ('kjerr',),
'kjerrene': ('kjerr',),
'kjerret': ('kjerr',),
'kjerrat': ('kjerrat',),
'kjerraten': ('kjerrat',),
'kjerratene': ('kjerrat',),
'kjerrater': ('kjerrat',),
'kjerra': ('kjerre',),
'kjerre': ('kjerre',),
'kjerren': ('kjerre',),
'kjerrene': ('kjerre',),
'kjerrer': ('kjerre',),
'kjerreveg': ('kjerreveg',),
'kjerrevegen': ('kjerreveg',),
'kjerrevegene': ('kjerreveg',),
'kjerreveger': ('kjerreveg',),
'kjerrevei': ('kjerrevei',),
'kjerreveien': ('kjerrevei',),
'kjerreveiene': ('kjerrevei',),
'kjerreveier': ('kjerrevei',),
'kjerring': ('kjerring',),
'kjerringa': ('kjerring',),
'kjerringen': ('kjerring',),
'kjerringene': ('kjerring',),
'kjerringer': ('kjerring',),
'kjerringemna': ('kjerringemne',),
'kjerringemne': ('kjerringemne',),
'kjerringemnene': ('kjerringemne',),
'kjerringemner': ('kjerringemne',),
'kjerringemnet': ('kjerringemne',),
'kjerringkjeft': ('kjerringkjeft',),
'kjerringkjeften': ('kjerringkjeft',),
'kjerringkjeftene': ('kjerringkjeft',),
'kjerringkjefter': ('kjerringkjeft',),
'kjerringknute': ('kjerringknute',),
'kjerringknuten': ('kjerringknute',),
'kjerringknutene': ('kjerringknute',),
'kjerringknuter': ('kjerringknute',),
'kjerringris': ('kjerringris',),
'kjerringrisa': ('kjerringris',),
'kjerringrisene': ('kjerringris',),
'kjerringriset': ('kjerringris',),
'kjerringrokk': ('kjerringrokk',),
'kjerringrokken': ('kjerringrokk',),
'kjerringrokkene': ('kjerringrokk',),
'kjerringrokker': ('kjerringrokk',),
'kjerris': ('kjerris',),
'kjerrisen': ('kjerris',),
'kjerrisene': ('kjerris',),
'kjerriser': ('kjerris',),
'kjerte': ('kjerte',),
'kjerten': ('kjerte',),
'kjertene': ('kjerte',),
'kjerter': ('kjerte',),
'kjertel': ('kjertel',),
'kjertelen': ('kjertel',),
'kjertlene': ('kjertel',),
'kjertler': ('kjertel',),
'kjertelys': ('kjertelys',),
'kjertelysa': ('kjertelys',),
'kjertelysene': ('kjertelys',),
'kjertelyset': ('kjertelys',),
'kjertesvein': ('kjertesvein',),
'kjertesveinen': ('kjertesvein',),
'kjertesveinene': ('kjertesvein',),
'kjertesveiner': ('kjertesvein',),
'kjerub': ('kjerub',),
'kjeruben': ('kjerub',),
'kjerubene': ('kjerub',),
'kjeruber': ('kjerub',),
'kjerv': ('kjerv',),
'kjerva': ('kjerv',),
'kjervene': ('kjerv',),
'kjervet': ('kjerv',),
'kjerva': ('kjerve',),
'kjerve': ('kjerve',),
'kjervene': ('kjerve',),
'kjerver': ('kjerve',),
'kjervet': ('kjerve',),
'kjese': ('kjese',),
'kjesen': ('kjese',),
'kjesene': ('kjese',),
'kjeser': ('kjese',),
'kjesk': ('kjesk',),
'kjeska': ('kjesk',),
'kjeskene': ('kjesk',),
'kjesket': ('kjesk',),
'kjeska': ('kjeske',),
'kjeske': ('kjeske',),
'kjeskene': ('kjeske',),
'kjesker': ('kjeske',),
'kjesket': ('kjeske',),
'kjetta': ('kjette',),
'kjette': ('kjette',),
'kjetten': ('kjette',),
'kjettene': ('kjette',),
'kjetter': ('kjette',),
'kjetter': ('kjetter',),
'kjettere': ('kjetter',),
'kjetteren': ('kjetter',),
'kjetterer': ('kjetter',),
'kjetterne': ('kjetter',),
'kjetteri': ('kjetteri',),
'kjetteria': ('kjetteri',),
'kjetteriene': ('kjetteri',),
'kjetterier': ('kjetteri',),
'kjetteriet': ('kjetteri',),
'kjetting': ('kjetting',),
'kjettingen': ('kjetting',),
'kjettingene': ('kjetting',),
'kjettinger': ('kjetting',),
'kjeve': ('kjeve',),
'kjeven': ('kjeve',),
'kjevene': ('kjeve',),
'kjever': ('kjeve',),
'kjevebein': ('kjevebein',),
'kjevebeina': ('kjevebein',),
'kjevebeinene': ('kjevebein',),
'kjevebeinet': ('kjevebein',),
'kjeveben': ('kjeveben',),
'kjevebena': ('kjeveben',),
'kjevebenene': ('kjeveben',),
'kjevebenet': ('kjeveben',),
'kjeveledd': ('kjeveledd',),
'kjeveledda': ('kjeveledd',),
'kjeveleddene': ('kjeveledd',),
'kjeveleddet': ('kjeveledd',),
'kjeveparti': ('kjeveparti',),
'kjevepartia': ('kjeveparti',),
'kjevepartiene': ('kjeveparti',),
'kjevepartier': ('kjeveparti',),
'kjevepartiet': ('kjeveparti',),
'kjevla': ('kjevle',),
'kjevle': ('kjevle',),
'kjevlene': ('kjevle',),
'kjevler': ('kjevle',),
'kjevlet': ('kjevle',),
'kjevlegras': ('kjevlegras',),
'kjevlegrasa': ('kjevlegras',),
'kjevlegrasene': ('kjevlegras',),
'kjevlegraset': ('kjevlegras',),
'kjevlegress': ('kjevlegress',),
'kjevlegressa': ('kjevlegress',),
'kjevlegressene': ('kjevlegress',),
'kjevlegresset': ('kjevlegress',),
'kjoks': ('kjoks',),
'kjoksen': ('kjoks',),
'kjoksene': ('kjoks',),
'kjokser': ('kjoks',),
'kjole': ('kjole',),
'kjolen': ('kjole',),
'kjolene': ('kjole',),
'kjoler': ('kjole',),
'kjoleliv': ('kjoleliv',),
'kjoleliva': ('kjoleliv',),
'kjolelivene': ('kjoleliv',),
'kjolelivet': ('kjoleliv',),
'kjona': ('kjone',),
'kjone': ('kjone',),
'kjonen': ('kjone',),
'kjonene': ('kjone',),
'kjoner': ('kjone',),
'kjortel': ('kjortel',),
'kjortelen': ('kjortel',),
'kjortlene': ('kjortel',),
'kjortler': ('kjortel',),
'kjos': ('kjos',),
'kjosen': ('kjos',),
'kjosene': ('kjos',),
'kjoser': ('kjos',),
'kjuka': ('kjuke',),
'kjuke': ('kjuke',),
'kjuken': ('kjuke',),
'kjukene': ('kjuke',),
'kjuker': ('kjuke',),
'kjukling': ('kjukling',),
'kjuklingen': ('kjukling',),
'kjuklingene': ('kjukling',),
'kjuklinger': ('kjukling',),
'kjælebarn': ('kjælebarn',),
'kjælebarna': ('kjælebarn',),
'kjælebarnene': ('kjælebarn',),
'kjælebarnet': ('kjælebarn',),
'kjæledegge': ('kjæledegge',),
'kjæledeggen': ('kjæledegge',),
'kjæledeggene': ('kjæledegge',),
'kjæledegger': ('kjæledegge',),
'kjælegris': ('kjælegris',),
'kjælegrisen': ('kjælegris',),
'kjælegrisene': ('kjælegris',),
'kjælegriser': ('kjælegris',),
'kjælenavn': ('kjælenavn',),
'kjælenavna': ('kjælenavn',),
'kjælenavnene': ('kjælenavn',),
'kjælenavnet': ('kjælenavn',),
'kjæleri': ('kjæleri',),
'kjæleria': ('kjæleri',),
'kjæleriene': ('kjæleri',),
'kjælerier': ('kjæleri',),
'kjæleriet': ('kjæleri',),
'kjæremål': ('kjæremål',),
'kjæremåla': ('kjæremål',),
'kjæremålene': ('kjæremål',),
'kjæremålet': ('kjæremål',),
'kjæremålsutvalg': ('kjæremålsutvalg',),
'kjæremålsutvalga': ('kjæremålsutvalg',),
'kjæremålsutvalgene': ('kjæremålsutvalg',),
'kjæremålsutvalget': ('kjæremålsutvalg',),
'kjæreste': ('kjæreste',),
'kjæresten': ('kjæreste',),
'kjærestene': ('kjæreste',),
'kjærester': ('kjæreste',),
'kjærestefolk': ('kjærestefolk',),
'kjærestefolka': ('kjærestefolk',),
'kjærestefolkene': ('kjærestefolk',),
'kjærestefolket': ('kjærestefolk',),
'kjærestepar': ('kjærestepar',),
'kjærestepara': ('kjærestepar',),
'kjæresteparene': ('kjærestepar',),
'kjæresteparet': ('kjærestepar',),
'kjærleik': ('kjærleik',),
'kjærleiken': ('kjærleik',),
'kjærleikene': ('kjærleik',),
'kjærleiker': ('kjærleik',),
'kjærlighet': ('kjærlighet',),
'kjærligheta': ('kjærlighet',),
'kjærligheten': ('kjærlighet',),
'kjærlighetene': ('kjærlighet',),
'kjærligheter': ('kjærlighet',),
'kjærlighetsaffære': ('kjærlighetsaffære',),
'kjærlighetsaffæren': ('kjærlighetsaffære',),
'kjærlighetsaffærene': ('kjærlighetsaffære',),
'kjærlighetsaffærer': ('kjærlighetsaffære',),
'kjærlighetsbarn': ('kjærlighetsbarn',),
'kjærlighetsbarna': ('kjærlighetsbarn',),
'kjærlighetsbarnene': ('kjærlighetsbarn',),
'kjærlighetsbarnet': ('kjærlighetsbarn',),
'kjærlighetsbrev': ('kjærlighetsbrev',),
'kjærlighetsbreva': ('kjærlighetsbrev',),
'kjærlighetsbrevene': ('kjærlighetsbrev',),
'kjærlighetsbrever': ('kjærlighetsbrev',),
'kjærlighetsbrevet': ('kjærlighetsbrev',),
'kjærlighetsdrikk': ('kjærlighetsdrikk',),
'kjærlighetsdrikken': ('kjærlighetsdrikk',),
'kjærlighetsdrikkene': ('kjærlighetsdrikk',),
'kjærlighetsdrikker': ('kjærlighetsdrikk',),
'kjærlighetsforhold': ('kjærlighetsforhold',),
'kjærlighetsforholda': ('kjærlighetsforhold',),
'kjærlighetsforholdene': ('kjærlighetsforhold',),
'kjærlighetsforholdet': ('kjærlighetsforhold',),
'kjærlighetsgud': ('kjærlighetsgud',),
'kjærlighetsguden': ('kjærlighetsgud',),
'kjærlighetsgudene': ('kjærlighetsgud',),
'kjærlighetsguder': ('kjærlighetsgud',),
'kjærlighetsgudinna': ('kjærlighetsgudinne',),
'kjærlighetsgudinne': ('kjærlighetsgudinne',),
'kjærlighetsgudinnen': ('kjærlighetsgudinne',),
'kjærlighetsgudinnene': ('kjærlighetsgudinne',),
'kjærlighetsgudinner': ('kjærlighetsgudinne',),
'kjærlighetshat': ('kjærlighetshat',),
'kjærlighetshata': ('kjærlighetshat',),
'kjærlighetshatene': ('kjærlighetshat',),
'kjærlighetshatet': ('kjærlighetshat',),
'kjærlighetshistoria': ('kjærlighetshistorie',),
'kjærlighetshistorie': ('kjærlighetshistorie',),
'kjærlighetshistorien': ('kjærlighetshistorie',),
'kjærlighetshistoriene': ('kjærlighetshistorie',),
'kjærlighetshistorier': ('kjærlighetshistorie',),
'kjærlighetsliv': ('kjærlighetsliv',),
'kjærlighetsliva': ('kjærlighetsliv',),
'kjærlighetslivene': ('kjærlighetsliv',),
'kjærlighetslivet': ('kjærlighetsliv',),
'kjærlighetsroman': ('kjærlighetsroman',),
'kjærlighetsromanen': ('kjærlighetsroman',),
'kjærlighetsromanene': ('kjærlighetsroman',),
'kjærlighetsromaner': ('kjærlighetsroman',),
'kjærlighetssorg': ('kjærlighetssorg',),
'kjærlighetssorga': ('kjærlighetssorg',),
'kjærlighetssorgen': ('kjærlighetssorg',),
'kjærlighetssorgene': ('kjærlighetssorg',),
'kjærlighetssorger': ('kjærlighetssorg',),
'kjærtegn': ('kjærtegn',),
'kjærtegna': ('kjærtegn',),
'kjærtegnene': ('kjærtegn',),
'kjærtegnet': ('kjærtegn',),
'kjæta': ('kjæte',),
'kjæte': ('kjæte',),
'kjæten': ('kjæte',),
'kjætene': ('kjæte',),
'kjæter': ('kjæte',),
'kjød': ('kjød',),
'kjøda': ('kjød',),
'kjødene': ('kjød',),
'kjødet': ('kjød',),
'kjødslyst': ('kjødslyst',),
'kjødslysta': ('kjødslyst',),
'kjødslysten': ('kjødslyst',),
'kjødslystene': ('kjødslyst',),
'kjødslyster': ('kjødslyst',),
'kjøa': ('kjøe',),
'kjøe': ('kjøe',),
'kjøen': ('kjøe',),
'kjøene': ('kjøe',),
'kjøer': ('kjøe',),
'kjøkemester': ('kjøkemester',),
'kjøkemestere': ('kjøkemester',),
'kjøkemesteren': ('kjøkemester',),
'kjøkemesterer': ('kjøkemester',),
'kjøkemesterne': ('kjøkemester',),
'kjøkemestre': ('kjøkemester',),
'kjøkemestrene': ('kjøkemester',),
'kjøkemestrer': ('kjøkemester',),
'kjøkken': ('kjøkken',),
'kjøkkena': ('kjøkken',),
'kjøkkenene': ('kjøkken',),
'kjøkkener': ('kjøkken',),
'kjøkkenet': ('kjøkken',),
'kjøkkenbenk': ('kjøkkenbenk',),
'kjøkkenbenken': ('kjøkkenbenk',),
'kjøkkenbenkene': ('kjøkkenbenk',),
'kjøkkenbenker': ('kjøkkenbenk',),
'kjøkkenhage': ('kjøkkenhage',),
'kjøkkenhagen': ('kjøkkenhage',),
'kjøkkenhagene': ('kjøkkenhage',),
'kjøkkenhager': ('kjøkkenhage',),
'kjøkkeninngang': ('kjøkkeninngang',),
'kjøkkeninngangen': ('kjøkkeninngang',),
'kjøkkeninngangene': ('kjøkkeninngang',),
'kjøkkeninnganger': ('kjøkkeninngang',),
'kjøkkenjenta': ('kjøkkenjente',),
'kjøkkenjente': ('kjøkkenjente',),
'kjøkkenjenten': ('kjøkkenjente',),
'kjøkkenjentene': ('kjøkkenjente',),
'kjøkkenjenter': ('kjøkkenjente',),
'kjøkkenkniv': ('kjøkkenkniv',),
'kjøkkenkniven': ('kjøkkenkniv',),
'kjøkkenknivene': ('kjøkkenkniv',),
'kjøkkenkniver': ('kjøkkenkniv',),
'kjøkkenkrok': ('kjøkkenkrok',),
'kjøkkenkroken': ('kjøkkenkrok',),
'kjøkkenkrokene': ('kjøkkenkrok',),
'kjøkkenkroker': ('kjøkkenkrok',),
'kjøkkenmaskin': ('kjøkkenmaskin',),
'kjøkkenmaskina': ('kjøkkenmaskin',),
'kjøkkenmaskinen': ('kjøkkenmaskin',),
'kjøkkenmaskinene': ('kjøkkenmaskin',),
'kjøkkenmaskiner': ('kjøkkenmaskin',),
'kjøkkenmødding': ('kjøkkenmødding',),
'kjøkkenmøddingen': ('kjøkkenmødding',),
'kjøkkenmøddingene': ('kjøkkenmødding',),
'kjøkkenmøddinger': ('kjøkkenmødding',),
'kjøkkensjef': ('kjøkkensjef',),
'kjøkkensjefen': ('kjøkkensjef',),
'kjøkkensjefene': ('kjøkkensjef',),
'kjøkkensjefer': ('kjøkkensjef',),
'kjøkkenskap': ('kjøkkenskap',),
'kjøkkenskapa': ('kjøkkenskap',),
'kjøkkenskapene': ('kjøkkenskap',),
'kjøkkenskapet': ('kjøkkenskap',),
'kjøkkenskriver': ('kjøkkenskriver',),
'kjøkkenskrivere': ('kjøkkenskriver',),
'kjøkkenskriveren': ('kjøkkenskriver',),
'kjøkkenskriverer': ('kjøkkenskriver',),
'kjøkkenskriverne': ('kjøkkenskriver',),
'kjøkkentrapp': ('kjøkkentrapp',),
'kjøkkentrappa': ('kjøkkentrapp',),
'kjøkkentrappen': ('kjøkkentrapp',),
'kjøkkentrappene': ('kjøkkentrapp',),
'kjøkkentrapper': ('kjøkkentrapp',),
'kjøkkentøy': ('kjøkkentøy',),
'kjøkkentøya': ('kjøkkentøy',),
'kjøkkentøyene': ('kjøkkentøy',),
'kjøkkentøyet': ('kjøkkentøy',),
'kjøkkenveg': ('kjøkkenveg',),
'kjøkkenvegen': ('kjøkkenveg',),
'kjøkkenvegene': ('kjøkkenveg',),
'kjøkkenveger': ('kjøkkenveg',),
'kjøkkenvei': ('kjøkkenvei',),
'kjøkkenveien': ('kjøkkenvei',),
'kjøkkenveiene': ('kjøkkenvei',),
'kjøkkenveier': ('kjøkkenvei',),
'kjøl': ('kjøl',),
'kjølen': ('kjøl',),
'kjølene': ('kjøl',),
'kjøler': ('kjøl',),
'kjøl': ('kjøl',),
'kjølen': ('kjøl',),
'kjølene': ('kjøl',),
'kjøler': ('kjøl',),
'kjølbord': ('kjølbord',),
'kjølborda': ('kjølbord',),
'kjølbordene': ('kjølbord',),
'kjølborder': ('kjølbord',),
'kjølbordet': ('kjølbord',),
'kjøld': ('kjøld',),
'kjølda': ('kjøld',),
'kjølden': ('kjøld',),
'kjøldene': ('kjøld',),
'kjølder': ('kjøld',),
'kjøleanlegg': ('kjøleanlegg',),
'kjøleanlegga': ('kjøleanlegg',),
'kjøleanleggene': ('kjøleanlegg',),
'kjøleanlegget': ('kjøleanlegg',),
'kjølebag': ('kjølebag',),
'kjølebagen': ('kjølebag',),
'kjølebagene': ('kjølebag',),
'kjølebager': ('kjølebag',),
'kjølebil': ('kjølebil',),
'kjølebilen': ('kjølebil',),
'kjølebilene': ('kjølebil',),
'kjølebiler': ('kjølebil',),
'kjøledisk': ('kjøledisk',),
'kjøledisken': ('kjøledisk',),
'kjølediskene': ('kjøledisk',),
'kjøledisker': ('kjøledisk',),
'kjøleelement': ('kjøleelement',),
'kjøleelementa': ('kjøleelement',),
'kjøleelementene': ('kjøleelement',),
'kjøleelementer': ('kjøleelement',),
'kjøleelementet': ('kjøleelement',),
'kjølekappa': ('kjølekappe',),
'kjølekappe': ('kjølekappe',),
'kjølekappen': ('kjølekappe',),
'kjølekappene': ('kjølekappe',),
'kjølekapper': ('kjølekappe',),
'kjølekonserv': ('kjølekonserv',),
'kjølekonserven': ('kjølekonserv',),
'kjølekonservene': ('kjølekonserv',),
'kjølekonserver': ('kjølekonserv',),
'kjølekonserve': ('kjølekonserve',),
'kjølekonserven': ('kjølekonserve',),
'kjølekonservene': ('kjølekonserve',),
'kjølekonserver': ('kjølekonserve',),
'kjølelager': ('kjølelager',),
'kjølelageret': ('kjølelager',),
'kjølelagra': ('kjølelager',),
'kjølelagre': ('kjølelager',),
'kjølelagrene': ('kjølelager',),
'kjølemaskin': ('kjølemaskin',),
'kjølemaskina': ('kjølemaskin',),
'kjølemaskinen': ('kjølemaskin',),
'kjølemaskinene': ('kjølemaskin',),
'kjølemaskiner': ('kjølemaskin',),
'kjøler': ('kjøler',),
'kjølere': ('kjøler',),
'kjøleren': ('kjøler',),
'kjølerer': ('kjøler',),
'kjølerne': ('kjøler',),
'kjølerom': ('kjølerom',),
'kjøleromma': ('kjølerom',),
'kjølerommene': ('kjølerom',),
'kjølerommet': ('kjølerom',),
'kjøleromstemperatur': ('kjøleromstemperatur',),
'kjøleromstemperaturen': ('kjøleromstemperatur',),
'kjøleromstemperaturene': ('kjøleromstemperatur',),
'kjøleromstemperaturer': ('kjøleromstemperatur',),
'kjøleskap': ('kjøleskap',),
'kjøleskapa': ('kjøleskap',),
'kjøleskapene': ('kjøleskap',),
'kjøleskapet': ('kjøleskap',),
'kjøleskapsdør': ('kjøleskapsdør',),
'kjøleskapsdøra': ('kjøleskapsdør',),
'kjøleskapsdøren': ('kjøleskapsdør',),
'kjøleskapsdørene': ('kjøleskapsdør',),
'kjøleskapsdører': ('kjøleskapsdør',),
'kjøleteknikk': ('kjøleteknikk',),
'kjøleteknikken': ('kjøleteknikk',),
'kjøleteknikkene': ('kjøleteknikk',),
'kjøleteknikker': ('kjøleteknikk',),
'kjølevann': ('kjølevann',),
'kjølevanna': ('kjølevann',),
'kjølevannene': ('kjølevann',),
'kjølevannet': ('kjølevann',),
'kjølevara': ('kjølevare',),
'kjølevare': ('kjølevare',),
'kjølevaren': ('kjølevare',),
'kjølevarene': ('kjølevare',),
'kjølevarer': ('kjølevare',),
'kjølevatn': ('kjølevatn',),
'kjølevatna': ('kjølevatn',),
'kjølevatnene': ('kjølevatn',),
'kjølevatnet': ('kjølevatn',),
'kjølevogn': ('kjølevogn',),
'kjølevogna': ('kjølevogn',),
'kjølevognen': ('kjølevogn',),
'kjølevognene': ('kjølevogn',),
'kjølevogner': ('kjølevogn',),
'kjølgang': ('kjølgang',),
'kjølgangen': ('kjølgang',),
'kjølgangene': ('kjølgang',),
'kjølganger': ('kjølgang',),
'kjølmakk': ('kjølmakk',),
'kjølmakken': ('kjølmakk',),
'kjølmakkene': ('kjølmakk',),
'kjølmakker': ('kjølmakk',),
'kjølmark': ('kjølmark',),
'kjølmarken': ('kjølmark',),
'kjølmarkene': ('kjølmark',),
'kjølmarker': ('kjølmark',),
'kjølna': ('kjølne',),
'kjølne': ('kjølne',),
'kjølnen': ('kjølne',),
'kjølnene': ('kjølne',),
'kjølner': ('kjølne',),
'kjølstripa': ('kjølstripe',),
'kjølstripe': ('kjølstripe',),
'kjølstripen': ('kjølstripe',),
'kjølstripene': ('kjølstripe',),
'kjølstriper': ('kjølstripe',),
'kjølsvin': ('kjølsvin',),
'kjølsvina': ('kjølsvin',),
'kjølsvinene': ('kjølsvin',),
'kjølsvinet': ('kjølsvin',),
'kjølvann': ('kjølvann',),
'kjølvanna': ('kjølvann',),
'kjølvannene': ('kjølvann',),
'kjølvannet': ('kjølvann',),
'kjølvatn': ('kjølvatn',),
'kjølvatna': ('kjølvatn',),
'kjølvatnene': ('kjølvatn',),
'kjølvatnet': ('kjølvatn',),
'kjømd': ('kjømd',),
'kjømda': ('kjømd',),
'kjømden': ('kjømd',),
'kjømdene': ('kjømd',),
'kjømder': ('kjømd',),
'kjønn': ('kjønn',),
'kjønna': ('kjønn',),
'kjønnene': ('kjønn',),
'kjønnet': ('kjønn',),
'kjønnsakt': ('kjønnsakt',),
'kjønnsakta': ('kjønnsakt',),
'kjønnsakten': ('kjønnsakt',),
'kjønnsaktene': ('kjønnsakt',),
'kjønnsakter': ('kjønnsakt',),
'kjønnsbøying': ('kjønnsbøying',),
'kjønnsbøyinga': ('kjønnsbøying',),
'kjønnsbøyingen': ('kjønnsbøying',),
'kjønnsbøyingene': ('kjønnsbøying',),
'kjønnsbøyinger': ('kjønnsbøying',),
'kjønnsbøyning': ('kjønnsbøyning',),
'kjønnsbøyninga': ('kjønnsbøyning',),
'kjønnsbøyningen': ('kjønnsbøyning',),
'kjønnsbøyningene': ('kjønnsbøyning',),
'kjønnsbøyninger': ('kjønnsbøyning',),
'kjønnscella': ('kjønnscelle',),
'kjønnscelle': ('kjønnscelle',),
'kjønnscellen': ('kjønnscelle',),
'kjønnscellene': ('kjønnscelle',),
'kjønnsceller': ('kjønnscelle',),
'kjønnsdel': ('kjønnsdel',),
'kjønnsdelen': ('kjønnsdel',),
'kjønnsdelene': ('kjønnsdel',),
'kjønnsdeler': ('kjønnsdel',),
'kjønnsdiskriminering': ('kjønnsdiskriminering',),
'kjønnsdiskrimineringa': ('kjønnsdiskriminering',),
'kjønnsdiskrimineringen': ('kjønnsdiskriminering',),
'kjønnsdiskrimineringene': ('kjønnsdiskriminering',),
'kjønnsdiskrimineringer': ('kjønnsdiskriminering',),
'kjønnsdrift': ('kjønnsdrift',),
'kjønnsdrifta': ('kjønnsdrift',),
'kjønnsdriften': ('kjønnsdrift',),
'kjønnsdriftene': ('kjønnsdrift',),
'kjønnsdrifter': ('kjønnsdrift',),
'kjønnshormon': ('kjønnshormon',),
'kjønnshormona': ('kjønnshormon',),
'kjønnshormonene': ('kjønnshormon',),
'kjønnshormoner': ('kjønnshormon',),
'kjønnshormonet': ('kjønnshormon',),
'kjønnskamp': ('kjønnskamp',),
'kjønnskampen': ('kjønnskamp',),
'kjønnskampene': ('kjønnskamp',),
'kjønnskamper': ('kjønnskamp',),
'kjønnskarakter': ('kjønnskarakter',),
'kjønnskarakteren': ('kjønnskarakter',),
'kjønnskarakterene': ('kjønnskarakter',),
'kjønnskarakterer': ('kjønnskarakter',),
'kjønnskjertel': ('kjønnskjertel',),
'kjønnskjertelen': ('kjønnskjertel',),
'kjønnskjertlene': ('kjønnskjertel',),
'kjønnskjertler': ('kjønnskjertel',),
'kjønnskromosom': ('kjønnskromosom',),
'kjønnskromosoma': ('kjønnskromosom',),
'kjønnskromosomene': ('kjønnskromosom',),
'kjønnskromosomer': ('kjønnskromosom',),
'kjønnskromosomet': ('kjønnskromosom',),
'kjønnskvotering': ('kjønnskvotering',),
'kjønnskvoteringa': ('kjønnskvotering',),
'kjønnskvoteringen': ('kjønnskvotering',),
'kjønnskvoteringene': ('kjønnskvotering',),
'kjønnskvoteringer': ('kjønnskvotering',),
'kjønnslem': ('kjønnslem',),
'kjønnslemma': ('kjønnslem',),
'kjønnslemmene': ('kjønnslem',),
'kjønnslemmer': ('kjønnslem',),
'kjønnslemmet': ('kjønnslem',),
'kjønnsleppa': ('kjønnsleppe',),
'kjønnsleppe': ('kjønnsleppe',),
'kjønnsleppen': ('kjønnsleppe',),
'kjønnsleppene': ('kjønnsleppe',),
'kjønnslepper': ('kjønnsleppe',),
'kjønnsliv': ('kjønnsliv',),
'kjønnsliva': ('kjønnsliv',),
'kjønnslivene': ('kjønnsliv',),
'kjønnslivet': ('kjønnsliv',),
'kjønnsobjekt': ('kjønnsobjekt',),
'kjønnsobjekta': ('kjønnsobjekt',),
'kjønnsobjektene': ('kjønnsobjekt',),
'kjønnsobjekter': ('kjønnsobjekt',),
'kjønnsobjektet': ('kjønnsobjekt',),
'kjønnsorgan': ('kjønnsorgan',),
'kjønnsorgana': ('kjønnsorgan',),
'kjønnsorganene': ('kjønnsorgan',),
'kjønnsorganer': ('kjønnsorgan',),
'kjønnsorganet': ('kjønnsorgan',),
'kjønnsrolla': ('kjønnsrolle',),
'kjønnsrolle': ('kjønnsrolle',),
'kjønnsrollen': ('kjønnsrolle',),
'kjønnsrollene': ('kjønnsrolle',),
'kjønnsroller': ('kjønnsrolle',),
'kjønnsrolledebatt': ('kjønnsrolledebatt',),
'kjønnsrolledebatten': ('kjønnsrolledebatt',),
'kjønnsrolledebattene': ('kjønnsrolledebatt',),
'kjønnsrolledebatter': ('kjønnsrolledebatt',),
'kjønnsrollemønster': ('kjønnsrollemønster',),
'kjønnsrollemønsteret': ('kjønnsrollemønster',),
'kjønnsrollemønstra': ('kjønnsrollemønster',),
'kjønnsrollemønstre': ('kjønnsrollemønster',),
'kjønnsrollemønstrene': ('kjønnsrollemønster',),
'kjønnsrollemønstret': ('kjønnsrollemønster',),
'kjønnssjukdom': ('kjønnssjukdom',),
'kjønnssjukdommen': ('kjønnssjukdom',),
'kjønnssjukdommene': ('kjønnssjukdom',),
'kjønnssjukdommer': ('kjønnssjukdom',),
'kjønnsskifta': ('kjønnsskifte',),
'kjønnsskifte': ('kjønnsskifte',),
'kjønnsskiftene': ('kjønnsskifte',),
'kjønnsskifter': ('kjønnsskifte',),
'kjønnsskiftet': ('kjønnsskifte',),
'kjønnssykdom': ('kjønnssykdom',),
'kjønnssykdommen': ('kjønnssykdom',),
'kjønnssykdommene': ('kjønnssykdom',),
'kjønnssykdommer': ('kjønnssykdom',),
'kjønrøk': ('kjønrøk',),
'kjønrøken': ('kjønrøk',),
'kjønrøkene': ('kjønrøk',),
'kjønrøker': ('kjønrøk',),
'kjøp': ('kjøp',),
'kjøpa': ('kjøp',),
'kjøpene': ('kjøp',),
'kjøpet': ('kjøp',),
'kjøpekontrakt': ('kjøpekontrakt',),
'kjøpekontrakten': ('kjøpekontrakt',),
'kjøpekontraktene': ('kjøpekontrakt',),
'kjøpekontrakter': ('kjøpekontrakt',),
'kjøpekort': ('kjøpekort',),
'kjøpekorta': ('kjøpekort',),
'kjøpekortene': ('kjøpekort',),
'kjøpekortet': ('kjøpekort',),
'kjøpekraft': ('kjøpekraft',),
'kjøpekrafta': ('kjøpekraft',),
'kjøpekraften': ('kjøpekraft',),
'kjøpekreftene': ('kjøpekraft',),
'kjøpekrefter': ('kjøpekraft',),
'kjøpepress': ('kjøpepress',),
'kjøpepressa': ('kjøpepress',),
'kjøpepressene': ('kjøpepress',),
'kjøpepresset': ('kjøpepress',),
'kjøper': ('kjøper',),
'kjøpere': ('kjøper',),
'kjøperen': ('kjøper',),
'kjøperer': ('kjøper',),
'kjøperne': ('kjøper',),
'kjøpesenter': ('kjøpesenter',),
'kjøpesenteret': ('kjøpesenter',),
'kjøpesentra': ('kjøpesenter',),
'kjøpesentre': ('kjøpesenter',),
'kjøpesentrene': ('kjøpesenter',),
'kjøpesentret': ('kjøpesenter',),
'kjøpesum': ('kjøpesum',),
'kjøpesummen': ('kjøpesum',),
'kjøpesummene': ('kjøpesum',),
'kjøpesummer': ('kjøpesum',),
'kjøpetillatelse': ('kjøpetillatelse',),
'kjøpetillatelsen': ('kjøpetillatelse',),
'kjøpetillatelsene': ('kjøpetillatelse',),
'kjøpetillatelser': ('kjøpetillatelse',),
'kjøpmann': ('kjøpmann',),
'kjøpmannen': ('kjøpmann',),
'kjøpmenn': ('kjøpmann',),
'kjøpmennene': ('kjøpmann',),
'kjøpskål': ('kjøpskål',),
'kjøpskålen': ('kjøpskål',),
'kjøpskålene': ('kjøpskål',),
'kjøpskåler': ('kjøpskål',),
'kjøpslov': ('kjøpslov',),
'kjøpsloven': ('kjøpslov',),
'kjøpslovene': ('kjøpslov',),
'kjøpslover': ('kjøpslov',),
'kjøpstad': ('kjøpstad',),
'kjøpstaden': ('kjøpstad',),
'kjøpstedene': ('kjøpstad',),
'kjøpsteder': ('kjøpstad',),
'kjør': ('kjør',),
'kjøra': ('kjør',),
'kjørene': ('kjør',),
'kjøret': ('kjør',),
'kjørebane': ('kjørebane',),
'kjørebanen': ('kjørebane',),
'kjørebanene': ('kjørebane',),
'kjørebaner': ('kjørebane',),
'kjørebro': ('kjørebro',),
'kjørebroa': ('kjørebro',),
'kjørebroen': ('kjørebro',),
'kjørebroene': ('kjørebro',),
'kjørebroer': ('kjørebro',),
'kjørebru': ('kjørebru',),
'kjørebrua': ('kjørebru',),
'kjørebruen': ('kjørebru',),
'kjørebruene': ('kjørebru',),
'kjørebruer': ('kjørebru',),
'kjøredoning': ('kjøredoning',),
'kjøredoninga': ('kjøredoning',),
'kjøredoningen': ('kjøredoning',),
'kjøredoningene': ('kjøredoning',),
'kjøredoninger': ('kjøredoning',),
'kjøreegenskap': ('kjøreegenskap',),
'kjøreegenskapen': ('kjøreegenskap',),
'kjøreegenskapene': ('kjøreegenskap',),
'kjøreegenskaper': ('kjøreegenskap',),
'kjørefelt': ('kjørefelt',),
'kjørefelta': ('kjørefelt',),
'kjørefeltene': ('kjørefelt',),
'kjørefelter': ('kjørefelt',),
'kjørefeltet': ('kjørefelt',),
'kjørefil': ('kjørefil',),
'kjørefilen': ('kjørefil',),
'kjørefilene': ('kjørefil',),
'kjørefiler': ('kjørefil',),
'kjørekar': ('kjørekar',),
'kjørekaren': ('kjørekar',),
'kjørekarene': ('kjørekar',),
'kjørekarer': ('kjørekar',),
'kjørel': ('kjørel',),
'kjørela': ('kjørel',),
'kjørelene': ('kjørel',),
'kjøreler': ('kjørel',),
'kjørelet': ('kjørel',),
'kjørla': ('kjørel',),
'kjørlene': ('kjørel',),
'kjørler': ('kjørel',),
'kjørlet': ('kjørel',),
'kjørel': ('kjørel',),
'kjørela': ('kjørel',),
'kjørelene': ('kjørel',),
'kjøreler': ('kjørel',),
'kjørelet': ('kjørel',),
'kjørla': ('kjørel',),
'kjørlene': ('kjørel',),
'kjørler': ('kjørel',),
'kjørlet': ('kjørel',),
'kjøreplan': ('kjøreplan',),
'kjøreplanen': ('kjøreplan',),
'kjøreplanene': ('kjøreplan',),
'kjøreplaner': ('kjøreplan',),
'kjører': ('kjører',),
'kjørere': ('kjører',),
'kjøreren': ('kjører',),
'kjørerer': ('kjører',),
'kjørerne': ('kjører',),
'kjøreretning': ('kjøreretning',),
'kjøreretninga': ('kjøreretning',),
'kjøreretningen': ('kjøreretning',),
'kjøreretningene': ('kjøreretning',),
'kjøreretninger': ('kjøreretning',),
'kjøreskole': ('kjøreskole',),
'kjøreskolen': ('kjøreskole',),
'kjøreskolene': ('kjøreskole',),
'kjøreskoler': ('kjøreskole',),
'kjøretur': ('kjøretur',),
'kjøreturen': ('kjøretur',),
'kjøreturene': ('kjøretur',),
'kjøreturer': ('kjøretur',),
'kjøretøy': ('kjøretøy',),
'kjøretøya': ('kjøretøy',),
'kjøretøyene': ('kjøretøy',),
'kjøretøyer': ('kjøretøy',),
'kjøretøyet': ('kjøretøy',),
'kjøreveg': ('kjøreveg',),
'kjørevegen': ('kjøreveg',),
'kjørevegene': ('kjøreveg',),
'kjøreveger': ('kjøreveg',),
'kjørevei': ('kjørevei',),
'kjøreveien': ('kjørevei',),
'kjøreveiene': ('kjørevei',),
'kjøreveier': ('kjørevei',),
'kjøring': ('kjøring',),
'kjøringa': ('kjøring',),
'kjøringen': ('kjøring',),
'kjøringene': ('kjøring',),
'kjøringer': ('kjøring',),
'kjørner': ('kjørner',),
'kjørnere': ('kjørner',),
'kjørneren': ('kjørner',),
'kjørnerer': ('kjørner',),
'kjørnerne': ('kjørner',),
'kjørsel': ('kjørsel',),
'kjørselen': ('kjørsel',),
'kjørsla': ('kjørsel',),
'kjørslene': ('kjørsel',),
'kjørsler': ('kjørsel',),
'kjørvel': ('kjørvel',),
'kjørvelen': ('kjørvel',),
'kjørvlene': ('kjørvel',),
'kjørvler': ('kjørvel',),
'kjøter': ('kjøter',),
'kjøtere': ('kjøter',),
'kjøteren': ('kjøter',),
'kjøterer': ('kjøter',),
'kjøterne': ('kjøter',),
'kjøtt': ('kjøtt',),
'kjøtta': ('kjøtt',),
'kjøttene': ('kjøtt',),
'kjøttet': ('kjøtt',),
'kjøttbein': ('kjøttbein',),
'kjøttbeina': ('kjøttbein',),
'kjøttbeinene': ('kjøttbein',),
'kjøttbeinet': ('kjøttbein',),
'kjøttben': ('kjøttben',),
'kjøttbena': ('kjøttben',),
'kjøttbenene': ('kjøttben',),
'kjøttbenet': ('kjøttben',),
'kjøttberg': ('kjøttberg',),
'kjøttberga': ('kjøttberg',),
'kjøttbergene': ('kjøttberg',),
'kjøttberget': ('kjøttberg',),
'kjøttdeig': ('kjøttdeig',),
'kjøttdeigen': ('kjøttdeig',),
'kjøttdeigene': ('kjøttdeig',),
'kjøttdeiger': ('kjøttdeig',),
'kjøttekstrakt': ('kjøttekstrakt',),
'kjøttekstrakten': ('kjøttekstrakt',),
'kjøttekstraktene': ('kjøttekstrakt',),
'kjøttekstrakter': ('kjøttekstrakt',),
'kjøtteter': ('kjøtteter',),
'kjøttetere': ('kjøtteter',),
'kjøtteteren': ('kjøtteter',),
'kjøtteterer': ('kjøtteter',),
'kjøtteterne': ('kjøtteter',),
'kjøttfarse': ('kjøttfarse',),
'kjøttfarsen': ('kjøttfarse',),
'kjøttfarsene': ('kjøttfarse',),
'kjøttfarser': ('kjøttfarse',),
'kjøttflua': ('kjøttflue',),
'kjøttflue': ('kjøttflue',),
'kjøttfluen': ('kjøttflue',),
'kjøttfluene': ('kjøttflue',),
'kjøttfluer': ('kjøttflue',),
'kjøttgryta': ('kjøttgryte',),
'kjøttgryte': ('kjøttgryte',),
'kjøttgryten': ('kjøttgryte',),
'kjøttgrytene': ('kjøttgryte',),
'kjøttgryter': ('kjøttgryte',),
'kjøttkaka': ('kjøttkake',),
'kjøttkake': ('kjøttkake',),
'kjøttkaken': ('kjøttkake',),
'kjøttkakene': ('kjøttkake',),
'kjøttkaker': ('kjøttkake',),
'kjøttkontroll': ('kjøttkontroll',),
'kjøttkontrollen': ('kjøttkontroll',),
'kjøttkontrollene': ('kjøttkontroll',),
'kjøttkontroller': ('kjøttkontroll',),
'kjøttkvern': ('kjøttkvern',),
'kjøttkverna': ('kjøttkvern',),
'kjøttkvernen': ('kjøttkvern',),
'kjøttkvernene': ('kjøttkvern',),
'kjøttkverner': ('kjøttkvern',),
'kjøttmeis': ('kjøttmeis',),
'kjøttmeisa': ('kjøttmeis',),
'kjøttmeisen': ('kjøttmeis',),
'kjøttmeisene': ('kjøttmeis',),
'kjøttmeiser': ('kjøttmeis',),
'kjøttpudding': ('kjøttpudding',),
'kjøttpuddingen': ('kjøttpudding',),
'kjøttpuddingene': ('kjøttpudding',),
'kjøttpuddinger': ('kjøttpudding',),
'kjøttsag': ('kjøttsag',),
'kjøttsaga': ('kjøttsag',),
'kjøttsagen': ('kjøttsag',),
'kjøttsagene': ('kjøttsag',),
'kjøttsager': ('kjøttsag',),
'kjøttsida': ('kjøttside',),
'kjøttside': ('kjøttside',),
'kjøttsiden': ('kjøttside',),
'kjøttsidene': ('kjøttside',),
'kjøttsider': ('kjøttside',),
'kjøttsuppa': ('kjøttsuppe',),
'kjøttsuppe': ('kjøttsuppe',),
'kjøttsuppen': ('kjøttsuppe',),
'kjøttsuppene': ('kjøttsuppe',),
'kjøttsupper': ('kjøttsuppe',),
'kjøttsår': ('kjøttsår',),
'kjøttsåra': ('kjøttsår',),
'kjøttsårene': ('kjøttsår',),
'kjøttsåret': ('kjøttsår',),
'kjøttøks': ('kjøttøks',),
'kjøttøksa': ('kjøttøks',),
'kjøttøksen': ('kjøttøks',),
'kjøttøksene': ('kjøttøks',),
'kjøttøkser': ('kjøttøks',),
'kjøv': ('kjøv',),
'kjøva': ('kjøv',),
'kjøvene': ('kjøv',),
'kjøvet': ('kjøv',),
'klabautermann': ('klabautermann',),
'klabautermannen': ('klabautermann',),
'klabautermenn': ('klabautermann',),
'klabautermennene': ('klabautermann',),
'klabb': ('klabb',),
'klabben': ('klabb',),
'klabbene': ('klabb',),
'klabber': ('klabb',),
'klabbeføra': ('klabbeføre',),
'klabbeføre': ('klabbeføre',),
'klabbeførene': ('klabbeføre',),
'klabbefører': ('klabbeføre',),
'klabbeføret': ('klabbeføre',),
'kladas': ('kladas',),
'kladasen': ('kladas',),
'kladasene': ('kladas',),
'kladaser': ('kladas',),
'kladd': ('kladd',),
'kladden': ('kladd',),
'kladdene': ('kladd',),
'kladder': ('kladd',),
'kladdeføra': ('kladdeføre',),
'kladdeføre': ('kladdeføre',),
'kladdeførene': ('kladdeføre',),
'kladdefører': ('kladdeføre',),
'kladdeføret': ('kladdeføre',),
'kladdepapir': ('kladdepapir',),
'kladdepapira': ('kladdepapir',),
'kladdepapirene': ('kladdepapir',),
'kladdepapirer': ('kladdepapir',),
'kladdepapiret': ('kladdepapir',),
'klaffebord': ('klaffebord',),
'klaffeborda': ('klaffebord',),
'klaffebordene': ('klaffebord',),
'klaffeborder': ('klaffebord',),
'klaffebordet': ('klaffebord',),
'klaga': ('klage',),
'klage': ('klage',),
'klagen': ('klage',),
'klagene': ('klage',),
'klager': ('klage',),
'klagebrev': ('klagebrev',),
'klagebreva': ('klagebrev',),
'klagebrevene': ('klagebrev',),
'klagebrever': ('klagebrev',),
'klagebrevet': ('klagebrev',),
'klagemål': ('klagemål',),
'klagemåla': ('klagemål',),
'klagemålene': ('klagemål',),
'klagemålet': ('klagemål',),
'klagenemnd': ('klagenemnd',),
'klagenemnda': ('klagenemnd',),
'klagenemnden': ('klagenemnd',),
'klagenemndene': ('klagenemnd',),
'klagenemnder': ('klagenemnd',),
'klager': ('klager',),
'klagere': ('klager',),
'klageren': ('klager',),
'klagerer': ('klager',),
'klagerne': ('klager',),
'klagerop': ('klagerop',),
'klageropa': ('klagerop',),
'klageropene': ('klagerop',),
'klageropet': ('klagerop',),
'klagesang': ('klagesang',),
'klagesangen': ('klagesang',),
'klagesangene': ('klagesang',),
'klagesanger': ('klagesang',),
'klageskriv': ('klageskriv',),
'klageskriva': ('klageskriv',),
'klageskrivene': ('klageskriv',),
'klageskrivet': ('klageskriv',),
'klageskrivelse': ('klageskrivelse',),
'klageskrivelsen': ('klageskrivelse',),
'klageskrivelsene': ('klageskrivelse',),
'klageskrivelser': ('klageskrivelse',),
'klake': ('klake',),
'klaken': ('klake',),
'klakene': ('klake',),
'klaker': ('klake',),
'klakk': ('klakk',),
'klakken': ('klakk',),
'klakkene': ('klakk',),
'klakker': ('klakk',),
'klakør': ('klakør',),
'klakøren': ('klakør',),
'klakørene': ('klakør',),
'klakører': ('klakør',),
'klamme': ('klamme',),
'klammen': ('klamme',),
'klammene': ('klamme',),
'klammer': ('klamme',),
'klammeform': ('klammeform',),
'klammeforma': ('klammeform',),
'klammeformen': ('klammeform',),
'klammeformene': ('klammeform',),
'klammeformer': ('klammeform',),
'klammer': ('klammer',),
'klammere': ('klammer',),
'klammeren': ('klammer',),
'klammerer': ('klammer',),
'klammerne': ('klammer',),
'klamrene': ('klammer',),
'klamrer': ('klammer',),
'klammer': ('klammer',),
'klammeret': ('klammer',),
'klamra': ('klammer',),
'klamre': ('klammer',),
'klamrene': ('klammer',),
'klammeri': ('klammeri',),
'klammeria': ('klammeri',),
'klammeriene': ('klammeri',),
'klammerier': ('klammeri',),
'klammeriet': ('klammeri',),
'klamp': ('klamp',),
'klampen': ('klamp',),
'klampene': ('klamp',),
'klamper': ('klamp',),
'klamydia': ('klamydia',),
'klamydiaen': ('klamydia',),
'klamydiaene': ('klamydia',),
'klamydiaer': ('klamydia',),
'klan': ('klan',),
'klanen': ('klan',),
'klanene': ('klan',),
'klaner': ('klan',),
'klanbror': ('klanbror',),
'klanbroren': ('klanbror',),
'klanbrødre': ('klanbror',),
'klanbrødrene': ('klanbror',),
'klander': ('klander',),
'klandera': ('klander',),
'klandere': ('klander',),
'klanderen': ('klander',),
'klanderene': ('klander',),
'klanderer': ('klander',),
'klanderet': ('klander',),
'klanderne': ('klander',),
'klandre': ('klander',),
'klandrene': ('klander',),
'klandrer': ('klander',),
'klang': ('klang',),
'klangen': ('klang',),
'klangene': ('klang',),
'klanger': ('klang',),
'klangbotn': ('klangbotn',),
'klangbotnen': ('klangbotn',),
'klangbotnene': ('klangbotn',),
'klangbotner': ('klangbotn',),
'klangbunn': ('klangbunn',),
'klangbunnen': ('klangbunn',),
'klangbunnene': ('klangbunn',),
'klangbunner': ('klangbunn',),
'klangfarge': ('klangfarge',),
'klangfargen': ('klangfarge',),
'klangfargene': ('klangfarge',),
'klangfarger': ('klangfarge',),
'klangfylde': ('klangfylde',),
'klangfylden': ('klangfylde',),
'klangfyldene': ('klangfylde',),
'klangfylder': ('klangfylde',),
'klangfylle': ('klangfylle',),
'klangfyllen': ('klangfylle',),
'klangfyllene': ('klangfylle',),
'klangfyller': ('klangfylle',),
'klangmasse': ('klangmasse',),
'klangmassen': ('klangmasse',),
'klangmassene': ('klangmasse',),
'klangmasser': ('klangmasse',),
'klangvirkning': ('klangvirkning',),
'klangvirkninga': ('klangvirkning',),
'klangvirkningen': ('klangvirkning',),
'klangvirkningene': ('klangvirkning',),
'klangvirkninger': ('klangvirkning',),
'klansystem': ('klansystem',),
'klansystema': ('klansystem',),
'klansystemene': ('klansystem',),
'klansystemer': ('klansystem',),
'klansystemet': ('klansystem',),
'klant': ('klant',),
'klanten': ('klant',),
'klantene': ('klant',),
'klanter': ('klant',),
'klapp': ('klapp',),
'klappen': ('klapp',),
'klappene': ('klapp',),
'klapper': ('klapp',),
'klapp': ('klapp',),
'klappa': ('klapp',),
'klappen': ('klapp',),
'klappene': ('klapp',),
'klapper': ('klapp',),
'klappet': ('klapp',),
'klapper': ('klapper',),
'klappere': ('klapper',),
'klapperen': ('klapper',),
'klapperer': ('klapper',),
'klapperne': ('klapper',),
'klapperslange': ('klapperslange',),
'klapperslangen': ('klapperslange',),
'klapperslangene': ('klapperslange',),
'klapperslanger': ('klapperslange',),
'klapphingst': ('klapphingst',),
'klapphingsten': ('klapphingst',),
'klapphingstene': ('klapphingst',),
'klapphingster': ('klapphingst',),
'klappjakt': ('klappjakt',),
'klappjakta': ('klappjakt',),
'klappjakten': ('klappjakt',),
'klappjaktene': ('klappjakt',),
'klappjakter': ('klappjakt',),
'klappmyss': ('klappmyss',),
'klappmyssen': ('klappmyss',),
'klappmyssene': ('klappmyss',),
'klappmysser': ('klappmyss',),
'klappseta': ('klappsete',),
'klappsete': ('klappsete',),
'klappsetene': ('klappsete',),
'klappseter': ('klappsete',),
'klappsetet': ('klappsete',),
'klaps': ('klaps',),
'klapsa': ('klaps',),
'klapsen': ('klaps',),
'klapsene': ('klaps',),
'klapset': ('klaps',),
'klara': ('klare',),
'klare': ('klare',),
'klaren': ('klare',),
'klarene': ('klare',),
'klarer': ('klare',),
'klareskinn': ('klareskinn',),
'klareskinna': ('klareskinn',),
'klareskinnene': ('klareskinn',),
'klareskinnet': ('klareskinn',),
'klarhet': ('klarhet',),
'klarheta': ('klarhet',),
'klarheten': ('klarhet',),
'klarhetene': ('klarhet',),
'klarheter': ('klarhet',),
'klarinett': ('klarinett',),
'klarinetten': ('klarinett',),
'klarinettene': ('klarinett',),
'klarinetter': ('klarinett',),
'klarinettist': ('klarinettist',),
'klarinettisten': ('klarinettist',),
'klarinettistene': ('klarinettist',),
'klarinettister': ('klarinettist',),
'klaring': ('klaring',),
'klaringa': ('klaring',),
'klaringen': ('klaring',),
'klaringene': ('klaring',),
'klaringer': ('klaring',),
'klarsignal': ('klarsignal',),
'klarsignala': ('klarsignal',),
'klarsignalene': ('klarsignal',),
'klarsignaler': ('klarsignal',),
'klarsignalet': ('klarsignal',),
'klarsyn': ('klarsyn',),
'klarsyna': ('klarsyn',),
'klarsynene': ('klarsyn',),
'klarsynet': ('klarsyn',),
'klartekst': ('klartekst',),
'klarteksta': ('klartekst',),
'klarteksten': ('klartekst',),
'klartekstene': ('klartekst',),
'klartekster': ('klartekst',),
'klarvær': ('klarvær',),
'klarværa': ('klarvær',),
'klarværene': ('klarvær',),
'klarværet': ('klarvær',),
'klase': ('klase',),
'klasen': ('klase',),
'klasene': ('klase',),
'klaser': ('klase',),
'klask': ('klask',),
'klaska': ('klask',),
'klasken': ('klask',),
'klaskene': ('klask',),
'klasker': ('klask',),
'klasket': ('klask',),
'klassa': ('klasse',),
'klasse': ('klasse',),
'klassen': ('klasse',),
'klassene': ('klasse',),
'klasser': ('klasse',),
'klasseavis': ('klasseavis',),
'klasseavisa': ('klasseavis',),
'klasseavisen': ('klasseavis',),
'klasseavisene': ('klasseavis',),
'klasseaviser': ('klasseavis',),
'klasseforræder': ('klasseforræder',),
'klasseforrædere': ('klasseforræder',),
'klasseforræderen': ('klasseforræder',),
'klasseforræderer': ('klasseforræder',),
'klasseforræderne': ('klasseforræder',),
'klasseforskjell': ('klasseforskjell',),
'klasseforskjellen': ('klasseforskjell',),
'klasseforskjellene': ('klasseforskjell',),
'klasseforskjeller': ('klasseforskjell',),
'klasseforstander': ('klasseforstander',),
'klasseforstandere': ('klasseforstander',),
'klasseforstanderen': ('klasseforstander',),
'klasseforstanderer': ('klasseforstander',),
'klasseforstanderne': ('klasseforstander',),
'klassefradrag': ('klassefradrag',),
'klassefradraga': ('klassefradrag',),
'klassefradragene': ('klassefradrag',),
'klassefradraget': ('klassefradrag',),
'klassehat': ('klassehat',),
'klassehata': ('klassehat',),
'klassehatene': ('klassehat',),
'klassehatet': ('klassehat',),
'klasseinteresse': ('klasseinteresse',),
'klasseinteressen': ('klasseinteresse',),
'klasseinteressene': ('klasseinteresse',),
'klasseinteresser': ('klasseinteresse',),
'klassekamerat': ('klassekamerat',),
'klassekameraten': ('klassekamerat',),
'klassekameratene': ('klassekamerat',),
'klassekamerater': ('klassekamerat',),
'klassekamp': ('klassekamp',),
'klassekampen': ('klassekamp',),
'klassekampene': ('klassekamp',),
'klassekamper': ('klassekamp',),
'klassekontakt': ('klassekontakt',),
'klassekontakten': ('klassekontakt',),
'klassekontaktene': ('klassekontakt',),
'klassekontakter': ('klassekontakt',),
'klasselærer': ('klasselærer',),
'klasselærere': ('klasselærer',),
'klasselæreren': ('klasselærer',),
'klasselærerer': ('klasselærer',),
'klasselærerne': ('klasselærer',),
'klassemotsetning': ('klassemotsetning',),
'klassemotsetninga': ('klassemotsetning',),
'klassemotsetningen': ('klassemotsetning',),
'klassemotsetningene': ('klassemotsetning',),
'klassemotsetninger': ('klassemotsetning',),
'klassepurk': ('klassepurk',),
'klassepurken': ('klassepurk',),
'klassepurkene': ('klassepurk',),
'klassepurker': ('klassepurk',),
'klasserom': ('klasserom',),
'klasseromma': ('klasserom',),
'klasserommene': ('klasserom',),
'klasserommet': ('klasserom',),
'klassesamfunn': ('klassesamfunn',),
'klassesamfunna': ('klassesamfunn',),
'klassesamfunnene': ('klassesamfunn',),
'klassesamfunnet': ('klassesamfunn',),
'klassetrinn': ('klassetrinn',),
'klassetrinna': ('klassetrinn',),
'klassetrinnene': ('klassetrinn',),
'klassetrinnet': ('klassetrinn',),
'klasseundervisning': ('klasseundervisning',),
'klasseundervisninga': ('klasseundervisning',),
'klasseundervisningen': ('klasseundervisning',),
'klasseundervisningene': ('klasseundervisning',),
'klasseundervisninger': ('klasseundervisning',),
'klassevinner': ('klassevinner',),
'klassevinnere': ('klassevinner',),
'klassevinneren': ('klassevinner',),
'klassevinnerer': ('klassevinner',),
'klassevinnerne': ('klassevinner',),
'klassifikasjon': ('klassifikasjon',),
'klassifikasjonen': ('klassifikasjon',),
'klassifikasjonene': ('klassifikasjon',),
'klassifikasjoner': ('klassifikasjon',),
'klassiker': ('klassiker',),
'klassikere': ('klassiker',),
'klassikeren': ('klassiker',),
'klassikerer': ('klassiker',),
'klassikerne': ('klassiker',),
'klassikk': ('klassikk',),
'klassikken': ('klassikk',),
'klassikkene': ('klassikk',),
'klassikker': ('klassikk',),
'klassisisme': ('klassisisme',),
'klassisismen': ('klassisisme',),
'klassisismene': ('klassisisme',),
'klassisismer': ('klassisisme',),
'klatrefot': ('klatrefot',),
'klatrefoten': ('klatrefot',),
'klatreføttene': ('klatrefot',),
'klatreføtter': ('klatrefot',),
'klatremus': ('klatremus',),
'klatremusa': ('klatremus',),
'klatremusen': ('klatremus',),
'klatremusene': ('klatremus',),
'klatreplanta': ('klatreplante',),
'klatreplante': ('klatreplante',),
'klatreplanten': ('klatreplante',),
'klatreplantene': ('klatreplante',),
'klatreplanter': ('klatreplante',),
'klatrer': ('klatrer',),
'klatrere': ('klatrer',),
'klatreren': ('klatrer',),
'klatrerer': ('klatrer',),
'klatrerne': ('klatrer',),
'klatrerosa': ('klatrerose',),
'klatrerose': ('klatrerose',),
'klatrerosen': ('klatrerose',),
'klatrerosene': ('klatrerose',),
'klatreroser': ('klatrerose',),
'klatresamfunn': ('klatresamfunn',),
'klatresamfunna': ('klatresamfunn',),
'klatresamfunnene': ('klatresamfunn',),
'klatresamfunnet': ('klatresamfunn',),
'klatresport': ('klatresport',),
'klatresporten': ('klatresport',),
'klatresportene': ('klatresport',),
'klatresporter': ('klatresport',),
'klatretau': ('klatretau',),
'klatretaua': ('klatretau',),
'klatretauene': ('klatretau',),
'klatretauer': ('klatretau',),
'klatretauet': ('klatretau',),
'klatrevegg': ('klatrevegg',),
'klatreveggen': ('klatrevegg',),
'klatreveggene': ('klatrevegg',),
'klatrevegger': ('klatrevegg',),
'klatt': ('klatt',),
'klatten': ('klatt',),
'klattene': ('klatt',),
'klatter': ('klatt',),
'klattegjeld': ('klattegjeld',),
'klattegjelda': ('klattegjeld',),
'klattegjelden': ('klattegjeld',),
'klattegjeldene': ('klattegjeld',),
'klattegjelder': ('klattegjeld',),
'klattemaler': ('klattemaler',),
'klattemalere': ('klattemaler',),
'klattemaleren': ('klattemaler',),
'klattemalerer': ('klattemaler',),
'klattemalerne': ('klattemaler',),
'klatteri': ('klatteri',),
'klatteria': ('klatteri',),
'klatteriene': ('klatteri',),
'klatterier': ('klatteri',),
'klatteriet': ('klatteri',),
'klattgjeld': ('klattgjeld',),
'klattgjelda': ('klattgjeld',),
'klattgjelden': ('klattgjeld',),
'klattgjeldene': ('klattgjeld',),
'klattgjelder': ('klattgjeld',),
'klattmaler': ('klattmaler',),
'klattmalere': ('klattmaler',),
'klattmaleren': ('klattmaler',),
'klattmalerer': ('klattmaler',),
'klattmalerne': ('klattmaler',),
'klaustrofobi': ('klaustrofobi',),
'klaustrofobien': ('klaustrofobi',),
'klaustrofobiene': ('klaustrofobi',),
'klaustrofobier': ('klaustrofobi',),
'klausul': ('klausul',),
'klausulen': ('klausul',),
'klausulene': ('klausul',),
'klausuler': ('klausul',),
'klauv': ('klauv',),
'klauva': ('klauv',),
'klauven': ('klauv',),
'klauvene': ('klauv',),
'klauver': ('klauv',),
'klauvdyr': ('klauvdyr',),
'klauvdyra': ('klauvdyr',),
'klauvdyrene': ('klauvdyr',),
'klauvdyret': ('klauvdyr',),
'klauvsjuka': ('klauvsjuke',),
'klauvsjuke': ('klauvsjuke',),
'klauvsjuken': ('klauvsjuke',),
'klauvsjukene': ('klauvsjuke',),
'klauvsjuker': ('klauvsjuke',),
'klauvsyka': ('klauvsyke',),
'klauvsyke': ('klauvsyke',),
'klauvsyken': ('klauvsyke',),
'klauvsykene': ('klauvsyke',),
'klauvsyker': ('klauvsyke',),
'klave': ('klave',),
'klaven': ('klave',),
'klavene': ('klave',),
'klaver': ('klave',),
'klaver': ('klaver',),
'klavera': ('klaver',),
'klaverene': ('klaver',),
'klaverer': ('klaver',),
'klaveret': ('klaver',),
'klaveraften': ('klaveraften',),
'klaveraftenen': ('klaveraften',),
'klaveraftenene': ('klaveraften',),
'klaveraftener': ('klaveraften',),
'klaverakkompagnement': ('klaverakkompagnement',),
'klaverakkompagnementa': ('klaverakkompagnement',),
'klaverakkompagnementene': ('klaverakkompagnement',),
'klaverakkompagnementer': ('klaverakkompagnement',),
'klaverakkompagnementet': ('klaverakkompagnement',),
'klaverinstrument': ('klaverinstrument',),
'klaverinstrumenta': ('klaverinstrument',),
'klaverinstrumentene': ('klaverinstrument',),
'klaverinstrumenter': ('klaverinstrument',),
'klaverinstrumentet': ('klaverinstrument',),
'klaverkonsert': ('klaverkonsert',),
'klaverkonserten': ('klaverkonsert',),
'klaverkonsertene': ('klaverkonsert',),
'klaverkonserter': ('klaverkonsert',),
'klaverpartitur': ('klaverpartitur',),
'klaverpartitura': ('klaverpartitur',),
'klaverpartiturene': ('klaverpartitur',),
'klaverpartiturer': ('klaverpartitur',),
'klaverpartituret': ('klaverpartitur',),
'klaveruttog': ('klaveruttog',),
'klaveruttoga': ('klaveruttog',),
'klaveruttogene': ('klaveruttog',),
'klaveruttoger': ('klaveruttog',),
'klaveruttoget': ('klaveruttog',),
'klaviatur': ('klaviatur',),
'klaviatura': ('klaviatur',),
'klaviaturen': ('klaviatur',),
'klaviaturene': ('klaviatur',),
'klaviaturer': ('klaviatur',),
'klaviaturet': ('klaviatur',),
'klavikord': ('klavikord',),
'klavikorda': ('klavikord',),
'klavikordene': ('klavikord',),
'klavikorder': ('klavikord',),
'klavikordet': ('klavikord',),
'kleber': ('kleber',),
'klebere': ('kleber',),
'kleberen': ('kleber',),
'kleberer': ('kleber',),
'kleberne': ('kleber',),
'klebre': ('kleber',),
'klebrene': ('kleber',),
'klebrer': ('kleber',),
'kleberstein': ('kleberstein',),
'klebersteinen': ('kleberstein',),
'klebersteinene': ('kleberstein',),
'klebersteiner': ('kleberstein',),
'kleda': ('klede',),
'klede': ('klede',),
'kledene': ('klede',),
'kleder': ('klede',),
'kledet': ('klede',),
'kledebon': ('kledebon',),
'kledebona': ('kledebon',),
'kledebonene': ('kledebon',),
'kledebonet': ('kledebon',),
'kledning': ('kledning',),
'kledninga': ('kledning',),
'kledningen': ('kledning',),
'kledningene': ('kledning',),
'kledninger': ('kledning',),
'klegg': ('klegg',),
'kleggen': ('klegg',),
'kleggene': ('klegg',),
'klegger': ('klegg',),
'kleggbitt': ('kleggbitt',),
'kleggbitta': ('kleggbitt',),
'kleggbittene': ('kleggbitt',),
'kleggbittet': ('kleggbitt',),
'kleggebitt': ('kleggebitt',),
'kleggebitta': ('kleggebitt',),
'kleggebittene': ('kleggebitt',),
'kleggebittet': ('kleggebitt',),
'kleim': ('kleim',),
'kleima': ('kleim',),
'kleimen': ('kleim',),
'kleimene': ('kleim',),
'kleimer': ('kleim',),
'kleima': ('kleime',),
'kleime': ('kleime',),
'kleimen': ('kleime',),
'kleimene': ('kleime',),
'kleimer': ('kleime',),
'kleinkunst': ('kleinkunst',),
'kleinkunsten': ('kleinkunst',),
'kleinkunstene': ('kleinkunst',),
'kleinkunster': ('kleinkunst',),
'kleinsmed': ('kleinsmed',),
'kleinsmeden': ('kleinsmed',),
'kleinsmedene': ('kleinsmed',),
'kleinsmeder': ('kleinsmed',),
'kleiv': ('kleiv',),
'kleiva': ('kleiv',),
'kleiven': ('kleiv',),
'kleivene': ('kleiv',),
'kleiver': ('kleiv',),
'klekkeri': ('klekkeri',),
'klekkeria': ('klekkeri',),
'klekkeriene': ('klekkeri',),
'klekkerier': ('klekkeri',),
'klekkeriet': ('klekkeri',),
'klem': ('klem',),
'klemmen': ('klem',),
'klemmene': ('klem',),
'klemmer': ('klem',),
'klematis': ('klematis',),
'klematisen': ('klematis',),
'klematisene': ('klematis',),
'klematiser': ('klematis',),
'klementin': ('klementin',),
'klementinen': ('klementin',),
'klementinene': ('klementin',),
'klementiner': ('klementin',),
'klemetsmess': ('klemetsmess',),
'klemetsmess': ('klemetsmess',),
'klemetsmesse': ('klemetsmesse',),
'klemma': ('klemme',),
'klemme': ('klemme',),
'klemmen': ('klemme',),
'klemmene': ('klemme',),
'klemmer': ('klemme',),
'klemt': ('klemt',),
'klemta': ('klemt',),
'klemtene': ('klemt',),
'klemtet': ('klemt',),
'klengenavn': ('klengenavn',),
'klengenavna': ('klengenavn',),
'klengenavnene': ('klengenavn',),
'klengenavnet': ('klengenavn',),
'klenodia': ('klenodie',),
'klenodie': ('klenodie',),
'klenodiene': ('klenodie',),
'klenodier': ('klenodie',),
'klenodiet': ('klenodie',),
'klenodia': ('klenodium',),
'klenodiene': ('klenodium',),
'klenodier': ('klenodium',),
'klenodiet': ('klenodium',),
'klenodium': ('klenodium',),
'klepp': ('klepp',),
'kleppen': ('klepp',),
'kleppene': ('klepp',),
'klepper': ('klepp',),
'klepper': ('klepper',),
'kleppere': ('klepper',),
'klepperen': ('klepper',),
'klepperer': ('klepper',),
'klepperne': ('klepper',),
'kleppfisk': ('kleppfisk',),
'kleppfisken': ('kleppfisk',),
'kleppfiskene': ('kleppfisk',),
'kleppfisker': ('kleppfisk',),
'kleppfisk': ('kleppfisk',),
'kleppfisken': ('kleppfisk',),
'kleppfiskene': ('kleppfisk',),
'kleppfisker': ('kleppfisk',),
'kleptoman': ('kleptoman',),
'kleptomanen': ('kleptoman',),
'kleptomanene': ('kleptoman',),
'kleptomaner': ('kleptoman',),
'kleptomani': ('kleptomani',),
'kleptomanien': ('kleptomani',),
'kleptomaniene': ('kleptomani',),
'kleptomanier': ('kleptomani',),
'kleresi': ('kleresi',),
'kleresia': ('kleresi',),
'kleresiene': ('kleresi',),
'kleresier': ('kleresi',),
'kleresiet': ('kleresi',),
'klerikalisme': ('klerikalisme',),
'klerikalismen': ('klerikalisme',),
'klerikalismene': ('klerikalisme',),
'klerikalismer': ('klerikalisme',),
'klerk': ('klerk',),
'klerken': ('klerk',),
'klerkene': ('klerk',),
'klerker': ('klerk',),
'klesbanker': ('klesbanker',),
'klesbankere': ('klesbanker',),
'klesbankeren': ('klesbanker',),
'klesbankerer': ('klesbanker',),
'klesbankerne': ('klesbanker',),
'klesbylt': ('klesbylt',),
'klesbylten': ('klesbylt',),
'klesbyltene': ('klesbylt',),
'klesbylter': ('klesbylt',),
'klesbørste': ('klesbørste',),
'klesbørsten': ('klesbørste',),
'klesbørstene': ('klesbørste',),
'klesbørster': ('klesbørste',),
'klesdrakt': ('klesdrakt',),
'klesdrakta': ('klesdrakt',),
'klesdrakten': ('klesdrakt',),
'klesdraktene': ('klesdrakt',),
'klesdrakter': ('klesdrakt',),
'klesforretning': ('klesforretning',),
'klesforretninga': ('klesforretning',),
'klesforretningen': ('klesforretning',),
'klesforretningene': ('klesforretning',),
'klesforretninger': ('klesforretning',),
'kleshenger': ('kleshenger',),
'kleshengere': ('kleshenger',),
'kleshengeren': ('kleshenger',),
'kleshengerer': ('kleshenger',),
'kleshengerne': ('kleshenger',),
'klesklypa': ('klesklype',),
'klesklype': ('klesklype',),
'klesklypen': ('klesklype',),
'klesklypene': ('klesklype',),
'klesklyper': ('klesklype',),
'kleskott': ('kleskott',),
'kleskotta': ('kleskott',),
'kleskottene': ('kleskott',),
'kleskottet': ('kleskott',),
'klesplagg': ('klesplagg',),
'klesplagga': ('klesplagg',),
'klesplaggene': ('klesplagg',),
'klesplagget': ('klesplagg',),
'kless': ('kless',),
'klessen': ('kless',),
'klessene': ('kless',),
'klesser': ('kless',),
'klessa': ('klesse',),
'klesse': ('klesse',),
'klessen': ('klesse',),
'klessene': ('klesse',),
'klesser': ('klesse',),
'klesskap': ('klesskap',),
'klesskapa': ('klesskap',),
'klesskapene': ('klesskap',),
'klesskapet': ('klesskap',),
'klessnor': ('klessnor',),
'klessnora': ('klessnor',),
'klessnoren': ('klessnor',),
'klessnorene': ('klessnor',),
'klessnorer': ('klessnor',),
'klestørk': ('klestørk',),
'klestørken': ('klestørk',),
'klestørkene': ('klestørk',),
'klestørker': ('klestørk',),
'klesvask': ('klesvask',),
'klesvasken': ('klesvask',),
'klesvaskene': ('klesvask',),
'klesvasker': ('klesvask',),
'klett': ('klett',),
'kletten': ('klett',),
'klettene': ('klett',),
'kletter': ('klett',),
'kleve': ('kleve',),
'kleven': ('kleve',),
'klevene': ('kleve',),
'klever': ('kleve',),
'kli': ('kli',),
'klia': ('kli',),
'kliene': ('kli',),
'kliet': ('kli',),
'klibrød': ('klibrød',),
'klibrøda': ('klibrød',),
'klibrødene': ('klibrød',),
'klibrødet': ('klibrød',),
'klient': ('klient',),
'klienten': ('klient',),
'klientene': ('klient',),
'klienter': ('klient',),
'klientell': ('klientell',),
'klientella': ('klientell',),
'klientellene': ('klientell',),
'klienteller': ('klientell',),
'klientellet': ('klientell',),
'klikkevesen': ('klikkevesen',),
'klikkevesena': ('klikkevesen',),
'klikkevesenene': ('klikkevesen',),
'klikkevesener': ('klikkevesen',),
'klikkevesenet': ('klikkevesen',),
'klima': ('klima',),
'klimaene': ('klima',),
'klimaer': ('klima',),
'klimaet': ('klima',),
'klimaanlegg': ('klimaanlegg',),
'klimaanlegga': ('klimaanlegg',),
'klimaanleggene': ('klimaanlegg',),
'klimaanlegget': ('klimaanlegg',),
'klimafeber': ('klimafeber',),
'klimafebere': ('klimafeber',),
'klimafeberen': ('klimafeber',),
'klimafeberne': ('klimafeber',),
'klimafebre': ('klimafeber',),
'klimafebrene': ('klimafeber',),
'klimafebrer': ('klimafeber',),
'klimagass': ('klimagass',),
'klimagassen': ('klimagass',),
'klimagassene': ('klimagass',),
'klimagasser': ('klimagass',),
'klimaks': ('klimaks',),
'klimaksa': ('klimaks',),
'klimaksen': ('klimaks',),
'klimaksene': ('klimaks',),
'klimakser': ('klimaks',),
'klimakset': ('klimaks',),
'klimakteria': ('klimakterium',),
'klimakteriene': ('klimakterium',),
'klimakterier': ('klimakterium',),
'klimakteriet': ('klimakterium',),
'klimakterium': ('klimakterium',),
'klimasjukdom': ('klimasjukdom',),
'klimasjukdommen': ('klimasjukdom',),
'klimasjukdommene': ('klimasjukdom',),
'klimasjukdommer': ('klimasjukdom',),
'klimasona': ('klimasone',),
'klimasone': ('klimasone',),
'klimasonen': ('klimasone',),
'klimasonene': ('klimasone',),
'klimasoner': ('klimasone',),
'klimasykdom': ('klimasykdom',),
'klimasykdommen': ('klimasykdom',),
'klimasykdommene': ('klimasykdom',),
'klimasykdommer': ('klimasykdom',),
'klimatolog': ('klimatolog',),
'klimatologen': ('klimatolog',),
'klimatologene': ('klimatolog',),
'klimatologer': ('klimatolog',),
'klimatologi': ('klimatologi',),
'klimatologien': ('klimatologi',),
'klimatologiene': ('klimatologi',),
'klimatologier': ('klimatologi',),
'klin': ('klin',),
'klina': ('klin',),
'klinene': ('klin',),
'klinet': ('klin',),
'kling': ('kling',),
'klingen': ('kling',),
'klingene': ('kling',),
'klinger': ('kling',),
'klinge': ('klinge',),
'klingen': ('klinge',),
'klingene': ('klinge',),
'klinger': ('klinge',),
'klingklang': ('klingklang',),
'klingklanga': ('klingklang',),
'klingklangen': ('klingklang',),
'klingklangene': ('klingklang',),
'klingklanger': ('klingklang',),
'klingklanget': ('klingklang',),
'kliniker': ('kliniker',),
'klinikere': ('kliniker',),
'klinikeren': ('kliniker',),
'klinikerer': ('kliniker',),
'klinikerne': ('kliniker',),
'klinikk': ('klinikk',),
'klinikken': ('klinikk',),
'klinikkene': ('klinikk',),
'klinikker': ('klinikk',),
'klining': ('klining',),
'klininga': ('klining',),
'kliningen': ('klining',),
'kliningene': ('klining',),
'klininger': ('klining',),
'klinka': ('klinke',),
'klinke': ('klinke',),
'klinken': ('klinke',),
'klinkene': ('klinke',),
'klinker': ('klinke',),
'klinkegg': ('klinkegg',),
'klinkegga': ('klinkegg',),
'klinkeggene': ('klinkegg',),
'klinkegget': ('klinkegg',),
'klinkekula': ('klinkekule',),
'klinkekule': ('klinkekule',),
'klinkekulen': ('klinkekule',),
'klinkekulene': ('klinkekule',),
'klinkekuler': ('klinkekule',),
'klinker': ('klinker',),
'klinkere': ('klinker',),
'klinkeren': ('klinker',),
'klinkerer': ('klinker',),
'klinkerne': ('klinker',),
'klinkhammar': ('klinkhammar',),
'klinkhammaren': ('klinkhammar',),
'klinkhamrene': ('klinkhammar',),
'klinkhamrer': ('klinkhammar',),
'klinkhammer': ('klinkhammer',),
'klinkhammere': ('klinkhammer',),
'klinkhammeren': ('klinkhammer',),
'klinkhammerer': ('klinkhammer',),
'klinkhammerne': ('klinkhammer',),
'klinkhamrene': ('klinkhammer',),
'klinkhamrer': ('klinkhammer',),
'klinknagle': ('klinknagle',),
'klinknaglen': ('klinknagle',),
'klinknaglene': ('klinknagle',),
'klinknagler': ('klinknagle',),
'klinte': ('klinte',),
'klinten': ('klinte',),
'klintene': ('klinte',),
'klinter': ('klinte',),
'klipp': ('klipp',),
'klippen': ('klipp',),
'klippene': ('klipp',),
'klipper': ('klipp',),
'klipp': ('klipp',),
'klippa': ('klipp',),
'klippene': ('klipp',),
'klippet': ('klipp',),
'klipparkiv': ('klipparkiv',),
'klipparkiva': ('klipparkiv',),
'klipparkivene': ('klipparkiv',),
'klipparkiver': ('klipparkiv',),
'klipparkivet': ('klipparkiv',),
'klippe': ('klippe',),
'klippen': ('klippe',),
'klippene': ('klippe',),
'klipper': ('klippe',),
'klippekort': ('klippekort',),
'klippekorta': ('klippekort',),
'klippekortene': ('klippekort',),
'klippekortet': ('klippekort',),
'klipper': ('klipper',),
'klippere': ('klipper',),
'klipperen': ('klipper',),
'klipperer': ('klipper',),
'klipperne': ('klipper',),
'klipper': ('klipper',),
'klippere': ('klipper',),
'klipperen': ('klipper',),
'klipperer': ('klipper',),
'klipperne': ('klipper',),
'klipperbaug': ('klipperbaug',),
'klipperbaugen': ('klipperbaug',),
'klipperbaugene': ('klipperbaug',),
'klipperbauger': ('klipperbaug',),
'klippfisk': ('klippfisk',),
'klippfisken': ('klippfisk',),
'klippfiskene': ('klippfisk',),
'klippfisker': ('klippfisk',),
'klippfisk': ('klippfisk',),
'klippfisken': ('klippfisk',),
'klippfiskene': ('klippfisk',),
'klippfisker': ('klippfisk',),
'klips': ('klips',),
'klipsa': ('klips',),
'klipsen': ('klips',),
'klipsene': ('klips',),
'klipset': ('klips',),
'klirr': ('klirr',),
'klirra': ('klirr',),
'klirren': ('klirr',),
'klirrene': ('klirr',),
'klirret': ('klirr',),
'klisje': ('klisje',),
'klisjeen': ('klisje',),
'klisjeene': ('klisje',),
'klisjeer': ('klisje',),
'kliss': ('kliss',),
'klissa': ('kliss',),
'klissene': ('kliss',),
'klisset': ('kliss',),
'klisseri': ('klisseri',),
'klisseria': ('klisseri',),
'klisseriene': ('klisseri',),
'klisserier': ('klisseri',),
'klisseriet': ('klisseri',),
'klister': ('klister',),
'klisteret': ('klister',),
'klistra': ('klister',),
'klistre': ('klister',),
'klistrene': ('klister',),
'klistret': ('klister',),
'klisterføra': ('klisterføre',),
'klisterføre': ('klisterføre',),
'klisterførene': ('klisterføre',),
'klisterfører': ('klisterføre',),
'klisterføret': ('klisterføre',),
'klisterhjerne': ('klisterhjerne',),
'klisterhjernen': ('klisterhjerne',),
'klisterhjernene': ('klisterhjerne',),
'klisterhjerner': ('klisterhjerne',),
'klitoris': ('klitoris',),
'klitorisen': ('klitoris',),
'klitorisene': ('klitoris',),
'klitoriser': ('klitoris',),
'kljå': ('kljå',),
'kljåen': ('kljå',),
'kljåene': ('kljå',),
'kljåer': ('kljå',),
'kljåstein': ('kljåstein',),
'kljåsteinen': ('kljåstein',),
'kljåsteinene': ('kljåstein',),
'kljåsteiner': ('kljåstein',),
'klo': ('klo',),
'kloa': ('klo',),
'kloen': ('klo',),
'klør': ('klo',),
'klørne': ('klo',),
'kloakk': ('kloakk',),
'kloakken': ('kloakk',),
'kloakkene': ('kloakk',),
'kloakker': ('kloakk',),
'kloakk-kum': ('kloakk-kum',),
'kloakk-kummen': ('kloakk-kum',),
'kloakk-kummene': ('kloakk-kum',),
'kloakk-kummer': ('kloakk-kum',),
'kloakkdyr': ('kloakkdyr',),
'kloakkdyra': ('kloakkdyr',),
'kloakkdyrene': ('kloakkdyr',),
'kloakkdyret': ('kloakkdyr',),
'kloakkledning': ('kloakkledning',),
'kloakkledninga': ('kloakkledning',),
'kloakkledningen': ('kloakkledning',),
'kloakkledningene': ('kloakkledning',),
'kloakkledninger': ('kloakkledning',),
'kloakkrenseanlegg': ('kloakkrenseanlegg',),
'kloakkrenseanlegga': ('kloakkrenseanlegg',),
'kloakkrenseanleggene': ('kloakkrenseanlegg',),
'kloakkrenseanlegget': ('kloakkrenseanlegg',),
'kloakkum': ('kloakkum',),
'kloakkummen': ('kloakkum',),
'kloakkummene': ('kloakkum',),
'kloakkummer': ('kloakkum',),
'klode': ('klode',),
'kloden': ('klode',),
'klodene': ('klode',),
'kloder': ('klode',),
'klodrian': ('klodrian',),
'klodrianen': ('klodrian',),
'klodrianene': ('klodrian',),
'klodrianer': ('klodrian',),
'klodyr': ('klodyr',),
'klodyra': ('klodyr',),
'klodyrene': ('klodyr',),
'klodyret': ('klodyr',),
'kloking': ('kloking',),
'klokingen': ('kloking',),
'klokingene': ('kloking',),
'klokinger': ('kloking',),
'klokka': ('klokke',),
'klokke': ('klokke',),
'klokken': ('klokke',),
'klokkene': ('klokke',),
'klokker': ('klokke',),
'klokkeband': ('klokkeband',),
'klokkebanda': ('klokkeband',),
'klokkebandene': ('klokkeband',),
'klokkebandet': ('klokkeband',),
'klokkebånd': ('klokkebånd',),
'klokkebånda': ('klokkebånd',),
'klokkebåndene': ('klokkebånd',),
'klokkebåndet': ('klokkebånd',),
'klokkebøya': ('klokkebøye',),
'klokkebøye': ('klokkebøye',),
'klokkebøyen': ('klokkebøye',),
'klokkebøyene': ('klokkebøye',),
'klokkebøyer': ('klokkebøye',),
'klokkekjeda': ('klokkekjede',),
'klokkekjede': ('klokkekjede',),
'klokkekjeden': ('klokkekjede',),
'klokkekjedene': ('klokkekjede',),
'klokkekjeder': ('klokkekjede',),
'klokkekjedet': ('klokkekjede',),
'klokkeklang': ('klokkeklang',),
'klokkeklangen': ('klokkeklang',),
'klokkeklangene': ('klokkeklang',),
'klokkeklanger': ('klokkeklang',),
'klokkekolv': ('klokkekolv',),
'klokkekolven': ('klokkekolv',),
'klokkekolvene': ('klokkekolv',),
'klokkekolver': ('klokkekolv',),
'klokkelyng': ('klokkelyng',),
'klokkelynga': ('klokkelyng',),
'klokkelyngen': ('klokkelyng',),
'klokkelyngene': ('klokkelyng',),
'klokkelynger': ('klokkelyng',),
'klokkelynget': ('klokkelyng',),
'klokkemaker': ('klokkemaker',),
'klokkemakere': ('klokkemaker',),
'klokkemakeren': ('klokkemaker',),
'klokkemakerer': ('klokkemaker',),
'klokkemakerne': ('klokkemaker',),
'klokker': ('klokker',),
'klokkere': ('klokker',),
'klokkeren': ('klokker',),
'klokkerer': ('klokker',),
'klokkerne': ('klokker',),
'klokkerbønn': ('klokkerbønn',),
'klokkerbønna': ('klokkerbønn',),
'klokkerbønnen': ('klokkerbønn',),
'klokkerbønnene': ('klokkerbønn',),
'klokkerbønner': ('klokkerbønn',),
'klokkerdansk': ('klokkerdansk',),
'klokkerdanskn': ('klokkerdansk',),
'klokkerdanskne': ('klokkerdansk',),
'klokkerdanskr': ('klokkerdansk',),
'klokkerkjærlighet': ('klokkerkjærlighet',),
'klokkerkjærligheta': ('klokkerkjærlighet',),
'klokkerkjærligheten': ('klokkerkjærlighet',),
'klokkerkjærlighetene': ('klokkerkjærlighet',),
'klokkerkjærligheter': ('klokkerkjærlighet',),
'klokkertro': ('klokkertro',),
'klokkertroa': ('klokkertro',),
'klokkertroen': ('klokkertro',),
'klokkertroene': ('klokkertro',),
'klokkertroer': ('klokkertro',),
'klokkeslett': ('klokkeslett',),
'klokkesletta': ('klokkeslett',),
'klokkeslettene': ('klokkeslett',),
'klokkeslettet': ('klokkeslett',),
'klokkespell': ('klokkespell',),
'klokkespella': ('klokkespell',),
'klokkespellene': ('klokkespell',),
'klokkespellet': ('klokkespell',),
'klokkespill': ('klokkespill',),
'klokkespilla': ('klokkespill',),
'klokkespillene': ('klokkespill',),
'klokkespillet': ('klokkespill',),
'klokkestreng': ('klokkestreng',),
'klokkestrengen': ('klokkestreng',),
'klokkestrengene': ('klokkestreng',),
'klokkestrenger': ('klokkestreng',),
'klokkestøping': ('klokkestøping',),
'klokkestøpinga': ('klokkestøping',),
'klokkestøpingen': ('klokkestøping',),
'klokkestøpingene': ('klokkestøping',),
'klokkestøpinger': ('klokkestøping',),
'klokkestøpning': ('klokkestøpning',),
'klokkestøpninga': ('klokkestøpning',),
'klokkestøpningen': ('klokkestøpning',),
'klokkestøpningene': ('klokkestøpning',),
'klokkestøpninger': ('klokkestøpning',),
'klokkestøpul': ('klokkestøpul',),
'klokkestøpulen': ('klokkestøpul',),
'klokkestøpulene': ('klokkestøpul',),
'klokkestøpuler': ('klokkestøpul',),
'klokkestøyping': ('klokkestøyping',),
'klokkestøypinga': ('klokkestøyping',),
'klokkestøypingen': ('klokkestøyping',),
'klokkestøypingene': ('klokkestøyping',),
'klokkestøypinger': ('klokkestøyping',),
'klokketime': ('klokketime',),
'klokketimen': ('klokketime',),
'klokketimene': ('klokketime',),
'klokketimer': ('klokketime',),
'klokskap': ('klokskap',),
'klokskapen': ('klokskap',),
'klokskapene': ('klokskap',),
'klokskaper': ('klokskap',),
'klon': ('klon',),
'klonen': ('klon',),
'klonene': ('klon',),
'kloner': ('klon',),
'klondyka': ('klondyke',),
'klondyke': ('klondyke',),
'klondykene': ('klondyke',),
'klondyker': ('klondyke',),
'klondyket': ('klondyke',),
'kloning': ('kloning',),
'kloninga': ('kloning',),
'kloningen': ('kloning',),
'kloningene': ('kloning',),
'kloninger': ('kloning',),
'klopp': ('klopp',),
'kloppa': ('klopp',),
'kloppen': ('klopp',),
'kloppene': ('klopp',),
'klopper': ('klopp',),
'kloral': ('kloral',),
'kloralen': ('kloral',),
'kloralene': ('kloral',),
'kloraler': ('kloral',),
'klorat': ('klorat',),
'klorata': ('klorat',),
'kloratene': ('klorat',),
'klorater': ('klorat',),
'kloratet': ('klorat',),
'klordamp': ('klordamp',),
'klordampen': ('klordamp',),
'klordampene': ('klordamp',),
'klordamper': ('klordamp',),
'klorgass': ('klorgass',),
'klorgassen': ('klorgass',),
'klorgassene': ('klorgass',),
'klorgasser': ('klorgass',),
'klorid': ('klorid',),
'klorida': ('klorid',),
'kloridene': ('klorid',),
'klorider': ('klorid',),
'kloridet': ('klorid',),
'klorkalium': ('klorkalium',),
'klorkaliuma': ('klorkalium',),
'klorkaliumene': ('klorkalium',),
'klorkaliumet': ('klorkalium',),
'klorkalk': ('klorkalk',),
'klorkalken': ('klorkalk',),
'klorkalkene': ('klorkalk',),
'klorkalker': ('klorkalk',),
'klorkalsium': ('klorkalsium',),
'klorkalsiuma': ('klorkalsium',),
'klorkalsiumene': ('klorkalsium',),
'klorkalsiumet': ('klorkalsium',),
'kloroform': ('kloroform',),
'kloroformen': ('kloroform',),
'kloroformene': ('kloroform',),
'kloroformer': ('kloroform',),
'klorofyll': ('klorofyll',),
'klorofylla': ('klorofyll',),
'klorofyllene': ('klorofyll',),
'klorofyllet': ('klorofyll',),
'kloroplast': ('kloroplast',),
'kloroplasten': ('kloroplast',),
'kloroplastene': ('kloroplast',),
'kloroplaster': ('kloroplast',),
'klorsalt': ('klorsalt',),
'klorsalta': ('klorsalt',),
'klorsaltene': ('klorsalt',),
'klorsalter': ('klorsalt',),
'klorsaltet': ('klorsalt',),
'klosett': ('klosett',),
'klosetta': ('klosett',),
'klosettene': ('klosett',),
'klosetter': ('klosett',),
'klosettet': ('klosett',),
'klosettpapir': ('klosettpapir',),
'klosettpapira': ('klosettpapir',),
'klosettpapirene': ('klosettpapir',),
'klosettpapirer': ('klosettpapir',),
'klosettpapiret': ('klosettpapir',),
'klosettskål': ('klosettskål',),
'klosettskåla': ('klosettskål',),
'klosettskålen': ('klosettskål',),
'klosettskålene': ('klosettskål',),
'klosettskåler': ('klosettskål',),
'kloss': ('kloss',),
'klossen': ('kloss',),
'klossene': ('kloss',),
'klosser': ('kloss',),
'klossmajor': ('klossmajor',),
'klossmajoren': ('klossmajor',),
'klossmajorene': ('klossmajor',),
'klossmajorer': ('klossmajor',),
'kloster': ('kloster',),
'klosteret': ('kloster',),
'klostra': ('kloster',),
'klostre': ('kloster',),
'klostrene': ('kloster',),
'klostret': ('kloster',),
'klostergods': ('klostergods',),
'klostergodsa': ('klostergods',),
'klostergodsene': ('klostergods',),
'klostergodser': ('klostergods',),
'klostergodset': ('klostergods',),
'klosterkirka': ('klosterkirke',),
'klosterkirke': ('klosterkirke',),
'klosterkirken': ('klosterkirke',),
'klosterkirkene': ('klosterkirke',),
'klosterkirker': ('klosterkirke',),
'klosterkjerka': ('klosterkjerke',),
'klosterkjerke': ('klosterkjerke',),
'klosterkjerken': ('klosterkjerke',),
'klosterkjerkene': ('klosterkjerke',),
'klosterkjerker': ('klosterkjerke',),
'klosterlatin': ('klosterlatin',),
'klosterlatinen': ('klosterlatin',),
'klosterlatinene': ('klosterlatin',),
'klosterlatiner': ('klosterlatin',),
'klosterlikør': ('klosterlikør',),
'klosterlikøren': ('klosterlikør',),
'klosterlikørene': ('klosterlikør',),
'klosterlikører': ('klosterlikør',),
'klosterløfta': ('klosterløfte',),
'klosterløfte': ('klosterløfte',),
'klosterløftene': ('klosterløfte',),
'klosterløfter': ('klosterløfte',),
'klosterløftet': ('klosterløfte',),
'klosterskole': ('klosterskole',),
'klosterskolen': ('klosterskole',),
'klosterskolene': ('klosterskole',),
'klosterskoler': ('klosterskole',),
'klostersøm': ('klostersøm',),
'klostersømmen': ('klostersøm',),
'klostersømmene': ('klostersøm',),
'klostersømmer': ('klostersøm',),
'klot': ('klot',),
'kloten': ('klot',),
'klotene': ('klot',),
'kloter': ('klot',),
'klourt': ('klourt',),
'klourta': ('klourt',),
'klourten': ('klourt',),
'klourtene': ('klourt',),
'klourter': ('klourt',),
'klov': ('klov',),
'klova': ('klov',),
'klovene': ('klov',),
'klovet': ('klov',),
'klov': ('klov',),
'klova': ('klov',),
'kloven': ('klov',),
'klovene': ('klov',),
'klover': ('klov',),
'klovdyr': ('klovdyr',),
'klovdyra': ('klovdyr',),
'klovdyrene': ('klovdyr',),
'klovdyret': ('klovdyr',),
'klove': ('klove',),
'kloven': ('klove',),
'klovene': ('klove',),
'klover': ('klove',),
'klova': ('klove',),
'klove': ('klove',),
'kloven': ('klove',),
'klovene': ('klove',),
'klover': ('klove',),
'klovn': ('klovn',),
'klovnen': ('klovn',),
'klovnene': ('klovn',),
'klovner': ('klovn',),
'klovneri': ('klovneri',),
'klovneria': ('klovneri',),
'klovneriene': ('klovneri',),
'klovnerier': ('klovneri',),
'klovneriet': ('klovneri',),
'klovning': ('klovning',),
'klovninga': ('klovning',),
'klovningen': ('klovning',),
'klovningene': ('klovning',),
'klovninger': ('klovning',),
'klovning': ('klovning',),
'klovninga': ('klovning',),
'klovningen': ('klovning',),
'klovningene': ('klovning',),
'klovninger': ('klovning',),
'klovsjuka': ('klovsjuke',),
'klovsjuke': ('klovsjuke',),
'klovsjuken': ('klovsjuke',),
'klovsjukene': ('klovsjuke',),
'klovsjuker': ('klovsjuke',),
'klovsyka': ('klovsyke',),
'klovsyke': ('klovsyke',),
'klovsyken': ('klovsyke',),
'klovsykene': ('klovsyke',),
'klovsyker': ('klovsyke',),
'klubb': ('klubb',),
'klubben': ('klubb',),
'klubbene': ('klubb',),
'klubber': ('klubb',),
'klubb': ('klubb',),
'klubben': ('klubb',),
'klubbene': ('klubb',),
'klubber': ('klubb',),
'klubbdrakt': ('klubbdrakt',),
'klubbdrakta': ('klubbdrakt',),
'klubbdrakten': ('klubbdrakt',),
'klubbdraktene': ('klubbdrakt',),
'klubbdrakter': ('klubbdrakt',),
'klubba': ('klubbe',),
'klubbe': ('klubbe',),
'klubben': ('klubbe',),
'klubbene': ('klubbe',),
'klubber': ('klubbe',),
'klubbformann': ('klubbformann',),
'klubbformannen': ('klubbformann',),
'klubbformenn': ('klubbformann',),
'klubbformennene': ('klubbformann',),
'klubbhus': ('klubbhus',),
'klubbhusa': ('klubbhus',),
'klubbhusene': ('klubbhus',),
'klubbhuset': ('klubbhus',),
'klubbkamerat': ('klubbkamerat',),
'klubbkameraten': ('klubbkamerat',),
'klubbkameratene': ('klubbkamerat',),
'klubbkamerater': ('klubbkamerat',),
'klubbmester': ('klubbmester',),
'klubbmestere': ('klubbmester',),
'klubbmesteren': ('klubbmester',),
'klubbmesterer': ('klubbmester',),
'klubbmesterne': ('klubbmester',),
'klubbmestre': ('klubbmester',),
'klubbmestrene': ('klubbmester',),
'klubbmestrer': ('klubbmester',),
'klubbmesterskap': ('klubbmesterskap',),
'klubbmesterskapa': ('klubbmesterskap',),
'klubbmesterskapene': ('klubbmesterskap',),
'klubbmesterskaper': ('klubbmesterskap',),
'klubbmesterskapet': ('klubbmesterskap',),
'klubbpatriot': ('klubbpatriot',),
'klubbpatrioten': ('klubbpatriot',),
'klubbpatriotene': ('klubbpatriot',),
'klubbpatrioter': ('klubbpatriot',),
'kludder': ('kludder',),
'kluddera': ('kludder',),
'kluddere': ('kludder',),
'kludderene': ('kludder',),
'kludderet': ('kludder',),
'kludderne': ('kludder',),
'kluft': ('kluft',),
'klufta': ('kluft',),
'kluften': ('kluft',),
'kluftene': ('kluft',),
'klufter': ('kluft',),
'klukk': ('klukk',),
'klukka': ('klukk',),
'klukken': ('klukk',),
'klukkene': ('klukk',),
'klukket': ('klukk',),
'klukkhøna': ('klukkhøne',),
'klukkhøne': ('klukkhøne',),
'klukkhønen': ('klukkhøne',),
'klukkhønene': ('klukkhøne',),
'klukkhøner': ('klukkhøne',),
'klump': ('klump',),
'klumpen': ('klump',),
'klumpene': ('klump',),
'klumper': ('klump',),
'klumprot': ('klumprot',),
'klumprota': ('klumprot',),
'klumproten': ('klumprot',),
'klumprøttene': ('klumprot',),
'klumprøtter': ('klumprot',),
'klunder': ('klunder',),
'klunderet': ('klunder',),
'klundra': ('klunder',),
'klundre': ('klunder',),
'klundrene': ('klunder',),
'klundret': ('klunder',),
'klunger': ('klunger',),
'klungere': ('klunger',),
'klungeren': ('klunger',),
'klungerne': ('klunger',),
'klungre': ('klunger',),
'klungrene': ('klunger',),
'klungrer': ('klunger',),
'klungerkjerr': ('klungerkjerr',),
'klungerkjerra': ('klungerkjerr',),
'klungerkjerrene': ('klungerkjerr',),
'klungerkjerret': ('klungerkjerr',),
'kluniasenser': ('kluniasenser',),
'kluniasensere': ('kluniasenser',),
'kluniasenseren': ('kluniasenser',),
'kluniasenserer': ('kluniasenser',),
'kluniasenserne': ('kluniasenser',),
'kluniasenserorden': ('kluniasenserorden',),
'kluniasenserordenen': ('kluniasenserorden',),
'kluniasenserordenene': ('kluniasenserorden',),
'kluniasenserordener': ('kluniasenserorden',),
'klunk': ('klunk',),
'klunken': ('klunk',),
'klunkene': ('klunk',),
'klunker': ('klunk',),
'klunk': ('klunk',),
'klunka': ('klunk',),
'klunkene': ('klunk',),
'klunket': ('klunk',),
'klunkeflaska': ('klunkeflaske',),
'klunkeflaske': ('klunkeflaske',),
'klunkeflasken': ('klunkeflaske',),
'klunkeflaskene': ('klunkeflaske',),
'klunkeflasker': ('klunkeflaske',),
'kluns': ('kluns',),
'klunsen': ('kluns',),
'klunsene': ('kluns',),
'klunser': ('kluns',),
'klusil': ('klusil',),
'klusilen': ('klusil',),
'klusilene': ('klusil',),
'klusiler': ('klusil',),
'kluss': ('kluss',),
'klussa': ('kluss',),
'klussene': ('kluss',),
'klusset': ('kluss',),
'klut': ('klut',),
'kluten': ('klut',),
'klutene': ('klut',),
'kluter': ('klut',),
'klutehandler': ('klutehandler',),
'klutehandlere': ('klutehandler',),
'klutehandleren': ('klutehandler',),
'klutehandlerer': ('klutehandler',),
'klutehandlerne': ('klutehandler',),
'klutepapir': ('klutepapir',),
'klutepapira': ('klutepapir',),
'klutepapirene': ('klutepapir',),
'klutepapirer': ('klutepapir',),
'klutepapiret': ('klutepapir',),
'klynga': ('klynge',),
'klynge': ('klynge',),
'klyngen': ('klynge',),
'klyngene': ('klynge',),
'klynger': ('klynge',),
'klynk': ('klynk',),
'klynka': ('klynk',),
'klynken': ('klynk',),
'klynkene': ('klynk',),
'klynket': ('klynk',),
'klyp': ('klyp',),
'klypa': ('klyp',),
'klypen': ('klyp',),
'klypene': ('klyp',),
'klypet': ('klyp',),
'klypa': ('klype',),
'klype': ('klype',),
'klypen': ('klype',),
'klypene': ('klype',),
'klyper': ('klype',),
'klypa': ('klype',),
'klype': ('klype',),
'klypen': ('klype',),
'klypene': ('klype',),
'klyper': ('klype',),
'klypp': ('klypp',),
'klyppen': ('klypp',),
'klyppene': ('klypp',),
'klypper': ('klypp',),
'klysa': ('klyse',),
'klyse': ('klyse',),
'klysen': ('klyse',),
'klysene': ('klyse',),
'klyser': ('klyse',),
'klyss': ('klyss',),
'klyssa': ('klyss',),
'klyssene': ('klyss',),
'klysset': ('klyss',),
'klyssrør': ('klyssrør',),
'klyssrøra': ('klyssrør',),
'klyssrørene': ('klyssrør',),
'klyssrøret': ('klyssrør',),
'klyster': ('klyster',),
'klystera': ('klyster',),
'klysterene': ('klyster',),
'klysterer': ('klyster',),
'klysteret': ('klyster',),
'klyv': ('klyv',),
'klyva': ('klyv',),
'klyvene': ('klyv',),
'klyvet': ('klyv',),
'klyver': ('klyver',),
'klyvere': ('klyver',),
'klyveren': ('klyver',),
'klyverer': ('klyver',),
'klyverne': ('klyver',),
'klyverbom': ('klyverbom',),
'klyverbommen': ('klyverbom',),
'klyverbommene': ('klyverbom',),
'klyverbommer': ('klyverbom',),
'klåe': ('klåe',),
'klåen': ('klåe',),
'klåene': ('klåe',),
'klåer': ('klåe',),
'klåfinger': ('klåfinger',),
'klåfingeren': ('klåfinger',),
'klåfingre': ('klåfinger',),
'klåfingrene': ('klåfinger',),
'klåfingrer': ('klåfinger',),
'klåta': ('klåte',),
'klåte': ('klåte',),
'klåten': ('klåte',),
'klåtene': ('klåte',),
'klåter': ('klåte',),
'klåtra': ('klåtre',),
'klåtre': ('klåtre',),
'klåtren': ('klåtre',),
'klåtrene': ('klåtre',),
'klåtrer': ('klåtre',),
'klær': ('klær',),
'klærne': ('klær',),
'kløe': ('kløe',),
'kløen': ('kløe',),
'kløene': ('kløe',),
'kløer': ('kløe',),
'kløft': ('kløft',),
'kløfta': ('kløft',),
'kløften': ('kløft',),
'kløftene': ('kløft',),
'kløfter': ('kløft',),
'kløkt': ('kløkt',),
'kløkten': ('kløkt',),
'kløktene': ('kløkt',),
'kløkter': ('kløkt',),
'kløna': ('kløne',),
'kløne': ('kløne',),
'klønen': ('kløne',),
'klønene': ('kløne',),
'kløner': ('kløne',),
'kløpper': ('kløpper',),
'kløppere': ('kløpper',),
'kløpperen': ('kløpper',),
'kløpperer': ('kløpper',),
'kløpperne': ('kløpper',),
'kløpulver': ('kløpulver',),
'kløpulvera': ('kløpulver',),
'kløpulvere': ('kløpulver',),
'kløpulveret': ('kløpulver',),
'kløpulverne': ('kløpulver',),
'kløsalva': ('kløsalve',),
'kløsalve': ('kløsalve',),
'kløsalven': ('kløsalve',),
'kløsalvene': ('kløsalve',),
'kløsalver': ('kløsalve',),
'kløtsj': ('kløtsj',),
'kløtsjen': ('kløtsj',),
'kløtsjene': ('kløtsj',),
'kløtsjer': ('kløtsj',),
'kløtsjpedal': ('kløtsjpedal',),
'kløtsjpedalen': ('kløtsjpedal',),
'kløtsjpedalene': ('kløtsjpedal',),
'kløtsjpedaler': ('kløtsjpedal',),
'kløv': ('kløv',),
'kløven': ('kløv',),
'kløvene': ('kløv',),
'kløver': ('kløv',),
'kløv': ('kløv',),
'kløva': ('kløv',),
'kløven': ('kløv',),
'kløvene': ('kløv',),
'kløver': ('kløv',),
'kløvdyr': ('kløvdyr',),
'kløvdyra': ('kløvdyr',),
'kløvdyrene': ('kløvdyr',),
'kløvdyret': ('kløvdyr',),
'kløvereng': ('kløvereng',),
'kløverenga': ('kløvereng',),
'kløverengen': ('kløvereng',),
'kløverengene': ('kløvereng',),
'kløverenger': ('kløvereng',),
'kløvhest': ('kløvhest',),
'kløvhesten': ('kløvhest',),
'kløvhestene': ('kløvhest',),
'kløvhester': ('kløvhest',),
'kløvjeveg': ('kløvjeveg',),
'kløvjevegen': ('kløvjeveg',),
'kløvjevegene': ('kløvjeveg',),
'kløvjeveger': ('kløvjeveg',),
'kløvjevei': ('kløvjevei',),
'kløvjeveien': ('kløvjevei',),
'kløvjeveiene': ('kløvjevei',),
'kløvjeveier': ('kløvjevei',),
'kløvmeis': ('kløvmeis',),
'kløvmeisa': ('kløvmeis',),
'kløvmeisen': ('kløvmeis',),
'kløvmeisene': ('kløvmeis',),
'kløvmeiser': ('kløvmeis',),
'kløvning': ('kløvning',),
'kløvninga': ('kløvning',),
'kløvningen': ('kløvning',),
'kløvningene': ('kløvning',),
'kløvninger': ('kløvning',),
'kløvsadel': ('kløvsadel',),
'kløvsadelen': ('kløvsadel',),
'kløvsadlene': ('kløvsadel',),
'kløvsadler': ('kløvsadel',),
'kløvsag': ('kløvsag',),
'kløvsaga': ('kløvsag',),
'kløvsagen': ('kløvsag',),
'kløvsagene': ('kløvsag',),
'kløvsager': ('kløvsag',),
'kløvsal': ('kløvsal',),
'kløvsalen': ('kløvsal',),
'kløvsalene': ('kløvsal',),
'kløvsaler': ('kløvsal',),
'kløvveg': ('kløvveg',),
'kløvvegen': ('kløvveg',),
'kløvvegene': ('kløvveg',),
'kløvveger': ('kløvveg',),
'kløvvei': ('kløvvei',),
'kløvveien': ('kløvvei',),
'kløvveiene': ('kløvvei',),
'kløvveier': ('kløvvei',),
'kløyv': ('kløyv',),
'kløyven': ('kløyv',),
'kløyvene': ('kløyv',),
'kløyver': ('kløyv',),
'kløyver': ('kløyver',),
'kløyvere': ('kløyver',),
'kløyveren': ('kløyver',),
'kløyverer': ('kløyver',),
'kløyverne': ('kløyver',),
'kløyvning': ('kløyvning',),
'kløyvninga': ('kløyvning',),
'kløyvningen': ('kløyvning',),
'kløyvningene': ('kløyvning',),
'kløyvninger': ('kløyvning',),
'kløyvsag': ('kløyvsag',),
'kløyvsaga': ('kløyvsag',),
'kløyvsagen': ('kløyvsag',),
'kløyvsagene': ('kløyvsag',),
'kløyvsager': ('kløyvsag',),
'knabb': ('knabb',),
'knabben': ('knabb',),
'knabbene': ('knabb',),
'knabber': ('knabb',),
'knaderi': ('knaderi',),
'knaderia': ('knaderi',),
'knaderiene': ('knaderi',),
'knaderier': ('knaderi',),
'knaderiet': ('knaderi',),
'knagg': ('knagg',),
'knaggen': ('knagg',),
'knaggene': ('knagg',),
'knagger': ('knagg',),
'knahus': ('knahus',),
'knahusa': ('knahus',),
'knahusene': ('knahus',),
'knahuset': ('knahus',),
'knak': ('knak',),
'knaka': ('knak',),
'knakene': ('knak',),
'knaket': ('knak',),
'knakk': ('knakk',),
'knakken': ('knakk',),
'knakkene': ('knakk',),
'knakker': ('knakk',),
'knakk': ('knakk',),
'knakka': ('knakk',),
'knakken': ('knakk',),
'knakkene': ('knakk',),
'knakket': ('knakk',),
'knakkpølsa': ('knakkpølse',),
'knakkpølse': ('knakkpølse',),
'knakkpølsen': ('knakkpølse',),
'knakkpølsene': ('knakkpølse',),
'knakkpølser': ('knakkpølse',),
'knakkwurst': ('knakkwurst',),
'knakkwursten': ('knakkwurst',),
'knakkwurstene': ('knakkwurst',),
'knall': ('knall',),
'knalla': ('knall',),
'knallene': ('knall',),
'knallet': ('knall',),
'knallavslutning': ('knallavslutning',),
'knallavslutninga': ('knallavslutning',),
'knallavslutningen': ('knallavslutning',),
'knallavslutningene': ('knallavslutning',),
'knallavslutninger': ('knallavslutning',),
'knallbongbong': ('knallbongbong',),
'knallbongbongen': ('knallbongbong',),
'knallbongbongene': ('knallbongbong',),
'knallbongbonger': ('knallbongbong',),
'knalleffekt': ('knalleffekt',),
'knalleffekten': ('knalleffekt',),
'knalleffektene': ('knalleffekt',),
'knalleffekter': ('knalleffekt',),
'knallert': ('knallert',),
'knallerten': ('knallert',),
'knallertene': ('knallert',),
'knallerter': ('knallert',),
'knallform': ('knallform',),
'knallforma': ('knallform',),
'knallformen': ('knallform',),
'knallformene': ('knallform',),
'knallformer': ('knallform',),
'knallgass': ('knallgass',),
'knallgassen': ('knallgass',),
'knallgassene': ('knallgass',),
'knallgasser': ('knallgass',),
'knallperla': ('knallperle',),
'knallperle': ('knallperle',),
'knallperlen': ('knallperle',),
'knallperlene': ('knallperle',),
'knallperler': ('knallperle',),
'knallpistol': ('knallpistol',),
'knallpistolen': ('knallpistol',),
'knallpistolene': ('knallpistol',),
'knallpistoler': ('knallpistol',),
'knallsuksess': ('knallsuksess',),
'knallsuksessen': ('knallsuksess',),
'knallsuksessene': ('knallsuksess',),
'knallsuksesser': ('knallsuksess',),
'knaost': ('knaost',),
'knaosten': ('knaost',),
'knaostene': ('knaost',),
'knaoster': ('knaost',),
'knapp': ('knapp',),
'knappen': ('knapp',),
'knappene': ('knapp',),
'knapper': ('knapp',),
'knappenål': ('knappenål',),
'knappenåla': ('knappenål',),
'knappenålen': ('knappenål',),
'knappenålene': ('knappenål',),
'knappenåler': ('knappenål',),
'knapphet': ('knapphet',),
'knappheta': ('knapphet',),
'knappheten': ('knapphet',),
'knapphetene': ('knapphet',),
'knappheter': ('knapphet',),
'knapphol': ('knapphol',),
'knapphola': ('knapphol',),
'knappholene': ('knapphol',),
'knappholet': ('knapphol',),
'knappholsblomst': ('knappholsblomst',),
'knappholsblomsten': ('knappholsblomst',),
'knappholsblomstene': ('knappholsblomst',),
'knappholsblomster': ('knappholsblomst',),
'knappholssting': ('knappholssting',),
'knappholsstinga': ('knappholssting',),
'knappholsstingene': ('knappholssting',),
'knappholsstinget': ('knappholssting',),
'knapphull': ('knapphull',),
'knapphulla': ('knapphull',),
'knapphullene': ('knapphull',),
'knapphuller': ('knapphull',),
'knapphullet': ('knapphull',),
'knapphullsblomst': ('knapphullsblomst',),
'knapphullsblomsten': ('knapphullsblomst',),
'knapphullsblomstene': ('knapphullsblomst',),
'knapphullsblomster': ('knapphullsblomst',),
'knapphullssting': ('knapphullssting',),
'knapphullsstinga': ('knapphullssting',),
'knapphullsstingene': ('knapphullssting',),
'knapphullsstinget': ('knapphullssting',),
'knark': ('knark',),
'knarken': ('knark',),
'knarkene': ('knark',),
'knarker': ('knark',),
'knark': ('knark',),
'knarka': ('knark',),
'knarkene': ('knark',),
'knarket': ('knark',),
'knarker': ('knarker',),
'knarkere': ('knarker',),
'knarkeren': ('knarker',),
'knarkerer': ('knarker',),
'knarkerne': ('knarker',),
'knarr': ('knarr',),
'knarren': ('knarr',),
'knarrene': ('knarr',),
'knarrer': ('knarr',),
'knart': ('knart',),
'knarten': ('knart',),
'knartene': ('knart',),
'knarter': ('knart',),
'knas': ('knas',),
'knasa': ('knas',),
'knasene': ('knas',),
'knaset': ('knas',),
'knask': ('knask',),
'knaska': ('knask',),
'knaskene': ('knask',),
'knasket': ('knask',),
'knast': ('knast',),
'knasten': ('knast',),
'knastene': ('knast',),
'knaster': ('knast',),
'knatt': ('knatt',),
'knatten': ('knatt',),
'knattene': ('knatt',),
'knatter': ('knatt',),
'knaus': ('knaus',),
'knausen': ('knaus',),
'knausene': ('knaus',),
'knauser': ('knaus',),
'knause': ('knause',),
'knausen': ('knause',),
'knausene': ('knause',),
'knauser': ('knause',),
'knavre': ('knavre',),
'knavren': ('knavre',),
'knavrene': ('knavre',),
'knavrer': ('knavre',),
'kne': ('kne',),
'knea': ('kne',),
'kneet': ('kne',),
'knær': ('kne',),
'knærne': ('kne',),
'knebel': ('knebel',),
'knebelen': ('knebel',),
'kneblene': ('knebel',),
'knebler': ('knebel',),
'knebel': ('knebel',),
'knebelen': ('knebel',),
'kneblene': ('knebel',),
'knebler': ('knebel',),
'knebel': ('knebel',),
'knebelen': ('knebel',),
'kneblene': ('knebel',),
'knebler': ('knebel',),
'knebelsbart': ('knebelsbart',),
'knebelsbarten': ('knebelsbart',),
'knebelsbartene': ('knebelsbart',),
'knebelsbarter': ('knebelsbart',),
'knebeskytter': ('knebeskytter',),
'knebeskyttere': ('knebeskytter',),
'knebeskytteren': ('knebeskytter',),
'knebeskytterer': ('knebeskytter',),
'knebeskytterne': ('knebeskytter',),
'knebuksa': ('knebukse',),
'knebukse': ('knebukse',),
'knebuksen': ('knebukse',),
'knebuksene': ('knebukse',),
'knebukser': ('knebukse',),
'knebøy': ('knebøy',),
'knebøyen': ('knebøy',),
'knebøyene': ('knebøy',),
'knebøyer': ('knebøy',),
'knebøyning': ('knebøyning',),
'knebøyninga': ('knebøyning',),
'knebøyningen': ('knebøyning',),
'knebøyningene': ('knebøyning',),
'knebøyninger': ('knebøyning',),
'knefall': ('knefall',),
'knefalla': ('knefall',),
'knefallene': ('knefall',),
'knefallet': ('knefall',),
'knegg': ('knegg',),
'knegga': ('knegg',),
'kneggen': ('knegg',),
'kneggene': ('knegg',),
'knegget': ('knegg',),
'knehase': ('knehase',),
'knehasen': ('knehase',),
'knehasene': ('knehase',),
'knehaser': ('knehase',),
'knehøna': ('knehøne',),
'knehøne': ('knehøne',),
'knehønen': ('knehøne',),
'knehønene': ('knehøne',),
'knehøner': ('knehøne',),
'kneik': ('kneik',),
'kneika': ('kneik',),
'kneiken': ('kneik',),
'kneikene': ('kneik',),
'kneiker': ('kneik',),
'kneipa': ('kneipe',),
'kneipe': ('kneipe',),
'kneipen': ('kneipe',),
'kneipene': ('kneipe',),
'kneiper': ('kneipe',),
'kneippbrød': ('kneippbrød',),
'kneippbrøda': ('kneippbrød',),
'kneippbrødene': ('kneippbrød',),
'kneippbrødet': ('kneippbrød',),
'kneippkavring': ('kneippkavring',),
'kneippkavringen': ('kneippkavring',),
'kneippkavringene': ('kneippkavring',),
'kneippkavringer': ('kneippkavring',),
'kneipploff': ('kneipploff',),
'kneipploffen': ('kneipploff',),
'kneipploffene': ('kneipploff',),
'kneipploffer': ('kneipploff',),
'knekkebrød': ('knekkebrød',),
'knekkebrøda': ('knekkebrød',),
'knekkebrødene': ('knekkebrød',),
'knekkebrødet': ('knekkebrød',),
'knekker': ('knekker',),
'knekkere': ('knekker',),
'knekkeren': ('knekker',),
'knekkerer': ('knekker',),
'knekkerne': ('knekker',),
'knekt': ('knekt',),
'knekten': ('knekt',),
'knektene': ('knekt',),
'knekter': ('knekt',),
'kneledd': ('kneledd',),
'kneledda': ('kneledd',),
'kneleddene': ('kneledd',),
'kneleddet': ('kneledd',),
'kneler': ('kneler',),
'knelere': ('kneler',),
'kneleren': ('kneler',),
'knelerer': ('kneler',),
'knelerne': ('kneler',),
'knep': ('knep',),
'knepa': ('knep',),
'knepene': ('knep',),
'knepet': ('knep',),
'knepp': ('knepp',),
'kneppa': ('knepp',),
'kneppen': ('knepp',),
'kneppene': ('knepp',),
'kneppet': ('knepp',),
'kneppkaka': ('kneppkake',),
'kneppkake': ('kneppkake',),
'kneppkaken': ('kneppkake',),
'kneppkakene': ('kneppkake',),
'kneppkaker': ('kneppkake',),
'knert': ('knert',),
'knerten': ('knert',),
'knertene': ('knert',),
'knerter': ('knert',),
'knesbot': ('knesbot',),
'knesbota': ('knesbot',),
'knesboten': ('knesbot',),
'knesbøtene': ('knesbot',),
'knesbøter': ('knesbot',),
'kneskål': ('kneskål',),
'kneskåla': ('kneskål',),
'kneskålen': ('kneskål',),
'kneskålene': ('kneskål',),
'kneskåler': ('kneskål',),
'knest': ('knest',),
'knesten': ('knest',),
'knestene': ('knest',),
'knester': ('knest',),
'knestrømpa': ('knestrømpe',),
'knestrømpe': ('knestrømpe',),
'knestrømpen': ('knestrømpe',),
'knestrømpene': ('knestrømpe',),
'knestrømper': ('knestrømpe',),
'knett': ('knett',),
'knetten': ('knett',),
'knettene': ('knett',),
'knetter': ('knett',),
'kniks': ('kniks',),
'kniksa': ('kniks',),
'kniksene': ('kniks',),
'knikset': ('kniks',),
'knip': ('knip',),
'knipa': ('knip',),
'knipene': ('knip',),
'knipet': ('knip',),
'knipa': ('knipe',),
'knipe': ('knipe',),
'knipen': ('knipe',),
'knipene': ('knipe',),
'kniper': ('knipe',),
'kniper': ('kniper',),
'knipere': ('kniper',),
'kniperen': ('kniper',),
'kniperer': ('kniper',),
'kniperne': ('kniper',),
'knipetak': ('knipetak',),
'knipetaka': ('knipetak',),
'knipetakene': ('knipetak',),
'knipetaket': ('knipetak',),
'kniplepinne': ('kniplepinne',),
'kniplepinnen': ('kniplepinne',),
'kniplepinnene': ('kniplepinne',),
'kniplepinner': ('kniplepinne',),
'knipling': ('knipling',),
'kniplingen': ('knipling',),
'kniplingene': ('knipling',),
'kniplinger': ('knipling',),
'knipling': ('knipling',),
'kniplinga': ('knipling',),
'kniplingen': ('knipling',),
'kniplingene': ('knipling',),
'kniplinger': ('knipling',),
'kniplingslommetørkle': ('kniplingslommetørkle',),
'kniplingslommetørkleet': ('kniplingslommetørkle',),
'kniplingslommetørklær': ('kniplingslommetørkle',),
'kniplingslommetørklærne': ('kniplingslommetørkle',),
'knippa': ('knippe',),
'knippe': ('knippe',),
'knippene': ('knippe',),
'knipper': ('knippe',),
'knippet': ('knippe',),
'knippa': ('knippe',),
'knippe': ('knippe',),
'knippen': ('knippe',),
'knippene': ('knippe',),
'knipper': ('knippe',),
'knips': ('knips',),
'knipsa': ('knips',),
'knipsene': ('knips',),
'knipset': ('knips',),
'knirk': ('knirk',),
'knirka': ('knirk',),
'knirken': ('knirk',),
'knirkene': ('knirk',),
'knirket': ('knirk',),
'knis': ('knis',),
'knisa': ('knis',),
'knisen': ('knis',),
'knisene': ('knis',),
'kniset': ('knis',),
'knisl': ('knisl',),
'knisla': ('knisl',),
'knislene': ('knisl',),
'knislet': ('knisl',),
'knittelvers': ('knittelvers',),
'knittelversa': ('knittelvers',),
'knittelversene': ('knittelvers',),
'knittelverset': ('knittelvers',),
'kniv': ('kniv',),
'kniven': ('kniv',),
'knivene': ('kniv',),
'kniver': ('kniv',),
'knivblad': ('knivblad',),
'knivblada': ('knivblad',),
'knivbladene': ('knivblad',),
'knivblader': ('knivblad',),
'knivbladet': ('knivblad',),
'knivegg': ('knivegg',),
'knivegga': ('knivegg',),
'kniveggen': ('knivegg',),
'kniveggene': ('knivegg',),
'knivegger': ('knivegg',),
'knivsblad': ('knivsblad',),
'knivsblada': ('knivsblad',),
'knivsbladene': ('knivsblad',),
'knivsblader': ('knivsblad',),
'knivsbladet': ('knivsblad',),
'knivsegg': ('knivsegg',),
'knivsegga': ('knivsegg',),
'knivseggen': ('knivsegg',),
'knivseggene': ('knivsegg',),
'knivsegger': ('knivsegg',),
'knivsliper': ('knivsliper',),
'knivslipere': ('knivsliper',),
'knivsliperen': ('knivsliper',),
'knivsliperer': ('knivsliper',),
'knivsliperne': ('knivsliper',),
'knivsodd': ('knivsodd',),
'knivsodden': ('knivsodd',),
'knivsoddene': ('knivsodd',),
'knivsodder': ('knivsodd',),
'knivstikk': ('knivstikk',),
'knivstikka': ('knivstikk',),
'knivstikkene': ('knivstikk',),
'knivstikket': ('knivstikk',),
'knivstikker': ('knivstikker',),
'knivstikkere': ('knivstikker',),
'knivstikkeren': ('knivstikker',),
'knivstikkerer': ('knivstikker',),
'knivstikkerne': ('knivstikker',),
'knockout': ('knockout',),
'knockouten': ('knockout',),
'knockoutene': ('knockout',),
'knockouter': ('knockout',),
'knog': ('knog',),
'knoga': ('knog',),
'knogene': ('knog',),
'knoget': ('knog',),
'knoger': ('knoger',),
'knogere': ('knoger',),
'knogeren': ('knoger',),
'knogerer': ('knoger',),
'knogerne': ('knoger',),
'knok': ('knok',),
'knoken': ('knok',),
'knokene': ('knok',),
'knoker': ('knok',),
'knoke': ('knoke',),
'knoken': ('knoke',),
'knokene': ('knoke',),
'knoker': ('knoke',),
'knokkel': ('knokkel',),
'knokkelen': ('knokkel',),
'knoklene': ('knokkel',),
'knokler': ('knokkel',),
'knokkelkamp': ('knokkelkamp',),
'knokkelkampen': ('knokkelkamp',),
'knokkelkampene': ('knokkelkamp',),
'knokkelkamper': ('knokkelkamp',),
'knoll': ('knoll',),
'knollen': ('knoll',),
'knollene': ('knoll',),
'knoller': ('knoll',),
'knopp': ('knopp',),
'knoppen': ('knopp',),
'knoppene': ('knopp',),
'knopper': ('knopp',),
'knoppskyting': ('knoppskyting',),
'knoppskytinga': ('knoppskyting',),
'knoppskytingen': ('knoppskyting',),
'knoppskytingene': ('knoppskyting',),
'knoppskytinger': ('knoppskyting',),
'knoppskytning': ('knoppskytning',),
'knoppskytninga': ('knoppskytning',),
'knoppskytningen': ('knoppskytning',),
'knoppskytningene': ('knoppskytning',),
'knoppskytninger': ('knoppskytning',),
'knoppsvana': ('knoppsvane',),
'knoppsvane': ('knoppsvane',),
'knoppsvanen': ('knoppsvane',),
'knoppsvanene': ('knoppsvane',),
'knoppsvaner': ('knoppsvane',),
'knort': ('knort',),
'knorten': ('knort',),
'knortene': ('knort',),
'knorter': ('knort',),
'knortekjepp': ('knortekjepp',),
'knortekjeppen': ('knortekjepp',),
'knortekjeppene': ('knortekjepp',),
'knortekjepper': ('knortekjepp',),
'knot': ('knot',),
'knota': ('knot',),
'knotene': ('knot',),
'knotet': ('knot',),
'knowhow': ('knowhow',),
'knowhowen': ('knowhow',),
'knowhowene': ('knowhow',),
'knowhower': ('knowhow',),
'knubb': ('knubb',),
'knubba': ('knubb',),
'knubbene': ('knubb',),
'knubbet': ('knubb',),
'knubbord': ('knubbord',),
'knubborda': ('knubbord',),
'knubbordene': ('knubbord',),
'knubbordet': ('knubbord',),
'knue': ('knue',),
'knuen': ('knue',),
'knuene': ('knue',),
'knuer': ('knue',),
'knull': ('knull',),
'knulla': ('knull',),
'knullene': ('knull',),
'knullet': ('knull',),
'knult': ('knult',),
'knulten': ('knult',),
'knultene': ('knult',),
'knulter': ('knult',),
'knultra': ('knultre',),
'knultre': ('knultre',),
'knultren': ('knultre',),
'knultrene': ('knultre',),
'knultrer': ('knultre',),
'knupp': ('knupp',),
'knuppen': ('knupp',),
'knuppene': ('knupp',),
'knupper': ('knupp',),
'knups': ('knups',),
'knupsa': ('knups',),
'knupsen': ('knups',),
'knupsene': ('knups',),
'knupset': ('knups',),
'knurr': ('knurr',),
'knurren': ('knurr',),
'knurrene': ('knurr',),
'knurrer': ('knurr',),
'knurr': ('knurr',),
'knurra': ('knurr',),
'knurrene': ('knurr',),
'knurret': ('knurr',),
'knurv': ('knurv',),
'knurven': ('knurv',),
'knurvene': ('knurv',),
'knurver': ('knurv',),
'knuseverk': ('knuseverk',),
'knuseverka': ('knuseverk',),
'knuseverkene': ('knuseverk',),
'knuseverker': ('knuseverk',),
'knuseverket': ('knuseverk',),
'knusk': ('knusk',),
'knusken': ('knusk',),
'knuskene': ('knusk',),
'knusker': ('knusk',),
'knusleri': ('knusleri',),
'knusleria': ('knusleri',),
'knusleriene': ('knusleri',),
'knuslerier': ('knusleri',),
'knusleriet': ('knusleri',),
'knusla': ('knussel',),
'knuslene': ('knussel',),
'knusler': ('knussel',),
'knuslet': ('knussel',),
'knussel': ('knussel',),
'knusselet': ('knussel',),
'knut': ('knut',),
'knuten': ('knut',),
'knutene': ('knut',),
'knuter': ('knut',),
'knute': ('knute',),
'knuten': ('knute',),
'knutene': ('knute',),
'knuter': ('knute',),
'knutekål': ('knutekål',),
'knutekålen': ('knutekål',),
'knutekålene': ('knutekål',),
'knutekåler': ('knutekål',),
'knutepunkt': ('knutepunkt',),
'knutepunkta': ('knutepunkt',),
'knutepunktene': ('knutepunkt',),
'knutepunkter': ('knutepunkt',),
'knutepunktet': ('knutepunkt',),
'knuterosen': ('knuterosen',),
'knuteskrift': ('knuteskrift',),
'knuteskrifta': ('knuteskrift',),
'knuteskriften': ('knuteskrift',),
'knuteskriftene': ('knuteskrift',),
'knuteskrifter': ('knuteskrift',),
'knutetann': ('knutetann',),
'knutetanna': ('knutetann',),
'knutetannen': ('knutetann',),
'knutetennene': ('knutetann',),
'knutetenner': ('knutetann',),
'knutt': ('knutt',),
'knutten': ('knutt',),
'knuttene': ('knutt',),
'knutter': ('knutt',),
'knuvl': ('knuvl',),
'knuvlen': ('knuvl',),
'knuvlene': ('knuvl',),
'knuvler': ('knuvl',),
'knuvl': ('knuvl',),
'knuvla': ('knuvl',),
'knuvlene': ('knuvl',),
'knuvlet': ('knuvl',),
'kny': ('kny',),
'knya': ('kny',),
'knyene': ('kny',),
'knyet': ('kny',),
'knyst': ('knyst',),
'knysta': ('knyst',),
'knysten': ('knyst',),
'knystene': ('knyst',),
'knystet': ('knyst',),
'knyting': ('knyting',),
'knytingen': ('knyting',),
'knytingene': ('knyting',),
'knytinger': ('knyting',),
'knytta': ('knytte',),
'knytte': ('knytte',),
'knyttene': ('knytte',),
'knytter': ('knytte',),
'knyttet': ('knytte',),
'knyttneve': ('knyttneve',),
'knyttneven': ('knyttneve',),
'knyttnevene': ('knyttneve',),
'knyttnever': ('knyttneve',),
'knøl': ('knøl',),
'knølen': ('knøl',),
'knølene': ('knøl',),
'knøler': ('knøl',),
'knølhval': ('knølhval',),
'knølhvalen': ('knølhval',),
'knølhvalene': ('knølhval',),
'knølhvaler': ('knølhval',),
'knølkval': ('knølkval',),
'knølkvalen': ('knølkval',),
'knølkvalene': ('knølkval',),
'knølkvaler': ('knølkval',),
'knøs': ('knøs',),
'knøsen': ('knøs',),
'knøsene': ('knøs',),
'knøser': ('knøs',),
'knøtt': ('knøtt',),
'knøtta': ('knøtt',),
'knøttene': ('knøtt',),
'knøttet': ('knøtt',),
'ko-ko': ('ko-ko',),
'ko-koa': ('ko-ko',),
'ko-koene': ('ko-ko',),
'ko-koet': ('ko-ko',),
'koagel': ('koagel',),
'koagelet': ('koagel',),
'koagla': ('koagel',),
'koaglene': ('koagel',),
'koagler': ('koagel',),
'koagulasjon': ('koagulasjon',),
'koagulasjonen': ('koagulasjon',),
'koagulasjonene': ('koagulasjon',),
'koagulasjoner': ('koagulasjon',),
'koaksialkabel': ('koaksialkabel',),
'koaksialkabelen': ('koaksialkabel',),
'koaksialkablene': ('koaksialkabel',),
'koaksialkabler': ('koaksialkabel',),
'koalisjon': ('koalisjon',),
'koalisjonen': ('koalisjon',),
'koalisjonene': ('koalisjon',),
'koalisjoner': ('koalisjon',),
'koalisjonsparti': ('koalisjonsparti',),
'koalisjonspartia': ('koalisjonsparti',),
'koalisjonspartiene': ('koalisjonsparti',),
'koalisjonspartier': ('koalisjonsparti',),
'koalisjonspartiet': ('koalisjonsparti',),
'koalisjonsregjering': ('koalisjonsregjering',),
'koalisjonsregjeringa': ('koalisjonsregjering',),
'koalisjonsregjeringen': ('koalisjonsregjering',),
'koalisjonsregjeringene': ('koalisjonsregjering',),
'koalisjonsregjeringer': ('koalisjonsregjering',),
'kobbe': ('kobbe',),
'kobben': ('kobbe',),
'kobbene': ('kobbe',),
'kobber': ('kobbe',),
'kobbeklysa': ('kobbeklyse',),
'kobbeklyse': ('kobbeklyse',),
'kobbeklysen': ('kobbeklyse',),
'kobbeklysene': ('kobbeklyse',),
'kobbeklyser': ('kobbeklyse',),
'kobbel': ('kobbel',),
'kobbelet': ('kobbel',),
'kobla': ('kobbel',),
'koblene': ('kobbel',),
'kobler': ('kobbel',),
'koblet': ('kobbel',),
'kobber': ('kobber',),
'kobbera': ('kobber',),
'kobbere': ('kobber',),
'kobberet': ('kobber',),
'kobberne': ('kobber',),
'kobbergruva': ('kobbergruve',),
'kobbergruve': ('kobbergruve',),
'kobbergruven': ('kobbergruve',),
'kobbergruvene': ('kobbergruve',),
'kobbergruver': ('kobbergruve',),
'kobberhud': ('kobberhud',),
'kobberhuda': ('kobberhud',),
'kobberhuden': ('kobberhud',),
'kobberhudene': ('kobberhud',),
'kobberhuder': ('kobberhud',),
'kobberkis': ('kobberkis',),
'kobberkisen': ('kobberkis',),
'kobberkisene': ('kobberkis',),
'kobberkiser': ('kobberkis',),
'kobberkjel': ('kobberkjel',),
'kobberkjelen': ('kobberkjel',),
'kobberkjelene': ('kobberkjel',),
'kobberkjeler': ('kobberkjel',),
'kobberkjele': ('kobberkjele',),
'kobberkjelen': ('kobberkjele',),
'kobberkjelene': ('kobberkjele',),
'kobberkjeler': ('kobberkjele',),
'kobbernagle': ('kobbernagle',),
'kobbernaglen': ('kobbernagle',),
'kobbernaglene': ('kobbernagle',),
'kobbernagler': ('kobbernagle',),
'kobberstikk': ('kobberstikk',),
'kobberstikka': ('kobberstikk',),
'kobberstikkene': ('kobberstikk',),
'kobberstikket': ('kobberstikk',),
'kobberstikk': ('kobberstikk',),
'kobberstikka': ('kobberstikk',),
'kobberstikkene': ('kobberstikk',),
'kobberstikket': ('kobberstikk',),
'kobbertråd': ('kobbertråd',),
'kobbertråden': ('kobbertråd',),
'kobbertrådene': ('kobbertråd',),
'kobbertråder': ('kobbertråd',),
'kobler': ('kobler',),
'koblere': ('kobler',),
'kobleren': ('kobler',),
'koblerer': ('kobler',),
'koblerne': ('kobler',),
'kobleri': ('kobleri',),
'kobleria': ('kobleri',),
'kobleriene': ('kobleri',),
'koblerier': ('kobleri',),
'kobleriet': ('kobleri',),
'koblerska': ('koblerske',),
'koblerske': ('koblerske',),
'koblersken': ('koblerske',),
'koblerskene': ('koblerske',),
'koblersker': ('koblerske',),
'kobling': ('kobling',),
'koblinga': ('kobling',),
'koblingen': ('kobling',),
'koblingene': ('kobling',),
'koblinger': ('kobling',),
'koblingsboks': ('koblingsboks',),
'koblingsboksen': ('koblingsboks',),
'koblingsboksene': ('koblingsboks',),
'koblingsbokser': ('koblingsboks',),
'kobolt': ('kobolt',),
'kobolta': ('kobolt',),
'kobolten': ('kobolt',),
'koboltene': ('kobolt',),
'kobolter': ('kobolt',),
'koboltet': ('kobolt',),
'koboltblått': ('koboltblått',),
'koboltglans': ('koboltglans',),
'koboltglansen': ('koboltglans',),
'koboltglansene': ('koboltglans',),
'koboltglanser': ('koboltglans',),
'koboltstål': ('koboltstål',),
'koboltståla': ('koboltstål',),
'koboltstålene': ('koboltstål',),
'koboltstålet': ('koboltstål',),
'kobra': ('kobra',),
'kobraen': ('kobra',),
'kobraene': ('kobra',),
'kobraer': ('kobra',),
'kochenille': ('kochenille',),
'kochenillen': ('kochenille',),
'kochenillene': ('kochenille',),
'kocheniller': ('kochenille',),
'kodd': ('kodd',),
'kodden': ('kodd',),
'koddene': ('kodd',),
'kodder': ('kodd',),
'kodde': ('kodde',),
'kodden': ('kodde',),
'koddene': ('kodde',),
'kodder': ('kodde',),
'kode': ('kode',),
'koden': ('kode',),
'kodene': ('kode',),
'koder': ('kode',),
'kode': ('kode',),
'koden': ('kode',),
'kodene': ('kode',),
'koder': ('kode',),
'kodebok': ('kodebok',),
'kodeboka': ('kodebok',),
'kodeboken': ('kodebok',),
'kodebøkene': ('kodebok',),
'kodebøker': ('kodebok',),
'kodeks': ('kodeks',),
'kodeksen': ('kodeks',),
'kodeksene': ('kodeks',),
'kodekser': ('kodeks',),
'kodelås': ('kodelås',),
'kodelåsa': ('kodelås',),
'kodelåsen': ('kodelås',),
'kodelåsene': ('kodelås',),
'kodelåser': ('kodelås',),
'kodelåset': ('kodelås',),
'koder': ('koder',),
'kodere': ('koder',),
'koderen': ('koder',),
'koderer': ('koder',),
'koderne': ('koder',),
'kodeskjema': ('kodeskjema',),
'kodeskjemaene': ('kodeskjema',),
'kodeskjemaer': ('kodeskjema',),
'kodeskjemaet': ('kodeskjema',),
'kodeskrift': ('kodeskrift',),
'kodeskrifta': ('kodeskrift',),
'kodeskriften': ('kodeskrift',),
'kodeskriftene': ('kodeskrift',),
'kodeskrifter': ('kodeskrift',),
'kodetelegram': ('kodetelegram',),
'kodetelegramma': ('kodetelegram',),
'kodetelegrammene': ('kodetelegram',),
'kodetelegrammer': ('kodetelegram',),
'kodetelegrammet': ('kodetelegram',),
'kodiakbjørn': ('kodiakbjørn',),
'kodiakbjørnen': ('kodiakbjørn',),
'kodiakbjørnene': ('kodiakbjørn',),
'kodiakbjørner': ('kodiakbjørn',),
'kodifikasjon': ('kodifikasjon',),
'kodifikasjonen': ('kodifikasjon',),
'kodifikasjonene': ('kodifikasjon',),
'kodifikasjoner': ('kodifikasjon',),
'kodifisering': ('kodifisering',),
'kodifiseringa': ('kodifisering',),
'kodifiseringen': ('kodifisering',),
'kodifiseringene': ('kodifisering',),
'kodifiseringer': ('kodifisering',),
'kodilje': ('kodilje',),
'kodiljen': ('kodilje',),
'kodiljene': ('kodilje',),
'kodiljer': ('kodilje',),
'kodisill': ('kodisill',),
'kodisillen': ('kodisill',),
'kodisillene': ('kodisill',),
'kodisiller': ('kodisill',),
'koeffisient': ('koeffisient',),
'koeffisienten': ('koeffisient',),
'koeffisientene': ('koeffisient',),
'koeffisienter': ('koeffisient',),
'koff': ('koff',),
'koffen': ('koff',),
'koffene': ('koff',),
'koffer': ('koff',),
'koffardi': ('koffardi',),
'koffardien': ('koffardi',),
'koffardiene': ('koffardi',),
'koffardier': ('koffardi',),
'koffardiskip': ('koffardiskip',),
'koffardiskipa': ('koffardiskip',),
'koffardiskipene': ('koffardiskip',),
'koffardiskipet': ('koffardiskip',),
'koffein': ('koffein',),
'koffeina': ('koffein',),
'koffeinen': ('koffein',),
'koffeinene': ('koffein',),
'koffeiner': ('koffein',),
'koffeinet': ('koffein',),
'koffein': ('koffein',),
'koffeina': ('koffein',),
'koffeinen': ('koffein',),
'koffeinene': ('koffein',),
'koffeiner': ('koffein',),
'koffeinet': ('koffein',),
'kofferdam': ('kofferdam',),
'kofferdammen': ('kofferdam',),
'kofferdammene': ('kofferdam',),
'kofferdammer': ('kofferdam',),
'koffernagle': ('koffernagle',),
'koffernaglen': ('koffernagle',),
'koffernaglene': ('koffernagle',),
'koffernagler': ('koffernagle',),
'koffert': ('koffert',),
'kofferten': ('koffert',),
'koffertene': ('koffert',),
'kofferter': ('koffert',),
'koffertklassa': ('koffertklasse',),
'koffertklasse': ('koffertklasse',),
'koffertklassen': ('koffertklasse',),
'koffertklassene': ('koffertklasse',),
'koffertklasser': ('koffertklasse',),
'koffertløper': ('koffertløper',),
'koffertløpere': ('koffertløper',),
'koffertløperen': ('koffertløper',),
'koffertløperer': ('koffertløper',),
'koffertløperne': ('koffertløper',),
'kofta': ('kofte',),
'kofte': ('kofte',),
'koften': ('kofte',),
'koftene': ('kofte',),
'kofter': ('kofte',),
'kogg': ('kogg',),
'koggen': ('kogg',),
'koggene': ('kogg',),
'kogger': ('kogg',),
'kogg': ('kogg',),
'koggen': ('kogg',),
'koggene': ('kogg',),
'kogger': ('kogg',),
'kogge': ('kogge',),
'koggen': ('kogge',),
'koggene': ('kogge',),
'kogger': ('kogge',),
'kogger': ('kogger',),
'koggeret': ('kogger',),
'kogra': ('kogger',),
'kogre': ('kogger',),
'kogrene': ('kogger',),
'kogleri': ('kogleri',),
'kogleria': ('kogleri',),
'kogleriene': ('kogleri',),
'koglerier': ('kogleri',),
'kogleriet': ('kogleri',),
'kognat': ('kognat',),
'kognaten': ('kognat',),
'kognatene': ('kognat',),
'kognater': ('kognat',),
'koherens': ('koherens',),
'koherensen': ('koherens',),
'koherensene': ('koherens',),
'koherenser': ('koherens',),
'kohesjon': ('kohesjon',),
'kohesjonen': ('kohesjon',),
'kohesjonene': ('kohesjon',),
'kohesjoner': ('kohesjon',),
'kohort': ('kohort',),
'kohorten': ('kohort',),
'kohortene': ('kohort',),
'kohorter': ('kohort',),
'koia': ('koie',),
'koie': ('koie',),
'koien': ('koie',),
'koiene': ('koie',),
'koier': ('koie',),
'koitus': ('koitus',),
'koitusen': ('koitus',),
'koitusene': ('koitus',),
'koituser': ('koitus',),
'kok': ('kok',),
'koka': ('kok',),
'koken': ('kok',),
'kokene': ('kok',),
'koker': ('kok',),
'koket': ('kok',),
'koka': ('koka',),
'kokaen': ('koka',),
'kokaene': ('koka',),
'kokaer': ('koka',),
'kokabusk': ('kokabusk',),
'kokabusken': ('kokabusk',),
'kokabuskene': ('kokabusk',),
'kokabusker': ('kokabusk',),
'kokain': ('kokain',),
'kokaina': ('kokain',),
'kokainen': ('kokain',),
'kokainene': ('kokain',),
'kokainer': ('kokain',),
'kokainet': ('kokain',),
'kokainist': ('kokainist',),
'kokainisten': ('kokainist',),
'kokainistene': ('kokainist',),
'kokainister': ('kokainist',),
'kokainmisbruk': ('kokainmisbruk',),
'kokainmisbruka': ('kokainmisbruk',),
'kokainmisbruken': ('kokainmisbruk',),
'kokainmisbrukene': ('kokainmisbruk',),
'kokainmisbruker': ('kokainmisbruk',),
'kokainmisbruket': ('kokainmisbruk',),
'kokarde': ('kokarde',),
'kokarden': ('kokarde',),
'kokardene': ('kokarde',),
'kokarder': ('kokarde',),
'koka': ('koke',),
'koke': ('koke',),
'koken': ('koke',),
'kokene': ('koke',),
'koker': ('koke',),
'koka': ('koke',),
'koke': ('koke',),
'koken': ('koke',),
'kokene': ('koke',),
'koker': ('koke',),
'kokefisk': ('kokefisk',),
'kokefisken': ('kokefisk',),
'kokefiskene': ('kokefisk',),
'kokefisker': ('kokefisk',),
'kokekar': ('kokekar',),
'kokekara': ('kokekar',),
'kokekarene': ('kokekar',),
'kokekaret': ('kokekar',),
'kokekunst': ('kokekunst',),
'kokekunsten': ('kokekunst',),
'kokekunstene': ('kokekunst',),
'kokekunster': ('kokekunst',),
'kokeplata': ('kokeplate',),
'kokeplate': ('kokeplate',),
'kokeplaten': ('kokeplate',),
'kokeplatene': ('kokeplate',),
'kokeplater': ('kokeplate',),
'kokepunkt': ('kokepunkt',),
'kokepunkta': ('kokepunkt',),
'kokepunktene': ('kokepunkt',),
'kokepunkter': ('kokepunkt',),
'kokepunktet': ('kokepunkt',),
'koker': ('koker',),
'kokere': ('koker',),
'kokeren': ('koker',),
'kokerer': ('koker',),
'kokerne': ('koker',),
'kokeri': ('kokeri',),
'kokeria': ('kokeri',),
'kokeriene': ('kokeri',),
'kokerier': ('kokeri',),
'kokeriet': ('kokeri',),
'kokesjokolade': ('kokesjokolade',),
'kokesjokoladen': ('kokesjokolade',),
'kokesjokoladene': ('kokesjokolade',),
'kokesjokolader': ('kokesjokolade',),
'koketta': ('kokette',),
'kokette': ('kokette',),
'koketten': ('kokette',),
'kokettene': ('kokette',),
'koketter': ('kokette',),
'koketteri': ('koketteri',),
'koketteria': ('koketteri',),
'koketteriene': ('koketteri',),
'koketterier': ('koketteri',),
'koketteriet': ('koketteri',),
'kokille': ('kokille',),
'kokillen': ('kokille',),
'kokillene': ('kokille',),
'kokiller': ('kokille',),
'kokk': ('kokk',),
'kokken': ('kokk',),
'kokkene': ('kokk',),
'kokker': ('kokk',),
'kokk': ('kokk',),
'kokken': ('kokk',),
'kokkene': ('kokk',),
'kokker': ('kokk',),
'kokka': ('kokke',),
'kokke': ('kokke',),
'kokken': ('kokke',),
'kokkene': ('kokke',),
'kokker': ('kokke',),
'kokkegutt': ('kokkegutt',),
'kokkegutten': ('kokkegutt',),
'kokkeguttene': ('kokkegutt',),
'kokkegutter': ('kokkegutt',),
'kokkejenta': ('kokkejente',),
'kokkejente': ('kokkejente',),
'kokkejenten': ('kokkejente',),
'kokkejentene': ('kokkejente',),
'kokkejenter': ('kokkejente',),
'kokksmat': ('kokksmat',),
'kokksmaten': ('kokksmat',),
'kokksmatene': ('kokksmat',),
'kokksmater': ('kokksmat',),
'kokning': ('kokning',),
'kokninga': ('kokning',),
'kokningen': ('kokning',),
'kokningene': ('kokning',),
'kokninger': ('kokning',),
'kokong': ('kokong',),
'kokongen': ('kokong',),
'kokongene': ('kokong',),
'kokonger': ('kokong',),
'kokos': ('kokos',),
'kokosen': ('kokos',),
'kokosene': ('kokos',),
'kokoser': ('kokos',),
'kokosmakron': ('kokosmakron',),
'kokosmakronen': ('kokosmakron',),
'kokosmakronene': ('kokosmakron',),
'kokosmakroner': ('kokosmakron',),
'kokosmasse': ('kokosmasse',),
'kokosmassen': ('kokosmasse',),
'kokosmassene': ('kokosmasse',),
'kokosmasser': ('kokosmasse',),
'kokosmatta': ('kokosmatte',),
'kokosmatte': ('kokosmatte',),
'kokosmatten': ('kokosmatte',),
'kokosmattene': ('kokosmatte',),
'kokosmatter': ('kokosmatte',),
'kokosmelk': ('kokosmelk',),
'kokosmelka': ('kokosmelk',),
'kokosmelken': ('kokosmelk',),
'kokosmelkene': ('kokosmelk',),
'kokosmelker': ('kokosmelk',),
'kokosmjølk': ('kokosmjølk',),
'kokosmjølka': ('kokosmjølk',),
'kokosmjølken': ('kokosmjølk',),
'kokosmjølkene': ('kokosmjølk',),
'kokosmjølker': ('kokosmjølk',),
'kokosnøtt': ('kokosnøtt',),
'kokosnøtta': ('kokosnøtt',),
'kokosnøtten': ('kokosnøtt',),
'kokosnøttene': ('kokosnøtt',),
'kokosnøtter': ('kokosnøtt',),
'kokospalme': ('kokospalme',),
'kokospalmen': ('kokospalme',),
'kokospalmene': ('kokospalme',),
'kokospalmer': ('kokospalme',),
'kokostau': ('kokostau',),
'kokostaua': ('kokostau',),
'kokostauene': ('kokostau',),
'kokostauet': ('kokostau',),
'kokotta': ('kokotte',),
'kokotte': ('kokotte',),
'kokotten': ('kokotte',),
'kokottene': ('kokotte',),
'kokotter': ('kokotte',),
'koks': ('koks',),
'koksen': ('koks',),
'koksene': ('koks',),
'kokser': ('koks',),
'koks': ('koks',),
'koksa': ('koks',),
'koksen': ('koks',),
'koksene': ('koks',),
'kokser': ('koks',),
'koksalt': ('koksalt',),
'koksalta': ('koksalt',),
'koksaltene': ('koksalt',),
'koksalter': ('koksalt',),
'koksaltet': ('koksalt',),
'koksomn': ('koksomn',),
'koksomnen': ('koksomn',),
'koksomnene': ('koksomn',),
'koksomner': ('koksomn',),
'koksovn': ('koksovn',),
'koksovnen': ('koksovn',),
'koksovnene': ('koksovn',),
'koksovner': ('koksovn',),
'koksverk': ('koksverk',),
'koksverka': ('koksverk',),
'koksverkene': ('koksverk',),
'koksverker': ('koksverk',),
'koksverket': ('koksverk',),
'kolbe': ('kolbe',),
'kolben': ('kolbe',),
'kolbene': ('kolbe',),
'kolber': ('kolbe',),
'kolbrenner': ('kolbrenner',),
'kolbrennere': ('kolbrenner',),
'kolbrenneren': ('kolbrenner',),
'kolbrennerer': ('kolbrenner',),
'kolbrennerne': ('kolbrenner',),
'koldbrann': ('koldbrann',),
'koldbrannen': ('koldbrann',),
'koldbrannene': ('koldbrann',),
'koldbranner': ('koldbrann',),
'koldfeber': ('koldfeber',),
'koldfebere': ('koldfeber',),
'koldfeberen': ('koldfeber',),
'koldfeberne': ('koldfeber',),
'koldfebre': ('koldfeber',),
'koldfebrene': ('koldfeber',),
'koldfebrer': ('koldfeber',),
'koldfyr': ('koldfyr',),
'koldfyren': ('koldfyr',),
'koldfyrene': ('koldfyr',),
'koldfyrer': ('koldfyr',),
'koldioksid': ('koldioksid',),
'koldioksida': ('koldioksid',),
'koldioksidene': ('koldioksid',),
'koldioksider': ('koldioksid',),
'koldioksidet': ('koldioksid',),
'koldjomfru': ('koldjomfru',),
'koldjomfrua': ('koldjomfru',),
'koldjomfruen': ('koldjomfru',),
'koldjomfruene': ('koldjomfru',),
'koldjomfruer': ('koldjomfru',),
'koldjomfru': ('koldjomfru',),
'koldjomfrua': ('koldjomfru',),
'koldjomfruen': ('koldjomfru',),
'koldjomfruene': ('koldjomfru',),
'koldjomfruer': ('koldjomfru',),
'koldkrem': ('koldkrem',),
'koldkremen': ('koldkrem',),
'koldkremene': ('koldkrem',),
'koldkremer': ('koldkrem',),
'koldtbord': ('koldtbord',),
'koldtborda': ('koldtbord',),
'koldtbordene': ('koldtbord',),
'koldtborder': ('koldtbord',),
'koldtbordet': ('koldtbord',),
'koldtbord': ('koldtbord',),
'koldtborda': ('koldtbord',),
'koldtbordene': ('koldtbord',),
'koldtborder': ('koldtbord',),
'koldtbordet': ('koldtbord',),
'koldtkjøkken': ('koldtkjøkken',),
'koldtkjøkkena': ('koldtkjøkken',),
'koldtkjøkkenene': ('koldtkjøkken',),
'koldtkjøkkener': ('koldtkjøkken',),
'koldtkjøkkenet': ('koldtkjøkken',),
'koldtkjøkken': ('koldtkjøkken',),
'koldtkjøkkena': ('koldtkjøkken',),
'koldtkjøkkenene': ('koldtkjøkken',),
'koldtkjøkkener': ('koldtkjøkken',),
'koldtkjøkkenet': ('koldtkjøkken',),
'kola': ('kole',),
'kole': ('kole',),
'kolen': ('kole',),
'kolene': ('kole',),
'koler': ('kole',),
'kolera': ('kolera',),
'koleraen': ('kolera',),
'koleraene': ('kolera',),
'koleraer': ('kolera',),
'koleriker': ('koleriker',),
'kolerikere': ('koleriker',),
'kolerikeren': ('koleriker',),
'kolerikerer': ('koleriker',),
'kolerikerne': ('koleriker',),
'kolerine': ('kolerine',),
'kolerinen': ('kolerine',),
'kolerinene': ('kolerine',),
'koleriner': ('kolerine',),
'kolesterol': ('kolesterol',),
'kolesterola': ('kolesterol',),
'kolesterolen': ('kolesterol',),
'kolesterolene': ('kolesterol',),
'kolesteroler': ('kolesterol',),
'kolesterolet': ('kolesterol',),
'kolhydrat': ('kolhydrat',),
'kolhydrata': ('kolhydrat',),
'kolhydratene': ('kolhydrat',),
'kolhydrater': ('kolhydrat',),
'kolhydratet': ('kolhydrat',),
'kolibakterie': ('kolibakterie',),
'kolibakterien': ('kolibakterie',),
'kolibakteriene': ('kolibakterie',),
'kolibakterier': ('kolibakterie',),
'kolibri': ('kolibri',),
'kolibrien': ('kolibri',),
'kolibriene': ('kolibri',),
'kolibrier': ('kolibri',),
'kolikk': ('kolikk',),
'kolikken': ('kolikk',),
'kolikkene': ('kolikk',),
'kolikker': ('kolikk',),
'kolitt': ('kolitt',),
'kolitten': ('kolitt',),
'kolittene': ('kolitt',),
'kolitter': ('kolitt',),
'kolja': ('kolje',),
'kolje': ('kolje',),
'koljen': ('kolje',),
'koljene': ('kolje',),
'koljer': ('kolje',),
'kolkos': ('kolkos',),
'kolkosa': ('kolkos',),
'kolkosene': ('kolkos',),
'kolkoser': ('kolkos',),
'kolkoset': ('kolkos',),
'koll': ('koll',),
'kollen': ('koll',),
'kollene': ('koll',),
'koller': ('koll',),
'kollaboratør': ('kollaboratør',),
'kollaboratøren': ('kollaboratør',),
'kollaboratørene': ('kollaboratør',),
'kollaboratører': ('kollaboratør',),
'kollaps': ('kollaps',),
'kollapsen': ('kollaps',),
'kollapsene': ('kollaps',),
'kollapser': ('kollaps',),
'kollas': ('kollas',),
'kollasen': ('kollas',),
'kollasene': ('kollas',),
'kollaser': ('kollas',),
'kollasj': ('kollasj',),
'kollasjen': ('kollasj',),
'kollasjene': ('kollasj',),
'kollasjer': ('kollasj',),
'kollasjon': ('kollasjon',),
'kollasjonen': ('kollasjon',),
'kollasjonene': ('kollasjon',),
'kollasjoner': ('kollasjon',),
'kollbøtta': ('kollbøtte',),
'kollbøtte': ('kollbøtte',),
'kollbøtten': ('kollbøtte',),
'kollbøttene': ('kollbøtte',),
'kollbøtter': ('kollbøtte',),
'kolle': ('kolle',),
'kollen': ('kolle',),
'kollene': ('kolle',),
'koller': ('kolle',),
'kolla': ('kolle',),
'kolle': ('kolle',),
'kollen': ('kolle',),
'kollene': ('kolle',),
'koller': ('kolle',),
'kolla': ('kolle',),
'kolle': ('kolle',),
'kollen': ('kolle',),
'kollene': ('kolle',),
'koller': ('kolle',),
'kollega': ('kollega',),
'kollegaen': ('kollega',),
'kollegaene': ('kollega',),
'kollegaer': ('kollega',),
'kollegene': ('kollega',),
'kolleger': ('kollega',),
'kollegialitet': ('kollegialitet',),
'kollegialiteten': ('kollegialitet',),
'kollegialitetene': ('kollegialitet',),
'kollegialiteter': ('kollegialitet',),
'kollegia': ('kollegium',),
'kollegiene': ('kollegium',),
'kollegier': ('kollegium',),
'kollegiet': ('kollegium',),
'kollegium': ('kollegium',),
'kolleksjon': ('kolleksjon',),
'kolleksjonen': ('kolleksjon',),
'kolleksjonene': ('kolleksjon',),
'kolleksjoner': ('kolleksjon',),
'kollekt': ('kollekt',),
'kollekten': ('kollekt',),
'kollektene': ('kollekt',),
'kollekter': ('kollekt',),
'kollektiv': ('kollektiv',),
'kollektiva': ('kollektiv',),
'kollektivene': ('kollektiv',),
'kollektiver': ('kollektiv',),
'kollektivet': ('kollektiv',),
'kollektivavtale': ('kollektivavtale',),
'kollektivavtalen': ('kollektivavtale',),
'kollektivavtalene': ('kollektivavtale',),
'kollektivavtaler': ('kollektivavtale',),
'kollektivbruk': ('kollektivbruk',),
'kollektivbruka': ('kollektivbruk',),
'kollektivbrukene': ('kollektivbruk',),
'kollektivbruket': ('kollektivbruk',),
'kollektivfelt': ('kollektivfelt',),
'kollektivfelta': ('kollektivfelt',),
'kollektivfeltene': ('kollektivfelt',),
'kollektivfelter': ('kollektivfelt',),
'kollektivfeltet': ('kollektivfelt',),
'kollektivisme': ('kollektivisme',),
'kollektivismen': ('kollektivisme',),
'kollektivismene': ('kollektivisme',),
'kollektivismer': ('kollektivisme',),
'kollektivist': ('kollektivist',),
'kollektivisten': ('kollektivist',),
'kollektivistene': ('kollektivist',),
'kollektivister': ('kollektivist',),
'kollektivroman': ('kollektivroman',),
'kollektivromanen': ('kollektivroman',),
'kollektivromanene': ('kollektivroman',),
'kollektivromaner': ('kollektivroman',),
'kollektivtrafikk': ('kollektivtrafikk',),
'kollektivtrafikken': ('kollektivtrafikk',),
'kollektivtrafikkene': ('kollektivtrafikk',),
'kollektivtrafikker': ('kollektivtrafikk',),
'kollektor': ('kollektor',),
'kollektoren': ('kollektor',),
'kollektorene': ('kollektor',),
'kollektorer': ('kollektor',),
'kolli': ('kolli',),
'kollia': ('kolli',),
'kolliene': ('kolli',),
'kollier': ('kolli',),
'kolliet': ('kolli',),
'kollisjon': ('kollisjon',),
'kollisjonen': ('kollisjon',),
'kollisjonene': ('kollisjon',),
'kollisjoner': ('kollisjon',),
'kollisjonskurs': ('kollisjonskurs',),
'kollisjonskursen': ('kollisjonskurs',),
'kollisjonskursene': ('kollisjonskurs',),
'kollisjonskurser': ('kollisjonskurs',),
'kollisjonsputa': ('kollisjonspute',),
'kollisjonspute': ('kollisjonspute',),
'kollisjonsputen': ('kollisjonspute',),
'kollisjonsputene': ('kollisjonspute',),
'kollisjonsputer': ('kollisjonspute',),
'kollodium': ('kollodium',),
'kollodiuma': ('kollodium',),
'kollodiumene': ('kollodium',),
'kollodiumet': ('kollodium',),
'kolloid': ('kolloid',),
'kolloida': ('kolloid',),
'kolloidene': ('kolloid',),
'kolloider': ('kolloid',),
'kolloidet': ('kolloid',),
'kollokviegruppa': ('kollokviegruppe',),
'kollokviegruppe': ('kollokviegruppe',),
'kollokviegruppen': ('kollokviegruppe',),
'kollokviegruppene': ('kollokviegruppe',),
'kollokviegrupper': ('kollokviegruppe',),
'kollokvieleder': ('kollokvieleder',),
'kollokvieledere': ('kollokvieleder',),
'kollokvielederen': ('kollokvieleder',),
'kollokvielederer': ('kollokvieleder',),
'kollokvielederne': ('kollokvieleder',),
'kollokvia': ('kollokvium',),
'kollokviene': ('kollokvium',),
'kollokvier': ('kollokvium',),
'kollokviet': ('kollokvium',),
'kollokvium': ('kollokvium',),
'kolmila': ('kolmile',),
'kolmile': ('kolmile',),
'kolmilen': ('kolmile',),
'kolmilene': ('kolmile',),
'kolmiler': ('kolmile',),
'kolmule': ('kolmule',),
'kolmulen': ('kolmule',),
'kolmulene': ('kolmule',),
'kolmuler': ('kolmule',),
'kolofon': ('kolofon',),
'kolofonen': ('kolofon',),
'kolofonene': ('kolofon',),
'kolofoner': ('kolofon',),
'kolofonsida': ('kolofonside',),
'kolofonside': ('kolofonside',),
'kolofonsiden': ('kolofonside',),
'kolofonsidene': ('kolofonside',),
'kolofonsider': ('kolofonside',),
'koloksid': ('koloksid',),
'koloksida': ('koloksid',),
'koloksidene': ('koloksid',),
'koloksider': ('koloksid',),
'koloksidet': ('koloksid',),
'kolokvint': ('kolokvint',),
'kolokvinten': ('kolokvint',),
'kolokvintene': ('kolokvint',),
'kolokvinter': ('kolokvint',),
'kolokvinter': ('kolokvinter',),
'kolokvintere': ('kolokvinter',),
'kolokvinteren': ('kolokvinter',),
'kolokvinterene': ('kolokvinter',),
'kolokvinterer': ('kolokvinter',),
'kolokvinterne': ('kolokvinter',),
'kolombianer': ('kolombianer',),
'kolombianere': ('kolombianer',),
'kolombianeren': ('kolombianer',),
'kolombianerer': ('kolombianer',),
'kolombianerne': ('kolombianer',),
'kolon': ('kolon',),
'kolona': ('kolon',),
'kolonene': ('kolon',),
'koloner': ('kolon',),
'kolonet': ('kolon',),
'koloni': ('koloni',),
'kolonien': ('koloni',),
'koloniene': ('koloni',),
'kolonier': ('koloni',),
'kolonial': ('kolonial',),
'kolonialen': ('kolonial',),
'kolonialene': ('kolonial',),
'kolonialer': ('kolonial',),
'kolonialbutikk': ('kolonialbutikk',),
'kolonialbutikken': ('kolonialbutikk',),
'kolonialbutikkene': ('kolonialbutikk',),
'kolonialbutikker': ('kolonialbutikk',),
'kolonialisme': ('kolonialisme',),
'kolonialismen': ('kolonialisme',),
'kolonialismene': ('kolonialisme',),
'kolonialismer': ('kolonialisme',),
'kolonialvara': ('kolonialvare',),
'kolonialvare': ('kolonialvare',),
'kolonialvaren': ('kolonialvare',),
'kolonialvarene': ('kolonialvare',),
'kolonialvarer': ('kolonialvare',),
'kolonihage': ('kolonihage',),
'kolonihagen': ('kolonihage',),
'kolonihagene': ('kolonihage',),
'kolonihager': ('kolonihage',),
'kolonimakt': ('kolonimakt',),
'kolonimakta': ('kolonimakt',),
'kolonimakten': ('kolonimakt',),
'kolonimaktene': ('kolonimakt',),
'kolonimakter': ('kolonimakt',),
'kolonisasjon': ('kolonisasjon',),
'kolonisasjonen': ('kolonisasjon',),
'kolonisasjonene': ('kolonisasjon',),
'kolonisasjoner': ('kolonisasjon',),
'kolonisator': ('kolonisator',),
'kolonisatoren': ('kolonisator',),
'kolonisatorene': ('kolonisator',),
'kolonisatorer': ('kolonisator',),
'kolonist': ('kolonist',),
'kolonisten': ('kolonist',),
'kolonistene': ('kolonist',),
'kolonister': ('kolonist',),
'kolonnade': ('kolonnade',),
'kolonnaden': ('kolonnade',),
'kolonnadene': ('kolonnade',),
'kolonnader': ('kolonnade',),
'kolonne': ('kolonne',),
'kolonnen': ('kolonne',),
'kolonnene': ('kolonne',),
'kolonner': ('kolonne',),
'koloradobille': ('koloradobille',),
'koloradobillen': ('koloradobille',),
'koloradobillene': ('koloradobille',),
'koloradobiller': ('koloradobille',),
'koloratur': ('koloratur',),
'koloraturen': ('koloratur',),
'koloraturene': ('koloratur',),
'koloraturer': ('koloratur',),
'koloratursangerinna': ('koloratursangerinne',),
'koloratursangerinne': ('koloratursangerinne',),
'koloratursangerinnen': ('koloratursangerinne',),
'koloratursangerinnene': ('koloratursangerinne',),
'koloratursangerinner': ('koloratursangerinne',),
'kolorimeter': ('kolorimeter',),
'kolorimeteret': ('kolorimeter',),
'kolorimetra': ('kolorimeter',),
'kolorimetre': ('kolorimeter',),
'kolorimetrene': ('kolorimeter',),
'kolorimetret': ('kolorimeter',),
'koloritt': ('koloritt',),
'koloritten': ('koloritt',),
'kolorittene': ('koloritt',),
'koloritter': ('koloritt',),
'kolos': ('kolos',),
'kolosen': ('kolos',),
'kolosene': ('kolos',),
'koloser': ('kolos',),
'koloss': ('koloss',),
'kolossen': ('koloss',),
'kolossene': ('koloss',),
'kolosser': ('koloss',),
'kolportasje': ('kolportasje',),
'kolportasjen': ('kolportasje',),
'kolportasjene': ('kolportasje',),
'kolportasjer': ('kolportasje',),
'kolportør': ('kolportør',),
'kolportøren': ('kolportør',),
'kolportørene': ('kolportør',),
'kolportører': ('kolportør',),
'kolstift': ('kolstift',),
'kolstiften': ('kolstift',),
'kolstiftene': ('kolstift',),
'kolstifter': ('kolstift',),
'kolstoff': ('kolstoff',),
'kolstoffa': ('kolstoff',),
'kolstoffene': ('kolstoff',),
'kolstoffer': ('kolstoff',),
'kolstoffet': ('kolstoff',),
'kolstøv': ('kolstøv',),
'kolstøva': ('kolstøv',),
'kolstøvene': ('kolstøv',),
'kolstøvet': ('kolstøv',),
'kolsviertro': ('kolsviertro',),
'kolsviertroa': ('kolsviertro',),
'kolsviertroen': ('kolsviertro',),
'kolsviertroene': ('kolsviertro',),
'kolsviertroer': ('kolsviertro',),
'kolsviertru': ('kolsviertru',),
'kolsviertrua': ('kolsviertru',),
'kolsviertruen': ('kolsviertru',),
'kolsviertruene': ('kolsviertru',),
'kolsviertruer': ('kolsviertru',),
'kolsyra': ('kolsyre',),
'kolsyre': ('kolsyre',),
'kolsyren': ('kolsyre',),
'kolsyrene': ('kolsyre',),
'kolsyrer': ('kolsyre',),
'kolsyreassimilasjon': ('kolsyreassimilasjon',),
'kolsyreassimilasjonen': ('kolsyreassimilasjon',),
'kolsyreassimilasjonene': ('kolsyreassimilasjon',),
'kolsyreassimilasjoner': ('kolsyreassimilasjon',),
'kolsyreis': ('kolsyreis',),
'kolsyreisen': ('kolsyreis',),
'kolsyreisene': ('kolsyreis',),
'kolsyreiser': ('kolsyreis',),
'koltegning': ('koltegning',),
'koltegninga': ('koltegning',),
'koltegningen': ('koltegning',),
'koltegningene': ('koltegning',),
'koltegninger': ('koltegning',),
'koltråd': ('koltråd',),
'koltråden': ('koltråd',),
'koltrådene': ('koltråd',),
'koltråder': ('koltråd',),
'kolumbaria': ('kolumbarium',),
'kolumbariene': ('kolumbarium',),
'kolumbarier': ('kolumbarium',),
'kolumbariet': ('kolumbarium',),
'kolumbarium': ('kolumbarium',),
'kolumne': ('kolumne',),
'kolumnen': ('kolumne',),
'kolumnene': ('kolumne',),
'kolumner': ('kolumne',),
'kolumnetitlene': ('kolumnetittel',),
'kolumnetitler': ('kolumnetittel',),
'kolumnetittel': ('kolumnetittel',),
'kolumnetittelen': ('kolumnetittel',),
'kolv': ('kolv',),
'kolven': ('kolv',),
'kolvene': ('kolv',),
'kolver': ('kolv',),
'kolvelås': ('kolvelås',),
'kolvelåsa': ('kolvelås',),
'kolvelåsen': ('kolvelås',),
'kolvelåsene': ('kolvelås',),
'kolvelåser': ('kolvelås',),
'kolvelåset': ('kolvelås',),
'kolvlås': ('kolvlås',),
'kolvlåsa': ('kolvlås',),
'kolvlåsen': ('kolvlås',),
'kolvlåsene': ('kolvlås',),
'kolvlåser': ('kolvlås',),
'kolvlåset': ('kolvlås',),
'koma': ('koma',),
'komaen': ('koma',),
'komaene': ('koma',),
'komaer': ('koma',),
'kombattant': ('kombattant',),
'kombattanten': ('kombattant',),
'kombattantene': ('kombattant',),
'kombattanter': ('kombattant',),
'kombibil': ('kombibil',),
'kombibilen': ('kombibil',),
'kombibilene': ('kombibil',),
'kombibiler': ('kombibil',),
'kombinasjon': ('kombinasjon',),
'kombinasjonen': ('kombinasjon',),
'kombinasjonene': ('kombinasjon',),
'kombinasjoner': ('kombinasjon',),
'kombinasjonsevna': ('kombinasjonsevne',),
'kombinasjonsevne': ('kombinasjonsevne',),
'kombinasjonsevnen': ('kombinasjonsevne',),
'kombinasjonsevnene': ('kombinasjonsevne',),
'kombinasjonsevner': ('kombinasjonsevne',),
'kombinasjonslås': ('kombinasjonslås',),
'kombinasjonslåsa': ('kombinasjonslås',),
'kombinasjonslåsen': ('kombinasjonslås',),
'kombinasjonslåsene': ('kombinasjonslås',),
'kombinasjonslåser': ('kombinasjonslås',),
'kombinasjonslåset': ('kombinasjonslås',),
'kombinasjonsskap': ('kombinasjonsskap',),
'kombinasjonsskapa': ('kombinasjonsskap',),
'kombinasjonsskapene': ('kombinasjonsskap',),
'kombinasjonsskapet': ('kombinasjonsskap',),
'kombinasjonsskip': ('kombinasjonsskip',),
'kombinasjonsskipa': ('kombinasjonsskip',),
'kombinasjonsskipene': ('kombinasjonsskip',),
'kombinasjonsskipet': ('kombinasjonsskip',),
'kombinasjonstang': ('kombinasjonstang',),
'kombinasjonstanga': ('kombinasjonstang',),
'kombinasjonstangen': ('kombinasjonstang',),
'kombinasjonstengene': ('kombinasjonstang',),
'kombinasjonstenger': ('kombinasjonstang',),
'kombinat': ('kombinat',),
'kombinata': ('kombinat',),
'kombinatene': ('kombinat',),
'kombinater': ('kombinat',),
'kombinatet': ('kombinat',),
'kombinert': ('kombinert',),
'kombinertrenn': ('kombinertrenn',),
'kombinertrenna': ('kombinertrenn',),
'kombinertrennene': ('kombinertrenn',),
'kombinertrennet': ('kombinertrenn',),
'kombioppgjør': ('kombioppgjør',),
'kombioppgjøra': ('kombioppgjør',),
'kombioppgjørene': ('kombioppgjør',),
'kombioppgjøret': ('kombioppgjør',),
'kombisykkel': ('kombisykkel',),
'kombisykkelen': ('kombisykkel',),
'kombisyklene': ('kombisykkel',),
'kombisykler': ('kombisykkel',),
'komediant': ('komediant',),
'komedianten': ('komediant',),
'komediantene': ('komediant',),
'komedianter': ('komediant',),
'komedie': ('komedie',),
'komedien': ('komedie',),
'komediene': ('komedie',),
'komedier': ('komedie',),
'komediefigur': ('komediefigur',),
'komediefiguren': ('komediefigur',),
'komediefigurene': ('komediefigur',),
'komediefigurer': ('komediefigur',),
'komedienna': ('komedienne',),
'komedienne': ('komedienne',),
'komediennen': ('komedienne',),
'komediennene': ('komedienne',),
'komedienner': ('komedienne',),
'komet': ('komet',),
'kometen': ('komet',),
'kometene': ('komet',),
'kometer': ('komet',),
'kometkarriera': ('kometkarriere',),
'kometkarriere': ('kometkarriere',),
'kometkarrieren': ('kometkarriere',),
'kometkarrierene': ('kometkarriere',),
'kometkarrierer': ('kometkarriere',),
'komfort': ('komfort',),
'komforten': ('komfort',),
'komfortene': ('komfort',),
'komforter': ('komfort',),
'komfyr': ('komfyr',),
'komfyren': ('komfyr',),
'komfyrene': ('komfyr',),
'komfyrer': ('komfyr',),
'komiker': ('komiker',),
'komikere': ('komiker',),
'komikeren': ('komiker',),
'komikerer': ('komiker',),
'komikerne': ('komiker',),
'komikk': ('komikk',),
'komikken': ('komikk',),
'komikkene': ('komikk',),
'komikker': ('komikk',),
'komiteen': ('komité',),
'komiteene': ('komité',),
'komiteer': ('komité',),
'komité': ('komité',),
'komitéen': ('komité',),
'komitéene': ('komité',),
'komitéer': ('komité',),
'komitéinnstilling': ('komitéinnstilling',),
'komitéinnstillinga': ('komitéinnstilling',),
'komitéinnstillingen': ('komitéinnstilling',),
'komitéinnstillingene': ('komitéinnstilling',),
'komitéinnstillinger': ('komitéinnstilling',),
'komma': ('komma',),
'kommaene': ('komma',),
'kommaer': ('komma',),
'kommaet': ('komma',),
'kommafeil': ('kommafeil',),
'kommafeilen': ('kommafeil',),
'kommafeilene': ('kommafeil',),
'kommag': ('kommag',),
'kommagen': ('kommag',),
'kommagene': ('kommag',),
'kommager': ('kommag',),
'kommandant': ('kommandant',),
'kommandanten': ('kommandant',),
'kommandantene': ('kommandant',),
'kommandanter': ('kommandant',),
'kommandantskap': ('kommandantskap',),
'kommandantskapa': ('kommandantskap',),
'kommandantskapene': ('kommandantskap',),
'kommandantskapet': ('kommandantskap',),
'kommandittist': ('kommandittist',),
'kommandittisten': ('kommandittist',),
'kommandittistene': ('kommandittist',),
'kommandittister': ('kommandittist',),
'kommandittselskap': ('kommandittselskap',),
'kommandittselskapa': ('kommandittselskap',),
'kommandittselskapene': ('kommandittselskap',),
'kommandittselskaper': ('kommandittselskap',),
'kommandittselskapet': ('kommandittselskap',),
'kommando': ('kommando',),
'kommandoen': ('kommando',),
'kommandoene': ('kommando',),
'kommandoer': ('kommando',),
'kommando': ('kommando',),
'kommandoen': ('kommando',),
'kommandoene': ('kommando',),
'kommandoer': ('kommando',),
'kommandobro': ('kommandobro',),
'kommandobroa': ('kommandobro',),
'kommandobroen': ('kommandobro',),
'kommandobroene': ('kommandobro',),
'kommandobroer': ('kommandobro',),
'kommandobru': ('kommandobru',),
'kommandobrua': ('kommandobru',),
'kommandobruen': ('kommandobru',),
'kommandobruene': ('kommandobru',),
'kommandobruer': ('kommandobru',),
'kommandoløp': ('kommandoløp',),
'kommandoløpa': ('kommandoløp',),
'kommandoløpene': ('kommandoløp',),
'kommandoløpet': ('kommandoløp',),
'kommandoraid': ('kommandoraid',),
'kommandoraida': ('kommandoraid',),
'kommandoraidene': ('kommandoraid',),
'kommandoraidet': ('kommandoraid',),
'kommandosak': ('kommandosak',),
'kommandosaka': ('kommandosak',),
'kommandosaken': ('kommandosak',),
'kommandosakene': ('kommandosak',),
'kommandosaker': ('kommandosak',),
'kommandosoldat': ('kommandosoldat',),
'kommandosoldaten': ('kommandosoldat',),
'kommandosoldatene': ('kommandosoldat',),
'kommandosoldater': ('kommandosoldat',),
'kommandotropp': ('kommandotropp',),
'kommandotroppen': ('kommandotropp',),
'kommandotroppene': ('kommandotropp',),
'kommandotropper': ('kommandotropp',),
'kommandør': ('kommandør',),
'kommandøren': ('kommandør',),
'kommandørene': ('kommandør',),
'kommandører': ('kommandør',),
'kommandørkaptein': ('kommandørkaptein',),
'kommandørkapteinen': ('kommandørkaptein',),
'kommandørkapteinene': ('kommandørkaptein',),
'kommandørkapteiner': ('kommandørkaptein',),
'kommaregel': ('kommaregel',),
'kommaregelen': ('kommaregel',),
'kommareglene': ('kommaregel',),
'kommaregler': ('kommaregel',),
'komma': ('komme',),
'komme': ('komme',),
'kommene': ('komme',),
'kommer': ('komme',),
'kommet': ('komme',),
'kommentar': ('kommentar',),
'kommentaren': ('kommentar',),
'kommentarene': ('kommentar',),
'kommentarer': ('kommentar',),
'kommentator': ('kommentator',),
'kommentatoren': ('kommentator',),
'kommentatorene': ('kommentator',),
'kommentatorer': ('kommentator',),
'kommers': ('kommers',),
'kommersen': ('kommers',),
'kommersene': ('kommers',),
'kommerser': ('kommers',),
'kommerselest': ('kommerselest',),
'kommerselesten': ('kommerselest',),
'kommerselestene': ('kommerselest',),
'kommerselester': ('kommerselest',),
'kommersialisme': ('kommersialisme',),
'kommersialismen': ('kommersialisme',),
'kommersialismene': ('kommersialisme',),
'kommersialismer': ('kommersialisme',),
'komming': ('komming',),
'komminga': ('komming',),
'kommingen': ('komming',),
'kommingene': ('komming',),
'komminger': ('komming',),
'kommisjon': ('kommisjon',),
'kommisjonen': ('kommisjon',),
'kommisjonene': ('kommisjon',),
'kommisjoner': ('kommisjon',),
'kommisjonshandel': ('kommisjonshandel',),
'kommisjonshandelen': ('kommisjonshandel',),
'kommisjonshandlene': ('kommisjonshandel',),
'kommisjonshandler': ('kommisjonshandel',),
'kommisjonær': ('kommisjonær',),
'kommisjonæren': ('kommisjonær',),
'kommisjonærene': ('kommisjonær',),
'kommisjonærer': ('kommisjonær',),
'kommissariat': ('kommissariat',),
'kommissariata': ('kommissariat',),
'kommissariatene': ('kommissariat',),
'kommissariater': ('kommissariat',),
'kommissariatet': ('kommissariat',),
'kommissær': ('kommissær',),
'kommissæren': ('kommissær',),
'kommissærene': ('kommissær',),
'kommissærer': ('kommissær',),
'kommittent': ('kommittent',),
'kommittenten': ('kommittent',),
'kommittentene': ('kommittent',),
'kommittenter': ('kommittent',),
'kommode': ('kommode',),
'kommoden': ('kommode',),
'kommodene': ('kommode',),
'kommoder': ('kommode',),
'kommodebein': ('kommodebein',),
'kommodebeina': ('kommodebein',),
'kommodebeinene': ('kommodebein',),
'kommodebeinet': ('kommodebein',),
'kommodeben': ('kommodeben',),
'kommodebena': ('kommodeben',),
'kommodebenene': ('kommodeben',),
'kommodebenet': ('kommodeben',),
'kommunaldepartement': ('kommunaldepartement',),
'kommunaldepartementa': ('kommunaldepartement',),
'kommunaldepartementene': ('kommunaldepartement',),
'kommunaldepartementer': ('kommunaldepartement',),
'kommunaldepartementet': ('kommunaldepartement',),
'kommunalminister': ('kommunalminister',),
'kommunalministere': ('kommunalminister',),
'kommunalministeren': ('kommunalminister',),
'kommunalministerer': ('kommunalminister',),
'kommunalministerne': ('kommunalminister',),
'kommunalministre': ('kommunalminister',),
'kommunalministrene': ('kommunalminister',),
'kommunalministrer': ('kommunalminister',),
'kommunalpolitikk': ('kommunalpolitikk',),
'kommunalpolitikken': ('kommunalpolitikk',),
'kommunalpolitikkene': ('kommunalpolitikk',),
'kommunalpolitikker': ('kommunalpolitikk',),
'kommunalråd': ('kommunalråd',),
'kommunalråden': ('kommunalråd',),
'kommunalrådene': ('kommunalråd',),
'kommunalråder': ('kommunalråd',),
'kommunard': ('kommunard',),
'kommunarden': ('kommunard',),
'kommunardene': ('kommunard',),
'kommunarder': ('kommunard',),
'kommune': ('kommune',),
'kommunen': ('kommune',),
'kommunene': ('kommune',),
'kommuner': ('kommune',),
'kommunehus': ('kommunehus',),
'kommunehusa': ('kommunehus',),
'kommunehusene': ('kommunehus',),
'kommunehuset': ('kommunehus',),
'kommunepolitikk': ('kommunepolitikk',),
'kommunepolitikken': ('kommunepolitikk',),
'kommunepolitikkene': ('kommunepolitikk',),
'kommunepolitikker': ('kommunepolitikk',),
'kommuneskatt': ('kommuneskatt',),
'kommuneskatten': ('kommuneskatt',),
'kommuneskattene': ('kommuneskatt',),
'kommuneskatter': ('kommuneskatt',),
'kommunestyra': ('kommunestyre',),
'kommunestyre': ('kommunestyre',),
'kommunestyrene': ('kommunestyre',),
'kommunestyrer': ('kommunestyre',),
'kommunestyret': ('kommunestyre',),
'kommunevalg': ('kommunevalg',),
'kommunevalga': ('kommunevalg',),
'kommunevalgene': ('kommunevalg',),
'kommunevalget': ('kommunevalg',),
'kommunikea': ('kommuniké',),
'kommunikeene': ('kommuniké',),
'kommunikeer': ('kommuniké',),
'kommunikeet': ('kommuniké',),
'kommuniké': ('kommuniké',),
'kommunikéa': ('kommuniké',),
'kommunikéene': ('kommuniké',),
'kommunikéer': ('kommuniké',),
'kommunikéet': ('kommuniké',),
'kommunikant': ('kommunikant',),
'kommunikanten': ('kommunikant',),
'kommunikantene': ('kommunikant',),
'kommunikanter': ('kommunikant',),
'kommunikasjon': ('kommunikasjon',),
'kommunikasjonen': ('kommunikasjon',),
'kommunikasjonene': ('kommunikasjon',),
'kommunikasjoner': ('kommunikasjon',),
'kommunikasjonslinja': ('kommunikasjonslinje',),
'kommunikasjonslinje': ('kommunikasjonslinje',),
'kommunikasjonslinjen': ('kommunikasjonslinje',),
'kommunikasjonslinjene': ('kommunikasjonslinje',),
'kommunikasjonslinjer': ('kommunikasjonslinje',),
'kommunikasjonsmiddel': ('kommunikasjonsmiddel',),
'kommunikasjonsmiddelet': ('kommunikasjonsmiddel',),
'kommunikasjonsmidla': ('kommunikasjonsmiddel',),
'kommunikasjonsmidlene': ('kommunikasjonsmiddel',),
'kommunikasjonsmidler': ('kommunikasjonsmiddel',),
'kommunikasjonsmidlet': ('kommunikasjonsmiddel',),
'kommunikasjonssatellitt': ('kommunikasjonssatellitt',),
'kommunikasjonssatellitten': ('kommunikasjonssatellitt',),
'kommunikasjonssatellittene': ('kommunikasjonssatellitt',),
'kommunikasjonssatellitter': ('kommunikasjonssatellitt',),
'kommunion': ('kommunion',),
'kommunionen': ('kommunion',),
'kommunionene': ('kommunion',),
'kommunioner': ('kommunion',),
'kommunisme': ('kommunisme',),
'kommunismen': ('kommunisme',),
'kommunismene': ('kommunisme',),
'kommunismer': ('kommunisme',),
'kommunist': ('kommunist',),
'kommunisten': ('kommunist',),
'kommunistene': ('kommunist',),
'kommunister': ('kommunist',),
'kommutasjon': ('kommutasjon',),
'kommutasjonen': ('kommutasjon',),
'kommutasjonene': ('kommutasjon',),
'kommutasjoner': ('kommutasjon',),
'kommutator': ('kommutator',),
'kommutatoren': ('kommutator',),
'kommutatorene': ('kommutator',),
'kommutatorer': ('kommutator',),
'komorer': ('komorer',),
'komorere': ('komorer',),
'komoreren': ('komorer',),
'komorerer': ('komorer',),
'komorerne': ('komorer',),
'komp': ('komp',),
'kompa': ('komp',),
'kompen': ('komp',),
'kompene': ('komp',),
'komper': ('komp',),
'kompet': ('komp',),
'kompaktor': ('kompaktor',),
'kompaktoren': ('kompaktor',),
'kompaktorene': ('kompaktor',),
'kompaktorer': ('kompaktor',),
'kompaktplata': ('kompaktplate',),
'kompaktplate': ('kompaktplate',),
'kompaktplaten': ('kompaktplate',),
'kompaktplatene': ('kompaktplate',),
'kompaktplater': ('kompaktplate',),
'kompani': ('kompani',),
'kompania': ('kompani',),
'kompaniene': ('kompani',),
'kompanier': ('kompani',),
'kompaniet': ('kompani',),
'kompanisjef': ('kompanisjef',),
'kompanisjefen': ('kompanisjef',),
'kompanisjefene': ('kompanisjef',),
'kompanisjefer': ('kompanisjef',),
'kompaniskap': ('kompaniskap',),
'kompaniskapa': ('kompaniskap',),
'kompaniskapene': ('kompaniskap',),
'kompaniskapet': ('kompaniskap',),
'kompanjong': ('kompanjong',),
'kompanjongen': ('kompanjong',),
'kompanjongene': ('kompanjong',),
'kompanjonger': ('kompanjong',),
'komparasjon': ('komparasjon',),
'komparasjonen': ('komparasjon',),
'komparasjonene': ('komparasjon',),
'komparasjoner': ('komparasjon',),
'komparativ': ('komparativ',),
'komparativen': ('komparativ',),
'komparativene': ('komparativ',),
'komparativer': ('komparativ',),
'kompas': ('kompas',),
'kompasa': ('kompas',),
'kompasen': ('kompas',),
'kompasene': ('kompas',),
'kompaser': ('kompas',),
'kompaset': ('kompas',),
'kompasbolle': ('kompasbolle',),
'kompasbollen': ('kompasbolle',),
'kompasbollene': ('kompasbolle',),
'kompasboller': ('kompasbolle',),
'kompashus': ('kompashus',),
'kompashusa': ('kompashus',),
'kompashusene': ('kompashus',),
'kompashuset': ('kompashus',),
'kompaskurs': ('kompaskurs',),
'kompaskursen': ('kompaskurs',),
'kompaskursene': ('kompaskurs',),
'kompaskurser': ('kompaskurs',),
'kompasnål': ('kompasnål',),
'kompasnåla': ('kompasnål',),
'kompasnålen': ('kompasnål',),
'kompasnålene': ('kompasnål',),
'kompasnåler': ('kompasnål',),
'kompasretning': ('kompasretning',),
'kompasretninga': ('kompasretning',),
'kompasretningen': ('kompasretning',),
'kompasretningene': ('kompasretning',),
'kompasretninger': ('kompasretning',),
'kompasrosa': ('kompasrose',),
'kompasrose': ('kompasrose',),
'kompasrosen': ('kompasrose',),
'kompasrosene': ('kompasrose',),
'kompasroser': ('kompasrose',),
'kompass': ('kompass',),
'kompassa': ('kompass',),
'kompassen': ('kompass',),
'kompassene': ('kompass',),
'kompasser': ('kompass',),
'kompasset': ('kompass',),
'kompassbolle': ('kompassbolle',),
'kompassbollen': ('kompassbolle',),
'kompassbollene': ('kompassbolle',),
'kompassboller': ('kompassbolle',),
'kompasshus': ('kompasshus',),
'kompasshusa': ('kompasshus',),
'kompasshusene': ('kompasshus',),
'kompasshuset': ('kompasshus',),
'kompasskurs': ('kompasskurs',),
'kompasskursen': ('kompasskurs',),
'kompasskursene': ('kompasskurs',),
'kompasskurser': ('kompasskurs',),
'kompassnål': ('kompassnål',),
'kompassnåla': ('kompassnål',),
'kompassnålen': ('kompassnål',),
'kompassnålene': ('kompassnål',),
'kompassnåler': ('kompassnål',),
'kompassretning': ('kompassretning',),
'kompassretninga': ('kompassretning',),
'kompassretningen': ('kompassretning',),
'kompassretningene': ('kompassretning',),
'kompassretninger': ('kompassretning',),
'kompassrosa': ('kompassrose',),
'kompassrose': ('kompassrose',),
'kompassrosen': ('kompassrose',),
'kompassrosene': ('kompassrose',),
'kompassroser': ('kompassrose',),
'kompatibilitet': ('kompatibilitet',),
'kompatibiliteten': ('kompatibilitet',),
'kompatibilitetene': ('kompatibilitet',),
'kompatibiliteter': ('kompatibilitet',),
'kompendia': ('kompendium',),
'kompendiene': ('kompendium',),
'kompendier': ('kompendium',),
'kompendiet': ('kompendium',),
'kompendium': ('kompendium',),
'kompensasjon': ('kompensasjon',),
'kompensasjonen': ('kompensasjon',),
'kompensasjonene': ('kompensasjon',),
'kompensasjoner': ('kompensasjon',),
'kompensator': ('kompensator',),
'kompensatoren': ('kompensator',),
'kompensatorene': ('kompensator',),
'kompensatorer': ('kompensator',),
'kompetanse': ('kompetanse',),
'kompetansen': ('kompetanse',),
'kompetansene': ('kompetanse',),
'kompetanser': ('kompetanse',),
'kompetanseerklæring': ('kompetanseerklæring',),
'kompetanseerklæringa': ('kompetanseerklæring',),
'kompetanseerklæringen': ('kompetanseerklæring',),
'kompetanseerklæringene': ('kompetanseerklæring',),
'kompetanseerklæringer': ('kompetanseerklæring',),
'kompilasjon': ('kompilasjon',),
'kompilasjonen': ('kompilasjon',),
'kompilasjonene': ('kompilasjon',),
'kompilasjoner': ('kompilasjon',),
'kompilator': ('kompilator',),
'kompilatoren': ('kompilator',),
'kompilatorene': ('kompilator',),
'kompilatorer': ('kompilator',),
'kompis': ('kompis',),
'kompisen': ('kompis',),
'kompisene': ('kompis',),
'kompiser': ('kompis',),
'kompiskjøring': ('kompiskjøring',),
'kompiskjøringa': ('kompiskjøring',),
'kompiskjøringen': ('kompiskjøring',),
'kompiskjøringene': ('kompiskjøring',),
'kompiskjøringer': ('kompiskjøring',),
'kompleks': ('kompleks',),
'kompleksa': ('kompleks',),
'kompleksene': ('kompleks',),
'komplekser': ('kompleks',),
'komplekset': ('kompleks',),
'kompleksitet': ('kompleksitet',),
'kompleksiteten': ('kompleksitet',),
'kompleksitetene': ('kompleksitet',),
'kompleksiteter': ('kompleksitet',),
'komplement': ('komplement',),
'komplementa': ('komplement',),
'komplementene': ('komplement',),
'komplementer': ('komplement',),
'komplementet': ('komplement',),
'komplementar': ('komplementar',),
'komplementaren': ('komplementar',),
'komplementarene': ('komplementar',),
'komplementarer': ('komplementar',),
'komplementaritet': ('komplementaritet',),
'komplementariteten': ('komplementaritet',),
'komplementaritetene': ('komplementaritet',),
'komplementariteter': ('komplementaritet',),
'komplementbue': ('komplementbue',),
'komplementbuen': ('komplementbue',),
'komplementbuene': ('komplementbue',),
'komplementbuer': ('komplementbue',),
'komplementvinkel': ('komplementvinkel',),
'komplementvinkelen': ('komplementvinkel',),
'komplementvinklene': ('komplementvinkel',),
'komplementvinkler': ('komplementvinkel',),
'komplementærfarge': ('komplementærfarge',),
'komplementærfargen': ('komplementærfarge',),
'komplementærfargene': ('komplementærfarge',),
'komplementærfarger': ('komplementærfarge',),
'komplikasjon': ('komplikasjon',),
'komplikasjonen': ('komplikasjon',),
'komplikasjonene': ('komplikasjon',),
'komplikasjoner': ('komplikasjon',),
'kompliment': ('kompliment',),
'komplimenten': ('kompliment',),
'komplimentene': ('kompliment',),
'komplimenter': ('kompliment',),
'komplott': ('komplott',),
'komplotta': ('komplott',),
'komplottene': ('komplott',),
'komplotter': ('komplott',),
'komplottet': ('komplott',),
'komponent': ('komponent',),
'komponenten': ('komponent',),
'komponentene': ('komponent',),
'komponenter': ('komponent',),
'komponist': ('komponist',),
'komponisten': ('komponist',),
'komponistene': ('komponist',),
'komponister': ('komponist',),
'komposisjon': ('komposisjon',),
'komposisjonen': ('komposisjon',),
'komposisjonene': ('komposisjon',),
'komposisjoner': ('komposisjon',),
'komposittfartøy': ('komposittfartøy',),
'komposittfartøya': ('komposittfartøy',),
'komposittfartøyene': ('komposittfartøy',),
'komposittfartøyer': ('komposittfartøy',),
'komposittfartøyet': ('komposittfartøy',),
'komposittmateriala': ('komposittmateriale',),
'komposittmateriale': ('komposittmateriale',),
'komposittmaterialene': ('komposittmateriale',),
'komposittmaterialer': ('komposittmateriale',),
'komposittmaterialet': ('komposittmateriale',),
'komposita': ('kompositum',),
'kompositaene': ('kompositum',),
'kompositum': ('kompositum',),
'kompositumet': ('kompositum',),
'kompost': ('kompost',),
'komposten': ('kompost',),
'kompostene': ('kompost',),
'komposter': ('kompost',),
'komposthaug': ('komposthaug',),
'komposthaugen': ('komposthaug',),
'komposthaugene': ('komposthaug',),
'komposthauger': ('komposthaug',),
'kompostjord': ('kompostjord',),
'kompostjorda': ('kompostjord',),
'kompostjorden': ('kompostjord',),
'kompostjordene': ('kompostjord',),
'kompostjorder': ('kompostjord',),
'kompott': ('kompott',),
'kompotten': ('kompott',),
'kompottene': ('kompott',),
'kompotter': ('kompott',),
'kompresjon': ('kompresjon',),
'kompresjonen': ('kompresjon',),
'kompresjonene': ('kompresjon',),
'kompresjoner': ('kompresjon',),
'kompresjonsforhold': ('kompresjonsforhold',),
'kompresjonsforholda': ('kompresjonsforhold',),
'kompresjonsforholdene': ('kompresjonsforhold',),
'kompresjonsforholdet': ('kompresjonsforhold',),
'kompress': ('kompress',),
'kompressen': ('kompress',),
'kompressene': ('kompress',),
'kompresser': ('kompress',),
'kompressibilitet': ('kompressibilitet',),
'kompressibiliteten': ('kompressibilitet',),
'kompressibilitetene': ('kompressibilitet',),
'kompressibiliteter': ('kompressibilitet',),
'kompressor': ('kompressor',),
'kompressoren': ('kompressor',),
'kompressorene': ('kompressor',),
'kompressorer': ('kompressor',),
'kompromiss': ('kompromiss',),
'kompromissa': ('kompromiss',),
'kompromissene': ('kompromiss',),
'kompromisser': ('kompromiss',),
'kompromisset': ('kompromiss',),
'komsa': ('komse',),
'komse': ('komse',),
'komsen': ('komse',),
'komsene': ('komse',),
'komser': ('komse',),
'komtessa': ('komtesse',),
'komtesse': ('komtesse',),
'komtessen': ('komtesse',),
'komtessene': ('komtesse',),
'komtesser': ('komtesse',),
'kon': ('kon',),
'konen': ('kon',),
'konene': ('kon',),
'koner': ('kon',),
'kondemnasjon': ('kondemnasjon',),
'kondemnasjonen': ('kondemnasjon',),
'kondemnasjonene': ('kondemnasjon',),
'kondemnasjoner': ('kondemnasjon',),
'kondens': ('kondens',),
'kondensen': ('kondens',),
'kondensene': ('kondens',),
'kondenser': ('kondens',),
'kondensasjon': ('kondensasjon',),
'kondensasjonen': ('kondensasjon',),
'kondensasjonene': ('kondensasjon',),
'kondensasjoner': ('kondensasjon',),
'kondensasjonskjerne': ('kondensasjonskjerne',),
'kondensasjonskjernen': ('kondensasjonskjerne',),
'kondensasjonskjernene': ('kondensasjonskjerne',),
'kondensasjonskjerner': ('kondensasjonskjerne',),
'kondensasjonsvarme': ('kondensasjonsvarme',),
'kondensasjonsvarmen': ('kondensasjonsvarme',),
'kondensasjonsvarmene': ('kondensasjonsvarme',),
'kondensasjonsvarmer': ('kondensasjonsvarme',),
'kondensat': ('kondensat',),
'kondensata': ('kondensat',),
'kondensatene': ('kondensat',),
'kondensater': ('kondensat',),
'kondensatet': ('kondensat',),
'kondensator': ('kondensator',),
'kondensatoren': ('kondensator',),
'kondensatorene': ('kondensator',),
'kondensatorer': ('kondensator',),
'kondenser': ('kondenser',),
'kondensere': ('kondenser',),
'kondenseren': ('kondenser',),
'kondenserer': ('kondenser',),
'kondenserne': ('kondenser',),
'kondensfjerner': ('kondensfjerner',),
'kondensfjernere': ('kondensfjerner',),
'kondensfjerneren': ('kondensfjerner',),
'kondensfjernerer': ('kondensfjerner',),
'kondensfjernerne': ('kondensfjerner',),
'kondensstripa': ('kondensstripe',),
'kondensstripe': ('kondensstripe',),
'kondensstripen': ('kondensstripe',),
'kondensstripene': ('kondensstripe',),
'kondensstriper': ('kondensstripe',),
'kondensvann': ('kondensvann',),
'kondensvanna': ('kondensvann',),
'kondensvannene': ('kondensvann',),
'kondensvannet': ('kondensvann',),
'kondensvatn': ('kondensvatn',),
'kondensvatna': ('kondensvatn',),
'kondensvatnene': ('kondensvatn',),
'kondensvatnet': ('kondensvatn',),
'kondis': ('kondis',),
'kondisen': ('kondis',),
'kondisene': ('kondis',),
'kondiser': ('kondis',),
'kondisjon': ('kondisjon',),
'kondisjonen': ('kondisjon',),
'kondisjonene': ('kondisjon',),
'kondisjoner': ('kondisjon',),
'kondisjonalis': ('kondisjonalis',),
'kondisjonalisen': ('kondisjonalis',),
'kondisjonalisene': ('kondisjonalis',),
'kondisjonaliser': ('kondisjonalis',),
'kondisjonstrening': ('kondisjonstrening',),
'kondisjonstreninga': ('kondisjonstrening',),
'kondisjonstreningen': ('kondisjonstrening',),
'kondisjonstreningene': ('kondisjonstrening',),
'kondisjonstreninger': ('kondisjonstrening',),
'konditor': ('konditor',),
'konditoren': ('konditor',),
'konditorene': ('konditor',),
'konditorer': ('konditor',),
'konditorfarge': ('konditorfarge',),
'konditorfargen': ('konditorfarge',),
'konditorfargene': ('konditorfarge',),
'konditorfarger': ('konditorfarge',),
'konditori': ('konditori',),
'konditoria': ('konditori',),
'konditoriene': ('konditori',),
'konditorier': ('konditori',),
'konditoriet': ('konditori',),
'kondolanse': ('kondolanse',),
'kondolansen': ('kondolanse',),
'kondolansene': ('kondolanse',),
'kondolanser': ('kondolanse',),
'kondolansebrev': ('kondolansebrev',),
'kondolansebreva': ('kondolansebrev',),
'kondolansebrevene': ('kondolansebrev',),
'kondolansebrever': ('kondolansebrev',),
'kondolansebrevet': ('kondolansebrev',),
'kondolansetelegram': ('kondolansetelegram',),
'kondolansetelegramma': ('kondolansetelegram',),
'kondolansetelegrammene': ('kondolansetelegram',),
'kondolansetelegrammer': ('kondolansetelegram',),
'kondolansetelegrammet': ('kondolansetelegram',),
'kondom': ('kondom',),
'kondoma': ('kondom',),
'kondomene': ('kondom',),
'kondomer': ('kondom',),
'kondomet': ('kondom',),
'kondominat': ('kondominat',),
'kondominata': ('kondominat',),
'kondominatene': ('kondominat',),
'kondominater': ('kondominat',),
'kondominatet': ('kondominat',),
'kondor': ('kondor',),
'kondoren': ('kondor',),
'kondorene': ('kondor',),
'kondorer': ('kondor',),
'konduite': ('konduite',),
'konduiten': ('konduite',),
'konduitene': ('konduite',),
'konduiter': ('konduite',),
'konduktans': ('konduktans',),
'konduktansen': ('konduktans',),
'konduktansene': ('konduktans',),
'konduktanser': ('konduktans',),
'konduktivitet': ('konduktivitet',),
'konduktiviteten': ('konduktivitet',),
'konduktivitetene': ('konduktivitet',),
'konduktiviteter': ('konduktivitet',),
'konduktor': ('konduktor',),
'konduktoren': ('konduktor',),
'konduktorene': ('konduktor',),
'konduktorer': ('konduktor',),
'konduktør': ('konduktør',),
'konduktøren': ('konduktør',),
'konduktørene': ('konduktør',),
'konduktører': ('konduktør',),
'kona': ('kone',),
'kone': ('kone',),
'konen': ('kone',),
'konene': ('kone',),
'koner': ('kone',),
'konebil': ('konebil',),
'konebilen': ('konebil',),
'konebilene': ('konebil',),
'konebiler': ('konebil',),
'konebåt': ('konebåt',),
'konebåten': ('konebåt',),
'konebåtene': ('konebåt',),
'konebåter': ('konebåt',),
'koneplager': ('koneplager',),
'koneplagere': ('koneplager',),
'koneplageren': ('koneplager',),
'koneplagerer': ('koneplager',),
'koneplagerne': ('koneplager',),
'konfeksjon': ('konfeksjon',),
'konfeksjonen': ('konfeksjon',),
'konfeksjonene': ('konfeksjon',),
'konfeksjoner': ('konfeksjon',),
'konfeksjonsindustri': ('konfeksjonsindustri',),
'konfeksjonsindustrien': ('konfeksjonsindustri',),
'konfeksjonsindustriene': ('konfeksjonsindustri',),
'konfeksjonsindustrier': ('konfeksjonsindustri',),
'konfeksjonssøm': ('konfeksjonssøm',),
'konfeksjonssømmen': ('konfeksjonssøm',),
'konfeksjonssømmene': ('konfeksjonssøm',),
'konfeksjonssømmer': ('konfeksjonssøm',),
'konfekt': ('konfekt',),
'konfekten': ('konfekt',),
'konfektene': ('konfekt',),
'konfekter': ('konfekt',),
'konfekteska': ('konfekteske',),
'konfekteske': ('konfekteske',),
'konfektesken': ('konfekteske',),
'konfekteskene': ('konfekteske',),
'konfektesker': ('konfekteske',),
'konferanse': ('konferanse',),
'konferansen': ('konferanse',),
'konferansene': ('konferanse',),
'konferanser': ('konferanse',),
'konferansetime': ('konferansetime',),
'konferansetimen': ('konferansetime',),
'konferansetimene': ('konferansetime',),
'konferansetimer': ('konferansetime',),
'konferansier': ('konferansier',),
'konferansieren': ('konferansier',),
'konferansierene': ('konferansier',),
'konferansierer': ('konferansier',),
'konfesjon': ('konfesjon',),
'konfesjonen': ('konfesjon',),
'konfesjonene': ('konfesjon',),
'konfesjoner': ('konfesjon',),
'konfesjonalisme': ('konfesjonalisme',),
'konfesjonalismen': ('konfesjonalisme',),
'konfesjonalismene': ('konfesjonalisme',),
'konfesjonalismer': ('konfesjonalisme',),
'konfetti': ('konfetti',),
'konfettien': ('konfetti',),
'konfettiene': ('konfetti',),
'konfettier': ('konfetti',),
'konfigurasjon': ('konfigurasjon',),
'konfigurasjonen': ('konfigurasjon',),
'konfigurasjonene': ('konfigurasjon',),
'konfigurasjoner': ('konfigurasjon',),
'konfirmant': ('konfirmant',),
'konfirmanten': ('konfirmant',),
'konfirmantene': ('konfirmant',),
'konfirmanter': ('konfirmant',),
'konfirmasjon': ('konfirmasjon',),
'konfirmasjonen': ('konfirmasjon',),
'konfirmasjonene': ('konfirmasjon',),
'konfirmasjoner': ('konfirmasjon',),
'konfiskasjon': ('konfiskasjon',),
'konfiskasjonen': ('konfiskasjon',),
'konfiskasjonene': ('konfiskasjon',),
'konfiskasjoner': ('konfiskasjon',),
'konfityr': ('konfityr',),
'konfityren': ('konfityr',),
'konfityrene': ('konfityr',),
'konfityrer': ('konfityr',),
'konflikt': ('konflikt',),
'konflikten': ('konflikt',),
'konfliktene': ('konflikt',),
'konflikter': ('konflikt',),
'konfliktforskning': ('konfliktforskning',),
'konfliktforskninga': ('konfliktforskning',),
'konfliktforskningen': ('konfliktforskning',),
'konfliktforskningene': ('konfliktforskning',),
'konfliktforskninger': ('konfliktforskning',),
'konformisme': ('konformisme',),
'konformismen': ('konformisme',),
'konformismene': ('konformisme',),
'konformismer': ('konformisme',),
'konformist': ('konformist',),
'konformisten': ('konformist',),
'konformistene': ('konformist',),
'konformister': ('konformist',),
'konformitet': ('konformitet',),
'konformiteten': ('konformitet',),
'konformitetene': ('konformitet',),
'konformiteter': ('konformitet',),
'konformitetspress': ('konformitetspress',),
'konformitetspressa': ('konformitetspress',),
'konformitetspressene': ('konformitetspress',),
'konformitetspresset': ('konformitetspress',),
'konfrontasjon': ('konfrontasjon',),
'konfrontasjonen': ('konfrontasjon',),
'konfrontasjonene': ('konfrontasjon',),
'konfrontasjoner': ('konfrontasjon',),
'konfusianisme': ('konfusianisme',),
'konfusianismen': ('konfusianisme',),
'konfusianismene': ('konfusianisme',),
'konfusianismer': ('konfusianisme',),
'konfusjon': ('konfusjon',),
'konfusjonen': ('konfusjon',),
'konfusjonene': ('konfusjon',),
'konfusjoner': ('konfusjon',),
'konføderasjon': ('konføderasjon',),
'konføderasjonen': ('konføderasjon',),
'konføderasjonene': ('konføderasjon',),
'konføderasjoner': ('konføderasjon',),
'kong': ('kong',),
'kongen': ('kong',),
'kongene': ('kong',),
'konger': ('kong',),
'konge': ('konge',),
'kongen': ('konge',),
'kongene': ('konge',),
'konger': ('konge',),
'kongeblått': ('kongeblått',),
'kongeboa': ('kongeboa',),
'kongeboaen': ('kongeboa',),
'kongeboaene': ('kongeboa',),
'kongeboaer': ('kongeboa',),
'kongebrev': ('kongebrev',),
'kongebreva': ('kongebrev',),
'kongebrevene': ('kongebrev',),
'kongebrever': ('kongebrev',),
'kongebrevet': ('kongebrev',),
'kongedømma': ('kongedømme',),
'kongedømme': ('kongedømme',),
'kongedømmene': ('kongedømme',),
'kongedømmer': ('kongedømme',),
'kongedømmet': ('kongedømme',),
'kongegambit': ('kongegambit',),
'kongegambiten': ('kongegambit',),
'kongegambitene': ('kongegambit',),
'kongegambiter': ('kongegambit',),
'kongehus': ('kongehus',),
'kongehusa': ('kongehus',),
'kongehusene': ('kongehus',),
'kongehuset': ('kongehus',),
'kongekrona': ('kongekrone',),
'kongekrone': ('kongekrone',),
'kongekronen': ('kongekrone',),
'kongekronene': ('kongekrone',),
'kongekroner': ('kongekrone',),
'kongekroning': ('kongekroning',),
'kongekroninga': ('kongekroning',),
'kongekroningen': ('kongekroning',),
'kongekroningene': ('kongekroning',),
'kongekroninger': ('kongekroning',),
'kongemakt': ('kongemakt',),
'kongemakta': ('kongemakt',),
'kongemakten': ('kongemakt',),
'kongemaktene': ('kongemakt',),
'kongemakter': ('kongemakt',),
'kongenavn': ('kongenavn',),
'kongenavna': ('kongenavn',),
'kongenavnene': ('kongenavn',),
'kongenavnet': ('kongenavn',),
'kongenialitet': ('kongenialitet',),
'kongenialiteten': ('kongenialitet',),
'kongenialitetene': ('kongenialitet',),
'kongenialiteter': ('kongenialitet',),
'kongepokal': ('kongepokal',),
'kongepokalen': ('kongepokal',),
'kongepokalene': ('kongepokal',),
'kongepokaler': ('kongepokal',),
'kongerika': ('kongerike',),
'kongerike': ('kongerike',),
'kongerikene': ('kongerike',),
'kongeriker': ('kongerike',),
'kongeriket': ('kongerike',),
'kongesaga': ('kongesaga',),
'kongesagaen': ('kongesaga',),
'kongesagaene': ('kongesaga',),
'kongesagaer': ('kongesaga',),
'kongesalutt': ('kongesalutt',),
'kongesalutten': ('kongesalutt',),
'kongesaluttene': ('kongesalutt',),
'kongesalutter': ('kongesalutt',),
'kongesang': ('kongesang',),
'kongesangen': ('kongesang',),
'kongesangene': ('kongesang',),
'kongesanger': ('kongesang',),
'kongeslange': ('kongeslange',),
'kongeslangen': ('kongeslange',),
'kongeslangene': ('kongeslange',),
'kongeslanger': ('kongeslange',),
'kongestion': ('kongestion',),
'kongestionen': ('kongestion',),
'kongestionene': ('kongestion',),
'kongestioner': ('kongestion',),
'kongetrona': ('kongetrone',),
'kongetrone': ('kongetrone',),
'kongetronen': ('kongetrone',),
'kongetronene': ('kongetrone',),
'kongetroner': ('kongetrone',),
'kongeveg': ('kongeveg',),
'kongevegen': ('kongeveg',),
'kongevegene': ('kongeveg',),
'kongeveger': ('kongeveg',),
'kongevei': ('kongevei',),
'kongeveien': ('kongevei',),
'kongeveiene': ('kongevei',),
'kongeveier': ('kongevei',),
'kongeørn': ('kongeørn',),
'kongeørna': ('kongeørn',),
'kongeørnen': ('kongeørn',),
'kongeørnene': ('kongeørn',),
'kongeørner': ('kongeørn',),
'kongla': ('kongle',),
'kongle': ('kongle',),
'konglen': ('kongle',),
'konglene': ('kongle',),
'kongler': ('kongle',),
'konglebit': ('konglebit',),
'konglebiten': ('konglebit',),
'konglebitene': ('konglebit',),
'konglebiter': ('konglebit',),
'kongleskjell': ('kongleskjell',),
'kongleskjella': ('kongleskjell',),
'kongleskjellen': ('kongleskjell',),
'kongleskjellene': ('kongleskjell',),
'kongleskjellet': ('kongleskjell',),
'konglomerat': ('konglomerat',),
'konglomerata': ('konglomerat',),
'konglomeratene': ('konglomerat',),
'konglomerater': ('konglomerat',),
'konglomeratet': ('konglomerat',),
'kongoleser': ('kongoleser',),
'kongolesere': ('kongoleser',),
'kongoleseren': ('kongoleser',),
'kongoleserer': ('kongoleser',),
'kongoleserne': ('kongoleser',),
'kongregasjon': ('kongregasjon',),
'kongregasjonen': ('kongregasjon',),
'kongregasjonene': ('kongregasjon',),
'kongregasjoner': ('kongregasjon',),
'kongress': ('kongress',),
'kongressen': ('kongress',),
'kongressene': ('kongress',),
'kongresser': ('kongress',),
'kongro': ('kongro',),
'kongroa': ('kongro',),
'kongroen': ('kongro',),
'kongroene': ('kongro',),
'kongroer': ('kongro',),
'kongrovev': ('kongrovev',),
'kongroveva': ('kongrovev',),
'kongroveven': ('kongrovev',),
'kongrovevene': ('kongrovev',),
'kongrovever': ('kongrovev',),
'kongrovevet': ('kongrovev',),
'kongruens': ('kongruens',),
'kongruensen': ('kongruens',),
'kongruensene': ('kongruens',),
'kongruenser': ('kongruens',),
'kongruensbøying': ('kongruensbøying',),
'kongruensbøyinga': ('kongruensbøying',),
'kongruensbøyingen': ('kongruensbøying',),
'kongruensbøyingene': ('kongruensbøying',),
'kongruensbøyinger': ('kongruensbøying',),
'kongruensbøyning': ('kongruensbøyning',),
'kongruensbøyninga': ('kongruensbøyning',),
'kongruensbøyningen': ('kongruensbøyning',),
'kongruensbøyningene': ('kongruensbøyning',),
'kongruensbøyninger': ('kongruensbøyning',),
'kongsemna': ('kongsemne',),
'kongsemne': ('kongsemne',),
'kongsemnene': ('kongsemne',),
'kongsemner': ('kongsemne',),
'kongsemnet': ('kongsemne',),
'kongsgard': ('kongsgard',),
'kongsgarden': ('kongsgard',),
'kongsgardene': ('kongsgard',),
'kongsgarder': ('kongsgard',),
'kongsgård': ('kongsgård',),
'kongsgården': ('kongsgård',),
'kongsgårdene': ('kongsgård',),
'kongsgårder': ('kongsgård',),
'kongslys': ('kongslys',),
'kongslysa': ('kongslys',),
'kongslysen': ('kongslys',),
'kongslysene': ('kongslys',),
'kongslyser': ('kongslys',),
'kongslyset': ('kongslys',),
'kongsmann': ('kongsmann',),
'kongsmannen': ('kongsmann',),
'kongsmenn': ('kongsmann',),
'kongsmennene': ('kongsmann',),
'kongsnavn': ('kongsnavn',),
'kongsnavna': ('kongsnavn',),
'kongsnavnene': ('kongsnavn',),
'kongsnavnet': ('kongsnavn',),
'kongstanke': ('kongstanke',),
'kongstanken': ('kongstanke',),
'kongstankene': ('kongstanke',),
'kongstanker': ('kongstanke',),
'konjakk': ('konjakk',),
'konjakken': ('konjakk',),
'konjakkene': ('konjakk',),
'konjakker': ('konjakk',),
'konjakker': ('konjakker',),
'konjakkere': ('konjakker',),
'konjakkeren': ('konjakker',),
'konjakkerer': ('konjakker',),
'konjakkerne': ('konjakker',),
'konjektur': ('konjektur',),
'konjekturen': ('konjektur',),
'konjekturene': ('konjektur',),
'konjekturer': ('konjektur',),
'konjugasjon': ('konjugasjon',),
'konjugasjonen': ('konjugasjon',),
'konjugasjonene': ('konjugasjon',),
'konjugasjoner': ('konjugasjon',),
'konjunksjon': ('konjunksjon',),
'konjunksjonen': ('konjunksjon',),
'konjunksjonene': ('konjunksjon',),
'konjunksjoner': ('konjunksjon',),
'konjunktiv': ('konjunktiv',),
'konjunktiven': ('konjunktiv',),
'konjunktivene': ('konjunktiv',),
'konjunktiver': ('konjunktiv',),
'konjunktur': ('konjunktur',),
'konjunkturen': ('konjunktur',),
'konjunkturene': ('konjunktur',),
'konjunkturer': ('konjunktur',),
'konjunkturbølga': ('konjunkturbølge',),
'konjunkturbølge': ('konjunkturbølge',),
'konjunkturbølgen': ('konjunkturbølge',),
'konjunkturbølgene': ('konjunkturbølge',),
'konjunkturbølger': ('konjunkturbølge',),
'konjunkturbølgja': ('konjunkturbølgje',),
'konjunkturbølgje': ('konjunkturbølgje',),
'konjunkturbølgjen': ('konjunkturbølgje',),
'konjunkturbølgjene': ('konjunkturbølgje',),
'konjunkturbølgjer': ('konjunkturbølgje',),
'konkavitet': ('konkavitet',),
'konkaviteten': ('konkavitet',),
'konkavitetene': ('konkavitet',),
'konkaviteter': ('konkavitet',),
'konklava': ('konklave',),
'konklave': ('konklave',),
'konklavene': ('konklave',),
'konklaver': ('konklave',),
'konklavet': ('konklave',),
'konklusjon': ('konklusjon',),
'konklusjonen': ('konklusjon',),
'konklusjonene': ('konklusjon',),
'konklusjoner': ('konklusjon',),
'konkordans': ('konkordans',),
'konkordansen': ('konkordans',),
'konkordansene': ('konkordans',),
'konkordanser': ('konkordans',),
'konkordat': ('konkordat',),
'konkordata': ('konkordat',),
'konkordatene': ('konkordat',),
'konkordater': ('konkordat',),
'konkordatet': ('konkordat',),
'konkordiebok': ('konkordiebok',),
'konkordieboka': ('konkordiebok',),
'konkordieboken': ('konkordiebok',),
'konkordiebøkene': ('konkordiebok',),
'konkordiebøker': ('konkordiebok',),
'konkordieformel': ('konkordieformel',),
'konkordieformelen': ('konkordieformel',),
'konkordieformlene': ('konkordieformel',),
'konkordieformler': ('konkordieformel',),
'konkrement': ('konkrement',),
'konkrementa': ('konkrement',),
'konkrementene': ('konkrement',),
'konkrementer': ('konkrement',),
'konkrementet': ('konkrement',),
'konkresjon': ('konkresjon',),
'konkresjonen': ('konkresjon',),
'konkresjonene': ('konkresjon',),
'konkresjoner': ('konkresjon',),
'konkret': ('konkret',),
'konkreten': ('konkret',),
'konkretene': ('konkret',),
'konkreter': ('konkret',),
'konkret': ('konkret',),
'konkreta': ('konkret',),
'konkretene': ('konkret',),
'konkreter': ('konkret',),
'konkretet': ('konkret',),
'konkretisme': ('konkretisme',),
'konkretismen': ('konkretisme',),
'konkretismene': ('konkretisme',),
'konkretismer': ('konkretisme',),
'konkretist': ('konkretist',),
'konkretisten': ('konkretist',),
'konkretistene': ('konkretist',),
'konkretister': ('konkretist',),
'konkubinat': ('konkubinat',),
'konkubinata': ('konkubinat',),
'konkubinatene': ('konkubinat',),
'konkubinater': ('konkubinat',),
'konkubinatet': ('konkubinat',),
'konkubina': ('konkubine',),
'konkubine': ('konkubine',),
'konkubinen': ('konkubine',),
'konkubinene': ('konkubine',),
'konkubiner': ('konkubine',),
'konkurranse': ('konkurranse',),
'konkurransen': ('konkurranse',),
'konkurransene': ('konkurranse',),
'konkurranser': ('konkurranse',),
'konkurranseevna': ('konkurranseevne',),
'konkurranseevne': ('konkurranseevne',),
'konkurranseevnen': ('konkurranseevne',),
'konkurranseevnene': ('konkurranseevne',),
'konkurranseevner': ('konkurranseevne',),
'konkurranseidrett': ('konkurranseidrett',),
'konkurranseidretten': ('konkurranseidrett',),
'konkurranseidrettene': ('konkurranseidrett',),
'konkurranseidretter': ('konkurranseidrett',),
'konkurransesamfunn': ('konkurransesamfunn',),
'konkurransesamfunna': ('konkurransesamfunn',),
'konkurransesamfunnene': ('konkurransesamfunn',),
'konkurransesamfunnet': ('konkurransesamfunn',),
'konkurrent': ('konkurrent',),
'konkurrenten': ('konkurrent',),
'konkurrentene': ('konkurrent',),
'konkurrenter': ('konkurrent',),
'konkurs': ('konkurs',),
'konkursen': ('konkurs',),
'konkursene': ('konkurs',),
'konkurser': ('konkurs',),
'konkursbo': ('konkursbo',),
'konkursboa': ('konkursbo',),
'konkursboene': ('konkursbo',),
'konkursboet': ('konkursbo',),
'konkursbu': ('konkursbu',),
'konkursbua': ('konkursbu',),
'konkursbuene': ('konkursbu',),
'konkursbuet': ('konkursbu',),
'konkursrytter': ('konkursrytter',),
'konkursryttere': ('konkursrytter',),
'konkursrytteren': ('konkursrytter',),
'konkursrytterer': ('konkursrytter',),
'konkursrytterne': ('konkursrytter',),
'konkylie': ('konkylie',),
'konkylien': ('konkylie',),
'konkyliene': ('konkylie',),
'konkylier': ('konkylie',),
'konnossement': ('konnossement',),
'konnossementa': ('konnossement',),
'konnossementene': ('konnossement',),
'konnossementer': ('konnossement',),
'konnossementet': ('konnossement',),
'konnotasjon': ('konnotasjon',),
'konnotasjonen': ('konnotasjon',),
'konnotasjonene': ('konnotasjon',),
'konnotasjoner': ('konnotasjon',),
'konsekvens': ('konsekvens',),
'konsekvensen': ('konsekvens',),
'konsekvensene': ('konsekvens',),
'konsekvenser': ('konsekvens',),
'konsekvensmaker': ('konsekvensmaker',),
'konsekvensmakere': ('konsekvensmaker',),
'konsekvensmakeren': ('konsekvensmaker',),
'konsekvensmakerer': ('konsekvensmaker',),
'konsekvensmakerne': ('konsekvensmaker',),
'konsens': ('konsens',),
'konsensen': ('konsens',),
'konsensene': ('konsens',),
'konsenser': ('konsens',),
'konsensen': ('konsensus',),
'konsensene': ('konsensus',),
'konsenser': ('konsensus',),
'konsensus': ('konsensus',),
'konsensusen': ('konsensus',),
'konsensusene': ('konsensus',),
'konsensuser': ('konsensus',),
'konsensvedtak': ('konsensvedtak',),
'konsensvedtaka': ('konsensvedtak',),
'konsensvedtakene': ('konsensvedtak',),
'konsensvedtaket': ('konsensvedtak',),
'konsentrasjon': ('konsentrasjon',),
'konsentrasjonen': ('konsentrasjon',),
'konsentrasjonene': ('konsentrasjon',),
'konsentrasjoner': ('konsentrasjon',),
'konsentrasjonsevna': ('konsentrasjonsevne',),
'konsentrasjonsevne': ('konsentrasjonsevne',),
'konsentrasjonsevnen': ('konsentrasjonsevne',),
'konsentrasjonsevnene': ('konsentrasjonsevne',),
'konsentrasjonsevner': ('konsentrasjonsevne',),
'konsentrasjonsleir': ('konsentrasjonsleir',),
'konsentrasjonsleiren': ('konsentrasjonsleir',),
'konsentrasjonsleirene': ('konsentrasjonsleir',),
'konsentrasjonsleirer': ('konsentrasjonsleir',),
'konsentrat': ('konsentrat',),
'konsentrata': ('konsentrat',),
'konsentratene': ('konsentrat',),
'konsentrater': ('konsentrat',),
'konsentratet': ('konsentrat',),
'konsepsjon': ('konsepsjon',),
'konsepsjonen': ('konsepsjon',),
'konsepsjonene': ('konsepsjon',),
'konsepsjoner': ('konsepsjon',),
'konsept': ('konsept',),
'konsepta': ('konsept',),
'konseptene': ('konsept',),
'konsepter': ('konsept',),
'konseptet': ('konsept',),
'konseptpapir': ('konseptpapir',),
'konseptpapira': ('konseptpapir',),
'konseptpapirene': ('konseptpapir',),
'konseptpapirer': ('konseptpapir',),
'konseptpapiret': ('konseptpapir',),
'konsern': ('konsern',),
'konserna': ('konsern',),
'konsernene': ('konsern',),
'konserner': ('konsern',),
'konsernet': ('konsern',),
'konsert': ('konsert',),
'konserten': ('konsert',),
'konsertene': ('konsert',),
'konserter': ('konsert',),
'konserthus': ('konserthus',),
'konserthusa': ('konserthus',),
'konserthusene': ('konserthus',),
'konserthuset': ('konserthus',),
'konsertmester': ('konsertmester',),
'konsertmestere': ('konsertmester',),
'konsertmesteren': ('konsertmester',),
'konsertmesterer': ('konsertmester',),
'konsertmesterne': ('konsertmester',),
'konsertmestre': ('konsertmester',),
'konsertmestrene': ('konsertmester',),
'konsertmestrer': ('konsertmester',),
'konserv': ('konserv',),
'konserven': ('konserv',),
'konservene': ('konserv',),
'konserver': ('konserv',),
'konservatisme': ('konservatisme',),
'konservatismen': ('konservatisme',),
'konservatismene': ('konservatisme',),
'konservatismer': ('konservatisme',),
'konservator': ('konservator',),
'konservatoren': ('konservator',),
'konservatorene': ('konservator',),
'konservatorer': ('konservator',),
'konservatoria': ('konservatorium',),
'konservatoriene': ('konservatorium',),
'konservatorier': ('konservatorium',),
'konservatoriet': ('konservatorium',),
'konservatorium': ('konservatorium',),
'konserve': ('konserve',),
'konserven': ('konserve',),
'konservene': ('konserve',),
'konserver': ('konserve',),
'konserveringsmiddel': ('konserveringsmiddel',),
'konserveringsmiddelet': ('konserveringsmiddel',),
'konserveringsmidla': ('konserveringsmiddel',),
'konserveringsmidlene': ('konserveringsmiddel',),
'konserveringsmidler': ('konserveringsmiddel',),
'konserveringsmidlet': ('konserveringsmiddel',),
'konsesjon': ('konsesjon',),
'konsesjonen': ('konsesjon',),
'konsesjonene': ('konsesjon',),
'konsesjoner': ('konsesjon',),
'konsesjonslov': ('konsesjonslov',),
'konsesjonsloven': ('konsesjonslov',),
'konsesjonslovene': ('konsesjonslov',),
'konsesjonslover': ('konsesjonslov',),
'konsesjonær': ('konsesjonær',),
'konsesjonæren': ('konsesjonær',),
'konsesjonærene': ('konsesjonær',),
'konsesjonærer': ('konsesjonær',),
'konsignant': ('konsignant',),
'konsignanten': ('konsignant',),
'konsignantene': ('konsignant',),
'konsignanter': ('konsignant',),
'konsignasjon': ('konsignasjon',),
'konsignasjonen': ('konsignasjon',),
'konsignasjonene': ('konsignasjon',),
'konsignasjoner': ('konsignasjon',),
'konsignatar': ('konsignatar',),
'konsignataren': ('konsignatar',),
'konsignatarene': ('konsignatar',),
'konsignatarer': ('konsignatar',),
'konsil': ('konsil',),
'konsila': ('konsil',),
'konsilene': ('konsil',),
'konsiler': ('konsil',),
'konsilet': ('konsil',),
'konsistens': ('konsistens',),
'konsistensen': ('konsistens',),
'konsistensene': ('konsistens',),
'konsistenser': ('konsistens',),
'konsistoria': ('konsistorium',),
'konsistoriene': ('konsistorium',),
'konsistorier': ('konsistorium',),
'konsistoriet': ('konsistorium',),
'konsistorium': ('konsistorium',),
'konskripsjon': ('konskripsjon',),
'konskripsjonen': ('konskripsjon',),
'konskripsjonene': ('konskripsjon',),
'konskripsjoner': ('konskripsjon',),
'konsoll': ('konsoll',),
'konsollen': ('konsoll',),
'konsollene': ('konsoll',),
'konsoller': ('konsoll',),
'konsollbord': ('konsollbord',),
'konsollborda': ('konsollbord',),
'konsollbordene': ('konsollbord',),
'konsollborder': ('konsollbord',),
'konsollbordet': ('konsollbord',),
'konsollspeil': ('konsollspeil',),
'konsollspeila': ('konsollspeil',),
'konsollspeilene': ('konsollspeil',),
'konsollspeilet': ('konsollspeil',),
'konsonans': ('konsonans',),
'konsonansen': ('konsonans',),
'konsonansene': ('konsonans',),
'konsonanser': ('konsonans',),
'konsonant': ('konsonant',),
'konsonanten': ('konsonant',),
'konsonantene': ('konsonant',),
'konsonanter': ('konsonant',),
'konsonantisme': ('konsonantisme',),
'konsonantismen': ('konsonantisme',),
'konsonantismene': ('konsonantisme',),
'konsonantismer': ('konsonantisme',),
'konsortene': ('konsorter',),
'konsorter': ('konsorter',),
'konsortia': ('konsortium',),
'konsortiene': ('konsortium',),
'konsortier': ('konsortium',),
'konsortiet': ('konsortium',),
'konsortium': ('konsortium',),
'konspirant': ('konspirant',),
'konspiranten': ('konspirant',),
'konspirantene': ('konspirant',),
'konspiranter': ('konspirant',),
'konspirasjon': ('konspirasjon',),
'konspirasjonen': ('konspirasjon',),
'konspirasjonene': ('konspirasjon',),
'konspirasjoner': ('konspirasjon',),
'konspirator': ('konspirator',),
'konspiratoren': ('konspirator',),
'konspiratorene': ('konspirator',),
'konspiratorer': ('konspirator',),
'konspiratør': ('konspiratør',),
'konspiratøren': ('konspiratør',),
'konspiratørene': ('konspiratør',),
'konspiratører': ('konspiratør',),
'konstabel': ('konstabel',),
'konstabelen': ('konstabel',),
'konstablene': ('konstabel',),
'konstabler': ('konstabel',),
'konstans': ('konstans',),
'konstansen': ('konstans',),
'konstansene': ('konstans',),
'konstanser': ('konstans',),
'konstant': ('konstant',),
'konstanten': ('konstant',),
'konstantene': ('konstant',),
'konstanter': ('konstant',),
'konstantan': ('konstantan',),
'konstantana': ('konstantan',),
'konstantanene': ('konstantan',),
'konstantanet': ('konstantan',),
'konstellasjon': ('konstellasjon',),
'konstellasjonen': ('konstellasjon',),
'konstellasjonene': ('konstellasjon',),
'konstellasjoner': ('konstellasjon',),
'konstellat': ('konstellat',),
'konstellata': ('konstellat',),
'konstellatene': ('konstellat',),
'konstellater': ('konstellat',),
'konstellatet': ('konstellat',),
'konstituent': ('konstituent',),
'konstituenten': ('konstituent',),
'konstituentene': ('konstituent',),
'konstituenter': ('konstituent',),
'konstitusjon': ('konstitusjon',),
'konstitusjonen': ('konstitusjon',),
'konstitusjonene': ('konstitusjon',),
'konstitusjoner': ('konstitusjon',),
'konstruksjon': ('konstruksjon',),
'konstruksjonen': ('konstruksjon',),
'konstruksjonene': ('konstruksjon',),
'konstruksjoner': ('konstruksjon',),
'konstruktivisme': ('konstruktivisme',),
'konstruktivismen': ('konstruktivisme',),
'konstruktivismene': ('konstruktivisme',),
'konstruktivismer': ('konstruktivisme',),
'konstruktivitet': ('konstruktivitet',),
'konstruktiviteten': ('konstruktivitet',),
'konstruktivitetene': ('konstruktivitet',),
'konstruktiviteter': ('konstruktivitet',),
'konstruktør': ('konstruktør',),
'konstruktøren': ('konstruktør',),
'konstruktørene': ('konstruktør',),
'konstruktører': ('konstruktør',),
'konsul': ('konsul',),
'konsulen': ('konsul',),
'konsulene': ('konsul',),
'konsuler': ('konsul',),
'konsulat': ('konsulat',),
'konsulata': ('konsulat',),
'konsulatene': ('konsulat',),
'konsulater': ('konsulat',),
'konsulatet': ('konsulat',),
'konsulattjeneste': ('konsulattjeneste',),
'konsulattjenesten': ('konsulattjeneste',),
'konsulattjenestene': ('konsulattjeneste',),
'konsulattjenester': ('konsulattjeneste',),
'konsulatvesen': ('konsulatvesen',),
'konsulatvesena': ('konsulatvesen',),
'konsulatvesenene': ('konsulatvesen',),
'konsulatvesener': ('konsulatvesen',),
'konsulatvesenet': ('konsulatvesen',),
'konsulent': ('konsulent',),
'konsulenten': ('konsulent',),
'konsulentene': ('konsulent',),
'konsulenter': ('konsulent',),
'konsulentfirma': ('konsulentfirma',),
'konsulentfirmaene': ('konsulentfirma',),
'konsulentfirmaer': ('konsulentfirma',),
'konsulentfirmaet': ('konsulentfirma',),
'konsultasjon': ('konsultasjon',),
'konsultasjonen': ('konsultasjon',),
'konsultasjonene': ('konsultasjon',),
'konsultasjoner': ('konsultasjon',),
'konsum': ('konsum',),
'konsuma': ('konsum',),
'konsumene': ('konsum',),
'konsumet': ('konsum',),
'konsument': ('konsument',),
'konsumenten': ('konsument',),
'konsumentene': ('konsument',),
'konsumenter': ('konsument',),
'konsummelk': ('konsummelk',),
'konsummelka': ('konsummelk',),
'konsummelken': ('konsummelk',),
'konsummelkene': ('konsummelk',),
'konsummelker': ('konsummelk',),
'konsumprisindeks': ('konsumprisindeks',),
'konsumprisindeksen': ('konsumprisindeks',),
'konsumprisindeksene': ('konsumprisindeks',),
'konsumprisindekser': ('konsumprisindeks',),
'konsumpsjon': ('konsumpsjon',),
'konsumpsjonen': ('konsumpsjon',),
'konsumpsjonene': ('konsumpsjon',),
'konsumpsjoner': ('konsumpsjon',),
'konsumvara': ('konsumvare',),
'konsumvare': ('konsumvare',),
'konsumvaren': ('konsumvare',),
'konsumvarene': ('konsumvare',),
'konsumvarer': ('konsumvare',),
'kont': ('kont',),
'konten': ('kont',),
'kontene': ('kont',),
'konter': ('kont',),
'kontakt': ('kontakt',),
'kontakten': ('kontakt',),
'kontaktene': ('kontakt',),
'kontakter': ('kontakt',),
'kontaktflata': ('kontaktflate',),
'kontaktflate': ('kontaktflate',),
'kontaktflaten': ('kontaktflate',),
'kontaktflatene': ('kontaktflate',),
'kontaktflater': ('kontaktflate',),
'kontaktlim': ('kontaktlim',),
'kontaktlima': ('kontaktlim',),
'kontaktlimene': ('kontaktlim',),
'kontaktlimet': ('kontaktlim',),
'kontaktlinsa': ('kontaktlinse',),
'kontaktlinse': ('kontaktlinse',),
'kontaktlinsen': ('kontaktlinse',),
'kontaktlinsene': ('kontaktlinse',),
'kontaktlinser': ('kontaktlinse',),
'kontaktnett': ('kontaktnett',),
'kontaktnetta': ('kontaktnett',),
'kontaktnettene': ('kontaktnett',),
'kontaktnettet': ('kontaktnett',),
'kontaktperson': ('kontaktperson',),
'kontaktpersonen': ('kontaktperson',),
'kontaktpersonene': ('kontaktperson',),
'kontaktpersoner': ('kontaktperson',),
'kontaminasjon': ('kontaminasjon',),
'kontaminasjonen': ('kontaminasjon',),
'kontaminasjonene': ('kontaminasjon',),
'kontaminasjoner': ('kontaminasjon',),
'kontant': ('kontant',),
'kontanten': ('kontant',),
'kontantene': ('kontant',),
'kontanter': ('kontant',),
'kontantautomat': ('kontantautomat',),
'kontantautomaten': ('kontantautomat',),
'kontantautomatene': ('kontantautomat',),
'kontantautomater': ('kontantautomat',),
'kontantkort': ('kontantkort',),
'kontantkorta': ('kontantkort',),
'kontantkortene': ('kontantkort',),
'kontantkortet': ('kontantkort',),
'kontantrabatt': ('kontantrabatt',),
'kontantrabatten': ('kontantrabatt',),
'kontantrabattene': ('kontantrabatt',),
'kontantrabatter': ('kontantrabatt',),
'kontantsalg': ('kontantsalg',),
'kontantsalga': ('kontantsalg',),
'kontantsalgene': ('kontantsalg',),
'kontantsalget': ('kontantsalg',),
'kontekst': ('kontekst',),
'konteksten': ('kontekst',),
'kontekstene': ('kontekst',),
'kontekster': ('kontekst',),
'kontemplasjon': ('kontemplasjon',),
'kontemplasjonen': ('kontemplasjon',),
'kontemplasjonene': ('kontemplasjon',),
'kontemplasjoner': ('kontemplasjon',),
'kontentum': ('kontentum',),
'kontentuma': ('kontentum',),
'kontentumene': ('kontentum',),
'kontentumet': ('kontentum',),
'kontinent': ('kontinent',),
'kontinenta': ('kontinent',),
'kontinentene': ('kontinent',),
'kontinenter': ('kontinent',),
'kontinentet': ('kontinent',),
'kontinentalsokkel': ('kontinentalsokkel',),
'kontinentalsokkelen': ('kontinentalsokkel',),
'kontinentalsoklene': ('kontinentalsokkel',),
'kontinentalsokler': ('kontinentalsokkel',),
'kontingent': ('kontingent',),
'kontingenten': ('kontingent',),
'kontingentene': ('kontingent',),
'kontingenter': ('kontingent',),
'kontinuant': ('kontinuant',),
'kontinuanten': ('kontinuant',),
'kontinuantene': ('kontinuant',),
'kontinuanter': ('kontinuant',),
'kontinuasjon': ('kontinuasjon',),
'kontinuasjonen': ('kontinuasjon',),
'kontinuasjonene': ('kontinuasjon',),
'kontinuasjoner': ('kontinuasjon',),
'kontinuitet': ('kontinuitet',),
'kontinuiteten': ('kontinuitet',),
'kontinuitetene': ('kontinuitet',),
'kontinuiteter': ('kontinuitet',),
'kontinua': ('kontinuum',),
'kontinuaene': ('kontinuum',),
'kontinuum': ('kontinuum',),
'kontinuumet': ('kontinuum',),
'konti': ('konto',),
'kontiene': ('konto',),
'konto': ('konto',),
'kontoen': ('konto',),
'kontoene': ('konto',),
'kontoer': ('konto',),
'kontobevis': ('kontobevis',),
'kontobevisa': ('kontobevis',),
'kontobevisene': ('kontobevis',),
'kontobeviser': ('kontobevis',),
'kontobeviset': ('kontobevis',),
'kontoid': ('kontoid',),
'kontoiden': ('kontoid',),
'kontoidene': ('kontoid',),
'kontoider': ('kontoid',),
'kontokort': ('kontokort',),
'kontokorta': ('kontokort',),
'kontokortene': ('kontokort',),
'kontokortet': ('kontokort',),
'kontokunde': ('kontokunde',),
'kontokunden': ('kontokunde',),
'kontokundene': ('kontokunde',),
'kontokunder': ('kontokunde',),
'kontokurant': ('kontokurant',),
'kontokuranten': ('kontokurant',),
'kontokurantene': ('kontokurant',),
'kontokuranter': ('kontokurant',),
'kontor': ('kontor',),
'kontora': ('kontor',),
'kontorene': ('kontor',),
'kontorer': ('kontor',),
'kontoret': ('kontor',),
'kontorassistent': ('kontorassistent',),
'kontorassistenten': ('kontorassistent',),
'kontorassistentene': ('kontorassistent',),
'kontorassistenter': ('kontorassistent',),
'kontordag': ('kontordag',),
'kontordagen': ('kontordag',),
'kontordagene': ('kontordag',),
'kontordager': ('kontordag',),
'kontordama': ('kontordame',),
'kontordame': ('kontordame',),
'kontordamen': ('kontordame',),
'kontordamene': ('kontordame',),
'kontordamer': ('kontordame',),
'kontorfullmektig': ('kontorfullmektig',),
'kontorfullmektigen': ('kontorfullmektig',),
'kontorfullmektigene': ('kontorfullmektig',),
'kontorfullmektiger': ('kontorfullmektig',),
'kontorhold': ('kontorhold',),
'kontorholda': ('kontorhold',),
'kontorholdene': ('kontorhold',),
'kontorholdet': ('kontorhold',),
'kontorist': ('kontorist',),
'kontoristen': ('kontorist',),
'kontoristene': ('kontorist',),
'kontorister': ('kontorist',),
'kontorlandskap': ('kontorlandskap',),
'kontorlandskapa': ('kontorlandskap',),
'kontorlandskapene': ('kontorlandskap',),
'kontorlandskaper': ('kontorlandskap',),
'kontorlandskapet': ('kontorlandskap',),
'kontormaskin': ('kontormaskin',),
'kontormaskina': ('kontormaskin',),
'kontormaskinen': ('kontormaskin',),
'kontormaskinene': ('kontormaskin',),
'kontormaskiner': ('kontormaskin',),
'kontorpersonala': ('kontorpersonale',),
'kontorpersonale': ('kontorpersonale',),
'kontorpersonalene': ('kontorpersonale',),
'kontorpersonaler': ('kontorpersonale',),
'kontorpersonalet': ('kontorpersonale',),
'kontorrotta': ('kontorrotte',),
'kontorrotte': ('kontorrotte',),
'kontorrotten': ('kontorrotte',),
'kontorrottene': ('kontorrotte',),
'kontorrotter': ('kontorrotte',),
'kontorsjef': ('kontorsjef',),
'kontorsjefen': ('kontorsjef',),
'kontorsjefene': ('kontorsjef',),
'kontorsjefer': ('kontorsjef',),
'kontorsjefsstilling': ('kontorsjefsstilling',),
'kontorsjefsstillinga': ('kontorsjefsstilling',),
'kontorsjefsstillingen': ('kontorsjefsstilling',),
'kontorsjefsstillingene': ('kontorsjefsstilling',),
'kontorsjefsstillinger': ('kontorsjefsstilling',),
'kontorsjefstilling': ('kontorsjefstilling',),
'kontorsjefstillinga': ('kontorsjefstilling',),
'kontorsjefstillingen': ('kontorsjefstilling',),
'kontorsjefstillingene': ('kontorsjefstilling',),
'kontorsjefstillinger': ('kontorsjefstilling',),
'kontorsøster': ('kontorsøster',),
'kontorsøstera': ('kontorsøster',),
'kontorsøsteren': ('kontorsøster',),
'kontorsøstre': ('kontorsøster',),
'kontorsøstrene': ('kontorsøster',),
'kontorsøstrer': ('kontorsøster',),
'kontortid': ('kontortid',),
'kontortida': ('kontortid',),
'kontortiden': ('kontortid',),
'kontortidene': ('kontortid',),
'kontortider': ('kontortid',),
'kontraalt': ('kontraalt',),
'kontraalten': ('kontraalt',),
'kontraaltene': ('kontraalt',),
'kontraalter': ('kontraalt',),
'kontrabande': ('kontrabande',),
'kontrabanden': ('kontrabande',),
'kontrabandene': ('kontrabande',),
'kontrabander': ('kontrabande',),
'kontrabass': ('kontrabass',),
'kontrabassen': ('kontrabass',),
'kontrabassene': ('kontrabass',),
'kontrabasser': ('kontrabass',),
'kontrabok': ('kontrabok',),
'kontraboka': ('kontrabok',),
'kontraboken': ('kontrabok',),
'kontrabøkene': ('kontrabok',),
'kontrabøker': ('kontrabok',),
'kontradans': ('kontradans',),
'kontradansen': ('kontradans',),
'kontradansene': ('kontradans',),
'kontradanser': ('kontradans',),
'kontradiksjon': ('kontradiksjon',),
'kontradiksjonen': ('kontradiksjon',),
'kontradiksjonene': ('kontradiksjon',),
'kontradiksjoner': ('kontradiksjon',),
'kontradiksjonsprinsipp': ('kontradiksjonsprinsipp',),
'kontradiksjonsprinsippa': ('kontradiksjonsprinsipp',),
'kontradiksjonsprinsippene': ('kontradiksjonsprinsipp',),
'kontradiksjonsprinsipper': ('kontradiksjonsprinsipp',),
'kontradiksjonsprinsippet': ('kontradiksjonsprinsipp',),
'kontrafei': ('kontrafei',),
'kontrafeia': ('kontrafei',),
'kontrafeiene': ('kontrafei',),
'kontrafeier': ('kontrafei',),
'kontrafeiet': ('kontrafei',),
'kontrafekting': ('kontrafekting',),
'kontrafektinga': ('kontrafekting',),
'kontrafektingen': ('kontrafekting',),
'kontrafektingene': ('kontrafekting',),
'kontrafektinger': ('kontrafekting',),
'kontrahent': ('kontrahent',),
'kontrahenten': ('kontrahent',),
'kontrahentene': ('kontrahent',),
'kontrahenter': ('kontrahent',),
'kontraksjon': ('kontraksjon',),
'kontraksjonen': ('kontraksjon',),
'kontraksjonene': ('kontraksjon',),
'kontraksjoner': ('kontraksjon',),
'kontrakt': ('kontrakt',),
'kontrakten': ('kontrakt',),
'kontraktene': ('kontrakt',),
'kontrakter': ('kontrakt',),
'kontraktbetingelse': ('kontraktbetingelse',),
'kontraktbetingelsen': ('kontraktbetingelse',),
'kontraktbetingelsene': ('kontraktbetingelse',),
'kontraktbetingelser': ('kontraktbetingelse',),
'kontraktbridge': ('kontraktbridge',),
'kontraktbridgen': ('kontraktbridge',),
'kontraktbridgene': ('kontraktbridge',),
'kontraktbridger': ('kontraktbridge',),
'kontraktbrott': ('kontraktbrott',),
'kontraktbrotta': ('kontraktbrott',),
'kontraktbrottene': ('kontraktbrott',),
'kontraktbrottet': ('kontraktbrott',),
'kontraktbrudd': ('kontraktbrudd',),
'kontraktbrudda': ('kontraktbrudd',),
'kontraktbruddene': ('kontraktbrudd',),
'kontraktbruddet': ('kontraktbrudd',),
'kontraktdyrking': ('kontraktdyrking',),
'kontraktdyrkinga': ('kontraktdyrking',),
'kontraktdyrkingen': ('kontraktdyrking',),
'kontraktdyrkingene': ('kontraktdyrking',),
'kontraktdyrkinger': ('kontraktdyrking',),
'kontraktforhold': ('kontraktforhold',),
'kontraktforholda': ('kontraktforhold',),
'kontraktforholdene': ('kontraktforhold',),
'kontraktforholdet': ('kontraktforhold',),
'kontraktor': ('kontraktor',),
'kontraktoren': ('kontraktor',),
'kontraktorene': ('kontraktor',),
'kontraktorer': ('kontraktor',),
'kontraktsbetingelse': ('kontraktsbetingelse',),
'kontraktsbetingelsen': ('kontraktsbetingelse',),
'kontraktsbetingelsene': ('kontraktsbetingelse',),
'kontraktsbetingelser': ('kontraktsbetingelse',),
'kontraktsforhold': ('kontraktsforhold',),
'kontraktsforholda': ('kontraktsforhold',),
'kontraktsforholdene': ('kontraktsforhold',),
'kontraktsforholdet': ('kontraktsforhold',),
'kontraktur': ('kontraktur',),
'kontrakturen': ('kontraktur',),
'kontrakturene': ('kontraktur',),
'kontrakturer': ('kontraktur',),
'kontraktør': ('kontraktør',),
'kontraktøren': ('kontraktør',),
'kontraktørene': ('kontraktør',),
'kontraktører': ('kontraktør',),
'kontraoktav': ('kontraoktav',),
'kontraoktaven': ('kontraoktav',),
'kontraoktavene': ('kontraoktav',),
'kontraoktaver': ('kontraoktav',),
'kontraordre': ('kontraordre',),
'kontraordren': ('kontraordre',),
'kontraordrene': ('kontraordre',),
'kontraordrer': ('kontraordre',),
'kontrapunkt': ('kontrapunkt',),
'kontrapunkta': ('kontrapunkt',),
'kontrapunktene': ('kontrapunkt',),
'kontrapunkter': ('kontrapunkt',),
'kontrapunktet': ('kontrapunkt',),
'kontrarevolusjon': ('kontrarevolusjon',),
'kontrarevolusjonen': ('kontrarevolusjon',),
'kontrarevolusjonene': ('kontrarevolusjon',),
'kontrarevolusjoner': ('kontrarevolusjon',),
'kontrasignatur': ('kontrasignatur',),
'kontrasignaturen': ('kontrasignatur',),
'kontrasignaturene': ('kontrasignatur',),
'kontrasignaturer': ('kontrasignatur',),
'kontraspionasje': ('kontraspionasje',),
'kontraspionasjen': ('kontraspionasje',),
'kontraspionasjene': ('kontraspionasje',),
'kontraspionasjer': ('kontraspionasje',),
'kontrast': ('kontrast',),
'kontrasten': ('kontrast',),
'kontrastene': ('kontrast',),
'kontraster': ('kontrast',),
'kontrastfarge': ('kontrastfarge',),
'kontrastfargen': ('kontrastfarge',),
'kontrastfargene': ('kontrastfarge',),
'kontrastfarger': ('kontrastfarge',),
'kontrastvirkning': ('kontrastvirkning',),
'kontrastvirkninga': ('kontrastvirkning',),
'kontrastvirkningen': ('kontrastvirkning',),
'kontrastvirkningene': ('kontrastvirkning',),
'kontrastvirkninger': ('kontrastvirkning',),
'kontrastøt': ('kontrastøt',),
'kontrastøta': ('kontrastøt',),
'kontrastøtene': ('kontrastøt',),
'kontrastøtet': ('kontrastøt',),
'kontratenor': ('kontratenor',),
'kontratenoren': ('kontratenor',),
'kontratenorene': ('kontratenor',),
'kontratenorer': ('kontratenor',),
'kontratrykk': ('kontratrykk',),
'kontratrykka': ('kontratrykk',),
'kontratrykkene': ('kontratrykk',),
'kontratrykket': ('kontratrykk',),
'kontravotering': ('kontravotering',),
'kontravoteringa': ('kontravotering',),
'kontravoteringen': ('kontravotering',),
'kontravoteringene': ('kontravotering',),
'kontravoteringer': ('kontravotering',),
'kontreadmiral': ('kontreadmiral',),
'kontreadmiralen': ('kontreadmiral',),
'kontreadmiralene': ('kontreadmiral',),
'kontreadmiraler': ('kontreadmiral',),
'kontribusjon': ('kontribusjon',),
'kontribusjonen': ('kontribusjon',),
'kontribusjonene': ('kontribusjon',),
'kontribusjoner': ('kontribusjon',),
'kontring': ('kontring',),
'kontringa': ('kontring',),
'kontringen': ('kontring',),
'kontringene': ('kontring',),
'kontringer': ('kontring',),
'kontroll': ('kontroll',),
'kontrollen': ('kontroll',),
'kontrollene': ('kontroll',),
'kontroller': ('kontroll',),
'kontroll-lag': ('kontroll-lag',),
'kontroll-laga': ('kontroll-lag',),
'kontroll-lagene': ('kontroll-lag',),
'kontroll-laget': ('kontroll-lag',),
'kontroll-lampa': ('kontroll-lampe',),
'kontroll-lampe': ('kontroll-lampe',),
'kontroll-lampen': ('kontroll-lampe',),
'kontroll-lampene': ('kontroll-lampe',),
'kontroll-lamper': ('kontroll-lampe',),
'kontrollag': ('kontrollag',),
'kontrollaga': ('kontrollag',),
'kontrollagene': ('kontrollag',),
'kontrollaget': ('kontrollag',),
'kontrollampa': ('kontrollampe',),
'kontrollampe': ('kontrollampe',),
'kontrollampen': ('kontrollampe',),
'kontrollampene': ('kontrollampe',),
'kontrollamper': ('kontrollampe',),
'kontrollapparat': ('kontrollapparat',),
'kontrollapparata': ('kontrollapparat',),
'kontrollapparatene': ('kontrollapparat',),
'kontrollapparater': ('kontrollapparat',),
'kontrollapparatet': ('kontrollapparat',),
'kontroller': ('kontroller',),
'kontrollere': ('kontroller',),
'kontrolleren': ('kontroller',),
'kontrollerer': ('kontroller',),
'kontrollerne': ('kontroller',),
'kontrollkommisjon': ('kontrollkommisjon',),
'kontrollkommisjonen': ('kontrollkommisjon',),
'kontrollkommisjonene': ('kontrollkommisjon',),
'kontrollkommisjoner': ('kontrollkommisjon',),
'kontrollpanel': ('kontrollpanel',),
'kontrollpanela': ('kontrollpanel',),
'kontrollpanelene': ('kontrollpanel',),
'kontrollpaneler': ('kontrollpanel',),
'kontrollpanelet': ('kontrollpanel',),
'kontrollrom': ('kontrollrom',),
'kontrollromma': ('kontrollrom',),
'kontrollrommene': ('kontrollrom',),
'kontrollrommet': ('kontrollrom',),
'kontrolltårn': ('kontrolltårn',),
'kontrolltårna': ('kontrolltårn',),
'kontrolltårnene': ('kontrolltårn',),
'kontrolltårnet': ('kontrolltårn',),
'kontrollør': ('kontrollør',),
'kontrolløren': ('kontrollør',),
'kontrollørene': ('kontrollør',),
'kontrollører': ('kontrollør',),
'kontrovers': ('kontrovers',),
'kontroversen': ('kontrovers',),
'kontroversene': ('kontrovers',),
'kontroverser': ('kontrovers',),
'kontur': ('kontur',),
'konturen': ('kontur',),
'konturene': ('kontur',),
'konturer': ('kontur',),
'konus': ('konus',),
'konusen': ('konus',),
'konusene': ('konus',),
'konuser': ('konus',),
'konvall': ('konvall',),
'konvallen': ('konvall',),
'konvallene': ('konvall',),
'konvaller': ('konvall',),
'konveksitet': ('konveksitet',),
'konveksiteten': ('konveksitet',),
'konveksitetene': ('konveksitet',),
'konveksiteter': ('konveksitet',),
'konveksjon': ('konveksjon',),
'konveksjonen': ('konveksjon',),
'konveksjonene': ('konveksjon',),
'konveksjoner': ('konveksjon',),
'konveniens': ('konveniens',),
'konveniensen': ('konveniens',),
'konveniensene': ('konveniens',),
'konvenienser': ('konveniens',),
'konvensjon': ('konvensjon',),
'konvensjonen': ('konvensjon',),
'konvensjonene': ('konvensjon',),
'konvensjoner': ('konvensjon',),
'konvensjonalisme': ('konvensjonalisme',),
'konvensjonalismen': ('konvensjonalisme',),
'konvensjonalismene': ('konvensjonalisme',),
'konvensjonalismer': ('konvensjonalisme',),
'konvent': ('konvent',),
'konventa': ('konvent',),
'konventene': ('konvent',),
'konventer': ('konvent',),
'konventet': ('konvent',),
'konventikkel': ('konventikkel',),
'konventikkelen': ('konventikkel',),
'konventiklene': ('konventikkel',),
'konventikler': ('konventikkel',),
'konvergens': ('konvergens',),
'konvergensen': ('konvergens',),
'konvergensene': ('konvergens',),
'konvergenser': ('konvergens',),
'konversasjon': ('konversasjon',),
'konversasjonen': ('konversasjon',),
'konversasjonene': ('konversasjon',),
'konversasjoner': ('konversasjon',),
'konversasjonsleksika': ('konversasjonsleksikon',),
'konversasjonsleksikaene': ('konversasjonsleksikon',),
'konversasjonsleksikon': ('konversasjonsleksikon',),
'konversasjonsleksikona': ('konversasjonsleksikon',),
'konversasjonsleksikonene': ('konversasjonsleksikon',),
'konversasjonsleksikoner': ('konversasjonsleksikon',),
'konversasjonsleksikonet': ('konversasjonsleksikon',),
'konverter': ('konverter',),
'konvertere': ('konverter',),
'konverteren': ('konverter',),
'konverterer': ('konverter',),
'konverterne': ('konverter',),
'konvertitt': ('konvertitt',),
'konvertitten': ('konvertitt',),
'konvertittene': ('konvertitt',),
'konvertitter': ('konvertitt',),
'konvoi': ('konvoi',),
'konvoien': ('konvoi',),
'konvoiene': ('konvoi',),
'konvoier': ('konvoi',),
'konvolutt': ('konvolutt',),
'konvolutten': ('konvolutt',),
'konvoluttene': ('konvolutt',),
'konvolutter': ('konvolutt',),
'konvulsjon': ('konvulsjon',),
'konvulsjonen': ('konvulsjon',),
'konvulsjonene': ('konvulsjon',),
'konvulsjoner': ('konvulsjon',),
'kooperasjon': ('kooperasjon',),
'kooperasjonen': ('kooperasjon',),
'kooperasjonene': ('kooperasjon',),
'kooperasjoner': ('kooperasjon',),
'kooperativ': ('kooperativ',),
'kooperativa': ('kooperativ',),
'kooperativene': ('kooperativ',),
'kooperativer': ('kooperativ',),
'kooperativet': ('kooperativ',),
'kooperatør': ('kooperatør',),
'kooperatøren': ('kooperatør',),
'kooperatørene': ('kooperatør',),
'kooperatører': ('kooperatør',),
'koordinasjon': ('koordinasjon',),
'koordinasjonen': ('koordinasjon',),
'koordinasjonene': ('koordinasjon',),
'koordinasjoner': ('koordinasjon',),
'koordinat': ('koordinat',),
'koordinaten': ('koordinat',),
'koordinatene': ('koordinat',),
'koordinater': ('koordinat',),
'koordinatakse': ('koordinatakse',),
'koordinataksen': ('koordinatakse',),
'koordinataksene': ('koordinatakse',),
'koordinatakser': ('koordinatakse',),
'koordinator': ('koordinator',),
'koordinatoren': ('koordinator',),
'koordinatorene': ('koordinator',),
'koordinatorer': ('koordinator',),
'koordinatsystem': ('koordinatsystem',),
'koordinatsystema': ('koordinatsystem',),
'koordinatsystemene': ('koordinatsystem',),
'koordinatsystemer': ('koordinatsystem',),
'koordinatsystemet': ('koordinatsystem',),
'koordinering': ('koordinering',),
'koordineringa': ('koordinering',),
'koordineringen': ('koordinering',),
'koordineringene': ('koordinering',),
'koordineringer': ('koordinering',),
'kop': ('kop',),
'kopen': ('kop',),
'kopene': ('kop',),
'koper': ('kop',),
'kopal': ('kopal',),
'kopalen': ('kopal',),
'kopalene': ('kopal',),
'kopaler': ('kopal',),
'kopek': ('kopek',),
'kopeken': ('kopek',),
'kopekene': ('kopek',),
'kopi': ('kopi',),
'kopien': ('kopi',),
'kopiene': ('kopi',),
'kopier': ('kopi',),
'kopiblyant': ('kopiblyant',),
'kopiblyanten': ('kopiblyant',),
'kopiblyantene': ('kopiblyant',),
'kopiblyanter': ('kopiblyant',),
'kopieringsmaskin': ('kopieringsmaskin',),
'kopieringsmaskina': ('kopieringsmaskin',),
'kopieringsmaskinen': ('kopieringsmaskin',),
'kopieringsmaskinene': ('kopieringsmaskin',),
'kopieringsmaskiner': ('kopieringsmaskin',),
'kopilot': ('kopilot',),
'kopiloten': ('kopilot',),
'kopilotene': ('kopilot',),
'kopiloter': ('kopilot',),
'kopimaskin': ('kopimaskin',),
'kopimaskina': ('kopimaskin',),
'kopimaskinen': ('kopimaskin',),
'kopimaskinene': ('kopimaskin',),
'kopimaskiner': ('kopimaskin',),
'kopist': ('kopist',),
'kopisten': ('kopist',),
'kopistene': ('kopist',),
'kopister': ('kopist',),
'kopling': ('kopling',),
'koplinga': ('kopling',),
'koplingen': ('kopling',),
'koplingene': ('kopling',),
'koplinger': ('kopling',),
'koplingsboks': ('koplingsboks',),
'koplingsboksen': ('koplingsboks',),
'koplingsboksene': ('koplingsboks',),
'koplingsbokser': ('koplingsboks',),
'kopp': ('kopp',),
'koppen': ('kopp',),
'koppene': ('kopp',),
'kopper': ('kopp',),
'kopp': ('kopp',),
'koppen': ('kopp',),
'koppene': ('kopp',),
'kopper': ('kopp',),
'koppeattest': ('koppeattest',),
'koppeattesten': ('koppeattest',),
'koppeattestene': ('koppeattest',),
'koppeattester': ('koppeattest',),
'kopla': ('koppel',),
'koplene': ('koppel',),
'kopler': ('koppel',),
'koplet': ('koppel',),
'koppel': ('koppel',),
'koppelet': ('koppel',),
'koppene': ('kopper',),
'kopper': ('kopper',),
'kopper': ('kopper',),
'koppera': ('kopper',),
'koppere': ('kopper',),
'kopperet': ('kopper',),
'kopperne': ('kopper',),
'koppergruva': ('koppergruve',),
'koppergruve': ('koppergruve',),
'koppergruven': ('koppergruve',),
'koppergruvene': ('koppergruve',),
'koppergruver': ('koppergruve',),
'kopperhud': ('kopperhud',),
'kopperhuda': ('kopperhud',),
'kopperhuden': ('kopperhud',),
'kopperhudene': ('kopperhud',),
'kopperhuder': ('kopperhud',),
'kopperkis': ('kopperkis',),
'kopperkisen': ('kopperkis',),
'kopperkisene': ('kopperkis',),
'kopperkiser': ('kopperkis',),
'kopperkjel': ('kopperkjel',),
'kopperkjelen': ('kopperkjel',),
'kopperkjelene': ('kopperkjel',),
'kopperkjeler': ('kopperkjel',),
'kopperkjele': ('kopperkjele',),
'kopperkjelen': ('kopperkjele',),
'kopperkjelene': ('kopperkjele',),
'kopperkjeler': ('kopperkjele',),
'koppernagle': ('koppernagle',),
'koppernaglen': ('koppernagle',),
'koppernaglene': ('koppernagle',),
'koppernagler': ('koppernagle',),
'kopperstikk': ('kopperstikk',),
'kopperstikka': ('kopperstikk',),
'kopperstikkene': ('kopperstikk',),
'kopperstikket': ('kopperstikk',),
'kopperstikk': ('kopperstikk',),
'kopperstikka': ('kopperstikk',),
'kopperstikkene': ('kopperstikk',),
'kopperstikket': ('kopperstikk',),
'koppertråd': ('koppertråd',),
'koppertråden': ('koppertråd',),
'koppertrådene': ('koppertråd',),
'koppertråder': ('koppertråd',),
'kopplam': ('kopplam',),
'kopplamma': ('kopplam',),
'kopplammene': ('kopplam',),
'kopplammet': ('kopplam',),
'koppskatt': ('koppskatt',),
'koppskatten': ('koppskatt',),
'koppskattene': ('koppskatt',),
'koppskatter': ('koppskatt',),
'kopra': ('kopra',),
'kopraen': ('kopra',),
'kopraene': ('kopra',),
'kopraer': ('kopra',),
'koproduksjon': ('koproduksjon',),
'koproduksjonen': ('koproduksjon',),
'koproduksjonene': ('koproduksjon',),
'koproduksjoner': ('koproduksjon',),
'kopter': ('kopter',),
'koptere': ('kopter',),
'kopteren': ('kopter',),
'kopterer': ('kopter',),
'kopterne': ('kopter',),
'kopula': ('kopula',),
'kopulaene': ('kopula',),
'kopulaer': ('kopula',),
'kopulaet': ('kopula',),
'kopulasjon': ('kopulasjon',),
'kopulasjonen': ('kopulasjon',),
'kopulasjonene': ('kopulasjon',),
'kopulasjoner': ('kopulasjon',),
'kor': ('kor',),
'kora': ('kor',),
'korene': ('kor',),
'koret': ('kor',),
'koral': ('koral',),
'koralen': ('koral',),
'koralene': ('koral',),
'koraler': ('koral',),
'koralbok': ('koralbok',),
'koralboka': ('koralbok',),
'koralboken': ('koralbok',),
'koralbøkene': ('koralbok',),
'koralbøker': ('koralbok',),
'korall': ('korall',),
'korallen': ('korall',),
'korallene': ('korall',),
'koraller': ('korall',),
'koralldyr': ('koralldyr',),
'koralldyra': ('koralldyr',),
'koralldyrene': ('koralldyr',),
'koralldyret': ('koralldyr',),
'korallrev': ('korallrev',),
'korallreva': ('korallrev',),
'korallrevene': ('korallrev',),
'korallrevet': ('korallrev',),
'korallrot': ('korallrot',),
'korallrota': ('korallrot',),
'korallroten': ('korallrot',),
'korallrøttene': ('korallrot',),
'korallrøtter': ('korallrot',),
'korallsmykka': ('korallsmykke',),
'korallsmykke': ('korallsmykke',),
'korallsmykkene': ('korallsmykke',),
'korallsmykker': ('korallsmykke',),
'korallsmykket': ('korallsmykke',),
'koralløy': ('koralløy',),
'koralløya': ('koralløy',),
'koralløyen': ('koralløy',),
'koralløyene': ('koralløy',),
'koralløyer': ('koralløy',),
'koran': ('koran',),
'koranen': ('koran',),
'koranene': ('koran',),
'koraner': ('koran',),
'korbroder': ('korbroder',),
'korbroderen': ('korbroder',),
'korbrødre': ('korbroder',),
'korbrødrene': ('korbroder',),
'korbror': ('korbror',),
'korbroren': ('korbror',),
'korbrødre': ('korbror',),
'korbrødrene': ('korbror',),
'kord': ('kord',),
'korden': ('kord',),
'kordene': ('kord',),
'korder': ('kord',),
'korde': ('korde',),
'korden': ('korde',),
'kordene': ('korde',),
'korder': ('korde',),
'kordel': ('kordel',),
'kordelen': ('kordel',),
'kordelene': ('kordel',),
'kordeler': ('kordel',),
'kordfløyel': ('kordfløyel',),
'kordfløyela': ('kordfløyel',),
'kordfløyelen': ('kordfløyel',),
'kordfløyelene': ('kordfløyel',),
'kordfløyeler': ('kordfløyel',),
'kordfløyelet': ('kordfløyel',),
'kordialitet': ('kordialitet',),
'kordialiteten': ('kordialitet',),
'kordialitetene': ('kordialitet',),
'kordialiteter': ('kordialitet',),
'kordong': ('kordong',),
'kordongen': ('kordong',),
'kordongene': ('kordong',),
'kordonger': ('kordong',),
'kordong': ('kordong',),
'kordongen': ('kordong',),
'kordongene': ('kordong',),
'kordonger': ('kordong',),
'korduan': ('korduan',),
'korduanen': ('korduan',),
'korduanene': ('korduan',),
'korduaner': ('korduan',),
'kordør': ('kordør',),
'kordøra': ('kordør',),
'kordøren': ('kordør',),
'kordørene': ('kordør',),
'kordører': ('kordør',),
'koreaner': ('koreaner',),
'koreanere': ('koreaner',),
'koreaneren': ('koreaner',),
'koreanerer': ('koreaner',),
'koreanerne': ('koreaner',),
'koreograf': ('koreograf',),
'koreografen': ('koreograf',),
'koreografene': ('koreograf',),
'koreografer': ('koreograf',),
'koreografi': ('koreografi',),
'koreografien': ('koreografi',),
'koreografiene': ('koreografi',),
'koreografier': ('koreografi',),
'korgball': ('korgball',),
'korgballen': ('korgball',),
'korgballene': ('korgball',),
'korgballer': ('korgball',),
'korgblomst': ('korgblomst',),
'korgblomsten': ('korgblomst',),
'korgblomstene': ('korgblomst',),
'korgblomster': ('korgblomst',),
'korgfletning': ('korgfletning',),
'korgfletninga': ('korgfletning',),
'korgfletningen': ('korgfletning',),
'korgfletningene': ('korgfletning',),
'korgfletninger': ('korgfletning',),
'korgmaker': ('korgmaker',),
'korgmakere': ('korgmaker',),
'korgmakeren': ('korgmaker',),
'korgmakerer': ('korgmaker',),
'korgmakerne': ('korgmaker',),
'korgplanta': ('korgplante',),
'korgplante': ('korgplante',),
'korgplanten': ('korgplante',),
'korgplantene': ('korgplante',),
'korgplanter': ('korgplante',),
'korgplantefamilie': ('korgplantefamilie',),
'korgplantefamilien': ('korgplantefamilie',),
'korgplantefamiliene': ('korgplantefamilie',),
'korgplantefamilier': ('korgplantefamilie',),
'korgutt': ('korgutt',),
'korgutten': ('korgutt',),
'korguttene': ('korgutt',),
'korgutter': ('korgutt',),
'korint': ('korint',),
'korinten': ('korint',),
'korintene': ('korint',),
'korinter': ('korint',),
'korinter': ('korinter',),
'korintere': ('korinter',),
'korinteren': ('korinter',),
'korinterer': ('korinter',),
'korinterne': ('korinter',),
'korist': ('korist',),
'koristen': ('korist',),
'koristene': ('korist',),
'korister': ('korist',),
'korjambe': ('korjambe',),
'korjamben': ('korjambe',),
'korjambene': ('korjambe',),
'korjamber': ('korjambe',),
'kork': ('kork',),
'korken': ('kork',),
'korkene': ('kork',),
'korker': ('kork',),
'kork': ('kork',),
'korken': ('kork',),
'korkene': ('kork',),
'korker': ('kork',),
'korkbelta': ('korkbelte',),
'korkbelte': ('korkbelte',),
'korkbeltene': ('korkbelte',),
'korkbelter': ('korkbelte',),
'korkbeltet': ('korkbelte',),
'korkebelta': ('korkebelte',),
'korkebelte': ('korkebelte',),
'korkebeltene': ('korkebelte',),
'korkebelter': ('korkebelte',),
'korkebeltet': ('korkebelte',),
'korkeik': ('korkeik',),
'korkeika': ('korkeik',),
'korkeiken': ('korkeik',),
'korkeikene': ('korkeik',),
'korkeiker': ('korkeik',),
'korketrekker': ('korketrekker',),
'korketrekkere': ('korketrekker',),
'korketrekkeren': ('korketrekker',),
'korketrekkerer': ('korketrekker',),
'korketrekkerne': ('korketrekker',),
'korketrekkerkrøll': ('korketrekkerkrøll',),
'korketrekkerkrøllen': ('korketrekkerkrøll',),
'korketrekkerkrøllene': ('korketrekkerkrøll',),
'korketrekkerkrøller': ('korketrekkerkrøll',),
'korn': ('korn',),
'korna': ('korn',),
'kornene': ('korn',),
'kornet': ('korn',),
'kornband': ('kornband',),
'kornbanda': ('kornband',),
'kornbandene': ('kornband',),
'kornbandet': ('kornband',),
'kornblanding': ('kornblanding',),
'kornblandinga': ('kornblanding',),
'kornblandingen': ('kornblanding',),
'kornblandingene': ('kornblanding',),
'kornblandinger': ('kornblanding',),
'kornblomst': ('kornblomst',),
'kornblomsten': ('kornblomst',),
'kornblomstene': ('kornblomst',),
'kornblomster': ('kornblomst',),
'kornbånd': ('kornbånd',),
'kornbånda': ('kornbånd',),
'kornbåndene': ('kornbånd',),
'kornbåndet': ('kornbånd',),
'kornell': ('kornell',),
'kornellen': ('kornell',),
'kornellene': ('kornell',),
'korneller': ('kornell',),
'kornellfamilie': ('kornellfamilie',),
'kornellfamilien': ('kornellfamilie',),
'kornellfamiliene': ('kornellfamilie',),
'kornellfamilier': ('kornellfamilie',),
'kornett': ('kornett',),
'kornetten': ('kornett',),
'kornettene': ('kornett',),
'kornetter': ('kornett',),
'kornettist': ('kornettist',),
'kornettisten': ('kornettist',),
'kornettistene': ('kornettist',),
'kornettister': ('kornettist',),
'korngard': ('korngard',),
'korngarden': ('korngard',),
'korngardene': ('korngard',),
'korngarder': ('korngard',),
'korngård': ('korngård',),
'korngården': ('korngård',),
'korngårdene': ('korngård',),
'korngårder': ('korngård',),
'kornkammer': ('kornkammer',),
'kornkammeret': ('kornkammer',),
'kornkamra': ('kornkammer',),
'kornkamre': ('kornkammer',),
'kornkamrene': ('kornkammer',),
'kornmo': ('kornmo',),
'kornmoen': ('kornmo',),
'kornmoene': ('kornmo',),
'kornmoer': ('kornmo',),
'kornnek': ('kornnek',),
'kornneka': ('kornnek',),
'kornnekene': ('kornnek',),
'kornneket': ('kornnek',),
'korntørka': ('korntørke',),
'korntørke': ('korntørke',),
'korntørken': ('korntørke',),
'korntørkene': ('korntørke',),
'korntørker': ('korntørke',),
'kornår': ('kornår',),
'kornåra': ('kornår',),
'kornårene': ('kornår',),
'kornåret': ('kornår',),
'korona': ('korona',),
'koronaen': ('korona',),
'koronaene': ('korona',),
'koronaer': ('korona',),
'korp': ('korp',),
'korpen': ('korp',),
'korpene': ('korp',),
'korper': ('korp',),
'korporal': ('korporal',),
'korporalen': ('korporal',),
'korporalene': ('korporal',),
'korporaler': ('korporal',),
'korporasjon': ('korporasjon',),
'korporasjonen': ('korporasjon',),
'korporasjonene': ('korporasjon',),
'korporasjoner': ('korporasjon',),
'korporativisme': ('korporativisme',),
'korporativismen': ('korporativisme',),
'korporativismene': ('korporativisme',),
'korporativismer': ('korporativisme',),
'korps': ('korps',),
'korpsa': ('korps',),
'korpsene': ('korps',),
'korpset': ('korps',),
'korpsånd': ('korpsånd',),
'korpsånden': ('korpsånd',),
'korpsåndene': ('korpsånd',),
'korpsånder': ('korpsånd',),
'korpulense': ('korpulense',),
'korpulensen': ('korpulense',),
'korpulensene': ('korpulense',),
'korpulenser': ('korpulense',),
'korpus': ('korpus',),
'korpusen': ('korpus',),
'korpusene': ('korpus',),
'korpuser': ('korpus',),
'korpus': ('korpus',),
'korpusa': ('korpus',),
'korpusen': ('korpus',),
'korpusene': ('korpus',),
'korpuser': ('korpus',),
'korpuset': ('korpus',),
'korreks': ('korreks',),
'korreksen': ('korreks',),
'korreksene': ('korreks',),
'korrekser': ('korreks',),
'korreksjon': ('korreksjon',),
'korreksjonen': ('korreksjon',),
'korreksjonene': ('korreksjon',),
'korreksjoner': ('korreksjon',),
'korrektiv': ('korrektiv',),
'korrektiva': ('korrektiv',),
'korrektivene': ('korrektiv',),
'korrektiver': ('korrektiv',),
'korrektivet': ('korrektiv',),
'korrektur': ('korrektur',),
'korrekturen': ('korrektur',),
'korrekturene': ('korrektur',),
'korrekturer': ('korrektur',),
'korrekturleser': ('korrekturleser',),
'korrekturlesere': ('korrekturleser',),
'korrekturleseren': ('korrekturleser',),
'korrekturleserer': ('korrekturleser',),
'korrekturleserne': ('korrekturleser',),
'korrekturtegn': ('korrekturtegn',),
'korrekturtegna': ('korrekturtegn',),
'korrekturtegnene': ('korrekturtegn',),
'korrekturtegnet': ('korrekturtegn',),
'korrelasjon': ('korrelasjon',),
'korrelasjonen': ('korrelasjon',),
'korrelasjonene': ('korrelasjon',),
'korrelasjoner': ('korrelasjon',),
'korrelat': ('korrelat',),
'korrelata': ('korrelat',),
'korrelatene': ('korrelat',),
'korrelater': ('korrelat',),
'korrelatet': ('korrelat',),
'korrespondanse': ('korrespondanse',),
'korrespondansen': ('korrespondanse',),
'korrespondansene': ('korrespondanse',),
'korrespondanser': ('korrespondanse',),
'korrespondansekurs': ('korrespondansekurs',),
'korrespondansekursa': ('korrespondansekurs',),
'korrespondansekursene': ('korrespondansekurs',),
'korrespondansekurser': ('korrespondansekurs',),
'korrespondansekurset': ('korrespondansekurs',),
'korrespondansekursene': ('korrespondansekursus',),
'korrespondansekurser': ('korrespondansekursus',),
'korrespondansekursus': ('korrespondansekursus',),
'korrespondansekursuset': ('korrespondansekursus',),
'korrespondanseskole': ('korrespondanseskole',),
'korrespondanseskolen': ('korrespondanseskole',),
'korrespondanseskolene': ('korrespondanseskole',),
'korrespondanseskoler': ('korrespondanseskole',),
'korrespondent': ('korrespondent',),
'korrespondenten': ('korrespondent',),
'korrespondentene': ('korrespondent',),
'korrespondenter': ('korrespondent',),
'korridor': ('korridor',),
'korridoren': ('korridor',),
'korridorene': ('korridor',),
'korridorer': ('korridor',),
'korridorpolitikk': ('korridorpolitikk',),
'korridorpolitikken': ('korridorpolitikk',),
'korridorpolitikkene': ('korridorpolitikk',),
'korridorpolitikker': ('korridorpolitikk',),
'korrosjon': ('korrosjon',),
'korrosjonen': ('korrosjon',),
'korrosjonene': ('korrosjon',),
'korrosjoner': ('korrosjon',),
'korrupsjon': ('korrupsjon',),
'korrupsjonen': ('korrupsjon',),
'korrupsjonene': ('korrupsjon',),
'korrupsjoner': ('korrupsjon',),
'kors': ('kors',),
'korsa': ('kors',),
'korsene': ('kors',),
'korset': ('kors',),
'korsang': ('korsang',),
'korsangen': ('korsang',),
'korsangene': ('korsang',),
'korsanger': ('korsang',),
'korsar': ('korsar',),
'korsaren': ('korsar',),
'korsarene': ('korsar',),
'korsarer': ('korsar',),
'korsats': ('korsats',),
'korsatsen': ('korsats',),
'korsatsene': ('korsats',),
'korsatser': ('korsats',),
'korsband': ('korsband',),
'korsbanda': ('korsband',),
'korsbandene': ('korsband',),
'korsbandet': ('korsband',),
'korsbein': ('korsbein',),
'korsbeina': ('korsbein',),
'korsbeinene': ('korsbein',),
'korsbeinet': ('korsbein',),
'korsben': ('korsben',),
'korsbena': ('korsben',),
'korsbenene': ('korsben',),
'korsbenet': ('korsben',),
'korsblom': ('korsblom',),
'korsblommen': ('korsblom',),
'korsblommene': ('korsblom',),
'korsblommer': ('korsblom',),
'korsblomst': ('korsblomst',),
'korsblomsten': ('korsblomst',),
'korsblomstene': ('korsblomst',),
'korsblomster': ('korsblomst',),
'korsblomstfamilie': ('korsblomstfamilie',),
'korsblomstfamilien': ('korsblomstfamilie',),
'korsblomstfamiliene': ('korsblomstfamilie',),
'korsblomstfamilier': ('korsblomstfamilie',),
'korsbånd': ('korsbånd',),
'korsbånda': ('korsbånd',),
'korsbåndene': ('korsbånd',),
'korsbåndet': ('korsbånd',),
'korsedderkopp': ('korsedderkopp',),
'korsedderkoppen': ('korsedderkopp',),
'korsedderkoppene': ('korsedderkopp',),
'korsedderkopper': ('korsedderkopp',),
'korselett': ('korselett',),
'korseletta': ('korselett',),
'korselettene': ('korselett',),
'korseletter': ('korselett',),
'korselettet': ('korselett',),
'korsett': ('korsett',),
'korsetta': ('korsett',),
'korsettene': ('korsett',),
'korsetter': ('korsett',),
'korsettet': ('korsett',),
'korsfarer': ('korsfarer',),
'korsfarere': ('korsfarer',),
'korsfareren': ('korsfarer',),
'korsfarerer': ('korsfarer',),
'korsfarerne': ('korsfarer',),
'korsfestelse': ('korsfestelse',),
'korsfestelsen': ('korsfestelse',),
'korsfestelsene': ('korsfestelse',),
'korsfestelser': ('korsfestelse',),
'korsfesting': ('korsfesting',),
'korsfestinga': ('korsfesting',),
'korsfestingen': ('korsfesting',),
'korsfestingene': ('korsfesting',),
'korsfestinger': ('korsfesting',),
'korsikaner': ('korsikaner',),
'korsikanere': ('korsikaner',),
'korsikaneren': ('korsikaner',),
'korsikanerer': ('korsikaner',),
'korsikanerne': ('korsikaner',),
'korskirka': ('korskirke',),
'korskirke': ('korskirke',),
'korskirken': ('korskirke',),
'korskirkene': ('korskirke',),
'korskirker': ('korskirke',),
'korskjerka': ('korskjerke',),
'korskjerke': ('korskjerke',),
'korskjerken': ('korskjerke',),
'korskjerkene': ('korskjerke',),
'korskjerker': ('korskjerke',),
'korsmerka': ('korsmerke',),
'korsmerke': ('korsmerke',),
'korsmerkene': ('korsmerke',),
'korsmerker': ('korsmerke',),
'korsmerket': ('korsmerke',),
'korsmess': ('korsmess',),
'korsmesse': ('korsmesse',),
'korsnebb': ('korsnebb',),
'korsnebben': ('korsnebb',),
'korsnebbene': ('korsnebb',),
'korsnebber': ('korsnebb',),
'korsrev': ('korsrev',),
'korsreven': ('korsrev',),
'korsrevene': ('korsrev',),
'korsrever': ('korsrev',),
'korsrygg': ('korsrygg',),
'korsryggen': ('korsrygg',),
'korsryggene': ('korsrygg',),
'korsrygger': ('korsrygg',),
'korssting': ('korssting',),
'korsstinga': ('korssting',),
'korsstingene': ('korssting',),
'korsstinget': ('korssting',),
'korstegn': ('korstegn',),
'korstegna': ('korstegn',),
'korstegnene': ('korstegn',),
'korstegnet': ('korstegn',),
'korstog': ('korstog',),
'korstoga': ('korstog',),
'korstogene': ('korstog',),
'korstoget': ('korstog',),
'korstroll': ('korstroll',),
'korstrolla': ('korstroll',),
'korstrollene': ('korstroll',),
'korstrollet': ('korstroll',),
'korsveg': ('korsveg',),
'korsvegen': ('korsveg',),
'korsvegene': ('korsveg',),
'korsveger': ('korsveg',),
'korsvei': ('korsvei',),
'korsveien': ('korsvei',),
'korsveiene': ('korsvei',),
'korsveier': ('korsvei',),
'kort': ('kort',),
'korta': ('kort',),
'kortene': ('kort',),
'kortet': ('kort',),
'kortbane': ('kortbane',),
'kortbanen': ('kortbane',),
'kortbanene': ('kortbane',),
'kortbaner': ('kortbane',),
'kortbaneflyplass': ('kortbaneflyplass',),
'kortbaneflyplassen': ('kortbaneflyplass',),
'kortbaneflyplassene': ('kortbaneflyplass',),
'kortbaneflyplasser': ('kortbaneflyplass',),
'kortblad': ('kortblad',),
'kortblada': ('kortblad',),
'kortbladene': ('kortblad',),
'kortblader': ('kortblad',),
'kortbladet': ('kortblad',),
'kortbuksa': ('kortbukse',),
'kortbukse': ('kortbukse',),
'kortbuksen': ('kortbukse',),
'kortbuksene': ('kortbukse',),
'kortbukser': ('kortbukse',),
'kortbølga': ('kortbølge',),
'kortbølge': ('kortbølge',),
'kortbølgen': ('kortbølge',),
'kortbølgene': ('kortbølge',),
'kortbølger': ('kortbølge',),
'kortbølgebehandling': ('kortbølgebehandling',),
'kortbølgebehandlinga': ('kortbølgebehandling',),
'kortbølgebehandlingen': ('kortbølgebehandling',),
'kortbølgebehandlingene': ('kortbølgebehandling',),
'kortbølgebehandlinger': ('kortbølgebehandling',),
'kortbølgja': ('kortbølgje',),
'kortbølgje': ('kortbølgje',),
'kortbølgjen': ('kortbølgje',),
'kortbølgjene': ('kortbølgje',),
'kortbølgjer': ('kortbølgje',),
'kortbølgjebehandling': ('kortbølgjebehandling',),
'kortbølgjebehandlinga': ('kortbølgjebehandling',),
'kortbølgjebehandlingen': ('kortbølgjebehandling',),
'kortbølgjebehandlingene': ('kortbølgjebehandling',),
'kortbølgjebehandlinger': ('kortbølgjebehandling',),
'kortdistanse': ('kortdistanse',),
'kortdistansen': ('kortdistanse',),
'kortdistansene': ('kortdistanse',),
'kortdistanser': ('kortdistanse',),
'kortdistansefly': ('kortdistansefly',),
'kortdistanseflya': ('kortdistansefly',),
'kortdistanseflyene': ('kortdistansefly',),
'kortdistanseflyet': ('kortdistansefly',),
'kortesje': ('kortesje',),
'kortesjen': ('kortesje',),
'kortesjene': ('kortesje',),
'kortesjer': ('kortesje',),
'kortevara': ('kortevare',),
'kortevare': ('kortevare',),
'kortevaren': ('kortevare',),
'kortevarene': ('kortevare',),
'kortevarer': ('kortevare',),
'kortfilm': ('kortfilm',),
'kortfilmen': ('kortfilm',),
'kortfilmene': ('kortfilm',),
'kortfilmer': ('kortfilm',),
'kortform': ('kortform',),
'kortforma': ('kortform',),
'kortformen': ('kortform',),
'kortformene': ('kortform',),
'kortformer': ('kortform',),
'korthekk': ('korthekk',),
'korthekken': ('korthekk',),
'korthekkene': ('korthekk',),
'korthekker': ('korthekk',),
'korthet': ('korthet',),
'kortheta': ('korthet',),
'kortheten': ('korthet',),
'korthetene': ('korthet',),
'kortheter': ('korthet',),
'korthus': ('korthus',),
'korthusa': ('korthus',),
'korthusene': ('korthus',),
'korthuset': ('korthus',),
'kortison': ('kortison',),
'kortisona': ('kortison',),
'kortisonene': ('kortison',),
'kortisonet': ('kortison',),
'kortkunst': ('kortkunst',),
'kortkunsten': ('kortkunst',),
'kortkunstene': ('kortkunst',),
'kortkunster': ('kortkunst',),
'kortlag': ('kortlag',),
'kortlaga': ('kortlag',),
'kortlagene': ('kortlag',),
'kortlaget': ('kortlag',),
'kortleik': ('kortleik',),
'kortleiken': ('kortleik',),
'kortleikene': ('kortleik',),
'kortleiker': ('kortleik',),
'kortleser': ('kortleser',),
'kortlesere': ('kortleser',),
'kortleseren': ('kortleser',),
'kortleserer': ('kortleser',),
'kortleserne': ('kortleser',),
'kortord': ('kortord',),
'kortorda': ('kortord',),
'kortordene': ('kortord',),
'kortordet': ('kortord',),
'kortprosa': ('kortprosa',),
'kortprosaen': ('kortprosa',),
'kortprosaene': ('kortprosa',),
'kortprosaer': ('kortprosa',),
'kortskalle': ('kortskalle',),
'kortskallen': ('kortskalle',),
'kortskallene': ('kortskalle',),
'kortskaller': ('kortskalle',),
'kortskott': ('kortskott',),
'kortskotta': ('kortskott',),
'kortskottene': ('kortskott',),
'kortskottet': ('kortskott',),
'kortskudd': ('kortskudd',),
'kortskudda': ('kortskudd',),
'kortskuddene': ('kortskudd',),
'kortskuddet': ('kortskudd',),
'kortslutning': ('kortslutning',),
'kortslutninga': ('kortslutning',),
'kortslutningen': ('kortslutning',),
'kortslutningene': ('kortslutning',),
'kortslutninger': ('kortslutning',),
'kortspell': ('kortspell',),
'kortspella': ('kortspell',),
'kortspellene': ('kortspell',),
'kortspellet': ('kortspell',),
'kortspill': ('kortspill',),
'kortspilla': ('kortspill',),
'kortspillene': ('kortspill',),
'kortspillet': ('kortspill',),
'kortstokk': ('kortstokk',),
'kortstokken': ('kortstokk',),
'kortstokkene': ('kortstokk',),
'kortstokker': ('kortstokk',),
'korttidsforsikring': ('korttidsforsikring',),
'korttidsforsikringa': ('korttidsforsikring',),
'korttidsforsikringen': ('korttidsforsikring',),
'korttidsforsikringene': ('korttidsforsikring',),
'korttidsforsikringer': ('korttidsforsikring',),
'korttrøya': ('korttrøye',),
'korttrøye': ('korttrøye',),
'korttrøyen': ('korttrøye',),
'korttrøyene': ('korttrøye',),
'korttrøyer': ('korttrøye',),
'kortvegg': ('kortvegg',),
'kortveggen': ('kortvegg',),
'kortveggene': ('kortvegg',),
'kortvegger': ('kortvegg',),
'koruna': ('koruna',),
'korunaen': ('koruna',),
'korunaene': ('koruna',),
'korund': ('korund',),
'korunden': ('korund',),
'korundene': ('korund',),
'korunder': ('korund',),
'korverk': ('korverk',),
'korverka': ('korverk',),
'korverkene': ('korverk',),
'korverker': ('korverk',),
'korverket': ('korverk',),
'korvett': ('korvett',),
'korvetten': ('korvett',),
'korvettene': ('korvett',),
'korvetter': ('korvett',),
'koryfe': ('koryfe',),
'koryfeen': ('koryfe',),
'koryfeene': ('koryfe',),
'koryfeer': ('koryfe',),
'kos': ('kos',),
'kosen': ('kos',),
'kosene': ('kos',),
'koser': ('kos',),
'kos': ('kos',),
'kosen': ('kos',),
'kosene': ('kos',),
'koser': ('kos',),
'kosakk': ('kosakk',),
'kosakken': ('kosakk',),
'kosakkene': ('kosakk',),
'kosakker': ('kosakk',),
'kosakkdans': ('kosakkdans',),
'kosakkdansen': ('kosakkdans',),
'kosakkdansene': ('kosakkdans',),
'kosakkdanser': ('kosakkdans',),
'kosakksamfunn': ('kosakksamfunn',),
'kosakksamfunna': ('kosakksamfunn',),
'kosakksamfunnene': ('kosakksamfunn',),
'kosakksamfunnet': ('kosakksamfunn',),
'kosedyr': ('kosedyr',),
'kosedyra': ('kosedyr',),
'kosedyrene': ('kosedyr',),
'kosedyret': ('kosedyr',),
'kosestund': ('kosestund',),
'kosestunda': ('kosestund',),
'kosestunden': ('kosestund',),
'kosestundene': ('kosestund',),
'kosestunder': ('kosestund',),
'koseunge': ('koseunge',),
'koseungen': ('koseunge',),
'koseungene': ('koseunge',),
'koseunger': ('koseunge',),
'kosmetiker': ('kosmetiker',),
'kosmetikere': ('kosmetiker',),
'kosmetikeren': ('kosmetiker',),
'kosmetikerer': ('kosmetiker',),
'kosmetikerne': ('kosmetiker',),
'kosmetikk': ('kosmetikk',),
'kosmetikken': ('kosmetikk',),
'kosmetikkene': ('kosmetikk',),
'kosmetikker': ('kosmetikk',),
'kosmetika': ('kosmetikum',),
'kosmetikaene': ('kosmetikum',),
'kosmetikum': ('kosmetikum',),
'kosmetikumet': ('kosmetikum',),
'kosmetolog': ('kosmetolog',),
'kosmetologen': ('kosmetolog',),
'kosmetologene': ('kosmetolog',),
'kosmetologer': ('kosmetolog',),
'kosmodrom': ('kosmodrom',),
'kosmodromen': ('kosmodrom',),
'kosmodromene': ('kosmodrom',),
'kosmodromer': ('kosmodrom',),
'kosmogoni': ('kosmogoni',),
'kosmogonien': ('kosmogoni',),
'kosmogoniene': ('kosmogoni',),
'kosmogonier': ('kosmogoni',),
'kosmologi': ('kosmologi',),
'kosmologien': ('kosmologi',),
'kosmologiene': ('kosmologi',),
'kosmologier': ('kosmologi',),
'kosmonaut': ('kosmonaut',),
'kosmonauten': ('kosmonaut',),
'kosmonautene': ('kosmonaut',),
'kosmonauter': ('kosmonaut',),
'kosmopolitisme': ('kosmopolitisme',),
'kosmopolitismen': ('kosmopolitisme',),
'kosmopolitismene': ('kosmopolitisme',),
'kosmopolitismer': ('kosmopolitisme',),
'kosmopolitt': ('kosmopolitt',),
'kosmopolitten': ('kosmopolitt',),
'kosmopolittene': ('kosmopolitt',),
'kosmopolitter': ('kosmopolitt',),
'kosmos': ('kosmos',),
'kosmosa': ('kosmos',),
'kosmosene': ('kosmos',),
'kosmoset': ('kosmos',),
'koss': ('koss',),
'kossa': ('koss',),
'kossen': ('koss',),
'kossene': ('koss',),
'kosser': ('koss',),
'kosset': ('koss',),
'kost': ('kost',),
'kosta': ('kost',),
'kostene': ('kost',),
'kostet': ('kost',),
'kost': ('kost',),
'kostarikaner': ('kostarikaner',),
'kostarikanere': ('kostarikaner',),
'kostarikaneren': ('kostarikaner',),
'kostarikanerer': ('kostarikaner',),
'kostarikanerne': ('kostarikaner',),
'kostbarhet': ('kostbarhet',),
'kostbarheta': ('kostbarhet',),
'kostbarheten': ('kostbarhet',),
'kostbarhetene': ('kostbarhet',),
'kostbarheter': ('kostbarhet',),
'kostdøgn': ('kostdøgn',),
'kostdøgna': ('kostdøgn',),
'kostdøgnene': ('kostdøgn',),
'kostdøgnet': ('kostdøgn',),
'kostebinderi': ('kostebinderi',),
'kostebinderia': ('kostebinderi',),
'kostebinderiene': ('kostebinderi',),
'kostebinderier': ('kostebinderi',),
'kostebinderiet': ('kostebinderi',),
'kostenda': ('kostende',),
'kostende': ('kostende',),
'kostendene': ('kostende',),
'kostender': ('kostende',),
'kostendet': ('kostende',),
'kosterbåt': ('kosterbåt',),
'kosterbåten': ('kosterbåt',),
'kosterbåtene': ('kosterbåt',),
'kosterbåter': ('kosterbåt',),
'kostforakter': ('kostforakter',),
'kostforaktere': ('kostforakter',),
'kostforakteren': ('kostforakter',),
'kostforakterer': ('kostforakter',),
'kostforakterne': ('kostforakter',),
'kostgodtgjørelse': ('kostgodtgjørelse',),
'kostgodtgjørelsen': ('kostgodtgjørelse',),
'kostgodtgjørelsene': ('kostgodtgjørelse',),
'kostgodtgjørelser': ('kostgodtgjørelse',),
'kostgodtgjøring': ('kostgodtgjøring',),
'kostgodtgjøringa': ('kostgodtgjøring',),
'kostgodtgjøringen': ('kostgodtgjøring',),
'kostgodtgjøringene': ('kostgodtgjøring',),
'kostgodtgjøringer': ('kostgodtgjøring',),
'kosthold': ('kosthold',),
'kostholda': ('kosthold',),
'kostholdene': ('kosthold',),
'kostholdet': ('kosthold',),
'kostholdsøkonom': ('kostholdsøkonom',),
'kostholdsøkonomen': ('kostholdsøkonom',),
'kostholdsøkonomene': ('kostholdsøkonom',),
'kostholdsøkonomer': ('kostholdsøkonom',),
'kostnad': ('kostnad',),
'kostnaden': ('kostnad',),
'kostnadene': ('kostnad',),
'kostnader': ('kostnad',),
'kostnadsoverslag': ('kostnadsoverslag',),
'kostnadsoverslaga': ('kostnadsoverslag',),
'kostnadsoverslagene': ('kostnadsoverslag',),
'kostnadsoverslaget': ('kostnadsoverslag',),
'kostnadsøkning': ('kostnadsøkning',),
'kostnadsøkninga': ('kostnadsøkning',),
'kostnadsøkningen': ('kostnadsøkning',),
'kostnadsøkningene': ('kostnadsøkning',),
'kostnadsøkninger': ('kostnadsøkning',),
'kostpengene': ('kostpenger',),
'kostpenger': ('kostpenger',),
'kostpris': ('kostpris',),
'kostprisen': ('kostpris',),
'kostprisene': ('kostpris',),
'kostpriser': ('kostpris',),
'kostregulativ': ('kostregulativ',),
'kostregulativa': ('kostregulativ',),
'kostregulativene': ('kostregulativ',),
'kostregulativer': ('kostregulativ',),
'kostregulativet': ('kostregulativ',),
'kostskole': ('kostskole',),
'kostskolen': ('kostskole',),
'kostskolene': ('kostskole',),
'kostskoler': ('kostskole',),
'kostyma': ('kostyme',),
'kostyme': ('kostyme',),
'kostymene': ('kostyme',),
'kostymer': ('kostyme',),
'kostymet': ('kostyme',),
'kostymeball': ('kostymeball',),
'kostymeballa': ('kostymeball',),
'kostymeballene': ('kostymeball',),
'kostymeballer': ('kostymeball',),
'kostymeballet': ('kostymeball',),
'kostymeprøva': ('kostymeprøve',),
'kostymeprøve': ('kostymeprøve',),
'kostymeprøven': ('kostymeprøve',),
'kostymeprøvene': ('kostymeprøve',),
'kostymeprøver': ('kostymeprøve',),
'kostøra': ('kostøre',),
'kostøre': ('kostøre',),
'kostørene': ('kostøre',),
'kostører': ('kostøre',),
'kostøret': ('kostøre',),
'kot': ('kot',),
'koten': ('kot',),
'kotene': ('kot',),
'koter': ('kot',),
'kote': ('kote',),
'koten': ('kote',),
'kotene': ('kote',),
'koter': ('kote',),
'kota': ('kote',),
'kote': ('kote',),
'koten': ('kote',),
'kotene': ('kote',),
'koter': ('kote',),
'kotelett': ('kotelett',),
'koteletten': ('kotelett',),
'kotelettene': ('kotelett',),
'koteletter': ('kotelett',),
'koteri': ('koteri',),
'koteria': ('koteri',),
'koteriene': ('koteri',),
'koterier': ('koteri',),
'koteriet': ('koteri',),
'kotiljong': ('kotiljong',),
'kotiljongen': ('kotiljong',),
'kotiljongene': ('kotiljong',),
'kotiljonger': ('kotiljong',),
'kotkar': ('kotkar',),
'kotkaren': ('kotkar',),
'kotkarene': ('kotkar',),
'kotkarer': ('kotkar',),
'kott': ('kott',),
'kotta': ('kott',),
'kottene': ('kott',),
'kottet': ('kott',),
'koturne': ('koturne',),
'koturnen': ('koturne',),
'koturnene': ('koturne',),
'koturner': ('koturne',),
'kov': ('kov',),
'kova': ('kov',),
'kovene': ('kov',),
'kovet': ('kov',),
'kovbakke': ('kovbakke',),
'kovbakken': ('kovbakke',),
'kovbakkene': ('kovbakke',),
'kovbakker': ('kovbakke',),
'kove': ('kove',),
'koven': ('kove',),
'kovene': ('kove',),
'kover': ('kove',),
'kra': ('kra',),
'kraa': ('kra',),
'kraene': ('kra',),
'kraet': ('kra',),
'kraal': ('kraal',),
'kraalen': ('kraal',),
'kraalene': ('kraal',),
'kraaler': ('kraal',),
'krabat': ('krabat',),
'krabaten': ('krabat',),
'krabatene': ('krabat',),
'krabater': ('krabat',),
'krabba': ('krabbe',),
'krabbe': ('krabbe',),
'krabben': ('krabbe',),
'krabbene': ('krabbe',),
'krabber': ('krabbe',),
'krabbefelt': ('krabbefelt',),
'krabbefelta': ('krabbefelt',),
'krabbefeltene': ('krabbefelt',),
'krabbefelter': ('krabbefelt',),
'krabbefeltet': ('krabbefelt',),
'krabbegang': ('krabbegang',),
'krabbegangen': ('krabbegang',),
'krabbegangene': ('krabbegang',),
'krabbeganger': ('krabbegang',),
'krabbegir': ('krabbegir',),
'krabbegira': ('krabbegir',),
'krabbegirene': ('krabbegir',),
'krabbegiret': ('krabbegir',),
'krabbeklo': ('krabbeklo',),
'krabbekloa': ('krabbeklo',),
'krabbekloen': ('krabbeklo',),
'krabbeklør': ('krabbeklo',),
'krabbeklørne': ('krabbeklo',),
'krafs': ('krafs',),
'krafsa': ('krafs',),
'krafsene': ('krafs',),
'krafset': ('krafs',),
'krafsa': ('krafse',),
'krafse': ('krafse',),
'krafsen': ('krafse',),
'krafsene': ('krafse',),
'krafser': ('krafse',),
'krafsebrett': ('krafsebrett',),
'krafsebretta': ('krafsebrett',),
'krafsebrettene': ('krafsebrett',),
'krafsebretter': ('krafsebrett',),
'krafsebrettet': ('krafsebrett',),
'kraft': ('kraft',),
'krafta': ('kraft',),
'kraften': ('kraft',),
'kreftene': ('kraft',),
'krefter': ('kraft',),
'kraftanstrengelse': ('kraftanstrengelse',),
'kraftanstrengelsen': ('kraftanstrengelse',),
'kraftanstrengelsene': ('kraftanstrengelse',),
'kraftanstrengelser': ('kraftanstrengelse',),
'kraftblokk': ('kraftblokk',),
'kraftblokka': ('kraftblokk',),
'kraftblokken': ('kraftblokk',),
'kraftblokkene': ('kraftblokk',),
'kraftblokker': ('kraftblokk',),
'kraftfelt': ('kraftfelt',),
'kraftfelta': ('kraftfelt',),
'kraftfeltene': ('kraftfelt',),
'kraftfelter': ('kraftfelt',),
'kraftfeltet': ('kraftfelt',),
'kraftgata': ('kraftgate',),
'kraftgate': ('kraftgate',),
'kraftgaten': ('kraftgate',),
'kraftgatene': ('kraftgate',),
'kraftgater': ('kraftgate',),
'kraftkar': ('kraftkar',),
'kraftkaren': ('kraftkar',),
'kraftkarene': ('kraftkar',),
'kraftkarer': ('kraftkar',),
'kraftkilde': ('kraftkilde',),
'kraftkilden': ('kraftkilde',),
'kraftkildene': ('kraftkilde',),
'kraftkilder': ('kraftkilde',),
'kraftkjelda': ('kraftkjelde',),
'kraftkjelde': ('kraftkjelde',),
'kraftkjelden': ('kraftkjelde',),
'kraftkjeldene': ('kraftkjelde',),
'kraftkjelder': ('kraftkjelde',),
'kraftledning': ('kraftledning',),
'kraftledninga': ('kraftledning',),
'kraftledningen': ('kraftledning',),
'kraftledningene': ('kraftledning',),
'kraftledninger': ('kraftledning',),
'kraftledningsgata': ('kraftledningsgate',),
'kraftledningsgate': ('kraftledningsgate',),
'kraftledningsgaten': ('kraftledningsgate',),
'kraftledningsgatene': ('kraftledningsgate',),
'kraftledningsgater': ('kraftledningsgate',),
'kraftlinja': ('kraftlinje',),
'kraftlinje': ('kraftlinje',),
'kraftlinjen': ('kraftlinje',),
'kraftlinjene': ('kraftlinje',),
'kraftlinjer': ('kraftlinje',),
'kraftmåler': ('kraftmåler',),
'kraftmålere': ('kraftmåler',),
'kraftmåleren': ('kraftmåler',),
'kraftmålerer': ('kraftmåler',),
'kraftmålerne': ('kraftmåler',),
'kraftoverføring': ('kraftoverføring',),
'kraftoverføringa': ('kraftoverføring',),
'kraftoverføringen': ('kraftoverføring',),
'kraftoverføringene': ('kraftoverføring',),
'kraftoverføringer': ('kraftoverføring',),
'kraftpapir': ('kraftpapir',),
'kraftpapira': ('kraftpapir',),
'kraftpapirene': ('kraftpapir',),
'kraftpapirer': ('kraftpapir',),
'kraftpapiret': ('kraftpapir',),
'kraftpapp': ('kraftpapp',),
'kraftpappen': ('kraftpapp',),
'kraftpappene': ('kraftpapp',),
'kraftpapper': ('kraftpapp',),
'kraftpatriot': ('kraftpatriot',),
'kraftpatrioten': ('kraftpatriot',),
'kraftpatriotene': ('kraftpatriot',),
'kraftpatrioter': ('kraftpatriot',),
'kraftsats': ('kraftsats',),
'kraftsatsen': ('kraftsats',),
'kraftsatsene': ('kraftsats',),
'kraftsatser': ('kraftsats',),
'kraftstasjon': ('kraftstasjon',),
'kraftstasjonen': ('kraftstasjon',),
'kraftstasjonene': ('kraftstasjon',),
'kraftstasjoner': ('kraftstasjon',),
'kraftstøt': ('kraftstøt',),
'kraftstøta': ('kraftstøt',),
'kraftstøtene': ('kraftstøt',),
'kraftstøtet': ('kraftstøt',),
'krafttak': ('krafttak',),
'krafttaka': ('krafttak',),
'krafttakene': ('krafttak',),
'krafttaket': ('krafttak',),
'kraftutbygging': ('kraftutbygging',),
'kraftutbygginga': ('kraftutbygging',),
'kraftutbyggingen': ('kraftutbygging',),
'kraftutbyggingene': ('kraftutbygging',),
'kraftutbygginger': ('kraftutbygging',),
'kraftuttrykk': ('kraftuttrykk',),
'kraftuttrykka': ('kraftuttrykk',),
'kraftuttrykkene': ('kraftuttrykk',),
'kraftuttrykket': ('kraftuttrykk',),
'kraftverk': ('kraftverk',),
'kraftverka': ('kraftverk',),
'kraftverkene': ('kraftverk',),
'kraftverker': ('kraftverk',),
'kraftverket': ('kraftverk',),
'krag': ('krag',),
'kragen': ('krag',),
'kragene': ('krag',),
'krager': ('krag',),
'krage': ('krage',),
'kragen': ('krage',),
'kragene': ('krage',),
'krager': ('krage',),
'kragebein': ('kragebein',),
'kragebeina': ('kragebein',),
'kragebeinene': ('kragebein',),
'kragebeinet': ('kragebein',),
'krageben': ('krageben',),
'kragebena': ('krageben',),
'kragebenene': ('krageben',),
'kragebenet': ('krageben',),
'kragg': ('kragg',),
'kraggen': ('kragg',),
'kraggene': ('kragg',),
'kragger': ('kragg',),
'krake': ('krake',),
'kraken': ('krake',),
'krakene': ('krake',),
'kraker': ('krake',),
'krake': ('krake',),
'kraken': ('krake',),
'krakene': ('krake',),
'kraker': ('krake',),
'krake': ('krake',),
'kraken': ('krake',),
'krakene': ('krake',),
'kraker': ('krake',),
'krake': ('krake',),
'kraken': ('krake',),
'krakene': ('krake',),
'kraker': ('krake',),
'krakk': ('krakk',),
'krakken': ('krakk',),
'krakkene': ('krakk',),
'krakker': ('krakk',),
'krakk': ('krakk',),
'krakken': ('krakk',),
'krakkene': ('krakk',),
'krakker': ('krakk',),
'krakk': ('krakk',),
'krakka': ('krakk',),
'krakkene': ('krakk',),
'krakket': ('krakk',),
'krakker': ('krakker',),
'krakkere': ('krakker',),
'krakkeren': ('krakker',),
'krakkerer': ('krakker',),
'krakkerne': ('krakker',),
'krakkmandel': ('krakkmandel',),
'krakkmandelen': ('krakkmandel',),
'krakkmandlene': ('krakkmandel',),
'krakkmandler': ('krakkmandel',),
'kral': ('kral',),
'kralen': ('kral',),
'kralene': ('kral',),
'kraler': ('kral',),
'kram': ('kram',),
'kramma': ('kram',),
'krammene': ('kram',),
'krammet': ('kram',),
'krambu': ('krambu',),
'krambua': ('krambu',),
'krambuen': ('krambu',),
'krambuene': ('krambu',),
'krambuer': ('krambu',),
'kramkar': ('kramkar',),
'kramkaren': ('kramkar',),
'kramkarene': ('kramkar',),
'kramkarer': ('kramkar',),
'krampe': ('krampe',),
'krampen': ('krampe',),
'krampene': ('krampe',),
'kramper': ('krampe',),
'krampe': ('krampe',),
'krampen': ('krampe',),
'krampene': ('krampe',),
'kramper': ('krampe',),
'krampeanfall': ('krampeanfall',),
'krampeanfalla': ('krampeanfall',),
'krampeanfallene': ('krampeanfall',),
'krampeanfallet': ('krampeanfall',),
'krampegråt': ('krampegråt',),
'krampegråten': ('krampegråt',),
'krampegråtene': ('krampegråt',),
'krampegråter': ('krampegråt',),
'krampelatrene': ('krampelatter',),
'krampelatrer': ('krampelatter',),
'krampelatter': ('krampelatter',),
'krampelattere': ('krampelatter',),
'krampelatteren': ('krampelatter',),
'krampelatterer': ('krampelatter',),
'krampelatterne': ('krampelatter',),
'krampetrekning': ('krampetrekning',),
'krampetrekninga': ('krampetrekning',),
'krampetrekningen': ('krampetrekning',),
'krampetrekningene': ('krampetrekning',),
'krampetrekninger': ('krampetrekning',),
'krampong': ('krampong',),
'krampongen': ('krampong',),
'krampongene': ('krampong',),
'kramponger': ('krampong',),
'kramsfugl': ('kramsfugl',),
'kramsfuglen': ('kramsfugl',),
'kramsfuglene': ('kramsfugl',),
'kramsfugler': ('kramsfugl',),
'kran': ('kran',),
'krana': ('kran',),
'kranen': ('kran',),
'kranene': ('kran',),
'kraner': ('kran',),
'kranarm': ('kranarm',),
'kranarmen': ('kranarm',),
'kranarmene': ('kranarm',),
'kranarmer': ('kranarm',),
'kranbil': ('kranbil',),
'kranbilen': ('kranbil',),
'kranbilene': ('kranbil',),
'kranbiler': ('kranbil',),
'krane': ('krane',),
'kranen': ('krane',),
'kranene': ('krane',),
'kraner': ('krane',),
'kranfører': ('kranfører',),
'kranførere': ('kranfører',),
'kranføreren': ('kranfører',),
'kranførerer': ('kranfører',),
'kranførerne': ('kranfører',),
'krangel': ('krangel',),
'krangelen': ('krangel',),
'kranglene': ('krangel',),
'krangler': ('krangel',),
'krangel': ('krangel',),
'krangelet': ('krangel',),
'krangla': ('krangel',),
'kranglene': ('krangel',),
'krangler': ('krangel',),
'kranglet': ('krangel',),
'kranglefant': ('kranglefant',),
'kranglefanten': ('kranglefant',),
'kranglefantene': ('kranglefant',),
'kranglefanter': ('kranglefant',),
'kraniebrott': ('kraniebrott',),
'kraniebrotta': ('kraniebrott',),
'kraniebrottene': ('kraniebrott',),
'kraniebrottet': ('kraniebrott',),
'kraniebrudd': ('kraniebrudd',),
'kraniebrudda': ('kraniebrudd',),
'kraniebruddene': ('kraniebrudd',),
'kraniebruddet': ('kraniebrudd',),
'krania': ('kranium',),
'kraniene': ('kranium',),
'kranier': ('kranium',),
'kraniet': ('kranium',),
'kranium': ('kranium',),
'krank': ('krank',),
'kranken': ('krank',),
'krankene': ('krank',),
'kranker': ('krank',),
'krans': ('krans',),
'kransen': ('krans',),
'kransene': ('krans',),
'kranser': ('krans',),
'kransekaka': ('kransekake',),
'kransekake': ('kransekake',),
'kransekaken': ('kransekake',),
'kransekakene': ('kransekake',),
'kransekaker': ('kransekake',),
'kranselag': ('kranselag',),
'kranselaga': ('kranselag',),
'kranselagene': ('kranselag',),
'kranselaget': ('kranselag',),
'kransepålegging': ('kransepålegging',),
'kransepålegginga': ('kransepålegging',),
'kransepåleggingen': ('kransepålegging',),
'kransepåleggingene': ('kransepålegging',),
'kransepålegginger': ('kransepålegging',),
'kranseskål': ('kranseskål',),
'kranseskålen': ('kranseskål',),
'kranseskålene': ('kranseskål',),
'kranseskåler': ('kranseskål',),
'kranskonvall': ('kranskonvall',),
'kranskonvallen': ('kranskonvall',),
'kranskonvallene': ('kranskonvall',),
'kranskonvaller': ('kranskonvall',),
'kranslilja': ('kranslilje',),
'kranslilje': ('kranslilje',),
'kransliljen': ('kranslilje',),
'kransliljene': ('kranslilje',),
'kransliljer': ('kranslilje',),
'krapyl': ('krapyl',),
'krapyla': ('krapyl',),
'krapylene': ('krapyl',),
'krapylet': ('krapyl',),
'kras': ('kras',),
'krasa': ('kras',),
'krasene': ('kras',),
'kraset': ('kras',),
'krasj': ('krasj',),
'krasja': ('krasj',),
'krasjen': ('krasj',),
'krasjene': ('krasj',),
'krasjet': ('krasj',),
'krasl': ('krasl',),
'krasla': ('krasl',),
'kraslene': ('krasl',),
'kraslet': ('krasl',),
'krater': ('krater',),
'krateret': ('krater',),
'kratra': ('krater',),
'kratre': ('krater',),
'kratrene': ('krater',),
'kratret': ('krater',),
'kratt': ('kratt',),
'kratta': ('kratt',),
'krattene': ('kratt',),
'krattet': ('kratt',),
'krattskog': ('krattskog',),
'krattskogen': ('krattskog',),
'krattskogene': ('krattskog',),
'krattskoger': ('krattskog',),
'krav': ('krav',),
'krava': ('krav',),
'kravene': ('krav',),
'kravet': ('krav',),
'krav': ('krav',),
'krava': ('krav',),
'kravene': ('krav',),
'kravet': ('krav',),
'kravbrev': ('kravbrev',),
'kravbreva': ('kravbrev',),
'kravbrevene': ('kravbrev',),
'kravbrever': ('kravbrev',),
'kravbrevet': ('kravbrev',),
'krave': ('krave',),
'kraven': ('krave',),
'kravene': ('krave',),
'kraver': ('krave',),
'krave': ('krave',),
'kraven': ('krave',),
'kravene': ('krave',),
'kraver': ('krave',),
'kravebein': ('kravebein',),
'kravebeina': ('kravebein',),
'kravebeinene': ('kravebein',),
'kravebeinet': ('kravebein',),
'kraveben': ('kraveben',),
'kravebena': ('kraveben',),
'kravebenene': ('kraveben',),
'kravebenet': ('kraveben',),
'kravell': ('kravell',),
'kravellen': ('kravell',),
'kravellene': ('kravell',),
'kraveller': ('kravell',),
'kravell': ('kravell',),
'kravellen': ('kravell',),
'kravellene': ('kravell',),
'kraveller': ('kravell',),
'kravis': ('kravis',),
'kravisen': ('kravis',),
'kravisene': ('kravis',),
'kraviser': ('kravis',),
'kravl': ('kravl',),
'kravla': ('kravl',),
'kravlene': ('kravl',),
'kravlet': ('kravl',),
'kravmentalitet': ('kravmentalitet',),
'kravmentaliteten': ('kravmentalitet',),
'kravmentalitetene': ('kravmentalitet',),
'kravmentaliteter': ('kravmentalitet',),
'kre': ('kre',),
'krea': ('kre',),
'kreene': ('kre',),
'kreet': ('kre',),
'kreasjon': ('kreasjon',),
'kreasjonen': ('kreasjon',),
'kreasjonene': ('kreasjon',),
'kreasjoner': ('kreasjon',),
'kreativitet': ('kreativitet',),
'kreativiteten': ('kreativitet',),
'kreativitetene': ('kreativitet',),
'kreativiteter': ('kreativitet',),
'kreatur': ('kreatur',),
'kreatura': ('kreatur',),
'kreaturene': ('kreatur',),
'kreaturer': ('kreatur',),
'kreaturet': ('kreatur',),
'kreatør': ('kreatør',),
'kreatøren': ('kreatør',),
'kreatørene': ('kreatør',),
'kreatører': ('kreatør',),
'kredit': ('kredit',),
'krediten': ('kredit',),
'kreditene': ('kredit',),
'krediter': ('kredit',),
'kreditiv': ('kreditiv',),
'kreditiva': ('kreditiv',),
'kreditivene': ('kreditiv',),
'kreditiver': ('kreditiv',),
'kreditivet': ('kreditiv',),
'kreditnota': ('kreditnota',),
'kreditnotaen': ('kreditnota',),
'kreditnotaene': ('kreditnota',),
'kreditnotaer': ('kreditnota',),
'kreditor': ('kreditor',),
'kreditoren': ('kreditor',),
'kreditorene': ('kreditor',),
'kreditorer': ('kreditor',),
'kreditsida': ('kreditside',),
'kreditside': ('kreditside',),
'kreditsiden': ('kreditside',),
'kreditsidene': ('kreditside',),
'kreditsider': ('kreditside',),
'kreditt': ('kreditt',),
'kreditten': ('kreditt',),
'kredittene': ('kreditt',),
'kreditter': ('kreditt',),
'kredittbank': ('kredittbank',),
'kredittbanken': ('kredittbank',),
'kredittbankene': ('kredittbank',),
'kredittbanker': ('kredittbank',),
'kredittforening': ('kredittforening',),
'kredittforeninga': ('kredittforening',),
'kredittforeningen': ('kredittforening',),
'kredittforeningene': ('kredittforening',),
'kredittforeninger': ('kredittforening',),
'kredittinstitusjon': ('kredittinstitusjon',),
'kredittinstitusjonen': ('kredittinstitusjon',),
'kredittinstitusjonene': ('kredittinstitusjon',),
'kredittinstitusjoner': ('kredittinstitusjon',),
'kredittkort': ('kredittkort',),
'kredittkorta': ('kredittkort',),
'kredittkortene': ('kredittkort',),
'kredittkortet': ('kredittkort',),
'kredittopplysning': ('kredittopplysning',),
'kredittopplysninga': ('kredittopplysning',),
'kredittopplysningen': ('kredittopplysning',),
'kredittopplysningene': ('kredittopplysning',),
'kredittopplysninger': ('kredittopplysning',),
'kredittpolitikk': ('kredittpolitikk',),
'kredittpolitikken': ('kredittpolitikk',),
'kredittpolitikkene': ('kredittpolitikk',),
'kredittpolitikker': ('kredittpolitikk',),
'kreft': ('kreft',),
'kreften': ('kreft',),
'kreftene': ('kreft',),
'krefter': ('kreft',),
'kreftbyll': ('kreftbyll',),
'kreftbyllen': ('kreftbyll',),
'kreftbyllene': ('kreftbyll',),
'kreftbyller': ('kreftbyll',),
'kreftcella': ('kreftcelle',),
'kreftcelle': ('kreftcelle',),
'kreftcellen': ('kreftcelle',),
'kreftcellene': ('kreftcelle',),
'kreftceller': ('kreftcelle',),
'kreftsvulst': ('kreftsvulst',),
'kreftsvulsten': ('kreftsvulst',),
'kreftsvulstene': ('kreftsvulst',),
'kreftsvulster': ('kreftsvulst',),
'kregda': ('kregde',),
'kregde': ('kregde',),
'kregden': ('kregde',),
'kregdene': ('kregde',),
'kregder': ('kregde',),
'krek': ('krek',),
'kreka': ('krek',),
'krekene': ('krek',),
'kreket': ('krek',),
'krekebær': ('krekebær',),
'krekebæra': ('krekebær',),
'krekebærene': ('krekebær',),
'krekebæret': ('krekebær',),
'krekebær': ('krekebær',),
'krekebæra': ('krekebær',),
'krekebærene': ('krekebær',),
'krekebæret': ('krekebær',),
'krekla': ('krekle',),
'krekle': ('krekle',),
'kreklen': ('krekle',),
'kreklene': ('krekle',),
'krekler': ('krekle',),
'krekling': ('krekling',),
'kreklingen': ('krekling',),
'kreklingene': ('krekling',),
'kreklinger': ('krekling',),
'krel': ('krel',),
'krelen': ('krel',),
'krelene': ('krel',),
'kreler': ('krel',),
'krem': ('krem',),
'kremen': ('krem',),
'kremene': ('krem',),
'kremer': ('krem',),
'kremasjon': ('kremasjon',),
'kremasjonen': ('kremasjon',),
'kremasjonene': ('kremasjon',),
'kremasjoner': ('kremasjon',),
'krematoria': ('krematorium',),
'krematoriene': ('krematorium',),
'krematorier': ('krematorium',),
'krematoriet': ('krematorium',),
'krematorium': ('krematorium',),
'kremfløte': ('kremfløte',),
'kremfløten': ('kremfløte',),
'kremfløtene': ('kremfløte',),
'kremfløter': ('kremfløte',),
'kremfløyte': ('kremfløyte',),
'kremfløyten': ('kremfløyte',),
'kremfløytene': ('kremfløyte',),
'kremfløyter': ('kremfløyte',),
'kremla': ('kremle',),
'kremle': ('kremle',),
'kremlen': ('kremle',),
'kremlene': ('kremle',),
'kremler': ('kremle',),
'kremmer': ('kremmer',),
'kremmere': ('kremmer',),
'kremmeren': ('kremmer',),
'kremmerer': ('kremmer',),
'kremmerne': ('kremmer',),
'kremmerhus': ('kremmerhus',),
'kremmerhusa': ('kremmerhus',),
'kremmerhusene': ('kremmerhus',),
'kremmerhuset': ('kremmerhus',),
'kremmersjel': ('kremmersjel',),
'kremmersjela': ('kremmersjel',),
'kremmersjelen': ('kremmersjel',),
'kremmersjelene': ('kremmersjel',),
'kremmersjeler': ('kremmersjel',),
'kremmerånd': ('kremmerånd',),
'kremmerånden': ('kremmerånd',),
'kremmeråndene': ('kremmerånd',),
'kremmerånder': ('kremmerånd',),
'kremt': ('kremt',),
'kremta': ('kremt',),
'kremten': ('kremt',),
'kremtene': ('kremt',),
'kremtet': ('kremt',),
'kremtopp': ('kremtopp',),
'kremtoppen': ('kremtopp',),
'kremtoppene': ('kremtopp',),
'kremtopper': ('kremtopp',),
'krengning': ('krengning',),
'krengninga': ('krengning',),
'krengningen': ('krengning',),
'krengningene': ('krengning',),
'krengninger': ('krengning',),
'krengningsprøva': ('krengningsprøve',),
'krengningsprøve': ('krengningsprøve',),
'krengningsprøven': ('krengningsprøve',),
'krengningsprøvene': ('krengningsprøve',),
'krengningsprøver': ('krengningsprøve',),
'krengningsstabilisator': ('krengningsstabilisator',),
'krengningsstabilisatoren': ('krengningsstabilisator',),
'krengningsstabilisatorene': ('krengningsstabilisator',),
'krengningsstabilisatorer': ('krengningsstabilisator',),
'krenkelse': ('krenkelse',),
'krenkelsen': ('krenkelse',),
'krenkelsene': ('krenkelse',),
'krenkelser': ('krenkelse',),
'krenking': ('krenking',),
'krenkinga': ('krenking',),
'krenkingen': ('krenking',),
'krenkingene': ('krenking',),
'krenkinger': ('krenking',),
'kreol': ('kreol',),
'kreolen': ('kreol',),
'kreolene': ('kreol',),
'kreoler': ('kreol',),
'kreolin': ('kreolin',),
'kreolina': ('kreolin',),
'kreolinene': ('kreolin',),
'kreolinet': ('kreolin',),
'kreolspråk': ('kreolspråk',),
'kreolspråka': ('kreolspråk',),
'kreolspråkene': ('kreolspråk',),
'kreolspråket': ('kreolspråk',),
'kreosol': ('kreosol',),
'kreosolen': ('kreosol',),
'kreosolene': ('kreosol',),
'kreosoler': ('kreosol',),
'kreosot': ('kreosot',),
'kreosoten': ('kreosot',),
'kreosotene': ('kreosot',),
'kreosoter': ('kreosot',),
'krepp-papir': ('krepp-papir',),
'krepp-papira': ('krepp-papir',),
'krepp-papirene': ('krepp-papir',),
'krepp-papirer': ('krepp-papir',),
'krepp-papiret': ('krepp-papir',),
'kreppapir': ('kreppapir',),
'kreppapira': ('kreppapir',),
'kreppapirene': ('kreppapir',),
'kreppapirer': ('kreppapir',),
'kreppapiret': ('kreppapir',),
'kreppa': ('kreppe',),
'kreppe': ('kreppe',),
'kreppen': ('kreppe',),
'kreppene': ('kreppe',),
'krepper': ('kreppe',),
'kreppgarn': ('kreppgarn',),
'kreppgarna': ('kreppgarn',),
'kreppgarnene': ('kreppgarn',),
'kreppgarnet': ('kreppgarn',),
'kreppnylon': ('kreppnylon',),
'kreppnylona': ('kreppnylon',),
'kreppnylonene': ('kreppnylon',),
'kreppnylonet': ('kreppnylon',),
'kreps': ('kreps',),
'krepsen': ('kreps',),
'krepsene': ('kreps',),
'krepser': ('kreps',),
'krepsdyr': ('krepsdyr',),
'krepsdyra': ('krepsdyr',),
'krepsdyrene': ('krepsdyr',),
'krepsdyret': ('krepsdyr',),
'krepsegang': ('krepsegang',),
'krepsegangen': ('krepsegang',),
'krepsegangene': ('krepsegang',),
'krepseganger': ('krepsegang',),
'krepsepest': ('krepsepest',),
'krepsepesta': ('krepsepest',),
'krepsepesten': ('krepsepest',),
'krepsepestene': ('krepsepest',),
'krepsepester': ('krepsepest',),
'krepser': ('krepser',),
'krepsere': ('krepser',),
'krepseren': ('krepser',),
'krepserer': ('krepser',),
'krepserne': ('krepser',),
'kresol': ('kresol',),
'kresolen': ('kresol',),
'kresolene': ('kresol',),
'kresoler': ('kresol',),
'kreter': ('kreter',),
'kretere': ('kreter',),
'kreteren': ('kreter',),
'kreterer': ('kreter',),
'kreterne': ('kreter',),
'kreti': ('kreti',),
'kretong': ('kretong',),
'kretongen': ('kretong',),
'kretongene': ('kretong',),
'kretonger': ('kretong',),
'krets': ('krets',),
'kretsen': ('krets',),
'kretsene': ('krets',),
'kretser': ('krets',),
'kretsfengsel': ('kretsfengsel',),
'kretsfengselet': ('kretsfengsel',),
'kretsfengsla': ('kretsfengsel',),
'kretsfengslene': ('kretsfengsel',),
'kretsfengsler': ('kretsfengsel',),
'kretsfengslet': ('kretsfengsel',),
'kretsgang': ('kretsgang',),
'kretsgangen': ('kretsgang',),
'kretsgangene': ('kretsgang',),
'kretsganger': ('kretsgang',),
'kretsløp': ('kretsløp',),
'kretsløpa': ('kretsløp',),
'kretsløpene': ('kretsløp',),
'kretsløpet': ('kretsløp',),
'kretsløpsressurs': ('kretsløpsressurs',),
'kretsløpsressursen': ('kretsløpsressurs',),
'kretsløpsressursene': ('kretsløpsressurs',),
'kretsløpsressurser': ('kretsløpsressurs',),
'kretsløpsresurs': ('kretsløpsresurs',),
'kretsløpsresursen': ('kretsløpsresurs',),
'kretsløpsresursene': ('kretsløpsresurs',),
'kretsløpsresurser': ('kretsløpsresurs',),
'kretsmeglingsmann': ('kretsmeglingsmann',),
'kretsmeglingsmannen': ('kretsmeglingsmann',),
'kretsmeglingsmenn': ('kretsmeglingsmann',),
'kretsmeglingsmennene': ('kretsmeglingsmann',),
'kretsmeklingsmann': ('kretsmeklingsmann',),
'kretsmeklingsmannen': ('kretsmeklingsmann',),
'kretsmeklingsmenn': ('kretsmeklingsmann',),
'kretsmeklingsmennene': ('kretsmeklingsmann',),
'kretsmesterskap': ('kretsmesterskap',),
'kretsmesterskapa': ('kretsmesterskap',),
'kretsmesterskapene': ('kretsmesterskap',),
'kretsmesterskaper': ('kretsmesterskap',),
'kretsmesterskapet': ('kretsmesterskap',),
'krig': ('krig',),
'krigen': ('krig',),
'krigene': ('krig',),
'kriger': ('krig',),
'kriger': ('kriger',),
'krigere': ('kriger',),
'krigeren': ('kriger',),
'krigerer': ('kriger',),
'krigerne': ('kriger',),
'krigføring': ('krigføring',),
'krigføringa': ('krigføring',),
'krigføringen': ('krigføring',),
'krigføringene': ('krigføring',),
'krigføringer': ('krigføring',),
'krigsberedskap': ('krigsberedskap',),
'krigsberedskapa': ('krigsberedskap',),
'krigsberedskapen': ('krigsberedskap',),
'krigsberedskapene': ('krigsberedskap',),
'krigsberedskaper': ('krigsberedskap',),
'krigsberedskapet': ('krigsberedskap',),
'krigsbytta': ('krigsbytte',),
'krigsbytte': ('krigsbytte',),
'krigsbyttene': ('krigsbytte',),
'krigsbytter': ('krigsbytte',),
'krigsbyttet': ('krigsbytte',),
'krigsdans': ('krigsdans',),
'krigsdansen': ('krigsdans',),
'krigsdansene': ('krigsdans',),
'krigsdanser': ('krigsdans',),
'krigserklæring': ('krigserklæring',),
'krigserklæringa': ('krigserklæring',),
'krigserklæringen': ('krigserklæring',),
'krigserklæringene': ('krigserklæring',),
'krigserklæringer': ('krigserklæring',),
'krigserstatning': ('krigserstatning',),
'krigserstatninga': ('krigserstatning',),
'krigserstatningen': ('krigserstatning',),
'krigserstatningene': ('krigserstatning',),
'krigserstatninger': ('krigserstatning',),
'krigsfilm': ('krigsfilm',),
'krigsfilmen': ('krigsfilm',),
'krigsfilmene': ('krigsfilm',),
'krigsfilmer': ('krigsfilm',),
'krigsforbrytelse': ('krigsforbrytelse',),
'krigsforbrytelsen': ('krigsforbrytelse',),
'krigsforbrytelsene': ('krigsforbrytelse',),
'krigsforbrytelser': ('krigsforbrytelse',),
'krigsforbryter': ('krigsforbryter',),
'krigsforbrytere': ('krigsforbryter',),
'krigsforbryteren': ('krigsforbryter',),
'krigsforbryterer': ('krigsforbryter',),
'krigsforbryterne': ('krigsforbryter',),
'krigsfot': ('krigsfot',),
'krigsfoten': ('krigsfot',),
'krigsfotene': ('krigsfot',),
'krigsfoter': ('krigsfot',),
'krigsgud': ('krigsgud',),
'krigsguden': ('krigsgud',),
'krigsgudene': ('krigsgud',),
'krigsguder': ('krigsgud',),
'krigsgudinna': ('krigsgudinne',),
'krigsgudinne': ('krigsgudinne',),
'krigsgudinnen': ('krigsgudinne',),
'krigsgudinnene': ('krigsgudinne',),
'krigsgudinner': ('krigsgudinne',),
'krigshandling': ('krigshandling',),
'krigshandlinga': ('krigshandling',),
'krigshandlingen': ('krigshandling',),
'krigshandlingene': ('krigshandling',),
'krigshandlinger': ('krigshandling',),
'krigshelt': ('krigshelt',),
'krigshelten': ('krigshelt',),
'krigsheltene': ('krigshelt',),
'krigshelter': ('krigshelt',),
'krigshisser': ('krigshisser',),
'krigshissere': ('krigshisser',),
'krigshisseren': ('krigshisser',),
'krigshisserer': ('krigshisser',),
'krigshisserne': ('krigshisser',),
'krigshumør': ('krigshumør',),
'krigshumøra': ('krigshumør',),
'krigshumørene': ('krigshumør',),
'krigshumøret': ('krigshumør',),
'krigsindustri': ('krigsindustri',),
'krigsindustrien': ('krigsindustri',),
'krigsindustriene': ('krigsindustri',),
'krigsindustrier': ('krigsindustri',),
'krigsinvalid': ('krigsinvalid',),
'krigsinvaliden': ('krigsinvalid',),
'krigsinvalidene': ('krigsinvalid',),
'krigsinvalider': ('krigsinvalid',),
'krigskommissariat': ('krigskommissariat',),
'krigskommissariata': ('krigskommissariat',),
'krigskommissariatene': ('krigskommissariat',),
'krigskommissariater': ('krigskommissariat',),
'krigskommissariatet': ('krigskommissariat',),
'krigskommissær': ('krigskommissær',),
'krigskommissæren': ('krigskommissær',),
'krigskommissærene': ('krigskommissær',),
'krigskommissærer': ('krigskommissær',),
'krigskorrespondent': ('krigskorrespondent',),
'krigskorrespondenten': ('krigskorrespondent',),
'krigskorrespondentene': ('krigskorrespondent',),
'krigskorrespondenter': ('krigskorrespondent',),
'krigslist': ('krigslist',),
'krigslista': ('krigslist',),
'krigslisten': ('krigslist',),
'krigslistene': ('krigslist',),
'krigslister': ('krigslist',),
'krigsmakt': ('krigsmakt',),
'krigsmakta': ('krigsmakt',),
'krigsmakten': ('krigsmakt',),
'krigsmaktene': ('krigsmakt',),
'krigsmakter': ('krigsmakt',),
'krigsmaling': ('krigsmaling',),
'krigsmalinga': ('krigsmaling',),
'krigsmalingen': ('krigsmaling',),
'krigsmalingene': ('krigsmaling',),
'krigsmalinger': ('krigsmaling',),
'krigsmann': ('krigsmann',),
'krigsmannen': ('krigsmann',),
'krigsmenn': ('krigsmann',),
'krigsmennene': ('krigsmann',),
'krigsmaskin': ('krigsmaskin',),
'krigsmaskina': ('krigsmaskin',),
'krigsmaskinen': ('krigsmaskin',),
'krigsmaskinene': ('krigsmaskin',),
'krigsmaskiner': ('krigsmaskin',),
'krigsmedalje': ('krigsmedalje',),
'krigsmedaljen': ('krigsmedalje',),
'krigsmedaljene': ('krigsmedalje',),
'krigsmedaljer': ('krigsmedalje',),
'krigspensjon': ('krigspensjon',),
'krigspensjonen': ('krigspensjon',),
'krigspensjonene': ('krigspensjon',),
'krigspensjoner': ('krigspensjon',),
'krigspsykose': ('krigspsykose',),
'krigspsykosen': ('krigspsykose',),
'krigspsykosene': ('krigspsykose',),
'krigspsykoser': ('krigspsykose',),
'krigsrett': ('krigsrett',),
'krigsretten': ('krigsrett',),
'krigsrettene': ('krigsrett',),
'krigsretter': ('krigsrett',),
'krigsrisikotillegg': ('krigsrisikotillegg',),
'krigsrisikotillegga': ('krigsrisikotillegg',),
'krigsrisikotilleggene': ('krigsrisikotillegg',),
'krigsrisikotillegget': ('krigsrisikotillegg',),
'krigsrop': ('krigsrop',),
'krigsropa': ('krigsrop',),
'krigsropene': ('krigsrop',),
'krigsropet': ('krigsrop',),
'krigsråd': ('krigsråd',),
'krigsråda': ('krigsråd',),
'krigsrådene': ('krigsråd',),
'krigsrådet': ('krigsråd',),
'krigsseiler': ('krigsseiler',),
'krigsseilere': ('krigsseiler',),
'krigsseileren': ('krigsseiler',),
'krigsseilerer': ('krigsseiler',),
'krigsseilerne': ('krigsseiler',),
'krigsskadeserstatning': ('krigsskadeserstatning',),
'krigsskadeserstatninga': ('krigsskadeserstatning',),
'krigsskadeserstatningen': ('krigsskadeserstatning',),
'krigsskadeserstatningene': ('krigsskadeserstatning',),
'krigsskadeserstatninger': ('krigsskadeserstatning',),
'krigsskip': ('krigsskip',),
'krigsskipa': ('krigsskip',),
'krigsskipene': ('krigsskip',),
'krigsskipet': ('krigsskip',),
'krigsskole': ('krigsskole',),
'krigsskolen': ('krigsskole',),
'krigsskolene': ('krigsskole',),
'krigsskoler': ('krigsskole',),
'krigsskueplass': ('krigsskueplass',),
'krigsskueplassen': ('krigsskueplass',),
'krigsskueplassene': ('krigsskueplass',),
'krigsskueplasser': ('krigsskueplass',),
'krigsspell': ('krigsspell',),
'krigsspella': ('krigsspell',),
'krigsspellene': ('krigsspell',),
'krigsspellet': ('krigsspell',),
'krigsspill': ('krigsspill',),
'krigsspilla': ('krigsspill',),
'krigsspillene': ('krigsspill',),
'krigsspillet': ('krigsspill',),
'krigssti': ('krigssti',),
'krigsstien': ('krigssti',),
'krigsstiene': ('krigssti',),
'krigsstier': ('krigssti',),
'krigstid': ('krigstid',),
'krigstida': ('krigstid',),
'krigstiden': ('krigstid',),
'krigstidene': ('krigstid',),
'krigstider': ('krigstid',),
'krigstilstand': ('krigstilstand',),
'krigstilstanden': ('krigstilstand',),
'krigstilstandene': ('krigstilstand',),
'krigstilstander': ('krigstilstand',),
'krigstjenestekort': ('krigstjenestekort',),
'krigstjenestekorta': ('krigstjenestekort',),
'krigstjenestekortene': ('krigstjenestekort',),
'krigstjenestekortet': ('krigstjenestekort',),
'krigstromma': ('krigstromme',),
'krigstromme': ('krigstromme',),
'krigstrommen': ('krigstromme',),
'krigstrommene': ('krigstromme',),
'krigstrommer': ('krigstromme',),
'krik': ('krik',),
'kriken': ('krik',),
'krikene': ('krik',),
'kriker': ('krik',),
'krike': ('krike',),
'kriken': ('krike',),
'krikene': ('krike',),
'kriker': ('krike',),
'krikkand': ('krikkand',),
'krikkanda': ('krikkand',),
'krikkanden': ('krikkand',),
'krikkendene': ('krikkand',),
'krikkender': ('krikkand',),
'kril': ('kril',),
'krilen': ('kril',),
'krilene': ('kril',),
'kriler': ('kril',),
'krill': ('krill',),
'krillen': ('krill',),
'krillene': ('krill',),
'kriller': ('krill',),
'krilla': ('krille',),
'krille': ('krille',),
'krillen': ('krille',),
'krillene': ('krille',),
'kriller': ('krille',),
'krim': ('krim',),
'krimmen': ('krim',),
'krimmene': ('krim',),
'krimmer': ('krim',),
'krim': ('krim',),
'krima': ('krim',),
'krimene': ('krim',),
'krimet': ('krim',),
'krimblad': ('krimblad',),
'krimblada': ('krimblad',),
'krimbladene': ('krimblad',),
'krimblader': ('krimblad',),
'krimbladet': ('krimblad',),
'krime': ('krime',),
'krimen': ('krime',),
'krimene': ('krime',),
'krimer': ('krime',),
'kriminalfilm': ('kriminalfilm',),
'kriminalfilmen': ('kriminalfilm',),
'kriminalfilmene': ('kriminalfilm',),
'kriminalfilmer': ('kriminalfilm',),
'kriminalfortelling': ('kriminalfortelling',),
'kriminalfortellinga': ('kriminalfortelling',),
'kriminalfortellingen': ('kriminalfortelling',),
'kriminalfortellingene': ('kriminalfortelling',),
'kriminalfortellinger': ('kriminalfortelling',),
'kriminalist': ('kriminalist',),
'kriminalisten': ('kriminalist',),
'kriminalistene': ('kriminalist',),
'kriminalister': ('kriminalist',),
'kriminalitet': ('kriminalitet',),
'kriminaliteten': ('kriminalitet',),
'kriminalitetene': ('kriminalitet',),
'kriminaliteter': ('kriminalitet',),
'kriminalomsorg': ('kriminalomsorg',),
'kriminalomsorga': ('kriminalomsorg',),
'kriminalomsorgen': ('kriminalomsorg',),
'kriminalomsorgene': ('kriminalomsorg',),
'kriminalomsorger': ('kriminalomsorg',),
'kriminalpoliti': ('kriminalpoliti',),
'kriminalpolitia': ('kriminalpoliti',),
'kriminalpolitiene': ('kriminalpoliti',),
'kriminalpolitier': ('kriminalpoliti',),
'kriminalpolitiet': ('kriminalpoliti',),
'kriminalregister': ('kriminalregister',),
'kriminalregisteret': ('kriminalregister',),
'kriminalregistra': ('kriminalregister',),
'kriminalregistre': ('kriminalregister',),
'kriminalregistrene': ('kriminalregister',),
'kriminalregistret': ('kriminalregister',),
'kriminalroman': ('kriminalroman',),
'kriminalromanen': ('kriminalroman',),
'kriminalromanene': ('kriminalroman',),
'kriminalromaner': ('kriminalroman',),
'kriminalsak': ('kriminalsak',),
'kriminalsaka': ('kriminalsak',),
'kriminalsaken': ('kriminalsak',),
'kriminalsakene': ('kriminalsak',),
'kriminalsaker': ('kriminalsak',),
'kriminalsosiologi': ('kriminalsosiologi',),
'kriminalsosiologien': ('kriminalsosiologi',),
'kriminalsosiologiene': ('kriminalsosiologi',),
'kriminalsosiologier': ('kriminalsosiologi',),
'kriminolog': ('kriminolog',),
'kriminologen': ('kriminolog',),
'kriminologene': ('kriminolog',),
'kriminologer': ('kriminolog',),
'kriminologi': ('kriminologi',),
'kriminologien': ('kriminologi',),
'kriminologiene': ('kriminologi',),
'kriminologier': ('kriminologi',),
'kriminologisk': ('kriminologisk',),
'kriminologisken': ('kriminologisk',),
'kriminologiskene': ('kriminologisk',),
'kriminologisker': ('kriminologisk',),
'krimsjuka': ('krimsjuke',),
'krimsjuke': ('krimsjuke',),
'krimsjuken': ('krimsjuke',),
'krimsjukene': ('krimsjuke',),
'krimsjuker': ('krimsjuke',),
'krimskrams': ('krimskrams',),
'krimskramsa': ('krimskrams',),
'krimskramsene': ('krimskrams',),
'krimskramset': ('krimskrams',),
'kringkaster': ('kringkaster',),
'kringkastere': ('kringkaster',),
'kringkasteren': ('kringkaster',),
'kringkasterer': ('kringkaster',),
'kringkasterne': ('kringkaster',),
'kringkasting': ('kringkasting',),
'kringkastinga': ('kringkasting',),
'kringkastingen': ('kringkasting',),
'kringkastingene': ('kringkasting',),
'kringkastinger': ('kringkasting',),
'kringkastingsavgift': ('kringkastingsavgift',),
'kringkastingsavgifta': ('kringkastingsavgift',),
'kringkastingsavgiften': ('kringkastingsavgift',),
'kringkastingsavgiftene': ('kringkastingsavgift',),
'kringkastingsavgifter': ('kringkastingsavgift',),
'kringkastingskort': ('kringkastingskort',),
'kringkastingskorta': ('kringkastingskort',),
'kringkastingskortene': ('kringkastingskort',),
'kringkastingskortet': ('kringkastingskort',),
'kringkastingslisens': ('kringkastingslisens',),
'kringkastingslisensen': ('kringkastingslisens',),
'kringkastingslisensene': ('kringkastingslisens',),
'kringkastingslisenser': ('kringkastingslisens',),
'kringkastingsstasjon': ('kringkastingsstasjon',),
'kringkastingsstasjonen': ('kringkastingsstasjon',),
'kringkastingsstasjonene': ('kringkastingsstasjon',),
'kringkastingsstasjoner': ('kringkastingsstasjon',),
'kringkastingsunion': ('kringkastingsunion',),
'kringkastingsunionen': ('kringkastingsunion',),
'kringkastingsunionene': ('kringkastingsunion',),
'kringkastingsunioner': ('kringkastingsunion',),
'kringla': ('kringle',),
'kringle': ('kringle',),
'kringlen': ('kringle',),
'kringlene': ('kringle',),
'kringler': ('kringle',),
'kringsjå': ('kringsjå',),
'kringsjåa': ('kringsjå',),
'kringsjåene': ('kringsjå',),
'kringsjået': ('kringsjå',),
'kringvern': ('kringvern',),
'kringverna': ('kringvern',),
'kringvernene': ('kringvern',),
'kringvernet': ('kringvern',),
'krinkel': ('krinkel',),
'krinkelen': ('krinkel',),
'krinklene': ('krinkel',),
'krinkler': ('krinkel',),
'krinkelkrok': ('krinkelkrok',),
'krinkelkroken': ('krinkelkrok',),
'krinkelkrokene': ('krinkelkrok',),
'krinkelkroker': ('krinkelkrok',),
'krinoline': ('krinoline',),
'krinolinen': ('krinoline',),
'krinolinene': ('krinoline',),
'krinoliner': ('krinoline',),
'krins': ('krins',),
'krinsen': ('krins',),
'krinsene': ('krins',),
'krinser': ('krins',),
'kris': ('kris',),
'krisen': ('kris',),
'krisene': ('kris',),
'kriser': ('kris',),
'krisa': ('krise',),
'krise': ('krise',),
'krisen': ('krise',),
'krisene': ('krise',),
'kriser': ('krise',),
'krisefond': ('krisefond',),
'krisefonda': ('krisefond',),
'krisefondene': ('krisefond',),
'krisefondet': ('krisefond',),
'krisehjelp': ('krisehjelp',),
'krisehjelpa': ('krisehjelp',),
'krisehjelpen': ('krisehjelp',),
'krisehjelpene': ('krisehjelp',),
'krisehjelper': ('krisehjelp',),
'kriseplan': ('kriseplan',),
'kriseplanen': ('kriseplan',),
'kriseplanene': ('kriseplan',),
'kriseplaner': ('kriseplan',),
'krisesenter': ('krisesenter',),
'krisesenteret': ('krisesenter',),
'krisesentra': ('krisesenter',),
'krisesentre': ('krisesenter',),
'krisesentrene': ('krisesenter',),
'krisesentret': ('krisesenter',),
'krisetid': ('krisetid',),
'krisetida': ('krisetid',),
'krisetiden': ('krisetid',),
'krisetidene': ('krisetid',),
'krisetider': ('krisetid',),
'krisis': ('krisis',),
'krisisen': ('krisis',),
'krisisene': ('krisis',),
'krisiser': ('krisis',),
'kristendom': ('kristendom',),
'kristendommen': ('kristendom',),
'kristendommene': ('kristendom',),
'kristendommer': ('kristendom',),
'kristendomskunnskap': ('kristendomskunnskap',),
'kristendomskunnskapen': ('kristendomskunnskap',),
'kristendomskunnskapene': ('kristendomskunnskap',),
'kristendomskunnskaper': ('kristendomskunnskap',),
'kristenfolk': ('kristenfolk',),
'kristenfolka': ('kristenfolk',),
'kristenfolkene': ('kristenfolk',),
'kristenfolket': ('kristenfolk',),
'kristenforfølgelse': ('kristenforfølgelse',),
'kristenforfølgelsen': ('kristenforfølgelse',),
'kristenforfølgelsene': ('kristenforfølgelse',),
'kristenforfølgelser': ('kristenforfølgelse',),
'kristenhet': ('kristenhet',),
'kristenheta': ('kristenhet',),
'kristenheten': ('kristenhet',),
'kristenhetene': ('kristenhet',),
'kristenheter': ('kristenhet',),
'kristenliv': ('kristenliv',),
'kristenliva': ('kristenliv',),
'kristenlivene': ('kristenliv',),
'kristenlivet': ('kristenliv',),
'kristenmann': ('kristenmann',),
'kristenmannen': ('kristenmann',),
'kristenmenn': ('kristenmann',),
'kristenmennene': ('kristenmann',),
'kristenplikt': ('kristenplikt',),
'kristenplikta': ('kristenplikt',),
'kristenplikten': ('kristenplikt',),
'kristenpliktene': ('kristenplikt',),
'kristenplikter': ('kristenplikt',),
'kristenrett': ('kristenrett',),
'kristenretten': ('kristenrett',),
'kristenrettene': ('kristenrett',),
'kristenretter': ('kristenrett',),
'kristentro': ('kristentro',),
'kristentroa': ('kristentro',),
'kristentroen': ('kristentro',),
'kristentroene': ('kristentro',),
'kristentroer': ('kristentro',),
'kristianiasving': ('kristianiasving',),
'kristianiasvingen': ('kristianiasving',),
'kristianiasvingene': ('kristianiasving',),
'kristianiasvinger': ('kristianiasving',),
'kristkirka': ('kristkirke',),
'kristkirke': ('kristkirke',),
'kristkirken': ('kristkirke',),
'kristkirkene': ('kristkirke',),
'kristkirker': ('kristkirke',),
'kristologi': ('kristologi',),
'kristologien': ('kristologi',),
'kristologiene': ('kristologi',),
'kristologier': ('kristologi',),
'kristtorn': ('kristtorn',),
'kristtornen': ('kristtorn',),
'kristtornene': ('kristtorn',),
'kristtorner': ('kristtorn',),
'kristusbilda': ('kristusbilde',),
'kristusbilde': ('kristusbilde',),
'kristusbildene': ('kristusbilde',),
'kristusbilder': ('kristusbilde',),
'kristusbildet': ('kristusbilde',),
'kristusmonogram': ('kristusmonogram',),
'kristusmonogramma': ('kristusmonogram',),
'kristusmonogrammene': ('kristusmonogram',),
'kristusmonogrammet': ('kristusmonogram',),
'kristusskikkelse': ('kristusskikkelse',),
'kristusskikkelsen': ('kristusskikkelse',),
'kristusskikkelsene': ('kristusskikkelse',),
'kristusskikkelser': ('kristusskikkelse',),
'kristussymbol': ('kristussymbol',),
'kristussymbola': ('kristussymbol',),
'kristussymbolene': ('kristussymbol',),
'kristussymboler': ('kristussymbol',),
'kristussymbolet': ('kristussymbol',),
'krit': ('krit',),
'krita': ('krit',),
'kriten': ('krit',),
'kritene': ('krit',),
'kriter': ('krit',),
'kriterieløp': ('kriterieløp',),
'kriterieløpa': ('kriterieløp',),
'kriterieløpene': ('kriterieløp',),
'kriterieløpet': ('kriterieløp',),
'kriteria': ('kriterium',),
'kriteriene': ('kriterium',),
'kriterier': ('kriterium',),
'kriteriet': ('kriterium',),
'kriterium': ('kriterium',),
'kritiker': ('kritiker',),
'kritikere': ('kritiker',),
'kritikeren': ('kritiker',),
'kritikerer': ('kritiker',),
'kritikerne': ('kritiker',),
'kritikk': ('kritikk',),
'kritikken': ('kritikk',),
'kritikkene': ('kritikk',),
'kritikker': ('kritikk',),
'kritikus': ('kritikus',),
'kritikusen': ('kritikus',),
'kritikusene': ('kritikus',),
'kritikuser': ('kritikus',),
'kritisisme': ('kritisisme',),
'kritisismen': ('kritisisme',),
'kritisismene': ('kritisisme',),
'kritisismer': ('kritisisme',),
'kritt': ('kritt',),
'kritt': ('kritt',),
'kritta': ('kritt',),
'krittene': ('kritt',),
'krittet': ('kritt',),
'krittformasjon': ('krittformasjon',),
'krittformasjonen': ('krittformasjon',),
'krittformasjonene': ('krittformasjon',),
'krittformasjoner': ('krittformasjon',),
'kritthus': ('kritthus',),
'kritthusa': ('kritthus',),
'kritthusene': ('kritthus',),
'kritthuset': ('kritthus',),
'krittperiode': ('krittperiode',),
'krittperioden': ('krittperiode',),
'krittperiodene': ('krittperiode',),
'krittperioder': ('krittperiode',),
'krittpipa': ('krittpipe',),
'krittpipe': ('krittpipe',),
'krittpipen': ('krittpipe',),
'krittpipene': ('krittpipe',),
'krittpiper': ('krittpipe',),
'krittsystem': ('krittsystem',),
'krittsystema': ('krittsystem',),
'krittsystemene': ('krittsystem',),
'krittsystemer': ('krittsystem',),
'krittsystemet': ('krittsystem',),
'kro': ('kro',),
'kroen': ('kro',),
'kroene': ('kro',),
'kroer': ('kro',),
'kro': ('kro',),
'kroa': ('kro',),
'kroen': ('kro',),
'kroene': ('kro',),
'kroer': ('kro',),
'kroat': ('kroat',),
'kroaten': ('kroat',),
'kroatene': ('kroat',),
'kroater': ('kroat',),
'krok': ('krok',),
'kroken': ('krok',),
'krokene': ('krok',),
'kroker': ('krok',),
'krokan': ('krokan',),
'krokanen': ('krokan',),
'krokanene': ('krokan',),
'krokaner': ('krokan',),
'krokanis': ('krokanis',),
'krokanisen': ('krokanis',),
'krokanisene': ('krokanis',),
'krokaniser': ('krokanis',),
'krokett': ('krokett',),
'kroketten': ('krokett',),
'krokettene': ('krokett',),
'kroketter': ('krokett',),
'krokfinger': ('krokfinger',),
'krokfingeren': ('krokfinger',),
'krokfingre': ('krokfinger',),
'krokfingrene': ('krokfinger',),
'krokfingrer': ('krokfinger',),
'kroki': ('kroki',),
'krokia': ('kroki',),
'krokien': ('kroki',),
'krokiene': ('kroki',),
'krokier': ('kroki',),
'krokiet': ('kroki',),
'krokket': ('krokket',),
'krokketen': ('krokket',),
'krokketene': ('krokket',),
'krokketer': ('krokket',),
'krokketkula': ('krokketkule',),
'krokketkule': ('krokketkule',),
'krokketkulen': ('krokketkule',),
'krokketkulene': ('krokketkule',),
'krokketkuler': ('krokketkule',),
'krokketkølla': ('krokketkølle',),
'krokketkølle': ('krokketkølle',),
'krokketkøllen': ('krokketkølle',),
'krokketkøllene': ('krokketkølle',),
'krokketkøller': ('krokketkølle',),
'kroknesa': ('kroknese',),
'kroknese': ('kroknese',),
'kroknesen': ('kroknese',),
'kroknesene': ('kroknese',),
'krokneser': ('kroknese',),
'krokodilla': ('krokodille',),
'krokodille': ('krokodille',),
'krokodillen': ('krokodille',),
'krokodillene': ('krokodille',),
'krokodiller': ('krokodille',),
'krokodilleskinn': ('krokodilleskinn',),
'krokodilleskinna': ('krokodilleskinn',),
'krokodilleskinnene': ('krokodilleskinn',),
'krokodilleskinnet': ('krokodilleskinn',),
'krokodilletåra': ('krokodilletåre',),
'krokodilletåre': ('krokodilletåre',),
'krokodilletåren': ('krokodilletåre',),
'krokodilletårene': ('krokodilletåre',),
'krokodilletårer': ('krokodilletåre',),
'krokstav': ('krokstav',),
'krokstaven': ('krokstav',),
'krokstavene': ('krokstav',),
'krokstaver': ('krokstav',),
'krokus': ('krokus',),
'krokusen': ('krokus',),
'krokusene': ('krokus',),
'krokuser': ('krokus',),
'krokveg': ('krokveg',),
'krokvegen': ('krokveg',),
'krokvegene': ('krokveg',),
'krokveger': ('krokveg',),
'krokvei': ('krokvei',),
'krokveien': ('krokvei',),
'krokveiene': ('krokvei',),
'krokveier': ('krokvei',),
'krom': ('krom',),
'kromma': ('krom',),
'krommene': ('krom',),
'krommet': ('krom',),
'kromat': ('kromat',),
'kromata': ('kromat',),
'kromatene': ('kromat',),
'kromater': ('kromat',),
'kromatet': ('kromat',),
'kromatikk': ('kromatikk',),
'kromatikken': ('kromatikk',),
'kromatikkene': ('kromatikk',),
'kromatikker': ('kromatikk',),
'kromatofor': ('kromatofor',),
'kromatoforen': ('kromatofor',),
'kromatoforene': ('kromatofor',),
'kromatoforer': ('kromatofor',),
'kromgrønt': ('kromgrønt',),
'kromgult': ('kromgult',),
'kromoplast': ('kromoplast',),
'kromoplasten': ('kromoplast',),
'kromoplastene': ('kromoplast',),
'kromoplaster': ('kromoplast',),
'kromosom': ('kromosom',),
'kromosoma': ('kromosom',),
'kromosomene': ('kromosom',),
'kromosomer': ('kromosom',),
'kromosomet': ('kromosom',),
'kromrødt': ('kromrødt',),
'kromstål': ('kromstål',),
'kromståla': ('kromstål',),
'kromstålene': ('kromstål',),
'kromstålet': ('kromstål',),
'kromsyra': ('kromsyre',),
'kromsyre': ('kromsyre',),
'kromsyren': ('kromsyre',),
'kromsyrene': ('kromsyre',),
'kromsyrer': ('kromsyre',),
'kronblad': ('kronblad',),
'kronblada': ('kronblad',),
'kronbladene': ('kronblad',),
'kronblader': ('kronblad',),
'kronbladet': ('kronblad',),
'krona': ('krone',),
'krone': ('krone',),
'kronen': ('krone',),
'kronene': ('krone',),
'kroner': ('krone',),
'krona': ('krone',),
'krone': ('krone',),
'kronen': ('krone',),
'kronene': ('krone',),
'kroner': ('krone',),
'kronekurs': ('kronekurs',),
'kronekursen': ('kronekurs',),
'kronekursene': ('kronekurs',),
'kronekurser': ('kronekurs',),
'kronemutrene': ('kronemutter',),
'kronemutrer': ('kronemutter',),
'kronemutter': ('kronemutter',),
'kronemuttere': ('kronemutter',),
'kronemutteren': ('kronemutter',),
'kronemutterer': ('kronemutter',),
'kronemutterne': ('kronemutter',),
'kronerulling': ('kronerulling',),
'kronerullinga': ('kronerulling',),
'kronerullingen': ('kronerulling',),
'kronerullingene': ('kronerulling',),
'kronerullinger': ('kronerulling',),
'kronestykka': ('kronestykke',),
'kronestykke': ('kronestykke',),
'kronestykkene': ('kronestykke',),
'kronestykker': ('kronestykke',),
'kronestykket': ('kronestykke',),
'kroneverdi': ('kroneverdi',),
'kroneverdien': ('kroneverdi',),
'kroneverdiene': ('kroneverdi',),
'kroneverdier': ('kroneverdi',),
'kronglass': ('kronglass',),
'kronglassa': ('kronglass',),
'kronglassene': ('kronglass',),
'kronglasset': ('kronglass',),
'krongla': ('krongle',),
'krongle': ('krongle',),
'kronglen': ('krongle',),
'kronglene': ('krongle',),
'krongler': ('krongle',),
'krongla': ('krongle',),
'krongle': ('krongle',),
'kronglen': ('krongle',),
'kronglene': ('krongle',),
'krongler': ('krongle',),
'kronglebjerk': ('kronglebjerk',),
'kronglebjerka': ('kronglebjerk',),
'kronglebjerken': ('kronglebjerk',),
'kronglebjerkene': ('kronglebjerk',),
'kronglebjerker': ('kronglebjerk',),
'kronglebjørk': ('kronglebjørk',),
'kronglebjørka': ('kronglebjørk',),
'kronglebjørken': ('kronglebjørk',),
'kronglebjørkene': ('kronglebjørk',),
'kronglebjørker': ('kronglebjørk',),
'kronglefuru': ('kronglefuru',),
'kronglefurua': ('kronglefuru',),
'kronglefuruen': ('kronglefuru',),
'kronglefuruene': ('kronglefuru',),
'kronglefuruer': ('kronglefuru',),
'krongods': ('krongods',),
'krongodsa': ('krongods',),
'krongodsene': ('krongods',),
'krongodser': ('krongods',),
'krongodset': ('krongods',),
'kronhjort': ('kronhjort',),
'kronhjorten': ('kronhjort',),
'kronhjortene': ('kronhjort',),
'kronhjorter': ('kronhjort',),
'kronidiot': ('kronidiot',),
'kronidioten': ('kronidiot',),
'kronidiotene': ('kronidiot',),
'kronidioter': ('kronidiot',),
'kroniker': ('kroniker',),
'kronikere': ('kroniker',),
'kronikeren': ('kroniker',),
'kronikerer': ('kroniker',),
'kronikerne': ('kroniker',),
'kronikk': ('kronikk',),
'kronikken': ('kronikk',),
'kronikkene': ('kronikk',),
'kronikker': ('kronikk',),
'kronikør': ('kronikør',),
'kronikøren': ('kronikør',),
'kronikørene': ('kronikør',),
'kronikører': ('kronikør',),
'kroning': ('kroning',),
'kroninga': ('kroning',),
'kroningen': ('kroning',),
'kroningene': ('kroning',),
'kroninger': ('kroning',),
'kronjord': ('kronjord',),
'kronjorda': ('kronjord',),
'kronjorden': ('kronjord',),
'kronjordene': ('kronjord',),
'kronjorder': ('kronjord',),
'kronjuvel': ('kronjuvel',),
'kronjuvelen': ('kronjuvel',),
'kronjuvelene': ('kronjuvel',),
'kronjuveler': ('kronjuvel',),
'kronkoloni': ('kronkoloni',),
'kronkolonien': ('kronkoloni',),
'kronkoloniene': ('kronkoloni',),
'kronkolonier': ('kronkoloni',),
'kronograf': ('kronograf',),
'kronografen': ('kronograf',),
'kronografene': ('kronograf',),
'kronografer': ('kronograf',),
'kronolog': ('kronolog',),
'kronologen': ('kronolog',),
'kronologene': ('kronolog',),
'kronologer': ('kronolog',),
'kronologi': ('kronologi',),
'kronologien': ('kronologi',),
'kronologiene': ('kronologi',),
'kronologier': ('kronologi',),
'kronometer': ('kronometer',),
'kronometeret': ('kronometer',),
'kronometra': ('kronometer',),
'kronometre': ('kronometer',),
'kronometrene': ('kronometer',),
'kronometret': ('kronometer',),
'kronprins': ('kronprins',),
'kronprinsen': ('kronprins',),
'kronprinsene': ('kronprins',),
'kronprinser': ('kronprins',),
'kronprinsessa': ('kronprinsesse',),
'kronprinsesse': ('kronprinsesse',),
'kronprinsessen': ('kronprinsesse',),
'kronprinsessene': ('kronprinsesse',),
'kronprinsesser': ('kronprinsesse',),
'kronprinsregent': ('kronprinsregent',),
'kronprinsregenten': ('kronprinsregent',),
'kronprinsregentene': ('kronprinsregent',),
'kronprinsregenter': ('kronprinsregent',),
'kronregaliene': ('kronregalier',),
'kronregalier': ('kronregalier',),
'kronrust': ('kronrust',),
'kronrusta': ('kronrust',),
'kronrusten': ('kronrust',),
'kronrustene': ('kronrust',),
'kronruster': ('kronrust',),
'kronvasall': ('kronvasall',),
'kronvasallen': ('kronvasall',),
'kronvasallene': ('kronvasall',),
'kronvasaller': ('kronvasall',),
'kronvitna': ('kronvitne',),
'kronvitne': ('kronvitne',),
'kronvitnene': ('kronvitne',),
'kronvitner': ('kronvitne',),
'kronvitnet': ('kronvitne',),
'kronår': ('kronår',),
'kronåra': ('kronår',),
'kronårene': ('kronår',),
'kronåret': ('kronår',),
'kroon': ('kroon',),
'kroonen': ('kroon',),
'kroonene': ('kroon',),
'kropp': ('kropp',),
'kroppen': ('kropp',),
'kroppene': ('kropp',),
'kropper': ('kropp',),
'kroppsarbeid': ('kroppsarbeid',),
'kroppsarbeida': ('kroppsarbeid',),
'kroppsarbeidene': ('kroppsarbeid',),
'kroppsarbeider': ('kroppsarbeid',),
'kroppsarbeidet': ('kroppsarbeid',),
'kroppsbygger': ('kroppsbygger',),
'kroppsbyggere': ('kroppsbygger',),
'kroppsbyggeren': ('kroppsbygger',),
'kroppsbyggerer': ('kroppsbygger',),
'kroppsbyggerne': ('kroppsbygger',),
'kroppsbygging': ('kroppsbygging',),
'kroppsbygginga': ('kroppsbygging',),
'kroppsbyggingen': ('kroppsbygging',),
'kroppsbyggingene': ('kroppsbygging',),
'kroppsbygginger': ('kroppsbygging',),
'kroppsføring': ('kroppsføring',),
'kroppsføringa': ('kroppsføring',),
'kroppsføringen': ('kroppsføring',),
'kroppsføringene': ('kroppsføring',),
'kroppsføringer': ('kroppsføring',),
'kroppshola': ('kroppshole',),
'kroppshole': ('kroppshole',),
'kroppsholen': ('kroppshole',),
'kroppsholene': ('kroppshole',),
'kroppsholer': ('kroppshole',),
'kroppshula': ('kroppshule',),
'kroppshule': ('kroppshule',),
'kroppshulen': ('kroppshule',),
'kroppshulene': ('kroppshule',),
'kroppshuler': ('kroppshule',),
'kroppskultur': ('kroppskultur',),
'kroppskulturen': ('kroppskultur',),
'kroppskulturene': ('kroppskultur',),
'kroppskulturer': ('kroppskultur',),
'kroppslus': ('kroppslus',),
'kroppslusa': ('kroppslus',),
'kroppslusen': ('kroppslus',),
'kroppslusene': ('kroppslus',),
'kroppspulsåra': ('kroppspulsåre',),
'kroppspulsåre': ('kroppspulsåre',),
'kroppspulsåren': ('kroppspulsåre',),
'kroppspulsårene': ('kroppspulsåre',),
'kroppspulsårer': ('kroppspulsåre',),
'kroppstemperatur': ('kroppstemperatur',),
'kroppstemperaturen': ('kroppstemperatur',),
'kroppstemperaturene': ('kroppstemperatur',),
'kroppstemperaturer': ('kroppstemperatur',),
'kroppsvarme': ('kroppsvarme',),
'kroppsvarmen': ('kroppsvarme',),
'kroppsvarmene': ('kroppsvarme',),
'kroppsvarmer': ('kroppsvarme',),
'kroppsvisitasjon': ('kroppsvisitasjon',),
'kroppsvisitasjonen': ('kroppsvisitasjon',),
'kroppsvisitasjonene': ('kroppsvisitasjon',),
'kroppsvisitasjoner': ('kroppsvisitasjon',),
'kroppsøving': ('kroppsøving',),
'kroppsøvinga': ('kroppsøving',),
'kroppsøvingen': ('kroppsøving',),
'kroppsøvingene': ('kroppsøving',),
'kroppsøvinger': ('kroppsøving',),
'krot': ('krot',),
'krota': ('krot',),
'krotene': ('krot',),
'krotet': ('krot',),
'krotekaka': ('krotekake',),
'krotekake': ('krotekake',),
'krotekaken': ('krotekake',),
'krotekakene': ('krotekake',),
'krotekaker': ('krotekake',),
'krotsøm': ('krotsøm',),
'krotsømmen': ('krotsøm',),
'krotsømmene': ('krotsøm',),
'krotsømmer': ('krotsøm',),
'krovert': ('krovert',),
'kroverten': ('krovert',),
'krovertene': ('krovert',),
'kroverter': ('krovert',),
'krugg': ('krugg',),
'kruggen': ('krugg',),
'kruggene': ('krugg',),
'krugger': ('krugg',),
'kruk': ('kruk',),
'kruken': ('kruk',),
'krukene': ('kruk',),
'kruker': ('kruk',),
'krukedans': ('krukedans',),
'krukedansen': ('krukedans',),
'krukedansene': ('krukedans',),
'krukedanser': ('krukedans',),
'krukka': ('krukke',),
'krukke': ('krukke',),
'krukken': ('krukke',),
'krukkene': ('krukke',),
'krukker': ('krukke',),
'krull': ('krull',),
'krullen': ('krull',),
'krullene': ('krull',),
'kruller': ('krull',),
'krumkaka': ('krumkake',),
'krumkake': ('krumkake',),
'krumkaken': ('krumkake',),
'krumkakene': ('krumkake',),
'krumkaker': ('krumkake',),
'krumkakejern': ('krumkakejern',),
'krumkakejerna': ('krumkakejern',),
'krumkakejernene': ('krumkakejern',),
'krumkakejernet': ('krumkakejern',),
'krumme': ('krumme',),
'krummen': ('krumme',),
'krummene': ('krumme',),
'krummer': ('krumme',),
'krummelur': ('krummelur',),
'krummeluren': ('krummelur',),
'krummelurene': ('krummelur',),
'krummelurer': ('krummelur',),
'krumming': ('krumming',),
'krumminga': ('krumming',),
'krummingen': ('krumming',),
'krummingene': ('krumming',),
'krumminger': ('krumming',),
'krumning': ('krumning',),
'krumninga': ('krumning',),
'krumningen': ('krumning',),
'krumningene': ('krumning',),
'krumninger': ('krumning',),
'krumningsradien': ('krumningsradius',),
'krumningsradiene': ('krumningsradius',),
'krumningsradier': ('krumningsradius',),
'krumningsradius': ('krumningsradius',),
'krumningsradiusen': ('krumningsradius',),
'krumspring': ('krumspring',),
'krumspringa': ('krumspring',),
'krumspringene': ('krumspring',),
'krumspringet': ('krumspring',),
'krumtapp': ('krumtapp',),
'krumtappen': ('krumtapp',),
'krumtappene': ('krumtapp',),
'krumtapper': ('krumtapp',),
'krungla': ('krungle',),
'krungle': ('krungle',),
'krunglen': ('krungle',),
'krunglene': ('krungle',),
'krungler': ('krungle',),
'krungla': ('krungle',),
'krungle': ('krungle',),
'krunglen': ('krungle',),
'krunglene': ('krungle',),
'krungler': ('krungle',),
'krunglebjerk': ('krunglebjerk',),
'krunglebjerka': ('krunglebjerk',),
'krunglebjerken': ('krunglebjerk',),
'krunglebjerkene': ('krunglebjerk',),
'krunglebjerker': ('krunglebjerk',),
'krunglebjørk': ('krunglebjørk',),
'krunglebjørka': ('krunglebjørk',),
'krunglebjørken': ('krunglebjørk',),
'krunglebjørkene': ('krunglebjørk',),
'krunglebjørker': ('krunglebjørk',),
'krunglebjørk': ('krunglebjørk',),
'krunglebjørka': ('krunglebjørk',),
'krunglebjørken': ('krunglebjørk',),
'krunglebjørkene': ('krunglebjørk',),
'krunglebjørker': ('krunglebjørk',),
'krunglefuru': ('krunglefuru',),
'krunglefurua': ('krunglefuru',),
'krunglefuruen': ('krunglefuru',),
'krunglefuruene': ('krunglefuru',),
'krunglefuruer': ('krunglefuru',),
'krunglefuru': ('krunglefuru',),
'krunglefurua': ('krunglefuru',),
'krunglefuruen': ('krunglefuru',),
'krunglefuruene': ('krunglefuru',),
'krunglefuruer': ('krunglefuru',),
'krupp': ('krupp',),
'kruppen': ('krupp',),
'kruppene': ('krupp',),
'krupper': ('krupp',),
'krus': ('krus',),
'krusa': ('krus',),
'krusene': ('krus',),
'kruset': ('krus',),
'krus': ('krus',),
'krusa': ('krus',),
'krusen': ('krus',),
'krusene': ('krus',),
'kruser': ('krus',),
'kruset': ('krus',),
'krusbrott': ('krusbrott',),
'krusbrotta': ('krusbrott',),
'krusbrottene': ('krusbrott',),
'krusbrottet': ('krusbrott',),
'krusedull': ('krusedull',),
'krusedullen': ('krusedull',),
'krusedullene': ('krusedull',),
'kruseduller': ('krusedull',),
'krusemynta': ('krusemynte',),
'krusemynte': ('krusemynte',),
'krusemynten': ('krusemynte',),
'krusemyntene': ('krusemynte',),
'krusemynter': ('krusemynte',),
'krusetistel': ('krusetistel',),
'krusetistelen': ('krusetistel',),
'krusetistlene': ('krusetistel',),
'krusetistler': ('krusetistel',),
'krushoda': ('krushode',),
'krushode': ('krushode',),
'krushodene': ('krushode',),
'krushoder': ('krushode',),
'krushodet': ('krushode',),
'krusifiks': ('krusifiks',),
'krusifiksa': ('krusifiks',),
'krusifiksene': ('krusifiks',),
'krusifikser': ('krusifiks',),
'krusifikset': ('krusifiks',),
'kruska': ('kruska',),
'kruskaen': ('kruska',),
'kruskaene': ('kruska',),
'kruskaer': ('kruska',),
'kruskål': ('kruskål',),
'kruskålen': ('kruskål',),
'kruskålene': ('kruskål',),
'kruskåler': ('kruskål',),
'krusling': ('krusling',),
'kruslingen': ('krusling',),
'kruslingene': ('krusling',),
'kruslinger': ('krusling',),
'krusning': ('krusning',),
'krusninga': ('krusning',),
'krusningen': ('krusning',),
'krusningene': ('krusning',),
'krusninger': ('krusning',),
'kruspersilla': ('kruspersille',),
'kruspersille': ('kruspersille',),
'kruspersillen': ('kruspersille',),
'kruspersillene': ('kruspersille',),
'kruspersiller': ('kruspersille',),
'krustade': ('krustade',),
'krustaden': ('krustade',),
'krustadene': ('krustade',),
'krustader': ('krustade',),
'krustøy': ('krustøy',),
'krustøya': ('krustøy',),
'krustøyene': ('krustøy',),
'krustøyet': ('krustøy',),
'krutong': ('krutong',),
'krutongen': ('krutong',),
'krutongene': ('krutong',),
'krutonger': ('krutong',),
'krutt': ('krutt',),
'krutta': ('krutt',),
'kruttene': ('krutt',),
'kruttet': ('krutt',),
'krutt-tynna': ('krutt-tynne',),
'krutt-tynne': ('krutt-tynne',),
'krutt-tynnen': ('krutt-tynne',),
'krutt-tynnene': ('krutt-tynne',),
'krutt-tynner': ('krutt-tynne',),
'krutt-tårn': ('krutt-tårn',),
'krutt-tårna': ('krutt-tårn',),
'krutt-tårnene': ('krutt-tårn',),
'krutt-tårnet': ('krutt-tårn',),
'krutt-tønna': ('krutt-tønne',),
'krutt-tønne': ('krutt-tønne',),
'krutt-tønnen': ('krutt-tønne',),
'krutt-tønnene': ('krutt-tønne',),
'krutt-tønner': ('krutt-tønne',),
'krutthorn': ('krutthorn',),
'krutthorna': ('krutthorn',),
'krutthornene': ('krutthorn',),
'krutthornet': ('krutthorn',),
'kruttkammer': ('kruttkammer',),
'kruttkammeret': ('kruttkammer',),
'kruttkamra': ('kruttkammer',),
'kruttkamre': ('kruttkammer',),
'kruttkamrene': ('kruttkammer',),
'kruttkjerring': ('kruttkjerring',),
'kruttkjerringa': ('kruttkjerring',),
'kruttkjerringen': ('kruttkjerring',),
'kruttkjerringene': ('kruttkjerring',),
'kruttkjerringer': ('kruttkjerring',),
'kruttlapp': ('kruttlapp',),
'kruttlappen': ('kruttlapp',),
'kruttlappene': ('kruttlapp',),
'kruttlapper': ('kruttlapp',),
'kruttlapp-pistol': ('kruttlapp-pistol',),
'kruttlapp-pistolen': ('kruttlapp-pistol',),
'kruttlapp-pistolene': ('kruttlapp-pistol',),
'kruttlapp-pistoler': ('kruttlapp-pistol',),
'kruttlappistol': ('kruttlappistol',),
'kruttlappistolen': ('kruttlappistol',),
'kruttlappistolene': ('kruttlappistol',),
'kruttlappistoler': ('kruttlappistol',),
'kruttmagasin': ('kruttmagasin',),
'kruttmagasina': ('kruttmagasin',),
'kruttmagasinene': ('kruttmagasin',),
'kruttmagasiner': ('kruttmagasin',),
'kruttmagasinet': ('kruttmagasin',),
'kruttrøyk': ('kruttrøyk',),
'kruttrøyken': ('kruttrøyk',),
'kruttrøykene': ('kruttrøyk',),
'kruttrøyker': ('kruttrøyk',),
'kruttslam': ('kruttslam',),
'kruttslamma': ('kruttslam',),
'kruttslammene': ('kruttslam',),
'kruttslammet': ('kruttslam',),
'kruttverk': ('kruttverk',),
'kruttverka': ('kruttverk',),
'kruttverkene': ('kruttverk',),
'kruttverker': ('kruttverk',),
'kruttverket': ('kruttverk',),
'kruttynna': ('kruttynne',),
'kruttynne': ('kruttynne',),
'kruttynnen': ('kruttynne',),
'kruttynnene': ('kruttynne',),
'kruttynner': ('kruttynne',),
'kruttårn': ('kruttårn',),
'kruttårna': ('kruttårn',),
'kruttårnene': ('kruttårn',),
'kruttårnet': ('kruttårn',),
'kruttønna': ('kruttønne',),
'kruttønne': ('kruttønne',),
'kruttønnen': ('kruttønne',),
'kruttønnene': ('kruttønne',),
'kruttønner': ('kruttønne',),
'krybba': ('krybbe',),
'krybbe': ('krybbe',),
'krybben': ('krybbe',),
'krybbene': ('krybbe',),
'krybber': ('krybbe',),
'krybbebiter': ('krybbebiter',),
'krybbebitere': ('krybbebiter',),
'krybbebiteren': ('krybbebiter',),
'krybbebiterer': ('krybbebiter',),
'krybbebiterne': ('krybbebiter',),
'krybbedød': ('krybbedød',),
'krybbedøden': ('krybbedød',),
'krybbedødene': ('krybbedød',),
'krybbedøder': ('krybbedød',),
'krydder': ('krydder',),
'kryddera': ('krydder',),
'kryddere': ('krydder',),
'krydderet': ('krydder',),
'krydderne': ('krydder',),
'krydderbrennevin': ('krydderbrennevin',),
'krydderbrennevinene': ('krydderbrennevin',),
'krydderbrenneviner': ('krydderbrennevin',),
'krydderbrennevinet': ('krydderbrennevin',),
'krydderhylla': ('krydderhylle',),
'krydderhylle': ('krydderhylle',),
'krydderhyllen': ('krydderhylle',),
'krydderhyllene': ('krydderhylle',),
'krydderhyller': ('krydderhylle',),
'krydderi': ('krydderi',),
'krydderia': ('krydderi',),
'krydderiene': ('krydderi',),
'krydderier': ('krydderi',),
'krydderiet': ('krydderi',),
'krydderkaka': ('krydderkake',),
'krydderkake': ('krydderkake',),
'krydderkaken': ('krydderkake',),
'krydderkakene': ('krydderkake',),
'krydderkaker': ('krydderkake',),
'kryddernellik': ('kryddernellik',),
'kryddernelliken': ('kryddernellik',),
'kryddernellikene': ('kryddernellik',),
'kryddernelliker': ('kryddernellik',),
'kryddernelliktre': ('kryddernelliktre',),
'kryddernelliktrea': ('kryddernelliktre',),
'kryddernelliktreet': ('kryddernelliktre',),
'kryddernelliktrær': ('kryddernelliktre',),
'kryddernelliktrærne': ('kryddernelliktre',),
'krydderplanta': ('krydderplante',),
'krydderplante': ('krydderplante',),
'krydderplanten': ('krydderplante',),
'krydderplantene': ('krydderplante',),
'krydderplanter': ('krydderplante',),
'kryddersild': ('kryddersild',),
'kryddersilda': ('kryddersild',),
'kryddersilden': ('kryddersild',),
'kryddersildene': ('kryddersild',),
'kryddersilder': ('kryddersild',),
'krykka': ('krykke',),
'krykke': ('krykke',),
'krykken': ('krykke',),
'krykkene': ('krykke',),
'krykker': ('krykke',),
'krykkja': ('krykkje',),
'krykkje': ('krykkje',),
'krykkjen': ('krykkje',),
'krykkjene': ('krykkje',),
'krykkjer': ('krykkje',),
'kryl': ('kryl',),
'krylen': ('kryl',),
'krylene': ('kryl',),
'kryler': ('kryl',),
'krymp': ('krymp',),
'krympen': ('krymp',),
'krympene': ('krymp',),
'krymper': ('krymp',),
'krymping': ('krymping',),
'krympinga': ('krymping',),
'krympingen': ('krymping',),
'krympingene': ('krymping',),
'krympinger': ('krymping',),
'kryofor': ('kryofor',),
'kryoforen': ('kryofor',),
'kryoforene': ('kryofor',),
'kryoforer': ('kryofor',),
'kryolitt': ('kryolitt',),
'kryolitten': ('kryolitt',),
'kryolittene': ('kryolitt',),
'kryolitter': ('kryolitt',),
'kryp': ('kryp',),
'krypa': ('kryp',),
'krypen': ('kryp',),
'krypene': ('kryp',),
'krypet': ('kryp',),
'krypdyr': ('krypdyr',),
'krypdyra': ('krypdyr',),
'krypdyrene': ('krypdyr',),
'krypdyret': ('krypdyr',),
'krypinn': ('krypinn',),
'krypinna': ('krypinn',),
'krypinnene': ('krypinn',),
'krypinnet': ('krypinn',),
'krypskytter': ('krypskytter',),
'krypskyttere': ('krypskytter',),
'krypskytteren': ('krypskytter',),
'krypskytterer': ('krypskytter',),
'krypskytterne': ('krypskytter',),
'krypsoleia': ('krypsoleie',),
'krypsoleie': ('krypsoleie',),
'krypsoleien': ('krypsoleie',),
'krypsoleiene': ('krypsoleie',),
'krypsoleier': ('krypsoleie',),
'krypsyl': ('krypsyl',),
'krypsylen': ('krypsyl',),
'krypsylene': ('krypsyl',),
'krypsyler': ('krypsyl',),
'krypt': ('krypt',),
'krypten': ('krypt',),
'kryptene': ('krypt',),
'krypter': ('krypt',),
'kryptogam': ('kryptogam',),
'kryptogamen': ('kryptogam',),
'kryptogamene': ('kryptogam',),
'kryptogamer': ('kryptogam',),
'kryptograf': ('kryptograf',),
'kryptografen': ('kryptograf',),
'kryptografene': ('kryptograf',),
'kryptografer': ('kryptograf',),
'kryptografi': ('kryptografi',),
'kryptografien': ('kryptografi',),
'kryptografiene': ('kryptografi',),
'kryptografier': ('kryptografi',),
'kryptogram': ('kryptogram',),
'kryptogramma': ('kryptogram',),
'kryptogrammene': ('kryptogram',),
'kryptogrammer': ('kryptogram',),
'kryptogrammet': ('kryptogram',),
'kryptokommunisme': ('kryptokommunisme',),
'kryptokommunismen': ('kryptokommunisme',),
'kryptokommunismene': ('kryptokommunisme',),
'kryptokommunismer': ('kryptokommunisme',),
'kryptokommunist': ('kryptokommunist',),
'kryptokommunisten': ('kryptokommunist',),
'kryptokommunistene': ('kryptokommunist',),
'kryptokommunister': ('kryptokommunist',),
'kryptolog': ('kryptolog',),
'kryptologen': ('kryptolog',),
'kryptologene': ('kryptolog',),
'kryptologer': ('kryptolog',),
'kryptologi': ('kryptologi',),
'kryptologien': ('kryptologi',),
'kryptologiene': ('kryptologi',),
'kryptologier': ('kryptologi',),
'krypton': ('krypton',),
'kryptona': ('krypton',),
'kryptonene': ('krypton',),
'kryptonet': ('krypton',),
'krysantemene': ('krysantemum',),
'krysantemer': ('krysantemum',),
'krysantemum': ('krysantemum',),
'krysantemumen': ('krysantemum',),
'krysantemumene': ('krysantemum',),
'krysantemumer': ('krysantemum',),
'krysning': ('krysning',),
'krysninga': ('krysning',),
'krysningen': ('krysning',),
'krysningene': ('krysning',),
'krysninger': ('krysning',),
'krysningspunkt': ('krysningspunkt',),
'krysningspunkta': ('krysningspunkt',),
'krysningspunktene': ('krysningspunkt',),
'krysningspunkter': ('krysningspunkt',),
'krysningspunktet': ('krysningspunkt',),
'krysningsspor': ('krysningsspor',),
'krysningsspora': ('krysningsspor',),
'krysningssporene': ('krysningsspor',),
'krysningssporet': ('krysningsspor',),
'krysolitt': ('krysolitt',),
'krysolitten': ('krysolitt',),
'krysolittene': ('krysolitt',),
'krysolitter': ('krysolitt',),
'kryss': ('kryss',),
'kryssa': ('kryss',),
'kryssene': ('kryss',),
'krysset': ('kryss',),
'kryss': ('kryss',),
'kryssa': ('kryss',),
'kryssene': ('kryss',),
'krysset': ('kryss',),
'kryssbefruktning': ('kryssbefruktning',),
'kryssbefruktninga': ('kryssbefruktning',),
'kryssbefruktningen': ('kryssbefruktning',),
'kryssbefruktningene': ('kryssbefruktning',),
'kryssbefruktninger': ('kryssbefruktning',),
'krysseld': ('krysseld',),
'krysselden': ('krysseld',),
'krysseldene': ('krysseld',),
'krysselder': ('krysseld',),
'krysseld': ('krysseld',),
'krysselden': ('krysseld',),
'krysseldene': ('krysseld',),
'krysselder': ('krysseld',),
'krysser': ('krysser',),
'kryssere': ('krysser',),
'krysseren': ('krysser',),
'krysserer': ('krysser',),
'krysserne': ('krysser',),
'krysserhekk': ('krysserhekk',),
'krysserhekken': ('krysserhekk',),
'krysserhekkene': ('krysserhekk',),
'krysserhekker': ('krysserhekk',),
'krysserrakett': ('krysserrakett',),
'krysserraketten': ('krysserrakett',),
'krysserrakettene': ('krysserrakett',),
'krysserraketter': ('krysserrakett',),
'kryssfiner': ('kryssfiner',),
'kryssfineren': ('kryssfiner',),
'kryssfinerene': ('kryssfiner',),
'kryssfinerer': ('kryssfiner',),
'kryssforhør': ('kryssforhør',),
'kryssforhøra': ('kryssforhør',),
'kryssforhørene': ('kryssforhør',),
'kryssforhøret': ('kryssforhør',),
'krysshenvisning': ('krysshenvisning',),
'krysshenvisninga': ('krysshenvisning',),
'krysshenvisningen': ('krysshenvisning',),
'krysshenvisningene': ('krysshenvisning',),
'krysshenvisninger': ('krysshenvisning',),
'kryssholt': ('kryssholt',),
'kryssholta': ('kryssholt',),
'kryssholten': ('kryssholt',),
'kryssholtene': ('kryssholt',),
'kryssholter': ('kryssholt',),
'kryssholtet': ('kryssholt',),
'kryssild': ('kryssild',),
'kryssilden': ('kryssild',),
'kryssildene': ('kryssild',),
'kryssilder': ('kryssild',),
'kryssild': ('kryssild',),
'kryssilden': ('kryssild',),
'kryssildene': ('kryssild',),
'kryssilder': ('kryssild',),
'kryssord': ('kryssord',),
'kryssorda': ('kryssord',),
'kryssordene': ('kryssord',),
'kryssordet': ('kryssord',),
'kryssordoppgava': ('kryssordoppgave',),
'kryssordoppgave': ('kryssordoppgave',),
'kryssordoppgaven': ('kryssordoppgave',),
'kryssordoppgavene': ('kryssordoppgave',),
'kryssordoppgaver': ('kryssordoppgave',),
'krysspeiling': ('krysspeiling',),
'krysspeilinga': ('krysspeiling',),
'krysspeilingen': ('krysspeiling',),
'krysspeilingene': ('krysspeiling',),
'krysspeilinger': ('krysspeiling',),
'krysspress': ('krysspress',),
'krysspressa': ('krysspress',),
'krysspressene': ('krysspress',),
'krysspresset': ('krysspress',),
'kryssrim': ('kryssrim',),
'kryssrima': ('kryssrim',),
'kryssrimene': ('kryssrim',),
'kryssrimet': ('kryssrim',),
'krystall': ('krystall',),
'krystalla': ('krystall',),
'krystallen': ('krystall',),
'krystallene': ('krystall',),
'krystaller': ('krystall',),
'krystallet': ('krystall',),
'krystallapparat': ('krystallapparat',),
'krystallapparata': ('krystallapparat',),
'krystallapparatene': ('krystallapparat',),
'krystallapparater': ('krystallapparat',),
'krystallapparatet': ('krystallapparat',),
'krystallgitra': ('krystallgitter',),
'krystallgitre': ('krystallgitter',),
'krystallgitrene': ('krystallgitter',),
'krystallgitret': ('krystallgitter',),
'krystallgitter': ('krystallgitter',),
'krystallgitteret': ('krystallgitter',),
'krystallglass': ('krystallglass',),
'krystallglassa': ('krystallglass',),
'krystallglassene': ('krystallglass',),
'krystallglasset': ('krystallglass',),
'krystallin': ('krystallin',),
'krystallina': ('krystallin',),
'krystallinene': ('krystallin',),
'krystallinet': ('krystallin',),
'krystallisasjon': ('krystallisasjon',),
'krystallisasjonen': ('krystallisasjon',),
'krystallisasjonene': ('krystallisasjon',),
'krystallisasjoner': ('krystallisasjon',),
'krystallografi': ('krystallografi',),
'krystallografien': ('krystallografi',),
'krystallografiene': ('krystallografi',),
'krystallografier': ('krystallografi',),
'krystalloid': ('krystalloid',),
'krystalloida': ('krystalloid',),
'krystalloidene': ('krystalloid',),
'krystalloider': ('krystalloid',),
'krystalloidet': ('krystalloid',),
'krystallosett': ('krystallosett',),
'krystallosetten': ('krystallosett',),
'krystallosettene': ('krystallosett',),
'krystallosetter': ('krystallosett',),
'krystallstruktur': ('krystallstruktur',),
'krystallstrukturen': ('krystallstruktur',),
'krystallstrukturene': ('krystallstruktur',),
'krystallstrukturer': ('krystallstruktur',),
'krystallvann': ('krystallvann',),
'krystallvanna': ('krystallvann',),
'krystallvannene': ('krystallvann',),
'krystallvannet': ('krystallvann',),
'krystallvatn': ('krystallvatn',),
'krystallvatna': ('krystallvatn',),
'krystallvatnene': ('krystallvatn',),
'krystallvatnet': ('krystallvatn',),
'krå': ('krå',),
'kråa': ('krå',),
'kråen': ('krå',),
'krær': ('krå',),
'krærne': ('krå',),
'kråka': ('kråke',),
'kråke': ('kråke',),
'kråken': ('kråke',),
'kråkene': ('kråke',),
'kråker': ('kråke',),
'kråkebolle': ('kråkebolle',),
'kråkebollen': ('kråkebolle',),
'kråkebollene': ('kråkebolle',),
'kråkeboller': ('kråkebolle',),
'kråkebær': ('kråkebær',),
'kråkebæra': ('kråkebær',),
'kråkebærene': ('kråkebær',),
'kråkebæret': ('kråkebær',),
'kråkefugl': ('kråkefugl',),
'kråkefuglen': ('kråkefugl',),
'kråkefuglene': ('kråkefugl',),
'kråkefugler': ('kråkefugl',),
'kråkemål': ('kråkemål',),
'kråkemåla': ('kråkemål',),
'kråkemålene': ('kråkemål',),
'kråkemålet': ('kråkemål',),
'kråkeskjell': ('kråkeskjell',),
'kråkeskjella': ('kråkeskjell',),
'kråkeskjellen': ('kråkeskjell',),
'kråkeskjellene': ('kråkeskjell',),
'kråkeskjellet': ('kråkeskjell',),
'kråkesølv': ('kråkesølv',),
'kråkesølva': ('kråkesølv',),
'kråkesølvene': ('kråkesølv',),
'kråkesølvet': ('kråkesølv',),
'kråketing': ('kråketing',),
'kråketinga': ('kråketing',),
'kråketingene': ('kråketing',),
'kråketinget': ('kråketing',),
'krål': ('krål',),
'krålen': ('krål',),
'krålene': ('krål',),
'kråler': ('krål',),
'krås': ('krås',),
'kråsen': ('krås',),
'kråsene': ('krås',),
'kråser': ('krås',),
'kråskap': ('kråskap',),
'kråskapa': ('kråskap',),
'kråskapene': ('kråskap',),
'kråskapet': ('kråskap',),
'krøkka': ('krøkke',),
'krøkke': ('krøkke',),
'krøkken': ('krøkke',),
'krøkkene': ('krøkke',),
'krøkker': ('krøkke',),
'krøkla': ('krøkle',),
'krøkle': ('krøkle',),
'krøklen': ('krøkle',),
'krøklene': ('krøkle',),
'krøkler': ('krøkle',),
'krøkla': ('krøkle',),
'krøkle': ('krøkle',),
'krøklen': ('krøkle',),
'krøklene': ('krøkle',),
'krøkler': ('krøkle',),
'krøll': ('krøll',),
'krøllen': ('krøll',),
'krøllene': ('krøll',),
'krøller': ('krøll',),
'krøll-lilja': ('krøll-lilje',),
'krøll-lilje': ('krøll-lilje',),
'krøll-liljen': ('krøll-lilje',),
'krøll-liljene': ('krøll-lilje',),
'krøll-liljer': ('krøll-lilje',),
'krølla': ('krølle',),
'krølle': ('krølle',),
'krøllen': ('krølle',),
'krøllene': ('krølle',),
'krøller': ('krølle',),
'krøllhår': ('krøllhår',),
'krøllhåra': ('krøllhår',),
'krøllhårene': ('krøllhår',),
'krøllhåret': ('krøllhår',),
'krøllilja': ('krøllilje',),
'krøllilje': ('krøllilje',),
'krølliljen': ('krøllilje',),
'krølliljene': ('krøllilje',),
'krølliljer': ('krøllilje',),
'krølltang': ('krølltang',),
'krølltanga': ('krølltang',),
'krølltangen': ('krølltang',),
'krølltengene': ('krølltang',),
'krølltenger': ('krølltang',),
'krølltopp': ('krølltopp',),
'krølltoppen': ('krølltopp',),
'krølltoppene': ('krølltopp',),
'krølltopper': ('krølltopp',),
'krønika': ('krønike',),
'krønike': ('krønike',),
'krøniken': ('krønike',),
'krønikene': ('krønike',),
'krøniker': ('krønike',),
'krønikeskriver': ('krønikeskriver',),
'krønikeskrivere': ('krønikeskriver',),
'krønikeskriveren': ('krønikeskriver',),
'krønikeskriverer': ('krønikeskriver',),
'krønikeskriverne': ('krønikeskriver',),
'krøpling': ('krøpling',),
'krøplingen': ('krøpling',),
'krøplingene': ('krøpling',),
'krøplinger': ('krøpling',),
'krøs': ('krøs',),
'krøsa': ('krøs',),
'krøsene': ('krøs',),
'krøset': ('krøs',),
'krøsus': ('krøsus',),
'krøsusen': ('krøsus',),
'krøsusene': ('krøsus',),
'krøsuser': ('krøsus',),
'krøtter': ('krøtter',),
'krøttera': ('krøtter',),
'krøtteret': ('krøtter',),
'krøtterne': ('krøtter',),
'krøttersti': ('krøttersti',),
'krøtterstien': ('krøttersti',),
'krøtterstiene': ('krøttersti',),
'krøtterstier': ('krøttersti',),
'ku': ('ku',),
'kua': ('ku',),
'kuen': ('ku',),
'kuene': ('ku',),
'kuer': ('ku',),
'kyr': ('ku',),
'kyrne': ('ku',),
'kuband': ('kuband',),
'kubanda': ('kuband',),
'kubandene': ('kuband',),
'kubandet': ('kuband',),
'kubaner': ('kubaner',),
'kubanere': ('kubaner',),
'kubaneren': ('kubaner',),
'kubanerer': ('kubaner',),
'kubanerne': ('kubaner',),
'kubb': ('kubb',),
'kubben': ('kubb',),
'kubbene': ('kubb',),
'kubber': ('kubb',),
'kubbe': ('kubbe',),
'kubben': ('kubbe',),
'kubbene': ('kubbe',),
'kubber': ('kubbe',),
'kubbelys': ('kubbelys',),
'kubbelysa': ('kubbelys',),
'kubbelysene': ('kubbelys',),
'kubbelyset': ('kubbelys',),
'kubbestol': ('kubbestol',),
'kubbestolen': ('kubbestol',),
'kubbestolene': ('kubbestol',),
'kubbestoler': ('kubbestol',),
'kubbeved': ('kubbeved',),
'kubbeveden': ('kubbeved',),
'kubbevedene': ('kubbeved',),
'kubbeveder': ('kubbeved',),
'kubbtømmer': ('kubbtømmer',),
'kubbtømmera': ('kubbtømmer',),
'kubbtømmerene': ('kubbtømmer',),
'kubbtømmeret': ('kubbtømmer',),
'kubbtømra': ('kubbtømmer',),
'kubbtømre': ('kubbtømmer',),
'kubbtømrene': ('kubbtømmer',),
'kube': ('kube',),
'kuben': ('kube',),
'kubene': ('kube',),
'kuber': ('kube',),
'kube': ('kube',),
'kuben': ('kube',),
'kubene': ('kube',),
'kuber': ('kube',),
'kubein': ('kubein',),
'kubeina': ('kubein',),
'kubeinene': ('kubein',),
'kubeinet': ('kubein',),
'kuben': ('kuben',),
'kubena': ('kuben',),
'kubenene': ('kuben',),
'kubenet': ('kuben',),
'kuben': ('kuben',),
'kubena': ('kuben',),
'kubenene': ('kuben',),
'kubenet': ('kuben',),
'kubikk': ('kubikk',),
'kubikken': ('kubikk',),
'kubikkene': ('kubikk',),
'kubikkcentimeter': ('kubikkcentimeter',),
'kubikkcentimeteren': ('kubikkcentimeter',),
'kubikkcentimeterne': ('kubikkcentimeter',),
'kubikkdesimeter': ('kubikkdesimeter',),
'kubikkdesimeteren': ('kubikkdesimeter',),
'kubikkdesimeterne': ('kubikkdesimeter',),
'kubikkenhet': ('kubikkenhet',),
'kubikkenheta': ('kubikkenhet',),
'kubikkenheten': ('kubikkenhet',),
'kubikkenhetene': ('kubikkenhet',),
'kubikkenheter': ('kubikkenhet',),
'kubikker': ('kubikker',),
'kubikkere': ('kubikker',),
'kubikkeren': ('kubikker',),
'kubikkerer': ('kubikker',),
'kubikkerne': ('kubikker',),
'kubikkinnhold': ('kubikkinnhold',),
'kubikkinnholda': ('kubikkinnhold',),
'kubikkinnholdene': ('kubikkinnhold',),
'kubikkinnholdet': ('kubikkinnhold',),
'kubikkrot': ('kubikkrot',),
'kubikkrota': ('kubikkrot',),
'kubikkroten': ('kubikkrot',),
'kubikkrøttene': ('kubikkrot',),
'kubikkrøtter': ('kubikkrot',),
'kubikksjarmør': ('kubikksjarmør',),
'kubikksjarmøren': ('kubikksjarmør',),
'kubikksjarmørene': ('kubikksjarmør',),
'kubikksjarmører': ('kubikksjarmør',),
'kubikktal': ('kubikktal',),
'kubikktala': ('kubikktal',),
'kubikktalene': ('kubikktal',),
'kubikktalet': ('kubikktal',),
'kubikktall': ('kubikktall',),
'kubikktalla': ('kubikktall',),
'kubikktallene': ('kubikktall',),
'kubikktallet': ('kubikktall',),
'kubisme': ('kubisme',),
'kubismen': ('kubisme',),
'kubismene': ('kubisme',),
'kubismer': ('kubisme',),
'kubist': ('kubist',),
'kubisten': ('kubist',),
'kubistene': ('kubist',),
'kubister': ('kubist',),
'kubjella': ('kubjelle',),
'kubjelle': ('kubjelle',),
'kubjellen': ('kubjelle',),
'kubjellene': ('kubjelle',),
'kubjeller': ('kubjelle',),
'kubjølla': ('kubjølle',),
'kubjølle': ('kubjølle',),
'kubjøllen': ('kubjølle',),
'kubjøllene': ('kubjølle',),
'kubjøller': ('kubjølle',),
'kubrems': ('kubrems',),
'kubremsen': ('kubrems',),
'kubremsene': ('kubrems',),
'kubremser': ('kubrems',),
'kubus': ('kubus',),
'kubusen': ('kubus',),
'kubusene': ('kubus',),
'kubuser': ('kubus',),
'kubånd': ('kubånd',),
'kubånda': ('kubånd',),
'kubåndene': ('kubånd',),
'kubåndet': ('kubånd',),
'kudu': ('kudu',),
'kuduen': ('kudu',),
'kuduene': ('kudu',),
'kuduer': ('kudu',),
'kufôrblanding': ('kufôrblanding',),
'kufôrblandinga': ('kufôrblanding',),
'kufôrblandingen': ('kufôrblanding',),
'kufôrblandingene': ('kufôrblanding',),
'kufôrblandinger': ('kufôrblanding',),
'kufanger': ('kufanger',),
'kufangere': ('kufanger',),
'kufangeren': ('kufanger',),
'kufangerer': ('kufanger',),
'kufangerne': ('kufanger',),
'kufta': ('kufte',),
'kufte': ('kufte',),
'kuften': ('kufte',),
'kuftene': ('kufte',),
'kufter': ('kufte',),
'kuguar': ('kuguar',),
'kuguaren': ('kuguar',),
'kuguarene': ('kuguar',),
'kuguarer': ('kuguar',),
'kujon': ('kujon',),
'kujonen': ('kujon',),
'kujonene': ('kujon',),
'kujoner': ('kujon',),
'kujoneri': ('kujoneri',),
'kujoneria': ('kujoneri',),
'kujoneriene': ('kujoneri',),
'kujoneriet': ('kujoneri',),
'kuk': ('kuk',),
'kuken': ('kuk',),
'kukene': ('kuk',),
'kuker': ('kuk',),
'kukaka': ('kukake',),
'kukake': ('kukake',),
'kukaken': ('kukake',),
'kukakene': ('kukake',),
'kukaker': ('kukake',),
'kukelure': ('kukelure',),
'kukeluren': ('kukelure',),
'kukelurene': ('kukelure',),
'kukelurer': ('kukelure',),
'kukk': ('kukk',),
'kukken': ('kukk',),
'kukkene': ('kukk',),
'kukker': ('kukk',),
'kuklegg': ('kuklegg',),
'kukleggen': ('kuklegg',),
'kukleggene': ('kuklegg',),
'kuklegger': ('kuklegg',),
'kukoppene': ('kukopper',),
'kukopper': ('kukopper',),
'kul': ('kul',),
'kulen': ('kul',),
'kulene': ('kul',),
'kuler': ('kul',),
'kulak': ('kulak',),
'kulaken': ('kulak',),
'kulakene': ('kulak',),
'kulaker': ('kulak',),
'kulakk': ('kulakk',),
'kulakken': ('kulakk',),
'kulakkene': ('kulakk',),
'kulakker': ('kulakk',),
'kulda': ('kulde',),
'kulde': ('kulde',),
'kulden': ('kulde',),
'kuldene': ('kulde',),
'kulder': ('kulde',),
'kuldebelta': ('kuldebelte',),
'kuldebelte': ('kuldebelte',),
'kuldebeltene': ('kuldebelte',),
'kuldebelter': ('kuldebelte',),
'kuldebeltet': ('kuldebelte',),
'kuldeblanding': ('kuldeblanding',),
'kuldeblandinga': ('kuldeblanding',),
'kuldeblandingen': ('kuldeblanding',),
'kuldeblandingene': ('kuldeblanding',),
'kuldeblandinger': ('kuldeblanding',),
'kuldebro': ('kuldebro',),
'kuldebroa': ('kuldebro',),
'kuldebroen': ('kuldebro',),
'kuldebroene': ('kuldebro',),
'kuldebroer': ('kuldebro',),
'kuldebru': ('kuldebru',),
'kuldebrua': ('kuldebru',),
'kuldebruen': ('kuldebru',),
'kuldebruene': ('kuldebru',),
'kuldebruer': ('kuldebru',),
'kuldebølga': ('kuldebølge',),
'kuldebølge': ('kuldebølge',),
'kuldebølgen': ('kuldebølge',),
'kuldebølgene': ('kuldebølge',),
'kuldebølger': ('kuldebølge',),
'kuldebølgja': ('kuldebølgje',),
'kuldebølgje': ('kuldebølgje',),
'kuldebølgjen': ('kuldebølgje',),
'kuldebølgjene': ('kuldebølgje',),
'kuldebølgjer': ('kuldebølgje',),
'kuldegrad': ('kuldegrad',),
'kuldegraden': ('kuldegrad',),
'kuldegradene': ('kuldegrad',),
'kuldegrader': ('kuldegrad',),
'kuldegys': ('kuldegys',),
'kuldegysa': ('kuldegys',),
'kuldegysene': ('kuldegys',),
'kuldegyset': ('kuldegys',),
'kuldegysning': ('kuldegysning',),
'kuldegysninga': ('kuldegysning',),
'kuldegysningen': ('kuldegysning',),
'kuldegysningene': ('kuldegysning',),
'kuldegysninger': ('kuldegysning',),
'kuldemaskin': ('kuldemaskin',),
'kuldemaskina': ('kuldemaskin',),
'kuldemaskinen': ('kuldemaskin',),
'kuldemaskinene': ('kuldemaskin',),
'kuldemaskiner': ('kuldemaskin',),
'kuldeperiode': ('kuldeperiode',),
'kuldeperioden': ('kuldeperiode',),
'kuldeperiodene': ('kuldeperiode',),
'kuldeperioder': ('kuldeperiode',),
'kuldepol': ('kuldepol',),
'kuldepolen': ('kuldepol',),
'kuldepolene': ('kuldepol',),
'kuldepoler': ('kuldepol',),
'kuldepunkt': ('kuldepunkt',),
'kuldepunkta': ('kuldepunkt',),
'kuldepunktene': ('kuldepunkt',),
'kuldepunkter': ('kuldepunkt',),
'kuldepunktet': ('kuldepunkt',),
'kuldesans': ('kuldesans',),
'kuldesansen': ('kuldesans',),
'kuldesansene': ('kuldesans',),
'kuldesanser': ('kuldesans',),
'kula': ('kule',),
'kule': ('kule',),
'kulen': ('kule',),
'kulene': ('kule',),
'kuler': ('kule',),
'kula': ('kule',),
'kule': ('kule',),
'kulen': ('kule',),
'kulene': ('kule',),
'kuler': ('kule',),
'kula': ('kule',),
'kule': ('kule',),
'kulen': ('kule',),
'kulene': ('kule',),
'kuler': ('kule',),
'kulebakterie': ('kulebakterie',),
'kulebakterien': ('kulebakterie',),
'kulebakteriene': ('kulebakterie',),
'kulebakterier': ('kulebakterie',),
'kulebane': ('kulebane',),
'kulebanen': ('kulebane',),
'kulebanene': ('kulebane',),
'kulebaner': ('kulebane',),
'kuleflata': ('kuleflate',),
'kuleflate': ('kuleflate',),
'kuleflaten': ('kuleflate',),
'kuleflatene': ('kuleflate',),
'kuleflater': ('kuleflate',),
'kulehoda': ('kulehode',),
'kulehode': ('kulehode',),
'kulehodene': ('kulehode',),
'kulehoder': ('kulehode',),
'kulehodet': ('kulehode',),
'kulehodemaskin': ('kulehodemaskin',),
'kulehodemaskina': ('kulehodemaskin',),
'kulehodemaskinen': ('kulehodemaskin',),
'kulehodemaskinene': ('kulehodemaskin',),
'kulehodemaskiner': ('kulehodemaskin',),
'kulehol': ('kulehol',),
'kulehola': ('kulehol',),
'kuleholene': ('kulehol',),
'kuleholet': ('kulehol',),
'kulehull': ('kulehull',),
'kulehulla': ('kulehull',),
'kulehullene': ('kulehull',),
'kulehuller': ('kulehull',),
'kulehullet': ('kulehull',),
'kulekjøring': ('kulekjøring',),
'kulekjøringa': ('kulekjøring',),
'kulekjøringen': ('kulekjøring',),
'kulekjøringene': ('kulekjøring',),
'kulekjøringer': ('kulekjøring',),
'kulelager': ('kulelager',),
'kulelageret': ('kulelager',),
'kulelagra': ('kulelager',),
'kulelagre': ('kulelager',),
'kulelagrene': ('kulelager',),
'kuleledd': ('kuleledd',),
'kuleledda': ('kuleledd',),
'kuleleddene': ('kuleledd',),
'kuleleddet': ('kuleledd',),
'kulelyn': ('kulelyn',),
'kulelyna': ('kulelyn',),
'kulelynene': ('kulelyn',),
'kulelynet': ('kulelyn',),
'kulemage': ('kulemage',),
'kulemagen': ('kulemage',),
'kulemagene': ('kulemage',),
'kulemager': ('kulemage',),
'kulepenn': ('kulepenn',),
'kulepennen': ('kulepenn',),
'kulepennene': ('kulepenn',),
'kulepenner': ('kulepenn',),
'kuleramma': ('kuleramme',),
'kuleramme': ('kuleramme',),
'kulerammen': ('kuleramme',),
'kulerammene': ('kuleramme',),
'kulerammer': ('kuleramme',),
'kuleregn': ('kuleregn',),
'kuleregna': ('kuleregn',),
'kuleregnene': ('kuleregn',),
'kuleregnet': ('kuleregn',),
'kulestøt': ('kulestøt',),
'kulestøta': ('kulestøt',),
'kulestøtene': ('kulestøt',),
'kulestøtet': ('kulestøt',),
'kulestøter': ('kulestøter',),
'kulestøtere': ('kulestøter',),
'kulestøteren': ('kulestøter',),
'kulestøterer': ('kulestøter',),
'kulestøterne': ('kulestøter',),
'kulestøyt': ('kulestøyt',),
'kulestøyten': ('kulestøyt',),
'kulestøytene': ('kulestøyt',),
'kulestøyter': ('kulestøyt',),
'kulestøyter': ('kulestøyter',),
'kulestøytere': ('kulestøyter',),
'kulestøyteren': ('kulestøyter',),
'kulestøyterer': ('kulestøyter',),
'kulestøyterne': ('kulestøyter',),
'kuleventil': ('kuleventil',),
'kuleventilen': ('kuleventil',),
'kuleventilene': ('kuleventil',),
'kuleventiler': ('kuleventil',),
'kuli': ('kuli',),
'kulien': ('kuli',),
'kuliene': ('kuli',),
'kulier': ('kuli',),
'kuling': ('kuling',),
'kulingen': ('kuling',),
'kulingene': ('kuling',),
'kulinger': ('kuling',),
'kulissa': ('kulisse',),
'kulisse': ('kulisse',),
'kulissen': ('kulisse',),
'kulissene': ('kulisse',),
'kulisser': ('kulisse',),
'kull': ('kull',),
'kulla': ('kull',),
'kullene': ('kull',),
'kullet': ('kull',),
'kull': ('kull',),
'kulla': ('kull',),
'kullene': ('kull',),
'kullet': ('kull',),
'kull': ('kull',),
'kullbrenner': ('kullbrenner',),
'kullbrennere': ('kullbrenner',),
'kullbrenneren': ('kullbrenner',),
'kullbrennerer': ('kullbrenner',),
'kullbrennerne': ('kullbrenner',),
'kulldioksid': ('kulldioksid',),
'kulldioksida': ('kulldioksid',),
'kulldioksidene': ('kulldioksid',),
'kulldioksider': ('kulldioksid',),
'kulldioksidet': ('kulldioksid',),
'kullgruva': ('kullgruve',),
'kullgruve': ('kullgruve',),
'kullgruven': ('kullgruve',),
'kullgruvene': ('kullgruve',),
'kullgruver': ('kullgruve',),
'kullhydrat': ('kullhydrat',),
'kullhydrata': ('kullhydrat',),
'kullhydratene': ('kullhydrat',),
'kullhydrater': ('kullhydrat',),
'kullhydratet': ('kullhydrat',),
'kullmila': ('kullmile',),
'kullmile': ('kullmile',),
'kullmilen': ('kullmile',),
'kullmilene': ('kullmile',),
'kullmiler': ('kullmile',),
'kulloksid': ('kulloksid',),
'kulloksida': ('kulloksid',),
'kulloksidene': ('kulloksid',),
'kulloksider': ('kulloksid',),
'kulloksidet': ('kulloksid',),
'kullos': ('kullos',),
'kullosen': ('kullos',),
'kullosene': ('kullos',),
'kulloser': ('kullos',),
'kullstift': ('kullstift',),
'kullstiften': ('kullstift',),
'kullstiftene': ('kullstift',),
'kullstifter': ('kullstift',),
'kullstoff': ('kullstoff',),
'kullstoffa': ('kullstoff',),
'kullstoffene': ('kullstoff',),
'kullstoffer': ('kullstoff',),
'kullstoffet': ('kullstoff',),
'kullstøv': ('kullstøv',),
'kullstøva': ('kullstøv',),
'kullstøvene': ('kullstøv',),
'kullstøvet': ('kullstøv',),
'kullsviertro': ('kullsviertro',),
'kullsviertroa': ('kullsviertro',),
'kullsviertroen': ('kullsviertro',),
'kullsviertroene': ('kullsviertro',),
'kullsviertroer': ('kullsviertro',),
'kullsviertru': ('kullsviertru',),
'kullsviertrua': ('kullsviertru',),
'kullsviertruen': ('kullsviertru',),
'kullsviertruene': ('kullsviertru',),
'kullsviertruer': ('kullsviertru',),
'kullsyra': ('kullsyre',),
'kullsyre': ('kullsyre',),
'kullsyren': ('kullsyre',),
'kullsyrene': ('kullsyre',),
'kullsyrer': ('kullsyre',),
'kullsyreassimilasjon': ('kullsyreassimilasjon',),
'kullsyreassimilasjonen': ('kullsyreassimilasjon',),
'kullsyreassimilasjonene': ('kullsyreassimilasjon',),
'kullsyreassimilasjoner': ('kullsyreassimilasjon',),
'kullsyreis': ('kullsyreis',),
'kullsyreisen': ('kullsyreis',),
'kullsyreisene': ('kullsyreis',),
'kullsyreiser': ('kullsyreis',),
'kulltegning': ('kulltegning',),
'kulltegninga': ('kulltegning',),
'kulltegningen': ('kulltegning',),
'kulltegningene': ('kulltegning',),
'kulltegninger': ('kulltegning',),
'kulltråd': ('kulltråd',),
'kulltråden': ('kulltråd',),
'kulltrådene': ('kulltråd',),
'kulltråder': ('kulltråd',),
'kulminasjon': ('kulminasjon',),
'kulminasjonen': ('kulminasjon',),
'kulminasjonene': ('kulminasjon',),
'kulminasjoner': ('kulminasjon',),
'kulokk': ('kulokk',),
'kulokken': ('kulokk',),
'kulokkene': ('kulokk',),
'kulokker': ('kulokk',),
'kulp': ('kulp',),
'kulpen': ('kulp',),
'kulpene': ('kulp',),
'kulper': ('kulp',),
'kuls': ('kuls',),
'kulsen': ('kuls',),
'kulsene': ('kuls',),
'kulser': ('kuls',),
'kult': ('kult',),
'kulten': ('kult',),
'kultene': ('kult',),
'kulter': ('kult',),
'kult': ('kult',),
'kulten': ('kult',),
'kultene': ('kult',),
'kulter': ('kult',),
'kultivar': ('kultivar',),
'kultivaren': ('kultivar',),
'kultivarene': ('kultivar',),
'kultivarer': ('kultivar',),
'kultivator': ('kultivator',),
'kultivatoren': ('kultivator',),
'kultivatorene': ('kultivator',),
'kultivatorer': ('kultivator',),
'kultminna': ('kultminne',),
'kultminne': ('kultminne',),
'kultminnene': ('kultminne',),
'kultminner': ('kultminne',),
'kultminnet': ('kultminne',),
'kultsted': ('kultsted',),
'kultstedene': ('kultsted',),
'kultsteder': ('kultsted',),
'kultstedet': ('kultsted',),
'kultur': ('kultur',),
'kulturen': ('kultur',),
'kulturene': ('kultur',),
'kulturer': ('kultur',),
'kulturantropologi': ('kulturantropologi',),
'kulturantropologien': ('kulturantropologi',),
'kulturantropologiene': ('kulturantropologi',),
'kulturantropologier': ('kulturantropologi',),
'kulturarbeid': ('kulturarbeid',),
'kulturarbeida': ('kulturarbeid',),
'kulturarbeidene': ('kulturarbeid',),
'kulturarbeider': ('kulturarbeid',),
'kulturarbeidet': ('kulturarbeid',),
'kulturarbeider': ('kulturarbeider',),
'kulturarbeidere': ('kulturarbeider',),
'kulturarbeideren': ('kulturarbeider',),
'kulturarbeiderer': ('kulturarbeider',),
'kulturarbeiderne': ('kulturarbeider',),
'kulturarv': ('kulturarv',),
'kulturarven': ('kulturarv',),
'kulturarvene': ('kulturarv',),
'kulturarver': ('kulturarv',),
'kulturavtale': ('kulturavtale',),
'kulturavtalen': ('kulturavtale',),
'kulturavtalene': ('kulturavtale',),
'kulturavtaler': ('kulturavtale',),
'kulturbeita': ('kulturbeite',),
'kulturbeite': ('kulturbeite',),
'kulturbeitene': ('kulturbeite',),
'kulturbeiter': ('kulturbeite',),
'kulturbeitet': ('kulturbeite',),
'kultureng': ('kultureng',),
'kulturenga': ('kultureng',),
'kulturengen': ('kultureng',),
'kulturengene': ('kultureng',),
'kulturenger': ('kultureng',),
'kulturfolk': ('kulturfolk',),
'kulturfolka': ('kulturfolk',),
'kulturfolkene': ('kulturfolk',),
'kulturfolket': ('kulturfolk',),
'kulturfond': ('kulturfond',),
'kulturfonda': ('kulturfond',),
'kulturfondene': ('kulturfond',),
'kulturfondet': ('kulturfond',),
'kulturform': ('kulturform',),
'kulturforma': ('kulturform',),
'kulturformen': ('kulturform',),
'kulturformene': ('kulturform',),
'kulturformer': ('kulturform',),
'kulturhistoria': ('kulturhistorie',),
'kulturhistorie': ('kulturhistorie',),
'kulturhistorien': ('kulturhistorie',),
'kulturhistoriene': ('kulturhistorie',),
'kulturhistorier': ('kulturhistorie',),
'kulturimperialisme': ('kulturimperialisme',),
'kulturimperialismen': ('kulturimperialisme',),
'kulturimperialismene': ('kulturimperialisme',),
'kulturimperialismer': ('kulturimperialisme',),
'kulturjord': ('kulturjord',),
'kulturjorda': ('kulturjord',),
'kulturjorden': ('kulturjord',),
'kulturjordene': ('kulturjord',),
'kulturjorder': ('kulturjord',),
'kulturkamp': ('kulturkamp',),
'kulturkampen': ('kulturkamp',),
'kulturkampene': ('kulturkamp',),
'kulturkamper': ('kulturkamp',),
'kulturkløft': ('kulturkløft',),
'kulturkløfta': ('kulturkløft',),
'kulturkløften': ('kulturkløft',),
'kulturkløftene': ('kulturkløft',),
'kulturkløfter': ('kulturkløft',),
'kulturkollisjon': ('kulturkollisjon',),
'kulturkollisjonen': ('kulturkollisjon',),
'kulturkollisjonene': ('kulturkollisjon',),
'kulturkollisjoner': ('kulturkollisjon',),
'kulturkrets': ('kulturkrets',),
'kulturkretsen': ('kulturkrets',),
'kulturkretsene': ('kulturkrets',),
'kulturkretser': ('kulturkrets',),
'kulturkveld': ('kulturkveld',),
'kulturkvelden': ('kulturkveld',),
'kulturkveldene': ('kulturkveld',),
'kulturkvelder': ('kulturkveld',),
'kulturland': ('kulturland',),
'kulturlanda': ('kulturland',),
'kulturlandene': ('kulturland',),
'kulturlandet': ('kulturland',),
'kulturlandskap': ('kulturlandskap',),
'kulturlandskapa': ('kulturlandskap',),
'kulturlandskapene': ('kulturlandskap',),
'kulturlandskaper': ('kulturlandskap',),
'kulturlandskapet': ('kulturlandskap',),
'kulturliv': ('kulturliv',),
'kulturliva': ('kulturliv',),
'kulturlivene': ('kulturliv',),
'kulturlivet': ('kulturliv',),
'kulturlån': ('kulturlån',),
'kulturlåna': ('kulturlån',),
'kulturlånene': ('kulturlån',),
'kulturlånet': ('kulturlån',),
'kulturmelk': ('kulturmelk',),
'kulturmelka': ('kulturmelk',),
'kulturmelken': ('kulturmelk',),
'kulturmelkene': ('kulturmelk',),
'kulturmelker': ('kulturmelk',),
'kulturminna': ('kulturminne',),
'kulturminne': ('kulturminne',),
'kulturminnene': ('kulturminne',),
'kulturminner': ('kulturminne',),
'kulturminnet': ('kulturminne',),
'kulturmord': ('kulturmord',),
'kulturmorda': ('kulturmord',),
'kulturmordene': ('kulturmord',),
'kulturmordet': ('kulturmord',),
'kulturnasjon': ('kulturnasjon',),
'kulturnasjonen': ('kulturnasjon',),
'kulturnasjonene': ('kulturnasjon',),
'kulturnasjoner': ('kulturnasjon',),
'kulturnavn': ('kulturnavn',),
'kulturnavna': ('kulturnavn',),
'kulturnavnene': ('kulturnavn',),
'kulturnavnet': ('kulturnavn',),
'kulturpause': ('kulturpause',),
'kulturpausen': ('kulturpause',),
'kulturpausene': ('kulturpause',),
'kulturpauser': ('kulturpause',),
'kulturperla': ('kulturperle',),
'kulturperle': ('kulturperle',),
'kulturperlen': ('kulturperle',),
'kulturperlene': ('kulturperle',),
'kulturperler': ('kulturperle',),
'kulturperson': ('kulturperson',),
'kulturpersonen': ('kulturperson',),
'kulturpersonene': ('kulturperson',),
'kulturpersoner': ('kulturperson',),
'kulturpersonlighet': ('kulturpersonlighet',),
'kulturpersonligheta': ('kulturpersonlighet',),
'kulturpersonligheten': ('kulturpersonlighet',),
'kulturpersonlighetene': ('kulturpersonlighet',),
'kulturpersonligheter': ('kulturpersonlighet',),
'kulturplanta': ('kulturplante',),
'kulturplante': ('kulturplante',),
'kulturplanten': ('kulturplante',),
'kulturplantene': ('kulturplante',),
'kulturplanter': ('kulturplante',),
'kulturradikaler': ('kulturradikaler',),
'kulturradikalere': ('kulturradikaler',),
'kulturradikaleren': ('kulturradikaler',),
'kulturradikalerer': ('kulturradikaler',),
'kulturradikalerne': ('kulturradikaler',),
'kulturradikalisme': ('kulturradikalisme',),
'kulturradikalismen': ('kulturradikalisme',),
'kulturradikalismene': ('kulturradikalisme',),
'kulturradikalismer': ('kulturradikalisme',),
'kulturrase': ('kulturrase',),
'kulturrasen': ('kulturrase',),
'kulturrasene': ('kulturrase',),
'kulturraser': ('kulturrase',),
'kulturredaktør': ('kulturredaktør',),
'kulturredaktøren': ('kulturredaktør',),
'kulturredaktørene': ('kulturredaktør',),
'kulturredaktører': ('kulturredaktør',),
'kulturrevolusjon': ('kulturrevolusjon',),
'kulturrevolusjonen': ('kulturrevolusjon',),
'kulturrevolusjonene': ('kulturrevolusjon',),
'kulturrevolusjoner': ('kulturrevolusjon',),
'kultursekretær': ('kultursekretær',),
'kultursekretæren': ('kultursekretær',),
'kultursekretærene': ('kultursekretær',),
'kultursekretærer': ('kultursekretær',),
'kultursenter': ('kultursenter',),
'kultursenteret': ('kultursenter',),
'kultursentra': ('kultursenter',),
'kultursentre': ('kultursenter',),
'kultursentrene': ('kultursenter',),
'kultursentret': ('kultursenter',),
'kultursentra': ('kultursentrum',),
'kultursentraene': ('kultursentrum',),
'kultursentre': ('kultursentrum',),
'kultursentrene': ('kultursentrum',),
'kultursentret': ('kultursentrum',),
'kultursentrum': ('kultursentrum',),
'kultursentrumet': ('kultursentrum',),
'kultursida': ('kulturside',),
'kulturside': ('kulturside',),
'kultursiden': ('kulturside',),
'kultursidene': ('kulturside',),
'kultursider': ('kulturside',),
'kultursyn': ('kultursyn',),
'kultursyna': ('kultursyn',),
'kultursynene': ('kultursyn',),
'kultursynet': ('kultursyn',),
'kulturvern': ('kulturvern',),
'kulturverna': ('kulturvern',),
'kulturvernene': ('kulturvern',),
'kulturvernet': ('kulturvern',),
'kultus': ('kultus',),
'kultusen': ('kultus',),
'kultusene': ('kultus',),
'kultuser': ('kultus',),
'kulvert': ('kulvert',),
'kulverten': ('kulvert',),
'kulvertene': ('kulvert',),
'kulverter': ('kulvert',),
'kulør': ('kulør',),
'kuløren': ('kulør',),
'kulørene': ('kulør',),
'kulører': ('kulør',),
'kum': ('kum',),
'kummen': ('kum',),
'kummene': ('kum',),
'kummer': ('kum',),
'kumla': ('kumle',),
'kumle': ('kumle',),
'kumlen': ('kumle',),
'kumlene': ('kumle',),
'kumler': ('kumle',),
'kumlokk': ('kumlokk',),
'kumlokka': ('kumlokk',),
'kumlokkene': ('kumlokk',),
'kumlokket': ('kumlokk',),
'kumme': ('kumme',),
'kummen': ('kumme',),
'kummene': ('kumme',),
'kummer': ('kumme',),
'kummer': ('kummer',),
'kummere': ('kummer',),
'kummeren': ('kummer',),
'kummerer': ('kummer',),
'kummerne': ('kummer',),
'kumrene': ('kummer',),
'kumrer': ('kummer',),
'kump': ('kump',),
'kumpen': ('kump',),
'kumpene': ('kump',),
'kumper': ('kump',),
'kumpan': ('kumpan',),
'kumpanen': ('kumpan',),
'kumpanene': ('kumpan',),
'kumpaner': ('kumpan',),
'kumpa': ('kumpe',),
'kumpe': ('kumpe',),
'kumpen': ('kumpe',),
'kumpene': ('kumpe',),
'kumper': ('kumpe',),
'kumulasjon': ('kumulasjon',),
'kumulasjonen': ('kumulasjon',),
'kumulasjonene': ('kumulasjon',),
'kumulasjoner': ('kumulasjon',),
'kumulussky': ('kumulussky',),
'kumulusskyen': ('kumulussky',),
'kumulusskyene': ('kumulussky',),
'kumulusskyer': ('kumulussky',),
'kunde': ('kunde',),
'kunden': ('kunde',),
'kundene': ('kunde',),
'kunder': ('kunde',),
'kundekrets': ('kundekrets',),
'kundekretsen': ('kundekrets',),
'kundekretsene': ('kundekrets',),
'kundekretser': ('kundekrets',),
'kundeservice': ('kundeservice',),
'kundeservicen': ('kundeservice',),
'kundeservicene': ('kundeservice',),
'kundeservicer': ('kundeservice',),
'kung': ('kung',),
'kungen': ('kung',),
'kungene': ('kung',),
'kunger': ('kung',),
'kungsgras': ('kungsgras',),
'kungsgrasa': ('kungsgras',),
'kungsgrasene': ('kungsgras',),
'kungsgraset': ('kungsgras',),
'kungsgress': ('kungsgress',),
'kungsgressa': ('kungsgress',),
'kungsgressene': ('kungsgress',),
'kungsgresset': ('kungsgress',),
'kunnen': ('kunnen',),
'kunngjørelse': ('kunngjørelse',),
'kunngjørelsen': ('kunngjørelse',),
'kunngjørelsene': ('kunngjørelse',),
'kunngjørelser': ('kunngjørelse',),
'kunngjøring': ('kunngjøring',),
'kunngjøringa': ('kunngjøring',),
'kunngjøringen': ('kunngjøring',),
'kunngjøringene': ('kunngjøring',),
'kunngjøringer': ('kunngjøring',),
'kunnskap': ('kunnskap',),
'kunnskapen': ('kunnskap',),
'kunnskapene': ('kunnskap',),
'kunnskaper': ('kunnskap',),
'kunst': ('kunst',),
'kunsten': ('kunst',),
'kunstene': ('kunst',),
'kunster': ('kunst',),
'kunstakademi': ('kunstakademi',),
'kunstakademia': ('kunstakademi',),
'kunstakademiene': ('kunstakademi',),
'kunstakademier': ('kunstakademi',),
'kunstakademiet': ('kunstakademi',),
'kunstart': ('kunstart',),
'kunstarta': ('kunstart',),
'kunstarten': ('kunstart',),
'kunstartene': ('kunstart',),
'kunstarter': ('kunstart',),
'kunstdikting': ('kunstdikting',),
'kunstdiktinga': ('kunstdikting',),
'kunstdiktingen': ('kunstdikting',),
'kunstdiktingene': ('kunstdikting',),
'kunstdiktinger': ('kunstdikting',),
'kunstdiktning': ('kunstdiktning',),
'kunstdiktninga': ('kunstdiktning',),
'kunstdiktningen': ('kunstdiktning',),
'kunstdiktningene': ('kunstdiktning',),
'kunstdiktninger': ('kunstdiktning',),
'kunsteng': ('kunsteng',),
'kunstenga': ('kunsteng',),
'kunstengen': ('kunsteng',),
'kunstengene': ('kunsteng',),
'kunstenger': ('kunsteng',),
'kunsteventyr': ('kunsteventyr',),
'kunsteventyra': ('kunsteventyr',),
'kunsteventyrene': ('kunsteventyr',),
'kunsteventyret': ('kunsteventyr',),
'kunstfiber': ('kunstfiber',),
'kunstfibere': ('kunstfiber',),
'kunstfiberen': ('kunstfiber',),
'kunstfiberne': ('kunstfiber',),
'kunstfibre': ('kunstfiber',),
'kunstfibrene': ('kunstfiber',),
'kunstfibrer': ('kunstfiber',),
'kunstforening': ('kunstforening',),
'kunstforeninga': ('kunstforening',),
'kunstforeningen': ('kunstforening',),
'kunstforeningene': ('kunstforening',),
'kunstforeninger': ('kunstforening',),
'kunstgalleri': ('kunstgalleri',),
'kunstgalleria': ('kunstgalleri',),
'kunstgalleriene': ('kunstgalleri',),
'kunstgallerier': ('kunstgalleri',),
'kunstgalleriet': ('kunstgalleri',),
'kunstgjødsel': ('kunstgjødsel',),
'kunstgjødselen': ('kunstgjødsel',),
'kunstgjødsla': ('kunstgjødsel',),
'kunstgjødslene': ('kunstgjødsel',),
'kunstgjødsler': ('kunstgjødsel',),
'kunstgrep': ('kunstgrep',),
'kunstgrepa': ('kunstgrep',),
'kunstgrepene': ('kunstgrep',),
'kunstgrepet': ('kunstgrep',),
'kunsthandel': ('kunsthandel',),
'kunsthandelen': ('kunsthandel',),
'kunsthandlene': ('kunsthandel',),
'kunsthandler': ('kunsthandel',),
'kunsthandverk': ('kunsthandverk',),
'kunsthandverka': ('kunsthandverk',),
'kunsthandverkene': ('kunsthandverk',),
'kunsthandverket': ('kunsthandverk',),
'kunsthistoria': ('kunsthistorie',),
'kunsthistorie': ('kunsthistorie',),
'kunsthistorien': ('kunsthistorie',),
'kunsthistoriene': ('kunsthistorie',),
'kunsthistorier': ('kunsthistorie',),
'kunsthåndverk': ('kunsthåndverk',),
'kunsthåndverka': ('kunsthåndverk',),
'kunsthåndverkene': ('kunsthåndverk',),
'kunsthåndverket': ('kunsthåndverk',),
'kunstindustri': ('kunstindustri',),
'kunstindustrien': ('kunstindustri',),
'kunstindustriene': ('kunstindustri',),
'kunstindustrier': ('kunstindustri',),
'kunstis': ('kunstis',),
'kunstisen': ('kunstis',),
'kunstisene': ('kunstis',),
'kunstiser': ('kunstis',),
'kunstisbane': ('kunstisbane',),
'kunstisbanen': ('kunstisbane',),
'kunstisbanene': ('kunstisbane',),
'kunstisbaner': ('kunstisbane',),
'kunstkjenner': ('kunstkjenner',),
'kunstkjennere': ('kunstkjenner',),
'kunstkjenneren': ('kunstkjenner',),
'kunstkjennerer': ('kunstkjenner',),
'kunstkjennerne': ('kunstkjenner',),
'kunstkritiker': ('kunstkritiker',),
'kunstkritikere': ('kunstkritiker',),
'kunstkritikeren': ('kunstkritiker',),
'kunstkritikerer': ('kunstkritiker',),
'kunstkritikerne': ('kunstkritiker',),
'kunstkritikk': ('kunstkritikk',),
'kunstkritikken': ('kunstkritikk',),
'kunstkritikkene': ('kunstkritikk',),
'kunstkritikker': ('kunstkritikk',),
'kunstlær': ('kunstlær',),
'kunstlæra': ('kunstlær',),
'kunstlærene': ('kunstlær',),
'kunstlæret': ('kunstlær',),
'kunstløp': ('kunstløp',),
'kunstløpa': ('kunstløp',),
'kunstløpene': ('kunstløp',),
'kunstløpet': ('kunstløp',),
'kunstløper': ('kunstløper',),
'kunstløpere': ('kunstløper',),
'kunstløperen': ('kunstløper',),
'kunstløperer': ('kunstløper',),
'kunstløperne': ('kunstløper',),
'kunstløpsskøyta': ('kunstløpsskøyte',),
'kunstløpsskøyte': ('kunstløpsskøyte',),
'kunstløpsskøyten': ('kunstløpsskøyte',),
'kunstløpsskøytene': ('kunstløpsskøyte',),
'kunstløpsskøyter': ('kunstløpsskøyte',),
'kunstmaler': ('kunstmaler',),
'kunstmalere': ('kunstmaler',),
'kunstmaleren': ('kunstmaler',),
'kunstmalerer': ('kunstmaler',),
'kunstmalerne': ('kunstmaler',),
'kunstmaling': ('kunstmaling',),
'kunstmalinga': ('kunstmaling',),
'kunstmalingen': ('kunstmaling',),
'kunstmalingene': ('kunstmaling',),
'kunstmalinger': ('kunstmaling',),
'kunstmusikk': ('kunstmusikk',),
'kunstmusikken': ('kunstmusikk',),
'kunstmusikkene': ('kunstmusikk',),
'kunstmusikker': ('kunstmusikk',),
'kunstner': ('kunstner',),
'kunstnere': ('kunstner',),
'kunstneren': ('kunstner',),
'kunstnerer': ('kunstner',),
'kunstnerne': ('kunstner',),
'kunstnerblod': ('kunstnerblod',),
'kunstnerbloda': ('kunstnerblod',),
'kunstnerblodene': ('kunstnerblod',),
'kunstnerblodet': ('kunstnerblod',),
'kunstnerlønn': ('kunstnerlønn',),
'kunstnerlønna': ('kunstnerlønn',),
'kunstnerlønnen': ('kunstnerlønn',),
'kunstnerlønnene': ('kunstnerlønn',),
'kunstnerlønner': ('kunstnerlønn',),
'kunstnernavn': ('kunstnernavn',),
'kunstnernavna': ('kunstnernavn',),
'kunstnernavnene': ('kunstnernavn',),
'kunstnernavnet': ('kunstnernavn',),
'kunstnerspira': ('kunstnerspire',),
'kunstnerspire': ('kunstnerspire',),
'kunstnerspiren': ('kunstnerspire',),
'kunstnerspirene': ('kunstnerspire',),
'kunstnerspirer': ('kunstnerspire',),
'kunstnerstipend': ('kunstnerstipend',),
'kunstnerstipenda': ('kunstnerstipend',),
'kunstnerstipendene': ('kunstnerstipend',),
'kunstnerstipender': ('kunstnerstipend',),
'kunstnerstipendet': ('kunstnerstipend',),
'kunstpause': ('kunstpause',),
'kunstpausen': ('kunstpause',),
'kunstpausene': ('kunstpause',),
'kunstpauser': ('kunstpause',),
'kunstprodukt': ('kunstprodukt',),
'kunstprodukta': ('kunstprodukt',),
'kunstproduktene': ('kunstprodukt',),
'kunstprodukter': ('kunstprodukt',),
'kunstproduktet': ('kunstprodukt',),
'kunstretning': ('kunstretning',),
'kunstretninga': ('kunstretning',),
'kunstretningen': ('kunstretning',),
'kunstretningene': ('kunstretning',),
'kunstretninger': ('kunstretning',),
'kunstsamler': ('kunstsamler',),
'kunstsamlere': ('kunstsamler',),
'kunstsamleren': ('kunstsamler',),
'kunstsamlerer': ('kunstsamler',),
'kunstsamlerne': ('kunstsamler',),
'kunstsilke': ('kunstsilke',),
'kunstsilken': ('kunstsilke',),
'kunstsilkene': ('kunstsilke',),
'kunstsilker': ('kunstsilke',),
'kunstskatt': ('kunstskatt',),
'kunstskatten': ('kunstskatt',),
'kunstskattene': ('kunstskatt',),
'kunstskatter': ('kunstskatt',),
'kunstspråk': ('kunstspråk',),
'kunstspråka': ('kunstspråk',),
'kunstspråkene': ('kunstspråk',),
'kunstspråket': ('kunstspråk',),
'kunststoff': ('kunststoff',),
'kunststoffa': ('kunststoff',),
'kunststoffene': ('kunststoff',),
'kunststoffer': ('kunststoff',),
'kunststoffet': ('kunststoff',),
'kunststopning': ('kunststopning',),
'kunststopninga': ('kunststopning',),
'kunststopningen': ('kunststopning',),
'kunststopningene': ('kunststopning',),
'kunststopninger': ('kunststopning',),
'kunststopping': ('kunststopping',),
'kunststoppinga': ('kunststopping',),
'kunststoppingen': ('kunststopping',),
'kunststoppingene': ('kunststopping',),
'kunststoppinger': ('kunststopping',),
'kunststykka': ('kunststykke',),
'kunststykke': ('kunststykke',),
'kunststykkene': ('kunststykke',),
'kunststykker': ('kunststykke',),
'kunststykket': ('kunststykke',),
'kunstverk': ('kunstverk',),
'kunstverka': ('kunstverk',),
'kunstverkene': ('kunstverk',),
'kunstverker': ('kunstverk',),
'kunstverket': ('kunstverk',),
'kupeen': ('kupé',),
'kupeene': ('kupé',),
'kupeer': ('kupé',),
'kupé': ('kupé',),
'kupéen': ('kupé',),
'kupéene': ('kupé',),
'kupéer': ('kupé',),
'kupévarmer': ('kupévarmer',),
'kupévarmere': ('kupévarmer',),
'kupévarmeren': ('kupévarmer',),
'kupévarmerer': ('kupévarmer',),
'kupévarmerne': ('kupévarmer',),
'kupévogn': ('kupévogn',),
'kupévogna': ('kupévogn',),
'kupévognen': ('kupévogn',),
'kupévognene': ('kupévogn',),
'kupévogner': ('kupévogn',),
'kupa': ('kupe',),
'kupe': ('kupe',),
'kupen': ('kupe',),
'kupene': ('kupe',),
'kuper': ('kupe',),
'kuplett': ('kuplett',),
'kupletten': ('kuplett',),
'kuplettene': ('kuplett',),
'kupletter': ('kuplett',),
'kupling': ('kupling',),
'kuplingen': ('kupling',),
'kuplingene': ('kupling',),
'kuplinger': ('kupling',),
'kupolomn': ('kupolomn',),
'kupolomnen': ('kupolomn',),
'kupolomnene': ('kupolomn',),
'kupolomner': ('kupolomn',),
'kupolovn': ('kupolovn',),
'kupolovnen': ('kupolovn',),
'kupolovnene': ('kupolovn',),
'kupolovner': ('kupolovn',),
'kupong': ('kupong',),
'kupongen': ('kupong',),
'kupongene': ('kupong',),
'kuponger': ('kupong',),
'kupongklipper': ('kupongklipper',),
'kupongklippere': ('kupongklipper',),
'kupongklipperen': ('kupongklipper',),
'kupongklipperer': ('kupongklipper',),
'kupongklipperne': ('kupongklipper',),
'kupongvara': ('kupongvare',),
'kupongvare': ('kupongvare',),
'kupongvaren': ('kupongvare',),
'kupongvarene': ('kupongvare',),
'kupongvarer': ('kupongvare',),
'kupp': ('kupp',),
'kuppa': ('kupp',),
'kuppene': ('kupp',),
'kuppet': ('kupp',),
'kuplene': ('kuppel',),
'kupler': ('kuppel',),
'kuppel': ('kuppel',),
'kuppelen': ('kuppel',),
'kuppelhoda': ('kuppelhode',),
'kuppelhode': ('kuppelhode',),
'kuppelhodene': ('kuppelhode',),
'kuppelhoder': ('kuppelhode',),
'kuppelhodet': ('kuppelhode',),
'kuppforsøk': ('kuppforsøk',),
'kuppforsøka': ('kuppforsøk',),
'kuppforsøkene': ('kuppforsøk',),
'kuppforsøket': ('kuppforsøk',),
'kur': ('kur',),
'kuren': ('kur',),
'kurene': ('kur',),
'kurer': ('kur',),
'kur': ('kur',),
'kuren': ('kur',),
'kurene': ('kur',),
'kurer': ('kur',),
'kuranstalt': ('kuranstalt',),
'kuranstalten': ('kuranstalt',),
'kuranstaltene': ('kuranstalt',),
'kuranstalter': ('kuranstalt',),
'kurant': ('kurant',),
'kuranten': ('kurant',),
'kurantene': ('kurant',),
'kuranter': ('kurant',),
'kurasje': ('kurasje',),
'kurasjen': ('kurasje',),
'kurasjene': ('kurasje',),
'kurasjer': ('kurasje',),
'kurator': ('kurator',),
'kuratoren': ('kurator',),
'kuratorene': ('kurator',),
'kuratorer': ('kurator',),
'kurbad': ('kurbad',),
'kurbada': ('kurbad',),
'kurbadene': ('kurbad',),
'kurbadet': ('kurbad',),
'kurder': ('kurder',),
'kurdere': ('kurder',),
'kurderen': ('kurder',),
'kurderer': ('kurder',),
'kurderne': ('kurder',),
'kurer': ('kurer',),
'kureren': ('kurer',),
'kurerene': ('kurer',),
'kurerer': ('kurer',),
'kurerpass': ('kurerpass',),
'kurerpassa': ('kurerpass',),
'kurerpassene': ('kurerpass',),
'kurerpasset': ('kurerpass',),
'kurerpost': ('kurerpost',),
'kurerposten': ('kurerpost',),
'kurerpostene': ('kurerpost',),
'kurerposter': ('kurerpost',),
'kurfyrste': ('kurfyrste',),
'kurfyrsten': ('kurfyrste',),
'kurfyrstene': ('kurfyrste',),
'kurfyrster': ('kurfyrste',),
'kurfyrstedømma': ('kurfyrstedømme',),
'kurfyrstedømme': ('kurfyrstedømme',),
'kurfyrstedømmene': ('kurfyrstedømme',),
'kurfyrstedømmer': ('kurfyrstedømme',),
'kurfyrstedømmet': ('kurfyrstedømme',),
'kurheim': ('kurheim',),
'kurheimen': ('kurheim',),
'kurheimene': ('kurheim',),
'kurheimer': ('kurheim',),
'kurhjem': ('kurhjem',),
'kurhjemma': ('kurhjem',),
'kurhjemmene': ('kurhjem',),
'kurhjemmet': ('kurhjem',),
'kurie': ('kurie',),
'kurien': ('kurie',),
'kuriene': ('kurie',),
'kurier': ('kurie',),
'kuriositet': ('kuriositet',),
'kuriositeten': ('kuriositet',),
'kuriositetene': ('kuriositet',),
'kuriositeter': ('kuriositet',),
'kuriosa': ('kuriosum',),
'kuriosaene': ('kuriosum',),
'kuriosum': ('kuriosum',),
'kuriosumet': ('kuriosum',),
'kurla': ('kurle',),
'kurle': ('kurle',),
'kurlen': ('kurle',),
'kurlene': ('kurle',),
'kurler': ('kurle',),
'kurlender': ('kurlender',),
'kurlendere': ('kurlender',),
'kurlenderen': ('kurlender',),
'kurlenderer': ('kurlender',),
'kurlenderne': ('kurlender',),
'kurlending': ('kurlending',),
'kurlendingen': ('kurlending',),
'kurlendingene': ('kurlending',),
'kurlendinger': ('kurlending',),
'kurmaker': ('kurmaker',),
'kurmakere': ('kurmaker',),
'kurmakeren': ('kurmaker',),
'kurmakerer': ('kurmaker',),
'kurmakerne': ('kurmaker',),
'kurmakeri': ('kurmakeri',),
'kurmakeria': ('kurmakeri',),
'kurmakeriene': ('kurmakeri',),
'kurmakerier': ('kurmakeri',),
'kurmakeriet': ('kurmakeri',),
'kurpengene': ('kurpenger',),
'kurpenger': ('kurpenger',),
'kurr': ('kurr',),
'kurra': ('kurr',),
'kurrene': ('kurr',),
'kurret': ('kurr',),
'kurre': ('kurre',),
'kurren': ('kurre',),
'kurrene': ('kurre',),
'kurrer': ('kurre',),
'kurs': ('kurs',),
'kursen': ('kurs',),
'kursene': ('kurs',),
'kurser': ('kurs',),
'kurs': ('kurs',),
'kursa': ('kurs',),
'kursene': ('kurs',),
'kurser': ('kurs',),
'kurset': ('kurs',),
'kurs': ('kurs',),
'kursa': ('kurs',),
'kursene': ('kurs',),
'kurser': ('kurs',),
'kurset': ('kurs',),
'kursendring': ('kursendring',),
'kursendringa': ('kursendring',),
'kursendringen': ('kursendring',),
'kursendringene': ('kursendring',),
'kursendringer': ('kursendring',),
'kursfall': ('kursfall',),
'kursfalla': ('kursfall',),
'kursfallene': ('kursfall',),
'kursfallet': ('kursfall',),
'kursiv': ('kursiv',),
'kursiven': ('kursiv',),
'kursivene': ('kursiv',),
'kursiver': ('kursiv',),
'kursivskrift': ('kursivskrift',),
'kursivskrifta': ('kursivskrift',),
'kursivskriften': ('kursivskrift',),
'kursivskriftene': ('kursivskrift',),
'kursivskrifter': ('kursivskrift',),
'kursleier': ('kursleier',),
'kursleiere': ('kursleier',),
'kursleieren': ('kursleier',),
'kursleierer': ('kursleier',),
'kursleierne': ('kursleier',),
'kurssvingning': ('kurssvingning',),
'kurssvingninga': ('kurssvingning',),
'kurssvingningen': ('kurssvingning',),
'kurssvingningene': ('kurssvingning',),
'kurssvingninger': ('kurssvingning',),
'kurstap': ('kurstap',),
'kurstapa': ('kurstap',),
'kurstapene': ('kurstap',),
'kurstapet': ('kurstap',),
'kursted': ('kursted',),
'kurstedene': ('kursted',),
'kursteder': ('kursted',),
'kurstedet': ('kursted',),
'kursene': ('kursus',),
'kurser': ('kursus',),
'kursus': ('kursus',),
'kursuset': ('kursus',),
'kurtasje': ('kurtasje',),
'kurtasjen': ('kurtasje',),
'kurtasjene': ('kurtasje',),
'kurtasjer': ('kurtasje',),
'kurtisana': ('kurtisane',),
'kurtisane': ('kurtisane',),
'kurtisanen': ('kurtisane',),
'kurtisanene': ('kurtisane',),
'kurtisaner': ('kurtisane',),
'kurtise': ('kurtise',),
'kurtisen': ('kurtise',),
'kurtisene': ('kurtise',),
'kurtiser': ('kurtise',),
'kurtisør': ('kurtisør',),
'kurtisøren': ('kurtisør',),
'kurtisørene': ('kurtisør',),
'kurtisører': ('kurtisør',),
'kuruka': ('kuruke',),
'kuruke': ('kuruke',),
'kuruken': ('kuruke',),
'kurukene': ('kuruke',),
'kuruker': ('kuruke',),
'kurumpa': ('kurumpe',),
'kurumpe': ('kurumpe',),
'kurumpen': ('kurumpe',),
'kurumpene': ('kurumpe',),
'kurumper': ('kurumpe',),
'kurv': ('kurv',),
'kurven': ('kurv',),
'kurvene': ('kurv',),
'kurver': ('kurv',),
'kurv': ('kurv',),
'kurven': ('kurv',),
'kurvene': ('kurv',),
'kurver': ('kurv',),
'kurvatur': ('kurvatur',),
'kurvaturen': ('kurvatur',),
'kurvaturene': ('kurvatur',),
'kurvaturer': ('kurvatur',),
'kurvball': ('kurvball',),
'kurvballen': ('kurvball',),
'kurvballene': ('kurvball',),
'kurvballer': ('kurvball',),
'kurvblomst': ('kurvblomst',),
'kurvblomsten': ('kurvblomst',),
'kurvblomstene': ('kurvblomst',),
'kurvblomster': ('kurvblomst',),
'kurve': ('kurve',),
'kurven': ('kurve',),
'kurvene': ('kurve',),
'kurver': ('kurve',),
'kurvfletning': ('kurvfletning',),
'kurvfletninga': ('kurvfletning',),
'kurvfletningen': ('kurvfletning',),
'kurvfletningene': ('kurvfletning',),
'kurvfletninger': ('kurvfletning',),
'kurvmaker': ('kurvmaker',),
'kurvmakere': ('kurvmaker',),
'kurvmakeren': ('kurvmaker',),
'kurvmakerer': ('kurvmaker',),
'kurvmakerne': ('kurvmaker',),
'kurvplanta': ('kurvplante',),
'kurvplante': ('kurvplante',),
'kurvplanten': ('kurvplante',),
'kurvplantene': ('kurvplante',),
'kurvplanter': ('kurvplante',),
'kurvplantefamilie': ('kurvplantefamilie',),
'kurvplantefamilien': ('kurvplantefamilie',),
'kurvplantefamiliene': ('kurvplantefamilie',),
'kurvplantefamilier': ('kurvplantefamilie',),
'kusa': ('kuse',),
'kuse': ('kuse',),
'kusen': ('kuse',),
'kusene': ('kuse',),
'kuser': ('kuse',),
'kusina': ('kusine',),
'kusine': ('kusine',),
'kusinen': ('kusine',),
'kusinene': ('kusine',),
'kusiner': ('kusine',),
'kusk': ('kusk',),
'kusken': ('kusk',),
'kuskene': ('kusk',),
'kusker': ('kusk',),
'kusma': ('kusma',),
'kusmaen': ('kusma',),
'kusmaene': ('kusma',),
'kusmaer': ('kusma',),
'kusopp': ('kusopp',),
'kusoppen': ('kusopp',),
'kusoppene': ('kusopp',),
'kusopper': ('kusopp',),
'kust': ('kust',),
'kusten': ('kust',),
'kustene': ('kust',),
'kuster': ('kust',),
'kustus': ('kustus',),
'kustusen': ('kustus',),
'kustusene': ('kustus',),
'kustuser': ('kustus',),
'kusymra': ('kusymre',),
'kusymre': ('kusymre',),
'kusymren': ('kusymre',),
'kusymrene': ('kusymre',),
'kusymrer': ('kusymre',),
'kut': ('kut',),
'kuten': ('kut',),
'kutene': ('kut',),
'kuter': ('kut',),
'kutikula': ('kutikula',),
'kutikulaen': ('kutikula',),
'kutikulaene': ('kutikula',),
'kutikulaer': ('kutikula',),
'kutt': ('kutt',),
'kutta': ('kutt',),
'kuttene': ('kutt',),
'kuttet': ('kutt',),
'kutta': ('kutte',),
'kutte': ('kutte',),
'kutten': ('kutte',),
'kuttene': ('kutte',),
'kutter': ('kutte',),
'kutter': ('kutter',),
'kuttere': ('kutter',),
'kutteren': ('kutter',),
'kutterer': ('kutter',),
'kutterne': ('kutter',),
'kutter': ('kutter',),
'kuttere': ('kutter',),
'kutteren': ('kutter',),
'kutterer': ('kutter',),
'kutterne': ('kutter',),
'kutterflis': ('kutterflis',),
'kutterflisa': ('kutterflis',),
'kutterflisen': ('kutterflis',),
'kutterflisene': ('kutterflis',),
'kutterfliser': ('kutterflis',),
'kutyme': ('kutyme',),
'kutymen': ('kutyme',),
'kutymene': ('kutyme',),
'kutymer': ('kutyme',),
'kuv': ('kuv',),
'kuven': ('kuv',),
'kuvene': ('kuv',),
'kuver': ('kuv',),
'kuvending': ('kuvending',),
'kuvendinga': ('kuvending',),
'kuvendingen': ('kuvending',),
'kuvendingene': ('kuvending',),
'kuvendinger': ('kuvending',),
'kuvert': ('kuvert',),
'kuverten': ('kuvert',),
'kuvertene': ('kuvert',),
'kuverter': ('kuvert',),
'kuvertavgift': ('kuvertavgift',),
'kuvertavgifta': ('kuvertavgift',),
'kuvertavgiften': ('kuvertavgift',),
'kuvertavgiftene': ('kuvertavgift',),
'kuvertavgifter': ('kuvertavgift',),
'kuvertbrikka': ('kuvertbrikke',),
'kuvertbrikke': ('kuvertbrikke',),
'kuvertbrikken': ('kuvertbrikke',),
'kuvertbrikkene': ('kuvertbrikke',),
'kuvertbrikker': ('kuvertbrikke',),
'kuvertglass': ('kuvertglass',),
'kuvertglassa': ('kuvertglass',),
'kuvertglassene': ('kuvertglass',),
'kuvertglasset': ('kuvertglass',),
'kuvogn': ('kuvogn',),
'kuvogna': ('kuvogn',),
'kuvognen': ('kuvogn',),
'kuvognene': ('kuvogn',),
'kuvogner': ('kuvogn',),
'kuvung': ('kuvung',),
'kuvungen': ('kuvung',),
'kuvungene': ('kuvung',),
'kuvunger': ('kuvung',),
'kuvøsa': ('kuvøse',),
'kuvøse': ('kuvøse',),
'kuvøsen': ('kuvøse',),
'kuvøsene': ('kuvøse',),
'kuvøser': ('kuvøse',),
'kuwaiter': ('kuwaiter',),
'kuwaitere': ('kuwaiter',),
'kuwaiteren': ('kuwaiter',),
'kuwaiterer': ('kuwaiter',),
'kuwaiterne': ('kuwaiter',),
'kuøya': ('kuøye',),
'kuøye': ('kuøye',),
'kuøyene': ('kuøye',),
'kuøyer': ('kuøye',),
'kuøyet': ('kuøye',),
'kuøyne': ('kuøye',),
'kuøynene': ('kuøye',),
'kvabb': ('kvabb',),
'kvabben': ('kvabb',),
'kvabbene': ('kvabb',),
'kvabber': ('kvabb',),
'kvad': ('kvad',),
'kvada': ('kvad',),
'kvadene': ('kvad',),
'kvadet': ('kvad',),
'kvader': ('kvader',),
'kvadere': ('kvader',),
'kvaderen': ('kvader',),
'kvaderne': ('kvader',),
'kvadre': ('kvader',),
'kvadrene': ('kvader',),
'kvadrer': ('kvader',),
'kvadermur': ('kvadermur',),
'kvadermuren': ('kvadermur',),
'kvadermurene': ('kvadermur',),
'kvadermurer': ('kvadermur',),
'kvaderstein': ('kvaderstein',),
'kvadersteinen': ('kvaderstein',),
'kvadersteinene': ('kvaderstein',),
'kvadersteiner': ('kvaderstein',),
'u': ('u',),
'uen': ('u',),
'uene': ('u',),
'uer': ('u',),
'kvadrant': ('kvadrant',),
'kvadranten': ('kvadrant',),
'kvadrantene': ('kvadrant',),
'kvadranter': ('kvadrant',),
'kvadrat': ('kvadrat',),
'kvadrata': ('kvadrat',),
'kvadratene': ('kvadrat',),
'kvadrater': ('kvadrat',),
'kvadratet': ('kvadrat',),
'kvadratinnhold': ('kvadratinnhold',),
'kvadratinnholda': ('kvadratinnhold',),
'kvadratinnholdene': ('kvadratinnhold',),
'kvadratinnholdet': ('kvadratinnhold',),
'kvadratkilometer': ('kvadratkilometer',),
'kvadratkilometeren': ('kvadratkilometer',),
'kvadratkilometerne': ('kvadratkilometer',),
'kvadrattal': ('kvadrattal',),
'kvadrattala': ('kvadrattal',),
'kvadrattalene': ('kvadrattal',),
'kvadrattalet': ('kvadrattal',),
'kvadrattall': ('kvadrattall',),
'kvadrattalla': ('kvadrattall',),
'kvadrattallene': ('kvadrattall',),
'kvadrattallet': ('kvadrattall',),
'kvadratur': ('kvadratur',),
'kvadraturen': ('kvadratur',),
'kvadraturene': ('kvadratur',),
'kvadraturer': ('kvadratur',),
'kvadrilje': ('kvadrilje',),
'kvadriljen': ('kvadrilje',),
'kvadriljene': ('kvadrilje',),
'kvadriljer': ('kvadrilje',),
'kvadrillion': ('kvadrillion',),
'kvadrillionen': ('kvadrillion',),
'kvadrillionene': ('kvadrillion',),
'kvadrillioner': ('kvadrillion',),
'kvadrofoni': ('kvadrofoni',),
'kvadrofonien': ('kvadrofoni',),
'kvadrofoniene': ('kvadrofoni',),
'kvadrofonier': ('kvadrofoni',),
'kvadron': ('kvadron',),
'kvadronen': ('kvadron',),
'kvadronene': ('kvadron',),
'kvadroner': ('kvadron',),
'kvadrupelallianse': ('kvadrupelallianse',),
'kvadrupelalliansen': ('kvadrupelallianse',),
'kvadrupelalliansene': ('kvadrupelallianse',),
'kvadrupelallianser': ('kvadrupelallianse',),
'kvae': ('kvae',),
'kvaen': ('kvae',),
'kvaene': ('kvae',),
'kvaer': ('kvae',),
'kvakk': ('kvakk',),
'kvakka': ('kvakk',),
'kvakkene': ('kvakk',),
'kvakket': ('kvakk',),
'kvakker': ('kvakker',),
'kvakkere': ('kvakker',),
'kvakkeren': ('kvakker',),
'kvakkerer': ('kvakker',),
'kvakkerne': ('kvakker',),
'kvakkerarbeid': ('kvakkerarbeid',),
'kvakkerarbeida': ('kvakkerarbeid',),
'kvakkerarbeidene': ('kvakkerarbeid',),
'kvakkerarbeider': ('kvakkerarbeid',),
'kvakkerarbeidet': ('kvakkerarbeid',),
'kvakksalver': ('kvakksalver',),
'kvakksalvere': ('kvakksalver',),
'kvakksalveren': ('kvakksalver',),
'kvakksalverer': ('kvakksalver',),
'kvakksalverne': ('kvakksalver',),
'kvakksalveri': ('kvakksalveri',),
'kvakksalveria': ('kvakksalveri',),
'kvakksalveriene': ('kvakksalveri',),
'kvakksalverier': ('kvakksalveri',),
'kvakksalveriet': ('kvakksalveri',),
'kval': ('kval',),
'kvalen': ('kval',),
'kvalene': ('kval',),
'kvaler': ('kval',),
'kval': ('kval',),
'kvalen': ('kval',),
'kvalene': ('kval',),
'kvaler': ('kval',),
'kvalbiff': ('kvalbiff',),
'kvalbiffen': ('kvalbiff',),
'kvalbiffene': ('kvalbiff',),
'kvalbiffer': ('kvalbiff',),
'kvalblåst': ('kvalblåst',),
'kvalblåsten': ('kvalblåst',),
'kvalblåstene': ('kvalblåst',),
'kvalblåster': ('kvalblåst',),
'kvalbåt': ('kvalbåt',),
'kvalbåten': ('kvalbåt',),
'kvalbåtene': ('kvalbåt',),
'kvalbåter': ('kvalbåt',),
'kvalfanger': ('kvalfanger',),
'kvalfangere': ('kvalfanger',),
'kvalfangeren': ('kvalfanger',),
'kvalfangerer': ('kvalfanger',),
'kvalfangerne': ('kvalfanger',),
'kvalfangst': ('kvalfangst',),
'kvalfangsten': ('kvalfangst',),
'kvalfangstene': ('kvalfangst',),
'kvalfangster': ('kvalfangst',),
'kvalhai': ('kvalhai',),
'kvalhaien': ('kvalhai',),
'kvalhaiene': ('kvalhai',),
'kvalhaier': ('kvalhai',),
'kvalifikasjon': ('kvalifikasjon',),
'kvalifikasjonen': ('kvalifikasjon',),
'kvalifikasjonene': ('kvalifikasjon',),
'kvalifikasjoner': ('kvalifikasjon',),
'kvalifisering': ('kvalifisering',),
'kvalifiseringa': ('kvalifisering',),
'kvalifiseringen': ('kvalifisering',),
'kvalifiseringene': ('kvalifisering',),
'kvalifiseringer': ('kvalifisering',),
'kvalifiseringskamp': ('kvalifiseringskamp',),
'kvalifiseringskampen': ('kvalifiseringskamp',),
'kvalifiseringskampene': ('kvalifiseringskamp',),
'kvalifiseringskamper': ('kvalifiseringskamp',),
'kvalifiseringsløp': ('kvalifiseringsløp',),
'kvalifiseringsløpa': ('kvalifiseringsløp',),
'kvalifiseringsløpene': ('kvalifiseringsløp',),
'kvalifiseringsløpet': ('kvalifiseringsløp',),
'kvalifiseringsrunde': ('kvalifiseringsrunde',),
'kvalifiseringsrunden': ('kvalifiseringsrunde',),
'kvalifiseringsrundene': ('kvalifiseringsrunde',),
'kvalifiseringsrunder': ('kvalifiseringsrunde',),
'kvalitet': ('kvalitet',),
'kvaliteten': ('kvalitet',),
'kvalitetene': ('kvalitet',),
'kvaliteter': ('kvalitet',),
'kvalitetsarbeid': ('kvalitetsarbeid',),
'kvalitetsarbeida': ('kvalitetsarbeid',),
'kvalitetsarbeidene': ('kvalitetsarbeid',),
'kvalitetsarbeider': ('kvalitetsarbeid',),
'kvalitetsarbeidet': ('kvalitetsarbeid',),
'kvalitetskontroll': ('kvalitetskontroll',),
'kvalitetskontrollen': ('kvalitetskontroll',),
'kvalitetskontrollene': ('kvalitetskontroll',),
'kvalitetskontroller': ('kvalitetskontroll',),
'kvalitetskrav': ('kvalitetskrav',),
'kvalitetskrava': ('kvalitetskrav',),
'kvalitetskravene': ('kvalitetskrav',),
'kvalitetskravet': ('kvalitetskrav',),
'kvalitetsprodukt': ('kvalitetsprodukt',),
'kvalitetsprodukta': ('kvalitetsprodukt',),
'kvalitetsproduktene': ('kvalitetsprodukt',),
'kvalitetsprodukter': ('kvalitetsprodukt',),
'kvalitetsproduktet': ('kvalitetsprodukt',),
'kvalkalv': ('kvalkalv',),
'kvalkalven': ('kvalkalv',),
'kvalkalvene': ('kvalkalv',),
'kvalkalver': ('kvalkalv',),
'kvalkanon': ('kvalkanon',),
'kvalkanonen': ('kvalkanon',),
'kvalkanonene': ('kvalkanon',),
'kvalkanoner': ('kvalkanon',),
'kvalkokeri': ('kvalkokeri',),
'kvalkokeria': ('kvalkokeri',),
'kvalkokeriene': ('kvalkokeri',),
'kvalkokerier': ('kvalkokeri',),
'kvalkokeriet': ('kvalkokeri',),
'kvalku': ('kvalku',),
'kvalkua': ('kvalku',),
'kvalkuen': ('kvalku',),
'kvalkuene': ('kvalku',),
'kvalkuer': ('kvalku',),
'kvalkyr': ('kvalku',),
'kvalkyrne': ('kvalku',),
'kvalm': ('kvalm',),
'kvalmen': ('kvalm',),
'kvalmene': ('kvalm',),
'kvalmer': ('kvalm',),
'kvalme': ('kvalme',),
'kvalmen': ('kvalme',),
'kvalmene': ('kvalme',),
'kvalmer': ('kvalme',),
'kvalming': ('kvalming',),
'kvalmingen': ('kvalming',),
'kvalmingene': ('kvalming',),
'kvalminger': ('kvalming',),
'kvalolja': ('kvalolje',),
'kvalolje': ('kvalolje',),
'kvaloljen': ('kvalolje',),
'kvaloljene': ('kvalolje',),
'kvaloljer': ('kvalolje',),
'kvalross': ('kvalross',),
'kvalrossen': ('kvalross',),
'kvalrossene': ('kvalross',),
'kvalrosser': ('kvalross',),
'kvalrosstann': ('kvalrosstann',),
'kvalrosstanna': ('kvalrosstann',),
'kvalrosstannen': ('kvalrosstann',),
'kvalrosstennene': ('kvalrosstann',),
'kvalrosstenner': ('kvalrosstann',),
'kvalskytter': ('kvalskytter',),
'kvalskyttere': ('kvalskytter',),
'kvalskytteren': ('kvalskytter',),
'kvalskytterer': ('kvalskytter',),
'kvalskytterne': ('kvalskytter',),
'kvalstasjon': ('kvalstasjon',),
'kvalstasjonen': ('kvalstasjon',),
'kvalstasjonene': ('kvalstasjon',),
'kvalstasjoner': ('kvalstasjon',),
'kvann': ('kvann',),
'kvanna': ('kvann',),
'kvannen': ('kvann',),
'kvannene': ('kvann',),
'kvanner': ('kvann',),
'kvanna': ('kvanne',),
'kvanne': ('kvanne',),
'kvannen': ('kvanne',),
'kvannene': ('kvanne',),
'kvanner': ('kvanne',),
'kvannejol': ('kvannejol',),
'kvannejolen': ('kvannejol',),
'kvannejolene': ('kvannejol',),
'kvannejoler': ('kvannejol',),
'kvannerot': ('kvannerot',),
'kvannerota': ('kvannerot',),
'kvanneroten': ('kvannerot',),
'kvannerøttene': ('kvannerot',),
'kvannerøtter': ('kvannerot',),
'kvannjol': ('kvannjol',),
'kvannjolen': ('kvannjol',),
'kvannjolene': ('kvannjol',),
'kvannjoler': ('kvannjol',),
'kvannrot': ('kvannrot',),
'kvannrota': ('kvannrot',),
'kvannroten': ('kvannrot',),
'kvannrøttene': ('kvannrot',),
'kvannrøtter': ('kvannrot',),
'kvant': ('kvant',),
'kvanta': ('kvant',),
'kvantene': ('kvant',),
'kvanter': ('kvant',),
'kvantet': ('kvant',),
'kvantefysikk': ('kvantefysikk',),
'kvantefysikken': ('kvantefysikk',),
'kvantefysikkene': ('kvantefysikk',),
'kvantefysikker': ('kvantefysikk',),
'kvantemekanikk': ('kvantemekanikk',),
'kvantemekanikken': ('kvantemekanikk',),
'kvantemekanikkene': ('kvantemekanikk',),
'kvantemekanikker': ('kvantemekanikk',),
'kvanteteori': ('kvanteteori',),
'kvanteteorien': ('kvanteteori',),
'kvanteteoriene': ('kvanteteori',),
'kvanteteorier': ('kvanteteori',),
'kvantifikasjon': ('kvantifikasjon',),
'kvantifikasjonen': ('kvantifikasjon',),
'kvantifikasjonene': ('kvantifikasjon',),
'kvantifikasjoner': ('kvantifikasjon',),
'kvantitet': ('kvantitet',),
'kvantiteten': ('kvantitet',),
'kvantitetene': ('kvantitet',),
'kvantiteter': ('kvantitet',),
'kvanta': ('kvantum',),
'kvantaene': ('kvantum',),
'kvantum': ('kvantum',),
'kvantumet': ('kvantum',),
'kvantumsrabatt': ('kvantumsrabatt',),
'kvantumsrabatten': ('kvantumsrabatt',),
'kvantumsrabattene': ('kvantumsrabatt',),
'kvantumsrabatter': ('kvantumsrabatt',),
'kvarg': ('kvarg',),
'kvargen': ('kvarg',),
'kvargene': ('kvarg',),
'kvarger': ('kvarg',),
'kvart': ('kvart',),
'kvarten': ('kvart',),
'kvartene': ('kvart',),
'kvarter': ('kvart',),
'kvartal': ('kvartal',),
'kvartala': ('kvartal',),
'kvartalene': ('kvartal',),
'kvartaler': ('kvartal',),
'kvartalet': ('kvartal',),
'kvartalsskrift': ('kvartalsskrift',),
'kvartalsskrifta': ('kvartalsskrift',),
'kvartalsskriftene': ('kvartalsskrift',),
'kvartalsskrifter': ('kvartalsskrift',),
'kvartalsskriftet': ('kvartalsskrift',),
'kvartbekkasin': ('kvartbekkasin',),
'kvartbekkasinen': ('kvartbekkasin',),
'kvartbekkasinene': ('kvartbekkasin',),
'kvartbekkasiner': ('kvartbekkasin',),
'kvartel': ('kvartel',),
'kvartelet': ('kvartel',),
'kvartla': ('kvartel',),
'kvartlene': ('kvartel',),
'kvartler': ('kvartel',),
'kvartlet': ('kvartel',),
'kvarter': ('kvarter',),
'kvartera': ('kvarter',),
'kvarterene': ('kvarter',),
'kvarterer': ('kvarter',),
'kvarteret': ('kvarter',),
'kvartermester': ('kvartermester',),
'kvartermestere': ('kvartermester',),
'kvartermesteren': ('kvartermester',),
'kvartermesterer': ('kvartermester',),
'kvartermesterne': ('kvartermester',),
'kvartermestre': ('kvartermester',),
'kvartermestrene': ('kvartermester',),
'kvartermestrer': ('kvartermester',),
'kvartett': ('kvartett',),
'kvartetten': ('kvartett',),
'kvartettene': ('kvartett',),
'kvartetter': ('kvartett',),
'kvartfinale': ('kvartfinale',),
'kvartfinalen': ('kvartfinale',),
'kvartfinalene': ('kvartfinale',),
'kvartfinaler': ('kvartfinale',),
'kvartfinalist': ('kvartfinalist',),
'kvartfinalisten': ('kvartfinalist',),
'kvartfinalistene': ('kvartfinalist',),
'kvartfinalister': ('kvartfinalist',),
'kvartformat': ('kvartformat',),
'kvartformata': ('kvartformat',),
'kvartformatene': ('kvartformat',),
'kvartformater': ('kvartformat',),
'kvartformatet': ('kvartformat',),
'kvartmil': ('kvartmil',),
'kvartmila': ('kvartmil',),
'kvartmilen': ('kvartmil',),
'kvartmilene': ('kvartmil',),
'kvarts': ('kvarts',),
'kvartsen': ('kvarts',),
'kvartsene': ('kvarts',),
'kvartser': ('kvarts',),
'kvartsglass': ('kvartsglass',),
'kvartsglassa': ('kvartsglass',),
'kvartsglassene': ('kvartsglass',),
'kvartsglasset': ('kvartsglass',),
'kvartsitt': ('kvartsitt',),
'kvartsitten': ('kvartsitt',),
'kvartsittene': ('kvartsitt',),
'kvartsitter': ('kvartsitt',),
'kvartskrystall': ('kvartskrystall',),
'kvartskrystalla': ('kvartskrystall',),
'kvartskrystallen': ('kvartskrystall',),
'kvartskrystallene': ('kvartskrystall',),
'kvartskrystaller': ('kvartskrystall',),
'kvartskrystallet': ('kvartskrystall',),
'kvartslampa': ('kvartslampe',),
'kvartslampe': ('kvartslampe',),
'kvartslampen': ('kvartslampe',),
'kvartslampene': ('kvartslampe',),
'kvartslamper': ('kvartslampe',),
'kvartsskifer': ('kvartsskifer',),
'kvartsskifere': ('kvartsskifer',),
'kvartsskiferen': ('kvartsskifer',),
'kvartsskiferer': ('kvartsskifer',),
'kvartsskiferne': ('kvartsskifer',),
'kvartsskifre': ('kvartsskifer',),
'kvartsskifrene': ('kvartsskifer',),
'kvartsskifrer': ('kvartsskifer',),
'kvartsur': ('kvartsur',),
'kvartsura': ('kvartsur',),
'kvartsurene': ('kvartsur',),
'kvartsuret': ('kvartsur',),
'kvartær': ('kvartær',),
'kvartæren': ('kvartær',),
'kvartærene': ('kvartær',),
'kvartærer': ('kvartær',),
'kvartærformasjon': ('kvartærformasjon',),
'kvartærformasjonen': ('kvartærformasjon',),
'kvartærformasjonene': ('kvartærformasjon',),
'kvartærformasjoner': ('kvartærformasjon',),
'kvartærperiode': ('kvartærperiode',),
'kvartærperioden': ('kvartærperiode',),
'kvartærperiodene': ('kvartærperiode',),
'kvartærperioder': ('kvartærperiode',),
'kvartærsystem': ('kvartærsystem',),
'kvartærsystema': ('kvartærsystem',),
'kvartærsystemene': ('kvartærsystem',),
'kvartærsystemer': ('kvartærsystem',),
'kvartærsystemet': ('kvartærsystem',),
'kvarv': ('kvarv',),
'kvarva': ('kvarv',),
'kvarvene': ('kvarv',),
'kvarvet': ('kvarv',),
'kvas': ('kvas',),
'kvasa': ('kvas',),
'kvasene': ('kvas',),
'kvaset': ('kvas',),
'kvase': ('kvase',),
'kvasen': ('kvase',),
'kvasene': ('kvase',),
'kvaser': ('kvase',),
'kvasifilosofi': ('kvasifilosofi',),
'kvasifilosofien': ('kvasifilosofi',),
'kvasifilosofiene': ('kvasifilosofi',),
'kvasifilosofier': ('kvasifilosofi',),
'kvasivitenskap': ('kvasivitenskap',),
'kvasivitenskapen': ('kvasivitenskap',),
'kvasivitenskapene': ('kvasivitenskap',),
'kvasivitenskaper': ('kvasivitenskap',),
'kvass': ('kvass',),
'kvassen': ('kvass',),
'kvassene': ('kvass',),
'kvasser': ('kvass',),
'kvassbuk': ('kvassbuk',),
'kvassbuken': ('kvassbuk',),
'kvassbukene': ('kvassbuk',),
'kvassbuker': ('kvassbuk',),
'kvassa': ('kvasse',),
'kvasse': ('kvasse',),
'kvassen': ('kvasse',),
'kvassene': ('kvasse',),
'kvasser': ('kvasse',),
'kvast': ('kvast',),
'kvasten': ('kvast',),
'kvastene': ('kvast',),
'kvaster': ('kvast',),
'kvast': ('kvast',),
'kvastfinna': ('kvastfinne',),
'kvastfinne': ('kvastfinne',),
'kvastfinnen': ('kvastfinne',),
'kvastfinnene': ('kvastfinne',),
'kvastfinner': ('kvastfinne',),
'kvastfinnefisk': ('kvastfinnefisk',),
'kvastfinnefisken': ('kvastfinnefisk',),
'kvastfinnefiskene': ('kvastfinnefisk',),
'kvastfinnefisker': ('kvastfinnefisk',),
'kvav': ('kvav',),
'kvava': ('kvav',),
'kvavene': ('kvav',),
'kvavet': ('kvav',),
'kve': ('kve',),
'kvea': ('kve',),
'kveen': ('kve',),
'kveene': ('kve',),
'kveer': ('kve',),
'kvede': ('kvede',),
'kveden': ('kvede',),
'kvedene': ('kvede',),
'kveder': ('kvede',),
'kveda': ('kvede',),
'kvede': ('kvede',),
'kvedene': ('kvede',),
'kveder': ('kvede',),
'kvedet': ('kvede',),
'kveg': ('kveg',),
'kvega': ('kveg',),
'kvegene': ('kveg',),
'kveget': ('kveg',),
'kvegdrift': ('kvegdrift',),
'kvegdrifta': ('kvegdrift',),
'kvegdriften': ('kvegdrift',),
'kvegdriftene': ('kvegdrift',),
'kvegdrifter': ('kvegdrift',),
'kvegpest': ('kvegpest',),
'kvegpesta': ('kvegpest',),
'kvegpesten': ('kvegpest',),
'kvegpestene': ('kvegpest',),
'kvegpester': ('kvegpest',),
'kveik': ('kveik',),
'kveiken': ('kveik',),
'kveikene': ('kveik',),
'kveiker': ('kveik',),
'kveika': ('kveike',),
'kveike': ('kveike',),
'kveikene': ('kveike',),
'kveiker': ('kveike',),
'kveiket': ('kveike',),
'kveil': ('kveil',),
'kveilen': ('kveil',),
'kveilene': ('kveil',),
'kveiler': ('kveil',),
'kvein': ('kvein',),
'kveina': ('kvein',),
'kveinen': ('kvein',),
'kveinene': ('kvein',),
'kveiner': ('kvein',),
'kveis': ('kveis',),
'kveisa': ('kveis',),
'kveisen': ('kveis',),
'kveisene': ('kveis',),
'kveiser': ('kveis',),
'kveis': ('kveis',),
'kveisa': ('kveis',),
'kveisen': ('kveis',),
'kveisene': ('kveis',),
'kveiser': ('kveis',),
'kveisa': ('kveise',),
'kveise': ('kveise',),
'kveisen': ('kveise',),
'kveisene': ('kveise',),
'kveiser': ('kveise',),
'kveite': ('kveite',),
'kveiten': ('kveite',),
'kveitene': ('kveite',),
'kveiter': ('kveite',),
'kveite': ('kveite',),
'kveiten': ('kveite',),
'kveitene': ('kveite',),
'kveiter': ('kveite',),
'kveita': ('kveite',),
'kveite': ('kveite',),
'kveiten': ('kveite',),
'kveitene': ('kveite',),
'kveiter': ('kveite',),
'kveitebolle': ('kveitebolle',),
'kveitebollen': ('kveitebolle',),
'kveitebollene': ('kveitebolle',),
'kveiteboller': ('kveitebolle',),
'kveitebolle': ('kveitebolle',),
'kveitebollen': ('kveitebolle',),
'kveitebollene': ('kveitebolle',),
'kveiteboller': ('kveitebolle',),
'kveitebrød': ('kveitebrød',),
'kveitebrøda': ('kveitebrød',),
'kveitebrødene': ('kveitebrød',),
'kveitebrødet': ('kveitebrød',),
'kveitebrød': ('kveitebrød',),
'kveitebrøda': ('kveitebrød',),
'kveitebrødene': ('kveitebrød',),
'kveitebrødet': ('kveitebrød',),
'kveitebrødsdag': ('kveitebrødsdag',),
'kveitebrødsdagen': ('kveitebrødsdag',),
'kveitebrødsdagene': ('kveitebrødsdag',),
'kveitebrødsdager': ('kveitebrødsdag',),
'kveitebrødsdag': ('kveitebrødsdag',),
'kveitebrødsdagen': ('kveitebrødsdag',),
'kveitebrødsdagene': ('kveitebrødsdag',),
'kveitebrødsdager': ('kveitebrødsdag',),
'kveitegrøpp': ('kveitegrøpp',),
'kveitegrøppa': ('kveitegrøpp',),
'kveitegrøppene': ('kveitegrøpp',),
'kveitegrøppet': ('kveitegrøpp',),
'kveitegrøpp': ('kveitegrøpp',),
'kveitegrøppa': ('kveitegrøpp',),
'kveitegrøppene': ('kveitegrøpp',),
'kveitegrøppet': ('kveitegrøpp',),
'kveitekaka': ('kveitekake',),
'kveitekake': ('kveitekake',),
'kveitekaken': ('kveitekake',),
'kveitekakene': ('kveitekake',),
'kveitekaker': ('kveitekake',),
'kveitekaka': ('kveitekake',),
'kveitekake': ('kveitekake',),
'kveitekaken': ('kveitekake',),
'kveitekakene': ('kveitekake',),
'kveitekaker': ('kveitekake',),
'kveitekli': ('kveitekli',),
'kveiteklia': ('kveitekli',),
'kveitekliene': ('kveitekli',),
'kveitekliet': ('kveitekli',),
'kveitekli': ('kveitekli',),
'kveiteklia': ('kveitekli',),
'kveitekliene': ('kveitekli',),
'kveitekliet': ('kveitekli',),
'kveitekorn': ('kveitekorn',),
'kveitekorna': ('kveitekorn',),
'kveitekornene': ('kveitekorn',),
'kveitekornet': ('kveitekorn',),
'kveitekorn': ('kveitekorn',),
'kveitekorna': ('kveitekorn',),
'kveitekornene': ('kveitekorn',),
'kveitekornet': ('kveitekorn',),
'kveitemel': ('kveitemel',),
'kveitemela': ('kveitemel',),
'kveitemelene': ('kveitemel',),
'kveitemelet': ('kveitemel',),
'kveitemel': ('kveitemel',),
'kveitemela': ('kveitemel',),
'kveitemelene': ('kveitemel',),
'kveitemelet': ('kveitemel',),
'kveitemjøl': ('kveitemjøl',),
'kveitemjøla': ('kveitemjøl',),
'kveitemjølene': ('kveitemjøl',),
'kveitemjølet': ('kveitemjøl',),
'kveitemjøl': ('kveitemjøl',),
'kveitemjøla': ('kveitemjøl',),
'kveitemjølene': ('kveitemjøl',),
'kveitemjølet': ('kveitemjøl',),
'kveka': ('kveke',),
'kveke': ('kveke',),
'kveken': ('kveke',),
'kvekene': ('kveke',),
'kveker': ('kveke',),
'kveker': ('kveker',),
'kvekere': ('kveker',),
'kvekeren': ('kveker',),
'kvekerer': ('kveker',),
'kvekerne': ('kveker',),
'kvekerhatt': ('kvekerhatt',),
'kvekerhatten': ('kvekerhatt',),
'kvekerhattene': ('kvekerhatt',),
'kvekerhatter': ('kvekerhatt',),
'kvekersamfunn': ('kvekersamfunn',),
'kvekersamfunna': ('kvekersamfunn',),
'kvekersamfunnene': ('kvekersamfunn',),
'kvekersamfunnet': ('kvekersamfunn',),
'kvekk': ('kvekk',),
'kvekka': ('kvekk',),
'kvekken': ('kvekk',),
'kvekkene': ('kvekk',),
'kvekker': ('kvekk',),
'kvekket': ('kvekk',),
'kvekk': ('kvekk',),
'kvekka': ('kvekk',),
'kvekkene': ('kvekk',),
'kvekket': ('kvekk',),
'kveld': ('kveld',),
'kvelden': ('kveld',),
'kveldene': ('kveld',),
'kvelder': ('kveld',),
'kveldfiol': ('kveldfiol',),
'kveldfiolen': ('kveldfiol',),
'kveldfiolene': ('kveldfiol',),
'kveldfioler': ('kveldfiol',),
'kveldfugl': ('kveldfugl',),
'kveldfuglen': ('kveldfugl',),
'kveldfuglene': ('kveldfugl',),
'kveldfugler': ('kveldfugl',),
'kvelding': ('kvelding',),
'kveldinga': ('kvelding',),
'kveldingen': ('kvelding',),
'kveldingene': ('kvelding',),
'kveldinger': ('kvelding',),
'kveldknarr': ('kveldknarr',),
'kveldknarren': ('kveldknarr',),
'kveldknarrene': ('kveldknarr',),
'kveldknarrer': ('kveldknarr',),
'kveldsarbeid': ('kveldsarbeid',),
'kveldsarbeida': ('kveldsarbeid',),
'kveldsarbeidene': ('kveldsarbeid',),
'kveldsarbeider': ('kveldsarbeid',),
'kveldsarbeidet': ('kveldsarbeid',),
'kveldsbeita': ('kveldsbeite',),
'kveldsbeite': ('kveldsbeite',),
'kveldsbeitene': ('kveldsbeite',),
'kveldsbeiter': ('kveldsbeite',),
'kveldsbeitet': ('kveldsbeite',),
'kveldsbord': ('kveldsbord',),
'kveldsborda': ('kveldsbord',),
'kveldsbordene': ('kveldsbord',),
'kveldsborder': ('kveldsbord',),
'kveldsbordet': ('kveldsbord',),
'kveldsbønn': ('kveldsbønn',),
'kveldsbønna': ('kveldsbønn',),
'kveldsbønnen': ('kveldsbønn',),
'kveldsbønnene': ('kveldsbønn',),
'kveldsbønner': ('kveldsbønn',),
'kveldseta': ('kveldsete',),
'kveldsete': ('kveldsete',),
'kveldseten': ('kveldsete',),
'kveldsetene': ('kveldsete',),
'kveldseter': ('kveldsete',),
'kveldshimlene': ('kveldshimmel',),
'kveldshimler': ('kveldshimmel',),
'kveldshimmel': ('kveldshimmel',),
'kveldshimmelen': ('kveldshimmel',),
'kveldskingla': ('kveldskingle',),
'kveldskingle': ('kveldskingle',),
'kveldskinglen': ('kveldskingle',),
'kveldskinglene': ('kveldskingle',),
'kveldskingler': ('kveldskingle',),
'kveldsmat': ('kveldsmat',),
'kveldsmaten': ('kveldsmat',),
'kveldsmatene': ('kveldsmat',),
'kveldsmater': ('kveldsmat',),
'kveldsmål': ('kveldsmål',),
'kveldsmåla': ('kveldsmål',),
'kveldsmålene': ('kveldsmål',),
'kveldsmålet': ('kveldsmål',),
'kveldsperm': ('kveldsperm',),
'kveldspermen': ('kveldsperm',),
'kveldspermene': ('kveldsperm',),
'kveldspermer': ('kveldsperm',),
'kveldspermisjon': ('kveldspermisjon',),
'kveldspermisjonen': ('kveldspermisjon',),
'kveldspermisjonene': ('kveldspermisjon',),
'kveldspermisjoner': ('kveldspermisjon',),
'kveldsskole': ('kveldsskole',),
'kveldsskolen': ('kveldsskole',),
'kveldsskolene': ('kveldsskole',),
'kveldsskoler': ('kveldsskole',),
'kveldsstund': ('kveldsstund',),
'kveldsstunda': ('kveldsstund',),
'kveldsstunden': ('kveldsstund',),
'kveldsstundene': ('kveldsstund',),
'kveldsstunder': ('kveldsstund',),
'kveldstid': ('kveldstid',),
'kveldstida': ('kveldstid',),
'kveldstiden': ('kveldstid',),
'kveldstidene': ('kveldstid',),
'kveldstider': ('kveldstid',),
'kveldstund': ('kveldstund',),
'kveldstunda': ('kveldstund',),
'kveldstunden': ('kveldstund',),
'kveldstundene': ('kveldstund',),
'kveldstunder': ('kveldstund',),
'kveldsverd': ('kveldsverd',),
'kveldsverden': ('kveldsverd',),
'kveldsverdene': ('kveldsverd',),
'kveldsverder': ('kveldsverd',),
'kveldsøkt': ('kveldsøkt',),
'kveldsøkta': ('kveldsøkt',),
'kveldsøkten': ('kveldsøkt',),
'kveldsøktene': ('kveldsøkt',),
'kveldsøkter': ('kveldsøkt',),
'kveler': ('kveler',),
'kvelere': ('kveler',),
'kveleren': ('kveler',),
'kvelerer': ('kveler',),
'kvelerne': ('kveler',),
'kvelerslange': ('kvelerslange',),
'kvelerslangen': ('kvelerslange',),
'kvelerslangene': ('kvelerslange',),
'kvelerslanger': ('kvelerslange',),
'kvelertak': ('kvelertak',),
'kvelertaka': ('kvelertak',),
'kvelertakene': ('kvelertak',),
'kvelertaket': ('kvelertak',),
'kvelning': ('kvelning',),
'kvelninga': ('kvelning',),
'kvelningen': ('kvelning',),
'kvelningene': ('kvelning',),
'kvelninger': ('kvelning',),
'kvelstoff': ('kvelstoff',),
'kvelstoffa': ('kvelstoff',),
'kvelstoffene': ('kvelstoff',),
'kvelstoffet': ('kvelstoff',),
'kvelv': ('kvelv',),
'kvelva': ('kvelv',),
'kvelven': ('kvelv',),
'kvelvene': ('kvelv',),
'kvelver': ('kvelv',),
'kvelvet': ('kvelv',),
'kvelving': ('kvelving',),
'kvelvingen': ('kvelving',),
'kvelvingene': ('kvelving',),
'kvelvinger': ('kvelving',),
'kven': ('kven',),
'kvenen': ('kven',),
'kvenene': ('kven',),
'kvener': ('kven',),
'kvensk': ('kvensk',),
'kvensken': ('kvensk',),
'kvenskene': ('kvensk',),
'kvensker': ('kvensk',),
'kvepp': ('kvepp',),
'kveppen': ('kvepp',),
'kveppene': ('kvepp',),
'kvepper': ('kvepp',),
'kverk': ('kverk',),
'kverken': ('kverk',),
'kverkene': ('kverk',),
'kverker': ('kverk',),
'kverka': ('kverke',),
'kverke': ('kverke',),
'kverken': ('kverke',),
'kverkene': ('kverke',),
'kverker': ('kverke',),
'kverkesvull': ('kverkesvull',),
'kverkesvullen': ('kverkesvull',),
'kverkesvullene': ('kverkesvull',),
'kverkesvuller': ('kverkesvull',),
'kvern': ('kvern',),
'kverna': ('kvern',),
'kvernen': ('kvern',),
'kvernene': ('kvern',),
'kverner': ('kvern',),
'kvernbruk': ('kvernbruk',),
'kvernbruka': ('kvernbruk',),
'kvernbrukene': ('kvernbruk',),
'kvernbruket': ('kvernbruk',),
'kverndam': ('kverndam',),
'kverndammen': ('kverndam',),
'kverndammene': ('kverndam',),
'kverndammer': ('kverndam',),
'kvernhus': ('kvernhus',),
'kvernhusa': ('kvernhus',),
'kvernhusene': ('kvernhus',),
'kvernhuset': ('kvernhus',),
'kvernkall': ('kvernkall',),
'kvernkallen': ('kvernkall',),
'kvernkallene': ('kvernkall',),
'kvernkaller': ('kvernkall',),
'kvernstein': ('kvernstein',),
'kvernsteinen': ('kvernstein',),
'kvernsteinene': ('kvernstein',),
'kvernsteiner': ('kvernstein',),
'kvernvann': ('kvernvann',),
'kvernvanna': ('kvernvann',),
'kvernvannene': ('kvernvann',),
'kvernvannet': ('kvernvann',),
'kvernvatn': ('kvernvatn',),
'kvernvatna': ('kvernvatn',),
'kvernvatnene': ('kvernvatn',),
'kvernvatnet': ('kvernvatn',),
'kversill': ('kversill',),
'kversilla': ('kversill',),
'kversillen': ('kversill',),
'kversillene': ('kversill',),
'kversiller': ('kversill',),
'kverulant': ('kverulant',),
'kverulanten': ('kverulant',),
'kverulantene': ('kverulant',),
'kverulanter': ('kverulant',),
'kverv': ('kverv',),
'kverva': ('kverv',),
'kvervene': ('kverv',),
'kvervet': ('kverv',),
'kverva': ('kverve',),
'kverve': ('kverve',),
'kvervene': ('kverve',),
'kverver': ('kverve',),
'kvervet': ('kverve',),
'kverva': ('kverve',),
'kverve': ('kverve',),
'kverven': ('kverve',),
'kvervene': ('kverve',),
'kverver': ('kverve',),
'kves': ('kves',),
'kvesa': ('kves',),
'kvesene': ('kves',),
'kveset': ('kves',),
'kvestelse': ('kvestelse',),
'kvestelsen': ('kvestelse',),
'kvestelsene': ('kvestelse',),
'kvestelser': ('kvestelse',),
'kvestor': ('kvestor',),
'kvestoren': ('kvestor',),
'kvestorene': ('kvestor',),
'kvestorer': ('kvestor',),
'kvestur': ('kvestur',),
'kvestura': ('kvestur',),
'kvesturene': ('kvestur',),
'kvesturer': ('kvestur',),
'kvesturet': ('kvestur',),
'kvide': ('kvide',),
'kviden': ('kvide',),
'kvidene': ('kvide',),
'kvider': ('kvide',),
'kviga': ('kvige',),
'kvige': ('kvige',),
'kvigen': ('kvige',),
'kvigene': ('kvige',),
'kviger': ('kvige',),
'kvik': ('kvik',),
'kviken': ('kvik',),
'kvikene': ('kvik',),
'kviker': ('kvik',),
'kvike': ('kvike',),
'kviken': ('kvike',),
'kvikene': ('kvike',),
'kviker': ('kvike',),
'kvikenda': ('kvikende',),
'kvikende': ('kvikende',),
'kvikendene': ('kvikende',),
'kvikender': ('kvikende',),
'kvikendet': ('kvikende',),
'kvikkleira': ('kvikkleire',),
'kvikkleire': ('kvikkleire',),
'kvikkleiren': ('kvikkleire',),
'kvikkleirene': ('kvikkleire',),
'kvikkleirer': ('kvikkleire',),
'kvikksand': ('kvikksand',),
'kvikksanden': ('kvikksand',),
'kvikksandene': ('kvikksand',),
'kvikksander': ('kvikksand',),
'kvikksølv': ('kvikksølv',),
'kvikksølva': ('kvikksølv',),
'kvikksølvene': ('kvikksølv',),
'kvikksølvet': ('kvikksølv',),
'kvikksølvdamplampa': ('kvikksølvdamplampe',),
'kvikksølvdamplampe': ('kvikksølvdamplampe',),
'kvikksølvdamplampen': ('kvikksølvdamplampe',),
'kvikksølvdamplampene': ('kvikksølvdamplampe',),
'kvikksølvdamplamper': ('kvikksølvdamplampe',),
'kvikksølvdød': ('kvikksølvdød',),
'kvikksølvdøden': ('kvikksølvdød',),
'kvikksølvdødene': ('kvikksølvdød',),
'kvikksølvdøder': ('kvikksølvdød',),
'kvikksølvtermometer': ('kvikksølvtermometer',),
'kvikksølvtermometeret': ('kvikksølvtermometer',),
'kvikksølvtermometra': ('kvikksølvtermometer',),
'kvikksølvtermometre': ('kvikksølvtermometer',),
'kvikksølvtermometrene': ('kvikksølvtermometer',),
'kvikksølvtermometret': ('kvikksølvtermometer',),
'kvil': ('kvil',),
'kvila': ('kvil',),
'kvilen': ('kvil',),
'kvilene': ('kvil',),
'kviler': ('kvil',),
'kvila': ('kvile',),
'kvile': ('kvile',),
'kvilen': ('kvile',),
'kvilene': ('kvile',),
'kviler': ('kvile',),
'kvilebu': ('kvilebu',),
'kvilebua': ('kvilebu',),
'kvilebuen': ('kvilebu',),
'kvilebuene': ('kvilebu',),
'kvilebuer': ('kvilebu',),
'kviledag': ('kviledag',),
'kviledagen': ('kviledag',),
'kviledagene': ('kviledag',),
'kviledager': ('kviledag',),
'kvileheim': ('kvileheim',),
'kvileheimma': ('kvileheim',),
'kvileheimmene': ('kvileheim',),
'kvileheimmet': ('kvileheim',),
'kvilehjem': ('kvilehjem',),
'kvilehjemma': ('kvilehjem',),
'kvilehjemmene': ('kvilehjem',),
'kvilehjemmet': ('kvilehjem',),
'kvilepause': ('kvilepause',),
'kvilepausen': ('kvilepause',),
'kvilepausene': ('kvilepause',),
'kvilepauser': ('kvilepause',),
'kvileseta': ('kvilesete',),
'kvilesete': ('kvilesete',),
'kvilesetene': ('kvilesete',),
'kvileseter': ('kvilesete',),
'kvilesetet': ('kvilesete',),
'kvilested': ('kvilested',),
'kvilestedene': ('kvilested',),
'kvilesteder': ('kvilested',),
'kvilestedet': ('kvilested',),
'kvilestilling': ('kvilestilling',),
'kvilestillinga': ('kvilestilling',),
'kvilestillingen': ('kvilestilling',),
'kvilestillingene': ('kvilestilling',),
'kvilestillinger': ('kvilestilling',),
'kvilestrøm': ('kvilestrøm',),
'kvilestrømmen': ('kvilestrøm',),
'kvilestrømmene': ('kvilestrøm',),
'kvilestrømmer': ('kvilestrøm',),
'kvileår': ('kvileår',),
'kvileåra': ('kvileår',),
'kvileårene': ('kvileår',),
'kvileåret': ('kvileår',),
'kvin': ('kvin',),
'kvina': ('kvin',),
'kvinen': ('kvin',),
'kvinene': ('kvin',),
'kvinet': ('kvin',),
'kvinand': ('kvinand',),
'kvinanda': ('kvinand',),
'kvinanden': ('kvinand',),
'kvinendene': ('kvinand',),
'kvinender': ('kvinand',),
'kvink': ('kvink',),
'kvinka': ('kvink',),
'kvinken': ('kvink',),
'kvinkene': ('kvink',),
'kvinket': ('kvink',),
'kvinkvagesima': ('kvinkvagesima',),
'kvinna': ('kvinne',),
'kvinne': ('kvinne',),
'kvinnen': ('kvinne',),
'kvinnene': ('kvinne',),
'kvinner': ('kvinne',),
'kvinneaksjon': ('kvinneaksjon',),
'kvinneaksjonen': ('kvinneaksjon',),
'kvinneaksjonene': ('kvinneaksjon',),
'kvinneaksjoner': ('kvinneaksjon',),
'kvinnebedårer': ('kvinnebedårer',),
'kvinnebedårere': ('kvinnebedårer',),
'kvinnebedåreren': ('kvinnebedårer',),
'kvinnebedårerer': ('kvinnebedårer',),
'kvinnebedårerne': ('kvinnebedårer',),
'kvinnedag': ('kvinnedag',),
'kvinnedagen': ('kvinnedag',),
'kvinnedagene': ('kvinnedag',),
'kvinnedager': ('kvinnedag',),
'kvinnediskriminering': ('kvinnediskriminering',),
'kvinnediskrimineringa': ('kvinnediskriminering',),
'kvinnediskrimineringen': ('kvinnediskriminering',),
'kvinnediskrimineringene': ('kvinnediskriminering',),
'kvinnediskrimineringer': ('kvinnediskriminering',),
'kvinneemansipasjon': ('kvinneemansipasjon',),
'kvinneemansipasjonen': ('kvinneemansipasjon',),
'kvinneemansipasjonene': ('kvinneemansipasjon',),
'kvinneemansipasjoner': ('kvinneemansipasjon',),
'kvinnefrigjøring': ('kvinnefrigjøring',),
'kvinnefrigjøringa': ('kvinnefrigjøring',),
'kvinnefrigjøringen': ('kvinnefrigjøring',),
'kvinnefrigjøringene': ('kvinnefrigjøring',),
'kvinnefrigjøringer': ('kvinnefrigjøring',),
'kvinnegruppa': ('kvinnegruppe',),
'kvinnegruppe': ('kvinnegruppe',),
'kvinnegruppen': ('kvinnegruppe',),
'kvinnegruppene': ('kvinnegruppe',),
'kvinnegrupper': ('kvinnegruppe',),
'kvinneidrett': ('kvinneidrett',),
'kvinneidretten': ('kvinneidrett',),
'kvinneidrettene': ('kvinneidrett',),
'kvinneidretter': ('kvinneidrett',),
'kvinnejeger': ('kvinnejeger',),
'kvinnejegere': ('kvinnejeger',),
'kvinnejegeren': ('kvinnejeger',),
'kvinnejegerer': ('kvinnejeger',),
'kvinnejegerne': ('kvinnejeger',),
'kvinnekamp': ('kvinnekamp',),
'kvinnekampen': ('kvinnekamp',),
'kvinnekampene': ('kvinnekamp',),
'kvinnekamper': ('kvinnekamp',),
'kvinnekjønn': ('kvinnekjønn',),
'kvinnekjønna': ('kvinnekjønn',),
'kvinnekjønnene': ('kvinnekjønn',),
'kvinnekjønnet': ('kvinnekjønn',),
'kvinneklinikk': ('kvinneklinikk',),
'kvinneklinikken': ('kvinneklinikk',),
'kvinneklinikkene': ('kvinneklinikk',),
'kvinneklinikker': ('kvinneklinikk',),
'kvinnelege': ('kvinnelege',),
'kvinnelegen': ('kvinnelege',),
'kvinnelegene': ('kvinnelege',),
'kvinneleger': ('kvinnelege',),
'kvinnelist': ('kvinnelist',),
'kvinnelista': ('kvinnelist',),
'kvinnelisten': ('kvinnelist',),
'kvinnelistene': ('kvinnelist',),
'kvinnelister': ('kvinnelist',),
'kvinnelitteratur': ('kvinnelitteratur',),
'kvinnelitteraturen': ('kvinnelitteratur',),
'kvinnelitteraturene': ('kvinnelitteratur',),
'kvinnelitteraturer': ('kvinnelitteratur',),
'kvinnemenneska': ('kvinnemenneske',),
'kvinnemenneske': ('kvinnemenneske',),
'kvinnemenneskene': ('kvinnemenneske',),
'kvinnemennesker': ('kvinnemenneske',),
'kvinnemennesket': ('kvinnemenneske',),
'kvinnerepresentasjon': ('kvinnerepresentasjon',),
'kvinnerepresentasjonen': ('kvinnerepresentasjon',),
'kvinnerepresentasjonene': ('kvinnerepresentasjon',),
'kvinnerepresentasjoner': ('kvinnerepresentasjon',),
'kvinnerolla': ('kvinnerolle',),
'kvinnerolle': ('kvinnerolle',),
'kvinnerollen': ('kvinnerolle',),
'kvinnerollene': ('kvinnerolle',),
'kvinneroller': ('kvinnerolle',),
'kvinnesak': ('kvinnesak',),
'kvinnesaka': ('kvinnesak',),
'kvinnesaken': ('kvinnesak',),
'kvinnesakene': ('kvinnesak',),
'kvinnesaker': ('kvinnesak',),
'kvinnesakskvinna': ('kvinnesakskvinne',),
'kvinnesakskvinne': ('kvinnesakskvinne',),
'kvinnesakskvinnen': ('kvinnesakskvinne',),
'kvinnesakskvinnene': ('kvinnesakskvinne',),
'kvinnesakskvinner': ('kvinnesakskvinne',),
'kvinnesaksmann': ('kvinnesaksmann',),
'kvinnesaksmannen': ('kvinnesaksmann',),
'kvinnesaksmenn': ('kvinnesaksmann',),
'kvinnesaksmennene': ('kvinnesaksmann',),
'kvinnetekka': ('kvinnetekke',),
'kvinnetekke': ('kvinnetekke',),
'kvinnetekkene': ('kvinnetekke',),
'kvinnetekker': ('kvinnetekke',),
'kvinnetekket': ('kvinnetekke',),
'kvinneundertrykkelse': ('kvinneundertrykkelse',),
'kvinneundertrykkelsen': ('kvinneundertrykkelse',),
'kvinneundertrykkelsene': ('kvinneundertrykkelse',),
'kvinneundertrykkelser': ('kvinneundertrykkelse',),
'kvinneyrka': ('kvinneyrke',),
'kvinneyrke': ('kvinneyrke',),
'kvinneyrkene': ('kvinneyrke',),
'kvinneyrker': ('kvinneyrke',),
'kvinneyrket': ('kvinneyrke',),
'kvinnfolk': ('kvinnfolk',),
'kvinnfolka': ('kvinnfolk',),
'kvinnfolkene': ('kvinnfolk',),
'kvinnfolket': ('kvinnfolk',),
'kvinnfolkarbeid': ('kvinnfolkarbeid',),
'kvinnfolkarbeida': ('kvinnfolkarbeid',),
'kvinnfolkarbeidene': ('kvinnfolkarbeid',),
'kvinnfolkarbeider': ('kvinnfolkarbeid',),
'kvinnfolkarbeidet': ('kvinnfolkarbeid',),
'kvint': ('kvint',),
'kvinten': ('kvint',),
'kvintene': ('kvint',),
'kvinter': ('kvint',),
'kvintessens': ('kvintessens',),
'kvintessensen': ('kvintessens',),
'kvintessensene': ('kvintessens',),
'kvintessenser': ('kvintessens',),
'kvintett': ('kvintett',),
'kvintetten': ('kvintett',),
'kvintettene': ('kvintett',),
'kvintetter': ('kvintett',),
'kvirrevitt': ('kvirrevitt',),
'kvirrevitten': ('kvirrevitt',),
'kvirrevittene': ('kvirrevitt',),
'kvirrevitter': ('kvirrevitt',),
'kvisa': ('kvise',),
'kvise': ('kvise',),
'kvisen': ('kvise',),
'kvisene': ('kvise',),
'kviser': ('kvise',),
'kvisla': ('kvissel',),
'kvislene': ('kvissel',),
'kvisler': ('kvissel',),
'kvissel': ('kvissel',),
'kvisselen': ('kvissel',),
'kvist': ('kvist',),
'kvisten': ('kvist',),
'kvistene': ('kvist',),
'kvister': ('kvist',),
'kvisthol': ('kvisthol',),
'kvisthola': ('kvisthol',),
'kvistholene': ('kvisthol',),
'kvistholet': ('kvisthol',),
'kvisthull': ('kvisthull',),
'kvisthulla': ('kvisthull',),
'kvisthullene': ('kvisthull',),
'kvisthuller': ('kvisthull',),
'kvisthullet': ('kvisthull',),
'kvistlakk': ('kvistlakk',),
'kvistlakken': ('kvistlakk',),
'kvistlakkene': ('kvistlakk',),
'kvistlakker': ('kvistlakk',),
'kvistrom': ('kvistrom',),
'kvistromma': ('kvistrom',),
'kvistrommene': ('kvistrom',),
'kvistrommet': ('kvistrom',),
'kvitbjørn': ('kvitbjørn',),
'kvitbjørnen': ('kvitbjørn',),
'kvitbjørnene': ('kvitbjørn',),
'kvitbjørner': ('kvitbjørn',),
'kvitbrystlo': ('kvitbrystlo',),
'kvitbrystloa': ('kvitbrystlo',),
'kvitbrystloen': ('kvitbrystlo',),
'kvitbrystloene': ('kvitbrystlo',),
'kvitbrystloer': ('kvitbrystlo',),
'kvite': ('kvite',),
'kviten': ('kvite',),
'kvitene': ('kvite',),
'kviter': ('kvite',),
'kvitel': ('kvitel',),
'kvitelen': ('kvitel',),
'kvitlene': ('kvitel',),
'kvitler': ('kvitel',),
'kvitemiddel': ('kvitemiddel',),
'kvitemiddelet': ('kvitemiddel',),
'kvitemidla': ('kvitemiddel',),
'kvitemidlene': ('kvitemiddel',),
'kvitemidler': ('kvitemiddel',),
'kvitemidlet': ('kvitemiddel',),
'kviterusser': ('kviterusser',),
'kviterussere': ('kviterusser',),
'kviterusseren': ('kviterusser',),
'kviterusserer': ('kviterusser',),
'kviterusserne': ('kviterusser',),
'kvitevara': ('kvitevare',),
'kvitevare': ('kvitevare',),
'kvitevaren': ('kvitevare',),
'kvitevarene': ('kvitevare',),
'kvitevarer': ('kvitevare',),
'kvitfisk': ('kvitfisk',),
'kvitfisken': ('kvitfisk',),
'kvitfiskene': ('kvitfisk',),
'kvitfisker': ('kvitfisk',),
'kvithval': ('kvithval',),
'kvithvalen': ('kvithval',),
'kvithvalene': ('kvithval',),
'kvithvaler': ('kvithval',),
'kviting': ('kviting',),
'kvitingen': ('kviting',),
'kvitingene': ('kviting',),
'kvitinger': ('kviting',),
'kviting': ('kviting',),
'kvitingen': ('kviting',),
'kvitingene': ('kviting',),
'kvitinger': ('kviting',),
'kviting': ('kviting',),
'kvitingen': ('kviting',),
'kvitingene': ('kviting',),
'kvitinger': ('kviting',),
'kvitkløver': ('kvitkløver',),
'kvitkløvere': ('kvitkløver',),
'kvitkløveren': ('kvitkløver',),
'kvitkløverer': ('kvitkløver',),
'kvitkløverne': ('kvitkløver',),
'kvitkrull': ('kvitkrull',),
'kvitkrullen': ('kvitkrull',),
'kvitkrullene': ('kvitkrull',),
'kvitkruller': ('kvitkrull',),
'kvitkval': ('kvitkval',),
'kvitkvalen': ('kvitkval',),
'kvitkvalene': ('kvitkval',),
'kvitkvaler': ('kvitkval',),
'kvitkål': ('kvitkål',),
'kvitkålen': ('kvitkål',),
'kvitkålene': ('kvitkål',),
'kvitkåler': ('kvitkål',),
'kvitløk': ('kvitløk',),
'kvitløken': ('kvitløk',),
'kvitløkene': ('kvitløk',),
'kvitløker': ('kvitløk',),
'kvitløkfedd': ('kvitløkfedd',),
'kvitløkfedda': ('kvitløkfedd',),
'kvitløkfeddene': ('kvitløkfedd',),
'kvitløkfeddet': ('kvitløkfedd',),
'kvitlølpulver': ('kvitlølpulver',),
'kvitlølpulvera': ('kvitlølpulver',),
'kvitlølpulvere': ('kvitlølpulver',),
'kvitlølpulveret': ('kvitlølpulver',),
'kvitlølpulverne': ('kvitlølpulver',),
'kvitmetall': ('kvitmetall',),
'kvitmetalla': ('kvitmetall',),
'kvitmetallene': ('kvitmetall',),
'kvitmetaller': ('kvitmetall',),
'kvitmetallet': ('kvitmetall',),
'kvitmose': ('kvitmose',),
'kvitmosen': ('kvitmose',),
'kvitmosene': ('kvitmose',),
'kvitmoser': ('kvitmose',),
'kvitost': ('kvitost',),
'kvitosten': ('kvitost',),
'kvitostene': ('kvitost',),
'kvitoster': ('kvitost',),
'kvitrev': ('kvitrev',),
'kvitreven': ('kvitrev',),
'kvitrevene': ('kvitrev',),
'kvitrever': ('kvitrev',),
'kvitrust': ('kvitrust',),
'kvitrusta': ('kvitrust',),
'kvitrusten': ('kvitrust',),
'kvitrustene': ('kvitrust',),
'kvitruster': ('kvitrust',),
'kvitsnipp': ('kvitsnipp',),
'kvitsnippen': ('kvitsnipp',),
'kvitsnippene': ('kvitsnipp',),
'kvitsnipper': ('kvitsnipp',),
'kvitsnippforbrytelse': ('kvitsnippforbrytelse',),
'kvitsnippforbrytelsen': ('kvitsnippforbrytelse',),
'kvitsnippforbrytelsene': ('kvitsnippforbrytelse',),
'kvitsnippforbrytelser': ('kvitsnippforbrytelse',),
'kvitsnippforbryter': ('kvitsnippforbryter',),
'kvitsnippforbrytere': ('kvitsnippforbryter',),
'kvitsnippforbryteren': ('kvitsnippforbryter',),
'kvitsnippforbryterer': ('kvitsnippforbryter',),
'kvitsnippforbryterne': ('kvitsnippforbryter',),
'kvitsnippyrka': ('kvitsnippyrke',),
'kvitsnippyrke': ('kvitsnippyrke',),
'kvitsnippyrkene': ('kvitsnippyrke',),
'kvitsnippyrker': ('kvitsnippyrke',),
'kvitsnippyrket': ('kvitsnippyrke',),
'kvitsunnhelg': ('kvitsunnhelg',),
'kvitsunnhelga': ('kvitsunnhelg',),
'kvitsunnhelgen': ('kvitsunnhelg',),
'kvitsunnhelgene': ('kvitsunnhelg',),
'kvitsunnhelger': ('kvitsunnhelg',),
'kvitsymra': ('kvitsymre',),
'kvitsymre': ('kvitsymre',),
'kvitsymren': ('kvitsymre',),
'kvitsymrene': ('kvitsymre',),
'kvitsymrer': ('kvitsymre',),
'kvitt': ('kvitt',),
'kvitta': ('kvitt',),
'kvittene': ('kvitt',),
'kvittet': ('kvitt',),
'kvitra': ('kvitter',),
'kvitre': ('kvitter',),
'kvitrene': ('kvitter',),
'kvitret': ('kvitter',),
'kvitter': ('kvitter',),
'kvitteret': ('kvitter',),
'kvittering': ('kvittering',),
'kvitteringa': ('kvittering',),
'kvitteringen': ('kvittering',),
'kvitteringene': ('kvittering',),
'kvitteringer': ('kvittering',),
'kvitunge': ('kvitunge',),
'kvitungen': ('kvitunge',),
'kvitungene': ('kvitunge',),
'kvitunger': ('kvitunge',),
'kvitveis': ('kvitveis',),
'kvitveisen': ('kvitveis',),
'kvitveisene': ('kvitveis',),
'kvitveiser': ('kvitveis',),
'kvitvin': ('kvitvin',),
'kvitvinen': ('kvitvin',),
'kvitvinene': ('kvitvin',),
'kvitviner': ('kvitvin',),
'kvote': ('kvote',),
'kvoten': ('kvote',),
'kvotene': ('kvote',),
'kvoter': ('kvote',),
'kvoteordning': ('kvoteordning',),
'kvoteordninga': ('kvoteordning',),
'kvoteordningen': ('kvoteordning',),
'kvoteordningene': ('kvoteordning',),
'kvoteordninger': ('kvoteordning',),
'kvotering': ('kvotering',),
'kvoteringa': ('kvotering',),
'kvoteringen': ('kvotering',),
'kvoteringene': ('kvotering',),
'kvoteringer': ('kvotering',),
'kvotetildeling': ('kvotetildeling',),
'kvotetildelinga': ('kvotetildeling',),
'kvotetildelingen': ('kvotetildeling',),
'kvotetildelingene': ('kvotetildeling',),
'kvotetildelinger': ('kvotetildeling',),
'kvotient': ('kvotient',),
'kvotienten': ('kvotient',),
'kvotientene': ('kvotient',),
'kvotienter': ('kvotient',),
'kwashiorkor': ('kwashiorkor',),
'kwashiorkoren': ('kwashiorkor',),
'kwashiorkorene': ('kwashiorkor',),
'kwashiorkorer': ('kwashiorkor',),
'kybernetiker': ('kybernetiker',),
'kybernetikere': ('kybernetiker',),
'kybernetikeren': ('kybernetiker',),
'kybernetikerer': ('kybernetiker',),
'kybernetikerne': ('kybernetiker',),
'kybernetikk': ('kybernetikk',),
'kybernetikken': ('kybernetikk',),
'kybernetikkene': ('kybernetikk',),
'kybernetikker': ('kybernetikk',),
'kykeliky': ('kykeliky',),
'kykelikya': ('kykeliky',),
'kykelikyene': ('kykeliky',),
'kykelikyer': ('kykeliky',),
'kykelikyet': ('kykeliky',),
'kyklop': ('kyklop',),
'kyklopen': ('kyklop',),
'kyklopene': ('kyklop',),
'kykloper': ('kyklop',),
'kylling': ('kylling',),
'kyllingen': ('kylling',),
'kyllingene': ('kylling',),
'kyllinger': ('kylling',),
'kyllingegg': ('kyllingegg',),
'kyllingegga': ('kyllingegg',),
'kyllingeggene': ('kyllingegg',),
'kyllingegget': ('kyllingegg',),
'kylna': ('kylne',),
'kylne': ('kylne',),
'kylnen': ('kylne',),
'kylnene': ('kylne',),
'kylner': ('kylne',),
'kymrer': ('kymrer',),
'kymrere': ('kymrer',),
'kymreren': ('kymrer',),
'kymrerer': ('kymrer',),
'kymrerne': ('kymrer',),
'kymrisk': ('kymrisk',),
'kymrisken': ('kymrisk',),
'kymriskene': ('kymrisk',),
'kymrisker': ('kymrisk',),
'kynd': ('kynd',),
'kynda': ('kynd',),
'kynden': ('kynd',),
'kyndene': ('kynd',),
'kynder': ('kynd',),
'kynda': ('kynde',),
'kynde': ('kynde',),
'kyndene': ('kynde',),
'kynder': ('kynde',),
'kyndet': ('kynde',),
'kyndel': ('kyndel',),
'kyndelen': ('kyndel',),
'kyndlene': ('kyndel',),
'kyndler': ('kyndel',),
'kyndelsmess': ('kyndelsmess',),
'kyndelsmesse': ('kyndelsmesse',),
'kyniker': ('kyniker',),
'kynikere': ('kyniker',),
'kynikeren': ('kyniker',),
'kynikerer': ('kyniker',),
'kynikerne': ('kyniker',),
'kynisme': ('kynisme',),
'kynismen': ('kynisme',),
'kynismene': ('kynisme',),
'kynismer': ('kynisme',),
'kynna': ('kynne',),
'kynne': ('kynne',),
'kynnene': ('kynne',),
'kynner': ('kynne',),
'kynnet': ('kynne',),
'kypriot': ('kypriot',),
'kyprioten': ('kypriot',),
'kypriotene': ('kypriot',),
'kyprioter': ('kypriot',),
'kyrass': ('kyrass',),
'kyrassa': ('kyrass',),
'kyrassene': ('kyrass',),
'kyrasser': ('kyrass',),
'kyrasset': ('kyrass',),
'kyrasser': ('kyrasser',),
'kyrasseren': ('kyrasser',),
'kyrasserene': ('kyrasser',),
'kyrasserer': ('kyrasser',),
'kyrlag': ('kyrlag',),
'kyrlaga': ('kyrlag',),
'kyrlagene': ('kyrlag',),
'kyrlaget': ('kyrlag',),
'kysa': ('kyse',),
'kyse': ('kyse',),
'kysen': ('kyse',),
'kysene': ('kyse',),
'kyser': ('kyse',),
'kysehatt': ('kysehatt',),
'kysehatten': ('kysehatt',),
'kysehattene': ('kysehatt',),
'kysehatter': ('kysehatt',),
'kyskhetsbelta': ('kyskhetsbelte',),
'kyskhetsbelte': ('kyskhetsbelte',),
'kyskhetsbeltene': ('kyskhetsbelte',),
'kyskhetsbelter': ('kyskhetsbelte',),
'kyskhetsbeltet': ('kyskhetsbelte',),
'kyss': ('kyss',),
'kyssa': ('kyss',),
'kyssen': ('kyss',),
'kyssene': ('kyss',),
'kysset': ('kyss',),
'kyst': ('kyst',),
'kysten': ('kyst',),
'kystene': ('kyst',),
'kyster': ('kyst',),
'kystartilleri': ('kystartilleri',),
'kystartilleria': ('kystartilleri',),
'kystartilleriene': ('kystartilleri',),
'kystartillerier': ('kystartilleri',),
'kystartilleriet': ('kystartilleri',),
'kystfart': ('kystfart',),
'kystfarten': ('kystfart',),
'kystfartene': ('kystfart',),
'kystfarter': ('kystfart',),
'kystfiska': ('kystfiske',),
'kystfiske': ('kystfiske',),
'kystfiskene': ('kystfiske',),
'kystfisker': ('kystfiske',),
'kystfisket': ('kystfiske',),
'kystforsvar': ('kystforsvar',),
'kystforsvara': ('kystforsvar',),
'kystforsvarene': ('kystforsvar',),
'kystforsvaret': ('kystforsvar',),
'kystklima': ('kystklima',),
'kystklimaene': ('kystklima',),
'kystklimaer': ('kystklima',),
'kystklimaet': ('kystklima',),
'kystradiostasjon': ('kystradiostasjon',),
'kystradiostasjonen': ('kystradiostasjon',),
'kystradiostasjonene': ('kystradiostasjon',),
'kystradiostasjoner': ('kystradiostasjon',),
'kystskipper': ('kystskipper',),
'kystskippere': ('kystskipper',),
'kystskipperen': ('kystskipper',),
'kystskipperer': ('kystskipper',),
'kystskipperne': ('kystskipper',),
'kystskippersertifikat': ('kystskippersertifikat',),
'kystskippersertifikata': ('kystskippersertifikat',),
'kystskippersertifikatene': ('kystskippersertifikat',),
'kystskippersertifikater': ('kystskippersertifikat',),
'kystskippersertifikatet': ('kystskippersertifikat',),
'kystvakt': ('kystvakt',),
'kystvakta': ('kystvakt',),
'kystvakten': ('kystvakt',),
'kystvaktene': ('kystvakt',),
'kystvakter': ('kystvakt',),
'kyt': ('kyt',),
'kyta': ('kyt',),
'kytene': ('kyt',),
'kytet': ('kyt',),
'kåk': ('kåk',),
'kåken': ('kåk',),
'kåkene': ('kåk',),
'kåker': ('kåk',),
'kål': ('kål',),
'kålen': ('kål',),
'kålene': ('kål',),
'kåler': ('kål',),
'kålhoda': ('kålhode',),
'kålhode': ('kålhode',),
'kålhodene': ('kålhode',),
'kålhoder': ('kålhode',),
'kålhodet': ('kålhode',),
'kålmakk': ('kålmakk',),
'kålmakken': ('kålmakk',),
'kålmakkene': ('kålmakk',),
'kålmakker': ('kålmakk',),
'kålmark': ('kålmark',),
'kålmarken': ('kålmark',),
'kålmarkene': ('kålmark',),
'kålmarker': ('kålmark',),
'kålorm': ('kålorm',),
'kålormen': ('kålorm',),
'kålormene': ('kålorm',),
'kålormer': ('kålorm',),
'kålrabi': ('kålrabi',),
'kålrabien': ('kålrabi',),
'kålrabiene': ('kålrabi',),
'kålrabier': ('kålrabi',),
'kålrulett': ('kålrulett',),
'kålruletten': ('kålrulett',),
'kålrulettene': ('kålrulett',),
'kålruletter': ('kålrulett',),
'kålsommerfugl': ('kålsommerfugl',),
'kålsommerfuglen': ('kålsommerfugl',),
'kålsommerfuglene': ('kålsommerfugl',),
'kålsommerfugler': ('kålsommerfugl',),
'kålstuing': ('kålstuing',),
'kålstuinga': ('kålstuing',),
'kålstuingen': ('kålstuing',),
'kålstuingene': ('kålstuing',),
'kålstuinger': ('kålstuing',),
'kåpa': ('kåpe',),
'kåpe': ('kåpe',),
'kåpen': ('kåpe',),
'kåpene': ('kåpe',),
'kåper': ('kåpe',),
'kår': ('kår',),
'kåra': ('kår',),
'kårene': ('kår',),
'kåret': ('kår',),
'kårbygning': ('kårbygning',),
'kårbygninga': ('kårbygning',),
'kårbygningen': ('kårbygning',),
'kårbygningene': ('kårbygning',),
'kårbygninger': ('kårbygning',),
'kårde': ('kårde',),
'kården': ('kårde',),
'kårdene': ('kårde',),
'kårder': ('kårde',),
'kåre': ('kåre',),
'kåren': ('kåre',),
'kårene': ('kåre',),
'kårer': ('kåre',),
'kårfolk': ('kårfolk',),
'kårfolka': ('kårfolk',),
'kårfolkene': ('kårfolk',),
'kårfolket': ('kårfolk',),
'kåringssjå': ('kåringssjå',),
'kåringssjåa': ('kåringssjå',),
'kåringssjåene': ('kåringssjå',),
'kåringssjået': ('kåringssjå',),
'kåringsskua': ('kåringsskue',),
'kåringsskue': ('kåringsskue',),
'kåringsskuene': ('kåringsskue',),
'kåringsskuer': ('kåringsskue',),
'kåringsskuet': ('kåringsskue',),
'kårkall': ('kårkall',),
'kårkallen': ('kårkall',),
'kårkallene': ('kårkall',),
'kårkaller': ('kårkall',),
'kårkona': ('kårkone',),
'kårkone': ('kårkone',),
'kårkonen': ('kårkone',),
'kårkonene': ('kårkone',),
'kårkoner': ('kårkone',),
'kårmann': ('kårmann',),
'kårmannen': ('kårmann',),
'kårmenn': ('kårmann',),
'kårmennene': ('kårmann',),
'kårstova': ('kårstove',),
'kårstove': ('kårstove',),
'kårstoven': ('kårstove',),
'kårstovene': ('kårstove',),
'kårstover': ('kårstove',),
'kårstua': ('kårstue',),
'kårstue': ('kårstue',),
'kårstuen': ('kårstue',),
'kårstuene': ('kårstue',),
'kårstuer': ('kårstue',),
'kåseri': ('kåseri',),
'kåseria': ('kåseri',),
'kåseriene': ('kåseri',),
'kåserier': ('kåseri',),
'kåseriet': ('kåseri',),
'kåsør': ('kåsør',),
'kåsøren': ('kåsør',),
'kåsørene': ('kåsør',),
'kåsører': ('kåsør',),
'kåta': ('kåte',),
'kåte': ('kåte',),
'kåten': ('kåte',),
'kåtene': ('kåte',),
'kåter': ('kåte',),
'kåthet': ('kåthet',),
'kåtheta': ('kåthet',),
'kåtheten': ('kåthet',),
'kåthetene': ('kåthet',),
'kåtheter': ('kåthet',),
'kåting': ('kåting',),
'kåtingen': ('kåting',),
'kåtingene': ('kåting',),
'kåtinger': ('kåting',),
'kø': ('kø',),
'køen': ('kø',),
'køene': ('kø',),
'køer': ('kø',),
'københavner': ('københavner',),
'københavnere': ('københavner',),
'københavneren': ('københavner',),
'københavnerer': ('københavner',),
'københavnerne': ('københavner',),
'kødannelse': ('kødannelse',),
'kødannelsen': ('kødannelse',),
'kødannelsene': ('kødannelse',),
'kødannelser': ('kødannelse',),
'kødanning': ('kødanning',),
'kødanninga': ('kødanning',),
'kødanningen': ('kødanning',),
'kødanningene': ('kødanning',),
'kødanninger': ('kødanning',),
'kødd': ('kødd',),
'kødden': ('kødd',),
'køddene': ('kødd',),
'kødder': ('kødd',),
'køkjøring': ('køkjøring',),
'køkjøringa': ('køkjøring',),
'køkjøringen': ('køkjøring',),
'køkjøringene': ('køkjøring',),
'køkjøringer': ('køkjøring',),
'køkultur': ('køkultur',),
'køkulturen': ('køkultur',),
'køkulturene': ('køkultur',),
'køkulturer': ('køkultur',),
'kølapp': ('kølapp',),
'kølappen': ('kølapp',),
'kølappene': ('kølapp',),
'kølapper': ('kølapp',),
'kølla': ('kølle',),
'kølle': ('kølle',),
'køllen': ('kølle',),
'køllene': ('kølle',),
'køller': ('kølle',),
'kølnervann': ('kølnervann',),
'kølnervanna': ('kølnervann',),
'kølnervannene': ('kølnervann',),
'kølnervannet': ('kølnervann',),
'kølnervatn': ('kølnervatn',),
'kølnervatna': ('kølnervatn',),
'kølnervatnene': ('kølnervatn',),
'kølnervatnet': ('kølnervatn',),
'kølnvann': ('kølnvann',),
'kølnvanna': ('kølnvann',),
'kølnvannene': ('kølnvann',),
'kølnvannet': ('kølnvann',),
'kølnvatn': ('kølnvatn',),
'kølnvatna': ('kølnvatn',),
'kølnvatnene': ('kølnvatn',),
'kølnvatnet': ('kølnvatn',),
'køordner': ('køordner',),
'køordnere': ('køordner',),
'køordneren': ('køordner',),
'køordnerer': ('køordner',),
'køordnerne': ('køordner',),
'køpenickiade': ('køpenickiade',),
'køpenickiaden': ('køpenickiade',),
'køpenickiadene': ('køpenickiade',),
'køpenickiader': ('køpenickiade',),
'køy': ('køy',),
'køya': ('køy',),
'køyen': ('køy',),
'køyene': ('køy',),
'køyer': ('køy',),
'køya': ('køye',),
'køye': ('køye',),
'køyen': ('køye',),
'køyene': ('køye',),
'køyer': ('køye',),
'køyeseng': ('køyeseng',),
'køyesenga': ('køyeseng',),
'køyesengen': ('køyeseng',),
'køyesengene': ('køyeseng',),
'køyesenger': ('køyeseng',),
'køyestrekk': ('køyestrekk',),
'køyestrekka': ('køyestrekk',),
'køyestrekken': ('køyestrekk',),
'køyestrekkene': ('køyestrekk',),
'køyestrekker': ('køyestrekk',),
'køyestrekket': ('køyestrekk',),
'køystrekk': ('køystrekk',),
'køystrekka': ('køystrekk',),
'køystrekken': ('køystrekk',),
'køystrekkene': ('køystrekk',),
'køystrekker': ('køystrekk',),
'køystrekket': ('køystrekk',),
'l': ('l',),
'l\'en': ('l',),
'l-en': ('l',),
'l-ene': ('l',),
'l-er': ('l',),
'l\'hombre': ('l\'hombre',),
'la': ('la',),
'laen': ('la',),
'laene': ('la',),
'laer': ('la',),
'la dolce vita': ('la dolce vita',),
'la-skure-mentalitet': ('la-skure-mentalitet',),
'la-skure-mentaliteten': ('la-skure-mentalitet',),
'la-skure-mentalitetene': ('la-skure-mentalitet',),
'la-skure-mentaliteter': ('la-skure-mentalitet',),
'lab': ('lab',),
'laben': ('lab',),
'labene': ('lab',),
'laber': ('lab',),
'laban': ('laban',),
'labanen': ('laban',),
'labanene': ('laban',),
'labaner': ('laban',),
'labank': ('labank',),
'labanken': ('labank',),
'labankene': ('labank',),
'labanker': ('labank',),
'labb': ('labb',),
'labben': ('labb',),
'labbene': ('labb',),
'labber': ('labb',),
'labbelensk': ('labbelensk',),
'labbelensken': ('labbelensk',),
'labbelenskene': ('labbelensk',),
'labbelensker': ('labbelensk',),
'labeit': ('labeit',),
'labeita': ('labeit',),
'labeiten': ('labeit',),
'labeitene': ('labeit',),
'labeiter': ('labeit',),
'labial': ('labial',),
'labialen': ('labial',),
'labialene': ('labial',),
'labialer': ('labial',),
'labilitet': ('labilitet',),
'labiliteten': ('labilitet',),
'labilitetene': ('labilitet',),
'labiliteter': ('labilitet',),
'labiodental': ('labiodental',),
'labiodentalen': ('labiodental',),
'labiodentalene': ('labiodental',),
'labiodentaler': ('labiodental',),
'laborant': ('laborant',),
'laboranten': ('laborant',),
'laborantene': ('laborant',),
'laboranter': ('laborant',),
'laborasjon': ('laborasjon',),
'laborasjonen': ('laborasjon',),
'laborasjonene': ('laborasjon',),
'laborasjoner': ('laborasjon',),
'laboratoriearbeid': ('laboratoriearbeid',),
'laboratoriearbeida': ('laboratoriearbeid',),
'laboratoriearbeidene': ('laboratoriearbeid',),
'laboratoriearbeider': ('laboratoriearbeid',),
'laboratoriearbeidet': ('laboratoriearbeid',),
'laboratorieforsøk': ('laboratorieforsøk',),
'laboratorieforsøka': ('laboratorieforsøk',),
'laboratorieforsøkene': ('laboratorieforsøk',),
'laboratorieforsøket': ('laboratorieforsøk',),
'laboratorietekniker': ('laboratorietekniker',),
'laboratorieteknikere': ('laboratorietekniker',),
'laboratorieteknikeren': ('laboratorietekniker',),
'laboratorieteknikerer': ('laboratorietekniker',),
'laboratorieteknikerne': ('laboratorietekniker',),
'laboratorieutstyr': ('laboratorieutstyr',),
'laboratorieutstyra': ('laboratorieutstyr',),
'laboratorieutstyrene': ('laboratorieutstyr',),
'laboratorieutstyret': ('laboratorieutstyr',),
'laboratorieøvelse': ('laboratorieøvelse',),
'laboratorieøvelsen': ('laboratorieøvelse',),
'laboratorieøvelsene': ('laboratorieøvelse',),
'laboratorieøvelser': ('laboratorieøvelse',),
'laboratorieøving': ('laboratorieøving',),
'laboratorieøvinga': ('laboratorieøving',),
'laboratorieøvingen': ('laboratorieøving',),
'laboratorieøvingene': ('laboratorieøving',),
'laboratorieøvinger': ('laboratorieøving',),
'laboratoria': ('laboratorium',),
'laboratoriene': ('laboratorium',),
'laboratorier': ('laboratorium',),
'laboratoriet': ('laboratorium',),
'laboratorium': ('laboratorium',),
'labrador': ('labrador',),
'labradoren': ('labrador',),
'labradorene': ('labrador',),
'labradorer': ('labrador',),
'labrador retriever': ('labrador retriever',),
'labrador retrievere': ('labrador retriever',),
'labrador retrieveren': ('labrador retriever',),
'labrador retrieverer': ('labrador retriever',),
'labrador retrieverne': ('labrador retriever',),
'labyrint': ('labyrint',),
'labyrinten': ('labyrint',),
'labyrintene': ('labyrint',),
'labyrinter': ('labyrint',),
'lad': ('lad',),
'lada': ('lad',),
'ladene': ('lad',),
'ladet': ('lad',),
'lad': ('lad',),
'lada': ('lad',),
'ladene': ('lad',),
'ladet': ('lad',),
'ladd': ('ladd',),
'ladden': ('ladd',),
'laddene': ('ladd',),
'ladder': ('ladd',),
'ladd': ('ladd',),
'ladden': ('ladd',),
'laddene': ('ladd',),
'ladder': ('ladd',),
'lada': ('lade',),
'lade': ('lade',),
'laden': ('lade',),
'ladene': ('lade',),
'lader': ('lade',),
'ladet': ('lade',),
'ladegard': ('ladegard',),
'ladegarden': ('ladegard',),
'ladegardene': ('ladegard',),
'ladegarder': ('ladegard',),
'ladegård': ('ladegård',),
'ladegården': ('ladegård',),
'ladegårdene': ('ladegård',),
'ladegårder': ('ladegård',),
'lader': ('lader',),
'ladested': ('ladested',),
'ladestedene': ('ladested',),
'ladesteder': ('ladested',),
'ladestedet': ('ladested',),
'ladning': ('ladning',),
'ladninga': ('ladning',),
'ladningen': ('ladning',),
'ladningene': ('ladning',),
'ladninger': ('ladning',),
'lady': ('lady',),
'ladyen': ('lady',),
'ladyene': ('lady',),
'ladyer': ('lady',),
'laft': ('laft',),
'lafta': ('laft',),
'laftene': ('laft',),
'laftet': ('laft',),
'laftehus': ('laftehus',),
'laftehusa': ('laftehus',),
'laftehusene': ('laftehus',),
'laftehuset': ('laftehus',),
'laftevegg': ('laftevegg',),
'lafteveggen': ('laftevegg',),
'lafteveggene': ('laftevegg',),
'laftevegger': ('laftevegg',),
'lafteverk': ('lafteverk',),
'lafteverka': ('lafteverk',),
'lafteverkene': ('lafteverk',),
'lafteverker': ('lafteverk',),
'lafteverket': ('lafteverk',),
'lag': ('lag',),
'laga': ('lag',),
'lagene': ('lag',),
'laget': ('lag',),
'lagarbeid': ('lagarbeid',),
'lagarbeida': ('lagarbeid',),
'lagarbeidene': ('lagarbeid',),
'lagarbeider': ('lagarbeid',),
'lagarbeidet': ('lagarbeid',),
'lagasild': ('lagasild',),
'lagasilda': ('lagasild',),
'lagasilden': ('lagasild',),
'lagasildene': ('lagasild',),
'lagasilder': ('lagasild',),
'lagdeling': ('lagdeling',),
'lagdelinga': ('lagdeling',),
'lagdelingen': ('lagdeling',),
'lagdelingene': ('lagdeling',),
'lagdelinger': ('lagdeling',),
'lagdommer': ('lagdommer',),
'lagdommere': ('lagdommer',),
'lagdommeren': ('lagdommer',),
'lagdommerer': ('lagdommer',),
'lagdommerne': ('lagdommer',),
'lagdømma': ('lagdømme',),
'lagdømme': ('lagdømme',),
'lagdømmene': ('lagdømme',),
'lagdømmer': ('lagdømme',),
'lagdømmet': ('lagdømme',),
'lager': ('lager',),
'lageret': ('lager',),
'lagra': ('lager',),
'lagre': ('lager',),
'lagrene': ('lager',),
'lagerarbeider': ('lagerarbeider',),
'lagerarbeidere': ('lagerarbeider',),
'lagerarbeideren': ('lagerarbeider',),
'lagerarbeiderer': ('lagerarbeider',),
'lagerarbeiderne': ('lagerarbeider',),
'lagerbeholdning': ('lagerbeholdning',),
'lagerbeholdninga': ('lagerbeholdning',),
'lagerbeholdningen': ('lagerbeholdning',),
'lagerbeholdningene': ('lagerbeholdning',),
'lagerbeholdninger': ('lagerbeholdning',),
'lagerekspeditør': ('lagerekspeditør',),
'lagerekspeditøren': ('lagerekspeditør',),
'lagerekspeditørene': ('lagerekspeditør',),
'lagerekspeditører': ('lagerekspeditør',),
'lagerenhet': ('lagerenhet',),
'lagerenheta': ('lagerenhet',),
'lagerenheten': ('lagerenhet',),
'lagerenhetene': ('lagerenhet',),
'lagerenheter': ('lagerenhet',),
'lagerfrakk': ('lagerfrakk',),
'lagerfrakken': ('lagerfrakk',),
'lagerfrakkene': ('lagerfrakk',),
'lagerfrakker': ('lagerfrakk',),
'lagerkapasitet': ('lagerkapasitet',),
'lagerkapasiteten': ('lagerkapasitet',),
'lagerkapasitetene': ('lagerkapasitet',),
'lagerkapasiteter': ('lagerkapasitet',),
'lagerpris': ('lagerpris',),
'lagerprisen': ('lagerpris',),
'lagerprisene': ('lagerpris',),
'lagerpriser': ('lagerpris',),
'lagerressurs': ('lagerressurs',),
'lagerressursen': ('lagerressurs',),
'lagerressursene': ('lagerressurs',),
'lagerressurser': ('lagerressurs',),
'lagerresurs': ('lagerresurs',),
'lagerresursen': ('lagerresurs',),
'lagerresursene': ('lagerresurs',),
'lagerresurser': ('lagerresurs',),
'lagersjef': ('lagersjef',),
'lagersjefen': ('lagersjef',),
'lagersjefene': ('lagersjef',),
'lagersjefer': ('lagersjef',),
'lagervara': ('lagervare',),
'lagervare': ('lagervare',),
'lagervaren': ('lagervare',),
'lagervarene': ('lagervare',),
'lagervarer': ('lagervare',),
'lagfører': ('lagfører',),
'lagførere': ('lagfører',),
'lagføreren': ('lagfører',),
'lagførerer': ('lagfører',),
'lagførerne': ('lagfører',),
'lagg': ('lagg',),
'laggen': ('lagg',),
'laggene': ('lagg',),
'lagger': ('lagg',),
'laggband': ('laggband',),
'laggbanda': ('laggband',),
'laggbandene': ('laggband',),
'laggbandet': ('laggband',),
'laggbånd': ('laggbånd',),
'laggbånda': ('laggbånd',),
'laggbåndene': ('laggbånd',),
'laggbåndet': ('laggbånd',),
'laggeband': ('laggeband',),
'laggebanda': ('laggeband',),
'laggebandene': ('laggeband',),
'laggebandet': ('laggeband',),
'laggebånd': ('laggebånd',),
'laggebånda': ('laggebånd',),
'laggebåndene': ('laggebånd',),
'laggebåndet': ('laggebånd',),
'lagger': ('lagger',),
'laggere': ('lagger',),
'laggeren': ('lagger',),
'laggerer': ('lagger',),
'laggerne': ('lagger',),
'lagidrett': ('lagidrett',),
'lagidretten': ('lagidrett',),
'lagidrettene': ('lagidrett',),
'lagidretter': ('lagidrett',),
'lagkaka': ('lagkake',),
'lagkake': ('lagkake',),
'lagkaken': ('lagkake',),
'lagkakene': ('lagkake',),
'lagkaker': ('lagkake',),
'lagkamerat': ('lagkamerat',),
'lagkameraten': ('lagkamerat',),
'lagkameratene': ('lagkamerat',),
'lagkamerater': ('lagkamerat',),
'lagkaptein': ('lagkaptein',),
'lagkapteinen': ('lagkaptein',),
'lagkapteinene': ('lagkaptein',),
'lagkapteiner': ('lagkaptein',),
'lagmann': ('lagmann',),
'lagmannen': ('lagmann',),
'lagmenn': ('lagmann',),
'lagmennene': ('lagmann',),
'lagmannsrett': ('lagmannsrett',),
'lagmannsretten': ('lagmannsrett',),
'lagmannsrettene': ('lagmannsrett',),
'lagmannsretter': ('lagmannsrett',),
'lagnad': ('lagnad',),
'lagnaden': ('lagnad',),
'lagnadene': ('lagnad',),
'lagnader': ('lagnad',),
'lagrett': ('lagrett',),
'lagretten': ('lagrett',),
'lagrettene': ('lagrett',),
'lagretter': ('lagrett',),
'lagrette': ('lagrette',),
'lagretten': ('lagrette',),
'lagrettene': ('lagrette',),
'lagretter': ('lagrette',),
'lagrettemann': ('lagrettemann',),
'lagrettemannen': ('lagrettemann',),
'lagrettemenn': ('lagrettemann',),
'lagrettemennene': ('lagrettemann',),
'lagring': ('lagring',),
'lagringa': ('lagring',),
'lagringen': ('lagring',),
'lagringene': ('lagring',),
'lagringer': ('lagring',),
'lagringstap': ('lagringstap',),
'lagringstapa': ('lagringstap',),
'lagringstapene': ('lagringstap',),
'lagringstapet': ('lagringstap',),
'lagsarbeid': ('lagsarbeid',),
'lagsarbeida': ('lagsarbeid',),
'lagsarbeidene': ('lagsarbeid',),
'lagsarbeider': ('lagsarbeid',),
'lagsarbeidet': ('lagsarbeid',),
'lagsdrift': ('lagsdrift',),
'lagsdrifta': ('lagsdrift',),
'lagsdriften': ('lagsdrift',),
'lagsdriftene': ('lagsdrift',),
'lagsdrifter': ('lagsdrift',),
'lagsformann': ('lagsformann',),
'lagsformannen': ('lagsformann',),
'lagsformenn': ('lagsformann',),
'lagsformennene': ('lagsformann',),
'lagsmøta': ('lagsmøte',),
'lagsmøte': ('lagsmøte',),
'lagsmøtene': ('lagsmøte',),
'lagsmøter': ('lagsmøte',),
'lagsmøtet': ('lagsmøte',),
'lagsogn': ('lagsogn',),
'lagsogna': ('lagsogn',),
'lagsognene': ('lagsogn',),
'lagsognet': ('lagsogn',),
'lagtemporitt': ('lagtemporitt',),
'lagtemporitta': ('lagtemporitt',),
'lagtemporittene': ('lagtemporitt',),
'lagtemporittet': ('lagtemporitt',),
'lagting': ('lagting',),
'lagtinga': ('lagting',),
'lagtingene': ('lagting',),
'lagtinget': ('lagting',),
'lagtingspresident': ('lagtingspresident',),
'lagtingspresidenten': ('lagtingspresident',),
'lagtingspresidentene': ('lagtingspresident',),
'lagtingspresidenter': ('lagtingspresident',),
'lagune': ('lagune',),
'lagunen': ('lagune',),
'lagunene': ('lagune',),
'laguner': ('lagune',),
'laissez faire': ('laissez faire',),
'laissez faire-politikk': ('laissez faire-politikk',),
'laissez faire-politikken': ('laissez faire-politikk',),
'laissez faire-politikkene': ('laissez faire-politikk',),
'laissez faire-politikker': ('laissez faire-politikk',),
'lake': ('lake',),
'laken': ('lake',),
'lakene': ('lake',),
'laker': ('lake',),
'lake': ('lake',),
'laken': ('lake',),
'lakene': ('lake',),
'laker': ('lake',),
'lakei': ('lakei',),
'lakeien': ('lakei',),
'lakeiene': ('lakei',),
'lakeier': ('lakei',),
'laken': ('laken',),
'lakena': ('laken',),
'lakenene': ('laken',),
'lakener': ('laken',),
'lakenet': ('laken',),
'lakenlerret': ('lakenlerret',),
'lakenlerreta': ('lakenlerret',),
'lakenlerretene': ('lakenlerret',),
'lakenlerreter': ('lakenlerret',),
'lakenlerretet': ('lakenlerret',),
'lakenpose': ('lakenpose',),
'lakenposen': ('lakenpose',),
'lakenposene': ('lakenpose',),
'lakenposer': ('lakenpose',),
'lakk': ('lakk',),
'lakken': ('lakk',),
'lakkene': ('lakk',),
'lakker': ('lakk',),
'lakkerer': ('lakkerer',),
'lakkerere': ('lakkerer',),
'lakkereren': ('lakkerer',),
'lakkererer': ('lakkerer',),
'lakkererne': ('lakkerer',),
'lakkfarge': ('lakkfarge',),
'lakkfargen': ('lakkfarge',),
'lakkfargene': ('lakkfarge',),
'lakkfarger': ('lakkfarge',),
'lakklær': ('lakklær',),
'lakklærene': ('lakklær',),
'lakklæret': ('lakklær',),
'lakkmaling': ('lakkmaling',),
'lakkmalinga': ('lakkmaling',),
'lakkmalingen': ('lakkmaling',),
'lakkmalingene': ('lakkmaling',),
'lakkmalinger': ('lakkmaling',),
'lakkpensel': ('lakkpensel',),
'lakkpenselen': ('lakkpensel',),
'lakkpenslene': ('lakkpensel',),
'lakkpensler': ('lakkpensel',),
'lakksegl': ('lakksegl',),
'lakksegla': ('lakksegl',),
'lakkseglene': ('lakksegl',),
'lakkseglet': ('lakksegl',),
'lakmus': ('lakmus',),
'lakmusen': ('lakmus',),
'lakmusene': ('lakmus',),
'lakmuser': ('lakmus',),
'lakmuspapir': ('lakmuspapir',),
'lakmuspapira': ('lakmuspapir',),
'lakmuspapirene': ('lakmuspapir',),
'lakmuspapirer': ('lakmuspapir',),
'lakmuspapiret': ('lakmuspapir',),
'lakoner': ('lakoner',),
'lakonere': ('lakoner',),
'lakoneren': ('lakoner',),
'lakonerer': ('lakoner',),
'lakonerne': ('lakoner',),
'lakonier': ('lakonier',),
'lakoniere': ('lakonier',),
'lakonieren': ('lakonier',),
'lakonierer': ('lakonier',),
'lakonierne': ('lakonier',),
'lakonisme': ('lakonisme',),
'lakonismen': ('lakonisme',),
'lakonismene': ('lakonisme',),
'lakonismer': ('lakonisme',),
'lakris': ('lakris',),
'lakrisen': ('lakris',),
'lakrisene': ('lakris',),
'lakriser': ('lakris',),
'lakrisbåt': ('lakrisbåt',),
'lakrisbåten': ('lakrisbåt',),
'lakrisbåtene': ('lakrisbåt',),
'lakrisbåter': ('lakrisbåt',),
'lakrisplanta': ('lakrisplante',),
'lakrisplante': ('lakrisplante',),
'lakrisplanten': ('lakrisplante',),
'lakrisplantene': ('lakrisplante',),
'lakrisplanter': ('lakrisplante',),
'lakrisrot': ('lakrisrot',),
'lakrisrota': ('lakrisrot',),
'lakrisroten': ('lakrisrot',),
'lakrisrøttene': ('lakrisrot',),
'lakrisrøtter': ('lakrisrot',),
'lakrisstang': ('lakrisstang',),
'lakrisstanga': ('lakrisstang',),
'lakrisstangen': ('lakrisstang',),
'lakrisstengene': ('lakrisstang',),
'lakrisstenger': ('lakrisstang',),
'laks': ('laks',),
'laksen': ('laks',),
'laksene': ('laks',),
'lakser': ('laks',),
'laksand': ('laksand',),
'laksanda': ('laksand',),
'laksanden': ('laksand',),
'laksendene': ('laksand',),
'laksender': ('laksand',),
'laksativ': ('laksativ',),
'laksativa': ('laksativ',),
'laksativene': ('laksativ',),
'laksativer': ('laksativ',),
'laksativet': ('laksativ',),
'lakseelv': ('lakseelv',),
'lakseelva': ('lakseelv',),
'lakseelven': ('lakseelv',),
'lakseelvene': ('lakseelv',),
'lakseelver': ('lakseelv',),
'laksefisk': ('laksefisk',),
'laksefisken': ('laksefisk',),
'laksefiskene': ('laksefisk',),
'laksefisker': ('laksefisk',),
'laksefiska': ('laksefiske',),
'laksefiske': ('laksefiske',),
'laksefiskene': ('laksefiske',),
'laksefisker': ('laksefiske',),
'laksefisket': ('laksefiske',),
'laksefisker': ('laksefisker',),
'laksefiskere': ('laksefisker',),
'laksefiskeren': ('laksefisker',),
'laksefiskerer': ('laksefisker',),
'laksefiskerne': ('laksefisker',),
'laksegarn': ('laksegarn',),
'laksegarna': ('laksegarn',),
'laksegarnene': ('laksegarn',),
'laksegarnet': ('laksegarn',),
'lakserolja': ('lakserolje',),
'lakserolje': ('lakserolje',),
'lakseroljen': ('lakserolje',),
'lakseroljene': ('lakserolje',),
'lakseroljer': ('lakserolje',),
'laksesild': ('laksesild',),
'laksesilda': ('laksesild',),
'laksesilden': ('laksesild',),
'laksesildene': ('laksesild',),
'laksesilder': ('laksesild',),
'laksestørja': ('laksestørje',),
'laksestørje': ('laksestørje',),
'laksestørjen': ('laksestørje',),
'laksestørjene': ('laksestørje',),
'laksestørjer': ('laksestørje',),
'laksetrapp': ('laksetrapp',),
'laksetrappa': ('laksetrapp',),
'laksetrappen': ('laksetrapp',),
'laksetrappene': ('laksetrapp',),
'laksetrapper': ('laksetrapp',),
'lakseyngel': ('lakseyngel',),
'lakseyngelen': ('lakseyngel',),
'lakseynglene': ('lakseyngel',),
'laksyngel': ('laksyngel',),
'laksyngelen': ('laksyngel',),
'laksynglene': ('laksyngel',),
'laktasjon': ('laktasjon',),
'laktasjonen': ('laktasjon',),
'laktasjonene': ('laktasjon',),
'laktasjoner': ('laktasjon',),
'laktasjonsperiode': ('laktasjonsperiode',),
'laktasjonsperioden': ('laktasjonsperiode',),
'laktasjonsperiodene': ('laktasjonsperiode',),
'laktasjonsperioder': ('laktasjonsperiode',),
'laktose': ('laktose',),
'laktosen': ('laktose',),
'laktosene': ('laktose',),
'laktoser': ('laktose',),
'laktovegetarian': ('laktovegetarian',),
'laktovegetarianen': ('laktovegetarian',),
'laktovegetarianene': ('laktovegetarian',),
'laktovegetarianer': ('laktovegetarian',),
'laktovegetarianer': ('laktovegetarianer',),
'laktovegetarianere': ('laktovegetarianer',),
'laktovegetarianeren': ('laktovegetarianer',),
'laktovegetarianerer': ('laktovegetarianer',),
'laktovegetarianerne': ('laktovegetarianer',),
'lakune': ('lakune',),
'lakunen': ('lakune',),
'lakunene': ('lakune',),
'lakuner': ('lakune',),
'lam': ('lam',),
'lamma': ('lam',),
'lammene': ('lam',),
'lammet': ('lam',),
'lameen': ('lamé',),
'lameene': ('lamé',),
'lameer': ('lamé',),
'lamé': ('lamé',),
'laméen': ('lamé',),
'laméene': ('lamé',),
'laméer': ('lamé',),
'lama': ('lama',),
'lamaen': ('lama',),
'lamaene': ('lama',),
'lamaer': ('lama',),
'lama': ('lama',),
'lamaen': ('lama',),
'lamaene': ('lama',),
'lamaer': ('lama',),
'lamaisme': ('lamaisme',),
'lamaismen': ('lamaisme',),
'lamaismene': ('lamaisme',),
'lamaismer': ('lamaisme',),
'lamell': ('lamell',),
'lamellen': ('lamell',),
'lamellene': ('lamell',),
'lameller': ('lamell',),
'lamellbebyggelse': ('lamellbebyggelse',),
'lamellbebyggelsen': ('lamellbebyggelse',),
'lamellbebyggelsene': ('lamellbebyggelse',),
'lamellbebyggelser': ('lamellbebyggelse',),
'lamellhus': ('lamellhus',),
'lamellhusa': ('lamellhus',),
'lamellhusene': ('lamellhus',),
'lamellhuset': ('lamellhus',),
'lamellkobling': ('lamellkobling',),
'lamellkoblinga': ('lamellkobling',),
'lamellkoblingen': ('lamellkobling',),
'lamellkoblingene': ('lamellkobling',),
'lamellkoblinger': ('lamellkobling',),
'lamellkopling': ('lamellkopling',),
'lamellkoplinga': ('lamellkopling',),
'lamellkoplingen': ('lamellkopling',),
'lamellkoplingene': ('lamellkopling',),
'lamellkoplinger': ('lamellkopling',),
'laminat': ('laminat',),
'laminata': ('laminat',),
'laminatene': ('laminat',),
'laminater': ('laminat',),
'laminatet': ('laminat',),
'lammekotelett': ('lammekotelett',),
'lammekoteletten': ('lammekotelett',),
'lammekotelettene': ('lammekotelett',),
'lammekoteletter': ('lammekotelett',),
'lammelse': ('lammelse',),
'lammelsen': ('lammelse',),
'lammelsene': ('lammelse',),
'lammelser': ('lammelse',),
'lammesadel': ('lammesadel',),
'lammesadelen': ('lammesadel',),
'lammesadlene': ('lammesadel',),
'lammesadler': ('lammesadel',),
'lammesal': ('lammesal',),
'lammesalen': ('lammesal',),
'lammesalene': ('lammesal',),
'lammesaler': ('lammesal',),
'lammesteik': ('lammesteik',),
'lammesteika': ('lammesteik',),
'lammesteiken': ('lammesteik',),
'lammesteikene': ('lammesteik',),
'lammesteiker': ('lammesteik',),
'lammestek': ('lammestek',),
'lammesteka': ('lammestek',),
'lammesteken': ('lammestek',),
'lammestekene': ('lammestek',),
'lammesteker': ('lammestek',),
'lammetid': ('lammetid',),
'lammetida': ('lammetid',),
'lammetiden': ('lammetid',),
'lammetidene': ('lammetid',),
'lammetider': ('lammetid',),
'lammeull': ('lammeull',),
'lammeulla': ('lammeull',),
'lammeullen': ('lammeull',),
'lammeullene': ('lammeull',),
'lammeuller': ('lammeull',),
'lampa': ('lampe',),
'lampe': ('lampe',),
'lampen': ('lampe',),
'lampene': ('lampe',),
'lamper': ('lampe',),
'lampefeber': ('lampefeber',),
'lampefebere': ('lampefeber',),
'lampefeberen': ('lampefeber',),
'lampefeberer': ('lampefeber',),
'lampefeberne': ('lampefeber',),
'lampefebre': ('lampefeber',),
'lampefebrene': ('lampefeber',),
'lampefebrer': ('lampefeber',),
'lampeglas': ('lampeglas',),
'lampeglasa': ('lampeglas',),
'lampeglasene': ('lampeglas',),
'lampeglaset': ('lampeglas',),
'lampeglass': ('lampeglass',),
'lampeglassa': ('lampeglass',),
'lampeglassene': ('lampeglass',),
'lampeglasset': ('lampeglass',),
'lampelys': ('lampelys',),
'lampelysa': ('lampelys',),
'lampelysene': ('lampelys',),
'lampelyset': ('lampelys',),
'lampeolja': ('lampeolje',),
'lampeolje': ('lampeolje',),
'lampeoljen': ('lampeolje',),
'lampeoljene': ('lampeolje',),
'lampeoljer': ('lampeolje',),
'lampeskjerm': ('lampeskjerm',),
'lampeskjermen': ('lampeskjerm',),
'lampeskjermene': ('lampeskjerm',),
'lampeskjermer': ('lampeskjerm',),
'lampett': ('lampett',),
'lampetten': ('lampett',),
'lampettene': ('lampett',),
'lampetter': ('lampett',),
'lamunge': ('lamunge',),
'lamungen': ('lamunge',),
'lamungene': ('lamunge',),
'lamunger': ('lamunge',),
'landadel': ('landadel',),
'landadelen': ('landadel',),
'landadlene': ('landadel',),
'landadler': ('landadel',),
'landauer': ('landauer',),
'landauere': ('landauer',),
'landaueren': ('landauer',),
'landauerer': ('landauer',),
'landauerne': ('landauer',),
'landboer': ('landboer',),
'landboere': ('landboer',),
'landboeren': ('landboer',),
'landboerer': ('landboer',),
'landboerne': ('landboer',),
'landbruk': ('landbruk',),
'landbruka': ('landbruk',),
'landbrukene': ('landbruk',),
'landbruket': ('landbruk',),
'landbruksdepartement': ('landbruksdepartement',),
'landbruksdepartementa': ('landbruksdepartement',),
'landbruksdepartementene': ('landbruksdepartement',),
'landbruksdepartementer': ('landbruksdepartement',),
'landbruksdepartementet': ('landbruksdepartement',),
'landbruksfly': ('landbruksfly',),
'landbruksflya': ('landbruksfly',),
'landbruksflyene': ('landbruksfly',),
'landbruksflyet': ('landbruksfly',),
'landbrukshøgskole': ('landbrukshøgskole',),
'landbrukshøgskolen': ('landbrukshøgskole',),
'landbrukshøgskolene': ('landbrukshøgskole',),
'landbrukshøgskoler': ('landbrukshøgskole',),
'landbrukshøyskole': ('landbrukshøyskole',),
'landbrukshøyskolen': ('landbrukshøyskole',),
'landbrukshøyskolene': ('landbrukshøyskole',),
'landbrukshøyskoler': ('landbrukshøyskole',),
'landbrukskandidat': ('landbrukskandidat',),
'landbrukskandidaten': ('landbrukskandidat',),
'landbrukskandidatene': ('landbrukskandidat',),
'landbrukskandidater': ('landbrukskandidat',),
'landbrukslag': ('landbrukslag',),
'landbrukslaga': ('landbrukslag',),
'landbrukslagene': ('landbrukslag',),
'landbrukslaget': ('landbrukslag',),
'landbruksmaskin': ('landbruksmaskin',),
'landbruksmaskina': ('landbruksmaskin',),
'landbruksmaskinen': ('landbruksmaskin',),
'landbruksmaskinene': ('landbruksmaskin',),
'landbruksmaskiner': ('landbruksmaskin',),
'landbruksminister': ('landbruksminister',),
'landbruksministere': ('landbruksminister',),
'landbruksministeren': ('landbruksminister',),
'landbruksministerer': ('landbruksminister',),
'landbruksministerne': ('landbruksminister',),
'landbruksministre': ('landbruksminister',),
'landbruksministrene': ('landbruksminister',),
'landbruksministrer': ('landbruksminister',),
'landbruksselskap': ('landbruksselskap',),
'landbruksselskapa': ('landbruksselskap',),
'landbruksselskapene': ('landbruksselskap',),
'landbruksselskaper': ('landbruksselskap',),
'landbruksselskapet': ('landbruksselskap',),
'landbruksskole': ('landbruksskole',),
'landbruksskolen': ('landbruksskole',),
'landbruksskolene': ('landbruksskole',),
'landbruksskoler': ('landbruksskole',),
'landbruksvikar': ('landbruksvikar',),
'landbruksvikaren': ('landbruksvikar',),
'landbruksvikarene': ('landbruksvikar',),
'landbruksvikarer': ('landbruksvikar',),
'landbruksvitenskap': ('landbruksvitenskap',),
'landbruksvitenskapen': ('landbruksvitenskap',),
'landbruksvitenskapene': ('landbruksvitenskap',),
'landbruksvitenskaper': ('landbruksvitenskap',),
'landbruksvitskap': ('landbruksvitskap',),
'landbruksvitskapen': ('landbruksvitskap',),
'landbruksvitskapene': ('landbruksvitskap',),
'landbruksvitskaper': ('landbruksvitskap',),
'landbuer': ('landbuer',),
'landbuere': ('landbuer',),
'landbueren': ('landbuer',),
'landbuerer': ('landbuer',),
'landbuerne': ('landbuer',),
'landdag': ('landdag',),
'landdagen': ('landdag',),
'landdagene': ('landdag',),
'landdager': ('landdag',),
'landdistrikt': ('landdistrikt',),
'landdistrikta': ('landdistrikt',),
'landdistriktene': ('landdistrikt',),
'landdistrikter': ('landdistrikt',),
'landdistriktet': ('landdistrikt',),
'landdyr': ('landdyr',),
'landdyra': ('landdyr',),
'landdyrene': ('landdyr',),
'landdyret': ('landdyr',),
'landegrensa': ('landegrense',),
'landegrense': ('landegrense',),
'landegrensen': ('landegrense',),
'landegrensene': ('landegrense',),
'landegrenser': ('landegrense',),
'landeiendom': ('landeiendom',),
'landeiendommen': ('landeiendom',),
'landeiendommene': ('landeiendom',),
'landeiendommer': ('landeiendom',),
'landemerka': ('landemerke',),
'landemerke': ('landemerke',),
'landemerkene': ('landemerke',),
'landemerker': ('landemerke',),
'landemerket': ('landemerke',),
'landeplaga': ('landeplage',),
'landeplage': ('landeplage',),
'landeplagen': ('landeplage',),
'landeplagene': ('landeplage',),
'landeplager': ('landeplage',),
'landesorg': ('landesorg',),
'landesorga': ('landesorg',),
'landesorgen': ('landesorg',),
'landesorgene': ('landesorg',),
'landesorger': ('landesorg',),
'landeveg': ('landeveg',),
'landevegen': ('landeveg',),
'landevegene': ('landeveg',),
'landeveger': ('landeveg',),
'landevegsløp': ('landevegsløp',),
'landevegsløpa': ('landevegsløp',),
'landevegsløpene': ('landevegsløp',),
'landevegsløpet': ('landevegsløp',),
'landevegsritt': ('landevegsritt',),
'landevegsritta': ('landevegsritt',),
'landevegsrittene': ('landevegsritt',),
'landevegsrittet': ('landevegsritt',),
'landevegsrøver': ('landevegsrøver',),
'landevegsrøvere': ('landevegsrøver',),
'landevegsrøveren': ('landevegsrøver',),
'landevegsrøverer': ('landevegsrøver',),
'landevegsrøverne': ('landevegsrøver',),
'landevegstraver': ('landevegstraver',),
'landevegstravere': ('landevegstraver',),
'landevegstraveren': ('landevegstraver',),
'landevegstraverer': ('landevegstraver',),
'landevegstraverne': ('landevegstraver',),
'landevei': ('landevei',),
'landeveien': ('landevei',),
'landeveiene': ('landevei',),
'landeveier': ('landevei',),
'landeveisløp': ('landeveisløp',),
'landeveisløpa': ('landeveisløp',),
'landeveisløpene': ('landeveisløp',),
'landeveisløpet': ('landeveisløp',),
'landeveisritt': ('landeveisritt',),
'landeveisritta': ('landeveisritt',),
'landeveisrittene': ('landeveisritt',),
'landeveisrittet': ('landeveisritt',),
'landeveisrøver': ('landeveisrøver',),
'landeveisrøvere': ('landeveisrøver',),
'landeveisrøveren': ('landeveisrøver',),
'landeveisrøverer': ('landeveisrøver',),
'landeveisrøverne': ('landeveisrøver',),
'landeveistraver': ('landeveistraver',),
'landeveistravere': ('landeveistraver',),
'landeveistraveren': ('landeveistraver',),
'landeveistraverer': ('landeveistraver',),
'landeveistraverne': ('landeveistraver',),
'landevinning': ('landevinning',),
'landevinninga': ('landevinning',),
'landevinningen': ('landevinning',),
'landevinningene': ('landevinning',),
'landevinninger': ('landevinning',),
'landflyktighet': ('landflyktighet',),
'landflyktigheta': ('landflyktighet',),
'landflyktigheten': ('landflyktighet',),
'landflyktighetene': ('landflyktighet',),
'landflyktigheter': ('landflyktighet',),
'landgang': ('landgang',),
'landgangen': ('landgang',),
'landgangene': ('landgang',),
'landganger': ('landgang',),
'landgangsbro': ('landgangsbro',),
'landgangsbroa': ('landgangsbro',),
'landgangsbroen': ('landgangsbro',),
'landgangsbroene': ('landgangsbro',),
'landgangsbroer': ('landgangsbro',),
'landgangsbru': ('landgangsbru',),
'landgangsbrua': ('landgangsbru',),
'landgangsbruen': ('landgangsbru',),
'landgangsbruene': ('landgangsbru',),
'landgangsbruer': ('landgangsbru',),
'landgangsfartøy': ('landgangsfartøy',),
'landgangsfartøya': ('landgangsfartøy',),
'landgangsfartøyene': ('landgangsfartøy',),
'landgangsfartøyer': ('landgangsfartøy',),
'landgangsfartøyet': ('landgangsfartøy',),
'landgul': ('landgul',),
'landgula': ('landgul',),
'landgulen': ('landgul',),
'landgulene': ('landgul',),
'landguler': ('landgul',),
'landgula': ('landgule',),
'landgule': ('landgule',),
'landgulen': ('landgule',),
'landgulene': ('landgule',),
'landguler': ('landgule',),
'landhandel': ('landhandel',),
'landhandelen': ('landhandel',),
'landhandlene': ('landhandel',),
'landhandler': ('landhandel',),
'landhandler': ('landhandler',),
'landhandlere': ('landhandler',),
'landhandleren': ('landhandler',),
'landhandlerer': ('landhandler',),
'landhandlerne': ('landhandler',),
'landhockey': ('landhockey',),
'landhockeyen': ('landhockey',),
'landhockeyene': ('landhockey',),
'landhockeyer': ('landhockey',),
'landing': ('landing',),
'landinga': ('landing',),
'landingen': ('landing',),
'landingene': ('landing',),
'landinger': ('landing',),
'landingshjul': ('landingshjul',),
'landingshjula': ('landingshjul',),
'landingshjulene': ('landingshjul',),
'landingshjulet': ('landingshjul',),
'landingsplass': ('landingsplass',),
'landingsplassen': ('landingsplass',),
'landingsplassene': ('landingsplass',),
'landingsplasser': ('landingsplass',),
'landingssted': ('landingssted',),
'landingsstedene': ('landingssted',),
'landingssteder': ('landingssted',),
'landingsstedet': ('landingssted',),
'landingsstripa': ('landingsstripe',),
'landingsstripe': ('landingsstripe',),
'landingsstripen': ('landingsstripe',),
'landingsstripene': ('landingsstripe',),
'landingsstriper': ('landingsstripe',),
'landjord': ('landjord',),
'landjorda': ('landjord',),
'landjorden': ('landjord',),
'landjordene': ('landjord',),
'landjorder': ('landjord',),
'landkjenning': ('landkjenning',),
'landkjenninga': ('landkjenning',),
'landkjenningen': ('landkjenning',),
'landkjenningene': ('landkjenning',),
'landkjenninger': ('landkjenning',),
'landkommune': ('landkommune',),
'landkommunen': ('landkommune',),
'landkommunene': ('landkommune',),
'landkommuner': ('landkommune',),
'landkrabba': ('landkrabbe',),
'landkrabbe': ('landkrabbe',),
'landkrabben': ('landkrabbe',),
'landkrabbene': ('landkrabbe',),
'landkrabber': ('landkrabbe',),
'landkum': ('landkum',),
'landkummen': ('landkum',),
'landkummene': ('landkum',),
'landkummer': ('landkum',),
'landligga': ('landligge',),
'landligge': ('landligge',),
'landliggene': ('landligge',),
'landligger': ('landligge',),
'landligget': ('landligge',),
'landlov': ('landlov',),
'landloven': ('landlov',),
'landlovene': ('landlov',),
'landlover': ('landlov',),
'landmerka': ('landmerke',),
'landmerke': ('landmerke',),
'landmerkene': ('landmerke',),
'landmerker': ('landmerke',),
'landmerket': ('landmerke',),
'landmina': ('landmine',),
'landmine': ('landmine',),
'landminen': ('landmine',),
'landminene': ('landmine',),
'landminer': ('landmine',),
'landmåler': ('landmåler',),
'landmålere': ('landmåler',),
'landmåleren': ('landmåler',),
'landmålerer': ('landmåler',),
'landmålerne': ('landmåler',),
'landmåling': ('landmåling',),
'landmålinga': ('landmåling',),
'landmålingen': ('landmåling',),
'landmålingene': ('landmåling',),
'landmålinger': ('landmåling',),
'landnåm': ('landnåm',),
'landnåma': ('landnåm',),
'landnåmene': ('landnåm',),
'landnåmet': ('landnåm',),
'landnåmstid': ('landnåmstid',),
'landnåmstida': ('landnåmstid',),
'landnåmstiden': ('landnåmstid',),
'landnåmstidene': ('landnåmstid',),
'landnåmstider': ('landnåmstid',),
'landområda': ('landområde',),
'landområde': ('landområde',),
'landområdene': ('landområde',),
'landområder': ('landområde',),
'landområdet': ('landområde',),
'landpostbud': ('landpostbud',),
'landpostbuda': ('landpostbud',),
'landpostbudene': ('landpostbud',),
'landpostbudet': ('landpostbud',),
'landsbasis': ('landsbasis',),
'landsbasisen': ('landsbasis',),
'landsbasisene': ('landsbasis',),
'landsbasiser': ('landsbasis',),
'landsby': ('landsby',),
'landsbyen': ('landsby',),
'landsbyene': ('landsby',),
'landsbyer': ('landsby',),
'landsbygd': ('landsbygd',),
'landsbygda': ('landsbygd',),
'landsbygden': ('landsbygd',),
'landsbygdene': ('landsbygd',),
'landsbygder': ('landsbygd',),
'landsdel': ('landsdel',),
'landsdelen': ('landsdel',),
'landsdelene': ('landsdel',),
'landsdeler': ('landsdel',),
'landsdelsplan': ('landsdelsplan',),
'landsdelsplanen': ('landsdelsplan',),
'landsdelsplanene': ('landsdelsplan',),
'landsdelsplaner': ('landsdelsplan',),
'landsende': ('landsende',),
'landsenden': ('landsende',),
'landsendene': ('landsende',),
'landsender': ('landsende',),
'landsfader': ('landsfader',),
'landsfaderen': ('landsfader',),
'landsfedre': ('landsfader',),
'landsfedrene': ('landsfader',),
'landsfar': ('landsfar',),
'landsfaren': ('landsfar',),
'landsfedre': ('landsfar',),
'landsfedrene': ('landsfar',),
'landsfengsel': ('landsfengsel',),
'landsfengselet': ('landsfengsel',),
'landsfengsla': ('landsfengsel',),
'landsfengslene': ('landsfengsel',),
'landsfengsler': ('landsfengsel',),
'landsfengslet': ('landsfengsel',),
'landsfolk': ('landsfolk',),
'landsfolka': ('landsfolk',),
'landsfolkene': ('landsfolk',),
'landsfolket': ('landsfolk',),
'landsforræder': ('landsforræder',),
'landsforrædere': ('landsforræder',),
'landsforræderen': ('landsforræder',),
'landsforræderer': ('landsforræder',),
'landsforræderne': ('landsforræder',),
'landsforræderi': ('landsforræderi',),
'landsforræderia': ('landsforræderi',),
'landsforræderiene': ('landsforræderi',),
'landsforræderier': ('landsforræderi',),
'landsforræderiet': ('landsforræderi',),
'landsforvisning': ('landsforvisning',),
'landsforvisninga': ('landsforvisning',),
'landsforvisningen': ('landsforvisning',),
'landsforvisningene': ('landsforvisning',),
'landsforvisninger': ('landsforvisning',),
'landsgjennomsnitt': ('landsgjennomsnitt',),
'landsgjennomsnitta': ('landsgjennomsnitt',),
'landsgjennomsnittene': ('landsgjennomsnitt',),
'landsgjennomsnittet': ('landsgjennomsnitt',),
'landsgymnas': ('landsgymnas',),
'landsgymnasa': ('landsgymnas',),
'landsgymnasene': ('landsgymnas',),
'landsgymnaser': ('landsgymnas',),
'landsgymnaset': ('landsgymnas',),
'landsgymnasia': ('landsgymnasium',),
'landsgymnasiene': ('landsgymnasium',),
'landsgymnasier': ('landsgymnasium',),
'landsgymnasiet': ('landsgymnasium',),
'landsgymnasium': ('landsgymnasium',),
'landshøvding': ('landshøvding',),
'landshøvdingen': ('landshøvding',),
'landshøvdingene': ('landshøvding',),
'landshøvdinger': ('landshøvding',),
'landskamp': ('landskamp',),
'landskampen': ('landskamp',),
'landskampene': ('landskamp',),
'landskamper': ('landskamp',),
'landskap': ('landskap',),
'landskapa': ('landskap',),
'landskapene': ('landskap',),
'landskaper': ('landskap',),
'landskapet': ('landskap',),
'landskappleik': ('landskappleik',),
'landskappleiken': ('landskappleik',),
'landskappleikene': ('landskappleik',),
'landskappleiker': ('landskappleik',),
'landskapsarkitekt': ('landskapsarkitekt',),
'landskapsarkitekten': ('landskapsarkitekt',),
'landskapsarkitektene': ('landskapsarkitekt',),
'landskapsarkitekter': ('landskapsarkitekt',),
'landskapsarkitektur': ('landskapsarkitektur',),
'landskapsarkitekturen': ('landskapsarkitektur',),
'landskapsarkitekturene': ('landskapsarkitektur',),
'landskapsarkitekturer': ('landskapsarkitektur',),
'landskapsbilda': ('landskapsbilde',),
'landskapsbilde': ('landskapsbilde',),
'landskapsbildene': ('landskapsbilde',),
'landskapsbilder': ('landskapsbilde',),
'landskapsbildet': ('landskapsbilde',),
'landskapsmaler': ('landskapsmaler',),
'landskapsmalere': ('landskapsmaler',),
'landskapsmaleren': ('landskapsmaler',),
'landskapsmalerer': ('landskapsmaler',),
'landskapsmalerne': ('landskapsmaler',),
'landskapsmaleri': ('landskapsmaleri',),
'landskapsmaleria': ('landskapsmaleri',),
'landskapsmaleriene': ('landskapsmaleri',),
'landskapsmalerier': ('landskapsmaleri',),
'landskapsmaleriet': ('landskapsmaleri',),
'landskapsvern': ('landskapsvern',),
'landskapsverna': ('landskapsvern',),
'landskapsvernene': ('landskapsvern',),
'landskapsvernet': ('landskapsvern',),
'landskapsvernområda': ('landskapsvernområde',),
'landskapsvernområde': ('landskapsvernområde',),
'landskapsvernområdene': ('landskapsvernområde',),
'landskapsvernområder': ('landskapsvernområde',),
'landskapsvernområdet': ('landskapsvernområde',),
'landskilpadda': ('landskilpadde',),
'landskilpadde': ('landskilpadde',),
'landskilpadden': ('landskilpadde',),
'landskilpaddene': ('landskilpadde',),
'landskilpadder': ('landskilpadde',),
'landsknekt': ('landsknekt',),
'landsknekten': ('landsknekt',),
'landsknektene': ('landsknekt',),
'landsknekter': ('landsknekt',),
'landskyld': ('landskyld',),
'landskylda': ('landskyld',),
'landskylden': ('landskyld',),
'landskyldene': ('landskyld',),
'landskylder': ('landskyld',),
'landslag': ('landslag',),
'landslaga': ('landslag',),
'landslagene': ('landslag',),
'landslaget': ('landslag',),
'landslagsspeller': ('landslagsspeller',),
'landslagsspellere': ('landslagsspeller',),
'landslagsspelleren': ('landslagsspeller',),
'landslagsspellerer': ('landslagsspeller',),
'landslagsspellerne': ('landslagsspeller',),
'landslagsspiller': ('landslagsspiller',),
'landslagsspillere': ('landslagsspiller',),
'landslagsspilleren': ('landslagsspiller',),
'landslagsspillerer': ('landslagsspiller',),
'landslagsspillerne': ('landslagsspiller',),
'landslott': ('landslott',),
'landslotten': ('landslott',),
'landslottene': ('landslott',),
'landslotter': ('landslott',),
'landslov': ('landslov',),
'landsloven': ('landslov',),
'landslovene': ('landslov',),
'landslover': ('landslov',),
'landsmann': ('landsmann',),
'landsmannen': ('landsmann',),
'landsmenn': ('landsmann',),
'landsmennene': ('landsmann',),
'landsmål': ('landsmål',),
'landsmåla': ('landsmål',),
'landsmålene': ('landsmål',),
'landsmålet': ('landsmål',),
'landsmålestokk': ('landsmålestokk',),
'landsmålestokken': ('landsmålestokk',),
'landsmålestokkene': ('landsmålestokk',),
'landsmålestokker': ('landsmålestokk',),
'landsmøta': ('landsmøte',),
'landsmøte': ('landsmøte',),
'landsmøtene': ('landsmøte',),
'landsmøter': ('landsmøte',),
'landsmøtet': ('landsmøte',),
'landsnummer': ('landsnummer',),
'landsnummeret': ('landsnummer',),
'landsnumra': ('landsnummer',),
'landsnumre': ('landsnummer',),
'landsnumrene': ('landsnummer',),
'landsorganisasjon': ('landsorganisasjon',),
'landsorganisasjonen': ('landsorganisasjon',),
'landsorganisasjonene': ('landsorganisasjon',),
'landsorganisasjoner': ('landsorganisasjon',),
'landsplan': ('landsplan',),
'landsplana': ('landsplan',),
'landsplanene': ('landsplan',),
'landsplanet': ('landsplan',),
'landsrenn': ('landsrenn',),
'landsrenna': ('landsrenn',),
'landsrennene': ('landsrenn',),
'landsrennet': ('landsrenn',),
'landssammenheng': ('landssammenheng',),
'landssammenhengen': ('landssammenheng',),
'landssammenhengene': ('landssammenheng',),
'landssammenhenger': ('landssammenheng',),
'landsstyra': ('landsstyre',),
'landsstyre': ('landsstyre',),
'landsstyrene': ('landsstyre',),
'landsstyrer': ('landsstyre',),
'landsstyret': ('landsstyre',),
'landssvik': ('landssvik',),
'landssvika': ('landssvik',),
'landssvikene': ('landssvik',),
'landssviket': ('landssvik',),
'landssviker': ('landssviker',),
'landssvikere': ('landssviker',),
'landssvikeren': ('landssviker',),
'landssvikerer': ('landssviker',),
'landssvikerne': ('landssviker',),
'landsted': ('landsted',),
'landstedene': ('landsted',),
'landsteder': ('landsted',),
'landstedet': ('landsted',),
'landstryker': ('landstryker',),
'landstrykere': ('landstryker',),
'landstrykeren': ('landstryker',),
'landstrykerer': ('landstryker',),
'landstrykerne': ('landstryker',),
'landsulykka': ('landsulykke',),
'landsulykke': ('landsulykke',),
'landsulykken': ('landsulykke',),
'landsulykkene': ('landsulykke',),
'landsulykker': ('landsulykke',),
'landsungdom': ('landsungdom',),
'landsungdommen': ('landsungdom',),
'landsungdommene': ('landsungdom',),
'landsungdommer': ('landsungdom',),
'landsynning': ('landsynning',),
'landsynninga': ('landsynning',),
'landsynningen': ('landsynning',),
'landsynningene': ('landsynning',),
'landsynninger': ('landsynning',),
'landtange': ('landtange',),
'landtangen': ('landtange',),
'landtangene': ('landtange',),
'landtanger': ('landtange',),
'landtau': ('landtau',),
'landtaua': ('landtau',),
'landtauene': ('landtau',),
'landtauet': ('landtau',),
'landtunga': ('landtunge',),
'landtunge': ('landtunge',),
'landtungen': ('landtunge',),
'landtungene': ('landtunge',),
'landtunger': ('landtunge',),
'landtur': ('landtur',),
'landturen': ('landtur',),
'landturene': ('landtur',),
'landturer': ('landtur',),
'landveg': ('landveg',),
'landvegen': ('landveg',),
'landvegene': ('landveg',),
'landveger': ('landveg',),
'landvei': ('landvei',),
'landveien': ('landvei',),
'landveiene': ('landvei',),
'landveier': ('landvei',),
'landvern': ('landvern',),
'landverna': ('landvern',),
'landvernene': ('landvern',),
'landvernet': ('landvern',),
'landvinning': ('landvinning',),
'landvinninga': ('landvinning',),
'landvinningen': ('landvinning',),
'landvinningene': ('landvinning',),
'landvinninger': ('landvinning',),
'langball': ('langball',),
'langballen': ('langball',),
'langballene': ('langball',),
'langballer': ('langball',),
'langbein': ('langbein',),
'langbeinen': ('langbein',),
'langbeinene': ('langbein',),
'langbeiner': ('langbein',),
'langben': ('langben',),
'langbenen': ('langben',),
'langbenene': ('langben',),
'langbener': ('langben',),
'langbord': ('langbord',),
'langborda': ('langbord',),
'langbordene': ('langbord',),
'langborder': ('langbord',),
'langbordet': ('langbord',),
'langbuksa': ('langbukse',),
'langbukse': ('langbukse',),
'langbuksen': ('langbukse',),
'langbuksene': ('langbukse',),
'langbukser': ('langbukse',),
'langbølga': ('langbølge',),
'langbølge': ('langbølge',),
'langbølgen': ('langbølge',),
'langbølgene': ('langbølge',),
'langbølger': ('langbølge',),
'langbølgja': ('langbølgje',),
'langbølgje': ('langbølgje',),
'langbølgjen': ('langbølgje',),
'langbølgjene': ('langbølgje',),
'langbølgjer': ('langbølgje',),
'langdistanse': ('langdistanse',),
'langdistansen': ('langdistanse',),
'langdistansene': ('langdistanse',),
'langdistanser': ('langdistanse',),
'langdistanseløp': ('langdistanseløp',),
'langdistanseløpa': ('langdistanseløp',),
'langdistanseløpene': ('langdistanseløp',),
'langdistanseløpet': ('langdistanseløp',),
'langdistanseløper': ('langdistanseløper',),
'langdistanseløpere': ('langdistanseløper',),
'langdistanseløperen': ('langdistanseløper',),
'langdistanseløperer': ('langdistanseløper',),
'langdistanseløperne': ('langdistanseløper',),
'langdistanserakett': ('langdistanserakett',),
'langdistanseraketten': ('langdistanserakett',),
'langdistanserakettene': ('langdistanserakett',),
'langdistanseraketter': ('langdistanserakett',),
'langdrag': ('langdrag',),
'langdraga': ('langdrag',),
'langdragene': ('langdrag',),
'langdraget': ('langdrag',),
'langa': ('lange',),
'lange': ('lange',),
'langen': ('lange',),
'langene': ('lange',),
'langer': ('lange',),
'langeleik': ('langeleik',),
'langeleiken': ('langeleik',),
'langeleikene': ('langeleik',),
'langeleiker': ('langeleik',),
'langemann': ('langemann',),
'langemannen': ('langemann',),
'langemenn': ('langemann',),
'langemennene': ('langemann',),
'langer': ('langer',),
'langere': ('langer',),
'langeren': ('langer',),
'langerer': ('langer',),
'langerne': ('langer',),
'langfart': ('langfart',),
'langfarten': ('langfart',),
'langfartene': ('langfart',),
'langfarter': ('langfart',),
'langfasta': ('langfaste',),
'langfaste': ('langfaste',),
'langfasten': ('langfaste',),
'langfastene': ('langfaste',),
'langfaster': ('langfaste',),
'langfilm': ('langfilm',),
'langfilmen': ('langfilm',),
'langfilmene': ('langfilm',),
'langfilmer': ('langfilm',),
'langfinger': ('langfinger',),
'langfingeren': ('langfinger',),
'langfingre': ('langfinger',),
'langfingrene': ('langfinger',),
'langfingrer': ('langfinger',),
'langfredag': ('langfredag',),
'langfredagen': ('langfredag',),
'langfredagene': ('langfredag',),
'langfredager': ('langfredag',),
'langfriminutt': ('langfriminutt',),
'langfriminutta': ('langfriminutt',),
'langfriminuttene': ('langfriminutt',),
'langfriminutter': ('langfriminutt',),
'langfriminuttet': ('langfriminutt',),
'langhalm': ('langhalm',),
'langhalmen': ('langhalm',),
'langhalmene': ('langhalm',),
'langhalmer': ('langhalm',),
'langhekk': ('langhekk',),
'langhekken': ('langhekk',),
'langhekkene': ('langhekk',),
'langhekker': ('langhekk',),
'langhelg': ('langhelg',),
'langhelga': ('langhelg',),
'langhelgen': ('langhelg',),
'langhelgene': ('langhelg',),
'langhelger': ('langhelg',),
'langkost': ('langkost',),
'langkosten': ('langkost',),
'langkostene': ('langkost',),
'langkoster': ('langkost',),
'langobard': ('langobard',),
'langobarden': ('langobard',),
'langobardene': ('langobard',),
'langobarder': ('langobard',),
'langpils': ('langpils',),
'langpilsen': ('langpils',),
'langpilsene': ('langpils',),
'langpilser': ('langpils',),
'langplata': ('langplate',),
'langplate': ('langplate',),
'langplaten': ('langplate',),
'langplatene': ('langplate',),
'langplater': ('langplate',),
'langrenn': ('langrenn',),
'langrenna': ('langrenn',),
'langrennene': ('langrenn',),
'langrennet': ('langrenn',),
'langrenner': ('langrenner',),
'langrennere': ('langrenner',),
'langrenneren': ('langrenner',),
'langrennerer': ('langrenner',),
'langrennerne': ('langrenner',),
'langrennsløper': ('langrennsløper',),
'langrennsløpere': ('langrennsløper',),
'langrennsløperen': ('langrennsløper',),
'langrennsløperer': ('langrennsløper',),
'langrennsløperne': ('langrennsløper',),
'langrennsløypa': ('langrennsløype',),
'langrennsløype': ('langrennsløype',),
'langrennsløypen': ('langrennsløype',),
'langrennsløypene': ('langrennsløype',),
'langrennsløyper': ('langrennsløype',),
'langrennsski': ('langrennsski',),
'langrennsskia': ('langrennsski',),
'langrennsskien': ('langrennsski',),
'langrennsskiene': ('langrennsski',),
'langrennsskier': ('langrennsski',),
'langsida': ('langside',),
'langside': ('langside',),
'langsiden': ('langside',),
'langsidene': ('langside',),
'langsider': ('langside',),
'langskalle': ('langskalle',),
'langskallen': ('langskalle',),
'langskallene': ('langskalle',),
'langskaller': ('langskalle',),
'langskip': ('langskip',),
'langskipa': ('langskip',),
'langskipene': ('langskip',),
'langskipet': ('langskip',),
'langskott': ('langskott',),
'langskotta': ('langskott',),
'langskottene': ('langskott',),
'langskottet': ('langskott',),
'langskudd': ('langskudd',),
'langskudda': ('langskudd',),
'langskuddene': ('langskudd',),
'langskuddet': ('langskudd',),
'langspellplata': ('langspellplate',),
'langspellplate': ('langspellplate',),
'langspellplaten': ('langspellplate',),
'langspellplatene': ('langspellplate',),
'langspellplater': ('langspellplate',),
'langspillplata': ('langspillplate',),
'langspillplate': ('langspillplate',),
'langspillplaten': ('langspillplate',),
'langspillplatene': ('langspillplate',),
'langspillplater': ('langspillplate',),
'langtidsbudsjett': ('langtidsbudsjett',),
'langtidsbudsjetta': ('langtidsbudsjett',),
'langtidsbudsjettene': ('langtidsbudsjett',),
'langtidsbudsjetter': ('langtidsbudsjett',),
'langtidsbudsjettet': ('langtidsbudsjett',),
'langtidspasient': ('langtidspasient',),
'langtidspasienten': ('langtidspasient',),
'langtidspasientene': ('langtidspasient',),
'langtidspasienter': ('langtidspasient',),
'langtidsplan': ('langtidsplan',),
'langtidsplanen': ('langtidsplan',),
'langtidsplanene': ('langtidsplan',),
'langtidsplaner': ('langtidsplan',),
'langtidsprogram': ('langtidsprogram',),
'langtidsprogramma': ('langtidsprogram',),
'langtidsprogrammene': ('langtidsprogram',),
'langtidsprogrammer': ('langtidsprogram',),
'langtidsprogrammet': ('langtidsprogram',),
'langtidsvarsel': ('langtidsvarsel',),
'langtidsvarselet': ('langtidsvarsel',),
'langtidsvarsla': ('langtidsvarsel',),
'langtidsvarslene': ('langtidsvarsel',),
'langtidsvarsler': ('langtidsvarsel',),
'langtidsvarslet': ('langtidsvarsel',),
'langtidsvirkning': ('langtidsvirkning',),
'langtidsvirkninga': ('langtidsvirkning',),
'langtidsvirkningen': ('langtidsvirkning',),
'langtidsvirkningene': ('langtidsvirkning',),
'langtidsvirkninger': ('langtidsvirkning',),
'langtransport': ('langtransport',),
'langtransporten': ('langtransport',),
'langtransportene': ('langtransport',),
'langtransporter': ('langtransport',),
'langtransportsjåfør': ('langtransportsjåfør',),
'langtransportsjåføren': ('langtransportsjåfør',),
'langtransportsjåførene': ('langtransportsjåfør',),
'langtransportsjåfører': ('langtransportsjåfør',),
'langtur': ('langtur',),
'langturen': ('langtur',),
'langturene': ('langtur',),
'langturer': ('langtur',),
'langust': ('langust',),
'langusten': ('langust',),
'langustene': ('langust',),
'languster': ('langust',),
'langvedsag': ('langvedsag',),
'langvedsaga': ('langvedsag',),
'langvedsagen': ('langvedsag',),
'langvedsagene': ('langvedsag',),
'langvedsager': ('langvedsag',),
'langvegg': ('langvegg',),
'langveggen': ('langvegg',),
'langveggene': ('langvegg',),
'langvegger': ('langvegg',),
'langvi': ('langvi',),
'langvien': ('langvi',),
'langviene': ('langvi',),
'langvier': ('langvi',),
'langviser': ('langviser',),
'langvisere': ('langviser',),
'langviseren': ('langviser',),
'langviserer': ('langviser',),
'langviserne': ('langviser',),
'lanke': ('lanke',),
'lanken': ('lanke',),
'lankene': ('lanke',),
'lanker': ('lanke',),
'lanolin': ('lanolin',),
'lanolinen': ('lanolin',),
'lanolinene': ('lanolin',),
'lanoliner': ('lanolin',),
'lansa': ('lanse',),
'lanse': ('lanse',),
'lansen': ('lanse',),
'lansene': ('lanse',),
'lanser': ('lanse',),
'lanseknekt': ('lanseknekt',),
'lanseknekten': ('lanseknekt',),
'lanseknektene': ('lanseknekt',),
'lanseknekter': ('lanseknekt',),
'lansett': ('lansett',),
'lansetten': ('lansett',),
'lansettene': ('lansett',),
'lansetter': ('lansett',),
'lansettfisk': ('lansettfisk',),
'lansettfisken': ('lansettfisk',),
'lansettfiskene': ('lansettfisk',),
'lansettfisker': ('lansettfisk',),
'lantan': ('lantan',),
'lantana': ('lantan',),
'lantanene': ('lantan',),
'lantanet': ('lantan',),
'lanterna': ('lanterne',),
'lanterne': ('lanterne',),
'lanternen': ('lanterne',),
'lanternene': ('lanterne',),
'lanterner': ('lanterne',),
'laot': ('laot',),
'laoten': ('laot',),
'laotene': ('laot',),
'laoter': ('laot',),
'lapidarskrift': ('lapidarskrift',),
'lapidarskrifta': ('lapidarskrift',),
'lapidarskriften': ('lapidarskrift',),
'lapidarskriftene': ('lapidarskrift',),
'lapidarskrifter': ('lapidarskrift',),
'lapidarstil': ('lapidarstil',),
'lapidarstilen': ('lapidarstil',),
'lapidarstilene': ('lapidarstil',),
'lapidarstiler': ('lapidarstil',),
'lapis': ('lapis',),
'lapisen': ('lapis',),
'lapisene': ('lapis',),
'lapiser': ('lapis',),
'lapp': ('lapp',),
'lappen': ('lapp',),
'lappene': ('lapp',),
'lapper': ('lapp',),
'lapp': ('lapp',),
'lappen': ('lapp',),
'lappene': ('lapp',),
'lapper': ('lapp',),
'lappedykker': ('lappedykker',),
'lappedykkere': ('lappedykker',),
'lappedykkeren': ('lappedykker',),
'lappedykkerer': ('lappedykker',),
'lappedykkerne': ('lappedykker',),
'lappefogd': ('lappefogd',),
'lappefogden': ('lappefogd',),
'lappefogdene': ('lappefogd',),
'lappefogder': ('lappefogd',),
'lappefut': ('lappefut',),
'lappefuten': ('lappefut',),
'lappefutene': ('lappefut',),
'lappefuter': ('lappefut',),
'lapperi': ('lapperi',),
'lapperia': ('lapperi',),
'lapperiene': ('lapperi',),
'lapperier': ('lapperi',),
'lapperiet': ('lapperi',),
'lappesakene': ('lappesaker',),
'lappesaker': ('lappesaker',),
'lappeskomaker': ('lappeskomaker',),
'lappeskomakere': ('lappeskomaker',),
'lappeskomakeren': ('lappeskomaker',),
'lappeskomakerer': ('lappeskomaker',),
'lappeskomakerne': ('lappeskomaker',),
'lappeteknikk': ('lappeteknikk',),
'lappeteknikken': ('lappeteknikk',),
'lappeteknikkene': ('lappeteknikk',),
'lappeteknikker': ('lappeteknikk',),
'lappeteppa': ('lappeteppe',),
'lappeteppe': ('lappeteppe',),
'lappeteppene': ('lappeteppe',),
'lappetepper': ('lappeteppe',),
'lappeteppet': ('lappeteppe',),
'lapplender': ('lapplender',),
'lapplendere': ('lapplender',),
'lapplenderen': ('lapplender',),
'lapplenderer': ('lapplender',),
'lapplenderne': ('lapplender',),
'lapplending': ('lapplending',),
'lapplendingen': ('lapplending',),
'lapplendingene': ('lapplending',),
'lapplendinger': ('lapplending',),
'lappolog': ('lappolog',),
'lappologen': ('lappolog',),
'lappologene': ('lappolog',),
'lappologer': ('lappolog',),
'lappologi': ('lappologi',),
'lappologien': ('lappologi',),
'lappologiene': ('lappologi',),
'lappologier': ('lappologi',),
'lapprosa': ('lapprose',),
'lapprose': ('lapprose',),
'lapprosen': ('lapprose',),
'lapprosene': ('lapprose',),
'lapproser': ('lapprose',),
'lappspurv': ('lappspurv',),
'lappspurven': ('lappspurv',),
'lappspurvene': ('lappspurv',),
'lappspurver': ('lappspurv',),
'lappverk': ('lappverk',),
'lappverka': ('lappverk',),
'lappverkene': ('lappverk',),
'lappverker': ('lappverk',),
'lappverket': ('lappverk',),
'laps': ('laps',),
'lapsen': ('laps',),
'lapsene': ('laps',),
'lapser': ('laps',),
'lapskaus': ('lapskaus',),
'lapskausen': ('lapskaus',),
'lapskausene': ('lapskaus',),
'lapskauser': ('lapskaus',),
'lapsus': ('lapsus',),
'lapsusen': ('lapsus',),
'lapsusene': ('lapsus',),
'lapsuser': ('lapsus',),
'larghetto': ('larghetto',),
'larghettoen': ('larghetto',),
'larghettoene': ('larghetto',),
'larghettoer': ('larghetto',),
'larghetto': ('larghetto',),
'larghettoa': ('larghetto',),
'larghettoene': ('larghetto',),
'larghettoer': ('larghetto',),
'larghettoet': ('larghetto',),
'largo': ('largo',),
'largoen': ('largo',),
'largoene': ('largo',),
'largoer': ('largo',),
'largo': ('largo',),
'largoa': ('largo',),
'largoene': ('largo',),
'largoer': ('largo',),
'largoet': ('largo',),
'larm': ('larm',),
'larmen': ('larm',),
'larmene': ('larm',),
'larmer': ('larm',),
'larsok': ('larsok',),
'larsoken': ('larsok',),
'larsokene': ('larsok',),
'larsoker': ('larsok',),
'larv': ('larv',),
'larven': ('larv',),
'larvene': ('larv',),
'larver': ('larv',),
'larv': ('larv',),
'larva': ('larv',),
'larvene': ('larv',),
'larvet': ('larv',),
'larve': ('larve',),
'larven': ('larve',),
'larvene': ('larve',),
'larver': ('larve',),
'larva': ('larve',),
'larve': ('larve',),
'larven': ('larve',),
'larvene': ('larve',),
'larver': ('larve',),
'larvestadia': ('larvestadium',),
'larvestadiene': ('larvestadium',),
'larvestadier': ('larvestadium',),
'larvestadiet': ('larvestadium',),
'larvestadium': ('larvestadium',),
'laryngal': ('laryngal',),
'laryngalen': ('laryngal',),
'laryngalene': ('laryngal',),
'laryngaler': ('laryngal',),
'laryngitt': ('laryngitt',),
'laryngitten': ('laryngitt',),
'laryngittene': ('laryngitt',),
'laryngitter': ('laryngitt',),
'laryngoskop': ('laryngoskop',),
'laryngoskopa': ('laryngoskop',),
'laryngoskopene': ('laryngoskop',),
'laryngoskoper': ('laryngoskop',),
'laryngoskopet': ('laryngoskop',),
'lasagne': ('lasagne',),
'lasagnen': ('lasagne',),
'lasagnene': ('lasagne',),
'lasagner': ('lasagne',),
'lasarett': ('lasarett',),
'lasaretta': ('lasarett',),
'lasarettene': ('lasarett',),
'lasaretter': ('lasarett',),
'lasarettet': ('lasarett',),
'lasaron': ('lasaron',),
'lasaronen': ('lasaron',),
'lasaronene': ('lasaron',),
'lasaroner': ('lasaron',),
'lase': ('lase',),
'lasen': ('lase',),
'lasene': ('lase',),
'laser': ('lase',),
'laser': ('laser',),
'lasere': ('laser',),
'laseren': ('laser',),
'laserer': ('laser',),
'laserne': ('laser',),
'laserkniv': ('laserkniv',),
'laserkniven': ('laserkniv',),
'laserknivene': ('laserkniv',),
'laserkniver': ('laserkniv',),
'laserskriver': ('laserskriver',),
'laserskrivere': ('laserskriver',),
'laserskriveren': ('laserskriver',),
'laserskriverer': ('laserskriver',),
'laserskriverne': ('laserskriver',),
'laserstråle': ('laserstråle',),
'laserstrålen': ('laserstråle',),
'laserstrålene': ('laserstråle',),
'laserstråler': ('laserstråle',),
'lasersveising': ('lasersveising',),
'lasersveisinga': ('lasersveising',),
'lasersveisingen': ('lasersveising',),
'lasersveisingene': ('lasersveising',),
'lasersveisinger': ('lasersveising',),
'lask': ('lask',),
'lasken': ('lask',),
'laskene': ('lask',),
'lasker': ('lask',),
'laske': ('laske',),
'lasken': ('laske',),
'laskene': ('laske',),
'lasker': ('laske',),
'lass': ('lass',),
'lassa': ('lass',),
'lassene': ('lass',),
'lasset': ('lass',),
'lassis': ('lassis',),
'lassisen': ('lassis',),
'lassisene': ('lassis',),
'lassiser': ('lassis',),
'lasso': ('lasso',),
'lassoen': ('lasso',),
'lassoene': ('lasso',),
'lassoer': ('lasso',),
'last': ('last',),
'lasta': ('last',),
'lasten': ('last',),
'lastene': ('last',),
'laster': ('last',),
'last': ('last',),
'lasta': ('last',),
'lasten': ('last',),
'lastene': ('last',),
'laster': ('last',),
'lastdyr': ('lastdyr',),
'lastdyra': ('lastdyr',),
'lastdyrene': ('lastdyr',),
'lastdyret': ('lastdyr',),
'lastearbeider': ('lastearbeider',),
'lastearbeidere': ('lastearbeider',),
'lastearbeideren': ('lastearbeider',),
'lastearbeiderer': ('lastearbeider',),
'lastearbeiderne': ('lastearbeider',),
'lastebil': ('lastebil',),
'lastebilen': ('lastebil',),
'lastebilene': ('lastebil',),
'lastebiler': ('lastebil',),
'lastebom': ('lastebom',),
'lastebommen': ('lastebom',),
'lastebommene': ('lastebom',),
'lastebommer': ('lastebom',),
'lastebåt': ('lastebåt',),
'lastebåten': ('lastebåt',),
'lastebåtene': ('lastebåt',),
'lastebåter': ('lastebåt',),
'lastedyr': ('lastedyr',),
'lastedyra': ('lastedyr',),
'lastedyrene': ('lastedyr',),
'lastedyret': ('lastedyr',),
'lasteevna': ('lasteevne',),
'lasteevne': ('lasteevne',),
'lasteevnen': ('lasteevne',),
'lasteevnene': ('lasteevne',),
'lasteevner': ('lasteevne',),
'lastegjeng': ('lastegjeng',),
'lastegjengen': ('lastegjeng',),
'lastegjengene': ('lastegjeng',),
'lastegjenger': ('lastegjeng',),
'lasteks': ('lasteks',),
'lasteksen': ('lasteks',),
'lasteksene': ('lasteks',),
'lastekser': ('lasteks',),
'lastelinja': ('lastelinje',),
'lastelinje': ('lastelinje',),
'lastelinjen': ('lastelinje',),
'lastelinjene': ('lastelinje',),
'lastelinjer': ('lastelinje',),
'lastelinjemerka': ('lastelinjemerke',),
'lastelinjemerke': ('lastelinjemerke',),
'lastelinjemerkene': ('lastelinjemerke',),
'lastelinjemerker': ('lastelinjemerke',),
'lastelinjemerket': ('lastelinjemerke',),
'lasteluka': ('lasteluke',),
'lasteluke': ('lasteluke',),
'lasteluken': ('lasteluke',),
'lastelukene': ('lasteluke',),
'lasteluker': ('lasteluke',),
'lastemerka': ('lastemerke',),
'lastemerke': ('lastemerke',),
'lastemerkene': ('lastemerke',),
'lastemerker': ('lastemerke',),
'lastemerket': ('lastemerke',),
'lastepall': ('lastepall',),
'lastepallen': ('lastepall',),
'lastepallene': ('lastepall',),
'lastepaller': ('lastepall',),
'lasteplan': ('lasteplan',),
'lasteplana': ('lasteplan',),
'lasteplanene': ('lasteplan',),
'lasteplanet': ('lasteplan',),
'lasteplass': ('lasteplass',),
'lasteplassen': ('lasteplass',),
'lasteplassene': ('lasteplass',),
'lasteplasser': ('lasteplass',),
'lasterom': ('lasterom',),
'lasteromma': ('lasterom',),
'lasterommene': ('lasterom',),
'lasterommet': ('lasterom',),
'lasting': ('lasting',),
'lastingen': ('lasting',),
'lastingene': ('lasting',),
'lastinger': ('lasting',),
'lastord': ('lastord',),
'lastorda': ('lastord',),
'lastordene': ('lastord',),
'lastordet': ('lastord',),
'lastverk': ('lastverk',),
'lastverka': ('lastverk',),
'lastverkene': ('lastverk',),
'lastverket': ('lastverk',),
'lasur': ('lasur',),
'lasuren': ('lasur',),
'lasurene': ('lasur',),
'lasurer': ('lasur',),
'lasurfarge': ('lasurfarge',),
'lasurfargen': ('lasurfarge',),
'lasurfargene': ('lasurfarge',),
'lasurfarger': ('lasurfarge',),
'lateks': ('lateks',),
'lateksen': ('lateks',),
'lateksene': ('lateks',),
'latekser': ('lateks',),
'lateksmaling': ('lateksmaling',),
'lateksmalinga': ('lateksmaling',),
'lateksmalingen': ('lateksmaling',),
'lateksmalingene': ('lateksmaling',),
'lateksmalinger': ('lateksmaling',),
'latens': ('latens',),
'latensen': ('latens',),
'latensene': ('latens',),
'latenser': ('latens',),
'latenstid': ('latenstid',),
'latenstida': ('latenstid',),
'latenstiden': ('latenstid',),
'latenstidene': ('latenstid',),
'latenstider': ('latenstid',),
'lateral': ('lateral',),
'lateralen': ('lateral',),
'lateralene': ('lateral',),
'lateraler': ('lateral',),
'lateritt': ('lateritt',),
'lateritten': ('lateritt',),
'laterittene': ('lateritt',),
'lateritter': ('lateritt',),
'lathans': ('lathans',),
'lathansen': ('lathans',),
'lathansene': ('lathans',),
'lathanser': ('lathans',),
'latin': ('latin',),
'latinen': ('latin',),
'latinene': ('latin',),
'latiner': ('latin',),
'latinamerikaner': ('latinamerikaner',),
'latinamerikanere': ('latinamerikaner',),
'latinamerikaneren': ('latinamerikaner',),
'latinamerikanerer': ('latinamerikaner',),
'latinamerikanerne': ('latinamerikaner',),
'latinartium': ('latinartium',),
'latinartiumen': ('latinartium',),
'latinartiumene': ('latinartium',),
'latinartiumer': ('latinartium',),
'latiner': ('latiner',),
'latinere': ('latiner',),
'latineren': ('latiner',),
'latinerer': ('latiner',),
'latinerne': ('latiner',),
'latinerkvarter': ('latinerkvarter',),
'latinerkvartera': ('latinerkvarter',),
'latinerkvarterene': ('latinerkvarter',),
'latinerkvarterer': ('latinerkvarter',),
'latinerkvarteret': ('latinerkvarter',),
'latinersegl': ('latinersegl',),
'latinersegla': ('latinersegl',),
'latinerseglene': ('latinersegl',),
'latinerseglet': ('latinersegl',),
'latinerseil': ('latinerseil',),
'latinerseila': ('latinerseil',),
'latinerseilene': ('latinerseil',),
'latinerseilet': ('latinerseil',),
'lating': ('lating',),
'latingen': ('lating',),
'latingene': ('lating',),
'latinger': ('lating',),
'latinisme': ('latinisme',),
'latinismen': ('latinisme',),
'latinismene': ('latinisme',),
'latinismer': ('latinisme',),
'latinitet': ('latinitet',),
'latiniteten': ('latinitet',),
'latinitetene': ('latinitet',),
'latiniteter': ('latinitet',),
'latinlinja': ('latinlinje',),
'latinlinje': ('latinlinje',),
'latinlinjen': ('latinlinje',),
'latinlinjene': ('latinlinje',),
'latinlinjer': ('latinlinje',),
'latinskole': ('latinskole',),
'latinskolen': ('latinskole',),
'latinskolene': ('latinskole',),
'latinskoler': ('latinskole',),
'latitude': ('latitude',),
'latituden': ('latitude',),
'latitudene': ('latitude',),
'latituder': ('latitude',),
'latmannsbør': ('latmannsbør',),
'latmannsbøra': ('latmannsbør',),
'latmannsbøren': ('latmannsbør',),
'latmannsbørene': ('latmannsbør',),
'latmannsbører': ('latmannsbør',),
'latmannsliv': ('latmannsliv',),
'latmannsliva': ('latmannsliv',),
'latmannslivene': ('latmannsliv',),
'latmannslivet': ('latmannsliv',),
'latmannstråd': ('latmannstråd',),
'latmannstråden': ('latmannstråd',),
'latmannstrådene': ('latmannstråd',),
'latmannstråder': ('latmannstråd',),
'latrina': ('latrine',),
'latrine': ('latrine',),
'latrinen': ('latrine',),
'latrinene': ('latrine',),
'latriner': ('latrine',),
'latsida': ('latside',),
'latside': ('latside',),
'latsiden': ('latside',),
'latsidene': ('latside',),
'latsider': ('latside',),
'latskap': ('latskap',),
'latskapen': ('latskap',),
'latskapene': ('latskap',),
'latskaper': ('latskap',),
'latrene': ('latter',),
'latrer': ('latter',),
'latter': ('latter',),
'lattere': ('latter',),
'latteren': ('latter',),
'latterer': ('latter',),
'latterne': ('latter',),
'latterdør': ('latterdør',),
'latterdøra': ('latterdør',),
'latterdøren': ('latterdør',),
'latterdørene': ('latterdør',),
'latterdører': ('latterdør',),
'latterkrampe': ('latterkrampe',),
'latterkrampen': ('latterkrampe',),
'latterkrampene': ('latterkrampe',),
'latterkramper': ('latterkrampe',),
'lattersalva': ('lattersalve',),
'lattersalve': ('lattersalve',),
'lattersalven': ('lattersalve',),
'lattersalvene': ('lattersalve',),
'lattersalver': ('lattersalve',),
'latvier': ('latvier',),
'latviere': ('latvier',),
'latvieren': ('latvier',),
'latvierer': ('latvier',),
'latvierne': ('latvier',),
'laud': ('laud',),
'lauden': ('laud',),
'laudene': ('laud',),
'lauder': ('laud',),
'laudabilis': ('laudabilis',),
'laudabilisen': ('laudabilis',),
'laudabilisene': ('laudabilis',),
'laudabiliser': ('laudabilis',),
'laua': ('laue',),
'laue': ('laue',),
'lauen': ('laue',),
'lauene': ('laue',),
'lauer': ('laue',),
'laug': ('laug',),
'lauga': ('laug',),
'laugene': ('laug',),
'lauget': ('laug',),
'laug': ('laug',),
'lauga': ('laug',),
'laugene': ('laug',),
'lauget': ('laug',),
'laugardam': ('laugardam',),
'laugardammen': ('laugardam',),
'laugardammene': ('laugardam',),
'laugardammer': ('laugardam',),
'laugarsted': ('laugarsted',),
'laugarstedene': ('laugarsted',),
'laugarsteder': ('laugarsted',),
'laugarstedet': ('laugarsted',),
'laugsplikt': ('laugsplikt',),
'laugsplikta': ('laugsplikt',),
'laugsplikten': ('laugsplikt',),
'laugspliktene': ('laugsplikt',),
'laugsplikter': ('laugsplikt',),
'laup': ('laup',),
'laupen': ('laup',),
'laupene': ('laup',),
'lauper': ('laup',),
'lauparsko': ('lauparsko',),
'lauparskoa': ('lauparsko',),
'lauparskoen': ('lauparsko',),
'lauparskoene': ('lauparsko',),
'lauparskor': ('lauparsko',),
'lauparskorne': ('lauparsko',),
'laurbær': ('laurbær',),
'laurbæra': ('laurbær',),
'laurbærene': ('laurbær',),
'laurbæret': ('laurbær',),
'laurbær': ('laurbær',),
'laurbæra': ('laurbær',),
'laurbærene': ('laurbær',),
'laurbæret': ('laurbær',),
'laurbærblad': ('laurbærblad',),
'laurbærblada': ('laurbærblad',),
'laurbærbladene': ('laurbærblad',),
'laurbærblader': ('laurbærblad',),
'laurbærbladet': ('laurbærblad',),
'laurbærkrans': ('laurbærkrans',),
'laurbærkransen': ('laurbærkrans',),
'laurbærkransene': ('laurbærkrans',),
'laurbærkranser': ('laurbærkrans',),
'laurbærtre': ('laurbærtre',),
'laurbærtrea': ('laurbærtre',),
'laurbærtreet': ('laurbærtre',),
'laurbærtrær': ('laurbærtre',),
'laurbærtrærne': ('laurbærtre',),
'laure': ('laure',),
'lauren': ('laure',),
'laurene': ('laure',),
'laurer': ('laure',),
'lausarbeid': ('lausarbeid',),
'lausarbeida': ('lausarbeid',),
'lausarbeidene': ('lausarbeid',),
'lausarbeider': ('lausarbeid',),
'lausarbeidet': ('lausarbeid',),
'lausarbeider': ('lausarbeider',),
'lausarbeidere': ('lausarbeider',),
'lausarbeideren': ('lausarbeider',),
'lausarbeiderer': ('lausarbeider',),
'lausarbeiderne': ('lausarbeider',),
'lausbikkja': ('lausbikkje',),
'lausbikkje': ('lausbikkje',),
'lausbikkjen': ('lausbikkje',),
'lausbikkjene': ('lausbikkje',),
'lausbikkjer': ('lausbikkje',),
'lausblad': ('lausblad',),
'lausblada': ('lausblad',),
'lausbladene': ('lausblad',),
'lausblader': ('lausblad',),
'lausbladet': ('lausblad',),
'lausbladsystem': ('lausbladsystem',),
'lausbladsystema': ('lausbladsystem',),
'lausbladsystemene': ('lausbladsystem',),
'lausbladsystemer': ('lausbladsystem',),
'lausbladsystemet': ('lausbladsystem',),
'lausdans': ('lausdans',),
'lausdansen': ('lausdans',),
'lausdansene': ('lausdans',),
'lausdanser': ('lausdans',),
'lausfart': ('lausfart',),
'lausfarten': ('lausfart',),
'lausfartene': ('lausfart',),
'lausfarter': ('lausfart',),
'lausgiing': ('lausgiing',),
'lausgiinga': ('lausgiing',),
'lausgiingen': ('lausgiing',),
'lausgiingene': ('lausgiing',),
'lausgiinger': ('lausgiing',),
'lausgivelse': ('lausgivelse',),
'lausgivelsen': ('lausgivelse',),
'lausgivelsene': ('lausgivelse',),
'lausgivelser': ('lausgivelse',),
'lausgiving': ('lausgiving',),
'lausgivinga': ('lausgiving',),
'lausgivingen': ('lausgiving',),
'lausgivingene': ('lausgiving',),
'lausgivinger': ('lausgiving',),
'lausgjenger': ('lausgjenger',),
'lausgjengere': ('lausgjenger',),
'lausgjengeren': ('lausgjenger',),
'lausgjengerer': ('lausgjenger',),
'lausgjengerne': ('lausgjenger',),
'laushest': ('laushest',),
'laushesten': ('laushest',),
'laushestene': ('laushest',),
'laushester': ('laushest',),
'laushår': ('laushår',),
'laushåra': ('laushår',),
'laushårene': ('laushår',),
'laushåret': ('laushår',),
'lauskar': ('lauskar',),
'lauskaren': ('lauskar',),
'lauskarene': ('lauskar',),
'lauskarer': ('lauskar',),
'lauskrutt': ('lauskrutt',),
'lauskrutta': ('lauskrutt',),
'lauskruttene': ('lauskrutt',),
'lauskruttet': ('lauskrutt',),
'lauslating': ('lauslating',),
'lauslatinga': ('lauslating',),
'lauslatingen': ('lauslating',),
'lauslatingene': ('lauslating',),
'lauslatinger': ('lauslating',),
'lauslevnet': ('lauslevnet',),
'lausmedarbeider': ('lausmedarbeider',),
'lausmedarbeidere': ('lausmedarbeider',),
'lausmedarbeideren': ('lausmedarbeider',),
'lausmedarbeiderer': ('lausmedarbeider',),
'lausmedarbeiderne': ('lausmedarbeider',),
'laussalg': ('laussalg',),
'laussalga': ('laussalg',),
'laussalgene': ('laussalg',),
'laussalget': ('laussalg',),
'laustann': ('laustann',),
'laustanna': ('laustann',),
'laustannen': ('laustann',),
'laustennene': ('laustann',),
'laustenner': ('laustann',),
'lausunge': ('lausunge',),
'lausungen': ('lausunge',),
'lausungene': ('lausunge',),
'lausunger': ('lausunge',),
'lausøra': ('lausøre',),
'lausøre': ('lausøre',),
'lausørene': ('lausøre',),
'lausører': ('lausøre',),
'lausøret': ('lausøre',),
'lauv': ('lauv',),
'lauva': ('lauv',),
'lauvene': ('lauv',),
'lauvet': ('lauv',),
'lauvblad': ('lauvblad',),
'lauvblada': ('lauvblad',),
'lauvbladene': ('lauvblad',),
'lauvblader': ('lauvblad',),
'lauvbladet': ('lauvblad',),
'lauvfall': ('lauvfall',),
'lauvfalla': ('lauvfall',),
'lauvfallene': ('lauvfall',),
'lauvfallet': ('lauvfall',),
'lauvhyttefest': ('lauvhyttefest',),
'lauvhyttefesten': ('lauvhyttefest',),
'lauvhyttefestene': ('lauvhyttefest',),
'lauvhyttefester': ('lauvhyttefest',),
'lauvmeis': ('lauvmeis',),
'lauvmeisa': ('lauvmeis',),
'lauvmeisen': ('lauvmeis',),
'lauvmeisene': ('lauvmeis',),
'lauvmeiser': ('lauvmeis',),
'lauvsag': ('lauvsag',),
'lauvsaga': ('lauvsag',),
'lauvsagen': ('lauvsag',),
'lauvsagene': ('lauvsag',),
'lauvsager': ('lauvsag',),
'lauvsanger': ('lauvsanger',),
'lauvsangere': ('lauvsanger',),
'lauvsangeren': ('lauvsanger',),
'lauvsangerer': ('lauvsanger',),
'lauvsangerne': ('lauvsanger',),
'lauvskog': ('lauvskog',),
'lauvskogen': ('lauvskog',),
'lauvskogene': ('lauvskog',),
'lauvskoger': ('lauvskog',),
'lauvskogbelta': ('lauvskogbelte',),
'lauvskogbelte': ('lauvskogbelte',),
'lauvskogbeltene': ('lauvskogbelte',),
'lauvskogbelter': ('lauvskogbelte',),
'lauvskogbeltet': ('lauvskogbelte',),
'lauvsprett': ('lauvsprett',),
'lauvspretta': ('lauvsprett',),
'lauvspretten': ('lauvsprett',),
'lauvsprettene': ('lauvsprett',),
'lauvspretter': ('lauvsprett',),
'lauvsprettet': ('lauvsprett',),
'lauvverk': ('lauvverk',),
'lauvverka': ('lauvverk',),
'lauvverkene': ('lauvverk',),
'lauvverket': ('lauvverk',),
'lav': ('lav',),
'lava': ('lav',),
'laven': ('lav',),
'lavene': ('lav',),
'laver': ('lav',),
'lavet': ('lav',),
'lava': ('lava',),
'lavaen': ('lava',),
'lavaene': ('lava',),
'lavaer': ('lava',),
'lavadel': ('lavadel',),
'lavadelen': ('lavadel',),
'lavadlene': ('lavadel',),
'lavadler': ('lavadel',),
'lavalder': ('lavalder',),
'lavaldere': ('lavalder',),
'lavalderen': ('lavalder',),
'lavalderer': ('lavalder',),
'lavalderne': ('lavalder',),
'lavaldre': ('lavalder',),
'lavaldrene': ('lavalder',),
'lavaldrer': ('lavalder',),
'lavblad': ('lavblad',),
'lavblada': ('lavblad',),
'lavbladene': ('lavblad',),
'lavblader': ('lavblad',),
'lavbladet': ('lavblad',),
'lavblokk': ('lavblokk',),
'lavblokka': ('lavblokk',),
'lavblokken': ('lavblokk',),
'lavblokkene': ('lavblokk',),
'lavblokker': ('lavblokk',),
'lavbygg': ('lavbygg',),
'lavbygga': ('lavbygg',),
'lavbyggene': ('lavbygg',),
'lavbygget': ('lavbygg',),
'lavement': ('lavement',),
'lavementa': ('lavement',),
'lavementene': ('lavement',),
'lavementer': ('lavement',),
'lavementet': ('lavement',),
'lavendel': ('lavendel',),
'lavendelen': ('lavendel',),
'lavendlene': ('lavendel',),
'lavendler': ('lavendel',),
'lavendelolja': ('lavendelolje',),
'lavendelolje': ('lavendelolje',),
'lavendeloljen': ('lavendelolje',),
'lavendeloljene': ('lavendelolje',),
'lavendeloljer': ('lavendelolje',),
'lavett': ('lavett',),
'lavetten': ('lavett',),
'lavettene': ('lavett',),
'lavetter': ('lavett',),
'lavfrekvens': ('lavfrekvens',),
'lavfrekvensen': ('lavfrekvens',),
'lavfrekvensene': ('lavfrekvens',),
'lavfrekvenser': ('lavfrekvens',),
'lavgir': ('lavgir',),
'lavgira': ('lavgir',),
'lavgirene': ('lavgir',),
'lavgiret': ('lavgir',),
'lavhus': ('lavhus',),
'lavhusa': ('lavhus',),
'lavhusene': ('lavhus',),
'lavhuset': ('lavhus',),
'lavina': ('lavine',),
'lavine': ('lavine',),
'lavinen': ('lavine',),
'lavinene': ('lavine',),
'laviner': ('lavine',),
'lavinehund': ('lavinehund',),
'lavinehunden': ('lavinehund',),
'lavinehundene': ('lavinehund',),
'lavinehunder': ('lavinehund',),
'lavinntektsgruppa': ('lavinntektsgruppe',),
'lavinntektsgruppe': ('lavinntektsgruppe',),
'lavinntektsgruppen': ('lavinntektsgruppe',),
'lavinntektsgruppene': ('lavinntektsgruppe',),
'lavinntektsgrupper': ('lavinntektsgruppe',),
'lavkomikk': ('lavkomikk',),
'lavkomikken': ('lavkomikk',),
'lavkomikkene': ('lavkomikk',),
'lavkomikker': ('lavkomikk',),
'lavkonjunktur': ('lavkonjunktur',),
'lavkonjunkturen': ('lavkonjunktur',),
'lavkonjunkturene': ('lavkonjunktur',),
'lavkonjunkturer': ('lavkonjunktur',),
'lavkostland': ('lavkostland',),
'lavkostlanda': ('lavkostland',),
'lavkostlandene': ('lavkostland',),
'lavkostlandet': ('lavkostland',),
'lavland': ('lavland',),
'lavlanda': ('lavland',),
'lavlandene': ('lavland',),
'lavlandet': ('lavland',),
'lavlandsbane': ('lavlandsbane',),
'lavlandsbanen': ('lavlandsbane',),
'lavlandsbanene': ('lavlandsbane',),
'lavlandsbaner': ('lavlandsbane',),
'lavlandsbjerk': ('lavlandsbjerk',),
'lavlandsbjerka': ('lavlandsbjerk',),
'lavlandsbjerken': ('lavlandsbjerk',),
'lavlandsbjerkene': ('lavlandsbjerk',),
'lavlandsbjerker': ('lavlandsbjerk',),
'lavlandsbjørk': ('lavlandsbjørk',),
'lavlandsbjørka': ('lavlandsbjørk',),
'lavlandsbjørken': ('lavlandsbjørk',),
'lavlandsbjørkene': ('lavlandsbjørk',),
'lavlandsbjørker': ('lavlandsbjørk',),
'lavlenda': ('lavlende',),
'lavlende': ('lavlende',),
'lavlendene': ('lavlende',),
'lavlendet': ('lavlende',),
'lavlender': ('lavlender',),
'lavlendere': ('lavlender',),
'lavlenderen': ('lavlender',),
'lavlenderer': ('lavlender',),
'lavlenderne': ('lavlender',),
'lavlending': ('lavlending',),
'lavlendingen': ('lavlending',),
'lavlendingene': ('lavlending',),
'lavlendinger': ('lavlending',),
'lavlønnsfond': ('lavlønnsfond',),
'lavlønnsfonda': ('lavlønnsfond',),
'lavlønnsfondene': ('lavlønnsfond',),
'lavlønnsfondet': ('lavlønnsfond',),
'lavlønnsgruppa': ('lavlønnsgruppe',),
'lavlønnsgruppe': ('lavlønnsgruppe',),
'lavlønnsgruppen': ('lavlønnsgruppe',),
'lavlønnsgruppene': ('lavlønnsgruppe',),
'lavlønnsgrupper': ('lavlønnsgruppe',),
'lavlønnstillegg': ('lavlønnstillegg',),
'lavlønnstillegga': ('lavlønnstillegg',),
'lavlønnstilleggene': ('lavlønnstillegg',),
'lavlønnstillegget': ('lavlønnstillegg',),
'lavlønnsyrka': ('lavlønnsyrke',),
'lavlønnsyrke': ('lavlønnsyrke',),
'lavlønnsyrkene': ('lavlønnsyrke',),
'lavlønnsyrker': ('lavlønnsyrke',),
'lavlønnsyrket': ('lavlønnsyrke',),
'lavmål': ('lavmål',),
'lavmåla': ('lavmål',),
'lavmålene': ('lavmål',),
'lavmålet': ('lavmål',),
'lavnivåspråk': ('lavnivåspråk',),
'lavnivåspråka': ('lavnivåspråk',),
'lavnivåspråkene': ('lavnivåspråk',),
'lavnivåspråket': ('lavnivåspråk',),
'lavoktan': ('lavoktan',),
'lavoktanen': ('lavoktan',),
'lavoktanene': ('lavoktan',),
'lavoktaner': ('lavoktan',),
'lavoktan': ('lavoktan',),
'lavoktana': ('lavoktan',),
'lavoktanene': ('lavoktan',),
'lavoktaner': ('lavoktan',),
'lavoktanet': ('lavoktan',),
'lavoktanbensin': ('lavoktanbensin',),
'lavoktanbensinen': ('lavoktanbensin',),
'lavoktanbensinene': ('lavoktanbensin',),
'lavoktanbensiner': ('lavoktanbensin',),
'lavpris': ('lavpris',),
'lavprisen': ('lavpris',),
'lavprisene': ('lavpris',),
'lavpriser': ('lavpris',),
'lavprisbutikk': ('lavprisbutikk',),
'lavprisbutikken': ('lavprisbutikk',),
'lavprisbutikkene': ('lavprisbutikk',),
'lavprisbutikker': ('lavprisbutikk',),
'lavprosa': ('lavprosa',),
'lavprosaen': ('lavprosa',),
'lavprosaene': ('lavprosa',),
'lavprosaer': ('lavprosa',),
'lavsesong': ('lavsesong',),
'lavsesongen': ('lavsesong',),
'lavsesongene': ('lavsesong',),
'lavsesonger': ('lavsesong',),
'lavskrika': ('lavskrike',),
'lavskrike': ('lavskrike',),
'lavskriken': ('lavskrike',),
'lavskrikene': ('lavskrike',),
'lavskriker': ('lavskrike',),
'lavsletta': ('lavslette',),
'lavslette': ('lavslette',),
'lavsletten': ('lavslette',),
'lavslettene': ('lavslette',),
'lavsletter': ('lavslette',),
'lavspenning': ('lavspenning',),
'lavspenninga': ('lavspenning',),
'lavspenningen': ('lavspenning',),
'lavspenningene': ('lavspenning',),
'lavspenninger': ('lavspenning',),
'lavspentledning': ('lavspentledning',),
'lavspentledninga': ('lavspentledning',),
'lavspentledningen': ('lavspentledning',),
'lavspentledningene': ('lavspentledning',),
'lavspentledninger': ('lavspentledning',),
'lavspentmast': ('lavspentmast',),
'lavspentmasta': ('lavspentmast',),
'lavspentmasten': ('lavspentmast',),
'lavspentmastene': ('lavspentmast',),
'lavspentmaster': ('lavspentmast',),
'lavspentnett': ('lavspentnett',),
'lavspentnetta': ('lavspentnett',),
'lavspentnettene': ('lavspentnett',),
'lavspentnettet': ('lavspentnett',),
'lavstatusgruppa': ('lavstatusgruppe',),
'lavstatusgruppe': ('lavstatusgruppe',),
'lavstatusgruppen': ('lavstatusgruppe',),
'lavstatusgruppene': ('lavstatusgruppe',),
'lavstatusgrupper': ('lavstatusgruppe',),
'lavstatusyrka': ('lavstatusyrke',),
'lavstatusyrke': ('lavstatusyrke',),
'lavstatusyrkene': ('lavstatusyrke',),
'lavstatusyrker': ('lavstatusyrke',),
'lavstatusyrket': ('lavstatusyrke',),
'lavtone': ('lavtone',),
'lavtonen': ('lavtone',),
'lavtonene': ('lavtone',),
'lavtoner': ('lavtone',),
'lavtrykk': ('lavtrykk',),
'lavtrykka': ('lavtrykk',),
'lavtrykkene': ('lavtrykk',),
'lavtrykket': ('lavtrykk',),
'lavtrykksområda': ('lavtrykksområde',),
'lavtrykksområde': ('lavtrykksområde',),
'lavtrykksområdene': ('lavtrykksområde',),
'lavtrykksområder': ('lavtrykksområde',),
'lavtrykksområdet': ('lavtrykksområde',),
'lavtrykkssentra': ('lavtrykkssentrum',),
'lavtrykkssentraene': ('lavtrykkssentrum',),
'lavtrykkssentre': ('lavtrykkssentrum',),
'lavtrykkssentrene': ('lavtrykkssentrum',),
'lavtrykkssentret': ('lavtrykkssentrum',),
'lavtrykkssentrum': ('lavtrykkssentrum',),
'lavtrykkssentrumet': ('lavtrykkssentrum',),
'lavtysk': ('lavtysk',),
'lavtysken': ('lavtysk',),
'lavtyskene': ('lavtysk',),
'lavtysker': ('lavtysk',),
'lavvann': ('lavvann',),
'lavvanna': ('lavvann',),
'lavvannene': ('lavvann',),
'lavvannet': ('lavvann',),
'lavvatn': ('lavvatn',),
'lavvatna': ('lavvatn',),
'lavvatnene': ('lavvatn',),
'lavvatnet': ('lavvatn',),
'lavvo': ('lavvo',),
'lavvoen': ('lavvo',),
'lavvoene': ('lavvo',),
'lavvoer': ('lavvo',),
'lawrencium': ('lawrencium',),
'lawrenciuma': ('lawrencium',),
'lawrenciumene': ('lawrencium',),
'lawrenciumet': ('lawrencium',),
'layout': ('layout',),
'layouten': ('layout',),
'layoutene': ('layout',),
'layouter': ('layout',),
'layouter': ('layouter',),
'layoutere': ('layouter',),
'layouteren': ('layouter',),
'layouterer': ('layouter',),
'layouterne': ('layouter',),
'layoutmedarbeider': ('layoutmedarbeider',),
'layoutmedarbeidere': ('layoutmedarbeider',),
'layoutmedarbeideren': ('layoutmedarbeider',),
'layoutmedarbeiderer': ('layoutmedarbeider',),
'layoutmedarbeiderne': ('layoutmedarbeider',),
'le': ('le',),
'lea': ('le',),
'leene': ('le',),
'leet': ('le',),
'leamus': ('leamus',),
'leamusa': ('leamus',),
'leamusen': ('leamus',),
'leamusene': ('leamus',),
'leamuser': ('leamus',),
'leasing': ('leasing',),
'leasingen': ('leasing',),
'leasingene': ('leasing',),
'leasinger': ('leasing',),
'leasingkontrakt': ('leasingkontrakt',),
'leasingkontrakten': ('leasingkontrakt',),
'leasingkontraktene': ('leasingkontrakt',),
'leasingkontrakter': ('leasingkontrakt',),
'leasingselskap': ('leasingselskap',),
'leasingselskapa': ('leasingselskap',),
'leasingselskapene': ('leasingselskap',),
'leasingselskaper': ('leasingselskap',),
'leasingselskapet': ('leasingselskap',),
'led': ('led',),
'leden': ('led',),
'ledene': ('led',),
'leder': ('led',),
'led': ('led',),
'leda': ('led',),
'ledene': ('led',),
'ledet': ('led',),
'ledbetennelse': ('ledbetennelse',),
'ledbetennelsen': ('ledbetennelse',),
'ledbetennelsene': ('ledbetennelse',),
'ledbetennelser': ('ledbetennelse',),
'ledbrott': ('ledbrott',),
'ledbrotta': ('ledbrott',),
'ledbrottene': ('ledbrott',),
'ledbrottet': ('ledbrott',),
'ledbrudd': ('ledbrudd',),
'ledbrudda': ('ledbrudd',),
'ledbruddene': ('ledbrudd',),
'ledbruddet': ('ledbrudd',),
'ledd': ('ledd',),
'ledda': ('ledd',),
'leddene': ('ledd',),
'leddet': ('ledd',),
'ledd-delsetning': ('ledd-delsetning',),
'ledd-delsetninga': ('ledd-delsetning',),
'ledd-delsetningen': ('ledd-delsetning',),
'ledd-delsetningene': ('ledd-delsetning',),
'ledd-delsetninger': ('ledd-delsetning',),
'ledd-dyr': ('ledd-dyr',),
'ledd-dyra': ('ledd-dyr',),
'ledd-dyrene': ('ledd-dyr',),
'ledd-dyret': ('ledd-dyr',),
'leddband': ('leddband',),
'leddbanda': ('leddband',),
'leddbandene': ('leddband',),
'leddbandet': ('leddband',),
'leddbandskade': ('leddbandskade',),
'leddbandskaden': ('leddbandskade',),
'leddbandskadene': ('leddbandskade',),
'leddbandskader': ('leddbandskade',),
'leddbandsskade': ('leddbandsskade',),
'leddbandsskaden': ('leddbandsskade',),
'leddbandsskadene': ('leddbandsskade',),
'leddbandsskader': ('leddbandsskade',),
'leddbetennelse': ('leddbetennelse',),
'leddbetennelsen': ('leddbetennelse',),
'leddbetennelsene': ('leddbetennelse',),
'leddbetennelser': ('leddbetennelse',),
'leddbrott': ('leddbrott',),
'leddbrotta': ('leddbrott',),
'leddbrottene': ('leddbrott',),
'leddbrottet': ('leddbrott',),
'leddbrudd': ('leddbrudd',),
'leddbrudda': ('leddbrudd',),
'leddbruddene': ('leddbrudd',),
'leddbruddet': ('leddbrudd',),
'leddbuss': ('leddbuss',),
'leddbussen': ('leddbuss',),
'leddbussene': ('leddbuss',),
'leddbusser': ('leddbuss',),
'leddbånd': ('leddbånd',),
'leddbånda': ('leddbånd',),
'leddbåndene': ('leddbånd',),
'leddbåndet': ('leddbånd',),
'leddbåndskade': ('leddbåndskade',),
'leddbåndskaden': ('leddbåndskade',),
'leddbåndskadene': ('leddbåndskade',),
'leddbåndskader': ('leddbåndskade',),
'leddbåndsskade': ('leddbåndsskade',),
'leddbåndsskaden': ('leddbåndsskade',),
'leddbåndsskadene': ('leddbåndsskade',),
'leddbåndsskader': ('leddbåndsskade',),
'leddelsetning': ('leddelsetning',),
'leddelsetninga': ('leddelsetning',),
'leddelsetningen': ('leddelsetning',),
'leddelsetningene': ('leddelsetning',),
'leddelsetninger': ('leddelsetning',),
'leddflata': ('leddflate',),
'leddflate': ('leddflate',),
'leddflaten': ('leddflate',),
'leddflatene': ('leddflate',),
'leddflater': ('leddflate',),
'leddgikt': ('leddgikt',),
'leddgikta': ('leddgikt',),
'leddgikten': ('leddgikt',),
'leddgiktene': ('leddgikt',),
'leddgikter': ('leddgikt',),
'leddhola': ('leddhole',),
'leddhole': ('leddhole',),
'leddholen': ('leddhole',),
'leddholene': ('leddhole',),
'leddholer': ('leddhole',),
'leddhula': ('leddhule',),
'leddhule': ('leddhule',),
'leddhulen': ('leddhule',),
'leddhulene': ('leddhule',),
'leddhuler': ('leddhule',),
'leddik': ('leddik',),
'leddiken': ('leddik',),
'leddikene': ('leddik',),
'leddiker': ('leddik',),
'leddkapsel': ('leddkapsel',),
'leddkapselen': ('leddkapsel',),
'leddkapslene': ('leddkapsel',),
'leddkapsler': ('leddkapsel',),
'leddmakk': ('leddmakk',),
'leddmakken': ('leddmakk',),
'leddmakkene': ('leddmakk',),
'leddmakker': ('leddmakk',),
'leddmark': ('leddmark',),
'leddmarken': ('leddmark',),
'leddmarkene': ('leddmark',),
'leddmarker': ('leddmark',),
'leddmus': ('leddmus',),
'leddmusa': ('leddmus',),
'leddmusen': ('leddmus',),
'leddmusene': ('leddmus',),
'leddmuser': ('leddmus',),
'leddorm': ('leddorm',),
'leddormen': ('leddorm',),
'leddormene': ('leddorm',),
'leddormer': ('leddorm',),
'leddsetning': ('leddsetning',),
'leddsetninga': ('leddsetning',),
'leddsetningen': ('leddsetning',),
'leddsetningene': ('leddsetning',),
'leddsetninger': ('leddsetning',),
'leddtrikk': ('leddtrikk',),
'leddtrikken': ('leddtrikk',),
'leddtrikkene': ('leddtrikk',),
'leddtrikker': ('leddtrikk',),
'leddvann': ('leddvann',),
'leddvanna': ('leddvann',),
'leddvannene': ('leddvann',),
'leddvannet': ('leddvann',),
'leddvatn': ('leddvatn',),
'leddvatna': ('leddvatn',),
'leddvatnene': ('leddvatn',),
'leddvatnet': ('leddvatn',),
'leddvæska': ('leddvæske',),
'leddvæske': ('leddvæske',),
'leddvæsken': ('leddvæske',),
'leddvæskene': ('leddvæske',),
'leddvæsker': ('leddvæske',),
'leddyr': ('leddyr',),
'leddyra': ('leddyr',),
'leddyrene': ('leddyr',),
'leddyret': ('leddyr',),
'lede': ('lede',),
'leden': ('lede',),
'ledene': ('lede',),
'leder': ('lede',),
'ledelse': ('ledelse',),
'ledelsen': ('ledelse',),
'ledelsene': ('ledelse',),
'ledelser': ('ledelse',),
'ledemot': ('ledemot',),
'ledemota': ('ledemot',),
'ledemotene': ('ledemot',),
'ledemotet': ('ledemot',),
'ledemotiv': ('ledemotiv',),
'ledemotiva': ('ledemotiv',),
'ledemotivene': ('ledemotiv',),
'ledemotiver': ('ledemotiv',),
'ledemotivet': ('ledemotiv',),
'leder': ('leder',),
'ledere': ('leder',),
'lederen': ('leder',),
'lederer': ('leder',),
'lederne': ('leder',),
'lederartikkel': ('lederartikkel',),
'lederartikkelen': ('lederartikkel',),
'lederartiklene': ('lederartikkel',),
'lederartikler': ('lederartikkel',),
'lederegenskap': ('lederegenskap',),
'lederegenskapen': ('lederegenskap',),
'lederegenskapene': ('lederegenskap',),
'lederegenskaper': ('lederegenskap',),
'lederplass': ('lederplass',),
'lederplassen': ('lederplass',),
'lederplassene': ('lederplass',),
'lederplasser': ('lederplass',),
'lederposisjon': ('lederposisjon',),
'lederposisjonen': ('lederposisjon',),
'lederposisjonene': ('lederposisjon',),
'lederposisjoner': ('lederposisjon',),
'ledersjikt': ('ledersjikt',),
'ledersjikta': ('ledersjikt',),
'ledersjiktene': ('ledersjikt',),
'ledersjiktet': ('ledersjikt',),
'lederskap': ('lederskap',),
'lederskapa': ('lederskap',),
'lederskapene': ('lederskap',),
'lederskapet': ('lederskap',),
'lederstilling': ('lederstilling',),
'lederstillinga': ('lederstilling',),
'lederstillingen': ('lederstilling',),
'lederstillingene': ('lederstilling',),
'lederstillinger': ('lederstilling',),
'ledertype': ('ledertype',),
'ledertypen': ('ledertype',),
'ledertypene': ('ledertype',),
'ledertyper': ('ledertype',),
'ledestjerna': ('ledestjerne',),
'ledestjerne': ('ledestjerne',),
'ledestjernen': ('ledestjerne',),
'ledestjernene': ('ledestjerne',),
'ledestjerner': ('ledestjerne',),
'ledetråd': ('ledetråd',),
'ledetråden': ('ledetråd',),
'ledetrådene': ('ledetråd',),
'ledetråder': ('ledetråd',),
'lediggang': ('lediggang',),
'lediggangen': ('lediggang',),
'lediggangene': ('lediggang',),
'ledigganger': ('lediggang',),
'ledighet': ('ledighet',),
'ledigheta': ('ledighet',),
'ledigheten': ('ledighet',),
'ledighetene': ('ledighet',),
'ledigheter': ('ledighet',),
'ledning': ('ledning',),
'ledninga': ('ledning',),
'ledningen': ('ledning',),
'ledningene': ('ledning',),
'ledninger': ('ledning',),
'ledningskart': ('ledningskart',),
'ledningskarta': ('ledningskart',),
'ledningskartene': ('ledningskart',),
'ledningskarter': ('ledningskart',),
'ledningskartet': ('ledningskart',),
'ledningsnett': ('ledningsnett',),
'ledningsnetta': ('ledningsnett',),
'ledningsnettene': ('ledningsnett',),
'ledningsnettet': ('ledningsnett',),
'ledningsstreng': ('ledningsstreng',),
'ledningsstrengen': ('ledningsstreng',),
'ledningsstrengene': ('ledningsstreng',),
'ledningsstrenger': ('ledningsstreng',),
'ledningsvev': ('ledningsvev',),
'ledningsveva': ('ledningsvev',),
'ledningsvevene': ('ledningsvev',),
'ledningsvevet': ('ledningsvev',),
'ledsager': ('ledsager',),
'ledsagere': ('ledsager',),
'ledsageren': ('ledsager',),
'ledsagerer': ('ledsager',),
'ledsagerne': ('ledsager',),
'ledtog': ('ledtog',),
'ledtoga': ('ledtog',),
'ledtogene': ('ledtog',),
'ledtoget': ('ledtog',),
'lefsa': ('lefse',),
'lefse': ('lefse',),
'lefsen': ('lefse',),
'lefsene': ('lefse',),
'lefser': ('lefse',),
'lefsekling': ('lefsekling',),
'lefseklingen': ('lefsekling',),
'lefseklingene': ('lefsekling',),
'lefseklinger': ('lefsekling',),
'lefseklining': ('lefseklining',),
'lefseklininga': ('lefseklining',),
'lefsekliningen': ('lefseklining',),
'lefsekliningene': ('lefseklining',),
'lefseklininger': ('lefseklining',),
'legalitet': ('legalitet',),
'legaliteten': ('legalitet',),
'legalitetene': ('legalitet',),
'legaliteter': ('legalitet',),
'legasjon': ('legasjon',),
'legasjonen': ('legasjon',),
'legasjonene': ('legasjon',),
'legasjoner': ('legasjon',),
'legasjonsråd': ('legasjonsråd',),
'legasjonsråden': ('legasjonsråd',),
'legasjonsrådene': ('legasjonsråd',),
'legasjonsråder': ('legasjonsråd',),
'legat': ('legat',),
'legaten': ('legat',),
'legatene': ('legat',),
'legater': ('legat',),
'legat': ('legat',),
'legata': ('legat',),
'legatene': ('legat',),
'legater': ('legat',),
'legatet': ('legat',),
'legatar': ('legatar',),
'legataren': ('legatar',),
'legatarene': ('legatar',),
'legatarer': ('legatar',),
'legatmiddel': ('legatmiddel',),
'legatmiddelet': ('legatmiddel',),
'legatmidla': ('legatmiddel',),
'legatmidlene': ('legatmiddel',),
'legatmidler': ('legatmiddel',),
'legatmidlet': ('legatmiddel',),
'legatmidler': ('legatmidler',),
'legatmidlere': ('legatmidler',),
'legatmidleren': ('legatmidler',),
'legatmidlerer': ('legatmidler',),
'legatmidlerne': ('legatmidler',),
'legato': ('legato',),
'legatoa': ('legato',),
'legatoene': ('legato',),
'legatoer': ('legato',),
'legatoet': ('legato',),
'legbror': ('legbror',),
'legbroren': ('legbror',),
'legbrødre': ('legbror',),
'legbrødrene': ('legbror',),
'legd': ('legd',),
'legda': ('legd',),
'legden': ('legd',),
'legdene': ('legd',),
'legder': ('legd',),
'legd': ('legd',),
'legda': ('legd',),
'legden': ('legd',),
'legdene': ('legd',),
'legder': ('legd',),
'legda': ('legde',),
'legde': ('legde',),
'legden': ('legde',),
'legdene': ('legde',),
'legder': ('legde',),
'legdefolk': ('legdefolk',),
'legdefolka': ('legdefolk',),
'legdefolkene': ('legdefolk',),
'legdefolket': ('legdefolk',),
'legdekall': ('legdekall',),
'legdekallen': ('legdekall',),
'legdekallene': ('legdekall',),
'legdekaller': ('legdekall',),
'legdekjerring': ('legdekjerring',),
'legdekjerringa': ('legdekjerring',),
'legdekjerringen': ('legdekjerring',),
'legdekjerringene': ('legdekjerring',),
'legdekjerringer': ('legdekjerring',),
'legdfolk': ('legdfolk',),
'legdfolka': ('legdfolk',),
'legdfolkene': ('legdfolk',),
'legdfolket': ('legdfolk',),
'legdkall': ('legdkall',),
'legdkallen': ('legdkall',),
'legdkallene': ('legdkall',),
'legdkaller': ('legdkall',),
'legdkjerring': ('legdkjerring',),
'legdkjerringa': ('legdkjerring',),
'legdkjerringen': ('legdkjerring',),
'legdkjerringene': ('legdkjerring',),
'legdkjerringer': ('legdkjerring',),
'legdommer': ('legdommer',),
'legdommere': ('legdommer',),
'legdommeren': ('legdommer',),
'legdommerer': ('legdommer',),
'legdommerne': ('legdommer',),
'legdsfolk': ('legdsfolk',),
'legdsfolka': ('legdsfolk',),
'legdsfolkene': ('legdsfolk',),
'legdsfolket': ('legdsfolk',),
'legdskall': ('legdskall',),
'legdskallen': ('legdskall',),
'legdskallene': ('legdskall',),
'legdskaller': ('legdskall',),
'legdskjerring': ('legdskjerring',),
'legdskjerringa': ('legdskjerring',),
'legdskjerringen': ('legdskjerring',),
'legdskjerringene': ('legdskjerring',),
'legdskjerringer': ('legdskjerring',),
'lege': ('lege',),
'legen': ('lege',),
'legene': ('lege',),
'leger': ('lege',),
'legeambulanse': ('legeambulanse',),
'legeambulansen': ('legeambulanse',),
'legeambulansene': ('legeambulanse',),
'legeambulanser': ('legeambulanse',),
'legeattest': ('legeattest',),
'legeattesten': ('legeattest',),
'legeattestene': ('legeattest',),
'legeattester': ('legeattest',),
'legebehandling': ('legebehandling',),
'legebehandlinga': ('legebehandling',),
'legebehandlingen': ('legebehandling',),
'legebehandlingene': ('legebehandling',),
'legebehandlinger': ('legebehandling',),
'legedom': ('legedom',),
'legedommen': ('legedom',),
'legedommene': ('legedom',),
'legedommer': ('legedom',),
'legeerklæring': ('legeerklæring',),
'legeerklæringa': ('legeerklæring',),
'legeerklæringen': ('legeerklæring',),
'legeerklæringene': ('legeerklæring',),
'legeerklæringer': ('legeerklæring',),
'legehjelp': ('legehjelp',),
'legehjelpa': ('legehjelp',),
'legehjelpen': ('legehjelp',),
'legehjelpene': ('legehjelp',),
'legehjelper': ('legehjelp',),
'legehonorar': ('legehonorar',),
'legehonorara': ('legehonorar',),
'legehonorarene': ('legehonorar',),
'legehonorarer': ('legehonorar',),
'legehonoraret': ('legehonorar',),
'legema': ('legeme',),
'legeme': ('legeme',),
'legemene': ('legeme',),
'legemer': ('legeme',),
'legemet': ('legeme',),
'legemiddel': ('legemiddel',),
'legemiddelet': ('legemiddel',),
'legemidla': ('legemiddel',),
'legemidlene': ('legemiddel',),
'legemidler': ('legemiddel',),
'legemidlet': ('legemiddel',),
'legemsbeskadigelse': ('legemsbeskadigelse',),
'legemsbeskadigelsen': ('legemsbeskadigelse',),
'legemsbeskadigelsene': ('legemsbeskadigelse',),
'legemsbeskadigelser': ('legemsbeskadigelse',),
'legemsbygning': ('legemsbygning',),
'legemsbygninga': ('legemsbygning',),
'legemsbygningen': ('legemsbygning',),
'legemsbygningene': ('legemsbygning',),
'legemsbygninger': ('legemsbygning',),
'legemsdel': ('legemsdel',),
'legemsdelen': ('legemsdel',),
'legemsdelene': ('legemsdel',),
'legemsdeler': ('legemsdel',),
'legemsfornærmelse': ('legemsfornærmelse',),
'legemsfornærmelsen': ('legemsfornærmelse',),
'legemsfornærmelsene': ('legemsfornærmelse',),
'legemsfornærmelser': ('legemsfornærmelse',),
'legemsskade': ('legemsskade',),
'legemsskaden': ('legemsskade',),
'legemsskadene': ('legemsskade',),
'legemsskader': ('legemsskade',),
'legende': ('legende',),
'legenden': ('legende',),
'legendene': ('legende',),
'legender': ('legende',),
'legering': ('legering',),
'legeringa': ('legering',),
'legeringen': ('legering',),
'legeringene': ('legering',),
'legeringer': ('legering',),
'legeråd': ('legeråd',),
'legeråda': ('legeråd',),
'legeråden': ('legeråd',),
'legerådene': ('legeråd',),
'legeråder': ('legeråd',),
'legerådet': ('legeråd',),
'legeråd': ('legeråd',),
'legeråda': ('legeråd',),
'legerådene': ('legeråd',),
'legerådet': ('legeråd',),
'legesekretær': ('legesekretær',),
'legesekretæren': ('legesekretær',),
'legesekretærene': ('legesekretær',),
'legesekretærer': ('legesekretær',),
'legesenter': ('legesenter',),
'legesenteret': ('legesenter',),
'legesentra': ('legesenter',),
'legesentre': ('legesenter',),
'legesentrene': ('legesenter',),
'legesentret': ('legesenter',),
'legestand': ('legestand',),
'legestanden': ('legestand',),
'legestandene': ('legestand',),
'legestander': ('legestand',),
'legetilsyn': ('legetilsyn',),
'legetilsyna': ('legetilsyn',),
'legetilsynene': ('legetilsyn',),
'legetilsynet': ('legetilsyn',),
'legevakt': ('legevakt',),
'legevakta': ('legevakt',),
'legevakten': ('legevakt',),
'legevaktene': ('legevakt',),
'legevakter': ('legevakt',),
'legevisitt': ('legevisitt',),
'legevisitten': ('legevisitt',),
'legevisittene': ('legevisitt',),
'legevisitter': ('legevisitt',),
'legevitenskap': ('legevitenskap',),
'legevitenskapen': ('legevitenskap',),
'legevitenskapene': ('legevitenskap',),
'legevitenskaper': ('legevitenskap',),
'legevitskap': ('legevitskap',),
'legevitskapen': ('legevitskap',),
'legevitskapene': ('legevitskap',),
'legevitskaper': ('legevitskap',),
'legg': ('legg',),
'legga': ('legg',),
'leggene': ('legg',),
'legget': ('legg',),
'leggbein': ('leggbein',),
'leggbeina': ('leggbein',),
'leggbeinene': ('leggbein',),
'leggbeinet': ('leggbein',),
'leggben': ('leggben',),
'leggbena': ('leggben',),
'leggbenene': ('leggben',),
'leggbenet': ('leggben',),
'leggbeskytter': ('leggbeskytter',),
'leggbeskyttere': ('leggbeskytter',),
'leggbeskytteren': ('leggbeskytter',),
'leggbeskytterer': ('leggbeskytter',),
'leggbeskytterne': ('leggbeskytter',),
'leggebein': ('leggebein',),
'leggebeina': ('leggebein',),
'leggebeinene': ('leggebein',),
'leggebeinet': ('leggebein',),
'leggeben': ('leggeben',),
'leggebena': ('leggeben',),
'leggebenene': ('leggeben',),
'leggebenet': ('leggeben',),
'leggebeskytter': ('leggebeskytter',),
'leggebeskyttere': ('leggebeskytter',),
'leggebeskytteren': ('leggebeskytter',),
'leggebeskytterer': ('leggebeskytter',),
'leggebeskytterne': ('leggebeskytter',),
'leggekrampe': ('leggekrampe',),
'leggekrampen': ('leggekrampe',),
'leggekrampene': ('leggekrampe',),
'leggekramper': ('leggekrampe',),
'legger': ('legger',),
'leggere': ('legger',),
'leggeren': ('legger',),
'leggerer': ('legger',),
'leggerne': ('legger',),
'leggesår': ('leggesår',),
'leggesåra': ('leggesår',),
'leggesårene': ('leggesår',),
'leggesåret': ('leggesår',),
'leggetid': ('leggetid',),
'leggetida': ('leggetid',),
'leggetiden': ('leggetid',),
'leggetidene': ('leggetid',),
'leggetider': ('leggetid',),
'leggevann': ('leggevann',),
'leggevanna': ('leggevann',),
'leggevannene': ('leggevann',),
'leggevannet': ('leggevann',),
'leggevatn': ('leggevatn',),
'leggevatna': ('leggevatn',),
'leggevatnene': ('leggevatn',),
'leggevatnet': ('leggevatn',),
'leggings': ('leggings',),
'leggingsene': ('leggings',),
'leggkrampe': ('leggkrampe',),
'leggkrampen': ('leggkrampe',),
'leggkrampene': ('leggkrampe',),
'leggkramper': ('leggkrampe',),
'leggsår': ('leggsår',),
'leggsåra': ('leggsår',),
'leggsårene': ('leggsår',),
'leggsåret': ('leggsår',),
'legio': ('legio',),
'legion': ('legion',),
'legionen': ('legion',),
'legionene': ('legion',),
'legioner': ('legion',),
'legionær': ('legionær',),
'legionæren': ('legionær',),
'legionærene': ('legionær',),
'legionærer': ('legionær',),
'legitimasjon': ('legitimasjon',),
'legitimasjonen': ('legitimasjon',),
'legitimasjonene': ('legitimasjon',),
'legitimasjoner': ('legitimasjon',),
'legitimasjonskort': ('legitimasjonskort',),
'legitimasjonskorta': ('legitimasjonskort',),
'legitimasjonskortene': ('legitimasjonskort',),
'legitimasjonskortet': ('legitimasjonskort',),
'legitimasjonspapir': ('legitimasjonspapir',),
'legitimasjonspapira': ('legitimasjonspapir',),
'legitimasjonspapirene': ('legitimasjonspapir',),
'legitimasjonspapirer': ('legitimasjonspapir',),
'legitimasjonspapiret': ('legitimasjonspapir',),
'legitimitet': ('legitimitet',),
'legitimiteten': ('legitimitet',),
'legitimitetene': ('legitimitet',),
'legitimiteter': ('legitimitet',),
'legmann': ('legmann',),
'legmannen': ('legmann',),
'legmenn': ('legmann',),
'legmennene': ('legmann',),
'legmannsbevegelse': ('legmannsbevegelse',),
'legmannsbevegelsen': ('legmannsbevegelse',),
'legmannsbevegelsene': ('legmannsbevegelse',),
'legmannsbevegelser': ('legmannsbevegelse',),
'legmannsforkynnelse': ('legmannsforkynnelse',),
'legmannsforkynnelsen': ('legmannsforkynnelse',),
'legmannsforkynnelsene': ('legmannsforkynnelse',),
'legmannsforkynnelser': ('legmannsforkynnelse',),
'legning': ('legning',),
'legninga': ('legning',),
'legningen': ('legning',),
'legningene': ('legning',),
'legninger': ('legning',),
'legpredikant': ('legpredikant',),
'legpredikanten': ('legpredikant',),
'legpredikantene': ('legpredikant',),
'legpredikanter': ('legpredikant',),
'lei': ('lei',),
'leien': ('lei',),
'leiene': ('lei',),
'lei': ('lei',),
'leia': ('lei',),
'leien': ('lei',),
'leiene': ('lei',),
'leier': ('lei',),
'leicestersau': ('leicestersau',),
'leicestersauen': ('leicestersau',),
'leicestersauene': ('leicestersau',),
'leicestersauer': ('leicestersau',),
'leidang': ('leidang',),
'leidangen': ('leidang',),
'leidangene': ('leidang',),
'leidanger': ('leidang',),
'leida': ('leide',),
'leide': ('leide',),
'leidene': ('leide',),
'leider': ('leide',),
'leidet': ('leide',),
'leidebrev': ('leidebrev',),
'leidebreva': ('leidebrev',),
'leidebrevene': ('leidebrev',),
'leidebrever': ('leidebrev',),
'leidebrevet': ('leidebrev',),
'leider': ('leider',),
'leidere': ('leider',),
'leideren': ('leider',),
'leiderer': ('leider',),
'leiderne': ('leider',),
'leia': ('leie',),
'leie': ('leie',),
'leiene': ('leie',),
'leier': ('leie',),
'leiet': ('leie',),
'leieavtale': ('leieavtale',),
'leieavtalen': ('leieavtale',),
'leieavtalene': ('leieavtale',),
'leieavtaler': ('leieavtale',),
'leiebil': ('leiebil',),
'leiebilen': ('leiebil',),
'leiebilene': ('leiebil',),
'leiebiler': ('leiebil',),
'leieboer': ('leieboer',),
'leieboere': ('leieboer',),
'leieboeren': ('leieboer',),
'leieboerer': ('leieboer',),
'leieboerne': ('leieboer',),
'leiebuer': ('leiebuer',),
'leiebuere': ('leiebuer',),
'leiebueren': ('leiebuer',),
'leiebuerer': ('leiebuer',),
'leiebuerne': ('leiebuer',),
'leiegård': ('leiegård',),
'leiegården': ('leiegård',),
'leiegårdene': ('leiegård',),
'leiegårder': ('leiegård',),
'leiekontrakt': ('leiekontrakt',),
'leiekontrakten': ('leiekontrakt',),
'leiekontraktene': ('leiekontrakt',),
'leiekontrakter': ('leiekontrakt',),
'leier': ('leier',),
'leiere': ('leier',),
'leieren': ('leier',),
'leierer': ('leier',),
'leierne': ('leier',),
'leier': ('leier',),
'leiere': ('leier',),
'leieren': ('leier',),
'leierer': ('leier',),
'leierne': ('leier',),
'leiesoldat': ('leiesoldat',),
'leiesoldaten': ('leiesoldat',),
'leiesoldatene': ('leiesoldat',),
'leiesoldater': ('leiesoldat',),
'leiesøker': ('leiesøker',),
'leiesøkere': ('leiesøker',),
'leiesøkeren': ('leiesøker',),
'leiesøkerer': ('leiesøker',),
'leiesøkerne': ('leiesøker',),
'leietaker': ('leietaker',),
'leietakere': ('leietaker',),
'leietakeren': ('leietaker',),
'leietakerer': ('leietaker',),
'leietakerne': ('leietaker',),
'leiing': ('leiing',),
'leiinga': ('leiing',),
'leiingen': ('leiing',),
'leiingene': ('leiing',),
'leiinger': ('leiing',),
'leik': ('leik',),
'leiken': ('leik',),
'leikene': ('leik',),
'leiker': ('leik',),
'leik': ('leik',),
'leiken': ('leik',),
'leikene': ('leik',),
'leiker': ('leik',),
'leikarring': ('leikarring',),
'leikarringen': ('leikarring',),
'leikarringene': ('leikarring',),
'leikarringer': ('leikarring',),
'leika': ('leike',),
'leike': ('leike',),
'leiken': ('leike',),
'leikene': ('leike',),
'leiker': ('leike',),
'leikefelt': ('leikefelt',),
'leikefelta': ('leikefelt',),
'leikefeltene': ('leikefelt',),
'leikefelter': ('leikefelt',),
'leikefeltet': ('leikefelt',),
'leikegrind': ('leikegrind',),
'leikegrinda': ('leikegrind',),
'leikegrinden': ('leikegrind',),
'leikegrindene': ('leikegrind',),
'leikegrinder': ('leikegrind',),
'leikekamerat': ('leikekamerat',),
'leikekameraten': ('leikekamerat',),
'leikekameratene': ('leikekamerat',),
'leikekamerater': ('leikekamerat',),
'leikeplass': ('leikeplass',),
'leikeplassen': ('leikeplass',),
'leikeplassene': ('leikeplass',),
'leikeplasser': ('leikeplass',),
'leiketøy': ('leiketøy',),
'leiketøya': ('leiketøy',),
'leiketøyene': ('leiketøy',),
'leiketøyer': ('leiketøy',),
'leiketøyet': ('leiketøy',),
'leikotek': ('leikotek',),
'leikoteka': ('leikotek',),
'leikotekene': ('leikotek',),
'leikoteker': ('leikotek',),
'leikoteket': ('leikotek',),
'leikotekar': ('leikotekar',),
'leikotekaren': ('leikotekar',),
'leikotekarene': ('leikotekar',),
'leikotekarer': ('leikotekar',),
'leilending': ('leilending',),
'leilendingen': ('leilending',),
'leilendingene': ('leilending',),
'leilendinger': ('leilending',),
'leilighet': ('leilighet',),
'leiligheta': ('leilighet',),
'leiligheten': ('leilighet',),
'leilighetene': ('leilighet',),
'leiligheter': ('leilighet',),
'leilighetsdikt': ('leilighetsdikt',),
'leilighetsdikta': ('leilighetsdikt',),
'leilighetsdiktene': ('leilighetsdikt',),
'leilighetsdiktet': ('leilighetsdikt',),
'leilighetsskyss': ('leilighetsskyss',),
'leilighetsskyssen': ('leilighetsskyss',),
'leilighetsskyssene': ('leilighetsskyss',),
'leilighetsskysser': ('leilighetsskyss',),
'leilighetstjuv': ('leilighetstjuv',),
'leilighetstjuven': ('leilighetstjuv',),
'leilighetstjuvene': ('leilighetstjuv',),
'leilighetstjuver': ('leilighetstjuv',),
'leilighetstyv': ('leilighetstyv',),
'leilighetstyven': ('leilighetstyv',),
'leilighetstyvene': ('leilighetstyv',),
'leilighetstyver': ('leilighetstyv',),
'leir': ('leir',),
'leiren': ('leir',),
'leirene': ('leir',),
'leirer': ('leir',),
'leir': ('leir',),
'leira': ('leir',),
'leirene': ('leir',),
'leiret': ('leir',),
'leir': ('leir',),
'leira': ('leir',),
'leirene': ('leir',),
'leiret': ('leir',),
'leirbakke': ('leirbakke',),
'leirbakken': ('leirbakke',),
'leirbakkene': ('leirbakke',),
'leirbakker': ('leirbakke',),
'leirbotn': ('leirbotn',),
'leirbotnen': ('leirbotn',),
'leirbotnene': ('leirbotn',),
'leirbotner': ('leirbotn',),
'leirbunn': ('leirbunn',),
'leirbunnen': ('leirbunn',),
'leirbunnene': ('leirbunn',),
'leirbunner': ('leirbunn',),
'leirbål': ('leirbål',),
'leirbåla': ('leirbål',),
'leirbålene': ('leirbål',),
'leirbålet': ('leirbål',),
'leirdua': ('leirdue',),
'leirdue': ('leirdue',),
'leirduen': ('leirdue',),
'leirduene': ('leirdue',),
'leirduer': ('leirdue',),
'leirdueskyting': ('leirdueskyting',),
'leirdueskytinga': ('leirdueskyting',),
'leirdueskytingen': ('leirdueskyting',),
'leirdueskytingene': ('leirdueskyting',),
'leirdueskytinger': ('leirdueskyting',),
'leira': ('leire',),
'leire': ('leire',),
'leiren': ('leire',),
'leirene': ('leire',),
'leirer': ('leire',),
'leira': ('leire',),
'leire': ('leire',),
'leiren': ('leire',),
'leirene': ('leire',),
'leirer': ('leire',),
'leirfall': ('leirfall',),
'leirfalla': ('leirfall',),
'leirfallene': ('leirfall',),
'leirfallet': ('leirfall',),
'leirfot': ('leirfot',),
'leirfoten': ('leirfot',),
'leirføttene': ('leirfot',),
'leirføtter': ('leirfot',),
'leirgauk': ('leirgauk',),
'leirgauken': ('leirgauk',),
'leirgaukene': ('leirgauk',),
'leirgauker': ('leirgauk',),
'leirgjøk': ('leirgjøk',),
'leirgjøken': ('leirgjøk',),
'leirgjøkene': ('leirgjøk',),
'leirgjøker': ('leirgjøk',),
'leirjord': ('leirjord',),
'leirjorda': ('leirjord',),
'leirjorden': ('leirjord',),
'leirjordene': ('leirjord',),
'leirjorder': ('leirjord',),
'leirmasse': ('leirmasse',),
'leirmassen': ('leirmasse',),
'leirmassene': ('leirmasse',),
'leirmasser': ('leirmasse',),
'leirplass': ('leirplass',),
'leirplassen': ('leirplass',),
'leirplassene': ('leirplass',),
'leirplasser': ('leirplass',),
'leirskole': ('leirskole',),
'leirskolen': ('leirskole',),
'leirskolene': ('leirskole',),
'leirskoler': ('leirskole',),
'leirskred': ('leirskred',),
'leirskreda': ('leirskred',),
'leirskredene': ('leirskred',),
'leirskredet': ('leirskred',),
'leist': ('leist',),
'leisten': ('leist',),
'leistene': ('leist',),
'leister': ('leist',),
'leist': ('leist',),
'leisten': ('leist',),
'leistene': ('leist',),
'leister': ('leist',),
'leit': ('leit',),
'leita': ('leite',),
'leite': ('leite',),
'leitene': ('leite',),
'leiter': ('leite',),
'leitet': ('leite',),
'leiteaksjon': ('leiteaksjon',),
'leiteaksjonen': ('leiteaksjon',),
'leiteaksjonene': ('leiteaksjon',),
'leiteaksjoner': ('leiteaksjon',),
'leitemannskap': ('leitemannskap',),
'leitemannskapa': ('leitemannskap',),
'leitemannskapene': ('leitemannskap',),
'leitemannskaper': ('leitemannskap',),
'leitemannskapet': ('leitemannskap',),
'leiter': ('leiter',),
'leitere': ('leiter',),
'leiteren': ('leiter',),
'leiterer': ('leiter',),
'leiterne': ('leiter',),
'leiv': ('leiv',),
'leiven': ('leiv',),
'leivene': ('leiv',),
'leiver': ('leiv',),
'lek': ('lek',),
'leken': ('lek',),
'lekene': ('lek',),
'leker': ('lek',),
'lekbror': ('lekbror',),
'lekbroren': ('lekbror',),
'lekbrødre': ('lekbror',),
'lekbrødrene': ('lekbror',),
'lekdommer': ('lekdommer',),
'lekdommere': ('lekdommer',),
'lekdommeren': ('lekdommer',),
'lekdommerer': ('lekdommer',),
'lekdommerne': ('lekdommer',),
'leka': ('leke',),
'leke': ('leke',),
'leken': ('leke',),
'lekene': ('leke',),
'leker': ('leke',),
'lekefelt': ('lekefelt',),
'lekefelta': ('lekefelt',),
'lekefeltene': ('lekefelt',),
'lekefelter': ('lekefelt',),
'lekefeltet': ('lekefelt',),
'lekegrind': ('lekegrind',),
'lekegrinda': ('lekegrind',),
'lekegrinden': ('lekegrind',),
'lekegrindene': ('lekegrind',),
'lekegrinder': ('lekegrind',),
'lekekamerat': ('lekekamerat',),
'lekekameraten': ('lekekamerat',),
'lekekameratene': ('lekekamerat',),
'lekekamerater': ('lekekamerat',),
'lekeplass': ('lekeplass',),
'lekeplassen': ('lekeplass',),
'lekeplassene': ('lekeplass',),
'lekeplasser': ('lekeplass',),
'leketøy': ('leketøy',),
'leketøya': ('leketøy',),
'leketøyene': ('leketøy',),
'leketøyer': ('leketøy',),
'leketøyet': ('leketøy',),
'lekk': ('lekk',),
'lekken': ('lekk',),
'lekkene': ('lekk',),
'lekker': ('lekk',),
'lekk': ('lekk',),
'lekken': ('lekk',),
'lekkene': ('lekk',),
'lekker': ('lekk',),
'lekkasje': ('lekkasje',),
'lekkasjen': ('lekkasje',),
'lekkasjene': ('lekkasje',),
'lekkasjer': ('lekkasje',),
'lekkerbisken': ('lekkerbisken',),
'lekkerbiskenen': ('lekkerbisken',),
'lekkerbiskenene': ('lekkerbisken',),
'lekkerbiskener': ('lekkerbisken',),
'lekkermunn': ('lekkermunn',),
'lekkermunnen': ('lekkermunn',),
'lekkermunnene': ('lekkermunn',),
'lekkermunner': ('lekkermunn',),
'lekmann': ('lekmann',),
'lekmannen': ('lekmann',),
'lekmenn': ('lekmann',),
'lekmennene': ('lekmann',),
'lekmannsbevegelse': ('lekmannsbevegelse',),
'lekmannsbevegelsen': ('lekmannsbevegelse',),
'lekmannsbevegelsene': ('lekmannsbevegelse',),
'lekmannsbevegelser': ('lekmannsbevegelse',),
'lekmannsforkynnelse': ('lekmannsforkynnelse',),
'lekmannsforkynnelsen': ('lekmannsforkynnelse',),
'lekmannsforkynnelsene': ('lekmannsforkynnelse',),
'lekmannsforkynnelser': ('lekmannsforkynnelse',),
'lekotek': ('lekotek',),
'lekoteka': ('lekotek',),
'lekotekene': ('lekotek',),
'lekoteker': ('lekotek',),
'lekoteket': ('lekotek',),
'lekotekar': ('lekotekar',),
'lekotekaren': ('lekotekar',),
'lekotekarene': ('lekotekar',),
'lekotekarer': ('lekotekar',),
'lekpredikant': ('lekpredikant',),
'lekpredikanten': ('lekpredikant',),
'lekpredikantene': ('lekpredikant',),
'lekpredikanter': ('lekpredikant',),
'leksa': ('lekse',),
'lekse': ('lekse',),
'leksen': ('lekse',),
'leksene': ('lekse',),
'lekser': ('lekse',),
'lekselesning': ('lekselesning',),
'lekselesninga': ('lekselesning',),
'lekselesningen': ('lekselesning',),
'lekselesningene': ('lekselesning',),
'lekselesninger': ('lekselesning',),
'leksikograf': ('leksikograf',),
'leksikografen': ('leksikograf',),
'leksikografene': ('leksikograf',),
'leksikografer': ('leksikograf',),
'leksikografi': ('leksikografi',),
'leksikografien': ('leksikografi',),
'leksikografiene': ('leksikografi',),
'leksikografier': ('leksikografi',),
'leksika': ('leksikon',),
'leksikaene': ('leksikon',),
'leksikon': ('leksikon',),
'leksikona': ('leksikon',),
'leksikonene': ('leksikon',),
'leksikoner': ('leksikon',),
'leksikonet': ('leksikon',),
'leksikonartikkel': ('leksikonartikkel',),
'leksikonartikkelen': ('leksikonartikkel',),
'leksikonartiklene': ('leksikonartikkel',),
'leksikonartikler': ('leksikonartikkel',),
'leksjon': ('leksjon',),
'leksjonen': ('leksjon',),
'leksjonene': ('leksjon',),
'leksjoner': ('leksjon',),
'lekt': ('lekt',),
'lekta': ('lekt',),
'lekten': ('lekt',),
'lektene': ('lekt',),
'lekter': ('lekt',),
'lekta': ('lekte',),
'lekte': ('lekte',),
'lekten': ('lekte',),
'lektene': ('lekte',),
'lekter': ('lekte',),
'lekter': ('lekter',),
'lektere': ('lekter',),
'lekteren': ('lekter',),
'lekterer': ('lekter',),
'lekterne': ('lekter',),
'lektie': ('lektie',),
'lektien': ('lektie',),
'lektiene': ('lektie',),
'lektier': ('lektie',),
'lektor': ('lektor',),
'lektoren': ('lektor',),
'lektorene': ('lektor',),
'lektorer': ('lektor',),
'lektorat': ('lektorat',),
'lektorata': ('lektorat',),
'lektoratene': ('lektorat',),
'lektorater': ('lektorat',),
'lektoratet': ('lektorat',),
'lektorstilling': ('lektorstilling',),
'lektorstillinga': ('lektorstilling',),
'lektorstillingen': ('lektorstilling',),
'lektorstillingene': ('lektorstilling',),
'lektorstillinger': ('lektorstilling',),
'lektyre': ('lektyre',),
'lektyren': ('lektyre',),
'lektyrene': ('lektyre',),
'lektyrer': ('lektyre',),
'lem': ('lem',),
'lemmen': ('lem',),
'lemmene': ('lem',),
'lemmer': ('lem',),
'lem': ('lem',),
'lemma': ('lem',),
'lemmene': ('lem',),
'lemmer': ('lem',),
'lemmet': ('lem',),
'lemen': ('lemen',),
'lemena': ('lemen',),
'lemenene': ('lemen',),
'lemener': ('lemen',),
'lemenet': ('lemen',),
'lemengris': ('lemengris',),
'lemengrisen': ('lemengris',),
'lemengrisene': ('lemengris',),
'lemengriser': ('lemengris',),
'lemenår': ('lemenår',),
'lemenåra': ('lemenår',),
'lemenårene': ('lemenår',),
'lemenåret': ('lemenår',),
'lemma': ('lemma',),
'lemmaene': ('lemma',),
'lemmaer': ('lemma',),
'lemmaet': ('lemma',),
'lempe': ('lempe',),
'lempen': ('lempe',),
'lempene': ('lempe',),
'lemper': ('lempe',),
'lempelse': ('lempelse',),
'lempelsen': ('lempelse',),
'lempelsene': ('lempelse',),
'lempelser': ('lempelse',),
'lempning': ('lempning',),
'lempninga': ('lempning',),
'lempningen': ('lempning',),
'lempningene': ('lempning',),
'lempninger': ('lempning',),
'lemus': ('lemus',),
'lemusa': ('lemus',),
'lemusen': ('lemus',),
'lemusene': ('lemus',),
'lemuser': ('lemus',),
'len': ('len',),
'lena': ('len',),
'lenene': ('len',),
'lenet': ('len',),
'lend': ('lend',),
'lenda': ('lend',),
'lenden': ('lend',),
'lendene': ('lend',),
'lender': ('lend',),
'lenda': ('lende',),
'lende': ('lende',),
'lendene': ('lende',),
'lender': ('lende',),
'lendet': ('lende',),
'lendekleda': ('lendeklede',),
'lendeklede': ('lendeklede',),
'lendekledene': ('lendeklede',),
'lendekleder': ('lendeklede',),
'lendekledet': ('lendeklede',),
'lendevirvel': ('lendevirvel',),
'lendevirvelen': ('lendevirvel',),
'lendevirvlene': ('lendevirvel',),
'lendevirvler': ('lendevirvel',),
'lendmann': ('lendmann',),
'lendmannen': ('lendmann',),
'lendmenn': ('lendmann',),
'lendmennene': ('lendmann',),
'lena': ('lene',),
'lene': ('lene',),
'lenene': ('lene',),
'lener': ('lene',),
'lenet': ('lene',),
'lenestol': ('lenestol',),
'lenestolen': ('lenestol',),
'lenestolene': ('lenestol',),
'lenestoler': ('lenestol',),
'lengd': ('lengd',),
'lengda': ('lengd',),
'lengden': ('lengd',),
'lengdene': ('lengd',),
'lengder': ('lengd',),
'lengda': ('lengde',),
'lengde': ('lengde',),
'lengden': ('lengde',),
'lengdene': ('lengde',),
'lengder': ('lengde',),
'lengde': ('lengde',),
'lengdegrad': ('lengdegrad',),
'lengdegraden': ('lengdegrad',),
'lengdegradene': ('lengdegrad',),
'lengdegrader': ('lengdegrad',),
'lengdehopp': ('lengdehopp',),
'lengdehoppa': ('lengdehopp',),
'lengdehoppene': ('lengdehopp',),
'lengdehoppet': ('lengdehopp',),
'lengdeløp': ('lengdeløp',),
'lengdeløpa': ('lengdeløp',),
'lengdeløpene': ('lengdeløp',),
'lengdeløpet': ('lengdeløp',),
'lengdeløper': ('lengdeløper',),
'lengdeløpere': ('lengdeløper',),
'lengdeløperen': ('lengdeløper',),
'lengdeløperer': ('lengdeløper',),
'lengdeløperne': ('lengdeløper',),
'lengdeløpsskøyta': ('lengdeløpsskøyte',),
'lengdeløpsskøyte': ('lengdeløpsskøyte',),
'lengdeløpsskøyten': ('lengdeløpsskøyte',),
'lengdeløpsskøytene': ('lengdeløpsskøyte',),
'lengdeløpsskøyter': ('lengdeløpsskøyte',),
'lengdeminutt': ('lengdeminutt',),
'lengdeminutta': ('lengdeminutt',),
'lengdeminuttene': ('lengdeminutt',),
'lengdeminutter': ('lengdeminutt',),
'lengdeminuttet': ('lengdeminutt',),
'lengderetning': ('lengderetning',),
'lengderetninga': ('lengderetning',),
'lengderetningen': ('lengderetning',),
'lengderetningene': ('lengderetning',),
'lengderetninger': ('lengderetning',),
'lengdesekund': ('lengdesekund',),
'lengdesekunda': ('lengdesekund',),
'lengdesekundene': ('lengdesekund',),
'lengdesekunder': ('lengdesekund',),
'lengdesekundet': ('lengdesekund',),
'lengdesirkel': ('lengdesirkel',),
'lengdesirkelen': ('lengdesirkel',),
'lengdesirklene': ('lengdesirkel',),
'lengdesirkler': ('lengdesirkel',),
'lengdesnitt': ('lengdesnitt',),
'lengdesnitta': ('lengdesnitt',),
'lengdesnittene': ('lengdesnitt',),
'lengdesnittet': ('lengdesnitt',),
'lenga': ('lenge',),
'lenge': ('lenge',),
'lengen': ('lenge',),
'lengene': ('lenge',),
'lenger': ('lenge',),
'lengsel': ('lengsel',),
'lengselen': ('lengsel',),
'lengslene': ('lengsel',),
'lengsler': ('lengsel',),
'lengt': ('lengt',),
'lengten': ('lengt',),
'lengtene': ('lengt',),
'lengter': ('lengt',),
'leninisme': ('leninisme',),
'leninismen': ('leninisme',),
'leninismene': ('leninisme',),
'leninismer': ('leninisme',),
'leninist': ('leninist',),
'leninisten': ('leninist',),
'leninistene': ('leninist',),
'leninister': ('leninist',),
'lenk': ('lenk',),
'lenken': ('lenk',),
'lenkene': ('lenk',),
'lenker': ('lenk',),
'lenka': ('lenke',),
'lenke': ('lenke',),
'lenken': ('lenke',),
'lenkene': ('lenke',),
'lenker': ('lenke',),
'lenning': ('lenning',),
'lenninga': ('lenning',),
'lenningen': ('lenning',),
'lenningene': ('lenning',),
'lenninger': ('lenning',),
'lens': ('lens',),
'lensen': ('lens',),
'lensene': ('lens',),
'lenser': ('lens',),
'lensadel': ('lensadel',),
'lensadelen': ('lensadel',),
'lensadlene': ('lensadel',),
'lensadler': ('lensadel',),
'lensa': ('lense',),
'lense': ('lense',),
'lensen': ('lense',),
'lensene': ('lense',),
'lenser': ('lense',),
'lenseport': ('lenseport',),
'lenseporten': ('lenseport',),
'lenseportene': ('lenseport',),
'lenseporter': ('lenseport',),
'lensepumpa': ('lensepumpe',),
'lensepumpe': ('lensepumpe',),
'lensepumpen': ('lensepumpe',),
'lensepumpene': ('lensepumpe',),
'lensepumper': ('lensepumpe',),
'lensherre': ('lensherre',),
'lensherren': ('lensherre',),
'lensherrene': ('lensherre',),
'lensherrer': ('lensherre',),
'lensmann': ('lensmann',),
'lensmannen': ('lensmann',),
'lensmenn': ('lensmann',),
'lensmennene': ('lensmann',),
'lensmannsbetjent': ('lensmannsbetjent',),
'lensmannsbetjenten': ('lensmannsbetjent',),
'lensmannsbetjentene': ('lensmannsbetjent',),
'lensmannsbetjenter': ('lensmannsbetjent',),
'lensmannsdistrikt': ('lensmannsdistrikt',),
'lensmannsdistrikta': ('lensmannsdistrikt',),
'lensmannsdistriktene': ('lensmannsdistrikt',),
'lensmannsdistrikter': ('lensmannsdistrikt',),
'lensmannsdistriktet': ('lensmannsdistrikt',),
'lensmannskontor': ('lensmannskontor',),
'lensmannskontora': ('lensmannskontor',),
'lensmannskontorene': ('lensmannskontor',),
'lensmannskontorer': ('lensmannskontor',),
'lensmannskontoret': ('lensmannskontor',),
'lensvesen': ('lensvesen',),
'lensvesena': ('lensvesen',),
'lensvesenene': ('lensvesen',),
'lensvesener': ('lensvesen',),
'lensvesenet': ('lensvesen',),
'leopard': ('leopard',),
'leoparden': ('leopard',),
'leopardene': ('leopard',),
'leoparder': ('leopard',),
'lepe': ('lepe',),
'lepen': ('lepe',),
'lepene': ('lepe',),
'leper': ('lepe',),
'lepeblomst': ('lepeblomst',),
'lepeblomsten': ('lepeblomst',),
'lepeblomstene': ('lepeblomst',),
'lepeblomster': ('lepeblomst',),
'lepeblomstfamilie': ('lepeblomstfamilie',),
'lepeblomstfamilien': ('lepeblomstfamilie',),
'lepeblomstfamiliene': ('lepeblomstfamilie',),
'lepeblomstfamilier': ('lepeblomstfamilie',),
'lepefisk': ('lepefisk',),
'lepefisken': ('lepefisk',),
'lepefiskene': ('lepefisk',),
'lepefisker': ('lepefisk',),
'leppa': ('leppe',),
'leppe': ('leppe',),
'leppen': ('leppe',),
'leppene': ('leppe',),
'lepper': ('leppe',),
'leppeblomst': ('leppeblomst',),
'leppeblomsten': ('leppeblomst',),
'leppeblomstene': ('leppeblomst',),
'leppeblomster': ('leppeblomst',),
'leppeblomstfamilie': ('leppeblomstfamilie',),
'leppeblomstfamilien': ('leppeblomstfamilie',),
'leppeblomstfamiliene': ('leppeblomstfamilie',),
'leppeblomstfamilier': ('leppeblomstfamilie',),
'leppefisk': ('leppefisk',),
'leppefisken': ('leppefisk',),
'leppefiskene': ('leppefisk',),
'leppefisker': ('leppefisk',),
'leppelyd': ('leppelyd',),
'leppelyden': ('leppelyd',),
'leppelydene': ('leppelyd',),
'leppelyder': ('leppelyd',),
'leppepomade': ('leppepomade',),
'leppepomaden': ('leppepomade',),
'leppepomadene': ('leppepomade',),
'leppepomader': ('leppepomade',),
'leppestift': ('leppestift',),
'leppestiften': ('leppestift',),
'leppestiftene': ('leppestift',),
'leppestifter': ('leppestift',),
'lepra': ('lepra',),
'lepraen': ('lepra',),
'lepraene': ('lepra',),
'lepraer': ('lepra',),
'leprabasill': ('leprabasill',),
'leprabasillen': ('leprabasill',),
'leprabasillene': ('leprabasill',),
'leprabasiller': ('leprabasill',),
'lepton': ('lepton',),
'leptona': ('lepton',),
'leptonene': ('lepton',),
'leptoner': ('lepton',),
'leptonet': ('lepton',),
'lerk': ('lerk',),
'lerken': ('lerk',),
'lerkene': ('lerk',),
'lerker': ('lerk',),
'lerka': ('lerke',),
'lerke': ('lerke',),
'lerken': ('lerke',),
'lerkene': ('lerke',),
'lerker': ('lerke',),
'lerka': ('lerke',),
'lerke': ('lerke',),
'lerken': ('lerke',),
'lerkene': ('lerke',),
'lerker': ('lerke',),
'lerketre': ('lerketre',),
'lerketrea': ('lerketre',),
'lerketreet': ('lerketre',),
'lerketrær': ('lerketre',),
'lerketrærne': ('lerketre',),
'lerret': ('lerret',),
'lerreta': ('lerret',),
'lerretene': ('lerret',),
'lerreter': ('lerret',),
'lerretet': ('lerret',),
'lerretsbinding': ('lerretsbinding',),
'lerretsbindinga': ('lerretsbinding',),
'lerretsbindingen': ('lerretsbinding',),
'lerretsbindingene': ('lerretsbinding',),
'lerretsbindinger': ('lerretsbinding',),
'lerretsskjorta': ('lerretsskjorte',),
'lerretsskjorte': ('lerretsskjorte',),
'lerretsskjorten': ('lerretsskjorte',),
'lerretsskjortene': ('lerretsskjorte',),
'lerretsskjorter': ('lerretsskjorte',),
'lesba': ('lesbe',),
'lesbe': ('lesbe',),
'lesben': ('lesbe',),
'lesbene': ('lesbe',),
'lesber': ('lesbe',),
'lesebok': ('lesebok',),
'leseboka': ('lesebok',),
'leseboken': ('lesebok',),
'lesebøkene': ('lesebok',),
'lesebøker': ('lesebok',),
'lesebrilla': ('lesebrille',),
'lesebrille': ('lesebrille',),
'lesebrillen': ('lesebrille',),
'lesebrillene': ('lesebrille',),
'lesebriller': ('lesebrille',),
'lesedrama': ('lesedrama',),
'lesedramaene': ('lesedrama',),
'lesedramaer': ('lesedrama',),
'lesedramaet': ('lesedrama',),
'leseferdighet': ('leseferdighet',),
'leseferdigheta': ('leseferdighet',),
'leseferdigheten': ('leseferdighet',),
'leseferdighetene': ('leseferdighet',),
'leseferdigheter': ('leseferdighet',),
'lesehest': ('lesehest',),
'lesehesten': ('lesehest',),
'lesehestene': ('lesehest',),
'lesehester': ('lesehest',),
'leselampa': ('leselampe',),
'leselampe': ('leselampe',),
'leselampen': ('leselampe',),
'leselampene': ('leselampe',),
'leselamper': ('leselampe',),
'lesemåte': ('lesemåte',),
'lesemåten': ('lesemåte',),
'lesemåtene': ('lesemåte',),
'lesemåter': ('lesemåte',),
'lesepenn': ('lesepenn',),
'lesepennen': ('lesepenn',),
'lesepennene': ('lesepenn',),
'lesepenner': ('lesepenn',),
'leseplikt': ('leseplikt',),
'leseplikta': ('leseplikt',),
'leseplikten': ('leseplikt',),
'lesepliktene': ('leseplikt',),
'leseplikter': ('leseplikt',),
'leseprøva': ('leseprøve',),
'leseprøve': ('leseprøve',),
'leseprøven': ('leseprøve',),
'leseprøvene': ('leseprøve',),
'leseprøver': ('leseprøve',),
'lesepult': ('lesepult',),
'lesepulten': ('lesepult',),
'lesepultene': ('lesepult',),
'lesepulter': ('lesepult',),
'leser': ('leser',),
'lesere': ('leser',),
'leseren': ('leser',),
'leserene': ('leser',),
'leserer': ('leser',),
'leserne': ('leser',),
'leserbrev': ('leserbrev',),
'leserbreva': ('leserbrev',),
'leserbrevene': ('leserbrev',),
'leserbrever': ('leserbrev',),
'leserbrevet': ('leserbrev',),
'leserinnlegg': ('leserinnlegg',),
'leserinnlegga': ('leserinnlegg',),
'leserinnleggene': ('leserinnlegg',),
'leserinnlegget': ('leserinnlegg',),
'leserkrets': ('leserkrets',),
'leserkretsen': ('leserkrets',),
'leserkretsene': ('leserkrets',),
'leserkretser': ('leserkrets',),
'lesesal': ('lesesal',),
'lesesalen': ('lesesal',),
'lesesalene': ('lesesal',),
'lesesaler': ('lesesal',),
'lesesirkel': ('lesesirkel',),
'lesesirkelen': ('lesesirkel',),
'lesesirklene': ('lesesirkel',),
'lesesirkler': ('lesesirkel',),
'lesestoff': ('lesestoff',),
'lesestoffa': ('lesestoff',),
'lesestoffene': ('lesestoff',),
'lesestoffer': ('lesestoff',),
'lesestoffet': ('lesestoff',),
'lesevanske': ('lesevanske',),
'lesevansken': ('lesevanske',),
'lesevanskene': ('lesevanske',),
'lesevansker': ('lesevanske',),
'leseverk': ('leseverk',),
'leseverka': ('leseverk',),
'leseverkene': ('leseverk',),
'leseverker': ('leseverk',),
'leseverket': ('leseverk',),
'lesida': ('leside',),
'leside': ('leside',),
'lesiden': ('leside',),
'lesidene': ('leside',),
'lesider': ('leside',),
'lesing': ('lesing',),
'lesinga': ('lesing',),
'lesingen': ('lesing',),
'lesingene': ('lesing',),
'lesinger': ('lesing',),
'lesjon': ('lesjon',),
'lesjonen': ('lesjon',),
'lesjonene': ('lesjon',),
'lesjoner': ('lesjon',),
'leskedrikk': ('leskedrikk',),
'leskedrikken': ('leskedrikk',),
'leskedrikkene': ('leskedrikk',),
'leskedrikker': ('leskedrikk',),
'leskur': ('leskur',),
'leskura': ('leskur',),
'leskurene': ('leskur',),
'leskuret': ('leskur',),
'lesnad': ('lesnad',),
'lesnaden': ('lesnad',),
'lesnadene': ('lesnad',),
'lesnader': ('lesnad',),
'lesning': ('lesning',),
'lesninga': ('lesning',),
'lesningen': ('lesning',),
'lesningene': ('lesning',),
'lesninger': ('lesning',),
'lesothoer': ('lesothoer',),
'lesothoere': ('lesothoer',),
'lesothoeren': ('lesothoer',),
'lesothoerer': ('lesothoer',),
'lesothoerne': ('lesothoer',),
'lesseapparat': ('lesseapparat',),
'lesseapparata': ('lesseapparat',),
'lesseapparatene': ('lesseapparat',),
'lesseapparater': ('lesseapparat',),
'lesseapparatet': ('lesseapparat',),
'lest': ('lest',),
'lesten': ('lest',),
'lestene': ('lest',),
'lester': ('lest',),
'lest': ('lest',),
'lesten': ('lest',),
'lestene': ('lest',),
'lester': ('lest',),
'lester': ('lester',),
'lestere': ('lester',),
'lesteren': ('lester',),
'lesterne': ('lester',),
'lestre': ('lester',),
'lestrene': ('lester',),
'lestrer': ('lester',),
'leteaksjon': ('leteaksjon',),
'leteaksjonen': ('leteaksjon',),
'leteaksjonene': ('leteaksjon',),
'leteaksjoner': ('leteaksjon',),
'letemannskap': ('letemannskap',),
'letemannskapa': ('letemannskap',),
'letemannskapene': ('letemannskap',),
'letemannskaper': ('letemannskap',),
'letemannskapet': ('letemannskap',),
'leter': ('leter',),
'letere': ('leter',),
'leteren': ('leter',),
'leterer': ('leter',),
'leterne': ('leter',),
'lett': ('lett',),
'letten': ('lett',),
'lettene': ('lett',),
'letter': ('lett',),
'lettbetong': ('lettbetong',),
'lettbetongen': ('lettbetong',),
'lettbetongene': ('lettbetong',),
'lettbetonger': ('lettbetong',),
'lettbåt': ('lettbåt',),
'lettbåten': ('lettbåt',),
'lettbåtene': ('lettbåt',),
'lettbåter': ('lettbåt',),
'lette': ('lette',),
'letten': ('lette',),
'lettene': ('lette',),
'letter': ('lette',),
'lettekorn': ('lettekorn',),
'lettekorna': ('lettekorn',),
'lettekornene': ('lettekorn',),
'lettekornet': ('lettekorn',),
'lettelse': ('lettelse',),
'lettelsen': ('lettelse',),
'lettelsene': ('lettelse',),
'lettelser': ('lettelse',),
'letter': ('letter',),
'lettere': ('letter',),
'letteren': ('letter',),
'letterer': ('letter',),
'letterne': ('letter',),
'letthet': ('letthet',),
'lettheta': ('letthet',),
'lettheten': ('letthet',),
'letthetene': ('letthet',),
'lettheter': ('letthet',),
'lettkorn': ('lettkorn',),
'lettkorna': ('lettkorn',),
'lettkornene': ('lettkorn',),
'lettkornet': ('lettkorn',),
'lettlesbok': ('lettlesbok',),
'lettlesboka': ('lettlesbok',),
'lettlesboken': ('lettlesbok',),
'lettlesbøkene': ('lettlesbok',),
'lettlesbøker': ('lettlesbok',),
'lettlestbok': ('lettlestbok',),
'lettlestboka': ('lettlestbok',),
'lettlestboken': ('lettlestbok',),
'lettlestbøkene': ('lettlestbok',),
'lettlestbøker': ('lettlestbok',),
'lettmatros': ('lettmatros',),
'lettmatrosen': ('lettmatros',),
'lettmatrosene': ('lettmatros',),
'lettmatroser': ('lettmatros',),
'lettmelk': ('lettmelk',),
'lettmelka': ('lettmelk',),
'lettmelken': ('lettmelk',),
'lettmelkene': ('lettmelk',),
'lettmelker': ('lettmelk',),
'lettmelkproduksjon': ('lettmelkproduksjon',),
'lettmelkproduksjonen': ('lettmelkproduksjon',),
'lettmelkproduksjonene': ('lettmelkproduksjon',),
'lettmelkproduksjoner': ('lettmelkproduksjon',),
'lettmetall': ('lettmetall',),
'lettmetalla': ('lettmetall',),
'lettmetallene': ('lettmetall',),
'lettmetaller': ('lettmetall',),
'lettmetallet': ('lettmetall',),
'lettmjølkproduksjon': ('lettmjølkproduksjon',),
'lettmjølkproduksjonen': ('lettmjølkproduksjon',),
'lettmjølkproduksjonene': ('lettmjølkproduksjon',),
'lettmjølkproduksjoner': ('lettmjølkproduksjon',),
'lettolja': ('lettolje',),
'lettolje': ('lettolje',),
'lettoljen': ('lettolje',),
'lettoljene': ('lettolje',),
'lettoljer': ('lettolje',),
'lettrømme': ('lettrømme',),
'lettrømmen': ('lettrømme',),
'lettrømmene': ('lettrømme',),
'lettrømmer': ('lettrømme',),
'lettsinn': ('lettsinn',),
'lettsinna': ('lettsinn',),
'lettsinnene': ('lettsinn',),
'lettsinnet': ('lettsinn',),
'lettvegg': ('lettvegg',),
'lettveggen': ('lettvegg',),
'lettveggene': ('lettvegg',),
'lettvegger': ('lettvegg',),
'lettvekt': ('lettvekt',),
'lettvekta': ('lettvekt',),
'lettvekten': ('lettvekt',),
'lettvektene': ('lettvekt',),
'lettvekter': ('lettvekt',),
'lettvekter': ('lettvekter',),
'lettvektere': ('lettvekter',),
'lettvekteren': ('lettvekter',),
'lettvekterer': ('lettvekter',),
'lettvekterne': ('lettvekter',),
'lettvektklassa': ('lettvektklasse',),
'lettvektklasse': ('lettvektklasse',),
'lettvektklassen': ('lettvektklasse',),
'lettvektklassene': ('lettvektklasse',),
'lettvektklasser': ('lettvektklasse',),
'lettvektsklassa': ('lettvektsklasse',),
'lettvektsklasse': ('lettvektsklasse',),
'lettvektsklassen': ('lettvektsklasse',),
'lettvektsklassene': ('lettvektsklasse',),
'lettvektsklasser': ('lettvektsklasse',),
'lettvin': ('lettvin',),
'lettvinen': ('lettvin',),
'lettvinene': ('lettvin',),
'lettviner': ('lettvin',),
'lettøl': ('lettøl',),
'lettøla': ('lettøl',),
'lettølet': ('lettøl',),
'leukemi': ('leukemi',),
'leukemien': ('leukemi',),
'leukemiene': ('leukemi',),
'leukemier': ('leukemi',),
'levantiner': ('levantiner',),
'levantinere': ('levantiner',),
'levantineren': ('levantiner',),
'levantinerer': ('levantiner',),
'levantinerne': ('levantiner',),
'leva': ('leve',),
'leve': ('leve',),
'levene': ('leve',),
'lever': ('leve',),
'levet': ('leve',),
'levealder': ('levealder',),
'levealdere': ('levealder',),
'levealderen': ('levealder',),
'levealderer': ('levealder',),
'levealderne': ('levealder',),
'levealdre': ('levealder',),
'levealdrene': ('levealder',),
'levealdrer': ('levealder',),
'levebrød': ('levebrød',),
'levebrøda': ('levebrød',),
'levebrødene': ('levebrød',),
'levebrødet': ('levebrød',),
'levedag': ('levedag',),
'levedagen': ('levedag',),
'levedagene': ('levedag',),
'levedager': ('levedag',),
'levekostnad': ('levekostnad',),
'levekostnaden': ('levekostnad',),
'levekostnadene': ('levekostnad',),
'levekostnader': ('levekostnad',),
'levekostnadsindeks': ('levekostnadsindeks',),
'levekostnadsindeksen': ('levekostnadsindeks',),
'levekostnadsindeksene': ('levekostnadsindeks',),
'levekostnadsindekser': ('levekostnadsindeks',),
'levemann': ('levemann',),
'levemannen': ('levemann',),
'levemenn': ('levemann',),
'levemennene': ('levemann',),
'levemåte': ('levemåte',),
'levemåten': ('levemåte',),
'levemåtene': ('levemåte',),
'levemåter': ('levemåte',),
'leven': ('leven',),
'levena': ('leven',),
'levenene': ('leven',),
'levenet': ('leven',),
'levendefisk': ('levendefisk',),
'levendefisken': ('levendefisk',),
'levendefiskene': ('levendefisk',),
'levendefisker': ('levendefisk',),
'levendevekt': ('levendevekt',),
'levendevekta': ('levendevekt',),
'levendevekten': ('levendevekt',),
'levendevektene': ('levendevekt',),
'levendevekter': ('levendevekt',),
'leveomkostning': ('leveomkostning',),
'leveomkostninga': ('leveomkostning',),
'leveomkostningen': ('leveomkostning',),
'leveomkostningene': ('leveomkostning',),
'leveomkostninger': ('leveomkostning',),
'lever': ('lever',),
'levere': ('lever',),
'leveren': ('lever',),
'leverer': ('lever',),
'leverne': ('lever',),
'levra': ('lever',),
'levre': ('lever',),
'levrene': ('lever',),
'levrer': ('lever',),
'leverandør': ('leverandør',),
'leverandøren': ('leverandør',),
'leverandørene': ('leverandør',),
'leverandører': ('leverandør',),
'leveranse': ('leveranse',),
'leveransen': ('leveranse',),
'leveransene': ('leveranse',),
'leveranser': ('leveranse',),
'leverbetennelse': ('leverbetennelse',),
'leverbetennelsen': ('leverbetennelse',),
'leverbetennelsene': ('leverbetennelse',),
'leverbetennelser': ('leverbetennelse',),
'leveregel': ('leveregel',),
'leveregelen': ('leveregel',),
'levereglene': ('leveregel',),
'leveregler': ('leveregel',),
'leverflekk': ('leverflekk',),
'leverflekken': ('leverflekk',),
'leverflekkene': ('leverflekk',),
'leverflekker': ('leverflekk',),
'leverikte': ('leverikte',),
'leverikten': ('leverikte',),
'leveriktene': ('leverikte',),
'leverikter': ('leverikte',),
'levering': ('levering',),
'leveringa': ('levering',),
'leveringen': ('levering',),
'leveringene': ('levering',),
'leveringer': ('levering',),
'leveringstid': ('leveringstid',),
'leveringstida': ('leveringstid',),
'leveringstiden': ('leveringstid',),
'leveringstidene': ('leveringstid',),
'leveringstider': ('leveringstid',),
'leverjo': ('leverjo',),
'leverjoen': ('leverjo',),
'leverjoene': ('leverjo',),
'leverjoer': ('leverjo',),
'levermose': ('levermose',),
'levermosen': ('levermose',),
'levermosene': ('levermose',),
'levermoser': ('levermose',),
'levermølja': ('levermølje',),
'levermølje': ('levermølje',),
'levermøljen': ('levermølje',),
'levermøljene': ('levermølje',),
'levermøljer': ('levermølje',),
'leverplett': ('leverplett',),
'leverpletten': ('leverplett',),
'leverplettene': ('leverplett',),
'leverpletter': ('leverplett',),
'leverpostei': ('leverpostei',),
'leverposteien': ('leverpostei',),
'leverposteiene': ('leverpostei',),
'leverposteier': ('leverpostei',),
'leverråte': ('leverråte',),
'leverråten': ('leverråte',),
'leverråtene': ('leverråte',),
'leverråter': ('leverråte',),
'levestandard': ('levestandard',),
'levestandarden': ('levestandard',),
'levestandardene': ('levestandard',),
'levestandarder': ('levestandard',),
'levested': ('levested',),
'levestedene': ('levested',),
'levesteder': ('levested',),
'levestedet': ('levested',),
'levetid': ('levetid',),
'levetida': ('levetid',),
'levetiden': ('levetid',),
'levetidene': ('levetid',),
'levetider': ('levetid',),
'leveveg': ('leveveg',),
'levevegen': ('leveveg',),
'levevegene': ('leveveg',),
'leveveger': ('leveveg',),
'levevei': ('levevei',),
'leveveien': ('levevei',),
'leveveiene': ('levevei',),
'leveveier': ('levevei',),
'leveår': ('leveår',),
'leveåra': ('leveår',),
'leveårene': ('leveår',),
'leveåret': ('leveår',),
'levitt': ('levitt',),
'levitten': ('levitt',),
'levittene': ('levitt',),
'levitter': ('levitt',),
'levkøy': ('levkøy',),
'levkøyen': ('levkøy',),
'levkøyene': ('levkøy',),
'levkøyer': ('levkøy',),
'levnet': ('levnet',),
'levneta': ('levnet',),
'levnetene': ('levnet',),
'levnetet': ('levnet',),
'levnetsbeskrivelse': ('levnetsbeskrivelse',),
'levnetsbeskrivelsen': ('levnetsbeskrivelse',),
'levnetsbeskrivelsene': ('levnetsbeskrivelse',),
'levnetsbeskrivelser': ('levnetsbeskrivelse',),
'levnetsløp': ('levnetsløp',),
'levnetsløpa': ('levnetsløp',),
'levnetsløpene': ('levnetsløp',),
'levnetsløpet': ('levnetsløp',),
'levnetsmiddel': ('levnetsmiddel',),
'levnetsmiddelet': ('levnetsmiddel',),
'levnetsmidla': ('levnetsmiddel',),
'levnetsmidlene': ('levnetsmiddel',),
'levnetsmidler': ('levnetsmiddel',),
'levnetsmidlet': ('levnetsmiddel',),
'levnetsmiddelindustri': ('levnetsmiddelindustri',),
'levnetsmiddelindustrien': ('levnetsmiddelindustri',),
'levnetsmiddelindustriene': ('levnetsmiddelindustri',),
'levnetsmiddelindustrier': ('levnetsmiddelindustri',),
'levning': ('levning',),
'levningen': ('levning',),
'levningene': ('levning',),
'levninger': ('levning',),
'leges': ('lex',),
'lex': ('lex',),
'li': ('li',),
'lia': ('li',),
'lien': ('li',),
'liene': ('li',),
'lier': ('li',),
'liaison': ('liaison',),
'liaisonen': ('liaison',),
'liaisonene': ('liaison',),
'liaisoner': ('liaison',),
'liaisonoffiser': ('liaisonoffiser',),
'liaisonoffiseren': ('liaisonoffiser',),
'liaisonoffiserene': ('liaisonoffiser',),
'liaisonoffiserer': ('liaisonoffiser',),
'lian': ('lian',),
'lianen': ('lian',),
'lianene': ('lian',),
'lianer': ('lian',),
'libaneser': ('libaneser',),
'libanesere': ('libaneser',),
'libaneseren': ('libaneser',),
'libaneserer': ('libaneser',),
'libaneserne': ('libaneser',),
'libelle': ('libelle',),
'libellen': ('libelle',),
'libellene': ('libelle',),
'libeller': ('libelle',),
'liberaler': ('liberaler',),
'liberalere': ('liberaler',),
'liberaleren': ('liberaler',),
'liberalerer': ('liberaler',),
'liberalerne': ('liberaler',),
'liberalisme': ('liberalisme',),
'liberalismen': ('liberalisme',),
'liberalismene': ('liberalisme',),
'liberalismer': ('liberalisme',),
'liberalist': ('liberalist',),
'liberalisten': ('liberalist',),
'liberalistene': ('liberalist',),
'liberalister': ('liberalist',),
'liberalitet': ('liberalitet',),
'liberaliteten': ('liberalitet',),
'liberalitetene': ('liberalitet',),
'liberaliteter': ('liberalitet',),
'liberier': ('liberier',),
'liberiere': ('liberier',),
'liberieren': ('liberier',),
'liberierer': ('liberier',),
'liberierne': ('liberier',),
'libero': ('libero',),
'liberoen': ('libero',),
'liberoene': ('libero',),
'liberoer': ('libero',),
'libertiner': ('libertiner',),
'libertinere': ('libertiner',),
'libertineren': ('libertiner',),
'libertinerer': ('libertiner',),
'libertinerne': ('libertiner',),
'libido': ('libido',),
'libidoen': ('libido',),
'libidoene': ('libido',),
'libidoer': ('libido',),
'librettist': ('librettist',),
'librettisten': ('librettist',),
'librettistene': ('librettist',),
'librettister': ('librettist',),
'libretto': ('libretto',),
'librettoen': ('libretto',),
'librettoene': ('libretto',),
'librettoer': ('libretto',),
'libyer': ('libyer',),
'libyere': ('libyer',),
'libyeren': ('libyer',),
'libyerer': ('libyer',),
'libyerne': ('libyer',),
'licentia': ('licentia',),
'lidelse': ('lidelse',),
'lidelsen': ('lidelse',),
'lidelsene': ('lidelse',),
'lidelser': ('lidelse',),
'lidelsesfelle': ('lidelsesfelle',),
'lidelsesfellen': ('lidelsesfelle',),
'lidelsesfellene': ('lidelsesfelle',),
'lidelsesfeller': ('lidelsesfelle',),
'lidelseshistoria': ('lidelseshistorie',),
'lidelseshistorie': ('lidelseshistorie',),
'lidelseshistorien': ('lidelseshistorie',),
'lidelseshistoriene': ('lidelseshistorie',),
'lidelseshistorier': ('lidelseshistorie',),
'lidenskap': ('lidenskap',),
'lidenskapen': ('lidenskap',),
'lidenskapene': ('lidenskap',),
'lidenskaper': ('lidenskap',),
'lidokain': ('lidokain',),
'lidokaina': ('lidokain',),
'lidokainene': ('lidokain',),
'lidokainet': ('lidokain',),
'lidokainsalva': ('lidokainsalve',),
'lidokainsalve': ('lidokainsalve',),
'lidokainsalven': ('lidokainsalve',),
'lidokainsalvene': ('lidokainsalve',),
'lidokainsalver': ('lidokainsalve',),
'liebhaber': ('liebhaber',),
'liebhabere': ('liebhaber',),
'liebhaberen': ('liebhaber',),
'liebhaberer': ('liebhaber',),
'liebhaberne': ('liebhaber',),
'liebhaberi': ('liebhaberi',),
'liebhaberia': ('liebhaberi',),
'liebhaberiene': ('liebhaberi',),
'liebhaberier': ('liebhaberi',),
'liebhaberiet': ('liebhaberi',),
'liechtensteiner': ('liechtensteiner',),
'liechtensteinere': ('liechtensteiner',),
'liechtensteineren': ('liechtensteiner',),
'liechtensteinerer': ('liechtensteiner',),
'liechtensteinerne': ('liechtensteiner',),
'lied': ('lied',),
'lieden': ('lied',),
'liedene': ('lied',),
'lieder': ('lied',),
'liedsanger': ('liedsanger',),
'liedsangere': ('liedsanger',),
'liedsangeren': ('liedsanger',),
'liedsangerer': ('liedsanger',),
'liedsangerne': ('liedsanger',),
'lift': ('lift',),
'liften': ('lift',),
'liftene': ('lift',),
'lifter': ('lift',),
'liga': ('liga',),
'ligaen': ('liga',),
'ligaene': ('liga',),
'ligaer': ('liga',),
'ligakamp': ('ligakamp',),
'ligakampen': ('ligakamp',),
'ligakampene': ('ligakamp',),
'ligakamper': ('ligakamp',),
'ligament': ('ligament',),
'ligamenta': ('ligament',),
'ligamentene': ('ligament',),
'ligamenter': ('ligament',),
'ligamentet': ('ligament',),
'ligand': ('ligand',),
'liganden': ('ligand',),
'ligandene': ('ligand',),
'ligander': ('ligand',),
'ligatur': ('ligatur',),
'ligaturen': ('ligatur',),
'ligaturene': ('ligatur',),
'ligaturer': ('ligatur',),
'liggedag': ('liggedag',),
'liggedagen': ('liggedag',),
'liggedagene': ('liggedag',),
'liggedager': ('liggedag',),
'ligger': ('ligger',),
'liggere': ('ligger',),
'liggeren': ('ligger',),
'liggerer': ('ligger',),
'liggerne': ('ligger',),
'liggeseta': ('liggesete',),
'liggesete': ('liggesete',),
'liggesetene': ('liggesete',),
'liggeseter': ('liggesete',),
'liggesetet': ('liggesete',),
'liggestol': ('liggestol',),
'liggestolen': ('liggestol',),
'liggestolene': ('liggestol',),
'liggestoler': ('liggestol',),
'liggesår': ('liggesår',),
'liggesåra': ('liggesår',),
'liggesårene': ('liggesår',),
'liggesåret': ('liggesår',),
'liggetid': ('liggetid',),
'liggetida': ('liggetid',),
'liggetiden': ('liggetid',),
'liggetidene': ('liggetid',),
'liggetider': ('liggetid',),
'liggevogn': ('liggevogn',),
'liggevogna': ('liggevogn',),
'liggevognen': ('liggevogn',),
'liggevognene': ('liggevogn',),
'liggevogner': ('liggevogn',),
'lighter': ('lighter',),
'lightere': ('lighter',),
'lighteren': ('lighter',),
'lighterer': ('lighter',),
'lighterne': ('lighter',),
'lignelse': ('lignelse',),
'lignelsen': ('lignelse',),
'lignelsene': ('lignelse',),
'lignelser': ('lignelse',),
'lignin': ('lignin',),
'lignina': ('lignin',),
'ligninene': ('lignin',),
'ligninet': ('lignin',),
'ligning': ('ligning',),
'ligninga': ('ligning',),
'ligningen': ('ligning',),
'ligningene': ('ligning',),
'ligninger': ('ligning',),
'ligningsattest': ('ligningsattest',),
'ligningsattesten': ('ligningsattest',),
'ligningsattestene': ('ligningsattest',),
'ligningsattester': ('ligningsattest',),
'ligningskontor': ('ligningskontor',),
'ligningskontora': ('ligningskontor',),
'ligningskontorene': ('ligningskontor',),
'ligningskontorer': ('ligningskontor',),
'ligningskontoret': ('ligningskontor',),
'ligningsnemnd': ('ligningsnemnd',),
'ligningsnemnda': ('ligningsnemnd',),
'ligningsnemnden': ('ligningsnemnd',),
'ligningsnemndene': ('ligningsnemnd',),
'ligningsnemnder': ('ligningsnemnd',),
'ligningssjef': ('ligningssjef',),
'ligningssjefen': ('ligningssjef',),
'ligningssjefene': ('ligningssjef',),
'ligningssjefer': ('ligningssjef',),
'ligningsvesen': ('ligningsvesen',),
'ligningsvesena': ('ligningsvesen',),
'ligningsvesenene': ('ligningsvesen',),
'ligningsvesener': ('ligningsvesen',),
'ligningsvesenet': ('ligningsvesen',),
'ligroin': ('ligroin',),
'ligroina': ('ligroin',),
'ligroinene': ('ligroin',),
'ligroinet': ('ligroin',),
'liguster': ('liguster',),
'ligusteren': ('liguster',),
'ligusterene': ('liguster',),
'ligusterer': ('liguster',),
'ligustersvermer': ('ligustersvermer',),
'ligustersvermere': ('ligustersvermer',),
'ligustersvermeren': ('ligustersvermer',),
'ligustersvermerer': ('ligustersvermer',),
'ligustersvermerne': ('ligustersvermer',),
'ligustertre': ('ligustertre',),
'ligustertrea': ('ligustertre',),
'ligustertreet': ('ligustertre',),
'ligustertrær': ('ligustertre',),
'ligustertrærne': ('ligustertre',),
'lik': ('lik',),
'lika': ('lik',),
'likene': ('lik',),
'liket': ('lik',),
'lik': ('lik',),
'lika': ('lik',),
'likene': ('lik',),
'liket': ('lik',),
'likbrenning': ('likbrenning',),
'likbrenninga': ('likbrenning',),
'likbrenningen': ('likbrenning',),
'likbrenningene': ('likbrenning',),
'likbrenninger': ('likbrenning',),
'likbærer': ('likbærer',),
'likbærere': ('likbærer',),
'likbæreren': ('likbærer',),
'likbærerer': ('likbærer',),
'likbærerne': ('likbærer',),
'like': ('like',),
'liken': ('like',),
'likene': ('like',),
'liker': ('like',),
'likelønn': ('likelønn',),
'likelønna': ('likelønn',),
'likelønnen': ('likelønn',),
'likelønnene': ('likelønn',),
'likelønner': ('likelønn',),
'likemann': ('likemann',),
'likemannen': ('likemann',),
'likemenn': ('likemann',),
'likemennene': ('likemann',),
'likeretter': ('likeretter',),
'likerettere': ('likeretter',),
'likeretteren': ('likeretter',),
'likeretterer': ('likeretter',),
'likeretterne': ('likeretter',),
'likestilling': ('likestilling',),
'likestillinga': ('likestilling',),
'likestillingen': ('likestilling',),
'likestillingene': ('likestilling',),
'likestillinger': ('likestilling',),
'likestillingslov': ('likestillingslov',),
'likestillingsloven': ('likestillingslov',),
'likestillingslovene': ('likestillingslov',),
'likestillingslover': ('likestillingslov',),
'likestillingsombud': ('likestillingsombud',),
'likestillingsombuda': ('likestillingsombud',),
'likestillingsombudene': ('likestillingsombud',),
'likestillingsombudet': ('likestillingsombud',),
'likestrøm': ('likestrøm',),
'likestrømmen': ('likestrøm',),
'likestrømmene': ('likestrøm',),
'likestrømmer': ('likestrøm',),
'likesæla': ('likesæle',),
'likesæle': ('likesæle',),
'likesælen': ('likesæle',),
'likesælene': ('likesæle',),
'likesæler': ('likesæle',),
'liketyding': ('liketyding',),
'liketydingen': ('liketyding',),
'liketydingene': ('liketyding',),
'liketydinger': ('liketyding',),
'likevekt': ('likevekt',),
'likevekta': ('likevekt',),
'likevekten': ('likevekt',),
'likevektene': ('likevekt',),
'likevekter': ('likevekt',),
'likevektssamfunn': ('likevektssamfunn',),
'likevektssamfunna': ('likevektssamfunn',),
'likevektssamfunnene': ('likevektssamfunn',),
'likevektssamfunnet': ('likevektssamfunn',),
'likeverd': ('likeverd',),
'likeverda': ('likeverd',),
'likeverdene': ('likeverd',),
'likeverdet': ('likeverd',),
'likferd': ('likferd',),
'likferda': ('likferd',),
'likferden': ('likferd',),
'likferdene': ('likferd',),
'likferder': ('likferd',),
'likflekk': ('likflekk',),
'likflekken': ('likflekk',),
'likflekkene': ('likflekk',),
'likflekker': ('likflekk',),
'likfølga': ('likfølge',),
'likfølge': ('likfølge',),
'likfølgene': ('likfølge',),
'likfølger': ('likfølge',),
'likfølget': ('likfølge',),
'likfølgja': ('likfølgje',),
'likfølgje': ('likfølgje',),
'likfølgjene': ('likfølgje',),
'likfølgjer': ('likfølgje',),
'likfølgjet': ('likfølgje',),
'likgift': ('likgift',),
'likgifta': ('likgift',),
'likgiften': ('likgift',),
'likgiftene': ('likgift',),
'likgifter': ('likgift',),
'likhalm': ('likhalm',),
'likhalmen': ('likhalm',),
'likhalmene': ('likhalm',),
'likhalmer': ('likhalm',),
'likhet': ('likhet',),
'likheta': ('likhet',),
'likheten': ('likhet',),
'likhetene': ('likhet',),
'likheter': ('likhet',),
'likhetspunkt': ('likhetspunkt',),
'likhetspunkta': ('likhetspunkt',),
'likhetspunktene': ('likhetspunkt',),
'likhetspunkter': ('likhetspunkt',),
'likhetspunktet': ('likhetspunkt',),
'likhetstanke': ('likhetstanke',),
'likhetstanken': ('likhetstanke',),
'likhetstankene': ('likhetstanke',),
'likhetstanker': ('likhetstanke',),
'likhetstegn': ('likhetstegn',),
'likhetstegna': ('likhetstegn',),
'likhetstegnene': ('likhetstegn',),
'likhetstegnet': ('likhetstegn',),
'likhus': ('likhus',),
'likhusa': ('likhus',),
'likhusene': ('likhus',),
'likhuset': ('likhus',),
'likkapell': ('likkapell',),
'likkapella': ('likkapell',),
'likkapellene': ('likkapell',),
'likkapeller': ('likkapell',),
'likkapellet': ('likkapell',),
'likkista': ('likkiste',),
'likkiste': ('likkiste',),
'likkisten': ('likkiste',),
'likkistene': ('likkiste',),
'likkister': ('likkiste',),
'likkleda': ('likklede',),
'likklede': ('likklede',),
'likkledene': ('likklede',),
'likkleder': ('likklede',),
'likkledet': ('likklede',),
'likklokka': ('likklokke',),
'likklokke': ('likklokke',),
'likklokken': ('likklokke',),
'likklokkene': ('likklokke',),
'likklokker': ('likklokke',),
'likklær': ('likklær',),
'likklærne': ('likklær',),
'liknelse': ('liknelse',),
'liknelsen': ('liknelse',),
'liknelsene': ('liknelse',),
'liknelser': ('liknelse',),
'likning': ('likning',),
'likninga': ('likning',),
'likningen': ('likning',),
'likningene': ('likning',),
'likninger': ('likning',),
'likningsattest': ('likningsattest',),
'likningsattesten': ('likningsattest',),
'likningsattestene': ('likningsattest',),
'likningsattester': ('likningsattest',),
'likningskontor': ('likningskontor',),
'likningskontora': ('likningskontor',),
'likningskontorene': ('likningskontor',),
'likningskontorer': ('likningskontor',),
'likningskontoret': ('likningskontor',),
'likningsnemnd': ('likningsnemnd',),
'likningsnemnda': ('likningsnemnd',),
'likningsnemnden': ('likningsnemnd',),
'likningsnemndene': ('likningsnemnd',),
'likningsnemnder': ('likningsnemnd',),
'likningssjef': ('likningssjef',),
'likningssjefen': ('likningssjef',),
'likningssjefene': ('likningssjef',),
'likningssjefer': ('likningssjef',),
'likningsvesen': ('likningsvesen',),
'likningsvesena': ('likningsvesen',),
'likningsvesenene': ('likningsvesen',),
'likningsvesener': ('likningsvesen',),
'likningsvesenet': ('likningsvesen',),
'likplett': ('likplett',),
'likpletten': ('likplett',),
'likplettene': ('likplett',),
'likpletter': ('likplett',),
'likplyndrer': ('likplyndrer',),
'likplyndrere': ('likplyndrer',),
'likplyndreren': ('likplyndrer',),
'likplyndrerer': ('likplyndrer',),
'likplyndrerne': ('likplyndrer',),
'liks': ('liks',),
'liksen': ('liks',),
'liksene': ('liks',),
'likser': ('liks',),
'liksalme': ('liksalme',),
'liksalmen': ('liksalme',),
'liksalmene': ('liksalme',),
'liksalmer': ('liksalme',),
'likskap': ('likskap',),
'likskapen': ('likskap',),
'likskapene': ('likskap',),
'likskaper': ('likskap',),
'likskjender': ('likskjender',),
'likskjendere': ('likskjender',),
'likskjenderen': ('likskjender',),
'likskjenderer': ('likskjender',),
'likskjenderne': ('likskjender',),
'likskjorta': ('likskjorte',),
'likskjorte': ('likskjorte',),
'likskjorten': ('likskjorte',),
'likskjortene': ('likskjorte',),
'likskjorter': ('likskjorte',),
'likskua': ('likskue',),
'likskue': ('likskue',),
'likskuene': ('likskue',),
'likskuer': ('likskue',),
'likskuet': ('likskue',),
'likstrå': ('likstrå',),
'likstråa': ('likstrå',),
'likstråene': ('likstrå',),
'likstrået': ('likstrå',),
'liksvøp': ('liksvøp',),
'liksvøpa': ('liksvøp',),
'liksvøpene': ('liksvøp',),
'liksvøpet': ('liksvøp',),
'liktale': ('liktale',),
'liktalen': ('liktale',),
'liktalene': ('liktale',),
'liktaler': ('liktale',),
'liktor': ('liktor',),
'liktoren': ('liktor',),
'liktorene': ('liktor',),
'liktorer': ('liktor',),
'liktorn': ('liktorn',),
'liktornen': ('liktorn',),
'liktornene': ('liktorn',),
'liktorner': ('liktorn',),
'liktå': ('liktå',),
'liktåa': ('liktå',),
'liktåen': ('liktå',),
'liktær': ('liktå',),
'liktærne': ('liktå',),
'likvid': ('likvid',),
'likviden': ('likvid',),
'likvidene': ('likvid',),
'likvider': ('likvid',),
'likvidasjon': ('likvidasjon',),
'likvidasjonen': ('likvidasjon',),
'likvidasjonene': ('likvidasjon',),
'likvidasjoner': ('likvidasjon',),
'likvidene': ('likvider',),
'likvider': ('likvider',),
'likviditet': ('likviditet',),
'likviditeten': ('likviditet',),
'likviditetene': ('likviditet',),
'likviditeter': ('likviditet',),
'likviditetslån': ('likviditetslån',),
'likviditetslåna': ('likviditetslån',),
'likviditetslånene': ('likviditetslån',),
'likviditetslånet': ('likviditetslån',),
'likviditetsvanske': ('likviditetsvanske',),
'likviditetsvansken': ('likviditetsvanske',),
'likviditetsvanskene': ('likviditetsvanske',),
'likviditetsvansker': ('likviditetsvanske',),
'likviditetsvanskelighet': ('likviditetsvanskelighet',),
'likviditetsvanskeligheta': ('likviditetsvanskelighet',),
'likviditetsvanskeligheten': ('likviditetsvanskelighet',),
'likviditetsvanskelighetene': ('likviditetsvanskelighet',),
'likviditetsvanskeligheter': ('likviditetsvanskelighet',),
'likåpning': ('likåpning',),
'likåpninga': ('likåpning',),
'likåpningen': ('likåpning',),
'likåpningene': ('likåpning',),
'likåpninger': ('likåpning',),
'likør': ('likør',),
'likøren': ('likør',),
'likørene': ('likør',),
'likører': ('likør',),
'lilja': ('lilje',),
'lilje': ('lilje',),
'liljen': ('lilje',),
'liljene': ('lilje',),
'liljer': ('lilje',),
'liljefamilie': ('liljefamilie',),
'liljefamilien': ('liljefamilie',),
'liljefamiliene': ('liljefamilie',),
'liljefamilier': ('liljefamilie',),
'liljekonvall': ('liljekonvall',),
'liljekonvallen': ('liljekonvall',),
'liljekonvallene': ('liljekonvall',),
'liljekonvaller': ('liljekonvall',),
'lille julaften': ('lille julaften',),
'lille julaftenen': ('lille julaften',),
'lille julaftenene': ('lille julaften',),
'lille julaftener': ('lille julaften',),
'lillebror': ('lillebror',),
'lillebroren': ('lillebror',),
'lillebrødre': ('lillebror',),
'lillebrødrene': ('lillebror',),
'lillefinger': ('lillefinger',),
'lillefingeren': ('lillefinger',),
'lillefingre': ('lillefinger',),
'lillefingrene': ('lillefinger',),
'lillefingrer': ('lillefinger',),
'lillehjerne': ('lillehjerne',),
'lillehjernen': ('lillehjerne',),
'lillehjernene': ('lillehjerne',),
'lillehjerner': ('lillehjerne',),
'lillejulaften': ('lillejulaften',),
'lillejulaftenen': ('lillejulaften',),
'lillejulaftenene': ('lillejulaften',),
'lillejulaftener': ('lillejulaften',),
'lillekonvall': ('lillekonvall',),
'lillekonvallen': ('lillekonvall',),
'lillekonvallene': ('lillekonvall',),
'lillekonvaller': ('lillekonvall',),
'lilleputt': ('lilleputt',),
'lilleputten': ('lilleputt',),
'lilleputtene': ('lilleputt',),
'lilleputter': ('lilleputt',),
'lilleputtlag': ('lilleputtlag',),
'lilleputtlaga': ('lilleputtlag',),
'lilleputtlagene': ('lilleputtlag',),
'lilleputtlaget': ('lilleputtlag',),
'lilleputtstat': ('lilleputtstat',),
'lilleputtstaten': ('lilleputtstat',),
'lilleputtstatene': ('lilleputtstat',),
'lilleputtstater': ('lilleputtstat',),
'lilleslem': ('lilleslem',),
'lilleslemmen': ('lilleslem',),
'lilleslemmene': ('lilleslem',),
'lilleslemmer': ('lilleslem',),
'lillesøster': ('lillesøster',),
'lillesøstera': ('lillesøster',),
'lillesøsteren': ('lillesøster',),
'lillesøstre': ('lillesøster',),
'lillesøstrene': ('lillesøster',),
'lillesøstrer': ('lillesøster',),
'lilletromma': ('lilletromme',),
'lilletromme': ('lilletromme',),
'lilletrommen': ('lilletromme',),
'lilletrommene': ('lilletromme',),
'lilletrommer': ('lilletromme',),
'lilletå': ('lilletå',),
'lilletåa': ('lilletå',),
'lilletåen': ('lilletå',),
'lilletær': ('lilletå',),
'lilletærne': ('lilletå',),
'lilleviser': ('lilleviser',),
'lillevisere': ('lilleviser',),
'lilleviseren': ('lilleviser',),
'lilleviserer': ('lilleviser',),
'lilleviserne': ('lilleviser',),
'lim': ('lim',),
'lima': ('lim',),
'limene': ('lim',),
'limet': ('lim',),
'limband': ('limband',),
'limbanda': ('limband',),
'limbandene': ('limband',),
'limbandet': ('limband',),
'limbånd': ('limbånd',),
'limbånda': ('limbånd',),
'limbåndene': ('limbånd',),
'limbåndet': ('limbånd',),
'lime': ('lime',),
'limen': ('lime',),
'limene': ('lime',),
'limer': ('lime',),
'limejuice': ('limejuice',),
'limejuicen': ('limejuice',),
'limejuicene': ('limejuice',),
'limejuicer': ('limejuice',),
'limejus': ('limejus',),
'limejusen': ('limejus',),
'limejusene': ('limejus',),
'limejuser': ('limejus',),
'limerick': ('limerick',),
'limericken': ('limerick',),
'limerickene': ('limerick',),
'limericker': ('limerick',),
'limett': ('limett',),
'limetten': ('limett',),
'limettene': ('limett',),
'limetter': ('limett',),
'limfarge': ('limfarge',),
'limfargen': ('limfarge',),
'limfargene': ('limfarge',),
'limfarger': ('limfarge',),
'liming': ('liming',),
'liminga': ('liming',),
'limingen': ('liming',),
'limingene': ('liming',),
'liminger': ('liming',),
'limnolog': ('limnolog',),
'limnologen': ('limnolog',),
'limnologene': ('limnolog',),
'limnologer': ('limnolog',),
'limnologi': ('limnologi',),
'limnologien': ('limnologi',),
'limnologiene': ('limnologi',),
'limnologier': ('limnologi',),
'limonade': ('limonade',),
'limonaden': ('limonade',),
'limonadene': ('limonade',),
'limonader': ('limonade',),
'limonitt': ('limonitt',),
'limonitten': ('limonitt',),
'limonittene': ('limonitt',),
'limonitter': ('limonitt',),
'limousin': ('limousin',),
'limousinen': ('limousin',),
'limousinene': ('limousin',),
'limousiner': ('limousin',),
'limpinne': ('limpinne',),
'limpinnen': ('limpinne',),
'limpinnene': ('limpinne',),
'limpinner': ('limpinne',),
'limtre': ('limtre',),
'limtrea': ('limtre',),
'limtreet': ('limtre',),
'limtrær': ('limtre',),
'limtrærne': ('limtre',),
'lin': ('lin',),
'lina': ('lin',),
'linene': ('lin',),
'linet': ('lin',),
'linbendel': ('linbendel',),
'linbendelen': ('linbendel',),
'linbendlene': ('linbendel',),
'linbendler': ('linbendel',),
'lind': ('lind',),
'linda': ('lind',),
'linden': ('lind',),
'lindene': ('lind',),
'linder': ('lind',),
'linde': ('linde',),
'linden': ('linde',),
'lindene': ('linde',),
'linder': ('linde',),
'lindebarn': ('lindebarn',),
'lindebarna': ('lindebarn',),
'lindebarnene': ('lindebarn',),
'lindebarnet': ('lindebarn',),
'lindefamilie': ('lindefamilie',),
'lindefamilien': ('lindefamilie',),
'lindefamiliene': ('lindefamilie',),
'lindefamilier': ('lindefamilie',),
'lindring': ('lindring',),
'lindringa': ('lindring',),
'lindringen': ('lindring',),
'lindringene': ('lindring',),
'lindringer': ('lindring',),
'linduk': ('linduk',),
'linduken': ('linduk',),
'lindukene': ('linduk',),
'linduker': ('linduk',),
'lina': ('line',),
'line': ('line',),
'linen': ('line',),
'linene': ('line',),
'liner': ('line',),
'linearitet': ('linearitet',),
'lineariteten': ('linearitet',),
'linearitetene': ('linearitet',),
'lineariteter': ('linearitet',),
'linebruk': ('linebruk',),
'linebruka': ('linebruk',),
'linebrukene': ('linebruk',),
'linebruket': ('linebruk',),
'linebåt': ('linebåt',),
'linebåten': ('linebåt',),
'linebåtene': ('linebåt',),
'linebåter': ('linebåt',),
'linedanser': ('linedanser',),
'linedansere': ('linedanser',),
'linedanseren': ('linedanser',),
'linedanserer': ('linedanser',),
'linedanserne': ('linedanser',),
'linefangst': ('linefangst',),
'linefangsten': ('linefangst',),
'linefangstene': ('linefangst',),
'linefangster': ('linefangst',),
'linefiska': ('linefiske',),
'linefiske': ('linefiske',),
'linefiskene': ('linefiske',),
'linefisker': ('linefiske',),
'linefisket': ('linefiske',),
'linefisker': ('linefisker',),
'linefiskere': ('linefisker',),
'linefiskeren': ('linefisker',),
'linefiskerer': ('linefisker',),
'linefiskerne': ('linefisker',),
'linerla': ('linerle',),
'linerle': ('linerle',),
'linerlen': ('linerle',),
'linerlene': ('linerle',),
'linerler': ('linerle',),
'linesetning': ('linesetning',),
'linesetninga': ('linesetning',),
'linesetningen': ('linesetning',),
'linesetningene': ('linesetning',),
'linesetninger': ('linesetning',),
'linesett': ('linesett',),
'linesetta': ('linesett',),
'linesettene': ('linesett',),
'linesettet': ('linesett',),
'linesetting': ('linesetting',),
'linesettinga': ('linesetting',),
'linesettingen': ('linesetting',),
'linesettingene': ('linesetting',),
'linesettinger': ('linesetting',),
'linfamilie': ('linfamilie',),
'linfamilien': ('linfamilie',),
'linfamiliene': ('linfamilie',),
'linfamilier': ('linfamilie',),
'linfrø': ('linfrø',),
'linfrøa': ('linfrø',),
'linfrøene': ('linfrø',),
'linfrøet': ('linfrø',),
'linfrøkaka': ('linfrøkake',),
'linfrøkake': ('linfrøkake',),
'linfrøkaken': ('linfrøkake',),
'linfrøkakene': ('linfrøkake',),
'linfrøkaker': ('linfrøkake',),
'lingo': ('lingo',),
'lingoa': ('lingo',),
'lingoene': ('lingo',),
'lingoer': ('lingo',),
'lingoet': ('lingo',),
'lingua franca': ('lingua franca',),
'lingvist': ('lingvist',),
'lingvisten': ('lingvist',),
'lingvistene': ('lingvist',),
'lingvister': ('lingvist',),
'lingvistikk': ('lingvistikk',),
'lingvistikken': ('lingvistikk',),
'lingvistikkene': ('lingvistikk',),
'lingvistikker': ('lingvistikk',),
'liniment': ('liniment',),
'linimenta': ('liniment',),
'linimentene': ('liniment',),
'linimenter': ('liniment',),
'linimentet': ('liniment',),
'linjal': ('linjal',),
'linjalen': ('linjal',),
'linjalene': ('linjal',),
'linjaler': ('linjal',),
'linja': ('linje',),
'linje': ('linje',),
'linjen': ('linje',),
'linjene': ('linje',),
'linjer': ('linje',),
'linjeakevitt': ('linjeakevitt',),
'linjeakevitten': ('linjeakevitt',),
'linjeakevittene': ('linjeakevitt',),
'linjeakevitter': ('linjeakevitt',),
'linjearbeid': ('linjearbeid',),
'linjearbeida': ('linjearbeid',),
'linjearbeidene': ('linjearbeid',),
'linjearbeider': ('linjearbeid',),
'linjearbeidet': ('linjearbeid',),
'linjebrott': ('linjebrott',),
'linjebrotta': ('linjebrott',),
'linjebrottene': ('linjebrott',),
'linjebrottet': ('linjebrott',),
'linjebrudd': ('linjebrudd',),
'linjebrudda': ('linjebrudd',),
'linjebruddene': ('linjebrudd',),
'linjebruddet': ('linjebrudd',),
'linjedeling': ('linjedeling',),
'linjedelinga': ('linjedeling',),
'linjedelingen': ('linjedeling',),
'linjedelingene': ('linjedeling',),
'linjedelinger': ('linjedeling',),
'linjedommer': ('linjedommer',),
'linjedommere': ('linjedommer',),
'linjedommeren': ('linjedommer',),
'linjedommerer': ('linjedommer',),
'linjedommerne': ('linjedommer',),
'linjefart': ('linjefart',),
'linjefarten': ('linjefart',),
'linjefartene': ('linjefart',),
'linjefarter': ('linjefart',),
'linjemann': ('linjemann',),
'linjemannen': ('linjemann',),
'linjemenn': ('linjemann',),
'linjemennene': ('linjemann',),
'linjenummer': ('linjenummer',),
'linjenummeret': ('linjenummer',),
'linjenumra': ('linjenummer',),
'linjenumre': ('linjenummer',),
'linjenumrene': ('linjenummer',),
'linjepapir': ('linjepapir',),
'linjepapira': ('linjepapir',),
'linjepapirene': ('linjepapir',),
'linjepapirer': ('linjepapir',),
'linjepapiret': ('linjepapir',),
'linjerederi': ('linjerederi',),
'linjerederia': ('linjerederi',),
'linjerederiene': ('linjerederi',),
'linjerederier': ('linjerederi',),
'linjerederiet': ('linjerederi',),
'linjeskift': ('linjeskift',),
'linjeskifta': ('linjeskift',),
'linjeskiftene': ('linjeskift',),
'linjeskiftet': ('linjeskift',),
'linjeskifta': ('linjeskifte',),
'linjeskifte': ('linjeskifte',),
'linjeskiftene': ('linjeskifte',),
'linjeskifter': ('linjeskifte',),
'linjeskiftet': ('linjeskifte',),
'linjeskip': ('linjeskip',),
'linjeskipa': ('linjeskip',),
'linjeskipene': ('linjeskip',),
'linjeskipet': ('linjeskip',),
'linjeskriver': ('linjeskriver',),
'linjeskrivere': ('linjeskriver',),
'linjeskriveren': ('linjeskriver',),
'linjeskriverer': ('linjeskriver',),
'linjeskriverne': ('linjeskriver',),
'linjesystem': ('linjesystem',),
'linjesystema': ('linjesystem',),
'linjesystemene': ('linjesystem',),
'linjesystemer': ('linjesystem',),
'linjesystemet': ('linjesystem',),
'link': ('link',),
'linken': ('link',),
'linkene': ('link',),
'linker': ('link',),
'linksskrue': ('linksskrue',),
'linksskruen': ('linksskrue',),
'linksskruene': ('linksskrue',),
'linksskruer': ('linksskrue',),
'linksskruve': ('linksskruve',),
'linksskruven': ('linksskruve',),
'linksskruvene': ('linksskruve',),
'linksskruver': ('linksskruve',),
'linksskytter': ('linksskytter',),
'linksskyttere': ('linksskytter',),
'linksskytteren': ('linksskytter',),
'linksskytterer': ('linksskytter',),
'linksskytterne': ('linksskytter',),
'linkstasjon': ('linkstasjon',),
'linkstasjonen': ('linkstasjon',),
'linkstasjonene': ('linkstasjon',),
'linkstasjoner': ('linkstasjon',),
'linna': ('linne',),
'linne': ('linne',),
'linnen': ('linne',),
'linnene': ('linne',),
'linner': ('linne',),
'linnea': ('linnea',),
'linneaen': ('linnea',),
'linneaene': ('linnea',),
'linneaer': ('linnea',),
'linnet': ('linnet',),
'linneta': ('linnet',),
'linnetene': ('linnet',),
'linneter': ('linnet',),
'linnetet': ('linnet',),
'linnetskap': ('linnetskap',),
'linnetskapa': ('linnetskap',),
'linnetskapene': ('linnetskap',),
'linnetskapet': ('linnetskap',),
'linning': ('linning',),
'linninga': ('linning',),
'linningen': ('linning',),
'linningene': ('linning',),
'linninger': ('linning',),
'linnvær': ('linnvær',),
'linnværa': ('linnvær',),
'linnværene': ('linnvær',),
'linnværet': ('linnvær',),
'linolensyra': ('linolensyre',),
'linolensyre': ('linolensyre',),
'linolensyren': ('linolensyre',),
'linolensyrene': ('linolensyre',),
'linolensyrer': ('linolensyre',),
'linoleum': ('linoleum',),
'linoleumen': ('linoleum',),
'linoleumene': ('linoleum',),
'linoleumer': ('linoleum',),
'linoleumssnitt': ('linoleumssnitt',),
'linoleumssnitta': ('linoleumssnitt',),
'linoleumssnittene': ('linoleumssnitt',),
'linoleumssnittet': ('linoleumssnitt',),
'linoleumstrykk': ('linoleumstrykk',),
'linoleumstrykka': ('linoleumstrykk',),
'linoleumstrykkene': ('linoleumstrykk',),
'linoleumstrykket': ('linoleumstrykk',),
'linolja': ('linolje',),
'linolje': ('linolje',),
'linoljen': ('linolje',),
'linoljene': ('linolje',),
'linoljer': ('linolje',),
'linolsyra': ('linolsyre',),
'linolsyre': ('linolsyre',),
'linolsyren': ('linolsyre',),
'linolsyrene': ('linolsyre',),
'linolsyrer': ('linolsyre',),
'linon': ('linon',),
'linona': ('linon',),
'linonen': ('linon',),
'linonene': ('linon',),
'linoner': ('linon',),
'linonet': ('linon',),
'linotype': ('linotype',),
'linotypen': ('linotype',),
'linotypene': ('linotype',),
'linotyper': ('linotype',),
'linsa': ('linse',),
'linse': ('linse',),
'linsen': ('linse',),
'linsene': ('linse',),
'linser': ('linse',),
'linsefrø': ('linsefrø',),
'linsefrøa': ('linsefrø',),
'linsefrøene': ('linsefrø',),
'linsefrøet': ('linsefrø',),
'linselus': ('linselus',),
'linselusa': ('linselus',),
'linselusen': ('linselus',),
'linselusene': ('linselus',),
'linsøster': ('linsøster',),
'linsøstera': ('linsøster',),
'linsøsteren': ('linsøster',),
'linsøstre': ('linsøster',),
'linsøstrene': ('linsøster',),
'linsøstrer': ('linsøster',),
'lintorskemunn': ('lintorskemunn',),
'lintorskemunnen': ('lintorskemunn',),
'lintorskemunnene': ('lintorskemunn',),
'lintorskemunner': ('lintorskemunn',),
'lintøyskap': ('lintøyskap',),
'lintøyskapa': ('lintøyskap',),
'lintøyskapene': ('lintøyskap',),
'lintøyskapet': ('lintøyskap',),
'lipid': ('lipid',),
'lipida': ('lipid',),
'lipidene': ('lipid',),
'lipider': ('lipid',),
'lipidet': ('lipid',),
'lire': ('lire',),
'liren': ('lire',),
'lirene': ('lire',),
'lira': ('lire',),
'lire': ('lire',),
'liren': ('lire',),
'lirene': ('lire',),
'lirer': ('lire',),
'lira': ('lire',),
'lire': ('lire',),
'liren': ('lire',),
'lirene': ('lire',),
'lirer': ('lire',),
'lirekassa': ('lirekasse',),
'lirekasse': ('lirekasse',),
'lirekassen': ('lirekasse',),
'lirekassene': ('lirekasse',),
'lirekasser': ('lirekasse',),
'lirumlarum': ('lirumlarum',),
'lirumlaruma': ('lirumlarum',),
'lirumlarumene': ('lirumlarum',),
'lirumlarumet': ('lirumlarum',),
'lirypa': ('lirype',),
'lirype': ('lirype',),
'lirypen': ('lirype',),
'lirypene': ('lirype',),
'liryper': ('lirype',),
'lisa': ('lise',),
'lise': ('lise',),
'lisen': ('lise',),
'lisene': ('lise',),
'liser': ('lise',),
'lisens': ('lisens',),
'lisensen': ('lisens',),
'lisensene': ('lisens',),
'lisenser': ('lisens',),
'lisensavgift': ('lisensavgift',),
'lisensavgifta': ('lisensavgift',),
'lisensavgiften': ('lisensavgift',),
'lisensavgiftene': ('lisensavgift',),
'lisensavgifter': ('lisensavgift',),
'lisensiat': ('lisensiat',),
'lisensiaten': ('lisensiat',),
'lisensiatene': ('lisensiat',),
'lisensiater': ('lisensiat',),
'lisensiatgrad': ('lisensiatgrad',),
'lisensiatgraden': ('lisensiatgrad',),
'lisensiatgradene': ('lisensiatgrad',),
'lisensiatgrader': ('lisensiatgrad',),
'lisitant': ('lisitant',),
'lisitanten': ('lisitant',),
'lisitantene': ('lisitant',),
'lisitanter': ('lisitant',),
'lisitasjon': ('lisitasjon',),
'lisitasjonen': ('lisitasjon',),
'lisitasjonene': ('lisitasjon',),
'lisitasjoner': ('lisitasjon',),
'lispund': ('lispund',),
'lispunda': ('lispund',),
'lispundene': ('lispund',),
'lispundet': ('lispund',),
'lissa': ('lisse',),
'lisse': ('lisse',),
'lissen': ('lisse',),
'lissene': ('lisse',),
'lisser': ('lisse',),
'lissing': ('lissing',),
'lissinga': ('lissing',),
'lissingen': ('lissing',),
'lissingene': ('lissing',),
'lissinger': ('lissing',),
'lista': ('liste',),
'liste': ('liste',),
'listen': ('liste',),
'listene': ('liste',),
'lister': ('liste',),
'lista': ('liste',),
'liste': ('liste',),
'listen': ('liste',),
'listene': ('liste',),
'lister': ('liste',),
'listeavstemning': ('listeavstemning',),
'listeavstemninga': ('listeavstemning',),
'listeavstemningen': ('listeavstemning',),
'listeavstemningene': ('listeavstemning',),
'listeavstemninger': ('listeavstemning',),
'listebærer': ('listebærer',),
'listebærere': ('listebærer',),
'listebæreren': ('listebærer',),
'listebærerer': ('listebærer',),
'listebærerne': ('listebærer',),
'listeforbund': ('listeforbund',),
'listeforbunda': ('listeforbund',),
'listeforbundene': ('listeforbund',),
'listeforbundet': ('listeforbund',),
'listepris': ('listepris',),
'listeprisen': ('listepris',),
'listeprisene': ('listepris',),
'listepriser': ('listepris',),
'listerbåt': ('listerbåt',),
'listerbåten': ('listerbåt',),
'listerbåtene': ('listerbåt',),
'listerbåter': ('listerbåt',),
'listesamband': ('listesamband',),
'listesambanda': ('listesamband',),
'listesambandene': ('listesamband',),
'listesambandet': ('listesamband',),
'listevalg': ('listevalg',),
'listevalga': ('listevalg',),
'listevalgene': ('listevalg',),
'listevalget': ('listevalg',),
'listring': ('listring',),
'listringen': ('listring',),
'listringene': ('listring',),
'listringer': ('listring',),
'listverk': ('listverk',),
'listverka': ('listverk',),
'listverkene': ('listverk',),
'listverket': ('listverk',),
'lit': ('lit',),
'lita': ('lit',),
'liten': ('lit',),
'litene': ('lit',),
'liter': ('lit',),
'lit': ('lit',),
'lita': ('lit',),
'liten': ('lit',),
'litene': ('lit',),
'liter': ('lit',),
'lit de parade': ('lit de parade',),
'litani': ('litani',),
'litania': ('litani',),
'litaniene': ('litani',),
'litanier': ('litani',),
'litaniet': ('litani',),
'litauer': ('litauer',),
'litauere': ('litauer',),
'litaueren': ('litauer',),
'litauerer': ('litauer',),
'litauerne': ('litauer',),
'litchi': ('litchi',),
'litchien': ('litchi',),
'litchiene': ('litchi',),
'litchier': ('litchi',),
'liter': ('liter',),
'literen': ('liter',),
'literne': ('liter',),
'litermål': ('litermål',),
'litermåla': ('litermål',),
'litermålene': ('litermål',),
'litermålet': ('litermål',),
'litium': ('litium',),
'litiuma': ('litium',),
'litiumene': ('litium',),
'litiumet': ('litium',),
'litograf': ('litograf',),
'litografen': ('litograf',),
'litografene': ('litograf',),
'litografer': ('litograf',),
'litolog': ('litolog',),
'litologen': ('litolog',),
'litologene': ('litolog',),
'litologer': ('litolog',),
'litologi': ('litologi',),
'litologien': ('litologi',),
'litologiene': ('litologi',),
'litologier': ('litologi',),
'litot': ('litot',),
'litoten': ('litot',),
'litotene': ('litot',),
'litoter': ('litot',),
'litotes': ('litotes',),
'litotesen': ('litotes',),
'litotesene': ('litotes',),
'litoteser': ('litotes',),
'litterat': ('litterat',),
'litteraten': ('litterat',),
'litteratene': ('litterat',),
'litterater': ('litterat',),
'litteratur': ('litteratur',),
'litteraturen': ('litteratur',),
'litteraturene': ('litteratur',),
'litteraturer': ('litteratur',),
'litteraturanmelder': ('litteraturanmelder',),
'litteraturanmeldere': ('litteraturanmelder',),
'litteraturanmelderen': ('litteraturanmelder',),
'litteraturanmelderer': ('litteraturanmelder',),
'litteraturanmelderne': ('litteraturanmelder',),
'litteraturforsker': ('litteraturforsker',),
'litteraturforskere': ('litteraturforsker',),
'litteraturforskeren': ('litteraturforsker',),
'litteraturforskerer': ('litteraturforsker',),
'litteraturforskerne': ('litteraturforsker',),
'litteraturhistoria': ('litteraturhistorie',),
'litteraturhistorie': ('litteraturhistorie',),
'litteraturhistorien': ('litteraturhistorie',),
'litteraturhistoriene': ('litteraturhistorie',),
'litteraturhistorier': ('litteraturhistorie',),
'litteraturkritikk': ('litteraturkritikk',),
'litteraturkritikken': ('litteraturkritikk',),
'litteraturkritikkene': ('litteraturkritikk',),
'litteraturkritikker': ('litteraturkritikk',),
'litteraturspråk': ('litteraturspråk',),
'litteraturspråka': ('litteraturspråk',),
'litteraturspråkene': ('litteraturspråk',),
'litteraturspråket': ('litteraturspråk',),
'liturg': ('liturg',),
'liturgen': ('liturg',),
'liturgene': ('liturg',),
'liturger': ('liturg',),
'liturgi': ('liturgi',),
'liturgien': ('liturgi',),
'liturgiene': ('liturgi',),
'liturgier': ('liturgi',),
'liv': ('liv',),
'liva': ('liv',),
'livene': ('liv',),
'livet': ('liv',),
'livbelta': ('livbelte',),
'livbelte': ('livbelte',),
'livbeltene': ('livbelte',),
'livbelter': ('livbelte',),
'livbeltet': ('livbelte',),
'livbåt': ('livbåt',),
'livbåten': ('livbåt',),
'livbåtene': ('livbåt',),
'livbåter': ('livbåt',),
'livbøya': ('livbøye',),
'livbøye': ('livbøye',),
'livbøyen': ('livbøye',),
'livbøyene': ('livbøye',),
'livbøyer': ('livbøye',),
'livd': ('livd',),
'livda': ('livd',),
'livden': ('livd',),
'livdene': ('livd',),
'livder': ('livd',),
'livdyr': ('livdyr',),
'livdyra': ('livdyr',),
'livdyrene': ('livdyr',),
'livdyret': ('livdyr',),
'live': ('live',),
'livegenskap': ('livegenskap',),
'livegenskapa': ('livegenskap',),
'livegenskapene': ('livegenskap',),
'livegenskapet': ('livegenskap',),
'liveopptak': ('liveopptak',),
'liveopptaka': ('liveopptak',),
'liveopptakene': ('liveopptak',),
'liveopptaket': ('liveopptak',),
'liver': ('liver',),
'livere': ('liver',),
'liveren': ('liver',),
'liverer': ('liver',),
'liverne': ('liver',),
'livgarde': ('livgarde',),
'livgarden': ('livgarde',),
'livgardene': ('livgarde',),
'livgarder': ('livgarde',),
'livgardist': ('livgardist',),
'livgardisten': ('livgardist',),
'livgardistene': ('livgardist',),
'livgardister': ('livgardist',),
'livgjord': ('livgjord',),
'livgjorda': ('livgjord',),
'livgjorden': ('livgjord',),
'livgjordene': ('livgjord',),
'livgjorder': ('livgjord',),
'livkjole': ('livkjole',),
'livkjolen': ('livkjole',),
'livkjolene': ('livkjole',),
'livkjoler': ('livkjole',),
'livlege': ('livlege',),
'livlegen': ('livlege',),
'livlegene': ('livlege',),
'livleger': ('livlege',),
'livlender': ('livlender',),
'livlendere': ('livlender',),
'livlenderen': ('livlender',),
'livlenderer': ('livlender',),
'livlenderne': ('livlender',),
'livlending': ('livlending',),
'livlendingen': ('livlending',),
'livlendingene': ('livlending',),
'livlendinger': ('livlending',),
'livlina': ('livline',),
'livline': ('livline',),
'livlinen': ('livline',),
'livlinene': ('livline',),
'livliner': ('livline',),
'livløshet': ('livløshet',),
'livløsheta': ('livløshet',),
'livløsheten': ('livløshet',),
'livløshetene': ('livløshet',),
'livløsheter': ('livløshet',),
'livløysa': ('livløyse',),
'livløyse': ('livløyse',),
'livløysen': ('livløyse',),
'livløysene': ('livløyse',),
'livløyser': ('livløyse',),
'livmor': ('livmor',),
'livmora': ('livmor',),
'livmoren': ('livmor',),
'livmorene': ('livmor',),
'livmorer': ('livmor',),
'livmorhals': ('livmorhals',),
'livmorhalsen': ('livmorhals',),
'livmorhalsene': ('livmorhals',),
'livmorhalser': ('livmorhals',),
'livmorkreft': ('livmorkreft',),
'livmorkreften': ('livmorkreft',),
'livmorkreftene': ('livmorkreft',),
'livmorkrefter': ('livmorkreft',),
'livpulsåra': ('livpulsåre',),
'livpulsåre': ('livpulsåre',),
'livpulsåren': ('livpulsåre',),
'livpulsårene': ('livpulsåre',),
'livpulsårer': ('livpulsåre',),
'livrea': ('livré',),
'livreene': ('livré',),
'livreer': ('livré',),
'livreet': ('livré',),
'livré': ('livré',),
'livréa': ('livré',),
'livréene': ('livré',),
'livréer': ('livré',),
'livréet': ('livré',),
'livredder': ('livredder',),
'livreddere': ('livredder',),
'livredderen': ('livredder',),
'livredderer': ('livredder',),
'livredderne': ('livredder',),
'livredning': ('livredning',),
'livredninga': ('livredning',),
'livredningen': ('livredning',),
'livredningene': ('livredning',),
'livredninger': ('livredning',),
'livreim': ('livreim',),
'livreima': ('livreim',),
'livreimen': ('livreim',),
'livreimene': ('livreim',),
'livreimer': ('livreim',),
'livrenta': ('livrente',),
'livrente': ('livrente',),
'livrenten': ('livrente',),
'livrentene': ('livrente',),
'livrenter': ('livrente',),
'livrett': ('livrett',),
'livretten': ('livrett',),
'livrettene': ('livrett',),
'livretter': ('livrett',),
'livsaften': ('livsaften',),
'livsaftenen': ('livsaften',),
'livsaftenene': ('livsaften',),
'livsaftener': ('livsaften',),
'livsanskuelse': ('livsanskuelse',),
'livsanskuelsen': ('livsanskuelse',),
'livsanskuelsene': ('livsanskuelse',),
'livsanskuelser': ('livsanskuelse',),
'livsarving': ('livsarving',),
'livsarvingen': ('livsarving',),
'livsarvingene': ('livsarving',),
'livsarvinger': ('livsarving',),
'livsbetraktning': ('livsbetraktning',),
'livsbetraktninga': ('livsbetraktning',),
'livsbetraktningen': ('livsbetraktning',),
'livsbetraktningene': ('livsbetraktning',),
'livsbetraktninger': ('livsbetraktning',),
'livseliksir': ('livseliksir',),
'livseliksiren': ('livseliksir',),
'livseliksirene': ('livseliksir',),
'livseliksirer': ('livseliksir',),
'livserfaring': ('livserfaring',),
'livserfaringa': ('livserfaring',),
'livserfaringen': ('livserfaring',),
'livserfaringene': ('livserfaring',),
'livserfaringer': ('livserfaring',),
'livsfange': ('livsfange',),
'livsfangen': ('livsfange',),
'livsfangene': ('livsfange',),
'livsfanger': ('livsfange',),
'livsfare': ('livsfare',),
'livsfaren': ('livsfare',),
'livsfarene': ('livsfare',),
'livsfarer': ('livsfare',),
'livsfilosofi': ('livsfilosofi',),
'livsfilosofien': ('livsfilosofi',),
'livsfilosofiene': ('livsfilosofi',),
'livsfilosofier': ('livsfilosofi',),
'livsform': ('livsform',),
'livsforma': ('livsform',),
'livsformen': ('livsform',),
'livsformene': ('livsform',),
'livsformer': ('livsform',),
'livsfornødenhet': ('livsfornødenhet',),
'livsfornødenheta': ('livsfornødenhet',),
'livsfornødenheten': ('livsfornødenhet',),
'livsfornødenhetene': ('livsfornødenhet',),
'livsfornødenheter': ('livsfornødenhet',),
'livsforsikring': ('livsforsikring',),
'livsforsikringa': ('livsforsikring',),
'livsforsikringen': ('livsforsikring',),
'livsforsikringene': ('livsforsikring',),
'livsforsikringer': ('livsforsikring',),
'livsførsel': ('livsførsel',),
'livsførselen': ('livsførsel',),
'livsførslene': ('livsførsel',),
'livsførsler': ('livsførsel',),
'livsgjerning': ('livsgjerning',),
'livsgjerninga': ('livsgjerning',),
'livsgjerningen': ('livsgjerning',),
'livsgjerningene': ('livsgjerning',),
'livsgjerninger': ('livsgjerning',),
'livsgleda': ('livsglede',),
'livsglede': ('livsglede',),
'livsgleden': ('livsglede',),
'livsgledene': ('livsglede',),
'livsgleder': ('livsglede',),
'livsgrunnlag': ('livsgrunnlag',),
'livsgrunnlaga': ('livsgrunnlag',),
'livsgrunnlagene': ('livsgrunnlag',),
'livsgrunnlaget': ('livsgrunnlag',),
'livshistoria': ('livshistorie',),
'livshistorie': ('livshistorie',),
'livshistorien': ('livshistorie',),
'livshistoriene': ('livshistorie',),
'livshistorier': ('livshistorie',),
'livsholdning': ('livsholdning',),
'livsholdninga': ('livsholdning',),
'livsholdningen': ('livsholdning',),
'livsholdningene': ('livsholdning',),
'livsholdninger': ('livsholdning',),
'livsinnhold': ('livsinnhold',),
'livsinnholda': ('livsinnhold',),
'livsinnholdene': ('livsinnhold',),
'livsinnholdet': ('livsinnhold',),
'livskamp': ('livskamp',),
'livskampen': ('livskamp',),
'livskampene': ('livskamp',),
'livskamper': ('livskamp',),
'livskraft': ('livskraft',),
'livskrafta': ('livskraft',),
'livskraften': ('livskraft',),
'livskreftene': ('livskraft',),
'livskrefter': ('livskraft',),
'livskunst': ('livskunst',),
'livskunsten': ('livskunst',),
'livskunstene': ('livskunst',),
'livskunster': ('livskunst',),
'livskunstner': ('livskunstner',),
'livskunstnere': ('livskunstner',),
'livskunstneren': ('livskunstner',),
'livskunstnerer': ('livskunstner',),
'livskunstnerne': ('livskunstner',),
'livskvalitet': ('livskvalitet',),
'livskvaliteten': ('livskvalitet',),
'livskvalitetene': ('livskvalitet',),
'livskvaliteter': ('livskvalitet',),
'livslede': ('livslede',),
'livsleden': ('livslede',),
'livsledene': ('livslede',),
'livsleder': ('livslede',),
'livsledsager': ('livsledsager',),
'livsledsagere': ('livsledsager',),
'livsledsageren': ('livsledsager',),
'livsledsagerer': ('livsledsager',),
'livsledsagerne': ('livsledsager',),
'livslov': ('livslov',),
'livsloven': ('livslov',),
'livslovene': ('livslov',),
'livslover': ('livslov',),
'livsløgn': ('livsløgn',),
'livsløgna': ('livsløgn',),
'livsløgnen': ('livsløgn',),
'livsløgnene': ('livsløgn',),
'livsløgner': ('livsløgn',),
'livsløp': ('livsløp',),
'livsløpa': ('livsløp',),
'livsløpene': ('livsløp',),
'livsløpet': ('livsløp',),
'livsmot': ('livsmot',),
'livsmota': ('livsmot',),
'livsmotene': ('livsmot',),
'livsmotet': ('livsmot',),
'livsmønster': ('livsmønster',),
'livsmønsteret': ('livsmønster',),
'livsmønstra': ('livsmønster',),
'livsmønstre': ('livsmønster',),
'livsmønstrene': ('livsmønster',),
'livsmønstret': ('livsmønster',),
'livsnerve': ('livsnerve',),
'livsnerven': ('livsnerve',),
'livsnervene': ('livsnerve',),
'livsnerver': ('livsnerve',),
'livsoppgava': ('livsoppgave',),
'livsoppgave': ('livsoppgave',),
'livsoppgaven': ('livsoppgave',),
'livsoppgavene': ('livsoppgave',),
'livsoppgaver': ('livsoppgave',),
'livsopphold': ('livsopphold',),
'livsoppholda': ('livsopphold',),
'livsoppholdene': ('livsopphold',),
'livsoppholdet': ('livsopphold',),
'livspolise': ('livspolise',),
'livspolisen': ('livspolise',),
'livspolisene': ('livspolise',),
'livspoliser': ('livspolise',),
'livssak': ('livssak',),
'livssaka': ('livssak',),
'livssaken': ('livssak',),
'livssakene': ('livssak',),
'livssaker': ('livssak',),
'livssituasjon': ('livssituasjon',),
'livssituasjonen': ('livssituasjon',),
'livssituasjonene': ('livssituasjon',),
'livssituasjoner': ('livssituasjon',),
'livsskildring': ('livsskildring',),
'livsskildringa': ('livsskildring',),
'livsskildringen': ('livsskildring',),
'livsskildringene': ('livsskildring',),
'livsskildringer': ('livsskildring',),
'livsstandard': ('livsstandard',),
'livsstandarden': ('livsstandard',),
'livsstandardene': ('livsstandard',),
'livsstandarder': ('livsstandard',),
'livsstil': ('livsstil',),
'livsstilen': ('livsstil',),
'livsstilene': ('livsstil',),
'livsstiler': ('livsstil',),
'livsstilssjukdom': ('livsstilssjukdom',),
'livsstilssjukdommen': ('livsstilssjukdom',),
'livsstilssjukdommene': ('livsstilssjukdom',),
'livsstilssjukdommer': ('livsstilssjukdom',),
'livsstilssykdom': ('livsstilssykdom',),
'livsstilssykdommen': ('livsstilssykdom',),
'livsstilssykdommene': ('livsstilssykdom',),
'livsstilssykdommer': ('livsstilssykdom',),
'livsstraff': ('livsstraff',),
'livsstraffen': ('livsstraff',),
'livsstraffene': ('livsstraff',),
'livsstraffer': ('livsstraff',),
'livssyklus': ('livssyklus',),
'livssyklusen': ('livssyklus',),
'livssyklusene': ('livssyklus',),
'livssykluser': ('livssyklus',),
'livssyn': ('livssyn',),
'livssyna': ('livssyn',),
'livssynene': ('livssyn',),
'livssynet': ('livssyn',),
'livssynsorientering': ('livssynsorientering',),
'livssynsorienteringa': ('livssynsorientering',),
'livssynsorienteringen': ('livssynsorientering',),
'livssynsorienteringene': ('livssynsorientering',),
'livssynsorienteringer': ('livssynsorientering',),
'livssynsskole': ('livssynsskole',),
'livssynsskolen': ('livssynsskole',),
'livssynsskolene': ('livssynsskole',),
'livssynsskoler': ('livssynsskole',),
'livssynsundervisning': ('livssynsundervisning',),
'livssynsundervisninga': ('livssynsundervisning',),
'livssynsundervisningen': ('livssynsundervisning',),
'livssynsundervisningene': ('livssynsundervisning',),
'livssynsundervisninger': ('livssynsundervisning',),
'livstegn': ('livstegn',),
'livstegna': ('livstegn',),
'livstegnene': ('livstegn',),
'livstegnet': ('livstegn',),
'livstestament': ('livstestament',),
'livstestamenta': ('livstestament',),
'livstestamentene': ('livstestament',),
'livstestamenter': ('livstestament',),
'livstestamentet': ('livstestament',),
'livstestamenta': ('livstestamente',),
'livstestamente': ('livstestamente',),
'livstestamentene': ('livstestamente',),
'livstestamenter': ('livstestamente',),
'livstestamentet': ('livstestamente',),
'livstid': ('livstid',),
'livstida': ('livstid',),
'livstiden': ('livstid',),
'livstidene': ('livstid',),
'livstider': ('livstid',),
'livstro': ('livstro',),
'livstroa': ('livstro',),
'livstroen': ('livstro',),
'livstroene': ('livstro',),
'livstroer': ('livstro',),
'livstru': ('livstru',),
'livstrua': ('livstru',),
'livstruen': ('livstru',),
'livstruene': ('livstru',),
'livstruer': ('livstru',),
'livstykka': ('livstykke',),
'livstykke': ('livstykke',),
'livstykkene': ('livstykke',),
'livstykker': ('livstykke',),
'livstykket': ('livstykke',),
'livsverk': ('livsverk',),
'livsverka': ('livsverk',),
'livsverkene': ('livsverk',),
'livsverker': ('livsverk',),
'livsverket': ('livsverk',),
'livsvilje': ('livsvilje',),
'livsviljen': ('livsvilje',),
'livsviljene': ('livsvilje',),
'livsviljer': ('livsvilje',),
'livsvilkår': ('livsvilkår',),
'livsvilkåra': ('livsvilkår',),
'livsvilkårene': ('livsvilkår',),
'livsvilkåret': ('livsvilkår',),
'livsvisdom': ('livsvisdom',),
'livsvisdommen': ('livsvisdom',),
'livsvisdommene': ('livsvisdom',),
'livsvisdommer': ('livsvisdom',),
'livsytring': ('livsytring',),
'livsytringa': ('livsytring',),
'livsytringen': ('livsytring',),
'livsytringene': ('livsytring',),
'livsytringer': ('livsytring',),
'livtak': ('livtak',),
'livtaka': ('livtak',),
'livtakene': ('livtak',),
'livtaket': ('livtak',),
'livvakt': ('livvakt',),
'livvakta': ('livvakt',),
'livvakten': ('livvakt',),
'livvaktene': ('livvakt',),
'livvakter': ('livvakt',),
'livvidda': ('livvidde',),
'livvidde': ('livvidde',),
'livvidden': ('livvidde',),
'livviddene': ('livvidde',),
'livvidder': ('livvidde',),
'ljom': ('ljom',),
'ljomen': ('ljom',),
'ljomene': ('ljom',),
'ljomer': ('ljom',),
'ljore': ('ljore',),
'ljoren': ('ljore',),
'ljorene': ('ljore',),
'ljorer': ('ljore',),
'ljorestang': ('ljorestang',),
'ljorestanga': ('ljorestang',),
'ljorestangen': ('ljorestang',),
'ljorestengene': ('ljorestang',),
'ljorestenger': ('ljorestang',),
'ljorestova': ('ljorestove',),
'ljorestove': ('ljorestove',),
'ljorestoven': ('ljorestove',),
'ljorestovene': ('ljorestove',),
'ljorestover': ('ljorestove',),
'ljorestua': ('ljorestue',),
'ljorestue': ('ljorestue',),
'ljorestuen': ('ljorestue',),
'ljorestuene': ('ljorestue',),
'ljorestuer': ('ljorestue',),
'ljug': ('ljug',),
'ljuga': ('ljug',),
'ljugene': ('ljug',),
'ljuget': ('ljug',),
'ljå': ('ljå',),
'ljåen': ('ljå',),
'ljåene': ('ljå',),
'ljåer': ('ljå',),
'ljåblom': ('ljåblom',),
'ljåblommen': ('ljåblom',),
'ljåblommene': ('ljåblom',),
'ljåblommer': ('ljåblom',),
'ljådrag': ('ljådrag',),
'ljådraga': ('ljådrag',),
'ljådragene': ('ljådrag',),
'ljådraget': ('ljådrag',),
'ljåorv': ('ljåorv',),
'ljåorva': ('ljåorv',),
'ljåorvene': ('ljåorv',),
'ljåorvet': ('ljåorv',),
'ljåslått': ('ljåslått',),
'ljåslåtten': ('ljåslått',),
'ljåslåttene': ('ljåslått',),
'ljåslåtter': ('ljåslått',),
'lo': ('lo',),
'loen': ('lo',),
'loene': ('lo',),
'loer': ('lo',),
'lo': ('lo',),
'loa': ('lo',),
'loene': ('lo',),
'loet': ('lo',),
'lobb': ('lobb',),
'lobben': ('lobb',),
'lobbene': ('lobb',),
'lobber': ('lobb',),
'lobby': ('lobby',),
'lobbyen': ('lobby',),
'lobbyene': ('lobby',),
'lobbyer': ('lobby',),
'lobbyist': ('lobbyist',),
'lobbyisten': ('lobbyist',),
'lobbyistene': ('lobbyist',),
'lobbyister': ('lobbyist',),
'lobbyvirksomhet': ('lobbyvirksomhet',),
'lobbyvirksomheta': ('lobbyvirksomhet',),
'lobbyvirksomheten': ('lobbyvirksomhet',),
'lobbyvirksomhetene': ('lobbyvirksomhet',),
'lobbyvirksomheter': ('lobbyvirksomhet',),
'lobelia': ('lobelia',),
'lobeliaen': ('lobelia',),
'lobeliaene': ('lobelia',),
'lobeliaer': ('lobelia',),
'lobotomi': ('lobotomi',),
'lobotomien': ('lobotomi',),
'lobotomiene': ('lobotomi',),
'lobotomier': ('lobotomi',),
'lobyisme': ('lobyisme',),
'lobyismen': ('lobyisme',),
'lobyismene': ('lobyisme',),
'lobyismer': ('lobyisme',),
'location': ('location',),
'lockout': ('lockout',),
'lockouten': ('lockout',),
'lockoutene': ('lockout',),
'lockouter': ('lockout',),
'lockoutvarsel': ('lockoutvarsel',),
'lockoutvarselet': ('lockoutvarsel',),
'lockoutvarsla': ('lockoutvarsel',),
'lockoutvarslene': ('lockoutvarsel',),
'lockoutvarsler': ('lockoutvarsel',),
'lockoutvarslet': ('lockoutvarsel',),
'lodd': ('lodd',),
'lodden': ('lodd',),
'loddene': ('lodd',),
'lodder': ('lodd',),
'lodd': ('lodd',),
'lodda': ('lodd',),
'loddene': ('lodd',),
'lodder': ('lodd',),
'loddet': ('lodd',),
'lodd': ('lodd',),
'lodda': ('lodd',),
'loddene': ('lodd',),
'lodder': ('lodd',),
'loddet': ('lodd',),
'loddbok': ('loddbok',),
'loddboka': ('loddbok',),
'loddboken': ('loddbok',),
'loddbøkene': ('loddbok',),
'loddbøker': ('loddbok',),
'lodde': ('lodde',),
'lodden': ('lodde',),
'loddene': ('lodde',),
'lodder': ('lodde',),
'lodda': ('lodde',),
'lodde': ('lodde',),
'lodden': ('lodde',),
'loddene': ('lodde',),
'lodder': ('lodde',),
'loddebolt': ('loddebolt',),
'loddebolten': ('loddebolt',),
'loddeboltene': ('loddebolt',),
'loddebolter': ('loddebolt',),
'loddefiska': ('loddefiske',),
'loddefiske': ('loddefiske',),
'loddefiskene': ('loddefiske',),
'loddefisker': ('loddefiske',),
'loddefisket': ('loddefiske',),
'loddelampa': ('loddelampe',),
'loddelampe': ('loddelampe',),
'loddelampen': ('loddelampe',),
'loddelampene': ('loddelampe',),
'loddelamper': ('loddelampe',),
'loddetorsk': ('loddetorsk',),
'loddetorsken': ('loddetorsk',),
'loddetorskene': ('loddetorsk',),
'loddetorsker': ('loddetorsk',),
'lodding': ('lodding',),
'loddinga': ('lodding',),
'loddingen': ('lodding',),
'loddingene': ('lodding',),
'loddinger': ('lodding',),
'loddkast': ('loddkast',),
'loddkasta': ('loddkast',),
'loddkastene': ('loddkast',),
'loddkastet': ('loddkast',),
'loddlina': ('loddline',),
'loddline': ('loddline',),
'loddlinen': ('loddline',),
'loddlinene': ('loddline',),
'loddliner': ('loddline',),
'loddlinja': ('loddlinje',),
'loddlinje': ('loddlinje',),
'loddlinjen': ('loddlinje',),
'loddlinjene': ('loddlinje',),
'loddlinjer': ('loddlinje',),
'loddsalg': ('loddsalg',),
'loddsalga': ('loddsalg',),
'loddsalgene': ('loddsalg',),
'loddsalget': ('loddsalg',),
'loddselger': ('loddselger',),
'loddselgere': ('loddselger',),
'loddselgeren': ('loddselger',),
'loddselgerer': ('loddselger',),
'loddselgerne': ('loddselger',),
'loddskott': ('loddskott',),
'loddskotta': ('loddskott',),
'loddskottene': ('loddskott',),
'loddskottet': ('loddskott',),
'loddskudd': ('loddskudd',),
'loddskudda': ('loddskudd',),
'loddskuddene': ('loddskudd',),
'loddskuddet': ('loddskudd',),
'loddsnor': ('loddsnor',),
'loddsnora': ('loddsnor',),
'loddsnoren': ('loddsnor',),
'loddsnorene': ('loddsnor',),
'loddsnorer': ('loddsnor',),
'loddtrekning': ('loddtrekning',),
'loddtrekninga': ('loddtrekning',),
'loddtrekningen': ('loddtrekning',),
'loddtrekningene': ('loddtrekning',),
'loddtrekninger': ('loddtrekning',),
'loden': ('loden',),
'lodenen': ('loden',),
'lodenene': ('loden',),
'lodener': ('loden',),
'lodenfrakk': ('lodenfrakk',),
'lodenfrakken': ('lodenfrakk',),
'lodenfrakkene': ('lodenfrakk',),
'lodenfrakker': ('lodenfrakk',),
'lodenkåpa': ('lodenkåpe',),
'lodenkåpe': ('lodenkåpe',),
'lodenkåpen': ('lodenkåpe',),
'lodenkåpene': ('lodenkåpe',),
'lodenkåper': ('lodenkåpe',),
'lodje': ('lodje',),
'lodjen': ('lodje',),
'lodjene': ('lodje',),
'lodjer': ('lodje',),
'lodnebregna': ('lodnebregne',),
'lodnebregne': ('lodnebregne',),
'lodnebregnen': ('lodnebregne',),
'lodnebregnene': ('lodnebregne',),
'lodnebregner': ('lodnebregne',),
'lodnegras': ('lodnegras',),
'lodnegrasa': ('lodnegras',),
'lodnegrasene': ('lodnegras',),
'lodnegraset': ('lodnegras',),
'lodnegress': ('lodnegress',),
'lodnegressa': ('lodnegress',),
'lodnegressene': ('lodnegress',),
'lodnegresset': ('lodnegress',),
'lodott': ('lodott',),
'lodotten': ('lodott',),
'lodottene': ('lodott',),
'lodotter': ('lodott',),
'lofilter': ('lofilter',),
'lofilteret': ('lofilter',),
'lofiltra': ('lofilter',),
'lofiltre': ('lofilter',),
'lofiltrene': ('lofilter',),
'lofiltret': ('lofilter',),
'lofotfiska': ('lofotfiske',),
'lofotfiske': ('lofotfiske',),
'lofotfiskene': ('lofotfiske',),
'lofotfisker': ('lofotfiske',),
'lofotfisket': ('lofotfiske',),
'lofotskrei': ('lofotskrei',),
'lofotskreien': ('lofotskrei',),
'lofotskreiene': ('lofotskrei',),
'lofotskreier': ('lofotskrei',),
'lofotværing': ('lofotværing',),
'lofotværingen': ('lofotværing',),
'lofotværingene': ('lofotværing',),
'lofotværinger': ('lofotværing',),
'loft': ('loft',),
'lofta': ('loft',),
'loftene': ('loft',),
'loftet': ('loft',),
'loftbjelke': ('loftbjelke',),
'loftbjelken': ('loftbjelke',),
'loftbjelkene': ('loftbjelke',),
'loftbjelker': ('loftbjelke',),
'loftbod': ('loftbod',),
'loftboden': ('loftbod',),
'loftbodene': ('loftbod',),
'loftboder': ('loftbod',),
'loftbu': ('loftbu',),
'loftbua': ('loftbu',),
'loftbuen': ('loftbu',),
'loftbuene': ('loftbu',),
'loftbuer': ('loftbu',),
'loftleilighet': ('loftleilighet',),
'loftleiligheta': ('loftleilighet',),
'loftleiligheten': ('loftleilighet',),
'loftleilighetene': ('loftleilighet',),
'loftleiligheter': ('loftleilighet',),
'loftrydding': ('loftrydding',),
'loftryddinga': ('loftrydding',),
'loftryddingen': ('loftrydding',),
'loftryddingene': ('loftrydding',),
'loftryddinger': ('loftrydding',),
'loftsbod': ('loftsbod',),
'loftsboden': ('loftsbod',),
'loftsbodene': ('loftsbod',),
'loftsboder': ('loftsbod',),
'loftsbu': ('loftsbu',),
'loftsbua': ('loftsbu',),
'loftsbuen': ('loftsbu',),
'loftsbuene': ('loftsbu',),
'loftsbuer': ('loftsbu',),
'loftsleilighet': ('loftsleilighet',),
'loftsleiligheta': ('loftsleilighet',),
'loftsleiligheten': ('loftsleilighet',),
'loftsleilighetene': ('loftsleilighet',),
'loftsleiligheter': ('loftsleilighet',),
'loftsrydding': ('loftsrydding',),
'loftsryddinga': ('loftsrydding',),
'loftsryddingen': ('loftsrydding',),
'loftsryddingene': ('loftsrydding',),
'loftsryddinger': ('loftsrydding',),
'loftstrapp': ('loftstrapp',),
'loftstrappa': ('loftstrapp',),
'loftstrappen': ('loftstrapp',),
'loftstrappene': ('loftstrapp',),
'loftstrapper': ('loftstrapp',),
'loftsværelsa': ('loftsværelse',),
'loftsværelse': ('loftsværelse',),
'loftsværelsene': ('loftsværelse',),
'loftsværelser': ('loftsværelse',),
'loftsværelset': ('loftsværelse',),
'lofttrapp': ('lofttrapp',),
'lofttrappa': ('lofttrapp',),
'lofttrappen': ('lofttrapp',),
'lofttrappene': ('lofttrapp',),
'lofttrapper': ('lofttrapp',),
'loftværelsa': ('loftværelse',),
'loftværelse': ('loftværelse',),
'loftværelsene': ('loftværelse',),
'loftværelser': ('loftværelse',),
'loftværelset': ('loftværelse',),
'log': ('log',),
'logen': ('log',),
'logene': ('log',),
'loger': ('log',),
'loganbær': ('loganbær',),
'loganbæra': ('loganbær',),
'loganbærene': ('loganbær',),
'loganbæret': ('loganbær',),
'loganbær': ('loganbær',),
'loganbæra': ('loganbær',),
'loganbærene': ('loganbær',),
'loganbæret': ('loganbær',),
'logaritme': ('logaritme',),
'logaritmen': ('logaritme',),
'logaritmene': ('logaritme',),
'logaritmer': ('logaritme',),
'logaritmeregning': ('logaritmeregning',),
'logaritmeregninga': ('logaritmeregning',),
'logaritmeregningen': ('logaritmeregning',),
'logaritmeregningene': ('logaritmeregning',),
'logaritmeregninger': ('logaritmeregning',),
'logaritmerekning': ('logaritmerekning',),
'logaritmerekninga': ('logaritmerekning',),
'logaritmerekningen': ('logaritmerekning',),
'logaritmerekningene': ('logaritmerekning',),
'logaritmerekninger': ('logaritmerekning',),
'logaritmetabell': ('logaritmetabell',),
'logaritmetabellen': ('logaritmetabell',),
'logaritmetabellene': ('logaritmetabell',),
'logaritmetabeller': ('logaritmetabell',),
'loge': ('loge',),
'logen': ('loge',),
'logene': ('loge',),
'loger': ('loge',),
'logg': ('logg',),
'loggen': ('logg',),
'loggene': ('logg',),
'logger': ('logg',),
'logg': ('logg',),
'loggen': ('logg',),
'loggene': ('logg',),
'logger': ('logg',),
'loggbok': ('loggbok',),
'loggboka': ('loggbok',),
'loggboken': ('loggbok',),
'loggbøkene': ('loggbok',),
'loggbøker': ('loggbok',),
'loggia': ('loggia',),
'loggiaen': ('loggia',),
'loggiaene': ('loggia',),
'loggiaer': ('loggia',),
'logiker': ('logiker',),
'logikere': ('logiker',),
'logikeren': ('logiker',),
'logikerer': ('logiker',),
'logikerne': ('logiker',),
'logikk': ('logikk',),
'logikken': ('logikk',),
'logikkene': ('logikk',),
'logikker': ('logikk',),
'logisme': ('logisme',),
'logismen': ('logisme',),
'logismene': ('logisme',),
'logismer': ('logisme',),
'logistikk': ('logistikk',),
'logistikken': ('logistikk',),
'logistikkene': ('logistikk',),
'logistikker': ('logistikk',),
'logn': ('logn',),
'logna': ('logn',),
'lognen': ('logn',),
'lognene': ('logn',),
'logner': ('logn',),
'logo': ('logo',),
'logoen': ('logo',),
'logoene': ('logo',),
'logoer': ('logo',),
'logoped': ('logoped',),
'logopeden': ('logoped',),
'logopedene': ('logoped',),
'logopeder': ('logoped',),
'logopedi': ('logopedi',),
'logopedien': ('logopedi',),
'logopediene': ('logopedi',),
'logopedier': ('logopedi',),
'lojalitet': ('lojalitet',),
'lojaliteten': ('lojalitet',),
'lojalitetene': ('lojalitet',),
'lojaliteter': ('lojalitet',),
'lok': ('lok',),
'loka': ('lok',),
'lokene': ('lok',),
'loket': ('lok',),
'lokal': ('lokal',),
'lokalen': ('lokal',),
'lokalene': ('lokal',),
'lokaler': ('lokal',),
'lokalavis': ('lokalavis',),
'lokalavisa': ('lokalavis',),
'lokalavisen': ('lokalavis',),
'lokalavisene': ('lokalavis',),
'lokalaviser': ('lokalavis',),
'lokalbedøvelse': ('lokalbedøvelse',),
'lokalbedøvelsen': ('lokalbedøvelse',),
'lokalbedøvelsene': ('lokalbedøvelse',),
'lokalbedøvelser': ('lokalbedøvelse',),
'lokalbedøving': ('lokalbedøving',),
'lokalbedøvinga': ('lokalbedøving',),
'lokalbedøvingen': ('lokalbedøving',),
'lokalbedøvingene': ('lokalbedøving',),
'lokalbedøvinger': ('lokalbedøving',),
'lokalbåt': ('lokalbåt',),
'lokalbåten': ('lokalbåt',),
'lokalbåtene': ('lokalbåt',),
'lokalbåter': ('lokalbåt',),
'lokala': ('lokale',),
'lokale': ('lokale',),
'lokalene': ('lokale',),
'lokaler': ('lokale',),
'lokalet': ('lokale',),
'lokalfarge': ('lokalfarge',),
'lokalfargen': ('lokalfarge',),
'lokalfargene': ('lokalfarge',),
'lokalfarger': ('lokalfarge',),
'lokalhistoria': ('lokalhistorie',),
'lokalhistorie': ('lokalhistorie',),
'lokalhistorien': ('lokalhistorie',),
'lokalhistoriene': ('lokalhistorie',),
'lokalhistorier': ('lokalhistorie',),
'lokalisasjon': ('lokalisasjon',),
'lokalisasjonen': ('lokalisasjon',),
'lokalisasjonene': ('lokalisasjon',),
'lokalisasjoner': ('lokalisasjon',),
'lokalisering': ('lokalisering',),
'lokaliseringa': ('lokalisering',),
'lokaliseringen': ('lokalisering',),
'lokaliseringene': ('lokalisering',),
'lokaliseringer': ('lokalisering',),
'lokaliseringspolitikk': ('lokaliseringspolitikk',),
'lokaliseringspolitikken': ('lokaliseringspolitikk',),
'lokaliseringspolitikkene': ('lokaliseringspolitikk',),
'lokaliseringspolitikker': ('lokaliseringspolitikk',),
'lokalitet': ('lokalitet',),
'lokaliteten': ('lokalitet',),
'lokalitetene': ('lokalitet',),
'lokaliteter': ('lokalitet',),
'lokalkoloritt': ('lokalkoloritt',),
'lokalkoloritten': ('lokalkoloritt',),
'lokalkolorittene': ('lokalkoloritt',),
'lokalkoloritter': ('lokalkoloritt',),
'lokalkontor': ('lokalkontor',),
'lokalkontora': ('lokalkontor',),
'lokalkontorene': ('lokalkontor',),
'lokalkontorer': ('lokalkontor',),
'lokalkontoret': ('lokalkontor',),
'lokallag': ('lokallag',),
'lokallaga': ('lokallag',),
'lokallagene': ('lokallag',),
'lokallaget': ('lokallag',),
'lokalmiljø': ('lokalmiljø',),
'lokalmiljøa': ('lokalmiljø',),
'lokalmiljøene': ('lokalmiljø',),
'lokalmiljøer': ('lokalmiljø',),
'lokalmiljøet': ('lokalmiljø',),
'lokalpatriot': ('lokalpatriot',),
'lokalpatrioten': ('lokalpatriot',),
'lokalpatriotene': ('lokalpatriot',),
'lokalpatrioter': ('lokalpatriot',),
'lokalpatriotisme': ('lokalpatriotisme',),
'lokalpatriotismen': ('lokalpatriotisme',),
'lokalpatriotismene': ('lokalpatriotisme',),
'lokalpatriotismer': ('lokalpatriotisme',),
'lokalplan': ('lokalplan',),
'lokalplana': ('lokalplan',),
'lokalplanene': ('lokalplan',),
'lokalplanet': ('lokalplan',),
'lokalprogram': ('lokalprogram',),
'lokalprogramma': ('lokalprogram',),
'lokalprogrammene': ('lokalprogram',),
'lokalprogrammer': ('lokalprogram',),
'lokalprogrammet': ('lokalprogram',),
'lokalradio': ('lokalradio',),
'lokalradioen': ('lokalradio',),
'lokalradioene': ('lokalradio',),
'lokalradioer': ('lokalradio',),
'lokalsamfunn': ('lokalsamfunn',),
'lokalsamfunna': ('lokalsamfunn',),
'lokalsamfunnene': ('lokalsamfunn',),
'lokalsamfunnet': ('lokalsamfunn',),
'lokalsamtale': ('lokalsamtale',),
'lokalsamtalen': ('lokalsamtale',),
'lokalsamtalene': ('lokalsamtale',),
'lokalsamtaler': ('lokalsamtale',),
'lokaltakst': ('lokaltakst',),
'lokaltaksten': ('lokaltakst',),
'lokaltakstene': ('lokaltakst',),
'lokaltakster': ('lokaltakst',),
'lokaltelefon': ('lokaltelefon',),
'lokaltelefonen': ('lokaltelefon',),
'lokaltelefonene': ('lokaltelefon',),
'lokaltelefoner': ('lokaltelefon',),
'lokaltog': ('lokaltog',),
'lokaltoga': ('lokaltog',),
'lokaltogene': ('lokaltog',),
'lokaltoget': ('lokaltog',),
'lokaltrafikk': ('lokaltrafikk',),
'lokaltrafikken': ('lokaltrafikk',),
'lokaltrafikkene': ('lokaltrafikk',),
'lokaltrafikker': ('lokaltrafikk',),
'lokalutvalg': ('lokalutvalg',),
'lokalutvalga': ('lokalutvalg',),
'lokalutvalgene': ('lokalutvalg',),
'lokalutvalget': ('lokalutvalg',),
'lokativ': ('lokativ',),
'lokativen': ('lokativ',),
'lokativene': ('lokativ',),
'lokativer': ('lokativ',),
'lokfører': ('lokfører',),
'lokførere': ('lokfører',),
'lokføreren': ('lokfører',),
'lokførerer': ('lokfører',),
'lokførerne': ('lokfører',),
'lokk': ('lokk',),
'lokken': ('lokk',),
'lokkene': ('lokk',),
'lokker': ('lokk',),
'lokk': ('lokk',),
'lokken': ('lokk',),
'lokkene': ('lokk',),
'lokker': ('lokk',),
'lokkedua': ('lokkedue',),
'lokkedue': ('lokkedue',),
'lokkeduen': ('lokkedue',),
'lokkeduene': ('lokkedue',),
'lokkeduer': ('lokkedue',),
'lokkefat': ('lokkefat',),
'lokkefata': ('lokkefat',),
'lokkefatene': ('lokkefat',),
'lokkefater': ('lokkefat',),
'lokkefatet': ('lokkefat',),
'lokkefugl': ('lokkefugl',),
'lokkefuglen': ('lokkefugl',),
'lokkefuglene': ('lokkefugl',),
'lokkefugler': ('lokkefugl',),
'lokkemat': ('lokkemat',),
'lokkematen': ('lokkemat',),
'lokkematene': ('lokkemat',),
'lokkemater': ('lokkemat',),
'lokkemiddel': ('lokkemiddel',),
'lokkemiddelet': ('lokkemiddel',),
'lokkemidla': ('lokkemiddel',),
'lokkemidlene': ('lokkemiddel',),
'lokkemidler': ('lokkemiddel',),
'lokkemidlet': ('lokkemiddel',),
'lokketone': ('lokketone',),
'lokketonen': ('lokketone',),
'lokketonene': ('lokketone',),
'lokketoner': ('lokketone',),
'lokomobil': ('lokomobil',),
'lokomobilen': ('lokomobil',),
'lokomobilene': ('lokomobil',),
'lokomobiler': ('lokomobil',),
'lokomotiv': ('lokomotiv',),
'lokomotiva': ('lokomotiv',),
'lokomotivene': ('lokomotiv',),
'lokomotiver': ('lokomotiv',),
'lokomotivet': ('lokomotiv',),
'lokomotivfører': ('lokomotivfører',),
'lokomotivførere': ('lokomotivfører',),
'lokomotivføreren': ('lokomotivfører',),
'lokomotivførerer': ('lokomotivfører',),
'lokomotivførerne': ('lokomotivfører',),
'lokomotivstall': ('lokomotivstall',),
'lokomotivstallen': ('lokomotivstall',),
'lokomotivstallene': ('lokomotivstall',),
'lokomotivstaller': ('lokomotivstall',),
'lom': ('lom',),
'lommen': ('lom',),
'lommene': ('lom',),
'lommer': ('lom',),
'lombard': ('lombard',),
'lombarden': ('lombard',),
'lombardene': ('lombard',),
'lombarder': ('lombard',),
'lombardlån': ('lombardlån',),
'lombardlåna': ('lombardlån',),
'lombardlånene': ('lombardlån',),
'lombardlånet': ('lombardlån',),
'lomhund': ('lomhund',),
'lomhunden': ('lomhund',),
'lomhundene': ('lomhund',),
'lomhunder': ('lomhund',),
'lomma': ('lomme',),
'lomme': ('lomme',),
'lommen': ('lomme',),
'lommene': ('lomme',),
'lommer': ('lomme',),
'lommeapotek': ('lommeapotek',),
'lommeapoteka': ('lommeapotek',),
'lommeapotekene': ('lommeapotek',),
'lommeapoteker': ('lommeapotek',),
'lommeapoteket': ('lommeapotek',),
'lommedisko': ('lommedisko',),
'lommediskoen': ('lommedisko',),
'lommediskoene': ('lommedisko',),
'lommediskoer': ('lommedisko',),
'lommeduk': ('lommeduk',),
'lommeduken': ('lommeduk',),
'lommedukene': ('lommeduk',),
'lommeduker': ('lommeduk',),
'lommeformat': ('lommeformat',),
'lommeformata': ('lommeformat',),
'lommeformatene': ('lommeformat',),
'lommeformater': ('lommeformat',),
'lommeformatet': ('lommeformat',),
'lommekalkulator': ('lommekalkulator',),
'lommekalkulatoren': ('lommekalkulator',),
'lommekalkulatorene': ('lommekalkulator',),
'lommekalkulatorer': ('lommekalkulator',),
'lommekniv': ('lommekniv',),
'lommekniven': ('lommekniv',),
'lommeknivene': ('lommekniv',),
'lommekniver': ('lommekniv',),
'lommelerka': ('lommelerke',),
'lommelerke': ('lommelerke',),
'lommelerken': ('lommelerke',),
'lommelerkene': ('lommelerke',),
'lommelerker': ('lommelerke',),
'lommelykt': ('lommelykt',),
'lommelykta': ('lommelykt',),
'lommelykten': ('lommelykt',),
'lommelyktene': ('lommelykt',),
'lommelykter': ('lommelykt',),
'lommeparkering': ('lommeparkering',),
'lommeparkeringa': ('lommeparkering',),
'lommeparkeringen': ('lommeparkering',),
'lommeparkeringene': ('lommeparkering',),
'lommeparkeringer': ('lommeparkering',),
'lommepengene': ('lommepenger',),
'lommepenger': ('lommepenger',),
'lommeregner': ('lommeregner',),
'lommeregnere': ('lommeregner',),
'lommeregneren': ('lommeregner',),
'lommeregnerer': ('lommeregner',),
'lommeregnerne': ('lommeregner',),
'lommerekner': ('lommerekner',),
'lommereknere': ('lommerekner',),
'lommerekneren': ('lommerekner',),
'lommereknerer': ('lommerekner',),
'lommereknerne': ('lommerekner',),
'lommeskilling': ('lommeskilling',),
'lommeskillingen': ('lommeskilling',),
'lommeskillingene': ('lommeskilling',),
'lommeskillinger': ('lommeskilling',),
'lommespeil': ('lommespeil',),
'lommespeila': ('lommespeil',),
'lommespeilene': ('lommespeil',),
'lommespeilet': ('lommespeil',),
'lommetjuv': ('lommetjuv',),
'lommetjuven': ('lommetjuv',),
'lommetjuvene': ('lommetjuv',),
'lommetjuver': ('lommetjuv',),
'lommetyv': ('lommetyv',),
'lommetyven': ('lommetyv',),
'lommetyvene': ('lommetyv',),
'lommetyver': ('lommetyv',),
'lommetørkle': ('lommetørkle',),
'lommetørkleet': ('lommetørkle',),
'lommetørklær': ('lommetørkle',),
'lommetørklærne': ('lommetørkle',),
'lommeur': ('lommeur',),
'lommeura': ('lommeur',),
'lommeurene': ('lommeur',),
'lommeuret': ('lommeur',),
'lommeutgava': ('lommeutgave',),
'lommeutgave': ('lommeutgave',),
'lommeutgaven': ('lommeutgave',),
'lommeutgavene': ('lommeutgave',),
'lommeutgaver': ('lommeutgave',),
'lomra': ('lomre',),
'lomre': ('lomre',),
'lomren': ('lomre',),
'lomrene': ('lomre',),
'lomrer': ('lomre',),
'lomvi': ('lomvi',),
'lomvien': ('lomvi',),
'lomviene': ('lomvi',),
'lomvier': ('lomvi',),
'lon': ('lon',),
'lona': ('lon',),
'lonen': ('lon',),
'lonene': ('lon',),
'loner': ('lon',),
'londoner': ('londoner',),
'londonere': ('londoner',),
'londoneren': ('londoner',),
'londonerer': ('londoner',),
'londonerne': ('londoner',),
'longdrink': ('longdrink',),
'longdrinken': ('longdrink',),
'longdrinkene': ('longdrink',),
'longdrinker': ('longdrink',),
'longe': ('longe',),
'longen': ('longe',),
'longene': ('longe',),
'longer': ('longe',),
'longa': ('longe',),
'longe': ('longe',),
'longen': ('longe',),
'longene': ('longe',),
'longer': ('longe',),
'longitude': ('longitude',),
'longituden': ('longitude',),
'longitudene': ('longitude',),
'longituder': ('longitude',),
'longplayingplata': ('longplayingplate',),
'longplayingplate': ('longplayingplate',),
'longplayingplaten': ('longplayingplate',),
'longplayingplatene': ('longplayingplate',),
'longplayingplater': ('longplayingplate',),
'longs': ('longs',),
'longsen': ('longs',),
'longsene': ('longs',),
'longør': ('longør',),
'longøren': ('longør',),
'longørene': ('longør',),
'longører': ('longør',),
'longør': ('longør',),
'longøren': ('longør',),
'longørene': ('longør',),
'longører': ('longør',),
'loop': ('loop',),
'loopen': ('loop',),
'loopene': ('loop',),
'looper': ('loop',),
'lopp': ('lopp',),
'loppen': ('lopp',),
'loppene': ('lopp',),
'lopper': ('lopp',),
'loppa': ('loppe',),
'loppe': ('loppe',),
'loppen': ('loppe',),
'loppene': ('loppe',),
'lopper': ('loppe',),
'loppekassa': ('loppekasse',),
'loppekasse': ('loppekasse',),
'loppekassen': ('loppekasse',),
'loppekassene': ('loppekasse',),
'loppekasser': ('loppekasse',),
'loppemarked': ('loppemarked',),
'loppemarkeda': ('loppemarked',),
'loppemarkedene': ('loppemarked',),
'loppemarkeder': ('loppemarked',),
'loppemarkedet': ('loppemarked',),
'loppemarknad': ('loppemarknad',),
'loppemarknaden': ('loppemarknad',),
'loppemarknadene': ('loppemarknad',),
'loppemarknader': ('loppemarknad',),
'loppesirkus': ('loppesirkus',),
'loppesirkusa': ('loppesirkus',),
'loppesirkusene': ('loppesirkus',),
'loppesirkuser': ('loppesirkus',),
'loppesirkuset': ('loppesirkus',),
'loran': ('loran',),
'loranen': ('loran',),
'loranene': ('loran',),
'loraner': ('loran',),
'lord': ('lord',),
'lorden': ('lord',),
'lordene': ('lord',),
'lorder': ('lord',),
'lordkansler': ('lordkansler',),
'lordkanslere': ('lordkansler',),
'lordkansleren': ('lordkansler',),
'lordkanslerer': ('lordkansler',),
'lordkanslerne': ('lordkansler',),
'lorgnett': ('lorgnett',),
'lorgnetten': ('lorgnett',),
'lorgnettene': ('lorgnett',),
'lorgnetter': ('lorgnett',),
'lorja': ('lorje',),
'lorje': ('lorje',),
'lorjen': ('lorje',),
'lorjene': ('lorje',),
'lorjer': ('lorje',),
'lort': ('lort',),
'lorten': ('lort',),
'lortene': ('lort',),
'lorter': ('lort',),
'lortand': ('lortand',),
'lortanda': ('lortand',),
'lortanden': ('lortand',),
'lortendene': ('lortand',),
'lortender': ('lortand',),
'los': ('los',),
'losen': ('los',),
'losene': ('los',),
'loser': ('los',),
'los': ('los',),
'losen': ('los',),
'losene': ('los',),
'loser': ('los',),
'losbåt': ('losbåt',),
'losbåten': ('losbåt',),
'losbåtene': ('losbåt',),
'losbåter': ('losbåt',),
'losfisk': ('losfisk',),
'losfisken': ('losfisk',),
'losfiskene': ('losfisk',),
'losfisker': ('losfisk',),
'losflagg': ('losflagg',),
'losflagga': ('losflagg',),
'losflaggene': ('losflagg',),
'losflagget': ('losflagg',),
'loshamn': ('loshamn',),
'loshamna': ('loshamn',),
'loshamnen': ('loshamn',),
'loshamnene': ('loshamn',),
'loshamner': ('loshamn',),
'loshavn': ('loshavn',),
'loshavna': ('loshavn',),
'loshavnen': ('loshavn',),
'loshavnene': ('loshavn',),
'loshavner': ('loshavn',),
'losje': ('losje',),
'losjen': ('losje',),
'losjene': ('losje',),
'losjer': ('losje',),
'losjerende': ('losjerende',),
'losjerenden': ('losjerende',),
'losjerendene': ('losjerende',),
'losjerender': ('losjerende',),
'losji': ('losji',),
'losjia': ('losji',),
'losjiene': ('losji',),
'losjier': ('losji',),
'losjiet': ('losji',),
'loslua': ('loslue',),
'loslue': ('loslue',),
'losluen': ('loslue',),
'losluene': ('loslue',),
'losluer': ('loslue',),
'losluva': ('losluve',),
'losluve': ('losluve',),
'losluven': ('losluve',),
'losluvene': ('losluve',),
'losluver': ('losluve',),
'losoldermann': ('losoldermann',),
'losoldermannen': ('losoldermann',),
'losoldermenn': ('losoldermann',),
'losoldermennene': ('losoldermann',),
'losoldermannskap': ('losoldermannskap',),
'losoldermannskapa': ('losoldermannskap',),
'losoldermannskapene': ('losoldermannskap',),
'losoldermannskapet': ('losoldermannskap',),
'lossearbeider': ('lossearbeider',),
'lossearbeidere': ('lossearbeider',),
'lossearbeideren': ('lossearbeider',),
'lossearbeiderer': ('lossearbeider',),
'lossearbeiderne': ('lossearbeider',),
'lossebom': ('lossebom',),
'lossebommen': ('lossebom',),
'lossebommene': ('lossebom',),
'lossebommer': ('lossebom',),
'lossegjeng': ('lossegjeng',),
'lossegjengen': ('lossegjeng',),
'lossegjengene': ('lossegjeng',),
'lossegjenger': ('lossegjeng',),
'losskøyta': ('losskøyte',),
'losskøyte': ('losskøyte',),
'losskøyten': ('losskøyte',),
'losskøytene': ('losskøyte',),
'losskøyter': ('losskøyte',),
'losvesen': ('losvesen',),
'losvesena': ('losvesen',),
'losvesenene': ('losvesen',),
'losvesener': ('losvesen',),
'losvesenet': ('losvesen',),
'lotion': ('lotion',),
'lotionen': ('lotion',),
'lotionene': ('lotion',),
'lotioner': ('lotion',),
'lott': ('lott',),
'lotten': ('lott',),
'lottene': ('lott',),
'lotter': ('lott',),
'lottbruk': ('lottbruk',),
'lottbruka': ('lottbruk',),
'lottbrukene': ('lottbruk',),
'lottbruket': ('lottbruk',),
'lottbruker': ('lottbruker',),
'lottbrukere': ('lottbruker',),
'lottbrukeren': ('lottbruker',),
'lottbrukerer': ('lottbruker',),
'lottbrukerne': ('lottbruker',),
'lotta': ('lotte',),
'lotte': ('lotte',),
'lotten': ('lotte',),
'lottene': ('lotte',),
'lotter': ('lotte',),
'lotteri': ('lotteri',),
'lotteria': ('lotteri',),
'lotteriene': ('lotteri',),
'lotterier': ('lotteri',),
'lotteriet': ('lotteri',),
'lottfiska': ('lottfiske',),
'lottfiske': ('lottfiske',),
'lottfiskene': ('lottfiske',),
'lottfisker': ('lottfiske',),
'lottfisket': ('lottfiske',),
'lottleia': ('lottleie',),
'lottleie': ('lottleie',),
'lottleien': ('lottleie',),
'lottleiene': ('lottleie',),
'lottleier': ('lottleie',),
'lottmann': ('lottmann',),
'lottmannen': ('lottmann',),
'lottmenn': ('lottmann',),
'lottmennene': ('lottmann',),
'lotus': ('lotus',),
'lotusen': ('lotus',),
'lotusene': ('lotus',),
'lotuser': ('lotus',),
'lotusblomst': ('lotusblomst',),
'lotusblomsten': ('lotusblomst',),
'lotusblomstene': ('lotusblomst',),
'lotusblomster': ('lotusblomst',),
'lotusstilling': ('lotusstilling',),
'lotusstillinga': ('lotusstilling',),
'lotusstillingen': ('lotusstilling',),
'lotusstillingene': ('lotusstilling',),
'lotusstillinger': ('lotusstilling',),
'louis-seize-stil': ('louis-seize-stil',),
'louis-seize-stilen': ('louis-seize-stil',),
'louis-seize-stilene': ('louis-seize-stil',),
'louis-seize-stiler': ('louis-seize-stil',),
'louisd\'or': ('louisd\'or',),
'louisd\'oren': ('louisd\'or',),
'louisd\'orene': ('louisd\'or',),
'louisd\'orer': ('louisd\'or',),
'lov': ('lov',),
'lovart': ('lovart',),
'lovbrott': ('lovbrott',),
'lovbrotta': ('lovbrott',),
'lovbrottene': ('lovbrott',),
'lovbrottet': ('lovbrott',),
'lovbrudd': ('lovbrudd',),
'lovbrudda': ('lovbrudd',),
'lovbruddene': ('lovbrudd',),
'lovbruddet': ('lovbrudd',),
'lovbryter': ('lovbryter',),
'lovbrytere': ('lovbryter',),
'lovbryteren': ('lovbryter',),
'lovbryterer': ('lovbryter',),
'lovbryterne': ('lovbryter',),
'love': ('love',),
'loven': ('love',),
'lovene': ('love',),
'lover': ('love',),
'love': ('love',),
'lovendring': ('lovendring',),
'lovendringa': ('lovendring',),
'lovendringen': ('lovendring',),
'lovendringene': ('lovendring',),
'lovendringer': ('lovendring',),
'lovforslag': ('lovforslag',),
'lovforslaga': ('lovforslag',),
'lovforslagene': ('lovforslag',),
'lovforslaget': ('lovforslag',),
'lovgiing': ('lovgiing',),
'lovgiinga': ('lovgiing',),
'lovgiingen': ('lovgiing',),
'lovgiingene': ('lovgiing',),
'lovgiinger': ('lovgiing',),
'lovgiving': ('lovgiving',),
'lovgivinga': ('lovgiving',),
'lovgivingen': ('lovgiving',),
'lovgivingene': ('lovgiving',),
'lovgivinger': ('lovgiving',),
'lovgivning': ('lovgivning',),
'lovgivninga': ('lovgivning',),
'lovgivningen': ('lovgivning',),
'lovgivningene': ('lovgivning',),
'lovgivninger': ('lovgivning',),
'lovheimel': ('lovheimel',),
'lovheimelen': ('lovheimel',),
'lovheimlene': ('lovheimel',),
'lovheimler': ('lovheimel',),
'lovhjemlene': ('lovhjemmel',),
'lovhjemler': ('lovhjemmel',),
'lovhjemmel': ('lovhjemmel',),
'lovhjemmelen': ('lovhjemmel',),
'lovkvad': ('lovkvad',),
'lovkvada': ('lovkvad',),
'lovkvadene': ('lovkvad',),
'lovkvadet': ('lovkvad',),
'lovkveda': ('lovkvede',),
'lovkvede': ('lovkvede',),
'lovkvedene': ('lovkvede',),
'lovkveder': ('lovkvede',),
'lovkvedet': ('lovkvede',),
'lovløshet': ('lovløshet',),
'lovløsheta': ('lovløshet',),
'lovløsheten': ('lovløshet',),
'lovløshetene': ('lovløshet',),
'lovløsheter': ('lovløshet',),
'lovløysa': ('lovløyse',),
'lovløyse': ('lovløyse',),
'lovløysen': ('lovløyse',),
'lovløysene': ('lovløyse',),
'lovløyser': ('lovløyse',),
'lovnad': ('lovnad',),
'lovnaden': ('lovnad',),
'lovnadene': ('lovnad',),
'lovnader': ('lovnad',),
'lovord': ('lovord',),
'lovorda': ('lovord',),
'lovordene': ('lovord',),
'lovordet': ('lovord',),
'lovott': ('lovott',),
'lovotten': ('lovott',),
'lovottene': ('lovott',),
'lovotter': ('lovott',),
'lovovertredelse': ('lovovertredelse',),
'lovovertredelsen': ('lovovertredelse',),
'lovovertredelsene': ('lovovertredelse',),
'lovovertredelser': ('lovovertredelse',),
'lovovertreder': ('lovovertreder',),
'lovovertredere': ('lovovertreder',),
'lovovertrederen': ('lovovertreder',),
'lovovertrederer': ('lovovertreder',),
'lovovertrederne': ('lovovertreder',),
'lovprising': ('lovprising',),
'lovprisingen': ('lovprising',),
'lovprisingene': ('lovprising',),
'lovprisinger': ('lovprising',),
'lovprisning': ('lovprisning',),
'lovprisninga': ('lovprisning',),
'lovprisningen': ('lovprisning',),
'lovprisningene': ('lovprisning',),
'lovprisninger': ('lovprisning',),
'lovsang': ('lovsang',),
'lovsangen': ('lovsang',),
'lovsangene': ('lovsang',),
'lovsanger': ('lovsang',),
'lovsigemann': ('lovsigemann',),
'lovsigemannen': ('lovsigemann',),
'lovsigemenn': ('lovsigemann',),
'lovsigemennene': ('lovsigemann',),
'lovspråk': ('lovspråk',),
'lovspråka': ('lovspråk',),
'lovspråkene': ('lovspråk',),
'lovspråket': ('lovspråk',),
'lovtale': ('lovtale',),
'lovtalen': ('lovtale',),
'lovtalene': ('lovtale',),
'lovtaler': ('lovtale',),
'lovtekst': ('lovtekst',),
'lovteksta': ('lovtekst',),
'lovteksten': ('lovtekst',),
'lovtekstene': ('lovtekst',),
'lovtekster': ('lovtekst',),
'lovutkast': ('lovutkast',),
'lovutkasta': ('lovutkast',),
'lovutkastene': ('lovutkast',),
'lovutkastet': ('lovutkast',),
'lovverk': ('lovverk',),
'lovverka': ('lovverk',),
'lovverkene': ('lovverk',),
'lovverker': ('lovverk',),
'lovverket': ('lovverk',),
'lp': ('lp',),
'lpen': ('lp',),
'lpene': ('lp',),
'lper': ('lp',),
'lp-plata': ('lp-plate',),
'lp-plate': ('lp-plate',),
'lp-platen': ('lp-plate',),
'lp-platene': ('lp-plate',),
'lp-plater': ('lp-plate',),
'lsd': ('lsd',),
'lsden': ('lsd',),
'lsdene': ('lsd',),
'lsder': ('lsd',),
'lsd-rus': ('lsd-rus',),
'lsd-rusa': ('lsd-rus',),
'lsd-rusen': ('lsd-rus',),
'lsd-rusene': ('lsd-rus',),
'lsd-ruser': ('lsd-rus',),
'lsd-ruset': ('lsd-rus',),
'lubb': ('lubb',),
'lubben': ('lubb',),
'lubbene': ('lubb',),
'lubber': ('lubb',),
'lubba': ('lubbe',),
'lubbe': ('lubbe',),
'lubben': ('lubbe',),
'lubbene': ('lubbe',),
'lubber': ('lubbe',),
'lubrikator': ('lubrikator',),
'lubrikatoren': ('lubrikator',),
'lubrikatorene': ('lubrikator',),
'lubrikatorer': ('lubrikator',),
'luciabrud': ('luciabrud',),
'luciabruda': ('luciabrud',),
'luciabruden': ('luciabrud',),
'luciabrudene': ('luciabrud',),
'luciabruder': ('luciabrud',),
'luciabrur': ('luciabrur',),
'luciabrura': ('luciabrur',),
'luciabrurene': ('luciabrur',),
'luciabrurer': ('luciabrur',),
'luciadag': ('luciadag',),
'luciadagen': ('luciadag',),
'luciadagene': ('luciadag',),
'luciadager': ('luciadag',),
'lucienatt': ('lucienatt',),
'lucienatta': ('lucienatt',),
'lucienatten': ('lucienatt',),
'lucienattene': ('lucienatt',),
'lucienatter': ('lucienatt',),
'lucinatt': ('lucinatt',),
'lucinatta': ('lucinatt',),
'lucinatten': ('lucinatt',),
'lucinattene': ('lucinatt',),
'lucinatter': ('lucinatt',),
'ludder': ('ludder',),
'luddera': ('ludder',),
'luddere': ('ludder',),
'ludderet': ('ludder',),
'ludderne': ('ludder',),
'ludo': ('ludo',),
'ludoen': ('ludo',),
'ludoene': ('ludo',),
'ludoer': ('ludo',),
'lue': ('lue',),
'luen': ('lue',),
'luene': ('lue',),
'luer': ('lue',),
'lua': ('lue',),
'lue': ('lue',),
'luen': ('lue',),
'luene': ('lue',),
'luer': ('lue',),
'lua': ('lue',),
'lue': ('lue',),
'luen': ('lue',),
'luene': ('lue',),
'luer': ('lue',),
'luffe': ('luffe',),
'luffen': ('luffe',),
'luffene': ('luffe',),
'luffer': ('luffe',),
'luft': ('luft',),
'lufta': ('luft',),
'luften': ('luft',),
'luftene': ('luft',),
'lufter': ('luft',),
'luftangrep': ('luftangrep',),
'luftangrepa': ('luftangrep',),
'luftangrepene': ('luftangrep',),
'luftangrepet': ('luftangrep',),
'luftballong': ('luftballong',),
'luftballongen': ('luftballong',),
'luftballongene': ('luftballong',),
'luftballonger': ('luftballong',),
'luftblæra': ('luftblære',),
'luftblære': ('luftblære',),
'luftblæren': ('luftblære',),
'luftblærene': ('luftblære',),
'luftblærer': ('luftblære',),
'luftbobla': ('luftboble',),
'luftboble': ('luftboble',),
'luftboblen': ('luftboble',),
'luftboblene': ('luftboble',),
'luftbobler': ('luftboble',),
'luftbro': ('luftbro',),
'luftbroa': ('luftbro',),
'luftbroen': ('luftbro',),
'luftbroene': ('luftbro',),
'luftbroer': ('luftbro',),
'luftbru': ('luftbru',),
'luftbrua': ('luftbru',),
'luftbruen': ('luftbru',),
'luftbruene': ('luftbru',),
'luftbruer': ('luftbru',),
'luftbuss': ('luftbuss',),
'luftbussen': ('luftbuss',),
'luftbussene': ('luftbuss',),
'luftbusser': ('luftbuss',),
'luftbørsa': ('luftbørse',),
'luftbørse': ('luftbørse',),
'luftbørsen': ('luftbørse',),
'luftbørsene': ('luftbørse',),
'luftbørser': ('luftbørse',),
'luftdrag': ('luftdrag',),
'luftdraga': ('luftdrag',),
'luftdragene': ('luftdrag',),
'luftdraget': ('luftdrag',),
'luftebalkong': ('luftebalkong',),
'luftebalkongen': ('luftebalkong',),
'luftebalkongene': ('luftebalkong',),
'luftebalkonger': ('luftebalkong',),
'luftegård': ('luftegård',),
'luftegården': ('luftegård',),
'luftegårdene': ('luftegård',),
'luftegårder': ('luftegård',),
'luftekko': ('luftekko',),
'luftekkoa': ('luftekko',),
'luftekkoene': ('luftekko',),
'luftekkoer': ('luftekko',),
'luftekkoet': ('luftekko',),
'lufteluka': ('lufteluke',),
'lufteluke': ('lufteluke',),
'lufteluken': ('lufteluke',),
'luftelukene': ('lufteluke',),
'lufteluker': ('lufteluke',),
'luftetur': ('luftetur',),
'lufteturen': ('luftetur',),
'lufteturene': ('luftetur',),
'lufteturer': ('luftetur',),
'luftfart': ('luftfart',),
'luftfarten': ('luftfart',),
'luftfartene': ('luftfart',),
'luftfarter': ('luftfart',),
'luftfartøy': ('luftfartøy',),
'luftfartøya': ('luftfartøy',),
'luftfartøyene': ('luftfartøy',),
'luftfartøyer': ('luftfartøy',),
'luftfartøyet': ('luftfartøy',),
'luftfilter': ('luftfilter',),
'luftfilteret': ('luftfilter',),
'luftfiltra': ('luftfilter',),
'luftfiltre': ('luftfilter',),
'luftfiltrene': ('luftfilter',),
'luftfiltret': ('luftfilter',),
'luftforandring': ('luftforandring',),
'luftforandringa': ('luftforandring',),
'luftforandringen': ('luftforandring',),
'luftforandringene': ('luftforandring',),
'luftforandringer': ('luftforandring',),
'luftform': ('luftform',),
'luftforma': ('luftform',),
'luftformen': ('luftform',),
'luftformene': ('luftform',),
'luftformer': ('luftform',),
'luftforsvar': ('luftforsvar',),
'luftforsvara': ('luftforsvar',),
'luftforsvarene': ('luftforsvar',),
'luftforsvaret': ('luftforsvar',),
'luftforurensning': ('luftforurensning',),
'luftforurensninga': ('luftforurensning',),
'luftforurensningen': ('luftforurensning',),
'luftforurensningene': ('luftforurensning',),
'luftforurensninger': ('luftforurensning',),
'luftfotografering': ('luftfotografering',),
'luftfotograferinga': ('luftfotografering',),
'luftfotograferingen': ('luftfotografering',),
'luftfotograferingene': ('luftfotografering',),
'luftfotograferinger': ('luftfotografering',),
'luftfukter': ('luftfukter',),
'luftfuktere': ('luftfukter',),
'luftfukteren': ('luftfukter',),
'luftfukterer': ('luftfukter',),
'luftfukterne': ('luftfukter',),
'luftfuktighet': ('luftfuktighet',),
'luftfuktigheta': ('luftfuktighet',),
'luftfuktigheten': ('luftfuktighet',),
'luftfuktighetene': ('luftfuktighet',),
'luftfuktigheter': ('luftfuktighet',),
'luftfyr': ('luftfyr',),
'luftfyra': ('luftfyr',),
'luftfyrene': ('luftfyr',),
'luftfyret': ('luftfyr',),
'luftgevær': ('luftgevær',),
'luftgeværa': ('luftgevær',),
'luftgeværene': ('luftgevær',),
'luftgeværer': ('luftgevær',),
'luftgeværet': ('luftgevær',),
'lufthamn': ('lufthamn',),
'lufthamna': ('lufthamn',),
'lufthamnen': ('lufthamn',),
'lufthamnene': ('lufthamn',),
'lufthamner': ('lufthamn',),
'lufthavn': ('lufthavn',),
'lufthavna': ('lufthavn',),
'lufthavnen': ('lufthavn',),
'lufthavnene': ('lufthavn',),
'lufthavner': ('lufthavn',),
'lufthol': ('lufthol',),
'lufthola': ('lufthol',),
'luftholene': ('lufthol',),
'luftholet': ('lufthol',),
'lufthull': ('lufthull',),
'lufthulla': ('lufthull',),
'lufthullene': ('lufthull',),
'lufthuller': ('lufthull',),
'lufthullet': ('lufthull',),
'lufting': ('lufting',),
'luftinga': ('lufting',),
'luftingen': ('lufting',),
'luftingene': ('lufting',),
'luftinger': ('lufting',),
'luftkamp': ('luftkamp',),
'luftkampen': ('luftkamp',),
'luftkampene': ('luftkamp',),
'luftkamper': ('luftkamp',),
'luftkastell': ('luftkastell',),
'luftkastella': ('luftkastell',),
'luftkastellene': ('luftkastell',),
'luftkasteller': ('luftkastell',),
'luftkastellet': ('luftkastell',),
'luftkommando': ('luftkommando',),
'luftkommandoen': ('luftkommando',),
'luftkommandoene': ('luftkommando',),
'luftkommandoer': ('luftkommando',),
'luftkondisjonering': ('luftkondisjonering',),
'luftkondisjoneringa': ('luftkondisjonering',),
'luftkondisjoneringen': ('luftkondisjonering',),
'luftkondisjoneringene': ('luftkondisjonering',),
'luftkondisjoneringer': ('luftkondisjonering',),
'luftkondisjoneringsanlegg': ('luftkondisjoneringsanlegg',),
'luftkondisjoneringsanlegga': ('luftkondisjoneringsanlegg',),
'luftkondisjoneringsanleggene': ('luftkondisjoneringsanlegg',),
'luftkondisjoneringsanlegget': ('luftkondisjoneringsanlegg',),
'luftkrig': ('luftkrig',),
'luftkrigen': ('luftkrig',),
'luftkrigene': ('luftkrig',),
'luftkriger': ('luftkrig',),
'luftlag': ('luftlag',),
'luftlaga': ('luftlag',),
'luftlagene': ('luftlag',),
'luftlaget': ('luftlag',),
'luftlinja': ('luftlinje',),
'luftlinje': ('luftlinje',),
'luftlinjen': ('luftlinje',),
'luftlinjene': ('luftlinje',),
'luftlinjer': ('luftlinje',),
'luftløk': ('luftløk',),
'luftløken': ('luftløk',),
'luftløkene': ('luftløk',),
'luftløker': ('luftløk',),
'luftmadrass': ('luftmadrass',),
'luftmadrassen': ('luftmadrass',),
'luftmadrassene': ('luftmadrass',),
'luftmadrasser': ('luftmadrass',),
'luftmaska': ('luftmaske',),
'luftmaske': ('luftmaske',),
'luftmasken': ('luftmaske',),
'luftmaskene': ('luftmaske',),
'luftmasker': ('luftmaske',),
'luftmasse': ('luftmasse',),
'luftmassen': ('luftmasse',),
'luftmassene': ('luftmasse',),
'luftmasser': ('luftmasse',),
'luftmotstand': ('luftmotstand',),
'luftmotstanden': ('luftmotstand',),
'luftmotstandene': ('luftmotstand',),
'luftmotstander': ('luftmotstand',),
'luftning': ('luftning',),
'luftninga': ('luftning',),
'luftningen': ('luftning',),
'luftningene': ('luftning',),
'luftninger': ('luftning',),
'luftpistol': ('luftpistol',),
'luftpistolen': ('luftpistol',),
'luftpistolene': ('luftpistol',),
'luftpistoler': ('luftpistol',),
'luftpost': ('luftpost',),
'luftposten': ('luftpost',),
'luftpostene': ('luftpost',),
'luftposter': ('luftpost',),
'luftpumpa': ('luftpumpe',),
'luftpumpe': ('luftpumpe',),
'luftpumpen': ('luftpumpe',),
'luftpumpene': ('luftpumpe',),
'luftpumper': ('luftpumpe',),
'luftputa': ('luftpute',),
'luftpute': ('luftpute',),
'luftputen': ('luftpute',),
'luftputene': ('luftpute',),
'luftputer': ('luftpute',),
'luftputebåt': ('luftputebåt',),
'luftputebåten': ('luftputebåt',),
'luftputebåtene': ('luftputebåt',),
'luftputebåter': ('luftputebåt',),
'luftputefartøy': ('luftputefartøy',),
'luftputefartøya': ('luftputefartøy',),
'luftputefartøyene': ('luftputefartøy',),
'luftputefartøyer': ('luftputefartøy',),
'luftputefartøyet': ('luftputefartøy',),
'luftrom': ('luftrom',),
'luftromma': ('luftrom',),
'luftrommene': ('luftrom',),
'luftrommet': ('luftrom',),
'luftrør': ('luftrør',),
'luftrøra': ('luftrør',),
'luftrørene': ('luftrør',),
'luftrøret': ('luftrør',),
'luftskip': ('luftskip',),
'luftskipa': ('luftskip',),
'luftskipene': ('luftskip',),
'luftskipet': ('luftskip',),
'luftskyts': ('luftskyts',),
'luftskytsa': ('luftskyts',),
'luftskytsene': ('luftskyts',),
'luftskytset': ('luftskyts',),
'luftslott': ('luftslott',),
'luftslotta': ('luftslott',),
'luftslottene': ('luftslott',),
'luftslottet': ('luftslott',),
'luftspeiling': ('luftspeiling',),
'luftspeilingen': ('luftspeiling',),
'luftspeilingene': ('luftspeiling',),
'luftspeilinger': ('luftspeiling',),
'luftstridskreftene': ('luftstridskrefter',),
'luftstridskrefter': ('luftstridskrefter',),
'luftterritoria': ('luftterritorium',),
'luftterritoriene': ('luftterritorium',),
'luftterritorier': ('luftterritorium',),
'luftterritoriet': ('luftterritorium',),
'luftterritorium': ('luftterritorium',),
'lufttilførsel': ('lufttilførsel',),
'lufttilførselen': ('lufttilførsel',),
'lufttilførslene': ('lufttilførsel',),
'lufttilførsler': ('lufttilførsel',),
'lufttrafikk': ('lufttrafikk',),
'lufttrafikken': ('lufttrafikk',),
'lufttrafikkene': ('lufttrafikk',),
'lufttrafikker': ('lufttrafikk',),
'lufttrykk': ('lufttrykk',),
'lufttrykka': ('lufttrykk',),
'lufttrykkene': ('lufttrykk',),
'lufttrykket': ('lufttrykk',),
'lufttrykksmåler': ('lufttrykksmåler',),
'lufttrykksmålere': ('lufttrykksmåler',),
'lufttrykksmåleren': ('lufttrykksmåler',),
'lufttrykksmålerer': ('lufttrykksmåler',),
'lufttrykksmålerne': ('lufttrykksmåler',),
'luftveg': ('luftveg',),
'luftvegen': ('luftveg',),
'luftvegene': ('luftveg',),
'luftveger': ('luftveg',),
'luftvegsinfeksjon': ('luftvegsinfeksjon',),
'luftvegsinfeksjonen': ('luftvegsinfeksjon',),
'luftvegsinfeksjonene': ('luftvegsinfeksjon',),
'luftvegsinfeksjoner': ('luftvegsinfeksjon',),
'luftvei': ('luftvei',),
'luftveien': ('luftvei',),
'luftveiene': ('luftvei',),
'luftveier': ('luftvei',),
'luftvern': ('luftvern',),
'luftverna': ('luftvern',),
'luftvernene': ('luftvern',),
'luftvernet': ('luftvern',),
'luftvernartilleri': ('luftvernartilleri',),
'luftvernartilleria': ('luftvernartilleri',),
'luftvernartilleriene': ('luftvernartilleri',),
'luftvernartillerier': ('luftvernartilleri',),
'luftvernartilleriet': ('luftvernartilleri',),
'luftvernkanon': ('luftvernkanon',),
'luftvernkanonen': ('luftvernkanon',),
'luftvernkanonene': ('luftvernkanon',),
'luftvernkanoner': ('luftvernkanon',),
'luftvernsartilleri': ('luftvernsartilleri',),
'luftvernsartilleria': ('luftvernsartilleri',),
'luftvernsartilleriene': ('luftvernsartilleri',),
'luftvernsartillerier': ('luftvernsartilleri',),
'luftvernsartilleriet': ('luftvernsartilleri',),
'luftvernsirena': ('luftvernsirene',),
'luftvernsirene': ('luftvernsirene',),
'luftvernsirenen': ('luftvernsirene',),
'luftvernsirenene': ('luftvernsirene',),
'luftvernsirener': ('luftvernsirene',),
'luftvernskanon': ('luftvernskanon',),
'luftvernskanonen': ('luftvernskanon',),
'luftvernskanonene': ('luftvernskanon',),
'luftvernskanoner': ('luftvernskanon',),
'luftvernskyts': ('luftvernskyts',),
'luftvernskytsa': ('luftvernskyts',),
'luftvernskytsene': ('luftvernskyts',),
'luftvernskytset': ('luftvernskyts',),
'luftvernssirena': ('luftvernssirene',),
'luftvernssirene': ('luftvernssirene',),
'luftvernssirenen': ('luftvernssirene',),
'luftvernssirenene': ('luftvernssirene',),
'luftvernssirener': ('luftvernssirene',),
'lugar': ('lugar',),
'lugaren': ('lugar',),
'lugarene': ('lugar',),
'lugarer': ('lugar',),
'lugarpika': ('lugarpike',),
'lugarpike': ('lugarpike',),
'lugarpiken': ('lugarpike',),
'lugarpikene': ('lugarpike',),
'lugarpiker': ('lugarpike',),
'lugg': ('lugg',),
'luggen': ('lugg',),
'luggene': ('lugg',),
'lugger': ('lugg',),
'lugg': ('lugg',),
'luggen': ('lugg',),
'luggene': ('lugg',),
'lugger': ('lugg',),
'lugg': ('lugg',),
'lugga': ('lugg',),
'luggene': ('lugg',),
'lugget': ('lugg',),
'lugger': ('lugger',),
'luggere': ('lugger',),
'luggeren': ('lugger',),
'luggerer': ('lugger',),
'luggerne': ('lugger',),
'luggersegl': ('luggersegl',),
'luggersegla': ('luggersegl',),
'luggerseglene': ('luggersegl',),
'luggerseglet': ('luggersegl',),
'luggerseil': ('luggerseil',),
'luggerseila': ('luggerseil',),
'luggerseilene': ('luggerseil',),
'luggerseilet': ('luggerseil',),
'luka': ('luke',),
'luke': ('luke',),
'luken': ('luke',),
'lukene': ('luke',),
'luker': ('luke',),
'lukekarm': ('lukekarm',),
'lukekarmen': ('lukekarm',),
'lukekarmene': ('lukekarm',),
'lukekarmer': ('lukekarm',),
'lukeparkering': ('lukeparkering',),
'lukeparkeringa': ('lukeparkering',),
'lukeparkeringen': ('lukeparkering',),
'lukeparkeringene': ('lukeparkering',),
'lukeparkeringer': ('lukeparkering',),
'lukka': ('lukke',),
'lukke': ('lukke',),
'lukkene': ('lukke',),
'lukker': ('lukke',),
'lukket': ('lukke',),
'lukkelyd': ('lukkelyd',),
'lukkelyden': ('lukkelyd',),
'lukkelydene': ('lukkelyd',),
'lukkelyder': ('lukkelyd',),
'lukkemekanisme': ('lukkemekanisme',),
'lukkemekanismen': ('lukkemekanisme',),
'lukkemekanismene': ('lukkemekanisme',),
'lukkemekanismer': ('lukkemekanisme',),
'lukker': ('lukker',),
'lukkere': ('lukker',),
'lukkeren': ('lukker',),
'lukkerer': ('lukker',),
'lukkerne': ('lukker',),
'lukning': ('lukning',),
'lukninga': ('lukning',),
'lukningen': ('lukning',),
'lukningene': ('lukning',),
'lukninger': ('lukning',),
'lukningsmekanisme': ('lukningsmekanisme',),
'lukningsmekanismen': ('lukningsmekanisme',),
'lukningsmekanismene': ('lukningsmekanisme',),
'lukningsmekanismer': ('lukningsmekanisme',),
'lukningstid': ('lukningstid',),
'lukningstida': ('lukningstid',),
'lukningstiden': ('lukningstid',),
'lukningstidene': ('lukningstid',),
'lukningstider': ('lukningstid',),
'lukningsvedtekt': ('lukningsvedtekt',),
'lukningsvedtekta': ('lukningsvedtekt',),
'lukningsvedtekten': ('lukningsvedtekt',),
'lukningsvedtektene': ('lukningsvedtekt',),
'lukningsvedtekter': ('lukningsvedtekt',),
'luksasjon': ('luksasjon',),
'luksasjonen': ('luksasjon',),
'luksasjonene': ('luksasjon',),
'luksasjoner': ('luksasjon',),
'luksus': ('luksus',),
'luksusen': ('luksus',),
'luksusene': ('luksus',),
'luksuser': ('luksus',),
'luksusartikkel': ('luksusartikkel',),
'luksusartikkelen': ('luksusartikkel',),
'luksusartiklene': ('luksusartikkel',),
'luksusartikler': ('luksusartikkel',),
'luksusavgift': ('luksusavgift',),
'luksusavgifta': ('luksusavgift',),
'luksusavgiften': ('luksusavgift',),
'luksusavgiftene': ('luksusavgift',),
'luksusavgifter': ('luksusavgift',),
'luksusbil': ('luksusbil',),
'luksusbilen': ('luksusbil',),
'luksusbilene': ('luksusbil',),
'luksusbiler': ('luksusbil',),
'luksusforbruk': ('luksusforbruk',),
'luksusforbruka': ('luksusforbruk',),
'luksusforbrukene': ('luksusforbruk',),
'luksusforbruket': ('luksusforbruk',),
'luksushotell': ('luksushotell',),
'luksushotella': ('luksushotell',),
'luksushotellene': ('luksushotell',),
'luksushoteller': ('luksushotell',),
'luksushotellet': ('luksushotell',),
'luksusskatt': ('luksusskatt',),
'luksusskatten': ('luksusskatt',),
'luksusskattene': ('luksusskatt',),
'luksusskatter': ('luksusskatt',),
'lukt': ('lukt',),
'lukta': ('lukt',),
'lukten': ('lukt',),
'luktene': ('lukt',),
'lukter': ('lukt',),
'luktecella': ('luktecelle',),
'luktecelle': ('luktecelle',),
'luktecellen': ('luktecelle',),
'luktecellene': ('luktecelle',),
'lukteceller': ('luktecelle',),
'lukteflaska': ('lukteflaske',),
'lukteflaske': ('lukteflaske',),
'lukteflasken': ('lukteflaske',),
'lukteflaskene': ('lukteflaske',),
'lukteflasker': ('lukteflaske',),
'lukteorgan': ('lukteorgan',),
'lukteorgana': ('lukteorgan',),
'lukteorganene': ('lukteorgan',),
'lukteorganer': ('lukteorgan',),
'lukteorganet': ('lukteorgan',),
'luktesans': ('luktesans',),
'luktesansen': ('luktesans',),
'luktesansene': ('luktesans',),
'luktesanser': ('luktesans',),
'luktevann': ('luktevann',),
'luktevanna': ('luktevann',),
'luktevannene': ('luktevann',),
'luktevannet': ('luktevann',),
'luktevatn': ('luktevatn',),
'luktevatna': ('luktevatn',),
'luktevatnene': ('luktevatn',),
'luktevatnet': ('luktevatn',),
'luktstoff': ('luktstoff',),
'luktstoffa': ('luktstoff',),
'luktstoffene': ('luktstoff',),
'luktstoffer': ('luktstoff',),
'luktstoffet': ('luktstoff',),
'lumbago': ('lumbago',),
'lumbagoen': ('lumbago',),
'lumbagoene': ('lumbago',),
'lumbagoer': ('lumbago',),
'lumen': ('lumen',),
'lumenen': ('lumen',),
'lumenene': ('lumen',),
'luminiscens': ('luminiscens',),
'luminiscensen': ('luminiscens',),
'luminiscensene': ('luminiscens',),
'luminiscenser': ('luminiscens',),
'lump': ('lump',),
'lumpen': ('lump',),
'lumpene': ('lump',),
'lumper': ('lump',),
'lumpa': ('lumpe',),
'lumpe': ('lumpe',),
'lumpen': ('lumpe',),
'lumpene': ('lumpe',),
'lumper': ('lumpe',),
'lund': ('lund',),
'lunden': ('lund',),
'lundene': ('lund',),
'lunder': ('lund',),
'lunde': ('lunde',),
'lunden': ('lunde',),
'lundene': ('lunde',),
'lunder': ('lunde',),
'lundefugl': ('lundefugl',),
'lundefuglen': ('lundefugl',),
'lundefuglene': ('lundefugl',),
'lundefugler': ('lundefugl',),
'lundehund': ('lundehund',),
'lundehunden': ('lundehund',),
'lundehundene': ('lundehund',),
'lundehunder': ('lundehund',),
'luna': ('lune',),
'lune': ('lune',),
'lunene': ('lune',),
'luner': ('lune',),
'lunet': ('lune',),
'lunga': ('lunge',),
'lunge': ('lunge',),
'lungen': ('lunge',),
'lungene': ('lunge',),
'lunger': ('lunge',),
'lungebetennelse': ('lungebetennelse',),
'lungebetennelsen': ('lungebetennelse',),
'lungebetennelsene': ('lungebetennelse',),
'lungebetennelser': ('lungebetennelse',),
'lungeblæra': ('lungeblære',),
'lungeblære': ('lungeblære',),
'lungeblæren': ('lungeblære',),
'lungeblærene': ('lungeblære',),
'lungeblærer': ('lungeblære',),
'lungebrann': ('lungebrann',),
'lungebrannen': ('lungebrann',),
'lungebrannene': ('lungebrann',),
'lungebranner': ('lungebrann',),
'lungeemfysem': ('lungeemfysem',),
'lungeemfysema': ('lungeemfysem',),
'lungeemfysemene': ('lungeemfysem',),
'lungeemfysemer': ('lungeemfysem',),
'lungeemfysemet': ('lungeemfysem',),
'lungefisk': ('lungefisk',),
'lungefisken': ('lungefisk',),
'lungefiskene': ('lungefisk',),
'lungefisker': ('lungefisk',),
'lungegangren': ('lungegangren',),
'lungegangrena': ('lungegangren',),
'lungegangrenen': ('lungegangren',),
'lungegangrenene': ('lungegangren',),
'lungegangrener': ('lungegangren',),
'lungegangrenet': ('lungegangren',),
'lungekreft': ('lungekreft',),
'lungekreften': ('lungekreft',),
'lungekreftene': ('lungekreft',),
'lungekrefter': ('lungekreft',),
'lungelapp': ('lungelapp',),
'lungelappen': ('lungelapp',),
'lungelappene': ('lungelapp',),
'lungelapper': ('lungelapp',),
'lungemos': ('lungemos',),
'lungemosen': ('lungemos',),
'lungemosene': ('lungemos',),
'lungemoser': ('lungemos',),
'lungepest': ('lungepest',),
'lungepesta': ('lungepest',),
'lungepesten': ('lungepest',),
'lungepestene': ('lungepest',),
'lungepester': ('lungepest',),
'lungesnegl': ('lungesnegl',),
'lungesneglen': ('lungesnegl',),
'lungesneglene': ('lungesnegl',),
'lungesnegler': ('lungesnegl',),
'lungesnile': ('lungesnile',),
'lungesnilen': ('lungesnile',),
'lungesnilene': ('lungesnile',),
'lungesniler': ('lungesnile',),
'lungespiss': ('lungespiss',),
'lungespissen': ('lungespiss',),
'lungespissene': ('lungespiss',),
'lungespisser': ('lungespiss',),
'lungevev': ('lungevev',),
'lungeveva': ('lungevev',),
'lungevevene': ('lungevev',),
'lungevevet': ('lungevev',),
'lungeødem': ('lungeødem',),
'lungeødema': ('lungeødem',),
'lungeødemene': ('lungeødem',),
'lungeødemer': ('lungeødem',),
'lungeødemet': ('lungeødem',),
'lunk': ('lunk',),
'lunken': ('lunk',),
'lunkene': ('lunk',),
'lunker': ('lunk',),
'lunn': ('lunn',),
'lunnen': ('lunn',),
'lunnene': ('lunn',),
'lunner': ('lunn',),
'lunna': ('lunne',),
'lunne': ('lunne',),
'lunnen': ('lunne',),
'lunnene': ('lunne',),
'lunner': ('lunne',),
'lunneplass': ('lunneplass',),
'lunneplassen': ('lunneplass',),
'lunneplassene': ('lunneplass',),
'lunneplasser': ('lunneplass',),
'lunsj': ('lunsj',),
'lunsjen': ('lunsj',),
'lunsjene': ('lunsj',),
'lunsjer': ('lunsj',),
'lunsjpause': ('lunsjpause',),
'lunsjpausen': ('lunsjpause',),
'lunsjpausene': ('lunsjpause',),
'lunsjpauser': ('lunsjpause',),
'lunt': ('lunt',),
'lunta': ('lunt',),
'luntene': ('lunt',),
'luntet': ('lunt',),
'lunta': ('lunte',),
'lunte': ('lunte',),
'lunten': ('lunte',),
'luntene': ('lunte',),
'lunter': ('lunte',),
'luntetrav': ('luntetrav',),
'luntetrava': ('luntetrav',),
'luntetravene': ('luntetrav',),
'luntetravet': ('luntetrav',),
'lupa': ('lupe',),
'lupe': ('lupe',),
'lupen': ('lupe',),
'lupene': ('lupe',),
'luper': ('lupe',),
'lupin': ('lupin',),
'lupinen': ('lupin',),
'lupinene': ('lupin',),
'lupiner': ('lupin',),
'lupus': ('lupus',),
'lupusen': ('lupus',),
'lupusene': ('lupus',),
'lupuser': ('lupus',),
'lur': ('lur',),
'luren': ('lur',),
'lurene': ('lur',),
'lurer': ('lur',),
'lur': ('lur',),
'luren': ('lur',),
'lurene': ('lur',),
'lurer': ('lur',),
'lur': ('lur',),
'lurblåser': ('lurblåser',),
'lurblåsere': ('lurblåser',),
'lurblåseren': ('lurblåser',),
'lurblåserer': ('lurblåser',),
'lurblåserne': ('lurblåser',),
'lurblåst': ('lurblåst',),
'lurblåsten': ('lurblåst',),
'lurblåstene': ('lurblåst',),
'lurblåster': ('lurblåst',),
'lurendreier': ('lurendreier',),
'lurendreiere': ('lurendreier',),
'lurendreieren': ('lurendreier',),
'lurendreierer': ('lurendreier',),
'lurendreierne': ('lurendreier',),
'lurendreieri': ('lurendreieri',),
'lurendreieria': ('lurendreieri',),
'lurendreieriene': ('lurendreieri',),
'lurendreierier': ('lurendreieri',),
'lurendreieriet': ('lurendreieri',),
'lureri': ('lureri',),
'lureria': ('lureri',),
'lureriene': ('lureri',),
'lurerier': ('lureri',),
'lureriet': ('lureri',),
'lureteppa': ('lureteppe',),
'lureteppe': ('lureteppe',),
'lureteppene': ('lureteppe',),
'luretepper': ('lureteppe',),
'lureteppet': ('lureteppe',),
'lureteppa': ('lureteppe',),
'lureteppe': ('lureteppe',),
'lureteppene': ('lureteppe',),
'luretepper': ('lureteppe',),
'lureteppet': ('lureteppe',),
'lurifaks': ('lurifaks',),
'lurifaksen': ('lurifaks',),
'lurifaksene': ('lurifaks',),
'lurifakser': ('lurifaks',),
'lurifas': ('lurifas',),
'lurifasen': ('lurifas',),
'lurifasene': ('lurifas',),
'lurifaser': ('lurifas',),
'luring': ('luring',),
'luringen': ('luring',),
'luringene': ('luring',),
'luringer': ('luring',),
'lurk': ('lurk',),
'lurken': ('lurk',),
'lurkene': ('lurk',),
'lurker': ('lurk',),
'lurv': ('lurv',),
'lurven': ('lurv',),
'lurvene': ('lurv',),
'lurver': ('lurv',),
'lurva': ('lurve',),
'lurve': ('lurve',),
'lurven': ('lurve',),
'lurvene': ('lurve',),
'lurver': ('lurve',),
'lurveleven': ('lurveleven',),
'lurvelevena': ('lurveleven',),
'lurvelevenene': ('lurveleven',),
'lurvelevenet': ('lurveleven',),
'lus': ('lus',),
'lusa': ('lus',),
'lusen': ('lus',),
'lusene': ('lus',),
'lusebetaling': ('lusebetaling',),
'lusebetalinga': ('lusebetaling',),
'lusebetalingen': ('lusebetaling',),
'lusebetalingene': ('lusebetaling',),
'lusebetalinger': ('lusebetaling',),
'lusefart': ('lusefart',),
'lusefarten': ('lusefart',),
'lusefartene': ('lusefart',),
'lusefarter': ('lusefart',),
'lusefrø': ('lusefrø',),
'lusefrøa': ('lusefrø',),
'lusefrøene': ('lusefrø',),
'lusefrøet': ('lusefrø',),
'lusegras': ('lusegras',),
'lusegrasa': ('lusegras',),
'lusegrasene': ('lusegras',),
'lusegraset': ('lusegras',),
'lusegress': ('lusegress',),
'lusegressa': ('lusegress',),
'lusegressene': ('lusegress',),
'lusegresset': ('lusegress',),
'lusekam': ('lusekam',),
'lusekammen': ('lusekam',),
'lusekammene': ('lusekam',),
'lusekammer': ('lusekam',),
'lusekjører': ('lusekjører',),
'lusekjørere': ('lusekjører',),
'lusekjøreren': ('lusekjører',),
'lusekjørerer': ('lusekjører',),
'lusekjørerne': ('lusekjører',),
'luseknekker': ('luseknekker',),
'luseknekkere': ('luseknekker',),
'luseknekkeren': ('luseknekker',),
'luseknekkerer': ('luseknekker',),
'luseknekkerne': ('luseknekker',),
'lusekofta': ('lusekofte',),
'lusekofte': ('lusekofte',),
'lusekoften': ('lusekofte',),
'lusekoftene': ('lusekofte',),
'lusekofter': ('lusekofte',),
'lusekufta': ('lusekufte',),
'lusekufte': ('lusekufte',),
'lusekuften': ('lusekufte',),
'lusekuftene': ('lusekufte',),
'lusekufter': ('lusekufte',),
'luselønn': ('luselønn',),
'luselønna': ('luselønn',),
'luselønnen': ('luselønn',),
'luselønnene': ('luselønn',),
'luselønner': ('luselønn',),
'lusern': ('lusern',),
'lusernen': ('lusern',),
'lusernene': ('lusern',),
'luserner': ('lusern',),
'luserne': ('luserne',),
'lusernen': ('luserne',),
'lusernene': ('luserne',),
'luserner': ('luserne',),
'lusflua': ('lusflue',),
'lusflue': ('lusflue',),
'lusfluen': ('lusflue',),
'lusfluene': ('lusflue',),
'lusfluer': ('lusflue',),
'lushatt': ('lushatt',),
'lushatten': ('lushatt',),
'lushattene': ('lushatt',),
'lushatter': ('lushatt',),
'lusing': ('lusing',),
'lusingen': ('lusing',),
'lusingene': ('lusing',),
'lusinger': ('lusing',),
'lussekatt': ('lussekatt',),
'lussekatten': ('lussekatt',),
'lussekattene': ('lussekatt',),
'lussekatter': ('lussekatt',),
'lut': ('lut',),
'luten': ('lut',),
'lutene': ('lut',),
'luter': ('lut',),
'lut': ('lut',),
'luta': ('lut',),
'luten': ('lut',),
'lutene': ('lut',),
'luter': ('lut',),
'lutaska': ('lutaske',),
'lutaske': ('lutaske',),
'lutasken': ('lutaske',),
'lutaskene': ('lutaske',),
'lutasker': ('lutaske',),
'lutefisk': ('lutefisk',),
'lutefisken': ('lutefisk',),
'lutefiskene': ('lutefisk',),
'lutefisker': ('lutefisk',),
'lutetium': ('lutetium',),
'lutetiuma': ('lutetium',),
'lutetiumene': ('lutetium',),
'lutetiumet': ('lutetium',),
'lutfisk': ('lutfisk',),
'lutfisken': ('lutfisk',),
'lutfiskene': ('lutfisk',),
'lutfisker': ('lutfisk',),
'lutheraner': ('lutheraner',),
'lutheranere': ('lutheraner',),
'lutheraneren': ('lutheraner',),
'lutheranerer': ('lutheraner',),
'lutheranerne': ('lutheraner',),
'lutherdom': ('lutherdom',),
'lutherdommen': ('lutherdom',),
'lutherdommene': ('lutherdom',),
'lutherdommer': ('lutherdom',),
'lutring': ('lutring',),
'lutringa': ('lutring',),
'lutringen': ('lutring',),
'lutringene': ('lutring',),
'lutringer': ('lutring',),
'lutt': ('lutt',),
'lutten': ('lutt',),
'luttene': ('lutt',),
'lutter': ('lutt',),
'luvart': ('luvart',),
'luva': ('luve',),
'luve': ('luve',),
'luven': ('luve',),
'luvene': ('luve',),
'luver': ('luve',),
'luva': ('luve',),
'luve': ('luve',),
'luven': ('luve',),
'luvene': ('luve',),
'luver': ('luve',),
'lux': ('lux',),
'luxen': ('lux',),
'luxene': ('lux',),
'luxembourger': ('luxembourger',),
'luxembourgere': ('luxembourger',),
'luxembourgeren': ('luxembourger',),
'luxembourgerer': ('luxembourger',),
'luxembourgerne': ('luxembourger',),
'luxemburger': ('luxemburger',),
'luxemburgere': ('luxemburger',),
'luxemburgeren': ('luxemburger',),
'luxemburgerer': ('luxemburger',),
'luxemburgerne': ('luxemburger',),
'luxmeter': ('luxmeter',),
'luxmeteret': ('luxmeter',),
'luxmetra': ('luxmeter',),
'luxmetre': ('luxmeter',),
'luxmetrene': ('luxmeter',),
'luxmetret': ('luxmeter',),
'ly': ('ly',),
'lya': ('ly',),
'lyene': ('ly',),
'lyet': ('ly',),
'lybekker': ('lybekker',),
'lybekkere': ('lybekker',),
'lybekkeren': ('lybekker',),
'lybekkerer': ('lybekker',),
'lybekkerne': ('lybekker',),
'lycea': ('lycé',),
'lyceene': ('lycé',),
'lyceer': ('lycé',),
'lyceet': ('lycé',),
'lycé': ('lycé',),
'lycéa': ('lycé',),
'lycéene': ('lycé',),
'lycéer': ('lycé',),
'lycéet': ('lycé',),
'lyd': ('lyd',),
'lyden': ('lyd',),
'lydene': ('lyd',),
'lyder': ('lyd',),
'lyd': ('lyd',),
'lyden': ('lyd',),
'lydene': ('lyd',),
'lyder': ('lyd',),
'lydarslått': ('lydarslått',),
'lydarslåtten': ('lydarslått',),
'lydarslåttene': ('lydarslått',),
'lydarslåtter': ('lydarslått',),
'lydavis': ('lydavis',),
'lydavisa': ('lydavis',),
'lydavisen': ('lydavis',),
'lydavisene': ('lydavis',),
'lydaviser': ('lydavis',),
'lydband': ('lydband',),
'lydbanda': ('lydband',),
'lydbandene': ('lydband',),
'lydbandet': ('lydband',),
'lydbandavis': ('lydbandavis',),
'lydbandavisa': ('lydbandavis',),
'lydbandavisen': ('lydbandavis',),
'lydbandavisene': ('lydbandavis',),
'lydbandaviser': ('lydbandavis',),
'lydbandavis': ('lydbandavis',),
'lydbandavisa': ('lydbandavis',),
'lydbandavisen': ('lydbandavis',),
'lydbandavisene': ('lydbandavis',),
'lydbandaviser': ('lydbandavis',),
'lydbandopptak': ('lydbandopptak',),
'lydbandopptaka': ('lydbandopptak',),
'lydbandopptakene': ('lydbandopptak',),
'lydbandopptaket': ('lydbandopptak',),
'lydbandopptaker': ('lydbandopptaker',),
'lydbandopptakere': ('lydbandopptaker',),
'lydbandopptakeren': ('lydbandopptaker',),
'lydbandopptakerer': ('lydbandopptaker',),
'lydbandopptakerne': ('lydbandopptaker',),
'lydbibliotek': ('lydbibliotek',),
'lydbiblioteka': ('lydbibliotek',),
'lydbibliotekene': ('lydbibliotek',),
'lydbiblioteker': ('lydbibliotek',),
'lydbiblioteket': ('lydbibliotek',),
'lydbrev': ('lydbrev',),
'lydbreva': ('lydbrev',),
'lydbrevene': ('lydbrev',),
'lydbrever': ('lydbrev',),
'lydbrevet': ('lydbrev',),
'lydbånd': ('lydbånd',),
'lydbånda': ('lydbånd',),
'lydbåndene': ('lydbånd',),
'lydbåndet': ('lydbånd',),
'lydbåndavis': ('lydbåndavis',),
'lydbåndavisa': ('lydbåndavis',),
'lydbåndavisen': ('lydbåndavis',),
'lydbåndavisene': ('lydbåndavis',),
'lydbåndaviser': ('lydbåndavis',),
'lydbåndavis': ('lydbåndavis',),
'lydbåndavisa': ('lydbåndavis',),
'lydbåndavisen': ('lydbåndavis',),
'lydbåndavisene': ('lydbåndavis',),
'lydbåndaviser': ('lydbåndavis',),
'lydbåndopptak': ('lydbåndopptak',),
'lydbåndopptaka': ('lydbåndopptak',),
'lydbåndopptakene': ('lydbåndopptak',),
'lydbåndopptaket': ('lydbåndopptak',),
'lydbåndopptaker': ('lydbåndopptaker',),
'lydbåndopptakere': ('lydbåndopptaker',),
'lydbåndopptakeren': ('lydbåndopptaker',),
'lydbåndopptakerer': ('lydbåndopptaker',),
'lydbåndopptakerne': ('lydbåndopptaker',),
'lydbølga': ('lydbølge',),
'lydbølge': ('lydbølge',),
'lydbølgen': ('lydbølge',),
'lydbølgene': ('lydbølge',),
'lydbølger': ('lydbølge',),
'lydbølgja': ('lydbølgje',),
'lydbølgje': ('lydbølgje',),
'lydbølgjen': ('lydbølgje',),
'lydbølgjene': ('lydbølgje',),
'lydbølgjer': ('lydbølgje',),
'lyddemper': ('lyddemper',),
'lyddempere': ('lyddemper',),
'lyddemperen': ('lyddemper',),
'lyddemperer': ('lyddemper',),
'lyddemperne': ('lyddemper',),
'lydendring': ('lydendring',),
'lydendringa': ('lydendring',),
'lydendringen': ('lydendring',),
'lydendringene': ('lydendring',),
'lydendringer': ('lydendring',),
'lydfilm': ('lydfilm',),
'lydfilmen': ('lydfilm',),
'lydfilmene': ('lydfilm',),
'lydfilmer': ('lydfilm',),
'lydforandring': ('lydforandring',),
'lydforandringa': ('lydforandring',),
'lydforandringen': ('lydforandring',),
'lydforandringene': ('lydforandring',),
'lydforandringer': ('lydforandring',),
'lydforskyvning': ('lydforskyvning',),
'lydforskyvninga': ('lydforskyvning',),
'lydforskyvningen': ('lydforskyvning',),
'lydforskyvningene': ('lydforskyvning',),
'lydforskyvninger': ('lydforskyvning',),
'lydhastighet': ('lydhastighet',),
'lydhastigheta': ('lydhastighet',),
'lydhastigheten': ('lydhastighet',),
'lydhastighetene': ('lydhastighet',),
'lydhastigheter': ('lydhastighet',),
'lydhoda': ('lydhode',),
'lydhode': ('lydhode',),
'lydhodene': ('lydhode',),
'lydhoder': ('lydhode',),
'lydhodet': ('lydhode',),
'lydhol': ('lydhol',),
'lydhola': ('lydhol',),
'lydholene': ('lydhol',),
'lydholet': ('lydhol',),
'lydhull': ('lydhull',),
'lydhulla': ('lydhull',),
'lydhullene': ('lydhull',),
'lydhuller': ('lydhull',),
'lydhullet': ('lydhull',),
'lydier': ('lydier',),
'lydiere': ('lydier',),
'lydieren': ('lydier',),
'lydierer': ('lydier',),
'lydierne': ('lydier',),
'lydighet': ('lydighet',),
'lydigheta': ('lydighet',),
'lydigheten': ('lydighet',),
'lydighetene': ('lydighet',),
'lydigheter': ('lydighet',),
'lydisolasjon': ('lydisolasjon',),
'lydisolasjonen': ('lydisolasjon',),
'lydisolasjonene': ('lydisolasjon',),
'lydisolasjoner': ('lydisolasjon',),
'lydkilde': ('lydkilde',),
'lydkilden': ('lydkilde',),
'lydkildene': ('lydkilde',),
'lydkilder': ('lydkilde',),
'lydkjelda': ('lydkjelde',),
'lydkjelde': ('lydkjelde',),
'lydkjelden': ('lydkjelde',),
'lydkjeldene': ('lydkjelde',),
'lydkjelder': ('lydkjelde',),
'lydkonge': ('lydkonge',),
'lydkongen': ('lydkonge',),
'lydkongene': ('lydkonge',),
'lydkonger': ('lydkonge',),
'lydkulissa': ('lydkulisse',),
'lydkulisse': ('lydkulisse',),
'lydkulissen': ('lydkulisse',),
'lydkulissene': ('lydkulisse',),
'lydkulisser': ('lydkulisse',),
'lydland': ('lydland',),
'lydlanda': ('lydland',),
'lydlandene': ('lydland',),
'lydlandet': ('lydland',),
'lydlov': ('lydlov',),
'lydloven': ('lydlov',),
'lydlovene': ('lydlov',),
'lydlover': ('lydlov',),
'lydlæra': ('lydlære',),
'lydlære': ('lydlære',),
'lydlæren': ('lydlære',),
'lydlærene': ('lydlære',),
'lydlærer': ('lydlære',),
'lydmur': ('lydmur',),
'lydmuren': ('lydmur',),
'lydmurene': ('lydmur',),
'lydmurer': ('lydmur',),
'lydnad': ('lydnad',),
'lydnaden': ('lydnad',),
'lydnadene': ('lydnad',),
'lydnader': ('lydnad',),
'lydord': ('lydord',),
'lydorda': ('lydord',),
'lydordene': ('lydord',),
'lydordet': ('lydord',),
'lydovergang': ('lydovergang',),
'lydovergangen': ('lydovergang',),
'lydovergangene': ('lydovergang',),
'lydoverganger': ('lydovergang',),
'lydplakat': ('lydplakat',),
'lydplakaten': ('lydplakat',),
'lydplakatene': ('lydplakat',),
'lydplakater': ('lydplakat',),
'lydpotta': ('lydpotte',),
'lydpotte': ('lydpotte',),
'lydpotten': ('lydpotte',),
'lydpottene': ('lydpotte',),
'lydpotter': ('lydpotte',),
'lydradio': ('lydradio',),
'lydradioen': ('lydradio',),
'lydradioene': ('lydradio',),
'lydradioer': ('lydradio',),
'lydrika': ('lydrike',),
'lydrike': ('lydrike',),
'lydrikene': ('lydrike',),
'lydriker': ('lydrike',),
'lydriket': ('lydrike',),
'lydsetting': ('lydsetting',),
'lydsettinga': ('lydsetting',),
'lydsettingen': ('lydsetting',),
'lydsettingene': ('lydsetting',),
'lydsettinger': ('lydsetting',),
'lydskrift': ('lydskrift',),
'lydskrifta': ('lydskrift',),
'lydskriften': ('lydskrift',),
'lydskriftene': ('lydskrift',),
'lydskrifter': ('lydskrift',),
'lydstyrke': ('lydstyrke',),
'lydstyrken': ('lydstyrke',),
'lydstyrkene': ('lydstyrke',),
'lydstyrker': ('lydstyrke',),
'lydtegn': ('lydtegn',),
'lydtegna': ('lydtegn',),
'lydtegnene': ('lydtegn',),
'lydtegnet': ('lydtegn',),
'lydtekniker': ('lydtekniker',),
'lydteknikere': ('lydtekniker',),
'lydteknikeren': ('lydtekniker',),
'lydteknikerer': ('lydtekniker',),
'lydteknikerne': ('lydtekniker',),
'lydtrykk': ('lydtrykk',),
'lydtrykka': ('lydtrykk',),
'lydtrykkene': ('lydtrykk',),
'lydtrykket': ('lydtrykk',),
'lydverk': ('lydverk',),
'lydverka': ('lydverk',),
'lydverkene': ('lydverk',),
'lydverker': ('lydverk',),
'lydverket': ('lydverk',),
'lykka': ('lykke',),
'lykke': ('lykke',),
'lykken': ('lykke',),
'lykkene': ('lykke',),
'lykker': ('lykke',),
'lykkedag': ('lykkedag',),
'lykkedagen': ('lykkedag',),
'lykkedagene': ('lykkedag',),
'lykkedager': ('lykkedag',),
'lykkehjul': ('lykkehjul',),
'lykkehjula': ('lykkehjul',),
'lykkehjulene': ('lykkehjul',),
'lykkehjulet': ('lykkehjul',),
'lykkeridder': ('lykkeridder',),
'lykkeriddere': ('lykkeridder',),
'lykkeridderen': ('lykkeridder',),
'lykkeridderer': ('lykkeridder',),
'lykkeridderne': ('lykkeridder',),
'lykkerus': ('lykkerus',),
'lykkerusa': ('lykkerus',),
'lykkerusen': ('lykkerus',),
'lykkerusene': ('lykkerus',),
'lykkeruser': ('lykkerus',),
'lykkeruset': ('lykkerus',),
'lykkeskilling': ('lykkeskilling',),
'lykkeskillingen': ('lykkeskilling',),
'lykkeskillingene': ('lykkeskilling',),
'lykkeskillinger': ('lykkeskilling',),
'lykketal': ('lykketal',),
'lykketala': ('lykketal',),
'lykketalene': ('lykketal',),
'lykketalet': ('lykketal',),
'lykketall': ('lykketall',),
'lykketalla': ('lykketall',),
'lykketallene': ('lykketall',),
'lykketallet': ('lykketall',),
'lykketreff': ('lykketreff',),
'lykketreffa': ('lykketreff',),
'lykketreffene': ('lykketreff',),
'lykketreffet': ('lykketreff',),
'lykkønskning': ('lykkønskning',),
'lykkønskninga': ('lykkønskning',),
'lykkønskningen': ('lykkønskning',),
'lykkønskningene': ('lykkønskning',),
'lykkønskninger': ('lykkønskning',),
'lykt': ('lykt',),
'lykta': ('lykt',),
'lykten': ('lykt',),
'lyktene': ('lykt',),
'lykter': ('lykt',),
'lyktemann': ('lyktemann',),
'lyktemannen': ('lyktemann',),
'lyktemenn': ('lyktemann',),
'lyktemennene': ('lyktemann',),
'lyktestolpe': ('lyktestolpe',),
'lyktestolpen': ('lyktestolpe',),
'lyktestolpene': ('lyktestolpe',),
'lyktestolper': ('lyktestolpe',),
'lyktetenner': ('lyktetenner',),
'lyktetennere': ('lyktetenner',),
'lyktetenneren': ('lyktetenner',),
'lyktetennerer': ('lyktetenner',),
'lyktetennerne': ('lyktetenner',),
'lymfe': ('lymfe',),
'lymfen': ('lymfe',),
'lymfene': ('lymfe',),
'lymfer': ('lymfe',),
'lymfecella': ('lymfecelle',),
'lymfecelle': ('lymfecelle',),
'lymfecellen': ('lymfecelle',),
'lymfecellene': ('lymfecelle',),
'lymfeceller': ('lymfecelle',),
'lymfekar': ('lymfekar',),
'lymfekara': ('lymfekar',),
'lymfekarene': ('lymfekar',),
'lymfekaret': ('lymfekar',),
'lymfekjertel': ('lymfekjertel',),
'lymfekjertelen': ('lymfekjertel',),
'lymfekjertlene': ('lymfekjertel',),
'lymfekjertler': ('lymfekjertel',),
'lymfeknute': ('lymfeknute',),
'lymfeknuten': ('lymfeknute',),
'lymfeknutene': ('lymfeknute',),
'lymfeknuter': ('lymfeknute',),
'lymfesystem': ('lymfesystem',),
'lymfesystema': ('lymfesystem',),
'lymfesystemene': ('lymfesystem',),
'lymfesystemer': ('lymfesystem',),
'lymfesystemet': ('lymfesystem',),
'lymfeåra': ('lymfeåre',),
'lymfeåre': ('lymfeåre',),
'lymfeåren': ('lymfeåre',),
'lymfeårene': ('lymfeåre',),
'lymfeårer': ('lymfeåre',),
'lymfeåresystem': ('lymfeåresystem',),
'lymfeåresystema': ('lymfeåresystem',),
'lymfeåresystemene': ('lymfeåresystem',),
'lymfeåresystemer': ('lymfeåresystem',),
'lymfeåresystemet': ('lymfeåresystem',),
'lymfocytt': ('lymfocytt',),
'lymfocytten': ('lymfocytt',),
'lymfocyttene': ('lymfocytt',),
'lymfocytter': ('lymfocytt',),
'lyn': ('lyn',),
'lyna': ('lyn',),
'lynene': ('lyn',),
'lynet': ('lyn',),
'lynavleder': ('lynavleder',),
'lynavledere': ('lynavleder',),
'lynavlederen': ('lynavleder',),
'lynavlederer': ('lynavleder',),
'lynavlederne': ('lynavleder',),
'lynblink': ('lynblink',),
'lynblinka': ('lynblink',),
'lynblinkene': ('lynblink',),
'lynblinket': ('lynblink',),
'lyneld': ('lyneld',),
'lynelden': ('lyneld',),
'lyneldene': ('lyneld',),
'lynelder': ('lyneld',),
'lyneld': ('lyneld',),
'lynelden': ('lyneld',),
'lyneldene': ('lyneld',),
'lynelder': ('lyneld',),
'lynfart': ('lynfart',),
'lynfarten': ('lynfart',),
'lynfartene': ('lynfart',),
'lynfarter': ('lynfart',),
'lyng': ('lyng',),
'lynga': ('lyng',),
'lyngen': ('lyng',),
'lyngene': ('lyng',),
'lynger': ('lyng',),
'lynget': ('lyng',),
'lyngfamilie': ('lyngfamilie',),
'lyngfamilien': ('lyngfamilie',),
'lyngfamiliene': ('lyngfamilie',),
'lyngfamilier': ('lyngfamilie',),
'lynghei': ('lynghei',),
'lyngheia': ('lynghei',),
'lyngheien': ('lynghei',),
'lyngheiene': ('lynghei',),
'lyngheier': ('lynghei',),
'lynghonning': ('lynghonning',),
'lynghonninga': ('lynghonning',),
'lynghonningen': ('lynghonning',),
'lynghonningene': ('lynghonning',),
'lynghonninger': ('lynghonning',),
'lynglimt': ('lynglimt',),
'lynglimta': ('lynglimt',),
'lynglimten': ('lynglimt',),
'lynglimtene': ('lynglimt',),
'lynglimtet': ('lynglimt',),
'lyngshest': ('lyngshest',),
'lyngshesten': ('lyngshest',),
'lyngshestene': ('lyngshest',),
'lyngshester': ('lyngshest',),
'lynild': ('lynild',),
'lynilden': ('lynild',),
'lynildene': ('lynild',),
'lynilder': ('lynild',),
'lynild': ('lynild',),
'lynilden': ('lynild',),
'lynildene': ('lynild',),
'lynilder': ('lynild',),
'lynkarriera': ('lynkarriere',),
'lynkarriere': ('lynkarriere',),
'lynkarrieren': ('lynkarriere',),
'lynkarrierene': ('lynkarriere',),
'lynkarrierer': ('lynkarriere',),
'lynkrig': ('lynkrig',),
'lynkrigen': ('lynkrig',),
'lynkrigene': ('lynkrig',),
'lynkriger': ('lynkrig',),
'lynkurs': ('lynkurs',),
'lynkursa': ('lynkurs',),
'lynkursene': ('lynkurs',),
'lynkurser': ('lynkurs',),
'lynkurset': ('lynkurs',),
'lynkursene': ('lynkursus',),
'lynkurser': ('lynkursus',),
'lynkursus': ('lynkursus',),
'lynkursuset': ('lynkursus',),
'lynna': ('lynne',),
'lynne': ('lynne',),
'lynnene': ('lynne',),
'lynner': ('lynne',),
'lynnet': ('lynne',),
'lynnedslag': ('lynnedslag',),
'lynnedslaga': ('lynnedslag',),
'lynnedslagene': ('lynnedslag',),
'lynnedslaget': ('lynnedslag',),
'lynol': ('lynol',),
'lynolen': ('lynol',),
'lynolene': ('lynol',),
'lynoler': ('lynol',),
'lynsjakk': ('lynsjakk',),
'lynsjakken': ('lynsjakk',),
'lynsjakkene': ('lynsjakk',),
'lynsjakker': ('lynsjakk',),
'lyntog': ('lyntog',),
'lyntoga': ('lyntog',),
'lyntogene': ('lyntog',),
'lyntoget': ('lyntog',),
'lynvisitt': ('lynvisitt',),
'lynvisitten': ('lynvisitt',),
'lynvisittene': ('lynvisitt',),
'lynvisitter': ('lynvisitt',),
'lyriker': ('lyriker',),
'lyrikere': ('lyriker',),
'lyrikeren': ('lyriker',),
'lyrikerer': ('lyriker',),
'lyrikerne': ('lyriker',),
'lyrikk': ('lyrikk',),
'lyrikken': ('lyrikk',),
'lyrikkene': ('lyrikk',),
'lyrikker': ('lyrikk',),
'lys': ('lys',),
'lysa': ('lys',),
'lysene': ('lys',),
'lyset': ('lys',),
'lysalv': ('lysalv',),
'lysalven': ('lysalv',),
'lysalvene': ('lysalv',),
'lysalver': ('lysalv',),
'lysarmatur': ('lysarmatur',),
'lysarmaturen': ('lysarmatur',),
'lysarmaturene': ('lysarmatur',),
'lysarmaturer': ('lysarmatur',),
'lysavis': ('lysavis',),
'lysavisa': ('lysavis',),
'lysavisen': ('lysavis',),
'lysavisene': ('lysavis',),
'lysaviser': ('lysavis',),
'lysbilda': ('lysbilde',),
'lysbilde': ('lysbilde',),
'lysbildene': ('lysbilde',),
'lysbilder': ('lysbilde',),
'lysbildet': ('lysbilde',),
'lysbildeapparat': ('lysbildeapparat',),
'lysbildeapparata': ('lysbildeapparat',),
'lysbildeapparatene': ('lysbildeapparat',),
'lysbildeapparater': ('lysbildeapparat',),
'lysbildeapparatet': ('lysbildeapparat',),
'lysbille': ('lysbille',),
'lysbillen': ('lysbille',),
'lysbillene': ('lysbille',),
'lysbiller': ('lysbille',),
'lysblink': ('lysblink',),
'lysblinka': ('lysblink',),
'lysblinkene': ('lysblink',),
'lysblinket': ('lysblink',),
'lysboge': ('lysboge',),
'lysbogen': ('lysboge',),
'lysbogene': ('lysboge',),
'lysboger': ('lysboge',),
'lysbomba': ('lysbombe',),
'lysbombe': ('lysbombe',),
'lysbomben': ('lysbombe',),
'lysbombene': ('lysbombe',),
'lysbomber': ('lysbombe',),
'lysbryter': ('lysbryter',),
'lysbrytere': ('lysbryter',),
'lysbryteren': ('lysbryter',),
'lysbryterer': ('lysbryter',),
'lysbryterne': ('lysbryter',),
'lysbryting': ('lysbryting',),
'lysbrytinga': ('lysbryting',),
'lysbrytingen': ('lysbryting',),
'lysbrytingene': ('lysbryting',),
'lysbrytinger': ('lysbryting',),
'lysbrytning': ('lysbrytning',),
'lysbrytninga': ('lysbrytning',),
'lysbrytningen': ('lysbrytning',),
'lysbrytningene': ('lysbrytning',),
'lysbrytninger': ('lysbrytning',),
'lysbue': ('lysbue',),
'lysbuen': ('lysbue',),
'lysbuene': ('lysbue',),
'lysbuer': ('lysbue',),
'lysbøya': ('lysbøye',),
'lysbøye': ('lysbøye',),
'lysbøyen': ('lysbøye',),
'lysbøyene': ('lysbøye',),
'lysbøyer': ('lysbøye',),
'lysa': ('lyse',),
'lyse': ('lyse',),
'lysen': ('lyse',),
'lysene': ('lyse',),
'lyser': ('lyse',),
'lysekrona': ('lysekrone',),
'lysekrone': ('lysekrone',),
'lysekronen': ('lysekrone',),
'lysekronene': ('lysekrone',),
'lysekroner': ('lysekrone',),
'lysergsyra': ('lysergsyre',),
'lysergsyre': ('lysergsyre',),
'lysergsyren': ('lysergsyre',),
'lysergsyrene': ('lysergsyre',),
'lysergsyrer': ('lysergsyre',),
'lysergsyredietylamid': ('lysergsyredietylamid',),
'lysergsyredietylamida': ('lysergsyredietylamid',),
'lysergsyredietylamidene': ('lysergsyredietylamid',),
'lysergsyredietylamider': ('lysergsyredietylamid',),
'lysergsyredietylamidet': ('lysergsyredietylamid',),
'lysesaks': ('lysesaks',),
'lysesaksa': ('lysesaks',),
'lysesaksen': ('lysesaks',),
'lysesaksene': ('lysesaks',),
'lysesakser': ('lysesaks',),
'lyseslokker': ('lyseslokker',),
'lyseslokkere': ('lyseslokker',),
'lyseslokkeren': ('lyseslokker',),
'lyseslokkerer': ('lyseslokker',),
'lyseslokkerne': ('lyseslokker',),
'lyseslukker': ('lyseslukker',),
'lyseslukkere': ('lyseslukker',),
'lyseslukkeren': ('lyseslukker',),
'lyseslukkerer': ('lyseslukker',),
'lyseslukkerne': ('lyseslukker',),
'lysestake': ('lysestake',),
'lysestaken': ('lysestake',),
'lysestakene': ('lysestake',),
'lysestaker': ('lysestake',),
'lysestøper': ('lysestøper',),
'lysestøpere': ('lysestøper',),
'lysestøperen': ('lysestøper',),
'lysestøperer': ('lysestøper',),
'lysestøperne': ('lysestøper',),
'lysestøyper': ('lysestøyper',),
'lysestøypere': ('lysestøyper',),
'lysestøyperen': ('lysestøyper',),
'lysestøyperer': ('lysestøyper',),
'lysestøyperne': ('lysestøyper',),
'lysfiska': ('lysfiske',),
'lysfiske': ('lysfiske',),
'lysfiskene': ('lysfiske',),
'lysfisker': ('lysfiske',),
'lysfisket': ('lysfiske',),
'lysgass': ('lysgass',),
'lysgassen': ('lysgass',),
'lysgassene': ('lysgass',),
'lysgasser': ('lysgass',),
'lysglimt': ('lysglimt',),
'lysglimta': ('lysglimt',),
'lysglimten': ('lysglimt',),
'lysglimtene': ('lysglimt',),
'lysglimtet': ('lysglimt',),
'lyshastighet': ('lyshastighet',),
'lyshastigheta': ('lyshastighet',),
'lyshastigheten': ('lyshastighet',),
'lyshastighetene': ('lyshastighet',),
'lyshastigheter': ('lyshastighet',),
'lyshorn': ('lyshorn',),
'lyshorna': ('lyshorn',),
'lyshornene': ('lyshorn',),
'lyshornet': ('lyshorn',),
'lysing': ('lysing',),
'lysingen': ('lysing',),
'lysingene': ('lysing',),
'lysinger': ('lysing',),
'lysing': ('lysing',),
'lysinga': ('lysing',),
'lysingen': ('lysing',),
'lysingene': ('lysing',),
'lysinger': ('lysing',),
'lyskassa': ('lyskasse',),
'lyskasse': ('lyskasse',),
'lyskassen': ('lyskasse',),
'lyskassene': ('lyskasse',),
'lyskasser': ('lyskasse',),
'lyskaster': ('lyskaster',),
'lyskastere': ('lyskaster',),
'lyskasteren': ('lyskaster',),
'lyskasterer': ('lyskaster',),
'lyskasterne': ('lyskaster',),
'lyske': ('lyske',),
'lysken': ('lyske',),
'lyskene': ('lyske',),
'lysker': ('lyske',),
'lyskebrokk': ('lyskebrokk',),
'lyskebrokka': ('lyskebrokk',),
'lyskebrokken': ('lyskebrokk',),
'lyskebrokkene': ('lyskebrokk',),
'lyskebrokker': ('lyskebrokk',),
'lyskebrokket': ('lyskebrokk',),
'lyskekanal': ('lyskekanal',),
'lyskekanalen': ('lyskekanal',),
'lyskekanalene': ('lyskekanal',),
'lyskekanaler': ('lyskekanal',),
'lyskilde': ('lyskilde',),
'lyskilden': ('lyskilde',),
'lyskildene': ('lyskilde',),
'lyskilder': ('lyskilde',),
'lyskjelda': ('lyskjelde',),
'lyskjelde': ('lyskjelde',),
'lyskjelden': ('lyskjelde',),
'lyskjeldene': ('lyskjelde',),
'lyskjelder': ('lyskjelde',),
'lyskopi': ('lyskopi',),
'lyskopien': ('lyskopi',),
'lyskopiene': ('lyskopi',),
'lyskopier': ('lyskopi',),
'lyskopiering': ('lyskopiering',),
'lyskopieringa': ('lyskopiering',),
'lyskopieringen': ('lyskopiering',),
'lyskopieringene': ('lyskopiering',),
'lyskopieringer': ('lyskopiering',),
'lyskryss': ('lyskryss',),
'lyskryssa': ('lyskryss',),
'lyskryssene': ('lyskryss',),
'lyskrysset': ('lyskryss',),
'lyskvant': ('lyskvant',),
'lyskvanta': ('lyskvant',),
'lyskvantene': ('lyskvant',),
'lyskvanter': ('lyskvant',),
'lyskvantet': ('lyskvant',),
'lysløypa': ('lysløype',),
'lysløype': ('lysløype',),
'lysløypen': ('lysløype',),
'lysløypene': ('lysløype',),
'lysløyper': ('lysløype',),
'lysmansjett': ('lysmansjett',),
'lysmansjetten': ('lysmansjett',),
'lysmansjettene': ('lysmansjett',),
'lysmansjetter': ('lysmansjett',),
'lysmast': ('lysmast',),
'lysmasta': ('lysmast',),
'lysmasten': ('lysmast',),
'lysmastene': ('lysmast',),
'lysmaster': ('lysmast',),
'lysmessa': ('lysmesse',),
'lysmesse': ('lysmesse',),
'lysmessen': ('lysmesse',),
'lysmessene': ('lysmesse',),
'lysmesser': ('lysmesse',),
'lysmester': ('lysmester',),
'lysmestere': ('lysmester',),
'lysmesteren': ('lysmester',),
'lysmesterer': ('lysmester',),
'lysmesterne': ('lysmester',),
'lysmestre': ('lysmester',),
'lysmestrene': ('lysmester',),
'lysmestrer': ('lysmester',),
'lysmåler': ('lysmåler',),
'lysmålere': ('lysmåler',),
'lysmåleren': ('lysmåler',),
'lysmålerer': ('lysmåler',),
'lysmålerne': ('lysmåler',),
'lysnett': ('lysnett',),
'lysnetta': ('lysnett',),
'lysnettene': ('lysnett',),
'lysnettet': ('lysnett',),
'lysning': ('lysning',),
'lysninga': ('lysning',),
'lysningen': ('lysning',),
'lysningene': ('lysning',),
'lysninger': ('lysning',),
'lysol': ('lysol',),
'lysolen': ('lysol',),
'lysolene': ('lysol',),
'lysoler': ('lysol',),
'lysolja': ('lysolje',),
'lysolje': ('lysolje',),
'lysoljen': ('lysolje',),
'lysoljene': ('lysolje',),
'lysoljer': ('lysolje',),
'lysorgan': ('lysorgan',),
'lysorgana': ('lysorgan',),
'lysorganene': ('lysorgan',),
'lysorganer': ('lysorgan',),
'lysorganet': ('lysorgan',),
'lysorgel': ('lysorgel',),
'lysorgelet': ('lysorgel',),
'lysorgla': ('lysorgel',),
'lysorglene': ('lysorgel',),
'lysorgler': ('lysorgel',),
'lysorglet': ('lysorgel',),
'lyspenn': ('lyspenn',),
'lyspennen': ('lyspenn',),
'lyspennene': ('lyspenn',),
'lyspenner': ('lyspenn',),
'lyspunkt': ('lyspunkt',),
'lyspunkta': ('lyspunkt',),
'lyspunktene': ('lyspunkt',),
'lyspunkter': ('lyspunkt',),
'lyspunktet': ('lyspunkt',),
'lyspæra': ('lyspære',),
'lyspære': ('lyspære',),
'lyspæren': ('lyspære',),
'lyspærene': ('lyspære',),
'lyspærer': ('lyspære',),
'lysreklame': ('lysreklame',),
'lysreklamen': ('lysreklame',),
'lysreklamene': ('lysreklame',),
'lysreklamer': ('lysreklame',),
'lysrør': ('lysrør',),
'lysrøra': ('lysrør',),
'lysrørene': ('lysrør',),
'lysrøret': ('lysrør',),
'lysrørpæra': ('lysrørpære',),
'lysrørpære': ('lysrørpære',),
'lysrørpæren': ('lysrørpære',),
'lysrørpærene': ('lysrørpære',),
'lysrørpærer': ('lysrørpære',),
'lyssida': ('lysside',),
'lysside': ('lysside',),
'lyssiden': ('lysside',),
'lyssidene': ('lysside',),
'lyssider': ('lysside',),
'lyssignal': ('lyssignal',),
'lyssignala': ('lyssignal',),
'lyssignalene': ('lyssignal',),
'lyssignaler': ('lyssignal',),
'lyssignalet': ('lyssignal',),
'lysstoffrør': ('lysstoffrør',),
'lysstoffrøra': ('lysstoffrør',),
'lysstoffrørene': ('lysstoffrør',),
'lysstoffrøret': ('lysstoffrør',),
'lysstrima': ('lysstrime',),
'lysstrime': ('lysstrime',),
'lysstrimen': ('lysstrime',),
'lysstrimene': ('lysstrime',),
'lysstrimer': ('lysstrime',),
'lysstråle': ('lysstråle',),
'lysstrålen': ('lysstråle',),
'lysstrålene': ('lysstråle',),
'lysstråler': ('lysstråle',),
'lysstrøm': ('lysstrøm',),
'lysstrømmen': ('lysstrøm',),
'lysstrømmene': ('lysstrøm',),
'lysstrømmer': ('lysstrøm',),
'lysstyrke': ('lysstyrke',),
'lysstyrken': ('lysstyrke',),
'lysstyrkene': ('lysstyrke',),
'lysstyrker': ('lysstyrke',),
'lyst': ('lyst',),
'lysta': ('lyst',),
'lysten': ('lyst',),
'lystene': ('lyst',),
'lyster': ('lyst',),
'lystbåt': ('lystbåt',),
'lystbåten': ('lystbåt',),
'lystbåtene': ('lystbåt',),
'lystbåter': ('lystbåt',),
'lyster': ('lyster',),
'lysteren': ('lyster',),
'lystra': ('lyster',),
'lystre': ('lyster',),
'lystrene': ('lyster',),
'lystrer': ('lyster',),
'lystfiska': ('lystfiske',),
'lystfiske': ('lystfiske',),
'lystfiskene': ('lystfiske',),
'lystfisker': ('lystfiske',),
'lystfisket': ('lystfiske',),
'lystfisker': ('lystfisker',),
'lystfiskere': ('lystfisker',),
'lystfiskeren': ('lystfisker',),
'lystfiskerer': ('lystfisker',),
'lystfiskerne': ('lystfisker',),
'lystgass': ('lystgass',),
'lystgassen': ('lystgass',),
'lystgassene': ('lystgass',),
'lystgasser': ('lystgass',),
'lysthus': ('lysthus',),
'lysthusa': ('lysthus',),
'lysthusene': ('lysthus',),
'lysthuset': ('lysthus',),
'lystløgner': ('lystløgner',),
'lystløgnere': ('lystløgner',),
'lystløgneren': ('lystløgner',),
'lystløgnerer': ('lystløgner',),
'lystløgnerne': ('lystløgner',),
'lystmord': ('lystmord',),
'lystmorda': ('lystmord',),
'lystmordene': ('lystmord',),
'lystmordet': ('lystmord',),
'lystmorder': ('lystmorder',),
'lystmordere': ('lystmorder',),
'lystmorderen': ('lystmorder',),
'lystmorderer': ('lystmorder',),
'lystmorderne': ('lystmorder',),
'lystspell': ('lystspell',),
'lystspella': ('lystspell',),
'lystspellene': ('lystspell',),
'lystspellet': ('lystspell',),
'lystspill': ('lystspill',),
'lystspilla': ('lystspill',),
'lystspillene': ('lystspill',),
'lystspillet': ('lystspill',),
'lysttur': ('lysttur',),
'lystturen': ('lysttur',),
'lystturene': ('lysttur',),
'lystturer': ('lysttur',),
'lysverk': ('lysverk',),
'lysverka': ('lysverk',),
'lysverkene': ('lysverk',),
'lysverker': ('lysverk',),
'lysverket': ('lysverk',),
'lysår': ('lysår',),
'lysåra': ('lysår',),
'lysårene': ('lysår',),
'lysåret': ('lysår',),
'lyta': ('lyte',),
'lyte': ('lyte',),
'lytene': ('lyte',),
'lyter': ('lyte',),
'lytet': ('lyte',),
'lytter': ('lytter',),
'lyttere': ('lytter',),
'lytteren': ('lytter',),
'lytterer': ('lytter',),
'lytterne': ('lytter',),
'lyttermasse': ('lyttermasse',),
'lyttermassen': ('lyttermasse',),
'lyttermassene': ('lyttermasse',),
'lyttermasser': ('lyttermasse',),
'lytterreaksjon': ('lytterreaksjon',),
'lytterreaksjonen': ('lytterreaksjon',),
'lytterreaksjonene': ('lytterreaksjon',),
'lytterreaksjoner': ('lytterreaksjon',),
'lyttertal': ('lyttertal',),
'lyttertala': ('lyttertal',),
'lyttertalene': ('lyttertal',),
'lyttertalet': ('lyttertal',),
'lyttertall': ('lyttertall',),
'lyttertalla': ('lyttertall',),
'lyttertallene': ('lyttertall',),
'lyttertallet': ('lyttertall',),
'lyttertetthet': ('lyttertetthet',),
'lyttertettheta': ('lyttertetthet',),
'lyttertettheten': ('lyttertetthet',),
'lyttertetthetene': ('lyttertetthet',),
'lyttertettheter': ('lyttertetthet',),
'lyttervane': ('lyttervane',),
'lyttervanen': ('lyttervane',),
'lyttervanene': ('lyttervane',),
'lyttervaner': ('lyttervane',),
'låg': ('låg',),
'lågen': ('låg',),
'lågene': ('låg',),
'låger': ('låg',),
'låg': ('låg',),
'låga': ('låg',),
'lågen': ('låg',),
'lægene': ('låg',),
'læger': ('låg',),
'lågadel': ('lågadel',),
'lågadelen': ('lågadel',),
'lågadlene': ('lågadel',),
'lågadler': ('lågadel',),
'lågalder': ('lågalder',),
'lågaldere': ('lågalder',),
'lågalderen': ('lågalder',),
'lågalderer': ('lågalder',),
'lågalderne': ('lågalder',),
'lågaldre': ('lågalder',),
'lågaldrene': ('lågalder',),
'lågaldrer': ('lågalder',),
'lågasild': ('lågasild',),
'lågasilda': ('lågasild',),
'lågasilden': ('lågasild',),
'lågasildene': ('lågasild',),
'lågasilder': ('lågasild',),
'lågblad': ('lågblad',),
'lågblada': ('lågblad',),
'lågbladene': ('lågblad',),
'lågblader': ('lågblad',),
'lågbladet': ('lågblad',),
'lågblokk': ('lågblokk',),
'lågblokka': ('lågblokk',),
'lågblokken': ('lågblokk',),
'lågblokkene': ('lågblokk',),
'lågblokker': ('lågblokk',),
'lågbygg': ('lågbygg',),
'lågbygga': ('lågbygg',),
'lågbyggene': ('lågbygg',),
'lågbygget': ('lågbygg',),
'lågfrekvens': ('lågfrekvens',),
'lågfrekvensen': ('lågfrekvens',),
'lågfrekvensene': ('lågfrekvens',),
'lågfrekvenser': ('lågfrekvens',),
'låggir': ('låggir',),
'låggira': ('låggir',),
'låggirene': ('låggir',),
'låggiret': ('låggir',),
'låghus': ('låghus',),
'låghusa': ('låghus',),
'låghusene': ('låghus',),
'låghuset': ('låghus',),
'låginntektsgruppa': ('låginntektsgruppe',),
'låginntektsgruppe': ('låginntektsgruppe',),
'låginntektsgruppen': ('låginntektsgruppe',),
'låginntektsgruppene': ('låginntektsgruppe',),
'låginntektsgrupper': ('låginntektsgruppe',),
'lågkomikk': ('lågkomikk',),
'lågkomikken': ('lågkomikk',),
'lågkomikkene': ('lågkomikk',),
'lågkomikker': ('lågkomikk',),
'lågkonjunktur': ('lågkonjunktur',),
'lågkonjunkturen': ('lågkonjunktur',),
'lågkonjunkturene': ('lågkonjunktur',),
'lågkonjunkturer': ('lågkonjunktur',),
'lågkostland': ('lågkostland',),
'lågkostlanda': ('lågkostland',),
'lågkostlandene': ('lågkostland',),
'lågkostlandet': ('lågkostland',),
'lågland': ('lågland',),
'låglanda': ('lågland',),
'låglandene': ('lågland',),
'låglandet': ('lågland',),
'låglandsbane': ('låglandsbane',),
'låglandsbanen': ('låglandsbane',),
'låglandsbanene': ('låglandsbane',),
'låglandsbaner': ('låglandsbane',),
'låglandsbjerk': ('låglandsbjerk',),
'låglandsbjerka': ('låglandsbjerk',),
'låglandsbjerken': ('låglandsbjerk',),
'låglandsbjerkene': ('låglandsbjerk',),
'låglandsbjerker': ('låglandsbjerk',),
'låglandsbjørk': ('låglandsbjørk',),
'låglandsbjørka': ('låglandsbjørk',),
'låglandsbjørken': ('låglandsbjørk',),
'låglandsbjørkene': ('låglandsbjørk',),
'låglandsbjørker': ('låglandsbjørk',),
'låglenda': ('låglende',),
'låglende': ('låglende',),
'låglendene': ('låglende',),
'låglendet': ('låglende',),
'låglender': ('låglender',),
'låglendere': ('låglender',),
'låglenderen': ('låglender',),
'låglenderer': ('låglender',),
'låglenderne': ('låglender',),
'låglending': ('låglending',),
'låglendingen': ('låglending',),
'låglendingene': ('låglending',),
'låglendinger': ('låglending',),
'låglønnsfond': ('låglønnsfond',),
'låglønnsfonda': ('låglønnsfond',),
'låglønnsfondene': ('låglønnsfond',),
'låglønnsfondet': ('låglønnsfond',),
'låglønnsgruppa': ('låglønnsgruppe',),
'låglønnsgruppe': ('låglønnsgruppe',),
'låglønnsgruppen': ('låglønnsgruppe',),
'låglønnsgruppene': ('låglønnsgruppe',),
'låglønnsgrupper': ('låglønnsgruppe',),
'låglønnstillegg': ('låglønnstillegg',),
'låglønnstillegga': ('låglønnstillegg',),
'låglønnstilleggene': ('låglønnstillegg',),
'låglønnstillegget': ('låglønnstillegg',),
'låglønnsyrka': ('låglønnsyrke',),
'låglønnsyrke': ('låglønnsyrke',),
'låglønnsyrkene': ('låglønnsyrke',),
'låglønnsyrker': ('låglønnsyrke',),
'låglønnsyrket': ('låglønnsyrke',),
'lågmål': ('lågmål',),
'lågmåla': ('lågmål',),
'lågmålene': ('lågmål',),
'lågmålet': ('lågmål',),
'lågnivåspråk': ('lågnivåspråk',),
'lågnivåspråka': ('lågnivåspråk',),
'lågnivåspråkene': ('lågnivåspråk',),
'lågnivåspråket': ('lågnivåspråk',),
'lågoktan': ('lågoktan',),
'lågoktanen': ('lågoktan',),
'lågoktanene': ('lågoktan',),
'lågoktaner': ('lågoktan',),
'lågoktan': ('lågoktan',),
'lågoktana': ('lågoktan',),
'lågoktanene': ('lågoktan',),
'lågoktaner': ('lågoktan',),
'lågoktanet': ('lågoktan',),
'lågoktanbensin': ('lågoktanbensin',),
'lågoktanbensinen': ('lågoktanbensin',),
'lågoktanbensinene': ('lågoktanbensin',),
'lågoktanbensiner': ('lågoktanbensin',),
'lågpris': ('lågpris',),
'lågprisen': ('lågpris',),
'lågprisene': ('lågpris',),
'lågpriser': ('lågpris',),
'lågprisbutikk': ('lågprisbutikk',),
'lågprisbutikken': ('lågprisbutikk',),
'lågprisbutikkene': ('lågprisbutikk',),
'lågprisbutikker': ('lågprisbutikk',),
'lågprosa': ('lågprosa',),
'lågprosaen': ('lågprosa',),
'lågprosaene': ('lågprosa',),
'lågprosaer': ('lågprosa',),
'lågsesong': ('lågsesong',),
'lågsesongen': ('lågsesong',),
'lågsesongene': ('lågsesong',),
'lågsesonger': ('lågsesong',),
'lågsletta': ('lågslette',),
'lågslette': ('lågslette',),
'lågsletten': ('lågslette',),
'lågslettene': ('lågslette',),
'lågsletter': ('lågslette',),
'lågspenning': ('lågspenning',),
'lågspenninga': ('lågspenning',),
'lågspenningen': ('lågspenning',),
'lågspenningene': ('lågspenning',),
'lågspenninger': ('lågspenning',),
'lågspentledning': ('lågspentledning',),
'lågspentledninga': ('lågspentledning',),
'lågspentledningen': ('lågspentledning',),
'lågspentledningene': ('lågspentledning',),
'lågspentledninger': ('lågspentledning',),
'lågspentmast': ('lågspentmast',),
'lågspentmasta': ('lågspentmast',),
'lågspentmasten': ('lågspentmast',),
'lågspentmastene': ('lågspentmast',),
'lågspentmaster': ('lågspentmast',),
'lågspentnett': ('lågspentnett',),
'lågspentnetta': ('lågspentnett',),
'lågspentnettene': ('lågspentnett',),
'lågspentnettet': ('lågspentnett',),
'lågstatusgruppa': ('lågstatusgruppe',),
'lågstatusgruppe': ('lågstatusgruppe',),
'lågstatusgruppen': ('lågstatusgruppe',),
'lågstatusgruppene': ('lågstatusgruppe',),
'lågstatusgrupper': ('lågstatusgruppe',),
'lågstatusyrka': ('lågstatusyrke',),
'lågstatusyrke': ('lågstatusyrke',),
'lågstatusyrkene': ('lågstatusyrke',),
'lågstatusyrker': ('lågstatusyrke',),
'lågstatusyrket': ('lågstatusyrke',),
'lågtone': ('lågtone',),
'lågtonen': ('lågtone',),
'lågtonene': ('lågtone',),
'lågtoner': ('lågtone',),
'lågtrykk': ('lågtrykk',),
'lågtrykka': ('lågtrykk',),
'lågtrykkene': ('lågtrykk',),
'lågtrykket': ('lågtrykk',),
'lågtrykksområda': ('lågtrykksområde',),
'lågtrykksområde': ('lågtrykksområde',),
'lågtrykksområdene': ('lågtrykksområde',),
'lågtrykksområder': ('lågtrykksområde',),
'lågtrykksområdet': ('lågtrykksområde',),
'lågtrykkssentra': ('lågtrykkssentrum',),
'lågtrykkssentraene': ('lågtrykkssentrum',),
'lågtrykkssentre': ('lågtrykkssentrum',),
'lågtrykkssentrene': ('lågtrykkssentrum',),
'lågtrykkssentret': ('lågtrykkssentrum',),
'lågtrykkssentrum': ('lågtrykkssentrum',),
'lågtrykkssentrumet': ('lågtrykkssentrum',),
'lågtysk': ('lågtysk',),
'lågtysken': ('lågtysk',),
'lågtyskene': ('lågtysk',),
'lågtysker': ('lågtysk',),
'lågvann': ('lågvann',),
'lågvanna': ('lågvann',),
'lågvannene': ('lågvann',),
'lågvannet': ('lågvann',),
'lågvatn': ('lågvatn',),
'lågvatna': ('lågvatn',),
'lågvatnene': ('lågvatn',),
'lågvatnet': ('lågvatn',),
'lågåsild': ('lågåsild',),
'lågåsilda': ('lågåsild',),
'lågåsilden': ('lågåsild',),
'lågåsildene': ('lågåsild',),
'lågåsilder': ('lågåsild',),
'låm': ('låm',),
'låma': ('låm',),
'låmen': ('låm',),
'låmene': ('låm',),
'låmer': ('låm',),
'lån': ('lån',),
'låna': ('lån',),
'lånene': ('lån',),
'lånet': ('lån',),
'lån': ('lån',),
'låna': ('lån',),
'lånen': ('lån',),
'lånene': ('lån',),
'låner': ('lån',),
'lånefinansiering': ('lånefinansiering',),
'lånefinansieringa': ('lånefinansiering',),
'lånefinansieringen': ('lånefinansiering',),
'lånefinansieringene': ('lånefinansiering',),
'lånefinansieringer': ('lånefinansiering',),
'lånefond': ('lånefond',),
'lånefonda': ('lånefond',),
'lånefondene': ('lånefond',),
'lånefondet': ('lånefond',),
'lånegjeld': ('lånegjeld',),
'lånegjelda': ('lånegjeld',),
'lånegjelden': ('lånegjeld',),
'lånegjeldene': ('lånegjeld',),
'lånegjelder': ('lånegjeld',),
'lånekassa': ('lånekasse',),
'lånekasse': ('lånekasse',),
'lånekassen': ('lånekasse',),
'lånekassene': ('lånekasse',),
'lånekasser': ('lånekasse',),
'lånekort': ('lånekort',),
'lånekorta': ('lånekort',),
'lånekortene': ('lånekort',),
'lånekortet': ('lånekort',),
'lånemarked': ('lånemarked',),
'lånemarkeda': ('lånemarked',),
'lånemarkedene': ('lånemarked',),
'lånemarkeder': ('lånemarked',),
'lånemarkedet': ('lånemarked',),
'lånemarknad': ('lånemarknad',),
'lånemarknaden': ('lånemarknad',),
'lånemarknadene': ('lånemarknad',),
'lånemarknader': ('lånemarknad',),
'låner': ('låner',),
'lånere': ('låner',),
'låneren': ('låner',),
'lånerer': ('låner',),
'lånerne': ('låner',),
'låneramma': ('låneramme',),
'låneramme': ('låneramme',),
'lånerammen': ('låneramme',),
'lånerammene': ('låneramme',),
'lånerammer': ('låneramme',),
'lånerenta': ('lånerente',),
'lånerente': ('lånerente',),
'lånerenten': ('lånerente',),
'lånerentene': ('lånerente',),
'lånerenter': ('lånerente',),
'lånesøknad': ('lånesøknad',),
'lånesøknaden': ('lånesøknad',),
'lånesøknadene': ('lånesøknad',),
'lånesøknader': ('lånesøknad',),
'lånetakst': ('lånetakst',),
'lånetaksten': ('lånetakst',),
'lånetakstene': ('lånetakst',),
'lånetakster': ('lånetakst',),
'lånetid': ('lånetid',),
'lånetida': ('lånetid',),
'lånetiden': ('lånetid',),
'lånetidene': ('lånetid',),
'lånetider': ('lånetid',),
'lånetilsagn': ('lånetilsagn',),
'lånetilsagna': ('lånetilsagn',),
'lånetilsagnene': ('lånetilsagn',),
'lånetilsagnet': ('lånetilsagn',),
'långiver': ('långiver',),
'långivere': ('långiver',),
'långiveren': ('långiver',),
'långiverer': ('långiver',),
'långiverne': ('långiver',),
'lånord': ('lånord',),
'lånorda': ('lånord',),
'lånordene': ('lånord',),
'lånordet': ('lånord',),
'lånsøker': ('lånsøker',),
'lånsøkere': ('lånsøker',),
'lånsøkeren': ('lånsøker',),
'lånsøkerer': ('lånsøker',),
'lånsøkerne': ('lånsøker',),
'låntaker': ('låntaker',),
'låntakere': ('låntaker',),
'låntakeren': ('låntaker',),
'låntakerer': ('låntaker',),
'låntakerne': ('låntaker',),
'lår': ('lår',),
'låra': ('lår',),
'lårene': ('lår',),
'låret': ('lår',),
'lårbein': ('lårbein',),
'lårbeina': ('lårbein',),
'lårbeinene': ('lårbein',),
'lårbeinet': ('lårbein',),
'lårbeinsbrudd': ('lårbeinsbrudd',),
'lårbeinsbrudda': ('lårbeinsbrudd',),
'lårbeinsbruddene': ('lårbeinsbrudd',),
'lårbeinsbruddet': ('lårbeinsbrudd',),
'lårbeinshals': ('lårbeinshals',),
'lårbeinshalsen': ('lårbeinshals',),
'lårbeinshalsene': ('lårbeinshals',),
'lårbeinshalser': ('lårbeinshals',),
'lårbeinshoda': ('lårbeinshode',),
'lårbeinshode': ('lårbeinshode',),
'lårbeinshodene': ('lårbeinshode',),
'lårbeinshoder': ('lårbeinshode',),
'lårbeinshodet': ('lårbeinshode',),
'lårben': ('lårben',),
'lårbena': ('lårben',),
'lårbenene': ('lårben',),
'lårbenet': ('lårben',),
'lårbensbrudd': ('lårbensbrudd',),
'lårbensbrudda': ('lårbensbrudd',),
'lårbensbruddene': ('lårbensbrudd',),
'lårbensbruddet': ('lårbensbrudd',),
'lårbenshals': ('lårbenshals',),
'lårbenshalsen': ('lårbenshals',),
'lårbenshalsene': ('lårbenshals',),
'lårbenshalser': ('lårbenshals',),
'lårbenshoda': ('lårbenshode',),
'lårbenshode': ('lårbenshode',),
'lårbenshodene': ('lårbenshode',),
'lårbenshoder': ('lårbenshode',),
'lårbenshodet': ('lårbenshode',),
'lårhals': ('lårhals',),
'lårhalsen': ('lårhals',),
'lårhalsene': ('lårhals',),
'lårhalser': ('lårhals',),
'lårhøna': ('lårhøne',),
'lårhøne': ('lårhøne',),
'lårhønen': ('lårhøne',),
'lårhønene': ('lårhøne',),
'lårhøner': ('lårhøne',),
'låring': ('låring',),
'låringa': ('låring',),
'låringen': ('låring',),
'låringene': ('låring',),
'låringer': ('låring',),
'lås': ('lås',),
'låsa': ('lås',),
'låsen': ('lås',),
'låsene': ('lås',),
'låser': ('lås',),
'låset': ('lås',),
'låsbeslag': ('låsbeslag',),
'låsbeslaga': ('låsbeslag',),
'låsbeslagene': ('låsbeslag',),
'låsbeslaget': ('låsbeslag',),
'låsebeslag': ('låsebeslag',),
'låsebeslaga': ('låsebeslag',),
'låsebeslagene': ('låsebeslag',),
'låsebeslaget': ('låsebeslag',),
'låsesmed': ('låsesmed',),
'låsesmeden': ('låsesmed',),
'låsesmedene': ('låsesmed',),
'låsesmeder': ('låsesmed',),
'låsmekanisme': ('låsmekanisme',),
'låsmekanismen': ('låsmekanisme',),
'låsmekanismene': ('låsmekanisme',),
'låsmekanismer': ('låsmekanisme',),
'låsplata': ('låsplate',),
'låsplate': ('låsplate',),
'låsplaten': ('låsplate',),
'låsplatene': ('låsplate',),
'låsplater': ('låsplate',),
'låt': ('låt',),
'låten': ('låt',),
'låtene': ('låt',),
'låter': ('låt',),
'lått': ('lått',),
'låtten': ('lått',),
'låttene': ('lått',),
'låtter': ('lått',),
'låve': ('låve',),
'låven': ('låve',),
'låvene': ('låve',),
'låver': ('låve',),
'låvebro': ('låvebro',),
'låvebroa': ('låvebro',),
'låvebroen': ('låvebro',),
'låvebroene': ('låvebro',),
'låvebroer': ('låvebro',),
'låvebru': ('låvebru',),
'låvebrua': ('låvebru',),
'låvebruen': ('låvebru',),
'låvebruene': ('låvebru',),
'låvebruer': ('låvebru',),
'låvedør': ('låvedør',),
'låvedøra': ('låvedør',),
'låvedøren': ('låvedør',),
'låvedørene': ('låvedør',),
'låvedører': ('låvedør',),
'låvesvala': ('låvesvale',),
'låvesvale': ('låvesvale',),
'låvesvalen': ('låvesvale',),
'låvesvalene': ('låvesvale',),
'låvesvaler': ('låvesvale',),
'læger': ('læger',),
'lægeret': ('læger',),
'lægerne': ('læger',),
'lægra': ('læger',),
'lægre': ('læger',),
'lægrene': ('læger',),
'lær': ('lær',),
'læra': ('lær',),
'lærene': ('lær',),
'læret': ('lær',),
'lærbelta': ('lærbelte',),
'lærbelte': ('lærbelte',),
'lærbeltene': ('lærbelte',),
'lærbelter': ('lærbelte',),
'lærbeltet': ('lærbelte',),
'lærbråk': ('lærbråk',),
'lærbråka': ('lærbråk',),
'lærbråken': ('lærbråk',),
'lærbrækene': ('lærbråk',),
'lærbræker': ('lærbråk',),
'lærdom': ('lærdom',),
'lærdommen': ('lærdom',),
'lærdommene': ('lærdom',),
'lærdommer': ('lærdom',),
'lærdomsseta': ('lærdomssete',),
'lærdomssete': ('lærdomssete',),
'lærdomssetene': ('lærdomssete',),
'lærdomsseter': ('lærdomssete',),
'lærdomssetet': ('lærdomssete',),
'lærebok': ('lærebok',),
'læreboka': ('lærebok',),
'læreboken': ('lærebok',),
'lærebøkene': ('lærebok',),
'lærebøker': ('lærebok',),
'lærebokforfatter': ('lærebokforfatter',),
'lærebokforfattere': ('lærebokforfatter',),
'lærebokforfatteren': ('lærebokforfatter',),
'lærebokforfatterer': ('lærebokforfatter',),
'lærebokforfatterne': ('lærebokforfatter',),
'læreboknormal': ('læreboknormal',),
'læreboknormalen': ('læreboknormal',),
'læreboknormalene': ('læreboknormal',),
'læreboknormaler': ('læreboknormal',),
'lærebygning': ('lærebygning',),
'lærebygninga': ('lærebygning',),
'lærebygningen': ('lærebygning',),
'lærebygningene': ('lærebygning',),
'lærebygninger': ('lærebygning',),
'læredikt': ('læredikt',),
'læredikta': ('læredikt',),
'lærediktene': ('læredikt',),
'lærediktet': ('læredikt',),
'læregutt': ('læregutt',),
'læregutten': ('læregutt',),
'læreguttene': ('læregutt',),
'læregutter': ('læregutt',),
'læremester': ('læremester',),
'læremestere': ('læremester',),
'læremesteren': ('læremester',),
'læremesterer': ('læremester',),
'læremesterne': ('læremester',),
'læremestre': ('læremester',),
'læremestrene': ('læremester',),
'læremestrer': ('læremester',),
'læremiddel': ('læremiddel',),
'læremiddelet': ('læremiddel',),
'læremidla': ('læremiddel',),
'læremidlene': ('læremiddel',),
'læremidler': ('læremiddel',),
'læremidlet': ('læremiddel',),
'lærepenge': ('lærepenge',),
'lærepengen': ('lærepenge',),
'lærepengene': ('lærepenge',),
'lærepenger': ('lærepenge',),
'læreplan': ('læreplan',),
'læreplanen': ('læreplan',),
'læreplanene': ('læreplan',),
'læreplaner': ('læreplan',),
'lærer': ('lærer',),
'lærere': ('lærer',),
'læreren': ('lærer',),
'lærerer': ('lærer',),
'lærerne': ('lærer',),
'lærereksamen': ('lærereksamen',),
'lærereksamenen': ('lærereksamen',),
'lærereksamenene': ('lærereksamen',),
'lærereksamener': ('lærereksamen',),
'lærerhøgskole': ('lærerhøgskole',),
'lærerhøgskolen': ('lærerhøgskole',),
'lærerhøgskolene': ('lærerhøgskole',),
'lærerhøgskoler': ('lærerhøgskole',),
'lærerhøyskole': ('lærerhøyskole',),
'lærerhøyskolen': ('lærerhøyskole',),
'lærerhøyskolene': ('lærerhøyskole',),
'lærerhøyskoler': ('lærerhøyskole',),
'lærerprøva': ('lærerprøve',),
'lærerprøve': ('lærerprøve',),
'lærerprøven': ('lærerprøve',),
'lærerprøvene': ('lærerprøve',),
'lærerprøver': ('lærerprøve',),
'lærerrom': ('lærerrom',),
'lærerromma': ('lærerrom',),
'lærerrommene': ('lærerrom',),
'lærerrommet': ('lærerrom',),
'lærerråd': ('lærerråd',),
'lærerråda': ('lærerråd',),
'lærerrådene': ('lærerråd',),
'lærerrådet': ('lærerråd',),
'lærerskole': ('lærerskole',),
'lærerskolen': ('lærerskole',),
'lærerskolene': ('lærerskole',),
'lærerskoler': ('lærerskole',),
'lærerutdannelse': ('lærerutdannelse',),
'lærerutdannelsen': ('lærerutdannelse',),
'lærerutdannelsene': ('lærerutdannelse',),
'lærerutdannelser': ('lærerutdannelse',),
'lærerutdanning': ('lærerutdanning',),
'lærerutdanninga': ('lærerutdanning',),
'lærerutdanningen': ('lærerutdanning',),
'lærerutdanningene': ('lærerutdanning',),
'lærerutdanninger': ('lærerutdanning',),
'læreryrka': ('læreryrke',),
'læreryrke': ('læreryrke',),
'læreryrkene': ('læreryrke',),
'læreryrker': ('læreryrke',),
'læreryrket': ('læreryrke',),
'læresetning': ('læresetning',),
'læresetninga': ('læresetning',),
'læresetningen': ('læresetning',),
'læresetningene': ('læresetning',),
'læresetninger': ('læresetning',),
'lærestol': ('lærestol',),
'lærestolen': ('lærestol',),
'lærestolene': ('lærestol',),
'lærestoler': ('lærestol',),
'læretid': ('læretid',),
'læretida': ('læretid',),
'læretiden': ('læretid',),
'læretidene': ('læretid',),
'læretider': ('læretid',),
'lærevanske': ('lærevanske',),
'lærevansken': ('lærevanske',),
'lærevanskene': ('lærevanske',),
'lærevansker': ('lærevanske',),
'lærhud': ('lærhud',),
'lærhuda': ('lærhud',),
'lærhuden': ('lærhud',),
'lærhudene': ('lærhud',),
'lærhuder': ('lærhud',),
'læring': ('læring',),
'læringa': ('læring',),
'læringen': ('læring',),
'læringene': ('læring',),
'læringer': ('læring',),
'læringspsykologi': ('læringspsykologi',),
'læringspsykologien': ('læringspsykologi',),
'læringspsykologiene': ('læringspsykologi',),
'læringspsykologier': ('læringspsykologi',),
'læringsteori': ('læringsteori',),
'læringsteorien': ('læringsteori',),
'læringsteoriene': ('læringsteori',),
'læringsteorier': ('læringsteori',),
'lærjakka': ('lærjakke',),
'lærjakke': ('lærjakke',),
'lærjakken': ('lærjakke',),
'lærjakkene': ('lærjakke',),
'lærjakker': ('lærjakke',),
'lærkula': ('lærkule',),
'lærkule': ('lærkule',),
'lærkulen': ('lærkule',),
'lærkulene': ('lærkule',),
'lærkuler': ('lærkule',),
'lærling': ('lærling',),
'lærlingen': ('lærling',),
'lærlingene': ('lærling',),
'lærlinger': ('lærling',),
'lærlingskole': ('lærlingskole',),
'lærlingskolen': ('lærlingskole',),
'lærlingskolene': ('lærlingskole',),
'lærlingskoler': ('lærlingskole',),
'lærreim': ('lærreim',),
'lærreima': ('lærreim',),
'lærreimen': ('lærreim',),
'lærreimene': ('lærreim',),
'lærreimer': ('lærreim',),
'lærrem': ('lærrem',),
'lærremma': ('lærrem',),
'lærremmen': ('lærrem',),
'lærremmene': ('lærrem',),
'lærremmer': ('lærrem',),
'lærskilpadda': ('lærskilpadde',),
'lærskilpadde': ('lærskilpadde',),
'lærskilpadden': ('lærskilpadde',),
'lærskilpaddene': ('lærskilpadde',),
'lærskilpadder': ('lærskilpadde',),
'læstadianer': ('læstadianer',),
'læstadianere': ('læstadianer',),
'læstadianeren': ('læstadianer',),
'læstadianerer': ('læstadianer',),
'læstadianerne': ('læstadianer',),
'læstadianisme': ('læstadianisme',),
'læstadianismen': ('læstadianisme',),
'læstadianismene': ('læstadianisme',),
'læstadianismer': ('læstadianisme',),
'læta': ('læte',),
'læte': ('læte',),
'lætene': ('læte',),
'læter': ('læte',),
'lætet': ('læte',),
'lød': ('lød',),
'løden': ('lød',),
'lødene': ('lød',),
'løder': ('lød',),
'løa': ('løe',),
'løe': ('løe',),
'løen': ('løe',),
'løene': ('løe',),
'løer': ('løe',),
'løft': ('løft',),
'løfta': ('løft',),
'løftene': ('løft',),
'løftet': ('løft',),
'løfta': ('løfte',),
'løfte': ('løfte',),
'løftene': ('løfte',),
'løfter': ('løfte',),
'løftet': ('løfte',),
'løftebrott': ('løftebrott',),
'løftebrotta': ('løftebrott',),
'løftebrottene': ('løftebrott',),
'løftebrottet': ('løftebrott',),
'løftebrudd': ('løftebrudd',),
'løftebrudda': ('løftebrudd',),
'løftebruddene': ('løftebrudd',),
'løftebruddet': ('løftebrudd',),
'løfteevna': ('løfteevne',),
'løfteevne': ('løfteevne',),
'løfteevnen': ('løfteevne',),
'løfteevnene': ('løfteevne',),
'løfteevner': ('løfteevne',),
'løfter': ('løfter',),
'løftere': ('løfter',),
'løfteren': ('løfter',),
'løfterer': ('løfter',),
'løfterne': ('løfter',),
'løftestang': ('løftestang',),
'løftestanga': ('løftestang',),
'løftestangen': ('løftestang',),
'løftestengene': ('løftestang',),
'løftestenger': ('løftestang',),
'løftestein': ('løftestein',),
'løftesteinen': ('løftestein',),
'løftesteinene': ('løftestein',),
'løftesteiner': ('løftestein',),
'løfting': ('løfting',),
'løftingen': ('løfting',),
'løftingene': ('løfting',),
'løftinger': ('løfting',),
'løfting': ('løfting',),
'løftinga': ('løfting',),
'løftingen': ('løfting',),
'løftingene': ('løfting',),
'løftinger': ('løfting',),
'løgn': ('løgn',),
'løgna': ('løgn',),
'løgnen': ('løgn',),
'løgnene': ('løgn',),
'løgner': ('løgn',),
'løgnagitasjon': ('løgnagitasjon',),
'løgnagitasjonen': ('løgnagitasjon',),
'løgnagitasjonene': ('løgnagitasjon',),
'løgnagitasjoner': ('løgnagitasjon',),
'løgndetektor': ('løgndetektor',),
'løgndetektoren': ('løgndetektor',),
'løgndetektorene': ('løgndetektor',),
'løgndetektorer': ('løgndetektor',),
'løgner': ('løgner',),
'løgnere': ('løgner',),
'løgneren': ('løgner',),
'løgnerer': ('løgner',),
'løgnerne': ('løgner',),
'løgnhals': ('løgnhals',),
'løgnhalsen': ('løgnhals',),
'løgnhalsene': ('løgnhals',),
'løgnhalser': ('løgnhals',),
'løgnpropaganda': ('løgnpropaganda',),
'løgnpropagandaen': ('løgnpropaganda',),
'løgnpropagandaene': ('løgnpropaganda',),
'løgnpropagandaer': ('løgnpropaganda',),
'løk': ('løk',),
'løken': ('løk',),
'løkene': ('løk',),
'løker': ('løk',),
'løk': ('løk',),
'løken': ('løk',),
'løkene': ('løk',),
'løker': ('løk',),
'løkkefotball': ('løkkefotball',),
'løkkefotballen': ('løkkefotball',),
'løkkefotballene': ('løkkefotball',),
'løkkefotballer': ('løkkefotball',),
'løkkuplene': ('løkkuppel',),
'løkkupler': ('løkkuppel',),
'løkkuppel': ('løkkuppel',),
'løkkuppelen': ('løkkuppel',),
'løkplanta': ('løkplante',),
'løkplante': ('løkplante',),
'løkplanten': ('løkplante',),
'løkplantene': ('løkplante',),
'løkplanter': ('løkplante',),
'løksaus': ('løksaus',),
'løksausen': ('løksaus',),
'løksausene': ('løksaus',),
'løksauser': ('løksaus',),
'løksuppa': ('løksuppe',),
'løksuppe': ('løksuppe',),
'løksuppen': ('løksuppe',),
'løksuppene': ('løksuppe',),
'løksupper': ('løksuppe',),
'løkurt': ('løkurt',),
'løkurta': ('løkurt',),
'løkurten': ('løkurt',),
'løkurtene': ('løkurt',),
'løkurter': ('løkurt',),
'lømlene': ('lømmel',),
'lømler': ('lømmel',),
'lømmel': ('lømmel',),
'lømmelen': ('lømmel',),
'lønn': ('lønn',),
'lønna': ('lønn',),
'lønnen': ('lønn',),
'lønnene': ('lønn',),
'lønner': ('lønn',),
'lønn': ('lønn',),
'lønna': ('lønn',),
'lønnen': ('lønn',),
'lønnene': ('lønn',),
'lønner': ('lønn',),
'lønn': ('lønn',),
'lønndom': ('lønndom',),
'lønndommen': ('lønndom',),
'lønndommene': ('lønndom',),
'lønndommer': ('lønndom',),
'lønndør': ('lønndør',),
'lønndøra': ('lønndør',),
'lønndøren': ('lønndør',),
'lønndørene': ('lønndør',),
'lønndører': ('lønndør',),
'lønneblad': ('lønneblad',),
'lønneblada': ('lønneblad',),
'lønnebladene': ('lønneblad',),
'lønneblader': ('lønneblad',),
'lønnebladet': ('lønneblad',),
'lønnetre': ('lønnetre',),
'lønnetrea': ('lønnetre',),
'lønnetreet': ('lønnetre',),
'lønnetrær': ('lønnetre',),
'lønnetrærne': ('lønnetre',),
'lønngang': ('lønngang',),
'lønngangen': ('lønngang',),
'lønngangene': ('lønngang',),
'lønnganger': ('lønngang',),
'lønning': ('lønning',),
'lønninga': ('lønning',),
'lønningen': ('lønning',),
'lønningene': ('lønning',),
'lønninger': ('lønning',),
'lønning': ('lønning',),
'lønninga': ('lønning',),
'lønningen': ('lønning',),
'lønningene': ('lønning',),
'lønninger': ('lønning',),
'lønningsdag': ('lønningsdag',),
'lønningsdagen': ('lønningsdag',),
'lønningsdagene': ('lønningsdag',),
'lønningsdager': ('lønningsdag',),
'lønningskontor': ('lønningskontor',),
'lønningskontora': ('lønningskontor',),
'lønningskontorene': ('lønningskontor',),
'lønningskontorer': ('lønningskontor',),
'lønningskontoret': ('lønningskontor',),
'lønningslista': ('lønningsliste',),
'lønningsliste': ('lønningsliste',),
'lønningslisten': ('lønningsliste',),
'lønningslistene': ('lønningsliste',),
'lønningslister': ('lønningsliste',),
'lønningspose': ('lønningspose',),
'lønningsposen': ('lønningspose',),
'lønningsposene': ('lønningspose',),
'lønningsposer': ('lønningspose',),
'lønnkammer': ('lønnkammer',),
'lønnkammeret': ('lønnkammer',),
'lønnkamra': ('lønnkammer',),
'lønnkamre': ('lønnkammer',),
'lønnkamrene': ('lønnkammer',),
'lønnsansiennitet': ('lønnsansiennitet',),
'lønnsansienniteten': ('lønnsansiennitet',),
'lønnsansiennitetene': ('lønnsansiennitet',),
'lønnsansienniteter': ('lønnsansiennitet',),
'lønnsarbeider': ('lønnsarbeider',),
'lønnsarbeidere': ('lønnsarbeider',),
'lønnsarbeideren': ('lønnsarbeider',),
'lønnsarbeiderer': ('lønnsarbeider',),
'lønnsarbeiderne': ('lønnsarbeider',),
'lønnsavtale': ('lønnsavtale',),
'lønnsavtalen': ('lønnsavtale',),
'lønnsavtalene': ('lønnsavtale',),
'lønnsavtaler': ('lønnsavtale',),
'lønnsevna': ('lønnsevne',),
'lønnsevne': ('lønnsevne',),
'lønnsevnen': ('lønnsevne',),
'lønnsevnene': ('lønnsevne',),
'lønnsevner': ('lønnsevne',),
'lønnsglidning': ('lønnsglidning',),
'lønnsglidninga': ('lønnsglidning',),
'lønnsglidningen': ('lønnsglidning',),
'lønnsglidningene': ('lønnsglidning',),
'lønnsglidninger': ('lønnsglidning',),
'lønnsinntekt': ('lønnsinntekt',),
'lønnsinntekta': ('lønnsinntekt',),
'lønnsinntekten': ('lønnsinntekt',),
'lønnsinntektene': ('lønnsinntekt',),
'lønnsinntekter': ('lønnsinntekt',),
'lønnsklassa': ('lønnsklasse',),
'lønnsklasse': ('lønnsklasse',),
'lønnsklassen': ('lønnsklasse',),
'lønnsklassene': ('lønnsklasse',),
'lønnsklasser': ('lønnsklasse',),
'lønnskonti': ('lønnskonto',),
'lønnskontiene': ('lønnskonto',),
'lønnskonto': ('lønnskonto',),
'lønnskontoen': ('lønnskonto',),
'lønnskontoene': ('lønnskonto',),
'lønnskontoer': ('lønnskonto',),
'lønnsnemnd': ('lønnsnemnd',),
'lønnsnemnda': ('lønnsnemnd',),
'lønnsnemnden': ('lønnsnemnd',),
'lønnsnemndene': ('lønnsnemnd',),
'lønnsnemnder': ('lønnsnemnd',),
'lønnsnivå': ('lønnsnivå',),
'lønnsnivåa': ('lønnsnivå',),
'lønnsnivåene': ('lønnsnivå',),
'lønnsnivåer': ('lønnsnivå',),
'lønnsnivået': ('lønnsnivå',),
'lønnsoppgava': ('lønnsoppgave',),
'lønnsoppgave': ('lønnsoppgave',),
'lønnsoppgaven': ('lønnsoppgave',),
'lønnsoppgavene': ('lønnsoppgave',),
'lønnsoppgaver': ('lønnsoppgave',),
'lønnsoppgjør': ('lønnsoppgjør',),
'lønnsoppgjøra': ('lønnsoppgjør',),
'lønnsoppgjørene': ('lønnsoppgjør',),
'lønnsoppgjøret': ('lønnsoppgjør',),
'lønnsopprykk': ('lønnsopprykk',),
'lønnsopprykka': ('lønnsopprykk',),
'lønnsopprykkene': ('lønnsopprykk',),
'lønnsopprykket': ('lønnsopprykk',),
'lønnsplan': ('lønnsplan',),
'lønnsplanen': ('lønnsplan',),
'lønnsplanene': ('lønnsplan',),
'lønnsplaner': ('lønnsplan',),
'lønnsregulativ': ('lønnsregulativ',),
'lønnsregulativa': ('lønnsregulativ',),
'lønnsregulativene': ('lønnsregulativ',),
'lønnsregulativer': ('lønnsregulativ',),
'lønnsregulativet': ('lønnsregulativ',),
'lønnsslave': ('lønnsslave',),
'lønnsslaven': ('lønnsslave',),
'lønnsslavene': ('lønnsslave',),
'lønnsslaver': ('lønnsslave',),
'lønnsspiral': ('lønnsspiral',),
'lønnsspiralen': ('lønnsspiral',),
'lønnsspiralene': ('lønnsspiral',),
'lønnsspiraler': ('lønnsspiral',),
'lønnsstopp': ('lønnsstopp',),
'lønnsstoppa': ('lønnsstopp',),
'lønnsstoppen': ('lønnsstopp',),
'lønnsstoppene': ('lønnsstopp',),
'lønnsstoppet': ('lønnsstopp',),
'lønnstaker': ('lønnstaker',),
'lønnstakere': ('lønnstaker',),
'lønnstakeren': ('lønnstaker',),
'lønnstakerer': ('lønnstaker',),
'lønnstakerne': ('lønnstaker',),
'lønnstariff': ('lønnstariff',),
'lønnstariffen': ('lønnstariff',),
'lønnstariffene': ('lønnstariff',),
'lønnstariffer': ('lønnstariff',),
'lønnstrekk': ('lønnstrekk',),
'lønnstrekka': ('lønnstrekk',),
'lønnstrekkene': ('lønnstrekk',),
'lønnstrekket': ('lønnstrekk',),
'lønnstrinn': ('lønnstrinn',),
'lønnstrinna': ('lønnstrinn',),
'lønnstrinnene': ('lønnstrinn',),
'lønnstrinnet': ('lønnstrinn',),
'lønnsutjamning': ('lønnsutjamning',),
'lønnsutjamninga': ('lønnsutjamning',),
'lønnsutjamningen': ('lønnsutjamning',),
'lønnsutjamningene': ('lønnsutjamning',),
'lønnsutjamninger': ('lønnsutjamning',),
'lønnsutjevning': ('lønnsutjevning',),
'lønnsutjevninga': ('lønnsutjevning',),
'lønnsutjevningen': ('lønnsutjevning',),
'lønnsutjevningene': ('lønnsutjevning',),
'lønnsutjevninger': ('lønnsutjevning',),
'løp': ('løp',),
'løpa': ('løp',),
'løpene': ('løp',),
'løpet': ('løp',),
'løpebane': ('løpebane',),
'løpebanen': ('løpebane',),
'løpebanene': ('løpebane',),
'løpebaner': ('løpebane',),
'løpebille': ('løpebille',),
'løpebillen': ('løpebille',),
'løpebillene': ('løpebille',),
'løpebiller': ('løpebille',),
'løpeeld': ('løpeeld',),
'løpeelden': ('løpeeld',),
'løpeeldene': ('løpeeld',),
'løpeelder': ('løpeeld',),
'løpeeld': ('løpeeld',),
'løpeelden': ('løpeeld',),
'løpeeldene': ('løpeeld',),
'løpeelder': ('løpeeld',),
'løpefot': ('løpefot',),
'løpefoten': ('løpefot',),
'løpeføttene': ('løpefot',),
'løpeføtter': ('løpefot',),
'løpegang': ('løpegang',),
'løpegangen': ('løpegang',),
'løpegangene': ('løpegang',),
'løpeganger': ('løpegang',),
'løpegrav': ('løpegrav',),
'løpegrava': ('løpegrav',),
'løpegraven': ('løpegrav',),
'løpegravene': ('løpegrav',),
'løpegraver': ('løpegrav',),
'løpegutt': ('løpegutt',),
'løpegutten': ('løpegutt',),
'løpeguttene': ('løpegutt',),
'løpegutter': ('løpegutt',),
'løpeild': ('løpeild',),
'løpeilden': ('løpeild',),
'løpeildene': ('løpeild',),
'løpeilder': ('løpeild',),
'løpeild': ('løpeild',),
'løpeilden': ('løpeild',),
'løpeildene': ('løpeild',),
'løpeilder': ('løpeild',),
'løpekatt': ('løpekatt',),
'løpekatten': ('løpekatt',),
'løpekattene': ('løpekatt',),
'løpekatter': ('løpekatt',),
'løpemeter': ('løpemeter',),
'løpemetere': ('løpemeter',),
'løpemeteren': ('løpemeter',),
'løpemeterer': ('løpemeter',),
'løpemeterne': ('løpemeter',),
'løpemåned': ('løpemåned',),
'løpemåneden': ('løpemåned',),
'løpemånedene': ('løpemåned',),
'løpemåneder': ('løpemåned',),
'løpenummer': ('løpenummer',),
'løpenummeret': ('løpenummer',),
'løpenumra': ('løpenummer',),
'løpenumre': ('løpenummer',),
'løpenumrene': ('løpenummer',),
'løpepass': ('løpepass',),
'løpepassa': ('løpepass',),
'løpepassene': ('løpepass',),
'løpepasset': ('løpepass',),
'løper': ('løper',),
'løpere': ('løper',),
'løperen': ('løper',),
'løperer': ('løper',),
'løperne': ('løper',),
'løpergutt': ('løpergutt',),
'løpergutten': ('løpergutt',),
'løperguttene': ('løpergutt',),
'løpergutter': ('løpergutt',),
'løperrekka': ('løperrekke',),
'løperrekke': ('løperrekke',),
'løperrekken': ('løperrekke',),
'løperrekkene': ('løperrekke',),
'løperrekker': ('løperrekke',),
'løpeseddel': ('løpeseddel',),
'løpeseddelen': ('løpeseddel',),
'løpesedlene': ('løpeseddel',),
'løpesedler': ('løpeseddel',),
'løpetid': ('løpetid',),
'løpetida': ('løpetid',),
'løpetiden': ('løpetid',),
'løpetidene': ('løpetid',),
'løpetider': ('løpetid',),
'løpstikka': ('løpstikke',),
'løpstikke': ('løpstikke',),
'løpstikken': ('løpstikke',),
'løpstikkene': ('løpstikke',),
'løpstikker': ('løpstikke',),
'løpstrening': ('løpstrening',),
'løpstreninga': ('løpstrening',),
'løpstreningen': ('løpstrening',),
'løpstreningene': ('løpstrening',),
'løpstreninger': ('løpstrening',),
'løpsøvelse': ('løpsøvelse',),
'løpsøvelsen': ('løpsøvelse',),
'løpsøvelsene': ('løpsøvelse',),
'løpsøvelser': ('løpsøvelse',),
'løpsøving': ('løpsøving',),
'løpsøvinga': ('løpsøving',),
'løpsøvingen': ('løpsøving',),
'løpsøvingene': ('løpsøving',),
'løpsøvinger': ('løpsøving',),
'lørdag': ('lørdag',),
'lørdagen': ('lørdag',),
'lørdagene': ('lørdag',),
'lørdager': ('lørdag',),
'lørdagsfrier': ('lørdagsfrier',),
'lørdagsfriere': ('lørdagsfrier',),
'lørdagsfrieren': ('lørdagsfrier',),
'lørdagsfrierer': ('lørdagsfrier',),
'lørdagsfrierne': ('lørdagsfrier',),
'lørdagsfrieri': ('lørdagsfrieri',),
'lørdagsfrieria': ('lørdagsfrieri',),
'lørdagsfrieriene': ('lørdagsfrieri',),
'lørdagsfrierier': ('lørdagsfrieri',),
'lørdagsfrieriet': ('lørdagsfrieri',),
'lørdagskveld': ('lørdagskveld',),
'lørdagskvelden': ('lørdagskveld',),
'lørdagskveldene': ('lørdagskveld',),
'lørdagskvelder': ('lørdagskveld',),
'lørdagslukning': ('lørdagslukning',),
'lørdagslukninga': ('lørdagslukning',),
'lørdagslukningen': ('lørdagslukning',),
'lørdagslukningene': ('lørdagslukning',),
'lørdagslukninger': ('lørdagslukning',),
'lørdagsnatt': ('lørdagsnatt',),
'lørdagsnatta': ('lørdagsnatt',),
'lørdagsnatten': ('lørdagsnatt',),
'lørdagsnettene': ('lørdagsnatt',),
'lørdagsnetter': ('lørdagsnatt',),
'løsarbeid': ('løsarbeid',),
'løsarbeida': ('løsarbeid',),
'løsarbeidene': ('løsarbeid',),
'løsarbeider': ('løsarbeid',),
'løsarbeidet': ('løsarbeid',),
'løsarbeider': ('løsarbeider',),
'løsarbeidere': ('løsarbeider',),
'løsarbeideren': ('løsarbeider',),
'løsarbeiderer': ('løsarbeider',),
'løsarbeiderne': ('løsarbeider',),
'løsbikkja': ('løsbikkje',),
'løsbikkje': ('løsbikkje',),
'løsbikkjen': ('løsbikkje',),
'løsbikkjene': ('løsbikkje',),
'løsbikkjer': ('løsbikkje',),
'løsblad': ('løsblad',),
'løsblada': ('løsblad',),
'løsbladene': ('løsblad',),
'løsblader': ('løsblad',),
'løsbladet': ('løsblad',),
'løsbladsystem': ('løsbladsystem',),
'løsbladsystema': ('løsbladsystem',),
'løsbladsystemene': ('løsbladsystem',),
'løsbladsystemer': ('løsbladsystem',),
'løsbladsystemet': ('løsbladsystem',),
'løsemiddel': ('løsemiddel',),
'løsemiddelet': ('løsemiddel',),
'løsemidla': ('løsemiddel',),
'løsemidlene': ('løsemiddel',),
'løsemidler': ('løsemiddel',),
'løsemidlet': ('løsemiddel',),
'løsen': ('løsen',),
'løsena': ('løsen',),
'løsenene': ('løsen',),
'løsener': ('løsen',),
'løsenet': ('løsen',),
'løsenord': ('løsenord',),
'løsenorda': ('løsenord',),
'løsenordene': ('løsenord',),
'løsenordet': ('løsenord',),
'løsensord': ('løsensord',),
'løsensorda': ('løsensord',),
'løsensordene': ('løsensord',),
'løsensordet': ('løsensord',),
'løsesum': ('løsesum',),
'løsesummen': ('løsesum',),
'løsesummene': ('løsesum',),
'løsesummer': ('løsesum',),
'løsfart': ('løsfart',),
'løsfarten': ('løsfart',),
'løsfartene': ('løsfart',),
'løsfarter': ('løsfart',),
'løsgiing': ('løsgiing',),
'løsgiinga': ('løsgiing',),
'løsgiingen': ('løsgiing',),
'løsgiingene': ('løsgiing',),
'løsgiinger': ('løsgiing',),
'løsgivelse': ('løsgivelse',),
'løsgivelsen': ('løsgivelse',),
'løsgivelsene': ('løsgivelse',),
'løsgivelser': ('løsgivelse',),
'løsgiving': ('løsgiving',),
'løsgivinga': ('løsgiving',),
'løsgivingen': ('løsgiving',),
'løsgivingene': ('løsgiving',),
'løsgivinger': ('løsgiving',),
'løsgjenger': ('løsgjenger',),
'løsgjengere': ('løsgjenger',),
'løsgjengeren': ('løsgjenger',),
'løsgjengerer': ('løsgjenger',),
'løsgjengerne': ('løsgjenger',),
'løshest': ('løshest',),
'løshesten': ('løshest',),
'løshestene': ('løshest',),
'løshester': ('løshest',),
'løshår': ('løshår',),
'løshåra': ('løshår',),
'løshårene': ('løshår',),
'løshåret': ('løshår',),
'løskrutt': ('løskrutt',),
'løskrutta': ('løskrutt',),
'løskruttene': ('løskrutt',),
'løskruttet': ('løskrutt',),
'løslatelse': ('løslatelse',),
'løslatelsen': ('løslatelse',),
'løslatelsene': ('løslatelse',),
'løslatelser': ('løslatelse',),
'løslating': ('løslating',),
'løslatinga': ('løslating',),
'løslatingen': ('løslating',),
'løslatingene': ('løslating',),
'løslatinger': ('løslating',),
'løslevnet': ('løslevnet',),
'løslevneta': ('løslevnet',),
'løslevnetene': ('løslevnet',),
'løslevnetet': ('løslevnet',),
'løsmedarbeider': ('løsmedarbeider',),
'løsmedarbeidere': ('løsmedarbeider',),
'løsmedarbeideren': ('løsmedarbeider',),
'løsmedarbeiderer': ('løsmedarbeider',),
'løsmedarbeiderne': ('løsmedarbeider',),
'løsning': ('løsning',),
'løsninga': ('løsning',),
'løsningen': ('løsning',),
'løsningene': ('løsning',),
'løsninger': ('løsning',),
'løsning': ('løsning',),
'løsninga': ('løsning',),
'løsningen': ('løsning',),
'løsningene': ('løsning',),
'løsninger': ('løsning',),
'løsningsmiddel': ('løsningsmiddel',),
'løsningsmiddelet': ('løsningsmiddel',),
'løsningsmidla': ('løsningsmiddel',),
'løsningsmidlene': ('løsningsmiddel',),
'løsningsmidler': ('løsningsmiddel',),
'løsningsmidlet': ('løsningsmiddel',),
'løsningsrett': ('løsningsrett',),
'løsningsretten': ('løsningsrett',),
'løsningsrettene': ('løsningsrett',),
'løsningsretter': ('løsningsrett',),
'løss': ('løss',),
'løssen': ('løss',),
'løssene': ('løss',),
'løsser': ('løss',),
'løssalg': ('løssalg',),
'løssalga': ('løssalg',),
'løssalgene': ('løssalg',),
'løssalget': ('løssalg',),
'løstann': ('løstann',),
'løstanna': ('løstann',),
'løstannen': ('løstann',),
'løstennene': ('løstann',),
'løstenner': ('løstann',),
'løsunge': ('løsunge',),
'løsungen': ('løsunge',),
'løsungene': ('løsunge',),
'løsunger': ('løsunge',),
'løsøra': ('løsøre',),
'løsøre': ('løsøre',),
'løsørene': ('løsøre',),
'løsører': ('løsøre',),
'løsøret': ('løsøre',),
'løv': ('løv',),
'løva': ('løv',),
'løvene': ('løv',),
'løvet': ('løv',),
'løvblad': ('løvblad',),
'løvblada': ('løvblad',),
'løvbladene': ('løvblad',),
'løvblader': ('løvblad',),
'løvbladet': ('løvblad',),
'løva': ('løve',),
'løve': ('løve',),
'løven': ('løve',),
'løvene': ('løve',),
'løver': ('løve',),
'løvehale': ('løvehale',),
'løvehalen': ('løvehale',),
'løvehalene': ('løvehale',),
'løvehaler': ('løvehale',),
'løvemanke': ('løvemanke',),
'løvemanken': ('løvemanke',),
'løvemankene': ('løvemanke',),
'løvemanker': ('løvemanke',),
'løvemunn': ('løvemunn',),
'løvemunnen': ('løvemunn',),
'løvemunnene': ('løvemunn',),
'løvemunner': ('løvemunn',),
'løvetann': ('løvetann',),
'løvetanna': ('løvetann',),
'løvetannen': ('løvetann',),
'løvetannene': ('løvetann',),
'løvetanner': ('løvetann',),
'løvetannsvin': ('løvetannsvin',),
'løvetannsvinen': ('løvetannsvin',),
'løvetannsvinene': ('løvetannsvin',),
'løvetannsviner': ('løvetannsvin',),
'løvetannvin': ('løvetannvin',),
'løvetannvinen': ('løvetannvin',),
'løvetannvinene': ('løvetannvin',),
'løvetannviner': ('løvetannvin',),
'løvetemmer': ('løvetemmer',),
'løvetemmere': ('løvetemmer',),
'løvetemmeren': ('løvetemmer',),
'løvetemmerer': ('løvetemmer',),
'løvetemmerne': ('løvetemmer',),
'løveunge': ('løveunge',),
'løveungen': ('løveunge',),
'løveungene': ('løveunge',),
'løveunger': ('løveunge',),
'løvfall': ('løvfall',),
'løvfalla': ('løvfall',),
'løvfallene': ('løvfall',),
'løvfallet': ('løvfall',),
'løvhyttefest': ('løvhyttefest',),
'løvhyttefesten': ('løvhyttefest',),
'løvhyttefestene': ('løvhyttefest',),
'løvhyttefester': ('løvhyttefest',),
'løvinna': ('løvinne',),
'løvinne': ('løvinne',),
'løvinnen': ('løvinne',),
'løvinnene': ('løvinne',),
'løvinner': ('løvinne',),
'løvmeis': ('løvmeis',),
'løvmeisa': ('løvmeis',),
'løvmeisen': ('løvmeis',),
'løvmeisene': ('løvmeis',),
'løvmeiser': ('løvmeis',),
'løvsag': ('løvsag',),
'løvsaga': ('løvsag',),
'løvsagen': ('løvsag',),
'løvsagene': ('løvsag',),
'løvsager': ('løvsag',),
'løvsanger': ('løvsanger',),
'løvsangere': ('løvsanger',),
'løvsangeren': ('løvsanger',),
'løvsangerer': ('løvsanger',),
'løvsangerne': ('løvsanger',),
'løvskog': ('løvskog',),
'løvskogen': ('løvskog',),
'løvskogene': ('løvskog',),
'løvskoger': ('løvskog',),
'løvskogbelta': ('løvskogbelte',),
'løvskogbelte': ('løvskogbelte',),
'løvskogbeltene': ('løvskogbelte',),
'løvskogbelter': ('løvskogbelte',),
'løvskogbeltet': ('løvskogbelte',),
'løvsprett': ('løvsprett',),
'løvspretta': ('løvsprett',),
'løvspretten': ('løvsprett',),
'løvsprettene': ('løvsprett',),
'løvspretter': ('løvsprett',),
'løvsprettet': ('løvsprett',),
'løvverk': ('løvverk',),
'løvverka': ('løvverk',),
'løvverkene': ('løvverk',),
'løvverket': ('løvverk',),
'løvvfall': ('løvvfall',),
'løvvfalla': ('løvvfall',),
'løvvfallene': ('løvvfall',),
'løvvfallet': ('løvvfall',),
'løybenk': ('løybenk',),
'løybenken': ('løybenk',),
'løybenkene': ('løybenk',),
'løybenker': ('løybenk',),
'løya': ('løye',),
'løye': ('løye',),
'løyene': ('løye',),
'løyer': ('løye',),
'løyet': ('løye',),
'løya': ('løye',),
'løye': ('løye',),
'løyen': ('løye',),
'løyene': ('løye',),
'løyer': ('løye',),
'løyene': ('løyer',),
'løyer': ('løyer',),
'løyert': ('løyert',),
'løyerten': ('løyert',),
'løyertene': ('løyert',),
'løyerter': ('løyert',),
'løynd': ('løynd',),
'løynda': ('løynd',),
'løynden': ('løynd',),
'løyndene': ('løynd',),
'løynder': ('løynd',),
'løyndom': ('løyndom',),
'løyndommen': ('løyndom',),
'løyndommene': ('løyndom',),
'løyndommer': ('løyndom',),
'løype': ('løype',),
'løypen': ('løype',),
'løypene': ('løype',),
'løyper': ('løype',),
'løype': ('løype',),
'løypen': ('løype',),
'løypene': ('løype',),
'løyper': ('løype',),
'løypa': ('løype',),
'løype': ('løype',),
'løypen': ('løype',),
'løypene': ('løype',),
'løyper': ('løype',),
'løypemage': ('løypemage',),
'løypemagen': ('løypemage',),
'løypemagene': ('løypemage',),
'løypemager': ('løypemage',),
'løypeski': ('løypeski',),
'løypeskia': ('løypeski',),
'løypeskien': ('løypeski',),
'løypeskiene': ('løypeski',),
'løypeskier': ('løypeski',),
'løypestreng': ('løypestreng',),
'løypestrengen': ('løypestreng',),
'løypestrengene': ('løypestreng',),
'løypestrenger': ('løypestreng',),
'løysemiddel': ('løysemiddel',),
'løysemiddelet': ('løysemiddel',),
'løysemidla': ('løysemiddel',),
'løysemidlene': ('løysemiddel',),
'løysemidler': ('løysemiddel',),
'løysemidlet': ('løysemiddel',),
'løysepengene': ('løysepenger',),
'løysepenger': ('løysepenger',),
'løysesum': ('løysesum',),
'løysesummen': ('løysesum',),
'løysesummene': ('løysesum',),
'løysesummer': ('løysesum',),
'løysing': ('løysing',),
'løysingen': ('løysing',),
'løysingene': ('løysing',),
'løysinger': ('løysing',),
'løysing': ('løysing',),
'løysinga': ('løysing',),
'løysingen': ('løysing',),
'løysingene': ('løysing',),
'løysinger': ('løysing',),
'løysingsrett': ('løysingsrett',),
'løysingsretten': ('løysingsrett',),
'løysingsrettene': ('løysingsrett',),
'løysingsretter': ('løysingsrett',),
'løytnant': ('løytnant',),
'løytnanten': ('løytnant',),
'løytnantene': ('løytnant',),
'løytnanter': ('løytnant',),
'løytnantshjerta': ('løytnantshjerte',),
'løytnantshjerte': ('løytnantshjerte',),
'løytnantshjerten': ('løytnantshjerte',),
'løytnantshjertene': ('løytnantshjerte',),
'løytnantshjerter': ('løytnantshjerte',),
'løytnantshjertet': ('løytnantshjerte',),
'løyva': ('løyve',),
'løyve': ('løyve',),
'løyvene': ('løyve',),
'løyver': ('løyve',),
'løyvet': ('løyve',),
'løyving': ('løyving',),
'løyvinga': ('løyving',),
'løyvingen': ('løyving',),
'løyvingene': ('løyving',),
'løyvinger': ('løyving',),
'm': ('m',),
'm\'en': ('m',),
'm-en': ('m',),
'm-ene': ('m',),
'm-er': ('m',),
'mach': ('mach',),
'machete': ('machete',),
'macheten': ('machete',),
'machetene': ('machete',),
'macheter': ('machete',),
'machiavellisme': ('machiavellisme',),
'machiavellismen': ('machiavellisme',),
'machiavellismene': ('machiavellisme',),
'machiavellismer': ('machiavellisme',),
'machomann': ('machomann',),
'machomannen': ('machomann',),
'machomenn': ('machomann',),
'machomennene': ('machomann',),
'machosamfunn': ('machosamfunn',),
'machosamfunna': ('machosamfunn',),
'machosamfunnene': ('machosamfunn',),
'machosamfunnet': ('machosamfunn',),
'machtal': ('machtal',),
'machtala': ('machtal',),
'machtalene': ('machtal',),
'machtalet': ('machtal',),
'machtall': ('machtall',),
'machtalla': ('machtall',),
'machtallene': ('machtall',),
'machtallet': ('machtall',),
'mad': ('mad',),
'mada': ('mad',),
'madene': ('mad',),
'madet': ('mad',),
'madagasser': ('madagasser',),
'madagassere': ('madagasser',),
'madagasseren': ('madagasser',),
'madagasserer': ('madagasser',),
'madagasserne': ('madagasser',),
'madam': ('madam',),
'madammen': ('madam',),
'madammene': ('madam',),
'madammer': ('madam',),
'madame': ('madame',),
'madamen': ('madame',),
'madamene': ('madame',),
'madamer': ('madame',),
'madapolam': ('madapolam',),
'madapolama': ('madapolam',),
'madapolamen': ('madapolam',),
'madapolamene': ('madapolam',),
'madapolamer': ('madapolam',),
'madapolamet': ('madapolam',),
'madeira': ('madeira',),
'madeiraen': ('madeira',),
'madeiraene': ('madeira',),
'madeiraer': ('madeira',),
'madeiravin': ('madeiravin',),
'madeiravinen': ('madeiravin',),
'madeiravinene': ('madeiravin',),
'madeiraviner': ('madeiravin',),
'mademoiselle': ('mademoiselle',),
'mademoisellen': ('mademoiselle',),
'mademoisellene': ('mademoiselle',),
'mademoiseller': ('mademoiselle',),
'madjar': ('madjar',),
'madjaren': ('madjar',),
'madjarene': ('madjar',),
'madjarer': ('madjar',),
'madonna': ('madonna',),
'madonnaen': ('madonna',),
'madonnaene': ('madonna',),
'madonnaer': ('madonna',),
'madonnabilda': ('madonnabilde',),
'madonnabilde': ('madonnabilde',),
'madonnabildene': ('madonnabilde',),
'madonnabilder': ('madonnabilde',),
'madonnabildet': ('madonnabilde',),
'madras': ('madras',),
'madrasa': ('madras',),
'madrasen': ('madras',),
'madrasene': ('madras',),
'madraser': ('madras',),
'madraset': ('madras',),
'madrasgardin': ('madrasgardin',),
'madrasgardina': ('madrasgardin',),
'madrasgardinen': ('madrasgardin',),
'madrasgardinene': ('madrasgardin',),
'madrasgardiner': ('madrasgardin',),
'madrasgardinet': ('madrasgardin',),
'madrass': ('madrass',),
'madrassen': ('madrass',),
'madrassene': ('madrass',),
'madrasser': ('madrass',),
'madrigal': ('madrigal',),
'madrigalen': ('madrigal',),
'madrigalene': ('madrigal',),
'madrigaler': ('madrigal',),
'maestro': ('maestro',),
'maestroen': ('maestro',),
'maestroene': ('maestro',),
'maestroer': ('maestro',),
'mafia': ('mafia',),
'mafiaen': ('mafia',),
'mafiaene': ('mafia',),
'mafiaer': ('mafia',),
'mafiosi': ('mafioso',),
'mafiosiene': ('mafioso',),
'mafioso': ('mafioso',),
'mafiosoen': ('mafioso',),
'magasin': ('magasin',),
'magasina': ('magasin',),
'magasinene': ('magasin',),
'magasiner': ('magasin',),
'magasinet': ('magasin',),
'magasinfylling': ('magasinfylling',),
'magasinfyllinga': ('magasinfylling',),
'magasinfyllingen': ('magasinfylling',),
'magasinfyllingene': ('magasinfylling',),
'magasinfyllinger': ('magasinfylling',),
'magasingevær': ('magasingevær',),
'magasingeværa': ('magasingevær',),
'magasingeværene': ('magasingevær',),
'magasingeværer': ('magasingevær',),
'magasingeværet': ('magasingevær',),
'magasinomn': ('magasinomn',),
'magasinomnen': ('magasinomn',),
'magasinomnene': ('magasinomn',),
'magasinomner': ('magasinomn',),
'magasinovn': ('magasinovn',),
'magasinovnen': ('magasinovn',),
'magasinovnene': ('magasinovn',),
'magasinovner': ('magasinovn',),
'mage': ('mage',),
'magen': ('mage',),
'magene': ('mage',),
'mager': ('mage',),
'magebelta': ('magebelte',),
'magebelte': ('magebelte',),
'magebeltene': ('magebelte',),
'magebelter': ('magebelte',),
'magebeltet': ('magebelte',),
'magedans': ('magedans',),
'magedansen': ('magedans',),
'magedansene': ('magedans',),
'magedanser': ('magedans',),
'magehistoria': ('magehistorie',),
'magehistorie': ('magehistorie',),
'magehistorien': ('magehistorie',),
'magehistoriene': ('magehistorie',),
'magehistorier': ('magehistorie',),
'magekatarr': ('magekatarr',),
'magekatarren': ('magekatarr',),
'magekatarrene': ('magekatarr',),
'magekatarrer': ('magekatarr',),
'mageknip': ('mageknip',),
'mageknipa': ('mageknip',),
'mageknipene': ('mageknip',),
'mageknipet': ('mageknip',),
'magekreft': ('magekreft',),
'magekreften': ('magekreft',),
'magekreftene': ('magekreft',),
'magekrefter': ('magekreft',),
'magemunn': ('magemunn',),
'magemunnen': ('magemunn',),
'magemunnene': ('magemunn',),
'magemunner': ('magemunn',),
'magemål': ('magemål',),
'magemåla': ('magemål',),
'magemålene': ('magemål',),
'magemålet': ('magemål',),
'mageonda': ('mageonde',),
'mageonde': ('mageonde',),
'mageondene': ('mageonde',),
'mageonder': ('mageonde',),
'mageondet': ('mageonde',),
'mageplask': ('mageplask',),
'mageplaska': ('mageplask',),
'mageplaskene': ('mageplask',),
'mageplasket': ('mageplask',),
'mageport': ('mageport',),
'mageporten': ('mageport',),
'mageportene': ('mageport',),
'mageporter': ('mageport',),
'mager': ('mager',),
'magere': ('mager',),
'mageren': ('mager',),
'magerer': ('mager',),
'magerne': ('mager',),
'magesaft': ('magesaft',),
'magesafta': ('magesaft',),
'magesaften': ('magesaft',),
'magesaftene': ('magesaft',),
'magesafter': ('magesaft',),
'magesekk': ('magesekk',),
'magesekken': ('magesekk',),
'magesekkene': ('magesekk',),
'magesekker': ('magesekk',),
'magesjau': ('magesjau',),
'magesjauen': ('magesjau',),
'magesjauene': ('magesjau',),
'magesjauer': ('magesjau',),
'magesyra': ('magesyre',),
'magesyre': ('magesyre',),
'magesyren': ('magesyre',),
'magesyrene': ('magesyre',),
'magesyrer': ('magesyre',),
'magesår': ('magesår',),
'magesåra': ('magesår',),
'magesårene': ('magesår',),
'magesåret': ('magesår',),
'magetilfella': ('magetilfelle',),
'magetilfelle': ('magetilfelle',),
'magetilfellene': ('magetilfelle',),
'magetilfeller': ('magetilfelle',),
'magetilfellet': ('magetilfelle',),
'magevegg': ('magevegg',),
'mageveggen': ('magevegg',),
'mageveggene': ('magevegg',),
'magevegger': ('magevegg',),
'magevelling': ('magevelling',),
'magevellinga': ('magevelling',),
'magevellingen': ('magevelling',),
'magevellingene': ('magevelling',),
'magevellinger': ('magevelling',),
'mageverk': ('mageverk',),
'mageverken': ('mageverk',),
'mageverkene': ('mageverk',),
'mageverker': ('mageverk',),
'magga': ('magge',),
'magge': ('magge',),
'maggen': ('magge',),
'maggene': ('magge',),
'magger': ('magge',),
'magi': ('magi',),
'magien': ('magi',),
'magiene': ('magi',),
'magier': ('magi',),
'magiker': ('magiker',),
'magikere': ('magiker',),
'magikeren': ('magiker',),
'magikerer': ('magiker',),
'magikerne': ('magiker',),
'magister': ('magister',),
'magistere': ('magister',),
'magisteren': ('magister',),
'magisterer': ('magister',),
'magisterne': ('magister',),
'magistre': ('magister',),
'magistrene': ('magister',),
'magistrer': ('magister',),
'magistergrad': ('magistergrad',),
'magistergraden': ('magistergrad',),
'magistergradene': ('magistergrad',),
'magistergrader': ('magistergrad',),
'magistergradsavhandling': ('magistergradsavhandling',),
'magistergradsavhandlinga': ('magistergradsavhandling',),
'magistergradsavhandlingen': ('magistergradsavhandling',),
'magistergradsavhandlingene': ('magistergradsavhandling',),
'magistergradsavhandlinger': ('magistergradsavhandling',),
'magistrat': ('magistrat',),
'magistraten': ('magistrat',),
'magistratene': ('magistrat',),
'magistrater': ('magistrat',),
'magma': ('magma',),
'magmaa': ('magma',),
'magmaen': ('magma',),
'magmaene': ('magma',),
'magmaer': ('magma',),
'magmaet': ('magma',),
'magnat': ('magnat',),
'magnaten': ('magnat',),
'magnatene': ('magnat',),
'magnater': ('magnat',),
'magnesia': ('magnesia',),
'magnesiaen': ('magnesia',),
'magnesiaene': ('magnesia',),
'magnesiaer': ('magnesia',),
'magnesium': ('magnesium',),
'magnesiuma': ('magnesium',),
'magnesiumen': ('magnesium',),
'magnesiumene': ('magnesium',),
'magnesiumer': ('magnesium',),
'magnesiumet': ('magnesium',),
'magnesiumoksid': ('magnesiumoksid',),
'magnesiumoksida': ('magnesiumoksid',),
'magnesiumoksidene': ('magnesiumoksid',),
'magnesiumoksider': ('magnesiumoksid',),
'magnesiumoksidet': ('magnesiumoksid',),
'magnesiumsilikat': ('magnesiumsilikat',),
'magnesiumsilikata': ('magnesiumsilikat',),
'magnesiumsilikatene': ('magnesiumsilikat',),
'magnesiumsilikater': ('magnesiumsilikat',),
'magnesiumsilikatet': ('magnesiumsilikat',),
'magnesiumsulfat': ('magnesiumsulfat',),
'magnesiumsulfata': ('magnesiumsulfat',),
'magnesiumsulfatene': ('magnesiumsulfat',),
'magnesiumsulfater': ('magnesiumsulfat',),
'magnesiumsulfatet': ('magnesiumsulfat',),
'magnet': ('magnet',),
'magneten': ('magnet',),
'magnetene': ('magnet',),
'magneter': ('magnet',),
'magnetband': ('magnetband',),
'magnetbanda': ('magnetband',),
'magnetbandene': ('magnetband',),
'magnetbandet': ('magnetband',),
'magnetbånd': ('magnetbånd',),
'magnetbånda': ('magnetbånd',),
'magnetbåndene': ('magnetbånd',),
'magnetbåndet': ('magnetbånd',),
'magnetfelt': ('magnetfelt',),
'magnetfelta': ('magnetfelt',),
'magnetfeltene': ('magnetfelt',),
'magnetfelter': ('magnetfelt',),
'magnetfeltet': ('magnetfelt',),
'magnetfeltterapi': ('magnetfeltterapi',),
'magnetfeltterapien': ('magnetfeltterapi',),
'magnetfeltterapiene': ('magnetfeltterapi',),
'magnetfeltterapier': ('magnetfeltterapi',),
'magnetisme': ('magnetisme',),
'magnetismen': ('magnetisme',),
'magnetismene': ('magnetisme',),
'magnetismer': ('magnetisme',),
'magnetitt': ('magnetitt',),
'magnetitten': ('magnetitt',),
'magnetittene': ('magnetitt',),
'magnetitter': ('magnetitt',),
'magnetjernstein': ('magnetjernstein',),
'magnetjernsteinen': ('magnetjernstein',),
'magnetjernsteinene': ('magnetjernstein',),
'magnetjernsteiner': ('magnetjernstein',),
'magnetkompas': ('magnetkompas',),
'magnetkompasa': ('magnetkompas',),
'magnetkompasen': ('magnetkompas',),
'magnetkompasene': ('magnetkompas',),
'magnetkompaser': ('magnetkompas',),
'magnetkompaset': ('magnetkompas',),
'magnetkompass': ('magnetkompass',),
'magnetkompassa': ('magnetkompass',),
'magnetkompassen': ('magnetkompass',),
'magnetkompassene': ('magnetkompass',),
'magnetkompasser': ('magnetkompass',),
'magnetkompasset': ('magnetkompass',),
'magnetkort': ('magnetkort',),
'magnetkorta': ('magnetkort',),
'magnetkortene': ('magnetkort',),
'magnetkortet': ('magnetkort',),
'magnetlager': ('magnetlager',),
'magnetlageret': ('magnetlager',),
'magnetlagra': ('magnetlager',),
'magnetlagre': ('magnetlager',),
'magnetlagrene': ('magnetlager',),
'magnetlukking': ('magnetlukking',),
'magnetlukkinga': ('magnetlukking',),
'magnetlukkingen': ('magnetlukking',),
'magnetlukkingene': ('magnetlukking',),
'magnetlukkinger': ('magnetlukking',),
'magnetnål': ('magnetnål',),
'magnetnåla': ('magnetnål',),
'magnetnålen': ('magnetnål',),
'magnetnålene': ('magnetnål',),
'magnetnåler': ('magnetnål',),
'magnetofon': ('magnetofon',),
'magnetofonen': ('magnetofon',),
'magnetofonene': ('magnetofon',),
'magnetofoner': ('magnetofon',),
'magnetosfære': ('magnetosfære',),
'magnetosfæren': ('magnetosfære',),
'magnetosfærene': ('magnetosfære',),
'magnetosfærer': ('magnetosfære',),
'magnetplata': ('magnetplate',),
'magnetplate': ('magnetplate',),
'magnetplaten': ('magnetplate',),
'magnetplatene': ('magnetplate',),
'magnetplater': ('magnetplate',),
'magnetplatelager': ('magnetplatelager',),
'magnetplatelageret': ('magnetplatelager',),
'magnetplatelagra': ('magnetplatelager',),
'magnetplatelagre': ('magnetplatelager',),
'magnetplatelagrene': ('magnetplatelager',),
'magnetpol': ('magnetpol',),
'magnetpolen': ('magnetpol',),
'magnetpolene': ('magnetpol',),
'magnetpoler': ('magnetpol',),
'magnetstav': ('magnetstav',),
'magnetstaven': ('magnetstav',),
'magnetstavene': ('magnetstav',),
'magnetstaver': ('magnetstav',),
'magnolia': ('magnolia',),
'magnoliaen': ('magnolia',),
'magnoliaene': ('magnolia',),
'magnoliaer': ('magnolia',),
'magnum': ('magnum',),
'magnumflaska': ('magnumflaske',),
'magnumflaske': ('magnumflaske',),
'magnumflasken': ('magnumflaske',),
'magnumflaskene': ('magnumflaske',),
'magnumflasker': ('magnumflaske',),
'maharaja': ('maharaja',),
'maharajaen': ('maharaja',),
'maharajaene': ('maharaja',),
'maharajaer': ('maharaja',),
'mahatma': ('mahatma',),
'mahatmaen': ('mahatma',),
'mahatmaene': ('mahatma',),
'mahatmaer': ('mahatma',),
'mahogni': ('mahogni',),
'mahognien': ('mahogni',),
'mahogniene': ('mahogni',),
'mahognier': ('mahogni',),
'mahognibord': ('mahognibord',),
'mahogniborda': ('mahognibord',),
'mahognibordene': ('mahognibord',),
'mahogniborder': ('mahognibord',),
'mahognibordet': ('mahognibord',),
'mai': ('mai',),
'maiblom': ('maiblom',),
'maiblommen': ('maiblom',),
'maiblommene': ('maiblom',),
'maiblommer': ('maiblom',),
'maigull': ('maigull',),
'maigulla': ('maigull',),
'maigullen': ('maigull',),
'maigullene': ('maigull',),
'maiguller': ('maigull',),
'maigullet': ('maigull',),
'mainepa': ('mainepe',),
'mainepe': ('mainepe',),
'mainepen': ('mainepe',),
'mainepene': ('mainepe',),
'maineper': ('mainepe',),
'mais': ('mais',),
'maisen': ('mais',),
'maisene': ('mais',),
'maiser': ('mais',),
'maisenna': ('maisenna',),
'maisennaen': ('maisenna',),
'maisennaene': ('maisenna',),
'maisennaer': ('maisenna',),
'maisgraut': ('maisgraut',),
'maisgrauten': ('maisgraut',),
'maisgrautene': ('maisgraut',),
'maisgrauter': ('maisgraut',),
'maisgrøt': ('maisgrøt',),
'maisgrøten': ('maisgrøt',),
'maisgrøtene': ('maisgrøt',),
'maisgrøter': ('maisgrøt',),
'maiskolbe': ('maiskolbe',),
'maiskolben': ('maiskolbe',),
'maiskolbene': ('maiskolbe',),
'maiskolber': ('maiskolbe',),
'maismel': ('maismel',),
'maismela': ('maismel',),
'maismelene': ('maismel',),
'maismelet': ('maismel',),
'maismjøl': ('maismjøl',),
'maismjøla': ('maismjøl',),
'maismjølene': ('maismjøl',),
'maismjølet': ('maismjøl',),
'maistang': ('maistang',),
'maistanga': ('maistang',),
'maistangen': ('maistang',),
'maistengene': ('maistang',),
'maistenger': ('maistang',),
'majestet': ('majestet',),
'majesteten': ('majestet',),
'majestetene': ('majestet',),
'majesteter': ('majestet',),
'majestetsforbrytelse': ('majestetsforbrytelse',),
'majestetsforbrytelsen': ('majestetsforbrytelse',),
'majestetsforbrytelsene': ('majestetsforbrytelse',),
'majestetsforbrytelser': ('majestetsforbrytelse',),
'majolika': ('majolika',),
'majolikaen': ('majolika',),
'majolikaene': ('majolika',),
'majolikaer': ('majolika',),
'majolikakrukka': ('majolikakrukke',),
'majolikakrukke': ('majolikakrukke',),
'majolikakrukken': ('majolikakrukke',),
'majolikakrukkene': ('majolikakrukke',),
'majolikakrukker': ('majolikakrukke',),
'majones': ('majones',),
'majonesen': ('majones',),
'majonesene': ('majones',),
'majoneser': ('majones',),
'major': ('major',),
'majoren': ('major',),
'majorene': ('major',),
'majorer': ('major',),
'majoritet': ('majoritet',),
'majoriteten': ('majoritet',),
'majoritetene': ('majoritet',),
'majoriteter': ('majoritet',),
'majuskel': ('majuskel',),
'majuskelen': ('majuskel',),
'majusklene': ('majuskel',),
'majuskler': ('majuskel',),
'majuskelskrift': ('majuskelskrift',),
'majuskelskrifta': ('majuskelskrift',),
'majuskelskriften': ('majuskelskrift',),
'majuskelskriftene': ('majuskelskrift',),
'majuskelskrifter': ('majuskelskrift',),
'mak': ('mak',),
'maka': ('mak',),
'maken': ('mak',),
'makene': ('mak',),
'maker': ('mak',),
'maket': ('mak',),
'makadam': ('makadam',),
'makadamen': ('makadam',),
'makadamene': ('makadam',),
'makadamer': ('makadam',),
'makaroni': ('makaroni',),
'makaronien': ('makaroni',),
'makaroniene': ('makaroni',),
'makaronier': ('makaroni',),
'makassarolja': ('makassarolje',),
'makassarolje': ('makassarolje',),
'makassaroljen': ('makassarolje',),
'makassaroljene': ('makassarolje',),
'makassaroljer': ('makassarolje',),
'make': ('make',),
'maken': ('make',),
'makene': ('make',),
'maker': ('make',),
'make-up': ('make-up',),
'make-upen': ('make-up',),
'make-upene': ('make-up',),
'make-uper': ('make-up',),
'makedoner': ('makedoner',),
'makedonere': ('makedoner',),
'makedoneren': ('makedoner',),
'makedonerer': ('makedoner',),
'makedonerne': ('makedoner',),
'makedonier': ('makedonier',),
'makedoniere': ('makedonier',),
'makedonieren': ('makedonier',),
'makedonierer': ('makedonier',),
'makedonierne': ('makedonier',),
'makelighet': ('makelighet',),
'makeligheta': ('makelighet',),
'makeligheten': ('makelighet',),
'makelighetene': ('makelighet',),
'makeligheter': ('makelighet',),
'makelighetshensyn': ('makelighetshensyn',),
'makelighetshensyna': ('makelighetshensyn',),
'makelighetshensynene': ('makelighetshensyn',),
'makelighetshensynet': ('makelighetshensyn',),
'makeskifta': ('makeskifte',),
'makeskifte': ('makeskifte',),
'makeskiftene': ('makeskifte',),
'makeskifter': ('makeskifte',),
'makeskiftet': ('makeskifte',),
'makk': ('makk',),
'makken': ('makk',),
'makkene': ('makk',),
'makker': ('makk',),
'makkabeer': ('makkabeer',),
'makkabeere': ('makkabeer',),
'makkabeeren': ('makkabeer',),
'makkabeerer': ('makkabeer',),
'makkabeerne': ('makkabeer',),
'makker': ('makker',),
'makkere': ('makker',),
'makkeren': ('makker',),
'makkerer': ('makker',),
'makkerne': ('makker',),
'makko': ('makko',),
'makkoen': ('makko',),
'makkoene': ('makko',),
'makkoer': ('makko',),
'makkoundertøy': ('makkoundertøy',),
'makkoundertøya': ('makkoundertøy',),
'makkoundertøyene': ('makkoundertøy',),
'makkoundertøyer': ('makkoundertøy',),
'makkoundertøyet': ('makkoundertøy',),
'makkverk': ('makkverk',),
'makkverka': ('makkverk',),
'makkverkene': ('makkverk',),
'makkverket': ('makkverk',),
'makramea': ('makramé',),
'makrameen': ('makramé',),
'makrameene': ('makramé',),
'makrameer': ('makramé',),
'makrameet': ('makramé',),
'makramé': ('makramé',),
'makraméen': ('makramé',),
'makraméene': ('makramé',),
'makraméer': ('makramé',),
'makraméarbeid': ('makraméarbeid',),
'makraméarbeida': ('makraméarbeid',),
'makraméarbeidene': ('makraméarbeid',),
'makraméarbeider': ('makraméarbeid',),
'makraméarbeidet': ('makraméarbeid',),
'makrell': ('makrell',),
'makrellen': ('makrell',),
'makrellene': ('makrell',),
'makreller': ('makrell',),
'makrellfisk': ('makrellfisk',),
'makrellfisken': ('makrellfisk',),
'makrellfiskene': ('makrellfisk',),
'makrellfisker': ('makrellfisk',),
'makrellfiska': ('makrellfiske',),
'makrellfiske': ('makrellfiske',),
'makrellfiskene': ('makrellfiske',),
'makrellfisker': ('makrellfiske',),
'makrellfisket': ('makrellfiske',),
'makrellsky': ('makrellsky',),
'makrellskya': ('makrellsky',),
'makrellskyen': ('makrellsky',),
'makrellskyene': ('makrellsky',),
'makrellskyer': ('makrellsky',),
'makrellstørja': ('makrellstørje',),
'makrellstørje': ('makrellstørje',),
'makrellstørjen': ('makrellstørje',),
'makrellstørjene': ('makrellstørje',),
'makrellstørjer': ('makrellstørje',),
'makro': ('makro',),
'makroen': ('makro',),
'makroene': ('makro',),
'makroer': ('makro',),
'makrokosmos': ('makrokosmos',),
'makrokosmosa': ('makrokosmos',),
'makrokosmosene': ('makrokosmos',),
'makrokosmoset': ('makrokosmos',),
'makromolekyl': ('makromolekyl',),
'makromolekyla': ('makromolekyl',),
'makromolekylene': ('makromolekyl',),
'makromolekyler': ('makromolekyl',),
'makromolekylet': ('makromolekyl',),
'makron': ('makron',),
'makronen': ('makron',),
'makronene': ('makron',),
'makroner': ('makron',),
'maksel': ('maksel',),
'makselen': ('maksel',),
'makslene': ('maksel',),
'maksler': ('maksel',),
'maksikjole': ('maksikjole',),
'maksikjolen': ('maksikjole',),
'maksikjolene': ('maksikjole',),
'maksikjoler': ('maksikjole',),
'maksikåpa': ('maksikåpe',),
'maksikåpe': ('maksikåpe',),
'maksikåpen': ('maksikåpe',),
'maksikåpene': ('maksikåpe',),
'maksikåper': ('maksikåpe',),
'maksimalhastighet': ('maksimalhastighet',),
'maksimalhastigheta': ('maksimalhastighet',),
'maksimalhastigheten': ('maksimalhastighet',),
'maksimalhastighetene': ('maksimalhastighet',),
'maksimalhastigheter': ('maksimalhastighet',),
'maksimalpris': ('maksimalpris',),
'maksimalprisen': ('maksimalpris',),
'maksimalprisene': ('maksimalpris',),
'maksimalpriser': ('maksimalpris',),
'maksime': ('maksime',),
'maksimen': ('maksime',),
'maksimene': ('maksime',),
'maksimer': ('maksime',),
'maksima': ('maksimum',),
'maksimaene': ('maksimum',),
'maksimum': ('maksimum',),
'maksimuma': ('maksimum',),
'maksimumene': ('maksimum',),
'maksimumer': ('maksimum',),
'maksimumet': ('maksimum',),
'maksimumstemperatur': ('maksimumstemperatur',),
'maksimumstemperaturen': ('maksimumstemperatur',),
'maksimumstemperaturene': ('maksimumstemperatur',),
'maksimumstemperaturer': ('maksimumstemperatur',),
'maksimumstermometer': ('maksimumstermometer',),
'maksimumstermometeret': ('maksimumstermometer',),
'maksimumstermometra': ('maksimumstermometer',),
'maksimumstermometre': ('maksimumstermometer',),
'maksimumstermometrene': ('maksimumstermometer',),
'maksimumstermometret': ('maksimumstermometer',),
'maksiskjørt': ('maksiskjørt',),
'maksiskjørta': ('maksiskjørt',),
'maksiskjørtene': ('maksiskjørt',),
'maksiskjørter': ('maksiskjørt',),
'maksiskjørtet': ('maksiskjørt',),
'maksvind': ('maksvind',),
'maksvinden': ('maksvind',),
'maksvindene': ('maksvind',),
'maksvinder': ('maksvind',),
'maksvær': ('maksvær',),
'maksværa': ('maksvær',),
'maksværene': ('maksvær',),
'maksværet': ('maksvær',),
'makt': ('makt',),
'makta': ('makt',),
'makten': ('makt',),
'maktene': ('makt',),
'makter': ('makt',),
'maktanvendelse': ('maktanvendelse',),
'maktanvendelsen': ('maktanvendelse',),
'maktanvendelsene': ('maktanvendelse',),
'maktanvendelser': ('maktanvendelse',),
'maktapparat': ('maktapparat',),
'maktapparata': ('maktapparat',),
'maktapparatene': ('maktapparat',),
'maktapparater': ('maktapparat',),
'maktapparatet': ('maktapparat',),
'maktbalanse': ('maktbalanse',),
'maktbalansen': ('maktbalanse',),
'maktbalansene': ('maktbalanse',),
'maktbalanser': ('maktbalanse',),
'maktbegjær': ('maktbegjær',),
'maktbegjæra': ('maktbegjær',),
'maktbegjærene': ('maktbegjær',),
'maktbegjæret': ('maktbegjær',),
'maktblokk': ('maktblokk',),
'maktblokka': ('maktblokk',),
'maktblokken': ('maktblokk',),
'maktblokkene': ('maktblokk',),
'maktblokker': ('maktblokk',),
'maktbruk': ('maktbruk',),
'maktbruka': ('maktbruk',),
'maktbruken': ('maktbruk',),
'maktbrukene': ('maktbruk',),
'maktbruker': ('maktbruk',),
'maktbruket': ('maktbruk',),
'maktbud': ('maktbud',),
'maktbuda': ('maktbud',),
'maktbudene': ('maktbud',),
'maktbudet': ('maktbud',),
'maktelite': ('maktelite',),
'makteliten': ('maktelite',),
'maktelitene': ('maktelite',),
'makteliter': ('maktelite',),
'maktesløshet': ('maktesløshet',),
'maktesløsheta': ('maktesløshet',),
'maktesløsheten': ('maktesløshet',),
'maktesløshetene': ('maktesløshet',),
'maktesløsheter': ('maktesløshet',),
'maktesløysa': ('maktesløyse',),
'maktesløyse': ('maktesløyse',),
'maktesløysen': ('maktesløyse',),
'maktesløysene': ('maktesløyse',),
'maktesløyser': ('maktesløyse',),
'maktfaktor': ('maktfaktor',),
'maktfaktoren': ('maktfaktor',),
'maktfaktorene': ('maktfaktor',),
'maktfaktorer': ('maktfaktor',),
'maktfordeling': ('maktfordeling',),
'maktfordelinga': ('maktfordeling',),
'maktfordelingen': ('maktfordeling',),
'maktfordelingene': ('maktfordeling',),
'maktfordelinger': ('maktfordeling',),
'maktfordelingsprinsipp': ('maktfordelingsprinsipp',),
'maktfordelingsprinsippa': ('maktfordelingsprinsipp',),
'maktfordelingsprinsippene': ('maktfordelingsprinsipp',),
'maktfordelingsprinsipper': ('maktfordelingsprinsipp',),
'maktfordelingsprinsippet': ('maktfordelingsprinsipp',),
'maktforhold': ('maktforhold',),
'maktforholda': ('maktforhold',),
'maktforholdene': ('maktforhold',),
'maktforholdet': ('maktforhold',),
'makthaver': ('makthaver',),
'makthavere': ('makthaver',),
'makthaveren': ('makthaver',),
'makthaverer': ('makthaver',),
'makthaverne': ('makthaver',),
'maktkamp': ('maktkamp',),
'maktkampen': ('maktkamp',),
'maktkampene': ('maktkamp',),
'maktkamper': ('maktkamp',),
'maktløshet': ('maktløshet',),
'maktløsheta': ('maktløshet',),
'maktløsheten': ('maktløshet',),
'maktløshetene': ('maktløshet',),
'maktløsheter': ('maktløshet',),
'maktløysa': ('maktløyse',),
'maktløyse': ('maktløyse',),
'maktløysen': ('maktløyse',),
'maktløysene': ('maktløyse',),
'maktløyser': ('maktløyse',),
'maktmenneska': ('maktmenneske',),
'maktmenneske': ('maktmenneske',),
'maktmenneskene': ('maktmenneske',),
'maktmennesker': ('maktmenneske',),
'maktmennesket': ('maktmenneske',),
'maktmiddel': ('maktmiddel',),
'maktmiddelet': ('maktmiddel',),
'maktmidla': ('maktmiddel',),
'maktmidlene': ('maktmiddel',),
'maktmidler': ('maktmiddel',),
'maktmidlet': ('maktmiddel',),
'maktmisbruk': ('maktmisbruk',),
'maktmisbruka': ('maktmisbruk',),
'maktmisbruken': ('maktmisbruk',),
'maktmisbrukene': ('maktmisbruk',),
'maktmisbruker': ('maktmisbruk',),
'maktmisbruket': ('maktmisbruk',),
'maktsentra': ('maktsentrum',),
'maktsentraene': ('maktsentrum',),
'maktsentre': ('maktsentrum',),
'maktsentrene': ('maktsentrum',),
'maktsentret': ('maktsentrum',),
'maktsentrum': ('maktsentrum',),
'maktsentrumet': ('maktsentrum',),
'maktsjuka': ('maktsjuke',),
'maktsjuke': ('maktsjuke',),
'maktsjuken': ('maktsjuke',),
'maktsjukene': ('maktsjuke',),
'maktsjuker': ('maktsjuke',),
'maktspråk': ('maktspråk',),
'maktspråka': ('maktspråk',),
'maktspråkene': ('maktspråk',),
'maktspråket': ('maktspråk',),
'maktsyka': ('maktsyke',),
'maktsyke': ('maktsyke',),
'maktsyken': ('maktsyke',),
'maktsykene': ('maktsyke',),
'maktsyker': ('maktsyke',),
'maktutfoldelse': ('maktutfoldelse',),
'maktutfoldelsen': ('maktutfoldelse',),
'maktutfoldelsene': ('maktutfoldelse',),
'maktutfoldelser': ('maktutfoldelse',),
'makulatur': ('makulatur',),
'makulaturen': ('makulatur',),
'makulaturene': ('makulatur',),
'makulaturer': ('makulatur',),
'mal': ('mal',),
'malen': ('mal',),
'malene': ('mal',),
'maler': ('mal',),
'mal': ('mal',),
'malen': ('mal',),
'malene': ('mal',),
'maler': ('mal',),
'malaga': ('malaga',),
'malagaen': ('malaga',),
'malagaene': ('malaga',),
'malagaer': ('malaga',),
'malagavin': ('malagavin',),
'malagavinen': ('malagavin',),
'malagavinene': ('malagavin',),
'malagaviner': ('malagavin',),
'malakitt': ('malakitt',),
'malakitten': ('malakitt',),
'malakittene': ('malakitt',),
'malakitter': ('malakitt',),
'malaria': ('malaria',),
'malariaen': ('malaria',),
'malariaene': ('malaria',),
'malariaer': ('malaria',),
'malariafeber': ('malariafeber',),
'malariafebere': ('malariafeber',),
'malariafeberen': ('malariafeber',),
'malariafeberer': ('malariafeber',),
'malariafeberne': ('malariafeber',),
'malariafebre': ('malariafeber',),
'malariafebrene': ('malariafeber',),
'malariafebrer': ('malariafeber',),
'malariamygg': ('malariamygg',),
'malariamyggen': ('malariamygg',),
'malariamyggene': ('malariamygg',),
'malariaparasitt': ('malariaparasitt',),
'malariaparasitten': ('malariaparasitt',),
'malariaparasittene': ('malariaparasitt',),
'malariaparasitter': ('malariaparasitt',),
'malawier': ('malawier',),
'malawiere': ('malawier',),
'malawieren': ('malawier',),
'malawierer': ('malawier',),
'malawierne': ('malawier',),
'malay': ('malay',),
'malayen': ('malay',),
'malayene': ('malay',),
'malayer': ('malay',),
'malayisk': ('malayisk',),
'malayisken': ('malayisk',),
'malayiskene': ('malayisk',),
'malayisker': ('malayisk',),
'malaysier': ('malaysier',),
'malaysiere': ('malaysier',),
'malaysieren': ('malaysier',),
'malaysierer': ('malaysier',),
'malaysierne': ('malaysier',),
'maldiver': ('maldiver',),
'maldivere': ('maldiver',),
'maldiveren': ('maldiver',),
'maldiverer': ('maldiver',),
'maldiverne': ('maldiver',),
'maler': ('maler',),
'malere': ('maler',),
'maleren': ('maler',),
'malerer': ('maler',),
'malerne': ('maler',),
'maleratelier': ('maleratelier',),
'malerateliera': ('maleratelier',),
'maleratelierene': ('maleratelier',),
'maleratelierer': ('maleratelier',),
'maleratelieret': ('maleratelier',),
'maleri': ('maleri',),
'maleria': ('maleri',),
'maleriene': ('maleri',),
'malerier': ('maleri',),
'maleriet': ('maleri',),
'malerisamling': ('malerisamling',),
'malerisamlinga': ('malerisamling',),
'malerisamlingen': ('malerisamling',),
'malerisamlingene': ('malerisamling',),
'malerisamlinger': ('malerisamling',),
'maleriutstilling': ('maleriutstilling',),
'maleriutstillinga': ('maleriutstilling',),
'maleriutstillingen': ('maleriutstilling',),
'maleriutstillingene': ('maleriutstilling',),
'maleriutstillinger': ('maleriutstilling',),
'malerkost': ('malerkost',),
'malerkosten': ('malerkost',),
'malerkostene': ('malerkost',),
'malerkoster': ('malerkost',),
'malerkunst': ('malerkunst',),
'malerkunsten': ('malerkunst',),
'malerkunstene': ('malerkunst',),
'malerkunster': ('malerkunst',),
'malerlæra': ('malerlære',),
'malerlære': ('malerlære',),
'malerlæren': ('malerlære',),
'malerlærene': ('malerlære',),
'malerlærer': ('malerlære',),
'malerlærling': ('malerlærling',),
'malerlærlingen': ('malerlærling',),
'malerlærlingene': ('malerlærling',),
'malerlærlinger': ('malerlærling',),
'malermester': ('malermester',),
'malermestere': ('malermester',),
'malermesteren': ('malermester',),
'malermesterer': ('malermester',),
'malermesterne': ('malermester',),
'malermestre': ('malermester',),
'malermestrene': ('malermester',),
'malermestrer': ('malermester',),
'malerpensel': ('malerpensel',),
'malerpenselen': ('malerpensel',),
'malerpenslene': ('malerpensel',),
'malerpensler': ('malerpensel',),
'malerskole': ('malerskole',),
'malerskolen': ('malerskole',),
'malerskolene': ('malerskole',),
'malerskoler': ('malerskole',),
'malerskrin': ('malerskrin',),
'malerskrina': ('malerskrin',),
'malerskrinene': ('malerskrin',),
'malerskrinet': ('malerskrin',),
'malier': ('malier',),
'maliere': ('malier',),
'malieren': ('malier',),
'malierer': ('malier',),
'malierne': ('malier',),
'maling': ('maling',),
'malinga': ('maling',),
'malingen': ('maling',),
'malingene': ('maling',),
'malinger': ('maling',),
'malingboks': ('malingboks',),
'malingboksen': ('malingboks',),
'malingboksene': ('malingboks',),
'malingbokser': ('malingboks',),
'malingflekk': ('malingflekk',),
'malingflekken': ('malingflekk',),
'malingflekkene': ('malingflekk',),
'malingflekker': ('malingflekk',),
'malingspann': ('malingspann',),
'malingspanna': ('malingspann',),
'malingspannene': ('malingspann',),
'malingspannet': ('malingspann',),
'malingtape': ('malingtape',),
'malingtapen': ('malingtape',),
'malingtapene': ('malingtape',),
'malingtaper': ('malingtape',),
'malingteip': ('malingteip',),
'malingteipen': ('malingteip',),
'malingteipene': ('malingteip',),
'malingteiper': ('malingteip',),
'malise': ('malise',),
'malisen': ('malise',),
'malisene': ('malise',),
'maliser': ('malise',),
'malja': ('malje',),
'malje': ('malje',),
'maljen': ('malje',),
'maljene': ('malje',),
'maljer': ('malje',),
'malle': ('malle',),
'mallen': ('malle',),
'mallene': ('malle',),
'maller': ('malle',),
'mallorcaner': ('mallorcaner',),
'mallorcanere': ('mallorcaner',),
'mallorcaneren': ('mallorcaner',),
'mallorcanerer': ('mallorcaner',),
'mallorcanerne': ('mallorcaner',),
'mallorkaner': ('mallorkaner',),
'mallorkanere': ('mallorkaner',),
'mallorkaneren': ('mallorkaner',),
'mallorkanerer': ('mallorkaner',),
'mallorkanerne': ('mallorkaner',),
'malmbåt': ('malmbåt',),
'malmbåten': ('malmbåt',),
'malmbåtene': ('malmbåt',),
'malmbåter': ('malmbåt',),
'malme': ('malme',),
'malmen': ('malme',),
'malmene': ('malme',),
'malmer': ('malme',),
'malmforekomst': ('malmforekomst',),
'malmforekomsten': ('malmforekomst',),
'malmforekomstene': ('malmforekomst',),
'malmforekomster': ('malmforekomst',),
'malmfunn': ('malmfunn',),
'malmfunna': ('malmfunn',),
'malmfunnene': ('malmfunn',),
'malmfunnet': ('malmfunn',),
'malmfuru': ('malmfuru',),
'malmfurua': ('malmfuru',),
'malmfuruen': ('malmfuru',),
'malmfuruene': ('malmfuru',),
'malmfuruer': ('malmfuru',),
'malmleia': ('malmleie',),
'malmleie': ('malmleie',),
'malmleiene': ('malmleie',),
'malmleier': ('malmleie',),
'malmleiet': ('malmleie',),
'malmskip': ('malmskip',),
'malmskipa': ('malmskip',),
'malmskipene': ('malmskip',),
'malmskipet': ('malmskip',),
'malmåra': ('malmåre',),
'malmåre': ('malmåre',),
'malmåren': ('malmåre',),
'malmårene': ('malmåre',),
'malmårer': ('malmåre',),
'malstrøm': ('malstrøm',),
'malstrømmen': ('malstrøm',),
'malstrømmene': ('malstrøm',),
'malstrømmer': ('malstrøm',),
'malt': ('malt',),
'malta': ('malt',),
'maltene': ('malt',),
'maltet': ('malt',),
'maltekstrakt': ('maltekstrakt',),
'maltekstrakten': ('maltekstrakt',),
'maltekstraktene': ('maltekstrakt',),
'maltekstrakter': ('maltekstrakt',),
'malteser': ('malteser',),
'maltesere': ('malteser',),
'malteseren': ('malteser',),
'malteserer': ('malteser',),
'malteserne': ('malteser',),
'malteserkors': ('malteserkors',),
'malteserkorsa': ('malteserkors',),
'malteserkorsene': ('malteserkors',),
'malteserkorset': ('malteserkors',),
'malteserorden': ('malteserorden',),
'malteserordenen': ('malteserorden',),
'malteserordenene': ('malteserorden',),
'malteserordener': ('malteserorden',),
'maltgroe': ('maltgroe',),
'maltgroen': ('maltgroe',),
'maltgroene': ('maltgroe',),
'maltgroer': ('maltgroe',),
'maltose': ('maltose',),
'maltosen': ('maltose',),
'maltosene': ('maltose',),
'maltoser': ('maltose',),
'maltsirup': ('maltsirup',),
'maltsirupen': ('maltsirup',),
'maltsirupene': ('maltsirup',),
'maltsiruper': ('maltsirup',),
'maltspira': ('maltspire',),
'maltspire': ('maltspire',),
'maltspiren': ('maltspire',),
'maltspirene': ('maltspire',),
'maltspirer': ('maltspire',),
'maltsukker': ('maltsukker',),
'maltsukkera': ('maltsukker',),
'maltsukkere': ('maltsukker',),
'maltsukkerene': ('maltsukker',),
'maltsukkeret': ('maltsukker',),
'maltsukkerne': ('maltsukker',),
'malurt': ('malurt',),
'malurta': ('malurt',),
'malurten': ('malurt',),
'malurtene': ('malurt',),
'malurter': ('malurt',),
'malvasier': ('malvasier',),
'malvasieren': ('malvasier',),
'malvasierene': ('malvasier',),
'malvasierer': ('malvasier',),
'malvasiervin': ('malvasiervin',),
'malvasiervinen': ('malvasiervin',),
'malvasiervinene': ('malvasiervin',),
'malvasierviner': ('malvasiervin',),
'malvasir': ('malvasir',),
'malvasiren': ('malvasir',),
'malvasirene': ('malvasir',),
'malvasirer': ('malvasir',),
'malvasirvin': ('malvasirvin',),
'malvasirvinen': ('malvasirvin',),
'malvasirvinene': ('malvasirvin',),
'malvasirviner': ('malvasirvin',),
'mamba': ('mamba',),
'mambaen': ('mamba',),
'mambaene': ('mamba',),
'mambaer': ('mamba',),
'mamelukk': ('mamelukk',),
'mamelukken': ('mamelukk',),
'mamelukkene': ('mamelukk',),
'mamelukker': ('mamelukk',),
'mamma': ('mamma',),
'mammaen': ('mamma',),
'mammaene': ('mamma',),
'mammaer': ('mamma',),
'mammadalt': ('mammadalt',),
'mammadalten': ('mammadalt',),
'mammadaltene': ('mammadalt',),
'mammadalter': ('mammadalt',),
'mammakjole': ('mammakjole',),
'mammakjolen': ('mammakjole',),
'mammakjolene': ('mammakjole',),
'mammakjoler': ('mammakjole',),
'mammaklær': ('mammaklær',),
'mammaklærne': ('mammaklær',),
'mammografi': ('mammografi',),
'mammografien': ('mammografi',),
'mammografiene': ('mammografi',),
'mammografier': ('mammografi',),
'mammon': ('mammon',),
'mammonstrell': ('mammonstrell',),
'mammonstrellen': ('mammonstrell',),
'mammonstrellene': ('mammonstrell',),
'mammonstreller': ('mammonstrell',),
'mammut': ('mammut',),
'mammuten': ('mammut',),
'mammutene': ('mammut',),
'mammuter': ('mammut',),
'mammutroman': ('mammutroman',),
'mammutromanen': ('mammutroman',),
'mammutromanene': ('mammutroman',),
'mammutromaner': ('mammutroman',),
'mammutsalg': ('mammutsalg',),
'mammutsalga': ('mammutsalg',),
'mammutsalgene': ('mammutsalg',),
'mammutsalget': ('mammutsalg',),
'mammutskole': ('mammutskole',),
'mammutskolen': ('mammutskole',),
'mammutskolene': ('mammutskole',),
'mammutskoler': ('mammutskole',),
'mammuttre': ('mammuttre',),
'mammuttrea': ('mammuttre',),
'mammuttreet': ('mammuttre',),
'mammuttrær': ('mammuttre',),
'mammuttrærne': ('mammuttre',),
'mamsell': ('mamsell',),
'mamsellen': ('mamsell',),
'mamsellene': ('mamsell',),
'mamseller': ('mamsell',),
'man': ('man',),
'mana': ('man',),
'manen': ('man',),
'manene': ('man',),
'maner': ('man',),
'manager': ('manager',),
'managere': ('manager',),
'manageren': ('manager',),
'managerer': ('manager',),
'managerne': ('manager',),
'manchurier': ('manchurier',),
'manchuriere': ('manchurier',),
'manchurieren': ('manchurier',),
'manchurierer': ('manchurier',),
'manchurierne': ('manchurier',),
'mandag': ('mandag',),
'mandagen': ('mandag',),
'mandagene': ('mandag',),
'mandager': ('mandag',),
'mandagsbil': ('mandagsbil',),
'mandagsbilen': ('mandagsbil',),
'mandagsbilene': ('mandagsbil',),
'mandagsbiler': ('mandagsbil',),
'mandagskveld': ('mandagskveld',),
'mandagskvelden': ('mandagskveld',),
'mandagskveldene': ('mandagskveld',),
'mandagskvelder': ('mandagskveld',),
'mandagsmorgen': ('mandagsmorgen',),
'mandagsmorgenen': ('mandagsmorgen',),
'mandagsmorgenene': ('mandagsmorgen',),
'mandagsmorgener': ('mandagsmorgen',),
'mandagsmorgnene': ('mandagsmorgen',),
'mandagsmorgner': ('mandagsmorgen',),
'mandagsnatt': ('mandagsnatt',),
'mandagsnatta': ('mandagsnatt',),
'mandagsnatten': ('mandagsnatt',),
'mandagsnettene': ('mandagsnatt',),
'mandagsnetter': ('mandagsnatt',),
'mandagsvara': ('mandagsvare',),
'mandagsvare': ('mandagsvare',),
'mandagsvaren': ('mandagsvare',),
'mandagsvarene': ('mandagsvare',),
'mandagsvarer': ('mandagsvare',),
'mandala': ('mandala',),
'mandalaen': ('mandala',),
'mandalaene': ('mandala',),
'mandalaer': ('mandala',),
'mandant': ('mandant',),
'mandanten': ('mandant',),
'mandantene': ('mandant',),
'mandanter': ('mandant',),
'mandarin': ('mandarin',),
'mandarinen': ('mandarin',),
'mandarinene': ('mandarin',),
'mandariner': ('mandarin',),
'mandat': ('mandat',),
'mandata': ('mandat',),
'mandatene': ('mandat',),
'mandater': ('mandat',),
'mandatet': ('mandat',),
'mandatar': ('mandatar',),
'mandataren': ('mandatar',),
'mandatarene': ('mandatar',),
'mandatarer': ('mandatar',),
'mandatfordeling': ('mandatfordeling',),
'mandatfordelinga': ('mandatfordeling',),
'mandatfordelingen': ('mandatfordeling',),
'mandatfordelingene': ('mandatfordeling',),
'mandatfordelinger': ('mandatfordeling',),
'mandatområda': ('mandatområde',),
'mandatområde': ('mandatområde',),
'mandatområdene': ('mandatområde',),
'mandatområder': ('mandatområde',),
'mandatområdet': ('mandatområde',),
'mandel': ('mandel',),
'mandelen': ('mandel',),
'mandlene': ('mandel',),
'mandler': ('mandel',),
'mandelbetennelse': ('mandelbetennelse',),
'mandelbetennelsen': ('mandelbetennelse',),
'mandelbetennelsene': ('mandelbetennelse',),
'mandelbetennelser': ('mandelbetennelse',),
'mandeldråpene': ('mandeldråper',),
'mandeldråper': ('mandeldråper',),
'mandelkjerne': ('mandelkjerne',),
'mandelkjernen': ('mandelkjerne',),
'mandelkjernene': ('mandelkjerne',),
'mandelkjerner': ('mandelkjerne',),
'mandelkvern': ('mandelkvern',),
'mandelkverna': ('mandelkvern',),
'mandelkvernen': ('mandelkvern',),
'mandelkvernene': ('mandelkvern',),
'mandelkverner': ('mandelkvern',),
'mandelmasse': ('mandelmasse',),
'mandelmassen': ('mandelmasse',),
'mandelmassene': ('mandelmasse',),
'mandelmasser': ('mandelmasse',),
'mandelolja': ('mandelolje',),
'mandelolje': ('mandelolje',),
'mandeloljen': ('mandelolje',),
'mandeloljene': ('mandelolje',),
'mandeloljer': ('mandelolje',),
'mandelpotet': ('mandelpotet',),
'mandelpoteten': ('mandelpotet',),
'mandelpotetene': ('mandelpotet',),
'mandelpoteter': ('mandelpotet',),
'mandighet': ('mandighet',),
'mandigheta': ('mandighet',),
'mandigheten': ('mandighet',),
'mandighetene': ('mandighet',),
'mandigheter': ('mandighet',),
'mandolin': ('mandolin',),
'mandolinen': ('mandolin',),
'mandolinene': ('mandolin',),
'mandoliner': ('mandolin',),
'mandrill': ('mandrill',),
'mandrillen': ('mandrill',),
'mandrillene': ('mandrill',),
'mandriller': ('mandrill',),
'mandsju': ('mandsju',),
'mandsjuen': ('mandsju',),
'mandsjuene': ('mandsju',),
'mandsjuer': ('mandsju',),
'mandsju': ('mandsju',),
'mandsjurier': ('mandsjurier',),
'mandsjuriere': ('mandsjurier',),
'mandsjurieren': ('mandsjurier',),
'mandsjurierer': ('mandsjurier',),
'mandsjurierne': ('mandsjurier',),
'maner': ('maner',),
'maneren': ('maner',),
'manerene': ('maner',),
'manerer': ('maner',),
'manesje': ('manesje',),
'manesjen': ('manesje',),
'manesjene': ('manesje',),
'manesjer': ('manesje',),
'manet': ('manet',),
'maneta': ('manet',),
'maneten': ('manet',),
'manetene': ('manet',),
'maneter': ('manet',),
'mangan': ('mangan',),
'mangana': ('mangan',),
'manganene': ('mangan',),
'manganet': ('mangan',),
'mangegifta': ('mangegifte',),
'mangegifte': ('mangegifte',),
'mangegiftene': ('mangegifte',),
'mangegifter': ('mangegifte',),
'mangegiftet': ('mangegifte',),
'mangekamp': ('mangekamp',),
'mangekampen': ('mangekamp',),
'mangekampene': ('mangekamp',),
'mangekamper': ('mangekamp',),
'mangekant': ('mangekant',),
'mangekanten': ('mangekant',),
'mangekantene': ('mangekant',),
'mangekanter': ('mangekant',),
'mangekjemper': ('mangekjemper',),
'mangekjempere': ('mangekjemper',),
'mangekjemperen': ('mangekjemper',),
'mangekjemperer': ('mangekjemper',),
'mangekjemperne': ('mangekjemper',),
'mangel': ('mangel',),
'mangelen': ('mangel',),
'manglene': ('mangel',),
'mangler': ('mangel',),
'mangellapp': ('mangellapp',),
'mangellappen': ('mangellapp',),
'mangellappene': ('mangellapp',),
'mangellapper': ('mangellapp',),
'mangelsjukdom': ('mangelsjukdom',),
'mangelsjukdommen': ('mangelsjukdom',),
'mangelsjukdommene': ('mangelsjukdom',),
'mangelsjukdommer': ('mangelsjukdom',),
'mangelsykdom': ('mangelsykdom',),
'mangelsykdommen': ('mangelsykdom',),
'mangelsykdommene': ('mangelsykdom',),
'mangelsykdommer': ('mangelsykdom',),
'mangelvara': ('mangelvare',),
'mangelvare': ('mangelvare',),
'mangelvaren': ('mangelvare',),
'mangelvarene': ('mangelvare',),
'mangelvarer': ('mangelvare',),
'mangemillionær': ('mangemillionær',),
'mangemillionæren': ('mangemillionær',),
'mangemillionærene': ('mangemillionær',),
'mangemillionærer': ('mangemillionær',),
'mangfold': ('mangfold',),
'mangfolda': ('mangfold',),
'mangfoldene': ('mangfold',),
'mangfoldet': ('mangfold',),
'mangfoldighet': ('mangfoldighet',),
'mangfoldigheta': ('mangfoldighet',),
'mangfoldigheten': ('mangfoldighet',),
'mangfoldighetene': ('mangfoldighet',),
'mangfoldigheter': ('mangfoldighet',),
'manglebrett': ('manglebrett',),
'manglebretta': ('manglebrett',),
'manglebrettene': ('manglebrett',),
'manglebretter': ('manglebrett',),
'manglebrettet': ('manglebrett',),
'manglestokk': ('manglestokk',),
'manglestokken': ('manglestokk',),
'manglestokkene': ('manglestokk',),
'manglestokker': ('manglestokk',),
'mangletre': ('mangletre',),
'mangletrea': ('mangletre',),
'mangletreet': ('mangletre',),
'mangletrær': ('mangletre',),
'mangletrærne': ('mangletre',),
'mango': ('mango',),
'mangoen': ('mango',),
'mangoene': ('mango',),
'mangoer': ('mango',),
'mangold': ('mangold',),
'mangolden': ('mangold',),
'mangoldene': ('mangold',),
'mangolder': ('mangold',),
'mangotre': ('mangotre',),
'mangotrea': ('mangotre',),
'mangotreet': ('mangotre',),
'mangotrær': ('mangotre',),
'mangotrærne': ('mangotre',),
'mangrove': ('mangrove',),
'mangroven': ('mangrove',),
'mangrovene': ('mangrove',),
'mangrover': ('mangrove',),
'mangroveskog': ('mangroveskog',),
'mangroveskogen': ('mangroveskog',),
'mangroveskogene': ('mangroveskog',),
'mangroveskoger': ('mangroveskog',),
'mani': ('mani',),
'manien': ('mani',),
'maniene': ('mani',),
'manier': ('mani',),
'manifest': ('manifest',),
'manifesta': ('manifest',),
'manifestene': ('manifest',),
'manifester': ('manifest',),
'manifestet': ('manifest',),
'manifestasjon': ('manifestasjon',),
'manifestasjonen': ('manifestasjon',),
'manifestasjonene': ('manifestasjon',),
'manifestasjoner': ('manifestasjon',),
'manifold': ('manifold',),
'manifolden': ('manifold',),
'manifoldene': ('manifold',),
'manifolder': ('manifold',),
'manikeer': ('manikeer',),
'manikeere': ('manikeer',),
'manikeeren': ('manikeer',),
'manikeerer': ('manikeer',),
'manikeerne': ('manikeer',),
'manikeisme': ('manikeisme',),
'manikeismen': ('manikeisme',),
'manikeismene': ('manikeisme',),
'manikeismer': ('manikeisme',),
'maniker': ('maniker',),
'manikere': ('maniker',),
'manikeren': ('maniker',),
'manikerer': ('maniker',),
'manikerne': ('maniker',),
'manikyr': ('manikyr',),
'manikyren': ('manikyr',),
'manikyrene': ('manikyr',),
'manikyrer': ('manikyr',),
'manikyre': ('manikyre',),
'manikyren': ('manikyre',),
'manikyrene': ('manikyre',),
'manikyrer': ('manikyre',),
'manikyrsett': ('manikyrsett',),
'manikyrsetta': ('manikyrsett',),
'manikyrsettene': ('manikyrsett',),
'manikyrsettet': ('manikyrsett',),
'manilahamp': ('manilahamp',),
'manilahampen': ('manilahamp',),
'manilahampene': ('manilahamp',),
'manilahamper': ('manilahamp',),
'manilamøbel': ('manilamøbel',),
'manilamøbelet': ('manilamøbel',),
'manilamøbla': ('manilamøbel',),
'manilamøblene': ('manilamøbel',),
'manilamøbler': ('manilamøbel',),
'manilamøblet': ('manilamøbel',),
'manilarør': ('manilarør',),
'manilarøra': ('manilarør',),
'manilarørene': ('manilarør',),
'manilarøret': ('manilarør',),
'maning': ('maning',),
'maninga': ('maning',),
'maningen': ('maning',),
'maningene': ('maning',),
'maninger': ('maning',),
'maningsrop': ('maningsrop',),
'maningsropa': ('maningsrop',),
'maningsropene': ('maningsrop',),
'maningsropet': ('maningsrop',),
'maniokplanta': ('maniokplante',),
'maniokplante': ('maniokplante',),
'maniokplanten': ('maniokplante',),
'maniokplantene': ('maniokplante',),
'maniokplanter': ('maniokplante',),
'manipulasjon': ('manipulasjon',),
'manipulasjonen': ('manipulasjon',),
'manipulasjonene': ('manipulasjon',),
'manipulasjoner': ('manipulasjon',),
'manipulator': ('manipulator',),
'manipulatoren': ('manipulator',),
'manipulatorene': ('manipulator',),
'manipulatorer': ('manipulator',),
'manke': ('manke',),
'manken': ('manke',),
'mankene': ('manke',),
'manker': ('manke',),
'mankement': ('mankement',),
'mankementa': ('mankement',),
'mankementene': ('mankement',),
'mankementer': ('mankement',),
'mankementet': ('mankement',),
'manko': ('manko',),
'mankoen': ('manko',),
'mankoene': ('manko',),
'mankoer': ('manko',),
'mann': ('mann',),
'mannen': ('mann',),
'menn': ('mann',),
'mennene': ('mann',),
'manna': ('manna',),
'mannaen': ('manna',),
'mannaene': ('manna',),
'mannaer': ('manna',),
'mannaask': ('mannaask',),
'mannaasken': ('mannaask',),
'mannaaskene': ('mannaask',),
'mannaasker': ('mannaask',),
'mannbjørn': ('mannbjørn',),
'mannbjørnen': ('mannbjørn',),
'mannbjørnene': ('mannbjørn',),
'mannbjørner': ('mannbjørn',),
'manndatter': ('manndatter',),
'manndattera': ('manndatter',),
'manndatteren': ('manndatter',),
'manndøtre': ('manndatter',),
'manndøtrene': ('manndatter',),
'manndøtrer': ('manndatter',),
'manndom': ('manndom',),
'manndommen': ('manndom',),
'manndommene': ('manndom',),
'manndommer': ('manndom',),
'manndomsprøva': ('manndomsprøve',),
'manndomsprøve': ('manndomsprøve',),
'manndomsprøven': ('manndomsprøve',),
'manndomsprøvene': ('manndomsprøve',),
'manndomsprøver': ('manndomsprøve',),
'manndomstid': ('manndomstid',),
'manndomstida': ('manndomstid',),
'manndomstiden': ('manndomstid',),
'manndomstidene': ('manndomstid',),
'manndomstider': ('manndomstid',),
'manndomsverk': ('manndomsverk',),
'manndomsverka': ('manndomsverk',),
'manndomsverkene': ('manndomsverk',),
'manndomsverker': ('manndomsverk',),
'manndomsverket': ('manndomsverk',),
'manndotter': ('manndotter',),
'manndottera': ('manndotter',),
'manndotteren': ('manndotter',),
'manndøtre': ('manndotter',),
'manndøtrene': ('manndotter',),
'manndøtrer': ('manndotter',),
'manndrap': ('manndrap',),
'manndrapa': ('manndrap',),
'manndrapene': ('manndrap',),
'manndrapet': ('manndrap',),
'manndraper': ('manndraper',),
'manndrapere': ('manndraper',),
'manndraperen': ('manndraper',),
'manndraperer': ('manndraper',),
'manndraperne': ('manndraper',),
'mannebarn': ('mannebarn',),
'mannebarna': ('mannebarn',),
'mannebarnene': ('mannebarn',),
'mannebarnet': ('mannebarn',),
'mannebein': ('mannebein',),
'mannebeina': ('mannebein',),
'mannebeinene': ('mannebein',),
'mannebeinet': ('mannebein',),
'manneben': ('manneben',),
'mannebena': ('manneben',),
'mannebenene': ('manneben',),
'mannebenet': ('manneben',),
'mannefall': ('mannefall',),
'mannefalla': ('mannefall',),
'mannefallene': ('mannefall',),
'mannefallet': ('mannefall',),
'mannefar': ('mannefar',),
'mannefara': ('mannefar',),
'mannefarene': ('mannefar',),
'mannefaret': ('mannefar',),
'mannekeng': ('mannekeng',),
'mannekengen': ('mannekeng',),
'mannekengene': ('mannekeng',),
'mannekenger': ('mannekeng',),
'mannekengoppvisning': ('mannekengoppvisning',),
'mannekengoppvisninga': ('mannekengoppvisning',),
'mannekengoppvisningen': ('mannekengoppvisning',),
'mannekengoppvisningene': ('mannekengoppvisning',),
'mannekengoppvisninger': ('mannekengoppvisning',),
'mannemål': ('mannemål',),
'mannemåla': ('mannemål',),
'mannemålene': ('mannemål',),
'mannemålet': ('mannemål',),
'mannevett': ('mannevett',),
'mannevetta': ('mannevett',),
'mannevettene': ('mannevett',),
'mannevettet': ('mannevett',),
'manneætt': ('manneætt',),
'manneætta': ('manneætt',),
'manneætten': ('manneætt',),
'manneættene': ('manneætt',),
'manneætter': ('manneætt',),
'mannfolk': ('mannfolk',),
'mannfolka': ('mannfolk',),
'mannfolkene': ('mannfolk',),
'mannfolket': ('mannfolk',),
'mannfolkarbeid': ('mannfolkarbeid',),
'mannfolkarbeida': ('mannfolkarbeid',),
'mannfolkarbeidene': ('mannfolkarbeid',),
'mannfolkarbeider': ('mannfolkarbeid',),
'mannfolkarbeidet': ('mannfolkarbeid',),
'mannfolkblad': ('mannfolkblad',),
'mannfolkblada': ('mannfolkblad',),
'mannfolkbladene': ('mannfolkblad',),
'mannfolkblader': ('mannfolkblad',),
'mannfolkbladet': ('mannfolkblad',),
'mannfolkklær': ('mannfolkklær',),
'mannfolkklærne': ('mannfolkklær',),
'mannfolksida': ('mannfolkside',),
'mannfolkside': ('mannfolkside',),
'mannfolksiden': ('mannfolkside',),
'mannfolksidene': ('mannfolkside',),
'mannfolksider': ('mannfolkside',),
'manngard': ('manngard',),
'manngarden': ('manngard',),
'manngardene': ('manngard',),
'manngarder': ('manngard',),
'mannjamning': ('mannjamning',),
'mannjamninga': ('mannjamning',),
'mannjamningen': ('mannjamning',),
'mannjamningene': ('mannjamning',),
'mannjamninger': ('mannjamning',),
'mannjevning': ('mannjevning',),
'mannjevninga': ('mannjevning',),
'mannjevningen': ('mannjevning',),
'mannjevningene': ('mannjevning',),
'mannjevninger': ('mannjevning',),
'mannsalder': ('mannsalder',),
'mannsaldere': ('mannsalder',),
'mannsalderen': ('mannsalder',),
'mannsalderer': ('mannsalder',),
'mannsalderne': ('mannsalder',),
'mannsaldre': ('mannsalder',),
'mannsaldrene': ('mannsalder',),
'mannsaldrer': ('mannsalder',),
'mannsdominans': ('mannsdominans',),
'mannsdominansen': ('mannsdominans',),
'mannsdominansene': ('mannsdominans',),
'mannsdominanser': ('mannsdominans',),
'mannskap': ('mannskap',),
'mannskapa': ('mannskap',),
'mannskapene': ('mannskap',),
'mannskaper': ('mannskap',),
'mannskapet': ('mannskap',),
'mannskapsbrakka': ('mannskapsbrakke',),
'mannskapsbrakke': ('mannskapsbrakke',),
'mannskapsbrakken': ('mannskapsbrakke',),
'mannskapsbrakkene': ('mannskapsbrakke',),
'mannskapsbrakker': ('mannskapsbrakke',),
'mannskapslista': ('mannskapsliste',),
'mannskapsliste': ('mannskapsliste',),
'mannskapslisten': ('mannskapsliste',),
'mannskapslistene': ('mannskapsliste',),
'mannskapslister': ('mannskapsliste',),
'mannskapslugar': ('mannskapslugar',),
'mannskapslugaren': ('mannskapslugar',),
'mannskapslugarene': ('mannskapslugar',),
'mannskapslugarer': ('mannskapslugar',),
'mannskapsstyrke': ('mannskapsstyrke',),
'mannskapsstyrken': ('mannskapsstyrke',),
'mannskapsstyrkene': ('mannskapsstyrke',),
'mannskapsstyrker': ('mannskapsstyrke',),
'mannskor': ('mannskor',),
'mannskora': ('mannskor',),
'mannskorene': ('mannskor',),
'mannskoret': ('mannskor',),
'mannsling': ('mannsling',),
'mannslingen': ('mannsling',),
'mannslingene': ('mannsling',),
'mannslinger': ('mannsling',),
'mannslinja': ('mannslinje',),
'mannslinje': ('mannslinje',),
'mannslinjen': ('mannslinje',),
'mannslinjene': ('mannslinje',),
'mannslinjer': ('mannslinje',),
'mannslott': ('mannslott',),
'mannslotten': ('mannslott',),
'mannslottene': ('mannslott',),
'mannslotter': ('mannslott',),
'mannsmot': ('mannsmot',),
'mannsmota': ('mannsmot',),
'mannsmotene': ('mannsmot',),
'mannsmotet': ('mannsmot',),
'mannsnavn': ('mannsnavn',),
'mannsnavna': ('mannsnavn',),
'mannsnavnene': ('mannsnavn',),
'mannsnavnet': ('mannsnavn',),
'mannsperson': ('mannsperson',),
'mannspersonen': ('mannsperson',),
'mannspersonene': ('mannsperson',),
'mannspersoner': ('mannsperson',),
'mannsrolla': ('mannsrolle',),
'mannsrolle': ('mannsrolle',),
'mannsrollen': ('mannsrolle',),
'mannsrollene': ('mannsrolle',),
'mannsroller': ('mannsrolle',),
'mannsrøst': ('mannsrøst',),
'mannsrøsta': ('mannsrøst',),
'mannsrøsten': ('mannsrøst',),
'mannsrøstene': ('mannsrøst',),
'mannsrøster': ('mannsrøst',),
'mannssamfunn': ('mannssamfunn',),
'mannssamfunna': ('mannssamfunn',),
'mannssamfunnene': ('mannssamfunn',),
'mannssamfunnet': ('mannssamfunn',),
'mannssang': ('mannssang',),
'mannssangen': ('mannssang',),
'mannssangene': ('mannssang',),
'mannssanger': ('mannssang',),
'mannssida': ('mannsside',),
'mannsside': ('mannsside',),
'mannssiden': ('mannsside',),
'mannssidene': ('mannsside',),
'mannssider': ('mannsside',),
'mannssjåvinisme': ('mannssjåvinisme',),
'mannssjåvinismen': ('mannssjåvinisme',),
'mannssjåvinismene': ('mannssjåvinisme',),
'mannssjåvinismer': ('mannssjåvinisme',),
'mannssjåvinist': ('mannssjåvinist',),
'mannssjåvinisten': ('mannssjåvinist',),
'mannssjåvinistene': ('mannssjåvinist',),
'mannssjåvinister': ('mannssjåvinist',),
'mannsstemme': ('mannsstemme',),
'mannsstemmen': ('mannsstemme',),
'mannsstemmene': ('mannsstemme',),
'mannsstemmer': ('mannsstemme',),
'mannstukt': ('mannstukt',),
'mannstukta': ('mannstukt',),
'mannstukten': ('mannstukt',),
'mannstuktene': ('mannstukt',),
'mannstukter': ('mannstukt',),
'mannsverk': ('mannsverk',),
'mannsverka': ('mannsverk',),
'mannsverkene': ('mannsverk',),
'mannsverket': ('mannsverk',),
'mannsyrka': ('mannsyrke',),
'mannsyrke': ('mannsyrke',),
'mannsyrkene': ('mannsyrke',),
'mannsyrker': ('mannsyrke',),
'mannsyrket': ('mannsyrke',),
'manntal': ('manntal',),
'manntala': ('manntal',),
'manntalene': ('manntal',),
'manntalet': ('manntal',),
'manntall': ('manntall',),
'manntalla': ('manntall',),
'manntallene': ('manntall',),
'manntallet': ('manntall',),
'manntallsfører': ('manntallsfører',),
'manntallsførere': ('manntallsfører',),
'manntallsføreren': ('manntallsfører',),
'manntallsførerer': ('manntallsfører',),
'manntallsførerne': ('manntallsfører',),
'manntallslista': ('manntallsliste',),
'manntallsliste': ('manntallsliste',),
'manntallslisten': ('manntallsliste',),
'manntallslistene': ('manntallsliste',),
'manntallslister': ('manntallsliste',),
'manntalsfører': ('manntalsfører',),
'manntalsførere': ('manntalsfører',),
'manntalsføreren': ('manntalsfører',),
'manntalsførerer': ('manntalsfører',),
'manntalsførerne': ('manntalsfører',),
'manntalslista': ('manntalsliste',),
'manntalsliste': ('manntalsliste',),
'manntalslisten': ('manntalsliste',),
'manntalslistene': ('manntalsliste',),
'manntalslister': ('manntalsliste',),
'manometer': ('manometer',),
'manometeret': ('manometer',),
'manometra': ('manometer',),
'manometre': ('manometer',),
'manometrene': ('manometer',),
'manometret': ('manometer',),
'manometertrykk': ('manometertrykk',),
'manometertrykka': ('manometertrykk',),
'manometertrykkene': ('manometertrykk',),
'manometertrykket': ('manometertrykk',),
'mansard': ('mansard',),
'mansarden': ('mansard',),
'mansardene': ('mansard',),
'mansarder': ('mansard',),
'mansardtak': ('mansardtak',),
'mansardtaka': ('mansardtak',),
'mansardtakene': ('mansardtak',),
'mansardtaket': ('mansardtak',),
'mansjett': ('mansjett',),
'mansjetten': ('mansjett',),
'mansjettene': ('mansjett',),
'mansjetter': ('mansjett',),
'mansjettknapp': ('mansjettknapp',),
'mansjettknappen': ('mansjettknapp',),
'mansjettknappene': ('mansjettknapp',),
'mansjettknapper': ('mansjettknapp',),
'mantel': ('mantel',),
'mantelen': ('mantel',),
'mantlene': ('mantel',),
'mantler': ('mantel',),
'mantelkrok': ('mantelkrok',),
'mantelkroken': ('mantelkrok',),
'mantelkrokene': ('mantelkrok',),
'mantelkroker': ('mantelkrok',),
'mantikk': ('mantikk',),
'mantikken': ('mantikk',),
'mantikkene': ('mantikk',),
'mantikker': ('mantikk',),
'mantilje': ('mantilje',),
'mantiljen': ('mantilje',),
'mantiljene': ('mantilje',),
'mantiljer': ('mantilje',),
'mantisse': ('mantisse',),
'mantissen': ('mantisse',),
'mantissene': ('mantisse',),
'mantisser': ('mantisse',),
'mantra': ('mantra',),
'mantraene': ('mantra',),
'mantraer': ('mantra',),
'mantraet': ('mantra',),
'mantrameditasjon': ('mantrameditasjon',),
'mantrameditasjonen': ('mantrameditasjon',),
'mantrameditasjonene': ('mantrameditasjon',),
'mantrameditasjoner': ('mantrameditasjon',),
'manual': ('manual',),
'manualen': ('manual',),
'manualene': ('manual',),
'manualer': ('manual',),
'manuduksjon': ('manuduksjon',),
'manuduksjonen': ('manuduksjon',),
'manuduksjonene': ('manuduksjon',),
'manuduksjoner': ('manuduksjon',),
'manuduktør': ('manuduktør',),
'manuduktøren': ('manuduktør',),
'manuduktørene': ('manuduktør',),
'manuduktører': ('manuduktør',),
'manufaktur': ('manufaktur',),
'manufakturen': ('manufaktur',),
'manufakturene': ('manufaktur',),
'manufakturer': ('manufaktur',),
'manufakturforretning': ('manufakturforretning',),
'manufakturforretninga': ('manufakturforretning',),
'manufakturforretningen': ('manufakturforretning',),
'manufakturforretningene': ('manufakturforretning',),
'manufakturforretninger': ('manufakturforretning',),
'manufakturhandel': ('manufakturhandel',),
'manufakturhandelen': ('manufakturhandel',),
'manufakturhandlene': ('manufakturhandel',),
'manufakturhandler': ('manufakturhandel',),
'manufakturhandler': ('manufakturhandler',),
'manufakturhandlere': ('manufakturhandler',),
'manufakturhandleren': ('manufakturhandler',),
'manufakturhandlerer': ('manufakturhandler',),
'manufakturhandlerne': ('manufakturhandler',),
'manufakturvara': ('manufakturvare',),
'manufakturvare': ('manufakturvare',),
'manufakturvaren': ('manufakturvare',),
'manufakturvarene': ('manufakturvare',),
'manufakturvarer': ('manufakturvare',),
'manus': ('manus',),
'manusa': ('manus',),
'manusene': ('manus',),
'manuser': ('manus',),
'manuset': ('manus',),
'manuskript': ('manuskript',),
'manuskripta': ('manuskript',),
'manuskriptene': ('manuskript',),
'manuskripter': ('manuskript',),
'manuskriptet': ('manuskript',),
'manx': ('manx',),
'manøver': ('manøver',),
'manøvere': ('manøver',),
'manøveren': ('manøver',),
'manøverne': ('manøver',),
'manøvre': ('manøver',),
'manøvrene': ('manøver',),
'manøvrer': ('manøver',),
'maoisme': ('maoisme',),
'maoismen': ('maoisme',),
'maoismene': ('maoisme',),
'maoismer': ('maoisme',),
'maoist': ('maoist',),
'maoisten': ('maoist',),
'maoistene': ('maoist',),
'maoister': ('maoist',),
'mappa': ('mappe',),
'mappe': ('mappe',),
'mappen': ('mappe',),
'mappene': ('mappe',),
'mapper': ('mappe',),
'mapuche': ('mapuche',),
'maquisard': ('maquisard',),
'maquisarden': ('maquisard',),
'maquisardene': ('maquisard',),
'maquisarder': ('maquisard',),
'marabu': ('marabu',),
'marabuen': ('marabu',),
'marabuene': ('marabu',),
'marabuer': ('marabu',),
'maracas': ('maracas',),
'maracasen': ('maracas',),
'maracasene': ('maracas',),
'maracaser': ('maracas',),
'maraton': ('maraton',),
'maratonen': ('maraton',),
'maratonene': ('maraton',),
'maratoner': ('maraton',),
'maratondebatt': ('maratondebatt',),
'maratondebatten': ('maratondebatt',),
'maratondebattene': ('maratondebatt',),
'maratondebatter': ('maratondebatt',),
'maratoner': ('maratoner',),
'maratonere': ('maratoner',),
'maratoneren': ('maratoner',),
'maratonerer': ('maratoner',),
'maratonerne': ('maratoner',),
'maratonløp': ('maratonløp',),
'maratonløpa': ('maratonløp',),
'maratonløpene': ('maratonløp',),
'maratonløpet': ('maratonløp',),
'maratonløper': ('maratonløper',),
'maratonløpere': ('maratonløper',),
'maratonløperen': ('maratonløper',),
'maratonløperer': ('maratonløper',),
'maratonløperne': ('maratonløper',),
'maratonmøta': ('maratonmøte',),
'maratonmøte': ('maratonmøte',),
'maratonmøtene': ('maratonmøte',),
'maratonmøter': ('maratonmøte',),
'maratonmøtet': ('maratonmøte',),
'marbakke': ('marbakke',),
'marbakken': ('marbakke',),
'marbakkene': ('marbakke',),
'marbakker': ('marbakke',),
'mara': ('mare',),
'mare': ('mare',),
'maren': ('mare',),
'marene': ('mare',),
'marer': ('mare',),
'maredrøm': ('maredrøm',),
'maredrømmen': ('maredrøm',),
'maredrømmene': ('maredrøm',),
'maredrømmer': ('maredrøm',),
'mareflyndra': ('mareflyndre',),
'mareflyndre': ('mareflyndre',),
'mareflyndren': ('mareflyndre',),
'mareflyndrene': ('mareflyndre',),
'mareflyndrer': ('mareflyndre',),
'marehalm': ('marehalm',),
'marehalmen': ('marehalm',),
'marehalmene': ('marehalm',),
'marehalmer': ('marehalm',),
'marekatt': ('marekatt',),
'marekatten': ('marekatt',),
'marekattene': ('marekatt',),
'marekatter': ('marekatt',),
'marengs': ('marengs',),
'marengsen': ('marengs',),
'marengsene': ('marengs',),
'marengser': ('marengs',),
'mareritt': ('mareritt',),
'mareritta': ('mareritt',),
'marerittene': ('mareritt',),
'marerittet': ('mareritt',),
'marflo': ('marflo',),
'marfloa': ('marflo',),
'marfloen': ('marflo',),
'marfloene': ('marflo',),
'marfloer': ('marflo',),
'marg': ('marg',),
'margen': ('marg',),
'margene': ('marg',),
'marger': ('marg',),
'marg': ('marg',),
'margen': ('marg',),
'margene': ('marg',),
'marger': ('marg',),
'marg': ('marg',),
'margen': ('marg',),
'margene': ('marg',),
'marger': ('marg',),
'margarin': ('margarin',),
'margarinen': ('margarin',),
'margarinene': ('margarin',),
'margariner': ('margarin',),
'margbein': ('margbein',),
'margbeina': ('margbein',),
'margbeinene': ('margbein',),
'margbeinet': ('margbein',),
'margbein': ('margbein',),
'margbeina': ('margbein',),
'margbeinene': ('margbein',),
'margbeinet': ('margbein',),
'margben': ('margben',),
'margbena': ('margben',),
'margbenene': ('margben',),
'margbenet': ('margben',),
'margben': ('margben',),
'margbena': ('margben',),
'margbenene': ('margben',),
'margbenet': ('margben',),
'margeritt': ('margeritt',),
'margeritten': ('margeritt',),
'margerittene': ('margeritt',),
'margeritter': ('margeritt',),
'margin': ('margin',),
'marginen': ('margin',),
'marginene': ('margin',),
'marginer': ('margin',),
'marginalgruppa': ('marginalgruppe',),
'marginalgruppe': ('marginalgruppe',),
'marginalgruppen': ('marginalgruppe',),
'marginalgruppene': ('marginalgruppe',),
'marginalgrupper': ('marginalgruppe',),
'marginalnote': ('marginalnote',),
'marginalnoten': ('marginalnote',),
'marginalnotene': ('marginalnote',),
'marginalnoter': ('marginalnote',),
'marginalskatt': ('marginalskatt',),
'marginalskatten': ('marginalskatt',),
'marginalskattene': ('marginalskatt',),
'marginalskatter': ('marginalskatt',),
'margpostei': ('margpostei',),
'margposteien': ('margpostei',),
'margposteiene': ('margpostei',),
'margposteier': ('margpostei',),
'margpostei': ('margpostei',),
'margposteien': ('margpostei',),
'margposteiene': ('margpostei',),
'margposteier': ('margpostei',),
'mariabilda': ('mariabilde',),
'mariabilde': ('mariabilde',),
'mariabildene': ('mariabilde',),
'mariabilder': ('mariabilde',),
'mariabildet': ('mariabilde',),
'mariadyrkelse': ('mariadyrkelse',),
'mariadyrkelsen': ('mariadyrkelse',),
'mariadyrkelsene': ('mariadyrkelse',),
'mariadyrkelser': ('mariadyrkelse',),
'mariadyrking': ('mariadyrking',),
'mariadyrkinga': ('mariadyrking',),
'mariadyrkingen': ('mariadyrking',),
'mariadyrkingene': ('mariadyrking',),
'mariadyrkinger': ('mariadyrking',),
'mariaflyfly': ('mariaflyfly',),
'mariaflyflyen': ('mariaflyfly',),
'mariaflyflyene': ('mariaflyfly',),
'mariaflyflyer': ('mariaflyfly',),
'mariagullsko': ('mariagullsko',),
'mariagullskoa': ('mariagullsko',),
'mariagullskoen': ('mariagullsko',),
'mariagullskoene': ('mariagullsko',),
'mariagullskor': ('mariagullsko',),
'mariagullskorne': ('mariagullsko',),
'marianøkleband': ('marianøkleband',),
'marianøklebanden': ('marianøkleband',),
'marianøklebandene': ('marianøkleband',),
'marianøkleblom': ('marianøkleblom',),
'marianøkleblommen': ('marianøkleblom',),
'marianøkleblommene': ('marianøkleblom',),
'marianøkleblommer': ('marianøkleblom',),
'marianøklebånd': ('marianøklebånd',),
'marianøklebånden': ('marianøklebånd',),
'marianøklebåndene': ('marianøklebånd',),
'marifly': ('marifly',),
'mariflya': ('marifly',),
'mariflyen': ('marifly',),
'mariflyene': ('marifly',),
'mariflyer': ('marifly',),
'marihand': ('marihand',),
'marihanda': ('marihand',),
'marihanden': ('marihand',),
'marihandene': ('marihand',),
'marihander': ('marihand',),
'marihandfamilie': ('marihandfamilie',),
'marihandfamilien': ('marihandfamilie',),
'marihandfamiliene': ('marihandfamilie',),
'marihandfamilier': ('marihandfamilie',),
'marihuana': ('marihuana',),
'marihuanaen': ('marihuana',),
'marihuanaene': ('marihuana',),
'marihuanaer': ('marihuana',),
'marihuanasigarett': ('marihuanasigarett',),
'marihuanasigaretten': ('marihuanasigarett',),
'marihuanasigarettene': ('marihuanasigarett',),
'marihuanasigaretter': ('marihuanasigarett',),
'marihøna': ('marihøne',),
'marihøne': ('marihøne',),
'marihønen': ('marihøne',),
'marihønene': ('marihøne',),
'marihøner': ('marihøne',),
'marikåpa': ('marikåpe',),
'marikåpe': ('marikåpe',),
'marikåpen': ('marikåpe',),
'marikåpene': ('marikåpe',),
'marikåper': ('marikåpe',),
'marimba': ('marimba',),
'marimbaen': ('marimba',),
'marimbaene': ('marimba',),
'marimbaer': ('marimba',),
'marimess': ('marimess',),
'marimesse': ('marimesse',),
'marimjella': ('marimjelle',),
'marimjelle': ('marimjelle',),
'marimjellen': ('marimjelle',),
'marimjellene': ('marimjelle',),
'marimjeller': ('marimjelle',),
'marina': ('marina',),
'marinaen': ('marina',),
'marinaene': ('marina',),
'marinaer': ('marina',),
'marinade': ('marinade',),
'marinaden': ('marinade',),
'marinadene': ('marinade',),
'marinader': ('marinade',),
'marinbiolog': ('marinbiolog',),
'marinbiologen': ('marinbiolog',),
'marinbiologene': ('marinbiolog',),
'marinbiologer': ('marinbiolog',),
'marinbiologi': ('marinbiologi',),
'marinbiologien': ('marinbiologi',),
'marinbiologiene': ('marinbiologi',),
'marinbiologier': ('marinbiologi',),
'marine': ('marine',),
'marinen': ('marine',),
'marinene': ('marine',),
'mariner': ('marine',),
'marinebase': ('marinebase',),
'marinebasen': ('marinebase',),
'marinebasene': ('marinebase',),
'marinebaser': ('marinebase',),
'marinegast': ('marinegast',),
'marinegasten': ('marinegast',),
'marinegastene': ('marinegast',),
'marinegaster': ('marinegast',),
'marineinfanteri': ('marineinfanteri',),
'marineinfanteria': ('marineinfanteri',),
'marineinfanteriene': ('marineinfanteri',),
'marineinfanterier': ('marineinfanteri',),
'marineinfanteriet': ('marineinfanteri',),
'marinemaler': ('marinemaler',),
'marinemalere': ('marinemaler',),
'marinemaleren': ('marinemaler',),
'marinemalerer': ('marinemaler',),
'marinemalerne': ('marinemaler',),
'marineoffiser': ('marineoffiser',),
'marineoffiseren': ('marineoffiser',),
'marineoffiserene': ('marineoffiser',),
'marineoffiserer': ('marineoffiser',),
'marinesoldat': ('marinesoldat',),
'marinesoldaten': ('marinesoldat',),
'marinesoldatene': ('marinesoldat',),
'marinesoldater': ('marinesoldat',),
'marinøkkel': ('marinøkkel',),
'marinøkkelen': ('marinøkkel',),
'marinøklene': ('marinøkkel',),
'marinøkler': ('marinøkkel',),
'marinøkleband': ('marinøkleband',),
'marinøklebanden': ('marinøkleband',),
'marinøklebandene': ('marinøkleband',),
'marinøkleband': ('marinøkleband',),
'marinøklebanden': ('marinøkleband',),
'marinøklebandene': ('marinøkleband',),
'marinøkleblom': ('marinøkleblom',),
'marinøkleblommen': ('marinøkleblom',),
'marinøkleblommene': ('marinøkleblom',),
'marinøkleblommer': ('marinøkleblom',),
'marinøklebånd': ('marinøklebånd',),
'marinøklebånden': ('marinøklebånd',),
'marinøklebåndene': ('marinøklebånd',),
'marinøklebånd': ('marinøklebånd',),
'marinøklebånden': ('marinøklebånd',),
'marinøklebåndene': ('marinøklebånd',),
'marionett': ('marionett',),
'marionetten': ('marionett',),
'marionettene': ('marionett',),
'marionetter': ('marionett',),
'marionett-teater': ('marionett-teater',),
'marionett-teateret': ('marionett-teater',),
'marionett-teatra': ('marionett-teater',),
'marionett-teatre': ('marionett-teater',),
'marionett-teatrene': ('marionett-teater',),
'marionett-teatret': ('marionett-teater',),
'marionetteater': ('marionetteater',),
'marionetteateret': ('marionetteater',),
'marionetteatra': ('marionetteater',),
'marionetteatre': ('marionetteater',),
'marionetteatrene': ('marionetteater',),
'marionetteatret': ('marionetteater',),
'marionettregjering': ('marionettregjering',),
'marionettregjeringa': ('marionettregjering',),
'marionettregjeringen': ('marionettregjering',),
'marionettregjeringene': ('marionettregjering',),
'marionettregjeringer': ('marionettregjering',),
'mark': ('mark',),
'marken': ('mark',),
'markene': ('mark',),
'marker': ('mark',),
'markadrakt': ('markadrakt',),
'markadrakta': ('markadrakt',),
'markadrakten': ('markadrakt',),
'markadraktene': ('markadrakt',),
'markadrakter': ('markadrakt',),
'markadress': ('markadress',),
'markadressen': ('markadress',),
'markadressene': ('markadress',),
'markadresser': ('markadress',),
'markblomst': ('markblomst',),
'markblomsten': ('markblomst',),
'markblomstene': ('markblomst',),
'markblomster': ('markblomst',),
'markebol': ('markebol',),
'markebola': ('markebol',),
'markebolene': ('markebol',),
'markebolet': ('markebol',),
'marked': ('marked',),
'markeda': ('marked',),
'markedene': ('marked',),
'markeder': ('marked',),
'markedet': ('marked',),
'markedsanalysa': ('markedsanalyse',),
'markedsanalyse': ('markedsanalyse',),
'markedsanalysen': ('markedsanalyse',),
'markedsanalysene': ('markedsanalyse',),
'markedsanalyser': ('markedsanalyse',),
'markedsdag': ('markedsdag',),
'markedsdagen': ('markedsdag',),
'markedsdagene': ('markedsdag',),
'markedsdager': ('markedsdag',),
'markedsfører': ('markedsfører',),
'markedsførere': ('markedsfører',),
'markedsføreren': ('markedsfører',),
'markedsførerer': ('markedsfører',),
'markedsførerne': ('markedsfører',),
'markedsføring': ('markedsføring',),
'markedsføringa': ('markedsføring',),
'markedsføringen': ('markedsføring',),
'markedsføringene': ('markedsføring',),
'markedsføringer': ('markedsføring',),
'markedsmekanisme': ('markedsmekanisme',),
'markedsmekanismen': ('markedsmekanisme',),
'markedsmekanismene': ('markedsmekanisme',),
'markedsmekanismer': ('markedsmekanisme',),
'markedsplass': ('markedsplass',),
'markedsplassen': ('markedsplass',),
'markedsplassene': ('markedsplass',),
'markedsplasser': ('markedsplass',),
'markedspris': ('markedspris',),
'markedsprisen': ('markedspris',),
'markedsprisene': ('markedspris',),
'markedspriser': ('markedspris',),
'markedsregulering': ('markedsregulering',),
'markedsreguleringa': ('markedsregulering',),
'markedsreguleringen': ('markedsregulering',),
'markedsreguleringene': ('markedsregulering',),
'markedsreguleringer': ('markedsregulering',),
'markedsverdi': ('markedsverdi',),
'markedsverdien': ('markedsverdi',),
'markedsverdiene': ('markedsverdi',),
'markedsverdier': ('markedsverdi',),
'markedsøkonomi': ('markedsøkonomi',),
'markedsøkonomien': ('markedsøkonomi',),
'markedsøkonomiene': ('markedsøkonomi',),
'markedsøkonomier': ('markedsøkonomi',),
'marken': ('marken',),
'markenen': ('marken',),
'markenene': ('marken',),
'markener': ('marken',),
'markering': ('markering',),
'markeringa': ('markering',),
'markeringen': ('markering',),
'markeringene': ('markering',),
'markeringer': ('markering',),
'markeringsbehov': ('markeringsbehov',),
'markeringsbehova': ('markeringsbehov',),
'markeringsbehovene': ('markeringsbehov',),
'markeringsbehovet': ('markeringsbehov',),
'markeskjell': ('markeskjell',),
'markeskjella': ('markeskjell',),
'markeskjellene': ('markeskjell',),
'markeskjellet': ('markeskjell',),
'marketenter': ('marketenter',),
'marketentere': ('marketenter',),
'marketenteren': ('marketenter',),
'marketenterer': ('marketenter',),
'marketenterne': ('marketenter',),
'marketenteri': ('marketenteri',),
'marketenteria': ('marketenteri',),
'marketenteriene': ('marketenteri',),
'marketenterier': ('marketenteri',),
'marketenteriet': ('marketenteri',),
'marketenterska': ('marketenterske',),
'marketenterske': ('marketenterske',),
'marketentersken': ('marketenterske',),
'marketenterskene': ('marketenterske',),
'marketentersker': ('marketenterske',),
'markfiol': ('markfiol',),
'markfiolen': ('markfiol',),
'markfiolene': ('markfiol',),
'markfioler': ('markfiol',),
'markgreve': ('markgreve',),
'markgreven': ('markgreve',),
'markgrevene': ('markgreve',),
'markgrever': ('markgreve',),
'marki': ('marki',),
'markien': ('marki',),
'markiene': ('marki',),
'markier': ('marki',),
'markisa': ('markise',),
'markise': ('markise',),
'markisen': ('markise',),
'markisene': ('markise',),
'markiser': ('markise',),
'markisa': ('markise',),
'markise': ('markise',),
'markisen': ('markise',),
'markisene': ('markise',),
'markiser': ('markise',),
'markiseduk': ('markiseduk',),
'markiseduken': ('markiseduk',),
'markisedukene': ('markiseduk',),
'markiseduker': ('markiseduk',),
'markisett': ('markisett',),
'markisetten': ('markisett',),
'markisettene': ('markisett',),
'markisetter': ('markisett',),
'markjordbær': ('markjordbær',),
'markjordbæra': ('markjordbær',),
'markjordbærene': ('markjordbær',),
'markjordbæret': ('markjordbær',),
'markkryper': ('markkryper',),
'markkrypere': ('markkryper',),
'markkryperen': ('markkryper',),
'markkryperer': ('markkryper',),
'markkryperne': ('markkryper',),
'markmus': ('markmus',),
'markmusa': ('markmus',),
'markmusen': ('markmus',),
'markmusene': ('markmus',),
'marknad': ('marknad',),
'marknaden': ('marknad',),
'marknadene': ('marknad',),
'marknader': ('marknad',),
'marknadsanalysa': ('marknadsanalyse',),
'marknadsanalyse': ('marknadsanalyse',),
'marknadsanalysen': ('marknadsanalyse',),
'marknadsanalysene': ('marknadsanalyse',),
'marknadsanalyser': ('marknadsanalyse',),
'marknadsdag': ('marknadsdag',),
'marknadsdagen': ('marknadsdag',),
'marknadsdagene': ('marknadsdag',),
'marknadsdager': ('marknadsdag',),
'marknadsfører': ('marknadsfører',),
'marknadsførere': ('marknadsfører',),
'marknadsføreren': ('marknadsfører',),
'marknadsførerer': ('marknadsfører',),
'marknadsførerne': ('marknadsfører',),
'marknadsføring': ('marknadsføring',),
'marknadsføringa': ('marknadsføring',),
'marknadsføringen': ('marknadsføring',),
'marknadsføringene': ('marknadsføring',),
'marknadsføringer': ('marknadsføring',),
'marknadsmekanisme': ('marknadsmekanisme',),
'marknadsmekanismen': ('marknadsmekanisme',),
'marknadsmekanismene': ('marknadsmekanisme',),
'marknadsmekanismer': ('marknadsmekanisme',),
'marknadsplass': ('marknadsplass',),
'marknadsplassen': ('marknadsplass',),
'marknadsplassene': ('marknadsplass',),
'marknadsplasser': ('marknadsplass',),
'marknadspris': ('marknadspris',),
'marknadsprisen': ('marknadspris',),
'marknadsprisene': ('marknadspris',),
'marknadspriser': ('marknadspris',),
'marknadsregulering': ('marknadsregulering',),
'marknadsreguleringa': ('marknadsregulering',),
'marknadsreguleringen': ('marknadsregulering',),
'marknadsreguleringene': ('marknadsregulering',),
'marknadsreguleringer': ('marknadsregulering',),
'marknadsverdi': ('marknadsverdi',),
'marknadsverdien': ('marknadsverdi',),
'marknadsverdiene': ('marknadsverdi',),
'marknadsverdier': ('marknadsverdi',),
'marknadsøkonomi': ('marknadsøkonomi',),
'marknadsøkonomien': ('marknadsøkonomi',),
'marknadsøkonomiene': ('marknadsøkonomi',),
'marknadsøkonomier': ('marknadsøkonomi',),
'markskriker': ('markskriker',),
'markskrikere': ('markskriker',),
'markskrikeren': ('markskriker',),
'markskrikerer': ('markskriker',),
'markskrikerne': ('markskriker',),
'markør': ('markør',),
'markøren': ('markør',),
'markørene': ('markør',),
'markører': ('markør',),
'marm': ('marm',),
'marma': ('marm',),
'marmen': ('marm',),
'marmene': ('marm',),
'marmer': ('marm',),
'marmet': ('marm',),
'marmelade': ('marmelade',),
'marmeladen': ('marmelade',),
'marmeladene': ('marmelade',),
'marmelader': ('marmelade',),
'marmor': ('marmor',),
'marmora': ('marmor',),
'marmoren': ('marmor',),
'marmorene': ('marmor',),
'marmorer': ('marmor',),
'marmoret': ('marmor',),
'marmorblokk': ('marmorblokk',),
'marmorblokka': ('marmorblokk',),
'marmorblokken': ('marmorblokk',),
'marmorblokkene': ('marmorblokk',),
'marmorblokker': ('marmorblokk',),
'marmorering': ('marmorering',),
'marmoreringa': ('marmorering',),
'marmoreringen': ('marmorering',),
'marmoreringene': ('marmorering',),
'marmoreringer': ('marmorering',),
'marmorskulptur': ('marmorskulptur',),
'marmorskulpturen': ('marmorskulptur',),
'marmorskulpturene': ('marmorskulptur',),
'marmorskulpturer': ('marmorskulptur',),
'marmortrapp': ('marmortrapp',),
'marmortrappa': ('marmortrapp',),
'marmortrappen': ('marmortrapp',),
'marmortrappene': ('marmortrapp',),
'marmortrapper': ('marmortrapp',),
'marmæle': ('marmæle',),
'marmælen': ('marmæle',),
'marmælene': ('marmæle',),
'marmæler': ('marmæle',),
'marodør': ('marodør',),
'marodøren': ('marodør',),
'marodørene': ('marodør',),
'marodører': ('marodør',),
'marokkaner': ('marokkaner',),
'marokkanere': ('marokkaner',),
'marokkaneren': ('marokkaner',),
'marokkanerer': ('marokkaner',),
'marokkanerne': ('marokkaner',),
'maronitt': ('maronitt',),
'maronitten': ('maronitt',),
'maronittene': ('maronitt',),
'maronitter': ('maronitt',),
'mars': ('mars',),
'marsbeboer': ('marsbeboer',),
'marsbeboere': ('marsbeboer',),
'marsbeboeren': ('marsbeboer',),
'marsbeboerer': ('marsbeboer',),
'marsbeboerne': ('marsbeboer',),
'marsboer': ('marsboer',),
'marsboere': ('marsboer',),
'marsboeren': ('marsboer',),
'marsboerer': ('marsboer',),
'marsboerne': ('marsboer',),
'marsbuer': ('marsbuer',),
'marsbuere': ('marsbuer',),
'marsbueren': ('marsbuer',),
'marsbuerer': ('marsbuer',),
'marsbuerne': ('marsbuer',),
'marsipan': ('marsipan',),
'marsipanen': ('marsipan',),
'marsipanene': ('marsipan',),
'marsipaner': ('marsipan',),
'marsipanbrød': ('marsipanbrød',),
'marsipanbrøda': ('marsipanbrød',),
'marsipanbrødene': ('marsipanbrød',),
'marsipanbrødet': ('marsipanbrød',),
'marsipanegg': ('marsipanegg',),
'marsipanegga': ('marsipanegg',),
'marsipaneggene': ('marsipanegg',),
'marsipanegget': ('marsipanegg',),
'marsipanfyll': ('marsipanfyll',),
'marsipanfylla': ('marsipanfyll',),
'marsipanfyllen': ('marsipanfyll',),
'marsipanfyllene': ('marsipanfyll',),
'marsipanfyller': ('marsipanfyll',),
'marsipanfyllet': ('marsipanfyll',),
'marsipangris': ('marsipangris',),
'marsipangrisen': ('marsipangris',),
'marsipangrisene': ('marsipangris',),
'marsipangriser': ('marsipangris',),
'marsipankaka': ('marsipankake',),
'marsipankake': ('marsipankake',),
'marsipankaken': ('marsipankake',),
'marsipankakene': ('marsipankake',),
'marsipankaker': ('marsipankake',),
'marsipanlokk': ('marsipanlokk',),
'marsipanlokka': ('marsipanlokk',),
'marsipanlokkene': ('marsipanlokk',),
'marsipanlokket': ('marsipanlokk',),
'marsj': ('marsj',),
'marsjen': ('marsj',),
'marsjene': ('marsj',),
'marsjer': ('marsj',),
'marsjall': ('marsjall',),
'marsjallen': ('marsjall',),
'marsjallene': ('marsjall',),
'marsjaller': ('marsjall',),
'marsjallstav': ('marsjallstav',),
'marsjallstaven': ('marsjallstav',),
'marsjallstavene': ('marsjallstav',),
'marsjallstaver': ('marsjallstav',),
'marsjandisebutikk': ('marsjandisebutikk',),
'marsjandisebutikken': ('marsjandisebutikk',),
'marsjandisebutikkene': ('marsjandisebutikk',),
'marsjandisebutikker': ('marsjandisebutikk',),
'marsjandiseforretning': ('marsjandiseforretning',),
'marsjandiseforretninga': ('marsjandiseforretning',),
'marsjandiseforretningen': ('marsjandiseforretning',),
'marsjandiseforretningene': ('marsjandiseforretning',),
'marsjandiseforretninger': ('marsjandiseforretning',),
'marsjandisehandel': ('marsjandisehandel',),
'marsjandisehandelen': ('marsjandisehandel',),
'marsjandisehandlene': ('marsjandisehandel',),
'marsjandisehandler': ('marsjandisehandel',),
'marsjandiser': ('marsjandiser',),
'marsjandisere': ('marsjandiser',),
'marsjandiseren': ('marsjandiser',),
'marsjandiserer': ('marsjandiser',),
'marsjandiserne': ('marsjandiser',),
'marsjfart': ('marsjfart',),
'marsjfarten': ('marsjfart',),
'marsjfartene': ('marsjfart',),
'marsjfarter': ('marsjfart',),
'marsjordre': ('marsjordre',),
'marsjordren': ('marsjordre',),
'marsjordrene': ('marsjordre',),
'marsjordrer': ('marsjordre',),
'marsjtakt': ('marsjtakt',),
'marsjtakta': ('marsjtakt',),
'marsjtakten': ('marsjtakt',),
'marsjtaktene': ('marsjtakt',),
'marsjtakter': ('marsjtakt',),
'marsk': ('marsk',),
'marsken': ('marsk',),
'marskene': ('marsk',),
'marsker': ('marsk',),
'marskalk': ('marskalk',),
'marskalken': ('marskalk',),
'marskalkene': ('marskalk',),
'marskalker': ('marskalk',),
'marskalkstav': ('marskalkstav',),
'marskalkstaven': ('marskalkstav',),
'marskalkstavene': ('marskalkstav',),
'marskalkstaver': ('marskalkstav',),
'marskland': ('marskland',),
'marsklanda': ('marskland',),
'marsklandene': ('marskland',),
'marsklandet': ('marskland',),
'marsvin': ('marsvin',),
'marsvina': ('marsvin',),
'marsvinene': ('marsvin',),
'marsvinet': ('marsvin',),
'martyr': ('martyr',),
'martyren': ('martyr',),
'martyrene': ('martyr',),
'martyrer': ('martyr',),
'martyrdød': ('martyrdød',),
'martyrdøden': ('martyrdød',),
'martyrdødene': ('martyrdød',),
'martyrdøder': ('martyrdød',),
'martyrglorie': ('martyrglorie',),
'martyrglorien': ('martyrglorie',),
'martyrgloriene': ('martyrglorie',),
'martyrglorier': ('martyrglorie',),
'martyria': ('martyrium',),
'martyriene': ('martyrium',),
'martyrier': ('martyrium',),
'martyriet': ('martyrium',),
'martyrium': ('martyrium',),
'martyrmina': ('martyrmine',),
'martyrmine': ('martyrmine',),
'martyrminen': ('martyrmine',),
'martyrminene': ('martyrmine',),
'martyrminer': ('martyrmine',),
'marulk': ('marulk',),
'marulken': ('marulk',),
'marulkene': ('marulk',),
'marulker': ('marulk',),
'marulka': ('marulke',),
'marulke': ('marulke',),
'marulken': ('marulke',),
'marulkene': ('marulke',),
'marulker': ('marulke',),
'marxisme': ('marxisme',),
'marxismen': ('marxisme',),
'marxismene': ('marxisme',),
'marxismer': ('marxisme',),
'marxisme-leninisme': ('marxisme-leninisme',),
'marxisme-leninismen': ('marxisme-leninisme',),
'marxisme-leninismene': ('marxisme-leninisme',),
'marxisme-leninismer': ('marxisme-leninisme',),
'marxist': ('marxist',),
'marxisten': ('marxist',),
'marxistene': ('marxist',),
'marxister': ('marxist',),
'marxist-leninist': ('marxist-leninist',),
'marxist-leninisten': ('marxist-leninist',),
'marxist-leninistene': ('marxist-leninist',),
'marxist-leninister': ('marxist-leninist',),
'mas': ('mas',),
'masa': ('mas',),
'masene': ('mas',),
'maset': ('mas',),
'mas': ('mas',),
'masa': ('mas',),
'masene': ('mas',),
'maset': ('mas',),
'masai': ('masai',),
'masaien': ('masai',),
'masaiene': ('masai',),
'masaier': ('masai',),
'masekopp': ('masekopp',),
'masekoppen': ('masekopp',),
'masekoppene': ('masekopp',),
'masekopper': ('masekopp',),
'maser': ('maser',),
'masere': ('maser',),
'maseren': ('maser',),
'maserer': ('maser',),
'maserne': ('maser',),
'mask': ('mask',),
'maska': ('mask',),
'masken': ('mask',),
'maskene': ('mask',),
'masker': ('mask',),
'masket': ('mask',),
'mask': ('mask',),
'maska': ('mask',),
'masken': ('mask',),
'maskene': ('mask',),
'masker': ('mask',),
'masket': ('mask',),
'mask': ('mask',),
'maskara': ('maskara',),
'maskaraen': ('maskara',),
'maskaraene': ('maskara',),
'maskaraer': ('maskara',),
'maska': ('maske',),
'maske': ('maske',),
'masken': ('maske',),
'maskene': ('maske',),
'masker': ('maske',),
'maska': ('maske',),
'maske': ('maske',),
'masken': ('maske',),
'maskene': ('maske',),
'masker': ('maske',),
'maskeball': ('maskeball',),
'maskeballa': ('maskeball',),
'maskeballene': ('maskeball',),
'maskeballer': ('maskeball',),
'maskeballet': ('maskeball',),
'maskepi': ('maskepi',),
'maskepia': ('maskepi',),
'maskepiene': ('maskepi',),
'maskepiet': ('maskepi',),
'maskerade': ('maskerade',),
'maskeraden': ('maskerade',),
'maskeradene': ('maskerade',),
'maskerader': ('maskerade',),
'maskeradedrakt': ('maskeradedrakt',),
'maskeradedrakta': ('maskeradedrakt',),
'maskeradedrakten': ('maskeradedrakt',),
'maskeradedraktene': ('maskeradedrakt',),
'maskeradedrakter': ('maskeradedrakt',),
'maskering': ('maskering',),
'maskeringa': ('maskering',),
'maskeringen': ('maskering',),
'maskeringene': ('maskering',),
'maskeringer': ('maskering',),
'maskeringstape': ('maskeringstape',),
'maskeringstapen': ('maskeringstape',),
'maskeringstapene': ('maskeringstape',),
'maskeringstaper': ('maskeringstape',),
'maskeringsteip': ('maskeringsteip',),
'maskeringsteipen': ('maskeringsteip',),
'maskeringsteipene': ('maskeringsteip',),
'maskeringsteiper': ('maskeringsteip',),
'maskestørrelse': ('maskestørrelse',),
'maskestørrelsen': ('maskestørrelse',),
'maskestørrelsene': ('maskestørrelse',),
'maskestørrelser': ('maskestørrelse',),
'masketal': ('masketal',),
'masketala': ('masketal',),
'masketalene': ('masketal',),
'masketalet': ('masketal',),
'masketall': ('masketall',),
'masketalla': ('masketall',),
'masketallene': ('masketall',),
'masketallet': ('masketall',),
'maskevidda': ('maskevidde',),
'maskevidde': ('maskevidde',),
'maskevidden': ('maskevidde',),
'maskeviddene': ('maskevidde',),
'maskevidder': ('maskevidde',),
'maskin': ('maskin',),
'maskina': ('maskin',),
'maskinen': ('maskin',),
'maskinene': ('maskin',),
'maskiner': ('maskin',),
'maskindel': ('maskindel',),
'maskindelen': ('maskindel',),
'maskindelene': ('maskindel',),
'maskindeler': ('maskindel',),
'maskindrift': ('maskindrift',),
'maskindrifta': ('maskindrift',),
'maskindriften': ('maskindrift',),
'maskindriftene': ('maskindrift',),
'maskindrifter': ('maskindrift',),
'maskindur': ('maskindur',),
'maskinduren': ('maskindur',),
'maskindurene': ('maskindur',),
'maskindurer': ('maskindur',),
'maskineri': ('maskineri',),
'maskineria': ('maskineri',),
'maskineriene': ('maskineri',),
'maskinerier': ('maskineri',),
'maskineriet': ('maskineri',),
'maskingevær': ('maskingevær',),
'maskingeværa': ('maskingevær',),
'maskingeværene': ('maskingevær',),
'maskingeværer': ('maskingevær',),
'maskingeværet': ('maskingevær',),
'maskinist': ('maskinist',),
'maskinisten': ('maskinist',),
'maskinistene': ('maskinist',),
'maskinister': ('maskinist',),
'maskinistsertifikat': ('maskinistsertifikat',),
'maskinistsertifikata': ('maskinistsertifikat',),
'maskinistsertifikatene': ('maskinistsertifikat',),
'maskinistsertifikater': ('maskinistsertifikat',),
'maskinistsertifikatet': ('maskinistsertifikat',),
'maskinkjører': ('maskinkjører',),
'maskinkjørere': ('maskinkjører',),
'maskinkjøreren': ('maskinkjører',),
'maskinkjørerer': ('maskinkjører',),
'maskinkjørerne': ('maskinkjører',),
'maskinlæra': ('maskinlære',),
'maskinlære': ('maskinlære',),
'maskinlæren': ('maskinlære',),
'maskinlærene': ('maskinlære',),
'maskinlærer': ('maskinlære',),
'maskinmenneska': ('maskinmenneske',),
'maskinmenneske': ('maskinmenneske',),
'maskinmenneskene': ('maskinmenneske',),
'maskinmennesker': ('maskinmenneske',),
'maskinmennesket': ('maskinmenneske',),
'maskinpapir': ('maskinpapir',),
'maskinpapira': ('maskinpapir',),
'maskinpapirene': ('maskinpapir',),
'maskinpapirer': ('maskinpapir',),
'maskinpapiret': ('maskinpapir',),
'maskinpark': ('maskinpark',),
'maskinparken': ('maskinpark',),
'maskinparkene': ('maskinpark',),
'maskinparker': ('maskinpark',),
'maskinpistol': ('maskinpistol',),
'maskinpistolen': ('maskinpistol',),
'maskinpistolene': ('maskinpistol',),
'maskinpistoler': ('maskinpistol',),
'maskinsetter': ('maskinsetter',),
'maskinsettere': ('maskinsetter',),
'maskinsetteren': ('maskinsetter',),
'maskinsetterer': ('maskinsetter',),
'maskinsetterne': ('maskinsetter',),
'maskinsjef': ('maskinsjef',),
'maskinsjefen': ('maskinsjef',),
'maskinsjefene': ('maskinsjef',),
'maskinsjefer': ('maskinsjef',),
'maskinskade': ('maskinskade',),
'maskinskaden': ('maskinskade',),
'maskinskadene': ('maskinskade',),
'maskinskader': ('maskinskade',),
'maskinslått': ('maskinslått',),
'maskinslåtten': ('maskinslått',),
'maskinslåttene': ('maskinslått',),
'maskinslåtter': ('maskinslått',),
'maskinspråk': ('maskinspråk',),
'maskinspråka': ('maskinspråk',),
'maskinspråkene': ('maskinspråk',),
'maskinspråket': ('maskinspråk',),
'maskinstasjon': ('maskinstasjon',),
'maskinstasjonen': ('maskinstasjon',),
'maskinstasjonene': ('maskinstasjon',),
'maskinstasjoner': ('maskinstasjon',),
'maskinsøm': ('maskinsøm',),
'maskinsømmen': ('maskinsøm',),
'maskinsømmene': ('maskinsøm',),
'maskinsømmer': ('maskinsøm',),
'maskintid': ('maskintid',),
'maskintida': ('maskintid',),
'maskintiden': ('maskintid',),
'maskintidene': ('maskintid',),
'maskintider': ('maskintid',),
'maskinutstyr': ('maskinutstyr',),
'maskinutstyra': ('maskinutstyr',),
'maskinutstyrene': ('maskinutstyr',),
'maskinutstyret': ('maskinutstyr',),
'maskinvara': ('maskinvare',),
'maskinvare': ('maskinvare',),
'maskinvaren': ('maskinvare',),
'maskinvarene': ('maskinvare',),
'maskinvarer': ('maskinvare',),
'maskot': ('maskot',),
'maskoten': ('maskot',),
'maskotene': ('maskot',),
'maskoter': ('maskot',),
'maskulinitet': ('maskulinitet',),
'maskuliniteten': ('maskulinitet',),
'maskulinitetene': ('maskulinitet',),
'maskuliniteter': ('maskulinitet',),
'maskulina': ('maskulinum',),
'maskulinaene': ('maskulinum',),
'maskulinene': ('maskulinum',),
'maskuliner': ('maskulinum',),
'maskulinet': ('maskulinum',),
'maskulinum': ('maskulinum',),
'maskulinumet': ('maskulinum',),
'masochisme': ('masochisme',),
'masochismen': ('masochisme',),
'masochismene': ('masochisme',),
'masochismer': ('masochisme',),
'masochist': ('masochist',),
'masochisten': ('masochist',),
'masochistene': ('masochist',),
'masochister': ('masochist',),
'masomn': ('masomn',),
'masomnen': ('masomn',),
'masomnene': ('masomn',),
'masomner': ('masomn',),
'masovn': ('masovn',),
'masovnen': ('masovn',),
'masovnene': ('masovn',),
'masovner': ('masovn',),
'massakre': ('massakre',),
'massakren': ('massakre',),
'massakrene': ('massakre',),
'massakrer': ('massakre',),
'massasje': ('massasje',),
'massasjen': ('massasje',),
'massasjene': ('massasje',),
'massasjer': ('massasje',),
'massasjebehandling': ('massasjebehandling',),
'massasjebehandlinga': ('massasjebehandling',),
'massasjebehandlingen': ('massasjebehandling',),
'massasjebehandlingene': ('massasjebehandling',),
'massasjebehandlinger': ('massasjebehandling',),
'massasjeinstitutt': ('massasjeinstitutt',),
'massasjeinstitutta': ('massasjeinstitutt',),
'massasjeinstituttene': ('massasjeinstitutt',),
'massasjeinstitutter': ('massasjeinstitutt',),
'massasjeinstituttet': ('massasjeinstitutt',),
'masse': ('masse',),
'massen': ('masse',),
'massene': ('masse',),
'masser': ('masse',),
'massearrestasjon': ('massearrestasjon',),
'massearrestasjonen': ('massearrestasjon',),
'massearrestasjonene': ('massearrestasjon',),
'massearrestasjoner': ('massearrestasjon',),
'masseenhet': ('masseenhet',),
'masseenheta': ('masseenhet',),
'masseenheten': ('masseenhet',),
'masseenhetene': ('masseenhet',),
'masseenheter': ('masseenhet',),
'massefabrikasjon': ('massefabrikasjon',),
'massefabrikasjonen': ('massefabrikasjon',),
'massefabrikasjonene': ('massefabrikasjon',),
'massefabrikasjoner': ('massefabrikasjon',),
'massegods': ('massegods',),
'massegodsa': ('massegods',),
'massegodsene': ('massegods',),
'massegodset': ('massegods',),
'massegrav': ('massegrav',),
'massegrava': ('massegrav',),
'massegraven': ('massegrav',),
'massegravene': ('massegrav',),
'massegraver': ('massegrav',),
'masseidrett': ('masseidrett',),
'masseidretten': ('masseidrett',),
'masseidrettene': ('masseidrett',),
'masseidretter': ('masseidrett',),
'massekommunikasjon': ('massekommunikasjon',),
'massekommunikasjonen': ('massekommunikasjon',),
'massekommunikasjonene': ('massekommunikasjon',),
'massekommunikasjoner': ('massekommunikasjon',),
'massekommunikasjonsmiddel': ('massekommunikasjonsmiddel',),
'massekommunikasjonsmiddelet': ('massekommunikasjonsmiddel',),
'massekommunikasjonsmidla': ('massekommunikasjonsmiddel',),
'massekommunikasjonsmidlene': ('massekommunikasjonsmiddel',),
'massekommunikasjonsmidler': ('massekommunikasjonsmiddel',),
'massekommunikasjonsmidlet': ('massekommunikasjonsmiddel',),
'massekorsband': ('massekorsband',),
'massekorsbanda': ('massekorsband',),
'massekorsbandene': ('massekorsband',),
'massekorsbandet': ('massekorsband',),
'massekorsbånd': ('massekorsbånd',),
'massekorsbånda': ('massekorsbånd',),
'massekorsbåndene': ('massekorsbånd',),
'massekorsbåndet': ('massekorsbånd',),
'massemedieforsking': ('massemedieforsking',),
'massemedieforskinga': ('massemedieforsking',),
'massemedieforskingen': ('massemedieforsking',),
'massemedieforskingene': ('massemedieforsking',),
'massemedieforskinger': ('massemedieforsking',),
'massemedieforskning': ('massemedieforskning',),
'massemedieforskninga': ('massemedieforskning',),
'massemedieforskningen': ('massemedieforskning',),
'massemedieforskningene': ('massemedieforskning',),
'massemedieforskninger': ('massemedieforskning',),
'massemedieinstitutt': ('massemedieinstitutt',),
'massemedieinstitutta': ('massemedieinstitutt',),
'massemedieinstituttene': ('massemedieinstitutt',),
'massemedieinstitutter': ('massemedieinstitutt',),
'massemedieinstituttet': ('massemedieinstitutt',),
'massemedielinja': ('massemedielinje',),
'massemedielinje': ('massemedielinje',),
'massemedielinjen': ('massemedielinje',),
'massemedielinjene': ('massemedielinje',),
'massemedielinjer': ('massemedielinje',),
'massemedia': ('massemedium',),
'massemediene': ('massemedium',),
'massemedier': ('massemedium',),
'massemediet': ('massemedium',),
'massemedium': ('massemedium',),
'massemord': ('massemord',),
'massemorda': ('massemord',),
'massemordene': ('massemord',),
'massemordet': ('massemord',),
'massemorder': ('massemorder',),
'massemordere': ('massemorder',),
'massemorderen': ('massemorder',),
'massemorderer': ('massemorder',),
'massemorderne': ('massemorder',),
'massemøta': ('massemøte',),
'massemøte': ('massemøte',),
'massemøtene': ('massemøte',),
'massemøter': ('massemøte',),
'massemøtet': ('massemøte',),
'masseoppbud': ('masseoppbud',),
'masseoppbuda': ('masseoppbud',),
'masseoppbudene': ('masseoppbud',),
'masseoppbudet': ('masseoppbud',),
'masseproduksjon': ('masseproduksjon',),
'masseproduksjonen': ('masseproduksjon',),
'masseproduksjonene': ('masseproduksjon',),
'masseproduksjoner': ('masseproduksjon',),
'massepsykose': ('massepsykose',),
'massepsykosen': ('massepsykose',),
'massepsykosene': ('massepsykose',),
'massepsykoser': ('massepsykose',),
'massesuggesjon': ('massesuggesjon',),
'massesuggesjonen': ('massesuggesjon',),
'massesuggesjonene': ('massesuggesjon',),
'massesuggesjoner': ('massesuggesjon',),
'massesuggestion': ('massesuggestion',),
'massesuggestionen': ('massesuggestion',),
'massesuggestionene': ('massesuggestion',),
'massesuggestioner': ('massesuggestion',),
'massetetthet': ('massetetthet',),
'massetettheta': ('massetetthet',),
'massetettheten': ('massetetthet',),
'massetetthetene': ('massetetthet',),
'massetettheter': ('massetetthet',),
'masseturisme': ('masseturisme',),
'masseturismen': ('masseturisme',),
'masseturismene': ('masseturisme',),
'masseturismer': ('masseturisme',),
'masseødeleggelse': ('masseødeleggelse',),
'masseødeleggelsen': ('masseødeleggelse',),
'masseødeleggelsene': ('masseødeleggelse',),
'masseødeleggelser': ('masseødeleggelse',),
'masseødeleggelsesmiddel': ('masseødeleggelsesmiddel',),
'masseødeleggelsesmiddelet': ('masseødeleggelsesmiddel',),
'masseødeleggelsesmidla': ('masseødeleggelsesmiddel',),
'masseødeleggelsesmidlene': ('masseødeleggelsesmiddel',),
'masseødeleggelsesmidler': ('masseødeleggelsesmiddel',),
'masseødeleggelsesmidlet': ('masseødeleggelsesmiddel',),
'masseødeleggelsesvåpen': ('masseødeleggelsesvåpen',),
'masseødeleggelsesvåpenet': ('masseødeleggelsesvåpen',),
'masseødeleggelsesvåpna': ('masseødeleggelsesvåpen',),
'masseødeleggelsesvåpnene': ('masseødeleggelsesvåpen',),
'massiv': ('massiv',),
'massiva': ('massiv',),
'massivene': ('massiv',),
'massiver': ('massiv',),
'massivet': ('massiv',),
'massør': ('massør',),
'massøren': ('massør',),
'massørene': ('massør',),
'massører': ('massør',),
'massøsa': ('massøse',),
'massøse': ('massøse',),
'massøsen': ('massøse',),
'massøsene': ('massøse',),
'massøser': ('massøse',),
'mast': ('mast',),
'masta': ('mast',),
'masten': ('mast',),
'mastene': ('mast',),
'master': ('mast',),
'mastefisk': ('mastefisk',),
'mastefisken': ('mastefisk',),
'mastefiskene': ('mastefisk',),
'mastefisker': ('mastefisk',),
'master': ('master',),
'mastere': ('master',),
'masteren': ('master',),
'masterer': ('master',),
'masterne': ('master',),
'masterkopi': ('masterkopi',),
'masterkopien': ('masterkopi',),
'masterkopiene': ('masterkopi',),
'masterkopier': ('masterkopi',),
'mastetopp': ('mastetopp',),
'mastetoppen': ('mastetopp',),
'mastetoppene': ('mastetopp',),
'mastetopper': ('mastetopp',),
'mastiks': ('mastiks',),
'mastiksen': ('mastiks',),
'mastiksene': ('mastiks',),
'mastikser': ('mastiks',),
'mastitt': ('mastitt',),
'mastitten': ('mastitt',),
'mastittene': ('mastitt',),
'mastitter': ('mastitt',),
'mastodont': ('mastodont',),
'mastodonten': ('mastodont',),
'mastodontene': ('mastodont',),
'mastodonter': ('mastodont',),
'masturbasjon': ('masturbasjon',),
'masturbasjonen': ('masturbasjon',),
'masturbasjonene': ('masturbasjon',),
'masturbasjoner': ('masturbasjon',),
'masurka': ('masurka',),
'masurkaen': ('masurka',),
'masurkaene': ('masurka',),
'masurkaer': ('masurka',),
'masverk': ('masverk',),
'masverka': ('masverk',),
'masverkene': ('masverk',),
'masverket': ('masverk',),
'mat': ('mat',),
'maten': ('mat',),
'matene': ('mat',),
'mater': ('mat',),
'matador': ('matador',),
'matadoren': ('matador',),
'matadorene': ('matador',),
'matadorer': ('matador',),
'matauk': ('matauk',),
'matauken': ('matauk',),
'mataukene': ('matauk',),
'matauker': ('matauk',),
'matauke': ('matauke',),
'matauken': ('matauke',),
'mataukene': ('matauke',),
'matauker': ('matauke',),
'matbete': ('matbete',),
'matbeten': ('matbete',),
'matbetene': ('matbete',),
'matbeter': ('matbete',),
'matbillett': ('matbillett',),
'matbilletten': ('matbillett',),
'matbillettene': ('matbillett',),
'matbilletter': ('matbillett',),
'matbit': ('matbit',),
'matbiten': ('matbit',),
'matbitene': ('matbit',),
'matbiter': ('matbit',),
'matbord': ('matbord',),
'matborda': ('matbord',),
'matbordene': ('matbord',),
'matborder': ('matbord',),
'matbordet': ('matbord',),
'match': ('match',),
'matchen': ('match',),
'matchene': ('match',),
'matcher': ('match',),
'matchball': ('matchball',),
'matchballen': ('matchball',),
'matchballene': ('matchball',),
'matchballer': ('matchball',),
'matchvekt': ('matchvekt',),
'matchvekta': ('matchvekt',),
'matchvekten': ('matchvekt',),
'matchvektene': ('matchvekt',),
'matchvekter': ('matchvekt',),
'matchvinner': ('matchvinner',),
'matchvinnere': ('matchvinner',),
'matchvinneren': ('matchvinner',),
'matchvinnerer': ('matchvinner',),
'matchvinnerne': ('matchvinner',),
'matebuss': ('matebuss',),
'matebussen': ('matebuss',),
'matebussene': ('matebuss',),
'matebusser': ('matebuss',),
'matelasseen': ('matelassé',),
'matelasseene': ('matelassé',),
'matelasseer': ('matelassé',),
'matelassé': ('matelassé',),
'matelasséen': ('matelassé',),
'matelasséene': ('matelassé',),
'matelasséer': ('matelassé',),
'matematiker': ('matematiker',),
'matematikere': ('matematiker',),
'matematikeren': ('matematiker',),
'matematikerer': ('matematiker',),
'matematikerne': ('matematiker',),
'matematikk': ('matematikk',),
'matematikken': ('matematikk',),
'matematikkene': ('matematikk',),
'matematikker': ('matematikk',),
'mater': ('mater',),
'matere': ('mater',),
'materen': ('mater',),
'materer': ('mater',),
'materne': ('mater',),
'material': ('material',),
'materiala': ('material',),
'materialene': ('material',),
'materialer': ('material',),
'materialet': ('material',),
'materialbilda': ('materialbilde',),
'materialbilde': ('materialbilde',),
'materialbildene': ('materialbilde',),
'materialbilder': ('materialbilde',),
'materialbildet': ('materialbilde',),
'materiala': ('materiale',),
'materiale': ('materiale',),
'materialene': ('materiale',),
'materialer': ('materiale',),
'materialet': ('materiale',),
'materialforvalter': ('materialforvalter',),
'materialforvaltere': ('materialforvalter',),
'materialforvalteren': ('materialforvalter',),
'materialforvalterer': ('materialforvalter',),
'materialforvalterne': ('materialforvalter',),
'materialisasjon': ('materialisasjon',),
'materialisasjonen': ('materialisasjon',),
'materialisasjonene': ('materialisasjon',),
'materialisasjoner': ('materialisasjon',),
'materialisering': ('materialisering',),
'materialiseringa': ('materialisering',),
'materialiseringen': ('materialisering',),
'materialiseringene': ('materialisering',),
'materialiseringer': ('materialisering',),
'materialisme': ('materialisme',),
'materialismen': ('materialisme',),
'materialismene': ('materialisme',),
'materialismer': ('materialisme',),
'materialist': ('materialist',),
'materialisten': ('materialist',),
'materialistene': ('materialist',),
'materialister': ('materialist',),
'materialprøving': ('materialprøving',),
'materialprøvinga': ('materialprøving',),
'materialprøvingen': ('materialprøving',),
'materialprøvingene': ('materialprøving',),
'materialprøvinger': ('materialprøving',),
'materialtretthet': ('materialtretthet',),
'materialtrettheta': ('materialtretthet',),
'materialtrettheten': ('materialtretthet',),
'materialtretthetene': ('materialtretthet',),
'materialtrettheter': ('materialtretthet',),
'materialtrøtthet': ('materialtrøtthet',),
'materialtrøttheta': ('materialtrøtthet',),
'materialtrøttheten': ('materialtrøtthet',),
'materialtrøtthetene': ('materialtrøtthet',),
'materialtrøttheter': ('materialtrøtthet',),
'materie': ('materie',),
'materien': ('materie',),
'materiene': ('materie',),
'materier': ('materie',),
'materiell': ('materiell',),
'materiella': ('materiell',),
'materiellene': ('materiell',),
'materiellet': ('materiell',),
'maternitet': ('maternitet',),
'materniteten': ('maternitet',),
'maternitetene': ('maternitet',),
'materniteter': ('maternitet',),
'matfat': ('matfat',),
'matfata': ('matfat',),
'matfatene': ('matfat',),
'matfater': ('matfat',),
'matfatet': ('matfat',),
'matfett': ('matfett',),
'matfetta': ('matfett',),
'matfettene': ('matfett',),
'matfettet': ('matfett',),
'matfisk': ('matfisk',),
'matfisken': ('matfisk',),
'matfiskene': ('matfisk',),
'matfisker': ('matfisk',),
'matforgiftning': ('matforgiftning',),
'matforgiftninga': ('matforgiftning',),
'matforgiftningen': ('matforgiftning',),
'matforgiftningene': ('matforgiftning',),
'matforgiftninger': ('matforgiftning',),
'matforsyning': ('matforsyning',),
'matforsyninga': ('matforsyning',),
'matforsyningen': ('matforsyning',),
'matforsyningene': ('matforsyning',),
'matforsyninger': ('matforsyning',),
'mathus': ('mathus',),
'mathusa': ('mathus',),
'mathusene': ('mathus',),
'mathuset': ('mathus',),
'matineen': ('matiné',),
'matineene': ('matiné',),
'matineer': ('matiné',),
'matiné': ('matiné',),
'matinéen': ('matiné',),
'matinéene': ('matiné',),
'matinéer': ('matiné',),
'mating': ('mating',),
'matinga': ('mating',),
'matingen': ('mating',),
'matingene': ('mating',),
'matinger': ('mating',),
'matjessild': ('matjessild',),
'matjessilda': ('matjessild',),
'matjessilden': ('matjessild',),
'matjessildene': ('matjessild',),
'matjessilder': ('matjessild',),
'matjord': ('matjord',),
'matjorda': ('matjord',),
'matjorden': ('matjord',),
'matjordene': ('matjord',),
'matjorder': ('matjord',),
'matkart': ('matkart',),
'matkarta': ('matkart',),
'matkartene': ('matkart',),
'matkarter': ('matkart',),
'matkartet': ('matkart',),
'matkjeller': ('matkjeller',),
'matkjellere': ('matkjeller',),
'matkjelleren': ('matkjeller',),
'matkjellerer': ('matkjeller',),
'matkjellerne': ('matkjeller',),
'matkrok': ('matkrok',),
'matkroken': ('matkrok',),
'matkrokene': ('matkrok',),
'matkroker': ('matkrok',),
'matlaging': ('matlaging',),
'matlaginga': ('matlaging',),
'matlagingen': ('matlaging',),
'matlagingene': ('matlaging',),
'matlaginger': ('matlaging',),
'matlagingsmaskin': ('matlagingsmaskin',),
'matlagingsmaskina': ('matlagingsmaskin',),
'matlagingsmaskinen': ('matlagingsmaskin',),
'matlagingsmaskinene': ('matlagingsmaskin',),
'matlagingsmaskiner': ('matlagingsmaskin',),
'matlagning': ('matlagning',),
'matlagninga': ('matlagning',),
'matlagningen': ('matlagning',),
'matlagningene': ('matlagning',),
'matlagninger': ('matlagning',),
'matlagningsmaskin': ('matlagningsmaskin',),
'matlagningsmaskina': ('matlagningsmaskin',),
'matlagningsmaskinen': ('matlagningsmaskin',),
'matlagningsmaskinene': ('matlagningsmaskin',),
'matlagningsmaskiner': ('matlagningsmaskin',),
'matlista': ('matliste',),
'matliste': ('matliste',),
'matlisten': ('matliste',),
'matlistene': ('matliste',),
'matlister': ('matliste',),
'matlukt': ('matlukt',),
'matlukta': ('matlukt',),
'matlukten': ('matlukt',),
'matluktene': ('matlukt',),
'matlukter': ('matlukt',),
'matlyst': ('matlyst',),
'matlysta': ('matlyst',),
'matlysten': ('matlyst',),
'matlystene': ('matlyst',),
'matlyster': ('matlyst',),
'matmons': ('matmons',),
'matmonsen': ('matmons',),
'matmonsene': ('matmons',),
'matmonser': ('matmons',),
'matolja': ('matolje',),
'matolje': ('matolje',),
'matoljen': ('matolje',),
'matoljene': ('matolje',),
'matoljer': ('matolje',),
'matoppskrift': ('matoppskrift',),
'matoppskrifta': ('matoppskrift',),
'matoppskriften': ('matoppskrift',),
'matoppskriftene': ('matoppskrift',),
'matoppskrifter': ('matoppskrift',),
'matpakka': ('matpakke',),
'matpakke': ('matpakke',),
'matpakken': ('matpakke',),
'matpakkene': ('matpakke',),
'matpakker': ('matpakke',),
'matpakkekjører': ('matpakkekjører',),
'matpakkekjørere': ('matpakkekjører',),
'matpakkekjøreren': ('matpakkekjører',),
'matpakkekjørerer': ('matpakkekjører',),
'matpakkekjørerne': ('matpakkekjører',),
'matpapir': ('matpapir',),
'matpapira': ('matpapir',),
'matpapirene': ('matpapir',),
'matpapirer': ('matpapir',),
'matpapiret': ('matpapir',),
'matpause': ('matpause',),
'matpausen': ('matpause',),
'matpausene': ('matpause',),
'matpauser': ('matpause',),
'matpotet': ('matpotet',),
'matpoteten': ('matpotet',),
'matpotetene': ('matpotet',),
'matpoteter': ('matpotet',),
'matpris': ('matpris',),
'matprisen': ('matpris',),
'matprisene': ('matpris',),
'matpriser': ('matpris',),
'matrest': ('matrest',),
'matresten': ('matrest',),
'matrestene': ('matrest',),
'matrester': ('matrest',),
'matriarkat': ('matriarkat',),
'matriarkata': ('matriarkat',),
'matriarkatene': ('matriarkat',),
'matriarkater': ('matriarkat',),
'matriarkatet': ('matriarkat',),
'matrikkel': ('matrikkel',),
'matrikkelen': ('matrikkel',),
'matriklene': ('matrikkel',),
'matrikler': ('matrikkel',),
'matrikkelnummer': ('matrikkelnummer',),
'matrikkelnummeret': ('matrikkelnummer',),
'matrikkelnumra': ('matrikkelnummer',),
'matrikkelnumre': ('matrikkelnummer',),
'matrikkelnumrene': ('matrikkelnummer',),
'matrikkelskatt': ('matrikkelskatt',),
'matrikkelskatten': ('matrikkelskatt',),
'matrikkelskattene': ('matrikkelskatt',),
'matrikkelskatter': ('matrikkelskatt',),
'matrikkelskyld': ('matrikkelskyld',),
'matrikkelskylda': ('matrikkelskyld',),
'matrikkelskylden': ('matrikkelskyld',),
'matrikkelskyldene': ('matrikkelskyld',),
'matrikkelskylder': ('matrikkelskyld',),
'matrise': ('matrise',),
'matrisen': ('matrise',),
'matrisene': ('matrise',),
'matriser': ('matrise',),
'matriseskriver': ('matriseskriver',),
'matriseskrivere': ('matriseskriver',),
'matriseskriveren': ('matriseskriver',),
'matriseskriverer': ('matriseskriver',),
'matriseskriverne': ('matriseskriver',),
'matro': ('matro',),
'matroa': ('matro',),
'matroen': ('matro',),
'matroene': ('matro',),
'matroer': ('matro',),
'matrona': ('matrone',),
'matrone': ('matrone',),
'matronen': ('matrone',),
'matronene': ('matrone',),
'matroner': ('matrone',),
'matros': ('matros',),
'matrosen': ('matros',),
'matrosene': ('matros',),
'matroser': ('matros',),
'matrosdress': ('matrosdress',),
'matrosdressen': ('matrosdress',),
'matrosdressene': ('matrosdress',),
'matrosdresser': ('matrosdress',),
'matroskrage': ('matroskrage',),
'matroskragen': ('matroskrage',),
'matroskragene': ('matroskrage',),
'matroskrager': ('matroskrage',),
'matroskrave': ('matroskrave',),
'matroskraven': ('matroskrave',),
'matroskravene': ('matroskrave',),
'matroskraver': ('matroskrave',),
'matsal': ('matsal',),
'matsalen': ('matsal',),
'matsalene': ('matsal',),
'matsaler': ('matsal',),
'matsenter': ('matsenter',),
'matsenteret': ('matsenter',),
'matsentra': ('matsenter',),
'matsentre': ('matsenter',),
'matsentrene': ('matsenter',),
'matsentret': ('matsenter',),
'matskjønner': ('matskjønner',),
'matskjønnere': ('matskjønner',),
'matskjønneren': ('matskjønner',),
'matskjønnerer': ('matskjønner',),
'matskjønnerne': ('matskjønner',),
'matsmule': ('matsmule',),
'matsmulen': ('matsmule',),
'matsmulene': ('matsmule',),
'matsmuler': ('matsmule',),
'matsopp': ('matsopp',),
'matsoppen': ('matsopp',),
'matsoppene': ('matsopp',),
'matsopper': ('matsopp',),
'matstasjon': ('matstasjon',),
'matstasjonen': ('matstasjon',),
'matstasjonene': ('matstasjon',),
'matstasjoner': ('matstasjon',),
'matstell': ('matstell',),
'matstella': ('matstell',),
'matstellene': ('matstell',),
'matstellet': ('matstell',),
'matstrev': ('matstrev',),
'matstreva': ('matstrev',),
'matstrevene': ('matstrev',),
'matstrevet': ('matstrev',),
'matt': ('matt',),
'matte': ('matte',),
'matten': ('matte',),
'mattene': ('matte',),
'matter': ('matte',),
'matta': ('matte',),
'matte': ('matte',),
'matten': ('matte',),
'mattene': ('matte',),
'matter': ('matte',),
'matteusmess': ('matteusmess',),
'matteusmess': ('matteusmess',),
'matteusmesse': ('matteusmesse',),
'matthet': ('matthet',),
'mattheta': ('matthet',),
'mattheten': ('matthet',),
'matthetene': ('matthet',),
'mattheter': ('matthet',),
'mattiasmess': ('mattiasmess',),
'mattiasmesse': ('mattiasmesse',),
'mattismess': ('mattismess',),
'mattismesse': ('mattismesse',),
'maturitet': ('maturitet',),
'maturiteten': ('maturitet',),
'maturitetene': ('maturitet',),
'maturiteter': ('maturitet',),
'matvara': ('matvare',),
'matvare': ('matvare',),
'matvaren': ('matvare',),
'matvarene': ('matvare',),
'matvarer': ('matvare',),
'matvareforretning': ('matvareforretning',),
'matvareforretninga': ('matvareforretning',),
'matvareforretningen': ('matvareforretning',),
'matvareforretningene': ('matvareforretning',),
'matvareforretninger': ('matvareforretning',),
'matvareforsyning': ('matvareforsyning',),
'matvareforsyninga': ('matvareforsyning',),
'matvareforsyningen': ('matvareforsyning',),
'matvareforsyningene': ('matvareforsyning',),
'matvareforsyninger': ('matvareforsyning',),
'matveg': ('matveg',),
'matvegen': ('matveg',),
'matvegene': ('matveg',),
'matveger': ('matveg',),
'matvei': ('matvei',),
'matveien': ('matvei',),
'matveiene': ('matvei',),
'matveier': ('matvei',),
'matvett': ('matvett',),
'matvetta': ('matvett',),
'matvettene': ('matvett',),
'matvettet': ('matvett',),
'maur': ('maur',),
'mauren': ('maur',),
'maurene': ('maur',),
'maura': ('maure',),
'maure': ('maure',),
'mauren': ('maure',),
'maurene': ('maure',),
'maurer': ('maure',),
'maurefamilie': ('maurefamilie',),
'maurefamilien': ('maurefamilie',),
'maurefamiliene': ('maurefamilie',),
'maurefamilier': ('maurefamilie',),
'maurer': ('maurer',),
'maurere': ('maurer',),
'maureren': ('maurer',),
'maurerer': ('maurer',),
'maurerne': ('maurer',),
'mauritanier': ('mauritanier',),
'mauritaniere': ('mauritanier',),
'mauritanieren': ('mauritanier',),
'mauritanierer': ('mauritanier',),
'mauritanierne': ('mauritanier',),
'mauritier': ('mauritier',),
'mauritiere': ('mauritier',),
'mauritieren': ('mauritier',),
'mauritierer': ('mauritier',),
'mauritierne': ('mauritier',),
'maurpiggsvin': ('maurpiggsvin',),
'maurpiggsvina': ('maurpiggsvin',),
'maurpiggsvinene': ('maurpiggsvin',),
'maurpiggsvinet': ('maurpiggsvin',),
'maurpinnsvin': ('maurpinnsvin',),
'maurpinnsvina': ('maurpinnsvin',),
'maurpinnsvinene': ('maurpinnsvin',),
'maurpinnsvinet': ('maurpinnsvin',),
'maurpiss': ('maurpiss',),
'maurpissa': ('maurpiss',),
'maurpissene': ('maurpiss',),
'maurpisset': ('maurpiss',),
'maursluker': ('maursluker',),
'maurslukere': ('maursluker',),
'maurslukeren': ('maursluker',),
'maurslukerer': ('maursluker',),
'maurslukerne': ('maursluker',),
'maursyra': ('maursyre',),
'maursyre': ('maursyre',),
'maursyren': ('maursyre',),
'maursyrene': ('maursyre',),
'maursyrer': ('maursyre',),
'maurtua': ('maurtue',),
'maurtue': ('maurtue',),
'maurtuen': ('maurtue',),
'maurtuene': ('maurtue',),
'maurtuer': ('maurtue',),
'maurtuva': ('maurtuve',),
'maurtuve': ('maurtuve',),
'maurtuven': ('maurtuve',),
'maurtuvene': ('maurtuve',),
'maurtuver': ('maurtuve',),
'mauser': ('mauser',),
'mausere': ('mauser',),
'mauseren': ('mauser',),
'mauserer': ('mauser',),
'mauserne': ('mauser',),
'mausergevær': ('mausergevær',),
'mausergeværa': ('mausergevær',),
'mausergeværene': ('mausergevær',),
'mausergeværer': ('mausergevær',),
'mausergeværet': ('mausergevær',),
'mausolea': ('mausolé',),
'mausoleene': ('mausolé',),
'mausoleer': ('mausolé',),
'mausoleet': ('mausolé',),
'mausolé': ('mausolé',),
'mausoléa': ('mausolé',),
'mausoléene': ('mausolé',),
'mausoléer': ('mausolé',),
'mausoléet': ('mausolé',),
'mausolea': ('mausoleum',),
'mausoleene': ('mausoleum',),
'mausoleer': ('mausoleum',),
'mausoleet': ('mausoleum',),
'mausoleum': ('mausoleum',),
'mave': ('mave',),
'maven': ('mave',),
'mavene': ('mave',),
'maver': ('mave',),
'mavebelta': ('mavebelte',),
'mavebelte': ('mavebelte',),
'mavebeltene': ('mavebelte',),
'mavebelter': ('mavebelte',),
'mavebeltet': ('mavebelte',),
'mavedans': ('mavedans',),
'mavedansen': ('mavedans',),
'mavedansene': ('mavedans',),
'mavedanser': ('mavedans',),
'mavehistoria': ('mavehistorie',),
'mavehistorie': ('mavehistorie',),
'mavehistorien': ('mavehistorie',),
'mavehistoriene': ('mavehistorie',),
'mavehistorier': ('mavehistorie',),
'mavekatarr': ('mavekatarr',),
'mavekatarren': ('mavekatarr',),
'mavekatarrene': ('mavekatarr',),
'mavekatarrer': ('mavekatarr',),
'maveknip': ('maveknip',),
'maveknipa': ('maveknip',),
'maveknipene': ('maveknip',),
'maveknipet': ('maveknip',),
'mavekreft': ('mavekreft',),
'mavekreften': ('mavekreft',),
'mavekreftene': ('mavekreft',),
'mavekrefter': ('mavekreft',),
'mavemunn': ('mavemunn',),
'mavemunnen': ('mavemunn',),
'mavemunnene': ('mavemunn',),
'mavemunner': ('mavemunn',),
'mavemål': ('mavemål',),
'mavemåla': ('mavemål',),
'mavemålene': ('mavemål',),
'mavemålet': ('mavemål',),
'maveonda': ('maveonde',),
'maveonde': ('maveonde',),
'maveondene': ('maveonde',),
'maveonder': ('maveonde',),
'maveondet': ('maveonde',),
'maveplask': ('maveplask',),
'maveplaska': ('maveplask',),
'maveplaskene': ('maveplask',),
'maveplasket': ('maveplask',),
'maveport': ('maveport',),
'maveporten': ('maveport',),
'maveportene': ('maveport',),
'maveporter': ('maveport',),
'mavesaft': ('mavesaft',),
'mavesafta': ('mavesaft',),
'mavesaften': ('mavesaft',),
'mavesaftene': ('mavesaft',),
'mavesafter': ('mavesaft',),
'mavesekk': ('mavesekk',),
'mavesekken': ('mavesekk',),
'mavesekkene': ('mavesekk',),
'mavesekker': ('mavesekk',),
'mavesjau': ('mavesjau',),
'mavesjauen': ('mavesjau',),
'mavesjauene': ('mavesjau',),
'mavesjauer': ('mavesjau',),
'mavesyra': ('mavesyre',),
'mavesyre': ('mavesyre',),
'mavesyren': ('mavesyre',),
'mavesyrene': ('mavesyre',),
'mavesyrer': ('mavesyre',),
'mavesår': ('mavesår',),
'mavesåra': ('mavesår',),
'mavesårene': ('mavesår',),
'mavesåret': ('mavesår',),
'mavetilfella': ('mavetilfelle',),
'mavetilfelle': ('mavetilfelle',),
'mavetilfellene': ('mavetilfelle',),
'mavetilfeller': ('mavetilfelle',),
'mavetilfellet': ('mavetilfelle',),
'mavevegg': ('mavevegg',),
'maveveggen': ('mavevegg',),
'maveveggene': ('mavevegg',),
'mavevegger': ('mavevegg',),
'mavevelling': ('mavevelling',),
'mavevellinga': ('mavevelling',),
'mavevellingen': ('mavevelling',),
'mavevellingene': ('mavevelling',),
'mavevellinger': ('mavevelling',),
'maveverk': ('maveverk',),
'maveverken': ('maveverk',),
'maveverkene': ('maveverk',),
'maveverker': ('maveverk',),
'maya': ('maya',),
'mayaen': ('maya',),
'mayaene': ('maya',),
'mayaer': ('maya',),
'mayafolk': ('mayafolk',),
'mayafolka': ('mayafolk',),
'mayafolkene': ('mayafolk',),
'mayafolket': ('mayafolk',),
'mayakultur': ('mayakultur',),
'mayakulturen': ('mayakultur',),
'mayakulturene': ('mayakultur',),
'mayakulturer': ('mayakultur',),
'mayaspråk': ('mayaspråk',),
'mayaspråka': ('mayaspråk',),
'mayaspråkene': ('mayaspråk',),
'mayaspråket': ('mayaspråk',),
'mayday': ('mayday',),
'mccarthyisme': ('mccarthyisme',),
'mccarthyismen': ('mccarthyisme',),
'mccarthyismene': ('mccarthyisme',),
'mccarthyismer': ('mccarthyisme',),
'meander': ('meander',),
'meandere': ('meander',),
'meanderen': ('meander',),
'meanderne': ('meander',),
'meandre': ('meander',),
'meandrene': ('meander',),
'meandrer': ('meander',),
'med': ('med',),
'meda': ('med',),
'medene': ('med',),
'medet': ('med',),
'medalje': ('medalje',),
'medaljen': ('medalje',),
'medaljene': ('medalje',),
'medaljer': ('medalje',),
'medaljeplass': ('medaljeplass',),
'medaljeplassen': ('medaljeplass',),
'medaljeplassene': ('medaljeplass',),
'medaljeplasser': ('medaljeplass',),
'medaljevinner': ('medaljevinner',),
'medaljevinnere': ('medaljevinner',),
'medaljevinneren': ('medaljevinner',),
'medaljevinnerer': ('medaljevinner',),
'medaljevinnerne': ('medaljevinner',),
'medaljong': ('medaljong',),
'medaljongen': ('medaljong',),
'medaljongene': ('medaljong',),
'medaljonger': ('medaljong',),
'medaljør': ('medaljør',),
'medaljøren': ('medaljør',),
'medaljørene': ('medaljør',),
'medaljører': ('medaljør',),
'medansvar': ('medansvar',),
'medansvara': ('medansvar',),
'medansvarene': ('medansvar',),
'medansvaret': ('medansvar',),
'medarbeider': ('medarbeider',),
'medarbeidere': ('medarbeider',),
'medarbeideren': ('medarbeider',),
'medarbeiderer': ('medarbeider',),
'medarbeiderne': ('medarbeider',),
'medbakke': ('medbakke',),
'medbakken': ('medbakke',),
'medbakkene': ('medbakke',),
'medbakker': ('medbakke',),
'medbestemmelsesrett': ('medbestemmelsesrett',),
'medbestemmelsesretten': ('medbestemmelsesrett',),
'medbestemmelsesrettene': ('medbestemmelsesrett',),
'medbestemmelsesretter': ('medbestemmelsesrett',),
'medborger': ('medborger',),
'medborgere': ('medborger',),
'medborgeren': ('medborger',),
'medborgerer': ('medborger',),
'medborgerne': ('medborger',),
'medbør': ('medbør',),
'medbøren': ('medbør',),
'medbørene': ('medbør',),
'medbører': ('medbør',),
'meddelelse': ('meddelelse',),
'meddelelsen': ('meddelelse',),
'meddelelsene': ('meddelelse',),
'meddelelser': ('meddelelse',),
'meddelelsesevna': ('meddelelsesevne',),
'meddelelsesevne': ('meddelelsesevne',),
'meddelelsesevnen': ('meddelelsesevne',),
'meddelelsesevnene': ('meddelelsesevne',),
'meddelelsesevner': ('meddelelsesevne',),
'meddelelseslyst': ('meddelelseslyst',),
'meddelelseslysta': ('meddelelseslyst',),
'meddelelseslysten': ('meddelelseslyst',),
'meddelelseslystene': ('meddelelseslyst',),
'meddelelseslyster': ('meddelelseslyst',),
'meddelelsesmiddel': ('meddelelsesmiddel',),
'meddelelsesmiddelet': ('meddelelsesmiddel',),
'meddelelsesmidla': ('meddelelsesmiddel',),
'meddelelsesmidlene': ('meddelelsesmiddel',),
'meddelelsesmidler': ('meddelelsesmiddel',),
'meddelelsesmidlet': ('meddelelsesmiddel',),
'meddelelsesmåte': ('meddelelsesmåte',),
'meddelelsesmåten': ('meddelelsesmåte',),
'meddelelsesmåtene': ('meddelelsesmåte',),
'meddelelsesmåter': ('meddelelsesmåte',),
'meddelelsestrang': ('meddelelsestrang',),
'meddelelsestrangen': ('meddelelsestrang',),
'meddelelsestrangene': ('meddelelsestrang',),
'meddelelsestranger': ('meddelelsestrang',),
'meddommer': ('meddommer',),
'meddommere': ('meddommer',),
'meddommeren': ('meddommer',),
'meddommerer': ('meddommer',),
'meddommerne': ('meddommer',),
'meddomsmann': ('meddomsmann',),
'meddomsmannen': ('meddomsmann',),
'meddomsmenn': ('meddomsmann',),
'meddomsmennene': ('meddomsmann',),
'meddomsrett': ('meddomsrett',),
'meddomsretten': ('meddomsrett',),
'meddomsrettene': ('meddomsrett',),
'meddomsretter': ('meddomsrett',),
'meded': ('meded',),
'mededen': ('meded',),
'mededene': ('meded',),
'mededer': ('meded',),
'medeier': ('medeier',),
'medeiere': ('medeier',),
'medeieren': ('medeier',),
'medeierer': ('medeier',),
'medeierne': ('medeier',),
'medelev': ('medelev',),
'medeleven': ('medelev',),
'medelevene': ('medelev',),
'medelever': ('medelev',),
'medfange': ('medfange',),
'medfangen': ('medfange',),
'medfangene': ('medfange',),
'medfanger': ('medfange',),
'medfart': ('medfart',),
'medfarten': ('medfart',),
'medfartene': ('medfart',),
'medfarter': ('medfart',),
'medferd': ('medferd',),
'medferda': ('medferd',),
'medferden': ('medferd',),
'medferdene': ('medferd',),
'medferder': ('medferd',),
'medfølelse': ('medfølelse',),
'medfølelsen': ('medfølelse',),
'medfølelsene': ('medfølelse',),
'medfølelser': ('medfølelse',),
'medfør': ('medfør',),
'medgang': ('medgang',),
'medgangen': ('medgang',),
'medgangene': ('medgang',),
'medganger': ('medgang',),
'medgift': ('medgift',),
'medgifta': ('medgift',),
'medgiften': ('medgift',),
'medgiftene': ('medgift',),
'medgifter': ('medgift',),
'medhjelper': ('medhjelper',),
'medhjelpere': ('medhjelper',),
'medhjelperen': ('medhjelper',),
'medhjelperer': ('medhjelper',),
'medhjelperne': ('medhjelper',),
'medhold': ('medhold',),
'medholda': ('medhold',),
'medholdene': ('medhold',),
'medholdet': ('medhold',),
'median': ('median',),
'medianen': ('median',),
'medianene': ('median',),
'medianer': ('median',),
'mediatek': ('mediatek',),
'mediateka': ('mediatek',),
'mediatekene': ('mediatek',),
'mediateker': ('mediatek',),
'mediateket': ('mediatek',),
'mediatekar': ('mediatekar',),
'mediatekaren': ('mediatekar',),
'mediatekarene': ('mediatekar',),
'mediatekarer': ('mediatekar',),
'medieforsking': ('medieforsking',),
'medieforskinga': ('medieforsking',),
'medieforskingen': ('medieforsking',),
'medieforskingene': ('medieforsking',),
'medieforskinger': ('medieforsking',),
'medieforskning': ('medieforskning',),
'medieforskninga': ('medieforskning',),
'medieforskningen': ('medieforskning',),
'medieforskningene': ('medieforskning',),
'medieforskninger': ('medieforskning',),
'mediekunnskap': ('mediekunnskap',),
'mediekunnskapen': ('mediekunnskap',),
'mediekunnskapene': ('mediekunnskap',),
'mediekunnskaper': ('mediekunnskap',),
'medielinja': ('medielinje',),
'medielinje': ('medielinje',),
'medielinjen': ('medielinje',),
'medielinjene': ('medielinje',),
'medielinjer': ('medielinje',),
'mediepolitikk': ('mediepolitikk',),
'mediepolitikken': ('mediepolitikk',),
'mediepolitikkene': ('mediepolitikk',),
'mediepolitikker': ('mediepolitikk',),
'medietek': ('medietek',),
'medieteka': ('medietek',),
'medietekene': ('medietek',),
'medieteker': ('medietek',),
'medieteket': ('medietek',),
'medietekar': ('medietekar',),
'medietekaren': ('medietekar',),
'medietekarene': ('medietekar',),
'medietekarer': ('medietekar',),
'medikament': ('medikament',),
'medikamenta': ('medikament',),
'medikamentene': ('medikament',),
'medikamenter': ('medikament',),
'medikamentet': ('medikament',),
'medikamentmisbruk': ('medikamentmisbruk',),
'medikamentmisbruka': ('medikamentmisbruk',),
'medikamentmisbruken': ('medikamentmisbruk',),
'medikamentmisbrukene': ('medikamentmisbruk',),
'medikamentmisbruker': ('medikamentmisbruk',),
'medikamentmisbruket': ('medikamentmisbruk',),
'medikus': ('medikus',),
'medikusen': ('medikus',),
'medikusene': ('medikus',),
'medikuser': ('medikus',),
'medinnehaver': ('medinnehaver',),
'medinnehavere': ('medinnehaver',),
'medinnehaveren': ('medinnehaver',),
'medinnehaverer': ('medinnehaver',),
'medinnehaverne': ('medinnehaver',),
'medinnflytelse': ('medinnflytelse',),
'medinnflytelsen': ('medinnflytelse',),
'medinnflytelsene': ('medinnflytelse',),
'medinnflytelser': ('medinnflytelse',),
'medisin': ('medisin',),
'medisinen': ('medisin',),
'medisinene': ('medisin',),
'medisiner': ('medisin',),
'medisiner': ('medisiner',),
'medisinere': ('medisiner',),
'medisineren': ('medisiner',),
'medisinerer': ('medisiner',),
'medisinerne': ('medisiner',),
'medisinflaska': ('medisinflaske',),
'medisinflaske': ('medisinflaske',),
'medisinflasken': ('medisinflaske',),
'medisinflaskene': ('medisinflaske',),
'medisinflasker': ('medisinflaske',),
'medisinmann': ('medisinmann',),
'medisinmannen': ('medisinmann',),
'medisinmenn': ('medisinmann',),
'medisinmennene': ('medisinmann',),
'medisinplanta': ('medisinplante',),
'medisinplante': ('medisinplante',),
'medisinplanten': ('medisinplante',),
'medisinplantene': ('medisinplante',),
'medisinplanter': ('medisinplante',),
'medisinskap': ('medisinskap',),
'medisinskapa': ('medisinskap',),
'medisinskapene': ('medisinskap',),
'medisinskapet': ('medisinskap',),
'medisintran': ('medisintran',),
'medisintrana': ('medisintran',),
'medisintranen': ('medisintran',),
'medisintranene': ('medisintran',),
'medisintraner': ('medisintran',),
'medister': ('medister',),
'medistere': ('medister',),
'medisteren': ('medister',),
'medisterer': ('medister',),
'medisterne': ('medister',),
'medistre': ('medister',),
'medistrene': ('medister',),
'medistrer': ('medister',),
'medisterdeig': ('medisterdeig',),
'medisterdeigen': ('medisterdeig',),
'medisterdeigene': ('medisterdeig',),
'medisterdeiger': ('medisterdeig',),
'medisterfarse': ('medisterfarse',),
'medisterfarsen': ('medisterfarse',),
'medisterfarsene': ('medisterfarse',),
'medisterfarser': ('medisterfarse',),
'medisterkaka': ('medisterkake',),
'medisterkake': ('medisterkake',),
'medisterkaken': ('medisterkake',),
'medisterkakene': ('medisterkake',),
'medisterkaker': ('medisterkake',),
'medisterpølsa': ('medisterpølse',),
'medisterpølse': ('medisterpølse',),
'medisterpølsen': ('medisterpølse',),
'medisterpølsene': ('medisterpølse',),
'medisterpølser': ('medisterpølse',),
'meditasjon': ('meditasjon',),
'meditasjonen': ('meditasjon',),
'meditasjonene': ('meditasjon',),
'meditasjoner': ('meditasjon',),
'meditasjonsord': ('meditasjonsord',),
'meditasjonsorda': ('meditasjonsord',),
'meditasjonsordene': ('meditasjonsord',),
'meditasjonsordet': ('meditasjonsord',),
'meditasjonsøvelse': ('meditasjonsøvelse',),
'meditasjonsøvelsen': ('meditasjonsøvelse',),
'meditasjonsøvelsene': ('meditasjonsøvelse',),
'meditasjonsøvelser': ('meditasjonsøvelse',),
'meditasjonsøving': ('meditasjonsøving',),
'meditasjonsøvinga': ('meditasjonsøving',),
'meditasjonsøvingen': ('meditasjonsøving',),
'meditasjonsøvingene': ('meditasjonsøving',),
'meditasjonsøvinger': ('meditasjonsøving',),
'media': ('medium',),
'mediene': ('medium',),
'medier': ('medium',),
'mediet': ('medium',),
'medium': ('medium',),
'medkjemper': ('medkjemper',),
'medkjempere': ('medkjemper',),
'medkjemperen': ('medkjemper',),
'medkjemperer': ('medkjemper',),
'medkjemperne': ('medkjemper',),
'medkjensla': ('medkjensle',),
'medkjensle': ('medkjensle',),
'medkjenslen': ('medkjensle',),
'medkjenslene': ('medkjensle',),
'medkjensler': ('medkjensle',),
'medlem': ('medlem',),
'medlemma': ('medlem',),
'medlemmene': ('medlem',),
'medlemmer': ('medlem',),
'medlemmet': ('medlem',),
'medlemsavgift': ('medlemsavgift',),
'medlemsavgifta': ('medlemsavgift',),
'medlemsavgiften': ('medlemsavgift',),
'medlemsavgiftene': ('medlemsavgift',),
'medlemsavgifter': ('medlemsavgift',),
'medlemsblad': ('medlemsblad',),
'medlemsblada': ('medlemsblad',),
'medlemsbladene': ('medlemsblad',),
'medlemsblader': ('medlemsblad',),
'medlemsbladet': ('medlemsblad',),
'medlemsfortegnelse': ('medlemsfortegnelse',),
'medlemsfortegnelsen': ('medlemsfortegnelse',),
'medlemsfortegnelsene': ('medlemsfortegnelse',),
'medlemsfortegnelser': ('medlemsfortegnelse',),
'medlemskap': ('medlemskap',),
'medlemskapa': ('medlemskap',),
'medlemskapene': ('medlemskap',),
'medlemskapet': ('medlemskap',),
'medlemskontingent': ('medlemskontingent',),
'medlemskontingenten': ('medlemskontingent',),
'medlemskontingentene': ('medlemskontingent',),
'medlemskontingenter': ('medlemskontingent',),
'medlemskort': ('medlemskort',),
'medlemskorta': ('medlemskort',),
'medlemskortene': ('medlemskort',),
'medlemskortet': ('medlemskort',),
'medlemsland': ('medlemsland',),
'medlemslanda': ('medlemsland',),
'medlemslandene': ('medlemsland',),
'medlemslandet': ('medlemsland',),
'medlemstal': ('medlemstal',),
'medlemstala': ('medlemstal',),
'medlemstalene': ('medlemstal',),
'medlemstalet': ('medlemstal',),
'medlemstall': ('medlemstall',),
'medlemstalla': ('medlemstall',),
'medlemstallene': ('medlemstall',),
'medlemstallet': ('medlemstall',),
'medley': ('medley',),
'medleyen': ('medley',),
'medleyene': ('medley',),
'medleyer': ('medley',),
'medlidenhet': ('medlidenhet',),
'medlidenheta': ('medlidenhet',),
'medlidenheten': ('medlidenhet',),
'medlidenhetene': ('medlidenhet',),
'medlidenheter': ('medlidenhet',),
'medlidenhetsdrap': ('medlidenhetsdrap',),
'medlidenhetsdrapa': ('medlidenhetsdrap',),
'medlidenhetsdrapene': ('medlidenhetsdrap',),
'medlidenhetsdrapet': ('medlidenhetsdrap',),
'medlinja': ('medlinje',),
'medlinje': ('medlinje',),
'medlinjen': ('medlinje',),
'medlinjene': ('medlinje',),
'medlinjer': ('medlinje',),
'medlyd': ('medlyd',),
'medlyden': ('medlyd',),
'medlydene': ('medlyd',),
'medlyder': ('medlyd',),
'medløper': ('medløper',),
'medløpere': ('medløper',),
'medløperen': ('medløper',),
'medløperer': ('medløper',),
'medløperne': ('medløper',),
'medmenneska': ('medmenneske',),
'medmenneske': ('medmenneske',),
'medmenneskene': ('medmenneske',),
'medmennesker': ('medmenneske',),
'medmennesket': ('medmenneske',),
'medmenneskelighet': ('medmenneskelighet',),
'medmenneskeligheta': ('medmenneskelighet',),
'medmenneskeligheten': ('medmenneskelighet',),
'medmenneskelighetene': ('medmenneskelighet',),
'medmenneskeligheter': ('medmenneskelighet',),
'medoc': ('medoc',),
'medocen': ('medoc',),
'medocene': ('medoc',),
'medocer': ('medoc',),
'medskyld': ('medskyld',),
'medskylda': ('medskyld',),
'medskylden': ('medskyld',),
'medskyldene': ('medskyld',),
'medskylder': ('medskyld',),
'medspeller': ('medspeller',),
'medspellere': ('medspeller',),
'medspelleren': ('medspeller',),
'medspellerer': ('medspeller',),
'medspellerne': ('medspeller',),
'medspiller': ('medspiller',),
'medspillere': ('medspiller',),
'medspilleren': ('medspiller',),
'medspillerer': ('medspiller',),
'medspillerne': ('medspiller',),
'medsøster': ('medsøster',),
'medsøstera': ('medsøster',),
'medsøsteren': ('medsøster',),
'medsøstre': ('medsøster',),
'medsøstrene': ('medsøster',),
'medsøstrer': ('medsøster',),
'medunderskrift': ('medunderskrift',),
'medunderskrifta': ('medunderskrift',),
'medunderskriften': ('medunderskrift',),
'medunderskriftene': ('medunderskrift',),
'medunderskrifter': ('medunderskrift',),
'meduse': ('meduse',),
'medusen': ('meduse',),
'medusene': ('meduse',),
'meduser': ('meduse',),
'meduseform': ('meduseform',),
'meduseforma': ('meduseform',),
'meduseformen': ('meduseform',),
'meduseformene': ('meduseform',),
'meduseformer': ('meduseform',),
'medvind': ('medvind',),
'medvinden': ('medvind',),
'medvindene': ('medvind',),
'medvinder': ('medvind',),
'medvirkning': ('medvirkning',),
'medvirkningen': ('medvirkning',),
'medvirkningene': ('medvirkning',),
'medvirkninger': ('medvirkning',),
'medviter': ('medviter',),
'medvitere': ('medviter',),
'medviteren': ('medviter',),
'medviterer': ('medviter',),
'medviterne': ('medviter',),
'medynk': ('medynk',),
'medynken': ('medynk',),
'medynkene': ('medynk',),
'medynker': ('medynk',),
'megabyte': ('megabyte',),
'megabyten': ('megabyte',),
'megabytene': ('megabyte',),
'megafon': ('megafon',),
'megafonen': ('megafon',),
'megafonene': ('megafon',),
'megafoner': ('megafon',),
'megahertz': ('megahertz',),
'megahertzen': ('megahertz',),
'megahertzene': ('megahertz',),
'megalitt': ('megalitt',),
'megalitten': ('megalitt',),
'megalittene': ('megalitt',),
'megalitter': ('megalitt',),
'megalittkultur': ('megalittkultur',),
'megalittkulturen': ('megalittkultur',),
'megalittkulturene': ('megalittkultur',),
'megalittkulturer': ('megalittkultur',),
'megaohm': ('megaohm',),
'megaohmen': ('megaohm',),
'megaohmene': ('megaohm',),
'megatonn': ('megatonn',),
'megatonna': ('megatonn',),
'megatonnene': ('megatonn',),
'megatonnet': ('megatonn',),
'megatonnbomba': ('megatonnbombe',),
'megatonnbombe': ('megatonnbombe',),
'megatonnbomben': ('megatonnbombe',),
'megatonnbombene': ('megatonnbombe',),
'megatonnbomber': ('megatonnbombe',),
'megatrend': ('megatrend',),
'megatrenden': ('megatrend',),
'megatrendene': ('megatrend',),
'megatrender': ('megatrend',),
'megavolt': ('megavolt',),
'megavolten': ('megavolt',),
'megavoltene': ('megavolt',),
'megawatt': ('megawatt',),
'megawatten': ('megawatt',),
'megawattene': ('megawatt',),
'meget': ('meget',),
'megeten': ('meget',),
'megetene': ('meget',),
'megeter': ('meget',),
'megga': ('megge',),
'megge': ('megge',),
'meggen': ('megge',),
'meggene': ('megge',),
'megger': ('megge',),
'megler': ('megler',),
'meglere': ('megler',),
'megleren': ('megler',),
'meglerer': ('megler',),
'meglerne': ('megler',),
'meglerfirma': ('meglerfirma',),
'meglerfirmaene': ('meglerfirma',),
'meglerfirmaer': ('meglerfirma',),
'meglerfirmaet': ('meglerfirma',),
'megling': ('megling',),
'meglinga': ('megling',),
'meglingen': ('megling',),
'meglingene': ('megling',),
'meglinger': ('megling',),
'meglingsmann': ('meglingsmann',),
'meglingsmannen': ('meglingsmann',),
'meglingsmenn': ('meglingsmann',),
'meglingsmennene': ('meglingsmann',),
'megæra': ('megære',),
'megære': ('megære',),
'megæren': ('megære',),
'megærene': ('megære',),
'megærer': ('megære',),
'mehe': ('mehe',),
'mehea': ('mehe',),
'meheene': ('mehe',),
'meheer': ('mehe',),
'meheet': ('mehe',),
'mei': ('mei',),
'meien': ('mei',),
'meiene': ('mei',),
'meier': ('mei',),
'meia': ('meie',),
'meie': ('meie',),
'meien': ('meie',),
'meiene': ('meie',),
'meier': ('meie',),
'meieri': ('meieri',),
'meieria': ('meieri',),
'meieriene': ('meieri',),
'meierier': ('meieri',),
'meieriet': ('meieri',),
'meieribestyrer': ('meieribestyrer',),
'meieribestyrere': ('meieribestyrer',),
'meieribestyreren': ('meieribestyrer',),
'meieribestyrerer': ('meieribestyrer',),
'meieribestyrerne': ('meieribestyrer',),
'meieridrift': ('meieridrift',),
'meieridrifta': ('meieridrift',),
'meieridriften': ('meieridrift',),
'meieridriftene': ('meieridrift',),
'meieridrifter': ('meieridrift',),
'meieriingeniør': ('meieriingeniør',),
'meieriingeniøren': ('meieriingeniør',),
'meieriingeniørene': ('meieriingeniør',),
'meieriingeniører': ('meieriingeniør',),
'meieriskole': ('meieriskole',),
'meieriskolen': ('meieriskole',),
'meieriskolene': ('meieriskole',),
'meieriskoler': ('meieriskole',),
'meierismør': ('meierismør',),
'meierismøra': ('meierismør',),
'meierismørene': ('meierismør',),
'meierismøret': ('meierismør',),
'meierispann': ('meierispann',),
'meierispanna': ('meierispann',),
'meierispannene': ('meierispann',),
'meierispannet': ('meierispann',),
'meierist': ('meierist',),
'meieristen': ('meierist',),
'meieristene': ('meierist',),
'meierister': ('meierist',),
'meieritekniker': ('meieritekniker',),
'meieriteknikere': ('meieritekniker',),
'meieriteknikeren': ('meieritekniker',),
'meieriteknikerer': ('meieritekniker',),
'meieriteknikerne': ('meieritekniker',),
'mein': ('mein',),
'meina': ('mein',),
'meinene': ('mein',),
'meinet': ('mein',),
'meined': ('meined',),
'meineden': ('meined',),
'meinedene': ('meined',),
'meineder': ('meined',),
'meineid': ('meineid',),
'meineida': ('meineid',),
'meineidene': ('meineid',),
'meineidet': ('meineid',),
'meining': ('meining',),
'meininga': ('meining',),
'meiningen': ('meining',),
'meiningene': ('meining',),
'meininger': ('meining',),
'meiningsbryting': ('meiningsbryting',),
'meiningsbrytinga': ('meiningsbryting',),
'meiningsbrytingen': ('meiningsbryting',),
'meiningsbrytingene': ('meiningsbryting',),
'meiningsbrytinger': ('meiningsbryting',),
'meiningsbrytning': ('meiningsbrytning',),
'meiningsbrytninga': ('meiningsbrytning',),
'meiningsbrytningen': ('meiningsbrytning',),
'meiningsbrytningene': ('meiningsbrytning',),
'meiningsbrytninger': ('meiningsbrytning',),
'meiningsfelle': ('meiningsfelle',),
'meiningsfellen': ('meiningsfelle',),
'meiningsfellene': ('meiningsfelle',),
'meiningsfeller': ('meiningsfelle',),
'meiningsforskjell': ('meiningsforskjell',),
'meiningsforskjellen': ('meiningsforskjell',),
'meiningsforskjellene': ('meiningsforskjell',),
'meiningsforskjeller': ('meiningsforskjell',),
'meiningsfrende': ('meiningsfrende',),
'meiningsfrenden': ('meiningsfrende',),
'meiningsfrendene': ('meiningsfrende',),
'meiningsfrender': ('meiningsfrende',),
'meiningsfylde': ('meiningsfylde',),
'meiningsfylden': ('meiningsfylde',),
'meiningsfyldene': ('meiningsfylde',),
'meiningsfylder': ('meiningsfylde',),
'meiningsfylde': ('meiningsfylde',),
'meiningsfylden': ('meiningsfylde',),
'meiningsfyldene': ('meiningsfylde',),
'meiningsfylder': ('meiningsfylde',),
'meiningsmåling': ('meiningsmåling',),
'meiningsmålinga': ('meiningsmåling',),
'meiningsmålingen': ('meiningsmåling',),
'meiningsmålingene': ('meiningsmåling',),
'meiningsmålinger': ('meiningsmåling',),
'meiningsutveksling': ('meiningsutveksling',),
'meiningsutvekslinga': ('meiningsutveksling',),
'meiningsutvekslingen': ('meiningsutveksling',),
'meiningsutvekslingene': ('meiningsutveksling',),
'meiningsutvekslinger': ('meiningsutveksling',),
'meiningsytring': ('meiningsytring',),
'meiningsytringa': ('meiningsytring',),
'meiningsytringen': ('meiningsytring',),
'meiningsytringene': ('meiningsytring',),
'meiningsytringer': ('meiningsytring',),
'meiose': ('meiose',),
'meiosen': ('meiose',),
'meiosene': ('meiose',),
'meioser': ('meiose',),
'meis': ('meis',),
'meisa': ('meis',),
'meisen': ('meis',),
'meisene': ('meis',),
'meiser': ('meis',),
'meis': ('meis',),
'meisa': ('meis',),
'meisen': ('meis',),
'meisene': ('meis',),
'meiser': ('meis',),
'meisa': ('meise',),
'meise': ('meise',),
'meisen': ('meise',),
'meisene': ('meise',),
'meiser': ('meise',),
'meisel': ('meisel',),
'meiselen': ('meisel',),
'meislene': ('meisel',),
'meisler': ('meisel',),
'meissenerporselen': ('meissenerporselen',),
'meissenerporselena': ('meissenerporselen',),
'meissenerporselenene': ('meissenerporselen',),
'meissenerporselener': ('meissenerporselen',),
'meissenerporselenet': ('meissenerporselen',),
'meissenporselen': ('meissenporselen',),
'meissenporselena': ('meissenporselen',),
'meissenporselenene': ('meissenporselen',),
'meissenporselener': ('meissenporselen',),
'meissenporselenet': ('meissenporselen',),
'meitemakk': ('meitemakk',),
'meitemakken': ('meitemakk',),
'meitemakkene': ('meitemakk',),
'meitemakker': ('meitemakk',),
'meitemark': ('meitemark',),
'meitemarken': ('meitemark',),
'meitemarkene': ('meitemark',),
'meitemarker': ('meitemark',),
'mekaniker': ('mekaniker',),
'mekanikere': ('mekaniker',),
'mekanikeren': ('mekaniker',),
'mekanikerer': ('mekaniker',),
'mekanikerne': ('mekaniker',),
'mekanikk': ('mekanikk',),
'mekanikken': ('mekanikk',),
'mekanikkene': ('mekanikk',),
'mekanikker': ('mekanikk',),
'mekanisme': ('mekanisme',),
'mekanismen': ('mekanisme',),
'mekanismene': ('mekanisme',),
'mekanismer': ('mekanisme',),
'mekanist': ('mekanist',),
'mekanisten': ('mekanist',),
'mekanistene': ('mekanist',),
'mekanister': ('mekanist',),
'mekler': ('mekler',),
'meklere': ('mekler',),
'mekleren': ('mekler',),
'meklerer': ('mekler',),
'meklerne': ('mekler',),
'meklerfirma': ('meklerfirma',),
'meklerfirmaene': ('meklerfirma',),
'meklerfirmaer': ('meklerfirma',),
'meklerfirmaet': ('meklerfirma',),
'mekling': ('mekling',),
'meklinga': ('mekling',),
'meklingen': ('mekling',),
'meklingene': ('mekling',),
'meklinger': ('mekling',),
'meklingsmann': ('meklingsmann',),
'meklingsmannen': ('meklingsmann',),
'meklingsmenn': ('meklingsmann',),
'meklingsmennene': ('meklingsmann',),
'mekregauk': ('mekregauk',),
'mekregauken': ('mekregauk',),
'mekregaukene': ('mekregauk',),
'mekregauker': ('mekregauk',),
'meksikaner': ('meksikaner',),
'meksikanere': ('meksikaner',),
'meksikaneren': ('meksikaner',),
'meksikanerer': ('meksikaner',),
'meksikanerne': ('meksikaner',),
'mel': ('mel',),
'melen': ('mel',),
'melene': ('mel',),
'meler': ('mel',),
'mel': ('mel',),
'melen': ('mel',),
'melene': ('mel',),
'meler': ('mel',),
'mel': ('mel',),
'mela': ('mel',),
'melene': ('mel',),
'melet': ('mel',),
'melamin': ('melamin',),
'melamina': ('melamin',),
'melaminene': ('melamin',),
'melaminet': ('melamin',),
'melaminplast': ('melaminplast',),
'melaminplasten': ('melaminplast',),
'melaminplastene': ('melaminplast',),
'melaminplaster': ('melaminplast',),
'melanesier': ('melanesier',),
'melanesiere': ('melanesier',),
'melanesieren': ('melanesier',),
'melanesierer': ('melanesier',),
'melanesierne': ('melanesier',),
'melankoli': ('melankoli',),
'melankolien': ('melankoli',),
'melankoliene': ('melankoli',),
'melankolier': ('melankoli',),
'melankoliker': ('melankoliker',),
'melankolikere': ('melankoliker',),
'melankolikeren': ('melankoliker',),
'melankolikerer': ('melankoliker',),
'melankolikerne': ('melankoliker',),
'melasse': ('melasse',),
'melassen': ('melasse',),
'melassene': ('melasse',),
'melasser': ('melasse',),
'melde': ('melde',),
'melden': ('melde',),
'meldene': ('melde',),
'melder': ('melde',),
'meldeplikt': ('meldeplikt',),
'meldeplikta': ('meldeplikt',),
'meldeplikten': ('meldeplikt',),
'meldepliktene': ('meldeplikt',),
'meldeplikter': ('meldeplikt',),
'melder': ('melder',),
'meldere': ('melder',),
'melderen': ('melder',),
'melderer': ('melder',),
'melderne': ('melder',),
'meldestokk': ('meldestokk',),
'meldestokken': ('meldestokk',),
'meldestokkene': ('meldestokk',),
'meldestokker': ('meldestokk',),
'melding': ('melding',),
'meldinga': ('melding',),
'meldingen': ('melding',),
'meldingene': ('melding',),
'meldinger': ('melding',),
'meldingstjeneste': ('meldingstjeneste',),
'meldingstjenesten': ('meldingstjeneste',),
'meldingstjenestene': ('meldingstjeneste',),
'meldingstjenester': ('meldingstjeneste',),
'meldugg': ('meldugg',),
'melduggen': ('meldugg',),
'melduggene': ('meldugg',),
'meldugger': ('meldugg',),
'mele': ('mele',),
'melen': ('mele',),
'melene': ('mele',),
'meler': ('mele',),
'mele': ('mele',),
'melen': ('mele',),
'melene': ('mele',),
'meler': ('mele',),
'melis': ('melis',),
'melisen': ('melis',),
'melisene': ('melis',),
'meliser': ('melis',),
'melisse': ('melisse',),
'melissen': ('melisse',),
'melissene': ('melisse',),
'melisser': ('melisse',),
'melk': ('melk',),
'melka': ('melk',),
'melken': ('melk',),
'melkene': ('melk',),
'melker': ('melk',),
'melke': ('melke',),
'melken': ('melke',),
'melkene': ('melke',),
'melker': ('melke',),
'melkebil': ('melkebil',),
'melkebilen': ('melkebil',),
'melkebilene': ('melkebil',),
'melkebiler': ('melkebil',),
'melkebutikk': ('melkebutikk',),
'melkebutikken': ('melkebutikk',),
'melkebutikkene': ('melkebutikk',),
'melkebutikker': ('melkebutikk',),
'melkebøtta': ('melkebøtte',),
'melkebøtte': ('melkebøtte',),
'melkebøtten': ('melkebøtte',),
'melkebøttene': ('melkebøtte',),
'melkebøtter': ('melkebøtte',),
'melkefe': ('melkefe',),
'melkefea': ('melkefe',),
'melkefeene': ('melkefe',),
'melkefeet': ('melkefe',),
'melkefeber': ('melkefeber',),
'melkefebere': ('melkefeber',),
'melkefeberen': ('melkefeber',),
'melkefeberne': ('melkefeber',),
'melkefebre': ('melkefeber',),
'melkefebrene': ('melkefeber',),
'melkefebrer': ('melkefeber',),
'melkeflaska': ('melkeflaske',),
'melkeflaske': ('melkeflaske',),
'melkeflasken': ('melkeflaske',),
'melkeflaskene': ('melkeflaske',),
'melkeflasker': ('melkeflaske',),
'melkeglas': ('melkeglas',),
'melkeglasa': ('melkeglas',),
'melkeglasene': ('melkeglas',),
'melkeglaset': ('melkeglas',),
'melkeglass': ('melkeglass',),
'melkeglassa': ('melkeglass',),
'melkeglassene': ('melkeglass',),
'melkeglasset': ('melkeglass',),
'melkekartong': ('melkekartong',),
'melkekartongen': ('melkekartong',),
'melkekartongene': ('melkekartong',),
'melkekartonger': ('melkekartong',),
'melkekjertel': ('melkekjertel',),
'melkekjertelen': ('melkekjertel',),
'melkekjertlene': ('melkekjertel',),
'melkekjertler': ('melkekjertel',),
'melkekolla': ('melkekolle',),
'melkekolle': ('melkekolle',),
'melkekollen': ('melkekolle',),
'melkekollene': ('melkekolle',),
'melkekoller': ('melkekolle',),
'melkeku': ('melkeku',),
'melkekua': ('melkeku',),
'melkekuen': ('melkeku',),
'melkekuene': ('melkeku',),
'melkekuer': ('melkeku',),
'melkekyr': ('melkeku',),
'melkekyrne': ('melkeku',),
'melkemaskin': ('melkemaskin',),
'melkemaskina': ('melkemaskin',),
'melkemaskinen': ('melkemaskin',),
'melkemaskinene': ('melkemaskin',),
'melkemaskiner': ('melkemaskin',),
'melkemat': ('melkemat',),
'melkematen': ('melkemat',),
'melkematene': ('melkemat',),
'melkemater': ('melkemat',),
'melkemugga': ('melkemugge',),
'melkemugge': ('melkemugge',),
'melkemuggen': ('melkemugge',),
'melkemuggene': ('melkemugge',),
'melkemugger': ('melkemugge',),
'melkeproduksjon': ('melkeproduksjon',),
'melkeproduksjonen': ('melkeproduksjon',),
'melkeproduksjonene': ('melkeproduksjon',),
'melkeproduksjoner': ('melkeproduksjon',),
'melkeprodukt': ('melkeprodukt',),
'melkeprodukta': ('melkeprodukt',),
'melkeproduktene': ('melkeprodukt',),
'melkeprodukter': ('melkeprodukt',),
'melkeproduktet': ('melkeprodukt',),
'melkeprodusent': ('melkeprodusent',),
'melkeprodusenten': ('melkeprodusent',),
'melkeprodusentene': ('melkeprodusent',),
'melkeprodusenter': ('melkeprodusent',),
'melkerampa': ('melkerampe',),
'melkerampe': ('melkerampe',),
'melkerampen': ('melkerampe',),
'melkerampene': ('melkerampe',),
'melkeramper': ('melkerampe',),
'melkeringa': ('melkeringe',),
'melkeringe': ('melkeringe',),
'melkeringen': ('melkeringe',),
'melkeringene': ('melkeringe',),
'melkeringer': ('melkeringe',),
'melkeruta': ('melkerute',),
'melkerute': ('melkerute',),
'melkeruten': ('melkerute',),
'melkerutene': ('melkerute',),
'melkeruter': ('melkerute',),
'melkesaft': ('melkesaft',),
'melkesafta': ('melkesaft',),
'melkesaften': ('melkesaft',),
'melkesaftene': ('melkesaft',),
'melkesafter': ('melkesaft',),
'melkesentral': ('melkesentral',),
'melkesentralen': ('melkesentral',),
'melkesentralene': ('melkesentral',),
'melkesentraler': ('melkesentral',),
'melkespann': ('melkespann',),
'melkespanna': ('melkespann',),
'melkespannene': ('melkespann',),
'melkespannet': ('melkespann',),
'melkespreng': ('melkespreng',),
'melkesprenga': ('melkespreng',),
'melkesprengen': ('melkespreng',),
'melkesprengene': ('melkespreng',),
'melkesprenger': ('melkespreng',),
'melkesprenget': ('melkespreng',),
'melkesukker': ('melkesukker',),
'melkesukkera': ('melkesukker',),
'melkesukkere': ('melkesukker',),
'melkesukkerene': ('melkesukker',),
'melkesukkeret': ('melkesukker',),
'melkesukkerne': ('melkesukker',),
'melkesuppa': ('melkesuppe',),
'melkesuppe': ('melkesuppe',),
'melkesuppen': ('melkesuppe',),
'melkesuppene': ('melkesuppe',),
'melkesupper': ('melkesuppe',),
'melkesyra': ('melkesyre',),
'melkesyre': ('melkesyre',),
'melkesyren': ('melkesyre',),
'melkesyrene': ('melkesyre',),
'melkesyrer': ('melkesyre',),
'melkesyrebakterie': ('melkesyrebakterie',),
'melkesyrebakterien': ('melkesyrebakterie',),
'melkesyrebakteriene': ('melkesyrebakterie',),
'melkesyrebakterier': ('melkesyrebakterie',),
'melketann': ('melketann',),
'melketanna': ('melketann',),
'melketannen': ('melketann',),
'melketennene': ('melketann',),
'melketenner': ('melketann',),
'melkeveg': ('melkeveg',),
'melkevegen': ('melkeveg',),
'melkevegene': ('melkeveg',),
'melkeveger': ('melkeveg',),
'melkevegsystem': ('melkevegsystem',),
'melkevegsystema': ('melkevegsystem',),
'melkevegsystemene': ('melkevegsystem',),
'melkevegsystemer': ('melkevegsystem',),
'melkevegsystemet': ('melkevegsystem',),
'melkevei': ('melkevei',),
'melkeveien': ('melkevei',),
'melkeveiene': ('melkevei',),
'melkeveier': ('melkevei',),
'melkeveisystem': ('melkeveisystem',),
'melkeveisystema': ('melkeveisystem',),
'melkeveisystemene': ('melkeveisystem',),
'melkeveisystemer': ('melkeveisystem',),
'melkeveisystemet': ('melkeveisystem',),
'mellomaksel': ('mellomaksel',),
'mellomakselen': ('mellomaksel',),
'mellomakslene': ('mellomaksel',),
'mellomaksler': ('mellomaksel',),
'mellomakt': ('mellomakt',),
'mellomakta': ('mellomakt',),
'mellomakten': ('mellomakt',),
'mellomaktene': ('mellomakt',),
'mellomakter': ('mellomakt',),
'mellomaktsmusikk': ('mellomaktsmusikk',),
'mellomaktsmusikken': ('mellomaktsmusikk',),
'mellomaktsmusikkene': ('mellomaktsmusikk',),
'mellomaktsmusikker': ('mellomaktsmusikk',),
'mellomalder': ('mellomalder',),
'mellomaldere': ('mellomalder',),
'mellomalderen': ('mellomalder',),
'mellomalderer': ('mellomalder',),
'mellomalderne': ('mellomalder',),
'mellomaldre': ('mellomalder',),
'mellomaldrene': ('mellomalder',),
'mellomaldrer': ('mellomalder',),
'mellombølga': ('mellombølge',),
'mellombølge': ('mellombølge',),
'mellombølgen': ('mellombølge',),
'mellombølgene': ('mellombølge',),
'mellombølger': ('mellombølge',),
'mellombølgja': ('mellombølgje',),
'mellombølgje': ('mellombølgje',),
'mellombølgjen': ('mellombølgje',),
'mellombølgjene': ('mellombølgje',),
'mellombølgjer': ('mellombølgje',),
'mellomdekk': ('mellomdekk',),
'mellomdekka': ('mellomdekk',),
'mellomdekkene': ('mellomdekk',),
'mellomdekket': ('mellomdekk',),
'mellomdistanse': ('mellomdistanse',),
'mellomdistansen': ('mellomdistanse',),
'mellomdistansene': ('mellomdistanse',),
'mellomdistanser': ('mellomdistanse',),
'mellomdistanseløper': ('mellomdistanseløper',),
'mellomdistanseløpere': ('mellomdistanseløper',),
'mellomdistanseløperen': ('mellomdistanseløper',),
'mellomdistanseløperer': ('mellomdistanseløper',),
'mellomdistanseløperne': ('mellomdistanseløper',),
'mellomdistanserakett': ('mellomdistanserakett',),
'mellomdistanseraketten': ('mellomdistanserakett',),
'mellomdistanserakettene': ('mellomdistanserakett',),
'mellomdistanseraketter': ('mellomdistanserakett',),
'mellomfag': ('mellomfag',),
'mellomfaga': ('mellomfag',),
'mellomfagene': ('mellomfag',),
'mellomfaget': ('mellomfag',),
'mellomfot': ('mellomfot',),
'mellomfoten': ('mellomfot',),
'mellomføttene': ('mellomfot',),
'mellomføtter': ('mellomfot',),
'mellomgenerasjon': ('mellomgenerasjon',),
'mellomgenerasjonen': ('mellomgenerasjon',),
'mellomgenerasjonene': ('mellomgenerasjon',),
'mellomgenerasjoner': ('mellomgenerasjon',),
'mellomgolv': ('mellomgolv',),
'mellomgolva': ('mellomgolv',),
'mellomgolvene': ('mellomgolv',),
'mellomgolvet': ('mellomgolv',),
'mellomgulv': ('mellomgulv',),
'mellomgulva': ('mellomgulv',),
'mellomgulvene': ('mellomgulv',),
'mellomgulvet': ('mellomgulv',),
'mellomheat': ('mellomheat',),
'mellomheata': ('mellomheat',),
'mellomheatene': ('mellomheat',),
'mellomheatet': ('mellomheat',),
'mellomjul': ('mellomjul',),
'mellomjula': ('mellomjul',),
'mellomjulen': ('mellomjul',),
'mellomjulene': ('mellomjul',),
'mellomjuler': ('mellomjul',),
'mellomklassa': ('mellomklasse',),
'mellomklasse': ('mellomklasse',),
'mellomklassen': ('mellomklasse',),
'mellomklassene': ('mellomklasse',),
'mellomklasser': ('mellomklasse',),
'mellomkomst': ('mellomkomst',),
'mellomkomsten': ('mellomkomst',),
'mellomkomstene': ('mellomkomst',),
'mellomkomster': ('mellomkomst',),
'mellomkrigstid': ('mellomkrigstid',),
'mellomkrigstida': ('mellomkrigstid',),
'mellomkrigstiden': ('mellomkrigstid',),
'mellomkrigstidene': ('mellomkrigstid',),
'mellomkrigstider': ('mellomkrigstid',),
'mellomlag': ('mellomlag',),
'mellomlaga': ('mellomlag',),
'mellomlagene': ('mellomlag',),
'mellomlaget': ('mellomlag',),
'mellomlanding': ('mellomlanding',),
'mellomlandinga': ('mellomlanding',),
'mellomlandingen': ('mellomlanding',),
'mellomlandingene': ('mellomlanding',),
'mellomlandinger': ('mellomlanding',),
'mellomledd': ('mellomledd',),
'mellomledda': ('mellomledd',),
'mellomleddene': ('mellomledd',),
'mellomleddet': ('mellomledd',),
'mellomlegg': ('mellomlegg',),
'mellomlegga': ('mellomlegg',),
'mellomleggene': ('mellomlegg',),
'mellomlegget': ('mellomlegg',),
'mellomleggspapir': ('mellomleggspapir',),
'mellomleggspapira': ('mellomleggspapir',),
'mellomleggspapirene': ('mellomleggspapir',),
'mellomleggspapirer': ('mellomleggspapir',),
'mellomleggspapiret': ('mellomleggspapir',),
'mellommann': ('mellommann',),
'mellommannen': ('mellommann',),
'mellommenn': ('mellommann',),
'mellommennene': ('mellommann',),
'mellommat': ('mellommat',),
'mellommaten': ('mellommat',),
'mellommatene': ('mellommat',),
'mellommater': ('mellommat',),
'mellommåltid': ('mellommåltid',),
'mellommåltida': ('mellommåltid',),
'mellommåltidene': ('mellommåltid',),
'mellommåltider': ('mellommåltid',),
'mellommåltidet': ('mellommåltid',),
'mellomnavn': ('mellomnavn',),
'mellomnavna': ('mellomnavn',),
'mellomnavnene': ('mellomnavn',),
'mellomnavnet': ('mellomnavn',),
'mellomnorsk': ('mellomnorsk',),
'mellomnorsken': ('mellomnorsk',),
'mellomnorskene': ('mellomnorsk',),
'mellomnorsker': ('mellomnorsk',),
'mellomparti': ('mellomparti',),
'mellompartia': ('mellomparti',),
'mellompartiene': ('mellomparti',),
'mellompartier': ('mellomparti',),
'mellompartiet': ('mellomparti',),
'mellomproporsjonal': ('mellomproporsjonal',),
'mellomproporsjonalen': ('mellomproporsjonal',),
'mellomproporsjonalene': ('mellomproporsjonal',),
'mellomproporsjonaler': ('mellomproporsjonal',),
'mellomregning': ('mellomregning',),
'mellomregninga': ('mellomregning',),
'mellomregningen': ('mellomregning',),
'mellomregningene': ('mellomregning',),
'mellomregninger': ('mellomregning',),
'mellomrekning': ('mellomrekning',),
'mellomrekninga': ('mellomrekning',),
'mellomrekningen': ('mellomrekning',),
'mellomrekningene': ('mellomrekning',),
'mellomrekninger': ('mellomrekning',),
'mellomriksveg': ('mellomriksveg',),
'mellomriksvegen': ('mellomriksveg',),
'mellomriksvegene': ('mellomriksveg',),
'mellomriksveger': ('mellomriksveg',),
'mellomriksvei': ('mellomriksvei',),
'mellomriksveien': ('mellomriksvei',),
'mellomriksveiene': ('mellomriksvei',),
'mellomriksveier': ('mellomriksvei',),
'mellomring': ('mellomring',),
'mellomringen': ('mellomring',),
'mellomringene': ('mellomring',),
'mellomringer': ('mellomring',),
'mellomrom': ('mellomrom',),
'mellomromma': ('mellomrom',),
'mellomrommene': ('mellomrom',),
'mellomrommet': ('mellomrom',),
'mellomsjikt': ('mellomsjikt',),
'mellomsjikta': ('mellomsjikt',),
'mellomsjiktene': ('mellomsjikt',),
'mellomsjiktet': ('mellomsjikt',),
'mellomspell': ('mellomspell',),
'mellomspella': ('mellomspell',),
'mellomspellene': ('mellomspell',),
'mellomspellet': ('mellomspell',),
'mellomspill': ('mellomspill',),
'mellomspilla': ('mellomspill',),
'mellomspillene': ('mellomspill',),
'mellomspillet': ('mellomspill',),
'mellomspråk': ('mellomspråk',),
'mellomspråka': ('mellomspråk',),
'mellomspråkene': ('mellomspråk',),
'mellomspråket': ('mellomspråk',),
'mellomstandpunkt': ('mellomstandpunkt',),
'mellomstandpunkta': ('mellomstandpunkt',),
'mellomstandpunktene': ('mellomstandpunkt',),
'mellomstandpunkter': ('mellomstandpunkt',),
'mellomstandpunktet': ('mellomstandpunkt',),
'mellomstilling': ('mellomstilling',),
'mellomstillinga': ('mellomstilling',),
'mellomstillingen': ('mellomstilling',),
'mellomstillingene': ('mellomstilling',),
'mellomstillinger': ('mellomstilling',),
'mellomtid': ('mellomtid',),
'mellomtida': ('mellomtid',),
'mellomtiden': ('mellomtid',),
'mellomtidene': ('mellomtid',),
'mellomtider': ('mellomtid',),
'mellomting': ('mellomting',),
'mellomtinga': ('mellomting',),
'mellomtingen': ('mellomting',),
'mellomtingene': ('mellomting',),
'mellomtungvekt': ('mellomtungvekt',),
'mellomtungvekta': ('mellomtungvekt',),
'mellomtungvekten': ('mellomtungvekt',),
'mellomtungvektene': ('mellomtungvekt',),
'mellomtungvekter': ('mellomtungvekt',),
'mellomveg': ('mellomveg',),
'mellomvegen': ('mellomveg',),
'mellomvegene': ('mellomveg',),
'mellomveger': ('mellomveg',),
'mellomvei': ('mellomvei',),
'mellomveien': ('mellomvei',),
'mellomveiene': ('mellomvei',),
'mellomveier': ('mellomvei',),
'mellomvekt': ('mellomvekt',),
'mellomvekta': ('mellomvekt',),
'mellomvekten': ('mellomvekt',),
'mellomvektene': ('mellomvekt',),
'mellomvekter': ('mellomvekt',),
'mellomvekter': ('mellomvekter',),
'mellomvektere': ('mellomvekter',),
'mellomvekteren': ('mellomvekter',),
'mellomvekterer': ('mellomvekter',),
'mellomvekterne': ('mellomvekter',),
'mellomvektklassa': ('mellomvektklasse',),
'mellomvektklasse': ('mellomvektklasse',),
'mellomvektklassen': ('mellomvektklasse',),
'mellomvektklassene': ('mellomvektklasse',),
'mellomvektklasser': ('mellomvektklasse',),
'mellomvektsklassa': ('mellomvektsklasse',),
'mellomvektsklasse': ('mellomvektsklasse',),
'mellomvektsklassen': ('mellomvektsklasse',),
'mellomvektsklassene': ('mellomvektsklasse',),
'mellomvektsklasser': ('mellomvektsklasse',),
'mellomverk': ('mellomverk',),
'mellomverka': ('mellomverk',),
'mellomverkene': ('mellomverk',),
'mellomverker': ('mellomverk',),
'mellomverket': ('mellomverk',),
'mellomvert': ('mellomvert',),
'mellomverten': ('mellomvert',),
'mellomvertene': ('mellomvert',),
'mellomverter': ('mellomvert',),
'mellomvær': ('mellomvær',),
'mellomværa': ('mellomvær',),
'mellomværene': ('mellomvær',),
'mellomværet': ('mellomvær',),
'mellomværende': ('mellomværende',),
'mellomværendene': ('mellomværende',),
'mellomværender': ('mellomværende',),
'mellomværendet': ('mellomværende',),
'mellomøra': ('mellomøre',),
'mellomøre': ('mellomøre',),
'mellomørene': ('mellomøre',),
'mellomører': ('mellomøre',),
'mellomøret': ('mellomøre',),
'mellomørebetennelse': ('mellomørebetennelse',),
'mellomørebetennelsen': ('mellomørebetennelse',),
'mellomørebetennelsene': ('mellomørebetennelse',),
'mellomørebetennelser': ('mellomørebetennelse',),
'melodi': ('melodi',),
'melodien': ('melodi',),
'melodiene': ('melodi',),
'melodier': ('melodi',),
'melodikk': ('melodikk',),
'melodikken': ('melodikk',),
'melodikkene': ('melodikk',),
'melodikker': ('melodikk',),
'melodont': ('melodont',),
'melodonten': ('melodont',),
'melodontene': ('melodont',),
'melodonter': ('melodont',),
'melodrama': ('melodrama',),
'melodramaene': ('melodrama',),
'melodramaer': ('melodrama',),
'melodramaet': ('melodrama',),
'melon': ('melon',),
'melonen': ('melon',),
'melonene': ('melon',),
'meloner': ('melon',),
'melrakke': ('melrakke',),
'melrakken': ('melrakke',),
'melrakkene': ('melrakke',),
'melrakker': ('melrakke',),
'melting': ('melting',),
'meltinga': ('melting',),
'meltingen': ('melting',),
'meltingene': ('melting',),
'meltinger': ('melting',),
'membran': ('membran',),
'membranen': ('membran',),
'membranene': ('membran',),
'membraner': ('membran',),
'memento': ('memento',),
'mementoa': ('memento',),
'mementoene': ('memento',),
'mementoer': ('memento',),
'mementoet': ('memento',),
'memo': ('memo',),
'memoa': ('memo',),
'memoene': ('memo',),
'memoer': ('memo',),
'memoet': ('memo',),
'memoarene': ('memoarer',),
'memoarer': ('memoarer',),
'memoarforfatter': ('memoarforfatter',),
'memoarforfattere': ('memoarforfatter',),
'memoarforfatteren': ('memoarforfatter',),
'memoarforfatterer': ('memoarforfatter',),
'memoarforfatterne': ('memoarforfatter',),
'memoarlitteratur': ('memoarlitteratur',),
'memoarlitteraturen': ('memoarlitteratur',),
'memoarlitteraturene': ('memoarlitteratur',),
'memoarlitteraturer': ('memoarlitteratur',),
'memoranda': ('memorandum',),
'memorandaene': ('memorandum',),
'memorandum': ('memorandum',),
'memoranduma': ('memorandum',),
'memorandumene': ('memorandum',),
'memorandumer': ('memorandum',),
'memorandumet': ('memorandum',),
'memorial': ('memorial',),
'memorialen': ('memorial',),
'memorialene': ('memorial',),
'memorialer': ('memorial',),
'men': ('men',),
'mena': ('men',),
'menene': ('men',),
'menet': ('men',),
'men': ('men',),
'mena': ('men',),
'menene': ('men',),
'mener': ('men',),
'menet': ('men',),
'menasjeri': ('menasjeri',),
'menasjeria': ('menasjeri',),
'menasjeriene': ('menasjeri',),
'menasjerier': ('menasjeri',),
'menasjeriet': ('menasjeri',),
'mendelevium': ('mendelevium',),
'mendeleviuma': ('mendelevium',),
'mendeleviumene': ('mendelevium',),
'mendeleviumet': ('mendelevium',),
'mene tekel': ('mene tekel',),
'mene tekela': ('mene tekel',),
'mene tekelene': ('mene tekel',),
'mene tekelet': ('mene tekel',),
'mened': ('mened',),
'meneden': ('mened',),
'menedene': ('mened',),
'meneder': ('mened',),
'mengd': ('mengd',),
'mengda': ('mengd',),
'mengden': ('mengd',),
'mengdene': ('mengd',),
'mengder': ('mengd',),
'mengde': ('mengde',),
'mengden': ('mengde',),
'mengdene': ('mengde',),
'mengder': ('mengde',),
'mengdeenhet': ('mengdeenhet',),
'mengdeenheten': ('mengdeenhet',),
'mengdeenhetene': ('mengdeenhet',),
'mengdeenheter': ('mengdeenhet',),
'mengdelæra': ('mengdelære',),
'mengdelære': ('mengdelære',),
'mengdelæren': ('mengdelære',),
'mengdelærene': ('mengdelære',),
'mengdelærer': ('mengdelære',),
'menighet': ('menighet',),
'menigheta': ('menighet',),
'menigheten': ('menighet',),
'menighetene': ('menighet',),
'menigheter': ('menighet',),
'menighetsblad': ('menighetsblad',),
'menighetsblada': ('menighetsblad',),
'menighetsbladene': ('menighetsblad',),
'menighetsblader': ('menighetsblad',),
'menighetsbladet': ('menighetsblad',),
'menighetsfakultet': ('menighetsfakultet',),
'menighetsfakulteta': ('menighetsfakultet',),
'menighetsfakultetene': ('menighetsfakultet',),
'menighetsfakulteter': ('menighetsfakultet',),
'menighetsfakultetet': ('menighetsfakultet',),
'menighetshus': ('menighetshus',),
'menighetshusa': ('menighetshus',),
'menighetshusene': ('menighetshus',),
'menighetshuset': ('menighetshus',),
'menighetspleia': ('menighetspleie',),
'menighetspleie': ('menighetspleie',),
'menighetspleien': ('menighetspleie',),
'menighetspleiene': ('menighetspleie',),
'menighetspleier': ('menighetspleie',),
'menighetsråd': ('menighetsråd',),
'menighetsråda': ('menighetsråd',),
'menighetsrådene': ('menighetsråd',),
'menighetsrådet': ('menighetsråd',),
'menighetssekretær': ('menighetssekretær',),
'menighetssekretæren': ('menighetssekretær',),
'menighetssekretærene': ('menighetssekretær',),
'menighetssekretærer': ('menighetssekretær',),
'menighetssøster': ('menighetssøster',),
'menighetssøstera': ('menighetssøster',),
'menighetssøsteren': ('menighetssøster',),
'menighetssøstre': ('menighetssøster',),
'menighetssøstrene': ('menighetssøster',),
'menighetssøstrer': ('menighetssøster',),
'menigmann': ('menigmann',),
'menigmannen': ('menigmann',),
'menigmenn': ('menigmann',),
'menigmennene': ('menigmann',),
'mening': ('mening',),
'meninga': ('mening',),
'meningen': ('mening',),
'meningene': ('mening',),
'meninger': ('mening',),
'meningitt': ('meningitt',),
'meningitten': ('meningitt',),
'meningittene': ('meningitt',),
'meningitter': ('meningitt',),
'meningsbryting': ('meningsbryting',),
'meningsbrytinga': ('meningsbryting',),
'meningsbrytingen': ('meningsbryting',),
'meningsbrytingene': ('meningsbryting',),
'meningsbrytinger': ('meningsbryting',),
'meningsbrytning': ('meningsbrytning',),
'meningsbrytninga': ('meningsbrytning',),
'meningsbrytningen': ('meningsbrytning',),
'meningsbrytningene': ('meningsbrytning',),
'meningsbrytninger': ('meningsbrytning',),
'meningsfelle': ('meningsfelle',),
'meningsfellen': ('meningsfelle',),
'meningsfellene': ('meningsfelle',),
'meningsfeller': ('meningsfelle',),
'meningsforskjell': ('meningsforskjell',),
'meningsforskjellen': ('meningsforskjell',),
'meningsforskjellene': ('meningsforskjell',),
'meningsforskjeller': ('meningsforskjell',),
'meningsfrende': ('meningsfrende',),
'meningsfrenden': ('meningsfrende',),
'meningsfrendene': ('meningsfrende',),
'meningsfrender': ('meningsfrende',),
'meningsfylde': ('meningsfylde',),
'meningsfylden': ('meningsfylde',),
'meningsfyldene': ('meningsfylde',),
'meningsfylder': ('meningsfylde',),
'meningsfylde': ('meningsfylde',),
'meningsfylden': ('meningsfylde',),
'meningsfyldene': ('meningsfylde',),
'meningsfylder': ('meningsfylde',),
'meningsmåling': ('meningsmåling',),
'meningsmålinga': ('meningsmåling',),
'meningsmålingen': ('meningsmåling',),
'meningsmålingene': ('meningsmåling',),
'meningsmålinger': ('meningsmåling',),
'meningsutveksling': ('meningsutveksling',),
'meningsutvekslinga': ('meningsutveksling',),
'meningsutvekslingen': ('meningsutveksling',),
'meningsutvekslingene': ('meningsutveksling',),
'meningsutvekslinger': ('meningsutveksling',),
'meningsytring': ('meningsytring',),
'meningsytringa': ('meningsytring',),
'meningsytringen': ('meningsytring',),
'meningsytringene': ('meningsytring',),
'meningsytringer': ('meningsytring',),
'menisk': ('menisk',),
'menisken': ('menisk',),
'meniskene': ('menisk',),
'menisker': ('menisk',),
'meniskskade': ('meniskskade',),
'meniskskaden': ('meniskskade',),
'meniskskadene': ('meniskskade',),
'meniskskader': ('meniskskade',),
'menneska': ('menneske',),
'menneske': ('menneske',),
'menneskene': ('menneske',),
'mennesker': ('menneske',),
'mennesket': ('menneske',),
'menneskealder': ('menneskealder',),
'menneskealdere': ('menneskealder',),
'menneskealderen': ('menneskealder',),
'menneskealderer': ('menneskealder',),
'menneskealderne': ('menneskealder',),
'menneskealdre': ('menneskealder',),
'menneskealdrene': ('menneskealder',),
'menneskealdrer': ('menneskealder',),
'menneskeapa': ('menneskeape',),
'menneskeape': ('menneskeape',),
'menneskeapen': ('menneskeape',),
'menneskeapene': ('menneskeape',),
'menneskeaper': ('menneskeape',),
'menneskebarn': ('menneskebarn',),
'menneskebarna': ('menneskebarn',),
'menneskebarnene': ('menneskebarn',),
'menneskebarnet': ('menneskebarn',),
'menneskeeter': ('menneskeeter',),
'menneskeetere': ('menneskeeter',),
'menneskeeteren': ('menneskeeter',),
'menneskeeterer': ('menneskeeter',),
'menneskeeterne': ('menneskeeter',),
'menneskefiende': ('menneskefiende',),
'menneskefienden': ('menneskefiende',),
'menneskefiendene': ('menneskefiende',),
'menneskefiender': ('menneskefiende',),
'menneskefisker': ('menneskefisker',),
'menneskefiskere': ('menneskefisker',),
'menneskefiskeren': ('menneskefisker',),
'menneskefiskerer': ('menneskefisker',),
'menneskefiskerne': ('menneskefisker',),
'menneskeflokk': ('menneskeflokk',),
'menneskeflokken': ('menneskeflokk',),
'menneskeflokkene': ('menneskeflokk',),
'menneskeflokker': ('menneskeflokk',),
'menneskeforakt': ('menneskeforakt',),
'menneskeforakten': ('menneskeforakt',),
'menneskeforaktene': ('menneskeforakt',),
'menneskeforakter': ('menneskeforakt',),
'menneskeføda': ('menneskeføde',),
'menneskeføde': ('menneskeføde',),
'menneskeføden': ('menneskeføde',),
'menneskefødene': ('menneskeføde',),
'menneskeføder': ('menneskeføde',),
'menneskehet': ('menneskehet',),
'menneskeheta': ('menneskehet',),
'menneskeheten': ('menneskehet',),
'menneskehetene': ('menneskehet',),
'menneskeheter': ('menneskehet',),
'menneskekjenner': ('menneskekjenner',),
'menneskekjennere': ('menneskekjenner',),
'menneskekjenneren': ('menneskekjenner',),
'menneskekjennerer': ('menneskekjenner',),
'menneskekjennerne': ('menneskekjenner',),
'menneskekropp': ('menneskekropp',),
'menneskekroppen': ('menneskekropp',),
'menneskekroppene': ('menneskekropp',),
'menneskekropper': ('menneskekropp',),
'menneskekunnskap': ('menneskekunnskap',),
'menneskekunnskapen': ('menneskekunnskap',),
'menneskekunnskapene': ('menneskekunnskap',),
'menneskekunnskaper': ('menneskekunnskap',),
'menneskelighet': ('menneskelighet',),
'menneskeligheta': ('menneskelighet',),
'menneskeligheten': ('menneskelighet',),
'menneskelighetene': ('menneskelighet',),
'menneskeligheter': ('menneskelighet',),
'menneskeliv': ('menneskeliv',),
'menneskeliva': ('menneskeliv',),
'menneskelivene': ('menneskeliv',),
'menneskelivet': ('menneskeliv',),
'menneskemasse': ('menneskemasse',),
'menneskemassen': ('menneskemasse',),
'menneskemassene': ('menneskemasse',),
'menneskemasser': ('menneskemasse',),
'menneskemengd': ('menneskemengd',),
'menneskemengda': ('menneskemengd',),
'menneskemengden': ('menneskemengd',),
'menneskemengdene': ('menneskemengd',),
'menneskemengder': ('menneskemengd',),
'menneskemengde': ('menneskemengde',),
'menneskemengden': ('menneskemengde',),
'menneskemengdene': ('menneskemengde',),
'menneskemengder': ('menneskemengde',),
'menneskenatur': ('menneskenatur',),
'menneskenaturen': ('menneskenatur',),
'menneskenaturene': ('menneskenatur',),
'menneskenaturer': ('menneskenatur',),
'menneskerase': ('menneskerase',),
'menneskerasen': ('menneskerase',),
'menneskerasene': ('menneskerase',),
'menneskeraser': ('menneskerase',),
'menneskerett': ('menneskerett',),
'menneskeretten': ('menneskerett',),
'menneskerettene': ('menneskerett',),
'menneskeretter': ('menneskerett',),
'menneskerettighet': ('menneskerettighet',),
'menneskerettigheta': ('menneskerettighet',),
'menneskerettigheten': ('menneskerettighet',),
'menneskerettighetene': ('menneskerettighet',),
'menneskerettigheter': ('menneskerettighet',),
'menneskerettighetsdomstol': ('menneskerettighetsdomstol',),
'menneskerettighetsdomstolen': ('menneskerettighetsdomstol',),
'menneskerettighetsdomstolene': ('menneskerettighetsdomstol',),
'menneskerettighetsdomstoler': ('menneskerettighetsdomstol',),
'menneskerettighetserklæring': ('menneskerettighetserklæring',),
'menneskerettighetserklæringa': ('menneskerettighetserklæring',),
'menneskerettighetserklæringen': ('menneskerettighetserklæring',),
'menneskerettighetserklæringene': ('menneskerettighetserklæring',),
'menneskerettighetserklæringer': ('menneskerettighetserklæring',),
'menneskerettighetsforkjemper': ('menneskerettighetsforkjemper',),
'menneskerettighetsforkjempere': ('menneskerettighetsforkjemper',),
'menneskerettighetsforkjemperen': ('menneskerettighetsforkjemper',),
'menneskerettighetsforkjemperer': ('menneskerettighetsforkjemper',),
'menneskerettighetsforkjemperne': ('menneskerettighetsforkjemper',),
'menneskerettighetskommisjon': ('menneskerettighetskommisjon',),
'menneskerettighetskommisjonen': ('menneskerettighetskommisjon',),
'menneskerettighetskommisjonene': ('menneskerettighetskommisjon',),
'menneskerettighetskommisjoner': ('menneskerettighetskommisjon',),
'menneskerettighetskonvensjon': ('menneskerettighetskonvensjon',),
'menneskerettighetskonvensjonen': ('menneskerettighetskonvensjon',),
'menneskerettighetskonvensjonene': ('menneskerettighetskonvensjon',),
'menneskerettighetskonvensjoner': ('menneskerettighetskonvensjon',),
'menneskerettsdomstol': ('menneskerettsdomstol',),
'menneskerettsdomstolen': ('menneskerettsdomstol',),
'menneskerettsdomstolene': ('menneskerettsdomstol',),
'menneskerettsdomstoler': ('menneskerettsdomstol',),
'menneskerettserklæring': ('menneskerettserklæring',),
'menneskerettserklæringa': ('menneskerettserklæring',),
'menneskerettserklæringen': ('menneskerettserklæring',),
'menneskerettserklæringene': ('menneskerettserklæring',),
'menneskerettserklæringer': ('menneskerettserklæring',),
'menneskerettsforkjemper': ('menneskerettsforkjemper',),
'menneskerettsforkjempere': ('menneskerettsforkjemper',),
'menneskerettsforkjemperen': ('menneskerettsforkjemper',),
'menneskerettsforkjemperer': ('menneskerettsforkjemper',),
'menneskerettsforkjemperne': ('menneskerettsforkjemper',),
'menneskerettskommisjon': ('menneskerettskommisjon',),
'menneskerettskommisjonen': ('menneskerettskommisjon',),
'menneskerettskommisjonene': ('menneskerettskommisjon',),
'menneskerettskommisjoner': ('menneskerettskommisjon',),
'menneskerettskonvensjon': ('menneskerettskonvensjon',),
'menneskerettskonvensjonen': ('menneskerettskonvensjon',),
'menneskerettskonvensjonene': ('menneskerettskonvensjon',),
'menneskerettskonvensjoner': ('menneskerettskonvensjon',),
'menneskerøst': ('menneskerøst',),
'menneskerøsta': ('menneskerøst',),
'menneskerøsten': ('menneskerøst',),
'menneskerøstene': ('menneskerøst',),
'menneskerøster': ('menneskerøst',),
'menneskesinn': ('menneskesinn',),
'menneskesinna': ('menneskesinn',),
'menneskesinnene': ('menneskesinn',),
'menneskesinnet': ('menneskesinn',),
'menneskesjel': ('menneskesjel',),
'menneskesjela': ('menneskesjel',),
'menneskesjelen': ('menneskesjel',),
'menneskesjelene': ('menneskesjel',),
'menneskesjeler': ('menneskesjel',),
'menneskeskildring': ('menneskeskildring',),
'menneskeskildringa': ('menneskeskildring',),
'menneskeskildringen': ('menneskeskildring',),
'menneskeskildringene': ('menneskeskildring',),
'menneskeskildringer': ('menneskeskildring',),
'menneskeslekt': ('menneskeslekt',),
'menneskeslekta': ('menneskeslekt',),
'menneskeslekten': ('menneskeslekt',),
'menneskeslektene': ('menneskeslekt',),
'menneskeslekter': ('menneskeslekt',),
'menneskesyn': ('menneskesyn',),
'menneskesyna': ('menneskesyn',),
'menneskesynene': ('menneskesyn',),
'menneskesynet': ('menneskesyn',),
'menneskesønn': ('menneskesønn',),
'menneskesønnen': ('menneskesønn',),
'menneskesønnene': ('menneskesønn',),
'menneskesønner': ('menneskesønn',),
'mennesketype': ('mennesketype',),
'mennesketypen': ('mennesketype',),
'mennesketypene': ('mennesketype',),
'mennesketyper': ('mennesketype',),
'menneskevenn': ('menneskevenn',),
'menneskevennen': ('menneskevenn',),
'menneskevennene': ('menneskevenn',),
'menneskevenner': ('menneskevenn',),
'menneskeverd': ('menneskeverd',),
'menneskeverda': ('menneskeverd',),
'menneskeverdene': ('menneskeverd',),
'menneskeverdet': ('menneskeverd',),
'menneskeverk': ('menneskeverk',),
'menneskeverka': ('menneskeverk',),
'menneskeverkene': ('menneskeverk',),
'menneskeverker': ('menneskeverk',),
'menneskeverket': ('menneskeverk',),
'menneskeætt': ('menneskeætt',),
'menneskeætta': ('menneskeætt',),
'menneskeætten': ('menneskeætt',),
'menneskeættene': ('menneskeætt',),
'menneskeætter': ('menneskeætt',),
'menopause': ('menopause',),
'menopausen': ('menopause',),
'menopausene': ('menopause',),
'menopauser': ('menopause',),
'mens': ('mens',),
'mensen': ('mens',),
'mensene': ('mens',),
'menser': ('mens',),
'mensendieckgymnastikk': ('mensendieckgymnastikk',),
'mensendieckgymnastikken': ('mensendieckgymnastikk',),
'mensendieckgymnastikkene': ('mensendieckgymnastikk',),
'mensendieckgymnastikker': ('mensendieckgymnastikk',),
'menses': ('menses',),
'mensjevik': ('mensjevik',),
'mensjeviken': ('mensjevik',),
'mensjevikene': ('mensjevik',),
'mensjeviker': ('mensjevik',),
'menstruasjon': ('menstruasjon',),
'menstruasjonen': ('menstruasjon',),
'menstruasjonene': ('menstruasjon',),
'menstruasjoner': ('menstruasjon',),
'menstruasjonsbind': ('menstruasjonsbind',),
'menstruasjonsbinda': ('menstruasjonsbind',),
'menstruasjonsbindene': ('menstruasjonsbind',),
'menstruasjonsbindet': ('menstruasjonsbind',),
'menstruasjonsblod': ('menstruasjonsblod',),
'menstruasjonsbloda': ('menstruasjonsblod',),
'menstruasjonsblodene': ('menstruasjonsblod',),
'menstruasjonsblodet': ('menstruasjonsblod',),
'menstruasjonssmerte': ('menstruasjonssmerte',),
'menstruasjonssmerten': ('menstruasjonssmerte',),
'menstruasjonssmertene': ('menstruasjonssmerte',),
'menstruasjonssmerter': ('menstruasjonssmerte',),
'menstruasjonssyklus': ('menstruasjonssyklus',),
'menstruasjonssyklusen': ('menstruasjonssyklus',),
'menstruasjonssyklusene': ('menstruasjonssyklus',),
'menstruasjonssykluser': ('menstruasjonssyklus',),
'mentalhygiene': ('mentalhygiene',),
'mentalhygienen': ('mentalhygiene',),
'mentalhygienene': ('mentalhygiene',),
'mentalhygiener': ('mentalhygiene',),
'mentalitet': ('mentalitet',),
'mentaliteten': ('mentalitet',),
'mentalitetene': ('mentalitet',),
'mentaliteter': ('mentalitet',),
'mentalitetsendring': ('mentalitetsendring',),
'mentalitetsendringa': ('mentalitetsendring',),
'mentalitetsendringen': ('mentalitetsendring',),
'mentalitetsendringene': ('mentalitetsendring',),
'mentalitetsendringer': ('mentalitetsendring',),
'mentalsjukehus': ('mentalsjukehus',),
'mentalsjukehusa': ('mentalsjukehus',),
'mentalsjukehusene': ('mentalsjukehus',),
'mentalsjukehuset': ('mentalsjukehus',),
'mentalsykehus': ('mentalsykehus',),
'mentalsykehusa': ('mentalsykehus',),
'mentalsykehusene': ('mentalsykehus',),
'mentalsykehuset': ('mentalsykehus',),
'mentalundersøkelse': ('mentalundersøkelse',),
'mentalundersøkelsen': ('mentalundersøkelse',),
'mentalundersøkelsene': ('mentalundersøkelse',),
'mentalundersøkelser': ('mentalundersøkelse',),
'mentalundersøking': ('mentalundersøking',),
'mentalundersøkinga': ('mentalundersøking',),
'mentalundersøkingen': ('mentalundersøking',),
'mentalundersøkingene': ('mentalundersøking',),
'mentalundersøkinger': ('mentalundersøking',),
'mente': ('mente',),
'menten': ('mente',),
'mentene': ('mente',),
'menter': ('mente',),
'mentetal': ('mentetal',),
'mentetala': ('mentetal',),
'mentetalene': ('mentetal',),
'mentetalet': ('mentetal',),
'mentetall': ('mentetall',),
'mentetalla': ('mentetall',),
'mentetallene': ('mentetall',),
'mentetallet': ('mentetall',),
'mentol': ('mentol',),
'mentolen': ('mentol',),
'mentolene': ('mentol',),
'mentoler': ('mentol',),
'mentometer': ('mentometer',),
'mentometeret': ('mentometer',),
'mentometra': ('mentometer',),
'mentometre': ('mentometer',),
'mentometrene': ('mentometer',),
'mentometret': ('mentometer',),
'mentometerknapp': ('mentometerknapp',),
'mentometerknappen': ('mentometerknapp',),
'mentometerknappene': ('mentometerknapp',),
'mentometerknapper': ('mentometerknapp',),
'mentor': ('mentor',),
'mentoren': ('mentor',),
'mentorene': ('mentor',),
'mentorer': ('mentor',),
'menuett': ('menuett',),
'menuetten': ('menuett',),
'menuettene': ('menuett',),
'menuetter': ('menuett',),
'meny': ('meny',),
'menyen': ('meny',),
'menyene': ('meny',),
'menyer': ('meny',),
'merarbeid': ('merarbeid',),
'merarbeida': ('merarbeid',),
'merarbeidene': ('merarbeid',),
'merarbeider': ('merarbeid',),
'merarbeidet': ('merarbeid',),
'merd': ('merd',),
'merden': ('merd',),
'merdene': ('merd',),
'merder': ('merd',),
'merg': ('merg',),
'mergen': ('merg',),
'mergene': ('merg',),
'merger': ('merg',),
'merg': ('merg',),
'mergen': ('merg',),
'mergene': ('merg',),
'merger': ('merg',),
'mergbein': ('mergbein',),
'mergbeina': ('mergbein',),
'mergbeinene': ('mergbein',),
'mergbeinet': ('mergbein',),
'mergbein': ('mergbein',),
'mergbeina': ('mergbein',),
'mergbeinene': ('mergbein',),
'mergbeinet': ('mergbein',),
'mergben': ('mergben',),
'mergbena': ('mergben',),
'mergbenene': ('mergben',),
'mergbenet': ('mergben',),
'mergel': ('mergel',),
'mergelen': ('mergel',),
'merglene': ('mergel',),
'mergler': ('mergel',),
'mergpostei': ('mergpostei',),
'mergposteien': ('mergpostei',),
'mergposteiene': ('mergpostei',),
'mergposteier': ('mergpostei',),
'mergpostei': ('mergpostei',),
'mergposteien': ('mergpostei',),
'mergposteiene': ('mergpostei',),
'mergposteier': ('mergpostei',),
'merian': ('merian',),
'merianen': ('merian',),
'merianene': ('merian',),
'merianer': ('merian',),
'merianolja': ('merianolje',),
'merianolje': ('merianolje',),
'merianoljen': ('merianolje',),
'merianoljene': ('merianolje',),
'merianoljer': ('merianolje',),
'meriansalva': ('meriansalve',),
'meriansalve': ('meriansalve',),
'meriansalven': ('meriansalve',),
'meriansalvene': ('meriansalve',),
'meriansalver': ('meriansalve',),
'meridian': ('meridian',),
'meridianen': ('meridian',),
'meridianene': ('meridian',),
'meridianer': ('meridian',),
'merinntekt': ('merinntekt',),
'merinntekta': ('merinntekt',),
'merinntekten': ('merinntekt',),
'merinntektene': ('merinntekt',),
'merinntekter': ('merinntekt',),
'merinntektsskatt': ('merinntektsskatt',),
'merinntektsskatten': ('merinntektsskatt',),
'merinntektsskattene': ('merinntektsskatt',),
'merinntektsskatter': ('merinntektsskatt',),
'merino': ('merino',),
'merinoa': ('merino',),
'merinoen': ('merino',),
'merinoene': ('merino',),
'merinoer': ('merino',),
'merinoet': ('merino',),
'merinosau': ('merinosau',),
'merinosauen': ('merinosau',),
'merinosauene': ('merinosau',),
'merinosauer': ('merinosau',),
'merinoull': ('merinoull',),
'merinoulla': ('merinoull',),
'merinoullen': ('merinoull',),
'merinoullene': ('merinoull',),
'merinouller': ('merinoull',),
'meritokrat': ('meritokrat',),
'meritokraten': ('meritokrat',),
'meritokratene': ('meritokrat',),
'meritokrater': ('meritokrat',),
'meritokrati': ('meritokrati',),
'meritokratia': ('meritokrati',),
'meritokratiene': ('meritokrati',),
'meritokratier': ('meritokrati',),
'meritokratiet': ('meritokrati',),
'meritt': ('meritt',),
'meritten': ('meritt',),
'merittene': ('meritt',),
'meritter': ('meritt',),
'merittlista': ('merittliste',),
'merittliste': ('merittliste',),
'merittlisten': ('merittliste',),
'merittlistene': ('merittliste',),
'merittlister': ('merittliste',),
'merkantilisme': ('merkantilisme',),
'merkantilismen': ('merkantilisme',),
'merkantilismene': ('merkantilisme',),
'merkantilismer': ('merkantilisme',),
'merka': ('merke',),
'merke': ('merke',),
'merkene': ('merke',),
'merker': ('merke',),
'merket': ('merke',),
'merkedag': ('merkedag',),
'merkedagen': ('merkedag',),
'merkedagene': ('merkedag',),
'merkedager': ('merkedag',),
'merkelapp': ('merkelapp',),
'merkelappen': ('merkelapp',),
'merkelappene': ('merkelapp',),
'merkelapper': ('merkelapp',),
'merkepæl': ('merkepæl',),
'merkepælen': ('merkepæl',),
'merkepælene': ('merkepæl',),
'merkepæler': ('merkepæl',),
'merkesak': ('merkesak',),
'merkesaka': ('merkesak',),
'merkesaken': ('merkesak',),
'merkesakene': ('merkesak',),
'merkesaker': ('merkesak',),
'merkesmann': ('merkesmann',),
'merkesmannen': ('merkesmann',),
'merkesmenn': ('merkesmann',),
'merkesmennene': ('merkesmann',),
'merkestang': ('merkestang',),
'merkestanga': ('merkestang',),
'merkestangen': ('merkestang',),
'merkestengene': ('merkestang',),
'merkestenger': ('merkestang',),
'merkestein': ('merkestein',),
'merkesteinen': ('merkestein',),
'merkesteinene': ('merkestein',),
'merkesteiner': ('merkestein',),
'merkevara': ('merkevare',),
'merkevare': ('merkevare',),
'merkevaren': ('merkevare',),
'merkevarene': ('merkevare',),
'merkevarer': ('merkevare',),
'merkeverksted': ('merkeverksted',),
'merkeverkstedene': ('merkeverksted',),
'merkeverksteder': ('merkeverksted',),
'merkeverkstedet': ('merkeverksted',),
'merkevesen': ('merkevesen',),
'merkevesena': ('merkevesen',),
'merkevesenene': ('merkevesen',),
'merkevesener': ('merkevesen',),
'merkevesenet': ('merkevesen',),
'merkeår': ('merkeår',),
'merkeåra': ('merkeår',),
'merkeårene': ('merkeår',),
'merkeåret': ('merkeår',),
'merking': ('merking',),
'merkinga': ('merking',),
'merkingen': ('merking',),
'merkingene': ('merking',),
'merkinger': ('merking',),
'merknad': ('merknad',),
'merknaden': ('merknad',),
'merknadene': ('merknad',),
'merknader': ('merknad',),
'merkostnad': ('merkostnad',),
'merkostnaden': ('merkostnad',),
'merkostnadene': ('merkostnad',),
'merkostnader': ('merkostnad',),
'merkverdighet': ('merkverdighet',),
'merkverdigheta': ('merkverdighet',),
'merkverdigheten': ('merkverdighet',),
'merkverdighetene': ('merkverdighet',),
'merkverdigheter': ('merkverdighet',),
'merlespiker': ('merlespiker',),
'merlespikere': ('merlespiker',),
'merlespikeren': ('merlespiker',),
'merlespikerne': ('merlespiker',),
'merlespikre': ('merlespiker',),
'merlespikrene': ('merlespiker',),
'merlespikrer': ('merlespiker',),
'merlestikk': ('merlestikk',),
'merlestikka': ('merlestikk',),
'merlestikkene': ('merlestikk',),
'merlestikket': ('merlestikk',),
'merlspiker': ('merlspiker',),
'merlspikere': ('merlspiker',),
'merlspikeren': ('merlspiker',),
'merlspikerne': ('merlspiker',),
'merlspikre': ('merlspiker',),
'merlspikrene': ('merlspiker',),
'merlspikrer': ('merlspiker',),
'merovinger': ('merovinger',),
'merovingere': ('merovinger',),
'merovingeren': ('merovinger',),
'merovingerer': ('merovinger',),
'merovingerne': ('merovinger',),
'merovingertid': ('merovingertid',),
'merovingertida': ('merovingertid',),
'merovingertiden': ('merovingertid',),
'merovingertidene': ('merovingertid',),
'merovingertider': ('merovingertid',),
'merr': ('merr',),
'merra': ('merr',),
'merren': ('merr',),
'merrene': ('merr',),
'merrer': ('merr',),
'merraflåer': ('merraflåer',),
'merraflåere': ('merraflåer',),
'merraflåeren': ('merraflåer',),
'merraflåerer': ('merraflåer',),
'merraflåerne': ('merraflåer',),
'mers': ('mers',),
'mersa': ('mers',),
'mersene': ('mers',),
'merset': ('mers',),
'mersestang': ('mersestang',),
'mersestanga': ('mersestang',),
'mersestangen': ('mersestang',),
'mersestengene': ('mersestang',),
'mersestenger': ('mersestang',),
'merskum': ('merskum',),
'merskumma': ('merskum',),
'merskummen': ('merskum',),
'merskummene': ('merskum',),
'merskummer': ('merskum',),
'merskummet': ('merskum',),
'merskumspipa': ('merskumspipe',),
'merskumspipe': ('merskumspipe',),
'merskumspipen': ('merskumspipe',),
'merskumspipene': ('merskumspipe',),
'merskumspiper': ('merskumspipe',),
'mersmak': ('mersmak',),
'mersmaken': ('mersmak',),
'mersmakene': ('mersmak',),
'mersmaker': ('mersmak',),
'merssegl': ('merssegl',),
'merssegla': ('merssegl',),
'mersseglene': ('merssegl',),
'mersseglet': ('merssegl',),
'mersseil': ('mersseil',),
'mersseila': ('mersseil',),
'mersseilene': ('mersseil',),
'mersseilet': ('mersseil',),
'merutbytta': ('merutbytte',),
'merutbytte': ('merutbytte',),
'merutbyttene': ('merutbytte',),
'merutbytter': ('merutbytte',),
'merutbyttet': ('merutbytte',),
'merutgift': ('merutgift',),
'merutgifta': ('merutgift',),
'merutgiften': ('merutgift',),
'merutgiftene': ('merutgift',),
'merutgifter': ('merutgift',),
'merverdi': ('merverdi',),
'merverdien': ('merverdi',),
'merverdiene': ('merverdi',),
'merverdier': ('merverdi',),
'merverdiavgift': ('merverdiavgift',),
'merverdiavgifta': ('merverdiavgift',),
'merverdiavgiften': ('merverdiavgift',),
'merverdiavgiftene': ('merverdiavgift',),
'merverdiavgifter': ('merverdiavgift',),
'mesallianse': ('mesallianse',),
'mesalliansen': ('mesallianse',),
'mesalliansene': ('mesallianse',),
'mesallianser': ('mesallianse',),
'mesan': ('mesan',),
'mesanen': ('mesan',),
'mesanene': ('mesan',),
'mesaner': ('mesan',),
'mesanin': ('mesanin',),
'mesaninen': ('mesanin',),
'mesaninene': ('mesanin',),
'mesaniner': ('mesanin',),
'mesaninetasje': ('mesaninetasje',),
'mesaninetasjen': ('mesaninetasje',),
'mesaninetasjene': ('mesaninetasje',),
'mesaninetasjer': ('mesaninetasje',),
'mesanmast': ('mesanmast',),
'mesanmasta': ('mesanmast',),
'mesanmasten': ('mesanmast',),
'mesanmastene': ('mesanmast',),
'mesanmaster': ('mesanmast',),
'mesen': ('mesen',),
'mesenen': ('mesen',),
'mesenene': ('mesen',),
'mesener': ('mesen',),
'mesenat': ('mesenat',),
'mesenaten': ('mesenat',),
'mesenatene': ('mesenat',),
'mesenater': ('mesenat',),
'mesk': ('mesk',),
'mesken': ('mesk',),
'meskene': ('mesk',),
'mesker': ('mesk',),
'meskalin': ('meskalin',),
'meskalina': ('meskalin',),
'meskalinene': ('meskalin',),
'meskalinet': ('meskalin',),
'meslingene': ('meslinger',),
'meslinger': ('meslinger',),
'mesoderm': ('mesoderm',),
'mesodermen': ('mesoderm',),
'mesodermene': ('mesoderm',),
'mesodermer': ('mesoderm',),
'meson': ('meson',),
'mesona': ('meson',),
'mesonene': ('meson',),
'mesoner': ('meson',),
'mesonet': ('meson',),
'mesonatom': ('mesonatom',),
'mesonatoma': ('mesonatom',),
'mesonatomene': ('mesonatom',),
'mesonatomer': ('mesonatom',),
'mesonatomet': ('mesonatom',),
'mesopotamier': ('mesopotamier',),
'mesopotamiere': ('mesopotamier',),
'mesopotamieren': ('mesopotamier',),
'mesopotamierer': ('mesopotamier',),
'mesopotamierne': ('mesopotamier',),
'mesozoikum': ('mesozoikum',),
'messa': ('messe',),
'messe': ('messe',),
'messen': ('messe',),
'messene': ('messe',),
'messer': ('messe',),
'messa': ('messe',),
'messe': ('messe',),
'messen': ('messe',),
'messene': ('messe',),
'messer': ('messe',),
'messa': ('messe',),
'messe': ('messe',),
'messen': ('messe',),
'messene': ('messe',),
'messer': ('messe',),
'messefall': ('messefall',),
'messefalla': ('messefall',),
'messefallene': ('messefall',),
'messefallet': ('messefall',),
'messegutt': ('messegutt',),
'messegutten': ('messegutt',),
'messeguttene': ('messegutt',),
'messegutter': ('messegutt',),
'messehagel': ('messehagel',),
'messehagelen': ('messehagel',),
'messehaglene': ('messehagel',),
'messehagler': ('messehagel',),
'messehall': ('messehall',),
'messehallen': ('messehall',),
'messehallene': ('messehall',),
'messehaller': ('messehall',),
'messepika': ('messepike',),
'messepike': ('messepike',),
'messepiken': ('messepike',),
'messepikene': ('messepike',),
'messepiker': ('messepike',),
'messeskjorta': ('messeskjorte',),
'messeskjorte': ('messeskjorte',),
'messeskjorten': ('messeskjorte',),
'messeskjortene': ('messeskjorte',),
'messeskjorter': ('messeskjorte',),
'messing': ('messing',),
'messingen': ('messing',),
'messingene': ('messing',),
'messinger': ('messing',),
'messingblåseinstrument': ('messingblåseinstrument',),
'messingblåseinstrumenta': ('messingblåseinstrument',),
'messingblåseinstrumentene': ('messingblåseinstrument',),
'messingblåseinstrumenter': ('messingblåseinstrument',),
'messingblåseinstrumentet': ('messingblåseinstrument',),
'messingblåser': ('messingblåser',),
'messingblåsere': ('messingblåser',),
'messingblåseren': ('messingblåser',),
'messingblåserer': ('messingblåser',),
'messingblåserne': ('messingblåser',),
'messingstake': ('messingstake',),
'messingstaken': ('messingstake',),
'messingstakene': ('messingstake',),
'messingstaker': ('messingstake',),
'mestepart': ('mestepart',),
'mesteparten': ('mestepart',),
'mestepartene': ('mestepart',),
'mesteparter': ('mestepart',),
'mester': ('mester',),
'mestere': ('mester',),
'mesteren': ('mester',),
'mesterer': ('mester',),
'mesterne': ('mester',),
'mestre': ('mester',),
'mestrene': ('mester',),
'mestrer': ('mester',),
'mesterbrev': ('mesterbrev',),
'mesterbreva': ('mesterbrev',),
'mesterbrevene': ('mesterbrev',),
'mesterbrever': ('mesterbrev',),
'mesterbrevet': ('mesterbrev',),
'mesterhand': ('mesterhand',),
'mesterhanda': ('mesterhand',),
'mesterhanden': ('mesterhand',),
'mesterhendene': ('mesterhand',),
'mesterhender': ('mesterhand',),
'mesterhendene': ('mesterhånd',),
'mesterhender': ('mesterhånd',),
'mesterhånd': ('mesterhånd',),
'mesterhånda': ('mesterhånd',),
'mesterhånden': ('mesterhånd',),
'mesterkokk': ('mesterkokk',),
'mesterkokken': ('mesterkokk',),
'mesterkokkene': ('mesterkokk',),
'mesterkokker': ('mesterkokk',),
'mestermann': ('mestermann',),
'mestermannen': ('mestermann',),
'mestermenn': ('mestermann',),
'mestermennene': ('mestermann',),
'mesterprøva': ('mesterprøve',),
'mesterprøve': ('mesterprøve',),
'mesterprøven': ('mesterprøve',),
'mesterprøvene': ('mesterprøve',),
'mesterprøver': ('mesterprøve',),
'mesterskap': ('mesterskap',),
'mesterskapa': ('mesterskap',),
'mesterskapene': ('mesterskap',),
'mesterskaper': ('mesterskap',),
'mesterskapet': ('mesterskap',),
'mesterskapsrekord': ('mesterskapsrekord',),
'mesterskapsrekorden': ('mesterskapsrekord',),
'mesterskapsrekordene': ('mesterskapsrekord',),
'mesterskapsrekorder': ('mesterskapsrekord',),
'mesterskapstitlene': ('mesterskapstittel',),
'mesterskapstitler': ('mesterskapstittel',),
'mesterskapstittel': ('mesterskapstittel',),
'mesterskapstittelen': ('mesterskapstittel',),
'mesterstykka': ('mesterstykke',),
'mesterstykke': ('mesterstykke',),
'mesterstykkene': ('mesterstykke',),
'mesterstykker': ('mesterstykke',),
'mesterstykket': ('mesterstykke',),
'mesterverk': ('mesterverk',),
'mesterverka': ('mesterverk',),
'mesterverkene': ('mesterverk',),
'mesterverker': ('mesterverk',),
'mesterverket': ('mesterverk',),
'mestis': ('mestis',),
'mestisen': ('mestis',),
'mestisene': ('mestis',),
'mestiser': ('mestis',),
'metabolisme': ('metabolisme',),
'metabolismen': ('metabolisme',),
'metabolismene': ('metabolisme',),
'metabolismer': ('metabolisme',),
'metafor': ('metafor',),
'metaforen': ('metafor',),
'metaforene': ('metafor',),
'metaforer': ('metafor',),
'metaforikk': ('metaforikk',),
'metaforikken': ('metaforikk',),
'metaforikkene': ('metaforikk',),
'metaforikker': ('metaforikk',),
'metafysiker': ('metafysiker',),
'metafysikere': ('metafysiker',),
'metafysikeren': ('metafysiker',),
'metafysikerer': ('metafysiker',),
'metafysikerne': ('metafysiker',),
'metafysikk': ('metafysikk',),
'metafysikken': ('metafysikk',),
'metafysikkene': ('metafysikk',),
'metafysikker': ('metafysikk',),
'metall': ('metall',),
'metalla': ('metall',),
'metallene': ('metall',),
'metaller': ('metall',),
'metallet': ('metall',),
'metalldetektor': ('metalldetektor',),
'metalldetektoren': ('metalldetektor',),
'metalldetektorene': ('metalldetektor',),
'metalldetektorer': ('metalldetektor',),
'metallglans': ('metallglans',),
'metallglansen': ('metallglans',),
'metallglansene': ('metallglans',),
'metallglanser': ('metallglans',),
'metallografi': ('metallografi',),
'metallografien': ('metallografi',),
'metallografiene': ('metallografi',),
'metallografier': ('metallografi',),
'metalloid': ('metalloid',),
'metalloida': ('metalloid',),
'metalloidene': ('metalloid',),
'metalloider': ('metalloid',),
'metalloidet': ('metalloid',),
'metallplata': ('metallplate',),
'metallplate': ('metallplate',),
'metallplaten': ('metallplate',),
'metallplatene': ('metallplate',),
'metallplater': ('metallplate',),
'metallsløyd': ('metallsløyd',),
'metallsløyden': ('metallsløyd',),
'metallsløydene': ('metallsløyd',),
'metallsløyder': ('metallsløyd',),
'metallsprøyting': ('metallsprøyting',),
'metallsprøytinga': ('metallsprøyting',),
'metallsprøytingen': ('metallsprøyting',),
'metallsprøytingene': ('metallsprøyting',),
'metallsprøytinger': ('metallsprøyting',),
'metallsøker': ('metallsøker',),
'metallsøkere': ('metallsøker',),
'metallsøkeren': ('metallsøker',),
'metallsøkerer': ('metallsøker',),
'metallsøkerne': ('metallsøker',),
'metalltråd': ('metalltråd',),
'metalltråden': ('metalltråd',),
'metalltrådene': ('metalltråd',),
'metalltråder': ('metalltråd',),
'metallurg': ('metallurg',),
'metallurgen': ('metallurg',),
'metallurgene': ('metallurg',),
'metallurger': ('metallurg',),
'metallurgi': ('metallurgi',),
'metallurgien': ('metallurgi',),
'metallurgiene': ('metallurgi',),
'metallurgier': ('metallurgi',),
'metamorfose': ('metamorfose',),
'metamorfosen': ('metamorfose',),
'metamorfosene': ('metamorfose',),
'metamorfoser': ('metamorfose',),
'metan': ('metan',),
'metana': ('metan',),
'metanene': ('metan',),
'metanet': ('metan',),
'metanol': ('metanol',),
'metanolen': ('metanol',),
'metanolene': ('metanol',),
'metanoler': ('metanol',),
'metaspråk': ('metaspråk',),
'metaspråka': ('metaspråk',),
'metaspråkene': ('metaspråk',),
'metaspråket': ('metaspråk',),
'metastase': ('metastase',),
'metastasen': ('metastase',),
'metastasene': ('metastase',),
'metastaser': ('metastase',),
'metatese': ('metatese',),
'metatesen': ('metatese',),
'metatesene': ('metatese',),
'metateser': ('metatese',),
'meteor': ('meteor',),
'meteoren': ('meteor',),
'meteorene': ('meteor',),
'meteorer': ('meteor',),
'meteoritt': ('meteoritt',),
'meteoritten': ('meteoritt',),
'meteorittene': ('meteoritt',),
'meteoritter': ('meteoritt',),
'meteorolog': ('meteorolog',),
'meteorologen': ('meteorolog',),
'meteorologene': ('meteorolog',),
'meteorologer': ('meteorolog',),
'meteorologi': ('meteorologi',),
'meteorologien': ('meteorologi',),
'meteorologiene': ('meteorologi',),
'meteorologier': ('meteorologi',),
'meteorstein': ('meteorstein',),
'meteorsteinen': ('meteorstein',),
'meteorsteinene': ('meteorstein',),
'meteorsteiner': ('meteorstein',),
'meter': ('meter',),
'meteren': ('meter',),
'meterne': ('meter',),
'meterbølga': ('meterbølge',),
'meterbølge': ('meterbølge',),
'meterbølgen': ('meterbølge',),
'meterbølgene': ('meterbølge',),
'meterbølger': ('meterbølge',),
'meterbølgekringkasting': ('meterbølgekringkasting',),
'meterbølgekringkastinga': ('meterbølgekringkasting',),
'meterbølgekringkastingen': ('meterbølgekringkasting',),
'meterbølgekringkastingene': ('meterbølgekringkasting',),
'meterbølgekringkastinger': ('meterbølgekringkasting',),
'meterbølgesender': ('meterbølgesender',),
'meterbølgesendere': ('meterbølgesender',),
'meterbølgesenderen': ('meterbølgesender',),
'meterbølgesenderer': ('meterbølgesender',),
'meterbølgesenderne': ('meterbølgesender',),
'meterbølgja': ('meterbølgje',),
'meterbølgje': ('meterbølgje',),
'meterbølgjen': ('meterbølgje',),
'meterbølgjene': ('meterbølgje',),
'meterbølgjer': ('meterbølgje',),
'meterbølgjekringkasting': ('meterbølgjekringkasting',),
'meterbølgjekringkastinga': ('meterbølgjekringkasting',),
'meterbølgjekringkastingen': ('meterbølgjekringkasting',),
'meterbølgjekringkastingene': ('meterbølgjekringkasting',),
'meterbølgjekringkastinger': ('meterbølgjekringkasting',),
'meterbølgjesender': ('meterbølgjesender',),
'meterbølgjesendere': ('meterbølgjesender',),
'meterbølgjesenderen': ('meterbølgjesender',),
'meterbølgjesenderer': ('meterbølgjesender',),
'meterbølgjesenderne': ('meterbølgjesender',),
'metermål': ('metermål',),
'metermåla': ('metermål',),
'metermålene': ('metermål',),
'metermålet': ('metermål',),
'meterstokk': ('meterstokk',),
'meterstokken': ('meterstokk',),
'meterstokkene': ('meterstokk',),
'meterstokker': ('meterstokk',),
'metersystem': ('metersystem',),
'metersystema': ('metersystem',),
'metersystemene': ('metersystem',),
'metersystemer': ('metersystem',),
'metersystemet': ('metersystem',),
'metervara': ('metervare',),
'metervare': ('metervare',),
'metervaren': ('metervare',),
'metervarene': ('metervare',),
'metervarer': ('metervare',),
'metier': ('metier',),
'metiera': ('metier',),
'metieren': ('metier',),
'metierene': ('metier',),
'metierer': ('metier',),
'metieret': ('metier',),
'metning': ('metning',),
'metninga': ('metning',),
'metningen': ('metning',),
'metningene': ('metning',),
'metninger': ('metning',),
'metningsgrad': ('metningsgrad',),
'metningsgraden': ('metningsgrad',),
'metningsgradene': ('metningsgrad',),
'metningsgrader': ('metningsgrad',),
'metningspunkt': ('metningspunkt',),
'metningspunkta': ('metningspunkt',),
'metningspunktene': ('metningspunkt',),
'metningspunkter': ('metningspunkt',),
'metningspunktet': ('metningspunkt',),
'metningstrykk': ('metningstrykk',),
'metningstrykka': ('metningstrykk',),
'metningstrykkene': ('metningstrykk',),
'metningstrykket': ('metningstrykk',),
'metode': ('metode',),
'metoden': ('metode',),
'metodene': ('metode',),
'metoder': ('metode',),
'metodekritikk': ('metodekritikk',),
'metodekritikken': ('metodekritikk',),
'metodekritikkene': ('metodekritikk',),
'metodekritikker': ('metodekritikk',),
'metodelæra': ('metodelære',),
'metodelære': ('metodelære',),
'metodelæren': ('metodelære',),
'metodelærene': ('metodelære',),
'metodelærer': ('metodelære',),
'metodiker': ('metodiker',),
'metodikere': ('metodiker',),
'metodikeren': ('metodiker',),
'metodikerer': ('metodiker',),
'metodikerne': ('metodiker',),
'metodikk': ('metodikk',),
'metodikken': ('metodikk',),
'metodikkene': ('metodikk',),
'metodikker': ('metodikk',),
'metodisme': ('metodisme',),
'metodismen': ('metodisme',),
'metodismene': ('metodisme',),
'metodismer': ('metodisme',),
'metodist': ('metodist',),
'metodisten': ('metodist',),
'metodistene': ('metodist',),
'metodister': ('metodist',),
'metodistkirka': ('metodistkirke',),
'metodistkirke': ('metodistkirke',),
'metodistkirken': ('metodistkirke',),
'metodistkirkene': ('metodistkirke',),
'metodistkirker': ('metodistkirke',),
'metodistkjerka': ('metodistkjerke',),
'metodistkjerke': ('metodistkjerke',),
'metodistkjerken': ('metodistkjerke',),
'metodistkjerkene': ('metodistkjerke',),
'metodistkjerker': ('metodistkjerke',),
'metodistprest': ('metodistprest',),
'metodistpresten': ('metodistprest',),
'metodistprestene': ('metodistprest',),
'metodistprester': ('metodistprest',),
'metodologi': ('metodologi',),
'metodologien': ('metodologi',),
'metodologiene': ('metodologi',),
'metodologier': ('metodologi',),
'metonymi': ('metonymi',),
'metonymien': ('metonymi',),
'metonymiene': ('metonymi',),
'metonymier': ('metonymi',),
'metope': ('metope',),
'metopen': ('metope',),
'metopene': ('metope',),
'metoper': ('metope',),
'metressa': ('metresse',),
'metresse': ('metresse',),
'metressen': ('metresse',),
'metressene': ('metresse',),
'metresser': ('metresse',),
'metrikk': ('metrikk',),
'metrikken': ('metrikk',),
'metrikkene': ('metrikk',),
'metrikker': ('metrikk',),
'metro': ('metro',),
'metroen': ('metro',),
'metroene': ('metro',),
'metroer': ('metro',),
'metrologi': ('metrologi',),
'metrologien': ('metrologi',),
'metrologiene': ('metrologi',),
'metrologier': ('metrologi',),
'metronom': ('metronom',),
'metronomen': ('metronom',),
'metronomene': ('metronom',),
'metronomer': ('metronom',),
'metronymika': ('metronymikon',),
'metronymikaene': ('metronymikon',),
'metronymikon': ('metronymikon',),
'metronymikonet': ('metronymikon',),
'metropol': ('metropol',),
'metropolen': ('metropol',),
'metropolene': ('metropol',),
'metropoler': ('metropol',),
'metropolitt': ('metropolitt',),
'metropolitten': ('metropolitt',),
'metropolittene': ('metropolitt',),
'metropolitter': ('metropolitt',),
'metra': ('metrum',),
'metraene': ('metrum',),
'metret': ('metrum',),
'metrum': ('metrum',),
'metruma': ('metrum',),
'metrumene': ('metrum',),
'metrumer': ('metrum',),
'metrumet': ('metrum',),
'metta': ('mette',),
'mette': ('mette',),
'metten': ('mette',),
'mettene': ('mette',),
'metter': ('mette',),
'metthet': ('metthet',),
'mettheta': ('metthet',),
'mettheten': ('metthet',),
'metthetene': ('metthet',),
'mettheter': ('metthet',),
'metthetsfølelse': ('metthetsfølelse',),
'metthetsfølelsen': ('metthetsfølelse',),
'metthetsfølelsene': ('metthetsfølelse',),
'metthetsfølelser': ('metthetsfølelse',),
'metusalem': ('metusalem',),
'metusalemmen': ('metusalem',),
'metusalemmene': ('metusalem',),
'metusalemmer': ('metusalem',),
'metyl': ('metyl',),
'metyla': ('metyl',),
'metylene': ('metyl',),
'metylet': ('metyl',),
'metylalkohol': ('metylalkohol',),
'metylalkoholen': ('metylalkohol',),
'metylalkoholene': ('metylalkohol',),
'metylalkoholer': ('metylalkohol',),
'metylen': ('metylen',),
'metylena': ('metylen',),
'metylenene': ('metylen',),
'metylenet': ('metylen',),
'mexicaner': ('mexicaner',),
'mexicanere': ('mexicaner',),
'mexicaneren': ('mexicaner',),
'mexicanerer': ('mexicaner',),
'mexicanerne': ('mexicaner',),
'mezzosopran': ('mezzosopran',),
'mezzosopranen': ('mezzosopran',),
'mezzosopranene': ('mezzosopran',),
'mezzosopraner': ('mezzosopran',),
'mi': ('mi',),
'mien': ('mi',),
'miene': ('mi',),
'mier': ('mi',),
'midd': ('midd',),
'midden': ('midd',),
'middene': ('midd',),
'midder': ('midd',),
'midd': ('midd',),
'midden': ('midd',),
'middene': ('midd',),
'midder': ('midd',),
'middag': ('middag',),
'middagen': ('middag',),
'middagene': ('middag',),
'middager': ('middag',),
'middagsavis': ('middagsavis',),
'middagsavisa': ('middagsavis',),
'middagsavisen': ('middagsavis',),
'middagsavisene': ('middagsavis',),
'middagsaviser': ('middagsavis',),
'middagsbord': ('middagsbord',),
'middagsborda': ('middagsbord',),
'middagsbordene': ('middagsbord',),
'middagsborder': ('middagsbord',),
'middagsbordet': ('middagsbord',),
'middagsgjest': ('middagsgjest',),
'middagsgjesten': ('middagsgjest',),
'middagsgjestene': ('middagsgjest',),
'middagsgjester': ('middagsgjest',),
'middagshvil': ('middagshvil',),
'middagshvilen': ('middagshvil',),
'middagshvilene': ('middagshvil',),
'middagshviler': ('middagshvil',),
'middagshøgd': ('middagshøgd',),
'middagshøgda': ('middagshøgd',),
'middagshøgdene': ('middagshøgd',),
'middagshøgder': ('middagshøgd',),
'middagshøyde': ('middagshøyde',),
'middagshøyden': ('middagshøyde',),
'middagshøydene': ('middagshøyde',),
'middagshøyder': ('middagshøyde',),
'middagskvil': ('middagskvil',),
'middagskvila': ('middagskvil',),
'middagskvilen': ('middagskvil',),
'middagskvilene': ('middagskvil',),
'middagskviler': ('middagskvil',),
'middagsleita': ('middagsleite',),
'middagsleite': ('middagsleite',),
'middagsleitene': ('middagsleite',),
'middagsleiter': ('middagsleite',),
'middagsleitet': ('middagsleite',),
'middagslinja': ('middagslinje',),
'middagslinje': ('middagslinje',),
'middagslinjen': ('middagslinje',),
'middagslinjene': ('middagslinje',),
'middagslinjer': ('middagslinje',),
'middagslur': ('middagslur',),
'middagsluren': ('middagslur',),
'middagslurene': ('middagslur',),
'middagslurer': ('middagslur',),
'middagsmat': ('middagsmat',),
'middagsmaten': ('middagsmat',),
'middagsmatene': ('middagsmat',),
'middagsmater': ('middagsmat',),
'middagsmåltid': ('middagsmåltid',),
'middagsmåltida': ('middagsmåltid',),
'middagsmåltidene': ('middagsmåltid',),
'middagsmåltider': ('middagsmåltid',),
'middagsmåltidet': ('middagsmåltid',),
'middagsselskap': ('middagsselskap',),
'middagsselskapa': ('middagsselskap',),
'middagsselskapene': ('middagsselskap',),
'middagsselskaper': ('middagsselskap',),
'middagsselskapet': ('middagsselskap',),
'middagsservisa': ('middagsservise',),
'middagsservise': ('middagsservise',),
'middagsservisene': ('middagsservise',),
'middagsserviser': ('middagsservise',),
'middagsserviset': ('middagsservise',),
'middagstallerken': ('middagstallerken',),
'middagstallerkenen': ('middagstallerken',),
'middagstallerkenene': ('middagstallerken',),
'middagstallerkener': ('middagstallerken',),
'middagstid': ('middagstid',),
'middagstida': ('middagstid',),
'middagstiden': ('middagstid',),
'middagstidene': ('middagstid',),
'middagstider': ('middagstid',),
'middagsøkt': ('middagsøkt',),
'middagsøkta': ('middagsøkt',),
'middagsøkten': ('middagsøkt',),
'middagsøktene': ('middagsøkt',),
'middagsøkter': ('middagsøkt',),
'middel': ('middel',),
'middelen': ('middel',),
'midlene': ('middel',),
'midler': ('middel',),
'middel': ('middel',),
'middelen': ('middel',),
'midlene': ('middel',),
'midler': ('middel',),
'middel': ('middel',),
'middelen': ('middel',),
'midlene': ('middel',),
'midler': ('middel',),
'middel': ('middel',),
'middelet': ('middel',),
'midla': ('middel',),
'midlene': ('middel',),
'midler': ('middel',),
'midlet': ('middel',),
'middelalder': ('middelalder',),
'middelaldere': ('middelalder',),
'middelalderen': ('middelalder',),
'middelalderer': ('middelalder',),
'middelalderne': ('middelalder',),
'middelaldre': ('middelalder',),
'middelaldrene': ('middelalder',),
'middelaldrer': ('middelalder',),
'middelhavsfarer': ('middelhavsfarer',),
'middelhavsfarere': ('middelhavsfarer',),
'middelhavsfareren': ('middelhavsfarer',),
'middelhavsfarerer': ('middelhavsfarer',),
'middelhavsfarerne': ('middelhavsfarer',),
'middelhavsklima': ('middelhavsklima',),
'middelhavsklimaene': ('middelhavsklima',),
'middelhavsklimaer': ('middelhavsklima',),
'middelhavsklimaet': ('middelhavsklima',),
'middelhavsland': ('middelhavsland',),
'middelhavslanda': ('middelhavsland',),
'middelhavslandene': ('middelhavsland',),
'middelhavslandet': ('middelhavsland',),
'middelhøgd': ('middelhøgd',),
'middelhøgda': ('middelhøgd',),
'middelhøgdene': ('middelhøgd',),
'middelhøgder': ('middelhøgd',),
'middelhøyde': ('middelhøyde',),
'middelhøyden': ('middelhøyde',),
'middelhøydene': ('middelhøyde',),
'middelhøyder': ('middelhøyde',),
'middelklassa': ('middelklasse',),
'middelklasse': ('middelklasse',),
'middelklassen': ('middelklasse',),
'middelklassene': ('middelklasse',),
'middelklasser': ('middelklasse',),
'middelmådighet': ('middelmådighet',),
'middelmådigheta': ('middelmådighet',),
'middelmådigheten': ('middelmådighet',),
'middelmådighetene': ('middelmådighet',),
'middelmådigheter': ('middelmådighet',),
'middelmåtighet': ('middelmåtighet',),
'middelmåtigheta': ('middelmåtighet',),
'middelmåtigheten': ('middelmåtighet',),
'middelmåtighetene': ('middelmåtighet',),
'middelmåtigheter': ('middelmåtighet',),
'middelpris': ('middelpris',),
'middelprisen': ('middelpris',),
'middelprisene': ('middelpris',),
'middelpriser': ('middelpris',),
'middelshøgd': ('middelshøgd',),
'middelshøgda': ('middelshøgd',),
'middelshøgdene': ('middelshøgd',),
'middelshøgder': ('middelshøgd',),
'middelshøyde': ('middelshøyde',),
'middelshøyden': ('middelshøyde',),
'middelshøydene': ('middelshøyde',),
'middelshøyder': ('middelshøyde',),
'middelsol': ('middelsol',),
'middelsola': ('middelsol',),
'middelsolen': ('middelsol',),
'middelsolene': ('middelsol',),
'middelsoler': ('middelsol',),
'middelstand': ('middelstand',),
'middelstanden': ('middelstand',),
'middelstandene': ('middelstand',),
'middelstander': ('middelstand',),
'middelstand': ('middelstand',),
'middelstanden': ('middelstand',),
'middelstandene': ('middelstand',),
'middelstander': ('middelstand',),
'middeltal': ('middeltal',),
'middeltala': ('middeltal',),
'middeltalene': ('middeltal',),
'middeltalet': ('middeltal',),
'middeltall': ('middeltall',),
'middeltalla': ('middeltall',),
'middeltallene': ('middeltall',),
'middeltallet': ('middeltall',),
'middeltemperatur': ('middeltemperatur',),
'middeltemperaturen': ('middeltemperatur',),
'middeltemperaturene': ('middeltemperatur',),
'middeltemperaturer': ('middeltemperatur',),
'middeltid': ('middeltid',),
'middeltida': ('middeltid',),
'middeltiden': ('middeltid',),
'middeltidene': ('middeltid',),
'middeltider': ('middeltid',),
'middelveg': ('middelveg',),
'middelvegen': ('middelveg',),
'middelvegene': ('middelveg',),
'middelveger': ('middelveg',),
'middelvei': ('middelvei',),
'middelveien': ('middelvei',),
'middelveiene': ('middelvei',),
'middelveier': ('middelvei',),
'middelverdi': ('middelverdi',),
'middelverdien': ('middelverdi',),
'middelverdiene': ('middelverdi',),
'middelverdier': ('middelverdi',),
'midel': ('midel',),
'midelen': ('midel',),
'midlene': ('midel',),
'midler': ('midel',),
'midel': ('midel',),
'midelen': ('midel',),
'midlene': ('midel',),
'midler': ('midel',),
'midfasta': ('midfaste',),
'midfaste': ('midfaste',),
'midfasten': ('midfaste',),
'midfastene': ('midfaste',),
'midfaster': ('midfaste',),
'midfastesøndag': ('midfastesøndag',),
'midfastesøndagen': ('midfastesøndag',),
'midfastesøndagene': ('midfastesøndag',),
'midfastesøndager': ('midfastesøndag',),
'midifrakk': ('midifrakk',),
'midifrakken': ('midifrakk',),
'midifrakkene': ('midifrakk',),
'midifrakker': ('midifrakk',),
'midikjole': ('midikjole',),
'midikjolen': ('midikjole',),
'midikjolene': ('midikjole',),
'midikjoler': ('midikjole',),
'midiskjørt': ('midiskjørt',),
'midiskjørta': ('midiskjørt',),
'midiskjørtene': ('midiskjørt',),
'midiskjørter': ('midiskjørt',),
'midiskjørtet': ('midiskjørt',),
'midja': ('midje',),
'midje': ('midje',),
'midjen': ('midje',),
'midjene': ('midje',),
'midjer': ('midje',),
'midlandsmål': ('midlandsmål',),
'midlandsmåla': ('midlandsmål',),
'midlandsmålene': ('midlandsmål',),
'midlandsmålet': ('midlandsmål',),
'midlandsnormal': ('midlandsnormal',),
'midlandsnormalen': ('midlandsnormal',),
'midlandsnormalene': ('midlandsnormal',),
'midlandsnormaler': ('midlandsnormal',),
'midler': ('midler',),
'midlere': ('midler',),
'midleren': ('midler',),
'midlerer': ('midler',),
'midlerne': ('midler',),
'midnatt': ('midnatt',),
'midnatta': ('midnatt',),
'midnatten': ('midnatt',),
'midnattene': ('midnatt',),
'midnatter': ('midnatt',),
'midnattsmessa': ('midnattsmesse',),
'midnattsmesse': ('midnattsmesse',),
'midnattsmessen': ('midnattsmesse',),
'midnattsmessene': ('midnattsmesse',),
'midnattsmesser': ('midnattsmesse',),
'midnattssol': ('midnattssol',),
'midnattssola': ('midnattssol',),
'midnattssolen': ('midnattssol',),
'midnattssolene': ('midnattssol',),
'midnattssoler': ('midnattssol',),
'midnattstid': ('midnattstid',),
'midnattstida': ('midnattstid',),
'midnattstiden': ('midnattstid',),
'midnattstidene': ('midnattstid',),
'midnattstider': ('midnattstid',),
'midsommer': ('midsommer',),
'midsommere': ('midsommer',),
'midsommeren': ('midsommer',),
'midsommerne': ('midsommer',),
'midsomre': ('midsommer',),
'midsomrene': ('midsommer',),
'midsomrer': ('midsommer',),
'midsommer': ('midsommer',),
'midsommere': ('midsommer',),
'midsommeren': ('midsommer',),
'midsommerne': ('midsommer',),
'midsomre': ('midsommer',),
'midsomrene': ('midsommer',),
'midsomrer': ('midsommer',),
'midsommernatt': ('midsommernatt',),
'midsommernatta': ('midsommernatt',),
'midsommernatten': ('midsommernatt',),
'midsommernettene': ('midsommernatt',),
'midsommernetter': ('midsommernatt',),
'midsommernatt': ('midsommernatt',),
'midsommernatta': ('midsommernatt',),
'midsommernatten': ('midsommernatt',),
'midsommernettene': ('midsommernatt',),
'midsommernetter': ('midsommernatt',),
'midt': ('midt',),
'midten': ('midt',),
'midtene': ('midt',),
'midter': ('midt',),
'midtbane': ('midtbane',),
'midtbanen': ('midtbane',),
'midtbanene': ('midtbane',),
'midtbaner': ('midtbane',),
'midtbanespeller': ('midtbanespeller',),
'midtbanespellere': ('midtbanespeller',),
'midtbanespelleren': ('midtbanespeller',),
'midtbanespellerer': ('midtbanespeller',),
'midtbanespellerne': ('midtbanespeller',),
'midtbanespiller': ('midtbanespiller',),
'midtbanespillere': ('midtbanespiller',),
'midtbanespilleren': ('midtbanespiller',),
'midtbanespillerer': ('midtbanespiller',),
'midtbanespillerne': ('midtbanespiller',),
'midtdeler': ('midtdeler',),
'midtdelere': ('midtdeler',),
'midtdeleren': ('midtdeler',),
'midtdelerer': ('midtdeler',),
'midtdelerne': ('midtdeler',),
'midte': ('midte',),
'midtgang': ('midtgang',),
'midtgangen': ('midtgang',),
'midtgangene': ('midtgang',),
'midtganger': ('midtgang',),
'midtlinja': ('midtlinje',),
'midtlinje': ('midtlinje',),
'midtlinjen': ('midtlinje',),
'midtlinjene': ('midtlinje',),
'midtlinjer': ('midtlinje',),
'midtparti': ('midtparti',),
'midtpartia': ('midtparti',),
'midtpartiene': ('midtparti',),
'midtpartier': ('midtparti',),
'midtpartiet': ('midtparti',),
'midtpunkt': ('midtpunkt',),
'midtpunkta': ('midtpunkt',),
'midtpunktene': ('midtpunkt',),
'midtpunkter': ('midtpunkt',),
'midtpunktet': ('midtpunkt',),
'midtrabatt': ('midtrabatt',),
'midtrabatten': ('midtrabatt',),
'midtrabattene': ('midtrabatt',),
'midtrabatter': ('midtrabatt',),
'midtsida': ('midtside',),
'midtside': ('midtside',),
'midtsiden': ('midtside',),
'midtsidene': ('midtside',),
'midtsider': ('midtside',),
'midtsidejenta': ('midtsidejente',),
'midtsidejente': ('midtsidejente',),
'midtsidejenten': ('midtsidejente',),
'midtsidejentene': ('midtsidejente',),
'midtsidejenter': ('midtsidejente',),
'midtskill': ('midtskill',),
'midtskillen': ('midtskill',),
'midtskillene': ('midtskill',),
'midtskiller': ('midtskill',),
'midtskip': ('midtskip',),
'midtskipa': ('midtskip',),
'midtskipene': ('midtskip',),
'midtskipet': ('midtskip',),
'midtsommer': ('midtsommer',),
'midtsommere': ('midtsommer',),
'midtsommeren': ('midtsommer',),
'midtsommerne': ('midtsommer',),
'midtsomre': ('midtsommer',),
'midtsomrene': ('midtsommer',),
'midtsomrer': ('midtsommer',),
'midtsommernatt': ('midtsommernatt',),
'midtsommernatta': ('midtsommernatt',),
'midtsommernatten': ('midtsommernatt',),
'midtsommernettene': ('midtsommernatt',),
'midtsommernetter': ('midtsommernatt',),
'midtsommernatt': ('midtsommernatt',),
'midtsommernatta': ('midtsommernatt',),
'midtsommernatten': ('midtsommernatt',),
'midtsommernettene': ('midtsommernatt',),
'midtsommernetter': ('midtsommernatt',),
'midtstopper': ('midtstopper',),
'midtstoppere': ('midtstopper',),
'midtstopperen': ('midtstopper',),
'midtstopperer': ('midtstopper',),
'midtstopperne': ('midtstopper',),
'midtstykka': ('midtstykke',),
'midtstykke': ('midtstykke',),
'midtstykkene': ('midtstykke',),
'midtstykker': ('midtstykke',),
'midtstykket': ('midtstykke',),
'midtstyring': ('midtstyring',),
'midtstyringa': ('midtstyring',),
'midtstyringen': ('midtstyring',),
'midtstyringene': ('midtstyring',),
'midtstyringer': ('midtstyring',),
'midtuka': ('midtuke',),
'midtuke': ('midtuke',),
'midtuken': ('midtuke',),
'midtukene': ('midtuke',),
'midtuker': ('midtuke',),
'midtuka': ('midtuke',),
'midtuke': ('midtuke',),
'midtuken': ('midtuke',),
'midtukene': ('midtuke',),
'midtuker': ('midtuke',),
'midtukedag': ('midtukedag',),
'midtukedagen': ('midtukedag',),
'midtukedagene': ('midtukedag',),
'midtukedager': ('midtukedag',),
'midtukedag': ('midtukedag',),
'midtukedagen': ('midtukedag',),
'midtukedagene': ('midtukedag',),
'midtukedager': ('midtukedag',),
'midtukerabatt': ('midtukerabatt',),
'midtukerabatten': ('midtukerabatt',),
'midtukerabattene': ('midtukerabatt',),
'midtukerabatter': ('midtukerabatt',),
'midtukerabatt': ('midtukerabatt',),
'midtukerabatten': ('midtukerabatt',),
'midtukerabattene': ('midtukerabatt',),
'midtukerabatter': ('midtukerabatt',),
'midtveka': ('midtveke',),
'midtveke': ('midtveke',),
'midtveken': ('midtveke',),
'midtvekene': ('midtveke',),
'midtveker': ('midtveke',),
'midtveka': ('midtveke',),
'midtveke': ('midtveke',),
'midtveken': ('midtveke',),
'midtvekene': ('midtveke',),
'midtveker': ('midtveke',),
'midtvekedag': ('midtvekedag',),
'midtvekedagen': ('midtvekedag',),
'midtvekedagene': ('midtvekedag',),
'midtvekedager': ('midtvekedag',),
'midtvekedag': ('midtvekedag',),
'midtvekedagen': ('midtvekedag',),
'midtvekedagene': ('midtvekedag',),
'midtvekedager': ('midtvekedag',),
'midtvekerabatt': ('midtvekerabatt',),
'midtvekerabatten': ('midtvekerabatt',),
'midtvekerabattene': ('midtvekerabatt',),
'midtvekerabatter': ('midtvekerabatt',),
'midtvekerabatt': ('midtvekerabatt',),
'midtvekerabatten': ('midtvekerabatt',),
'midtvekerabattene': ('midtvekerabatt',),
'midtvekerabatter': ('midtvekerabatt',),
'midtvinter': ('midtvinter',),
'midtvintere': ('midtvinter',),
'midtvinteren': ('midtvinter',),
'midtvinterne': ('midtvinter',),
'midtvintre': ('midtvinter',),
'midtvintrene': ('midtvinter',),
'midtvintrer': ('midtvinter',),
'midtøstenland': ('midtøstenland',),
'midtøstenlanda': ('midtøstenland',),
'midtøstenlandene': ('midtøstenland',),
'midtøstenlandet': ('midtøstenland',),
'midtøstland': ('midtøstland',),
'midtøstlanda': ('midtøstland',),
'midtøstlandene': ('midtøstland',),
'midtøstlandet': ('midtøstland',),
'midvinter': ('midvinter',),
'midvintere': ('midvinter',),
'midvinteren': ('midvinter',),
'midvinterne': ('midvinter',),
'midvintre': ('midvinter',),
'midvintrene': ('midvinter',),
'midvintrer': ('midvinter',),
'migemaur': ('migemaur',),
'migemauren': ('migemaur',),
'migemaurene': ('migemaur',),
'migmaur': ('migmaur',),
'migmauren': ('migmaur',),
'migmaurene': ('migmaur',),
'migrasjon': ('migrasjon',),
'migrasjonen': ('migrasjon',),
'migrasjonene': ('migrasjon',),
'migrasjoner': ('migrasjon',),
'migrene': ('migrene',),
'migrenen': ('migrene',),
'migrenene': ('migrene',),
'migrener': ('migrene',),
'mikado': ('mikado',),
'mikadoen': ('mikado',),
'mikadoene': ('mikado',),
'mikadoer': ('mikado',),
'mikkel': ('mikkel',),
'mikkelen': ('mikkel',),
'miklene': ('mikkel',),
'mikler': ('mikkel',),
'mikkelsbær': ('mikkelsbær',),
'mikkelsbæra': ('mikkelsbær',),
'mikkelsbærene': ('mikkelsbær',),
'mikkelsbæret': ('mikkelsbær',),
'mikkelsmess': ('mikkelsmess',),
'mikkelsmesse': ('mikkelsmesse',),
'mikrobe': ('mikrobe',),
'mikroben': ('mikrobe',),
'mikrobene': ('mikrobe',),
'mikrober': ('mikrobe',),
'mikrobiologi': ('mikrobiologi',),
'mikrobiologien': ('mikrobiologi',),
'mikrobiologiene': ('mikrobiologi',),
'mikrobiologier': ('mikrobiologi',),
'mikrobølga': ('mikrobølge',),
'mikrobølge': ('mikrobølge',),
'mikrobølgen': ('mikrobølge',),
'mikrobølgene': ('mikrobølge',),
'mikrobølger': ('mikrobølge',),
'mikrobølgeomn': ('mikrobølgeomn',),
'mikrobølgeomnen': ('mikrobølgeomn',),
'mikrobølgeomnene': ('mikrobølgeomn',),
'mikrobølgeomner': ('mikrobølgeomn',),
'mikrobølgeovn': ('mikrobølgeovn',),
'mikrobølgeovnen': ('mikrobølgeovn',),
'mikrobølgeovnene': ('mikrobølgeovn',),
'mikrobølgeovner': ('mikrobølgeovn',),
'mikrobølgja': ('mikrobølgje',),
'mikrobølgje': ('mikrobølgje',),
'mikrobølgjen': ('mikrobølgje',),
'mikrobølgjene': ('mikrobølgje',),
'mikrobølgjer': ('mikrobølgje',),
'mikrobølgjeomn': ('mikrobølgjeomn',),
'mikrobølgjeomnen': ('mikrobølgjeomn',),
'mikrobølgjeomnene': ('mikrobølgjeomn',),
'mikrobølgjeomner': ('mikrobølgjeomn',),
'mikrobølgjeovn': ('mikrobølgjeovn',),
'mikrobølgjeovnen': ('mikrobølgjeovn',),
'mikrobølgjeovnene': ('mikrobølgjeovn',),
'mikrobølgjeovner': ('mikrobølgjeovn',),
'mikrodatamaskin': ('mikrodatamaskin',),
'mikrodatamaskina': ('mikrodatamaskin',),
'mikrodatamaskinen': ('mikrodatamaskin',),
'mikrodatamaskinene': ('mikrodatamaskin',),
'mikrodatamaskiner': ('mikrodatamaskin',),
'mikrofiche': ('mikrofiche',),
'mikrofichen': ('mikrofiche',),
'mikrofichene': ('mikrofiche',),
'mikroficher': ('mikrofiche',),
'mikrofilm': ('mikrofilm',),
'mikrofilmen': ('mikrofilm',),
'mikrofilmene': ('mikrofilm',),
'mikrofilmer': ('mikrofilm',),
'mikrofilmkort': ('mikrofilmkort',),
'mikrofilmkorta': ('mikrofilmkort',),
'mikrofilmkortene': ('mikrofilmkort',),
'mikrofilmkortet': ('mikrofilmkort',),
'mikrofon': ('mikrofon',),
'mikrofonen': ('mikrofon',),
'mikrofonene': ('mikrofon',),
'mikrofoner': ('mikrofon',),
'mikrofotografering': ('mikrofotografering',),
'mikrofotograferinga': ('mikrofotografering',),
'mikrofotograferingen': ('mikrofotografering',),
'mikrofotograferingene': ('mikrofotografering',),
'mikrofotograferinger': ('mikrofotografering',),
'mikrokirurgi': ('mikrokirurgi',),
'mikrokirurgien': ('mikrokirurgi',),
'mikrokirurgiene': ('mikrokirurgi',),
'mikrokirurgier': ('mikrokirurgi',),
'mikrokort': ('mikrokort',),
'mikrokorta': ('mikrokort',),
'mikrokortene': ('mikrokort',),
'mikrokortet': ('mikrokort',),
'mikrokosmos': ('mikrokosmos',),
'mikrokosmosa': ('mikrokosmos',),
'mikrokosmosene': ('mikrokosmos',),
'mikrokosmoset': ('mikrokosmos',),
'mikromaskin': ('mikromaskin',),
'mikromaskina': ('mikromaskin',),
'mikromaskinen': ('mikromaskin',),
'mikromaskinene': ('mikromaskin',),
'mikromaskiner': ('mikromaskin',),
'mikrometer': ('mikrometer',),
'mikrometeren': ('mikrometer',),
'mikrometerne': ('mikrometer',),
'mikrometer': ('mikrometer',),
'mikrometeret': ('mikrometer',),
'mikrometra': ('mikrometer',),
'mikrometre': ('mikrometer',),
'mikrometrene': ('mikrometer',),
'mikrometret': ('mikrometer',),
'mikrometerskrue': ('mikrometerskrue',),
'mikrometerskruen': ('mikrometerskrue',),
'mikrometerskruene': ('mikrometerskrue',),
'mikrometerskruer': ('mikrometerskrue',),
'mikron': ('mikron',),
'mikronen': ('mikron',),
'mikronene': ('mikron',),
'mikroner': ('mikron',),
'mikroorganisme': ('mikroorganisme',),
'mikroorganismen': ('mikroorganisme',),
'mikroorganismene': ('mikroorganisme',),
'mikroorganismer': ('mikroorganisme',),
'mikroprosessor': ('mikroprosessor',),
'mikroprosessoren': ('mikroprosessor',),
'mikroprosessorene': ('mikroprosessor',),
'mikroprosessorer': ('mikroprosessor',),
'mikroskop': ('mikroskop',),
'mikroskopa': ('mikroskop',),
'mikroskopene': ('mikroskop',),
'mikroskoper': ('mikroskop',),
'mikroskopet': ('mikroskop',),
'mikroskopi': ('mikroskopi',),
'mikroskopien': ('mikroskopi',),
'mikroskopiene': ('mikroskopi',),
'mikroskopier': ('mikroskopi',),
'miks': ('miks',),
'miksa': ('miks',),
'miksen': ('miks',),
'miksene': ('miks',),
'mikser': ('miks',),
'mikset': ('miks',),
'miksepult': ('miksepult',),
'miksepulten': ('miksepult',),
'miksepultene': ('miksepult',),
'miksepulter': ('miksepult',),
'mikser': ('mikser',),
'miksere': ('mikser',),
'mikseren': ('mikser',),
'mikserer': ('mikser',),
'mikserne': ('mikser',),
'miksmaster': ('miksmaster',),
'miksmastere': ('miksmaster',),
'miksmasteren': ('miksmaster',),
'miksmasterer': ('miksmaster',),
'miksmasterne': ('miksmaster',),
'mikstur': ('mikstur',),
'miksturen': ('mikstur',),
'miksturene': ('mikstur',),
'miksturer': ('mikstur',),
'mil': ('mil',),
'mila': ('mil',),
'milen': ('mil',),
'milene': ('mil',),
'mil': ('mil',),
'milaneser': ('milaneser',),
'milanesere': ('milaneser',),
'milaneseren': ('milaneser',),
'milaneserer': ('milaneser',),
'milaneserne': ('milaneser',),
'mildvær': ('mildvær',),
'mildværa': ('mildvær',),
'mildværene': ('mildvær',),
'mildværet': ('mildvær',),
'mildvær': ('mildvær',),
'mildværa': ('mildvær',),
'mildværene': ('mildvær',),
'mildværet': ('mildvær',),
'mildværsperiode': ('mildværsperiode',),
'mildværsperioden': ('mildværsperiode',),
'mildværsperiodene': ('mildværsperiode',),
'mildværsperioder': ('mildværsperiode',),
'mile': ('mile',),
'milen': ('mile',),
'milene': ('mile',),
'miles': ('mile',),
'mila': ('mile',),
'mile': ('mile',),
'milen': ('mile',),
'milene': ('mile',),
'miler': ('mile',),
'milebrenning': ('milebrenning',),
'milebrenninga': ('milebrenning',),
'milebrenningen': ('milebrenning',),
'milebrenningene': ('milebrenning',),
'milebrenninger': ('milebrenning',),
'milepæl': ('milepæl',),
'milepælen': ('milepæl',),
'milepælene': ('milepæl',),
'milepæler': ('milepæl',),
'milestolpe': ('milestolpe',),
'milestolpen': ('milestolpe',),
'milestolpene': ('milestolpe',),
'milestolper': ('milestolpe',),
'miligholdelse': ('miligholdelse',),
'miligholdelsen': ('miligholdelse',),
'miligholdelsene': ('miligholdelse',),
'miligholdelser': ('miligholdelse',),
'militarisme': ('militarisme',),
'militarismen': ('militarisme',),
'militarismene': ('militarisme',),
'militarismer': ('militarisme',),
'militarist': ('militarist',),
'militaristen': ('militarist',),
'militaristene': ('militarist',),
'militarister': ('militarist',),
'milits': ('milits',),
'militsen': ('milits',),
'militsene': ('milits',),
'militser': ('milits',),
'militær': ('militær',),
'militæra': ('militær',),
'militærene': ('militær',),
'militæret': ('militær',),
'militærbase': ('militærbase',),
'militærbasen': ('militærbase',),
'militærbasene': ('militærbase',),
'militærbaser': ('militærbase',),
'militærdiktatur': ('militærdiktatur',),
'militærdiktatura': ('militærdiktatur',),
'militærdiktaturene': ('militærdiktatur',),
'militærdiktaturer': ('militærdiktatur',),
'militærdiktaturet': ('militærdiktatur',),
'militærfly': ('militærfly',),
'militærflya': ('militærfly',),
'militærflyene': ('militærfly',),
'militærflyet': ('militærfly',),
'militærjunta': ('militærjunta',),
'militærjuntaen': ('militærjunta',),
'militærjuntaene': ('militærjunta',),
'militærjuntaer': ('militærjunta',),
'militærkupp': ('militærkupp',),
'militærkuppa': ('militærkupp',),
'militærkuppene': ('militærkupp',),
'militærkuppet': ('militærkupp',),
'militærleir': ('militærleir',),
'militærleiren': ('militærleir',),
'militærleirene': ('militærleir',),
'militærleirer': ('militærleir',),
'militærmakt': ('militærmakt',),
'militærmakta': ('militærmakt',),
'militærmakten': ('militærmakt',),
'militærmaktene': ('militærmakt',),
'militærmakter': ('militærmakt',),
'militærnekter': ('militærnekter',),
'militærnektere': ('militærnekter',),
'militærnekteren': ('militærnekter',),
'militærnekterer': ('militærnekter',),
'militærnekterne': ('militærnekter',),
'militærparade': ('militærparade',),
'militærparaden': ('militærparade',),
'militærparadene': ('militærparade',),
'militærparader': ('militærparade',),
'militærpoliti': ('militærpoliti',),
'militærpolitia': ('militærpoliti',),
'militærpolitiene': ('militærpoliti',),
'militærpolitier': ('militærpoliti',),
'militærpolitiet': ('militærpoliti',),
'militærregjering': ('militærregjering',),
'militærregjeringa': ('militærregjering',),
'militærregjeringen': ('militærregjering',),
'militærregjeringene': ('militærregjering',),
'militærregjeringer': ('militærregjering',),
'militærstat': ('militærstat',),
'militærstaten': ('militærstat',),
'militærstatene': ('militærstat',),
'militærstater': ('militærstat',),
'militærstyra': ('militærstyre',),
'militærstyre': ('militærstyre',),
'militærstyrene': ('militærstyre',),
'militærstyrer': ('militærstyre',),
'militærstyret': ('militærstyre',),
'militærtjeneste': ('militærtjeneste',),
'militærtjenesten': ('militærtjeneste',),
'militærtjenestene': ('militærtjeneste',),
'militærtjenester': ('militærtjeneste',),
'militærvelda': ('militærvelde',),
'militærvelde': ('militærvelde',),
'militærveldene': ('militærvelde',),
'militærvelder': ('militærvelde',),
'militærveldet': ('militærvelde',),
'militærvesen': ('militærvesen',),
'militærvesena': ('militærvesen',),
'militærvesenene': ('militærvesen',),
'militærvesener': ('militærvesen',),
'militærvesenet': ('militærvesen',),
'militærøvelse': ('militærøvelse',),
'militærøvelsen': ('militærøvelse',),
'militærøvelsene': ('militærøvelse',),
'militærøvelser': ('militærøvelse',),
'militærøving': ('militærøving',),
'militærøvinga': ('militærøving',),
'militærøvingen': ('militærøving',),
'militærøvingene': ('militærøving',),
'militærøvinger': ('militærøving',),
'miljø': ('miljø',),
'miljøa': ('miljø',),
'miljøene': ('miljø',),
'miljøer': ('miljø',),
'miljøet': ('miljø',),
'miljøarbeider': ('miljøarbeider',),
'miljøarbeidere': ('miljøarbeider',),
'miljøarbeideren': ('miljøarbeider',),
'miljøarbeiderer': ('miljøarbeider',),
'miljøarbeiderne': ('miljøarbeider',),
'miljøbot': ('miljøbot',),
'miljøbota': ('miljøbot',),
'miljøboten': ('miljøbot',),
'miljøbøtene': ('miljøbot',),
'miljøbøter': ('miljøbot',),
'miljøfaktor': ('miljøfaktor',),
'miljøfaktoren': ('miljøfaktor',),
'miljøfaktorene': ('miljøfaktor',),
'miljøfaktorer': ('miljøfaktor',),
'miljøkjemi': ('miljøkjemi',),
'miljøkjemien': ('miljøkjemi',),
'miljøkjemiene': ('miljøkjemi',),
'miljøkjemier': ('miljøkjemi',),
'miljøskade': ('miljøskade',),
'miljøskaden': ('miljøskade',),
'miljøskadene': ('miljøskade',),
'miljøskader': ('miljøskade',),
'miljøskildring': ('miljøskildring',),
'miljøskildringa': ('miljøskildring',),
'miljøskildringen': ('miljøskildring',),
'miljøskildringene': ('miljøskildring',),
'miljøskildringer': ('miljøskildring',),
'miljøterapeut': ('miljøterapeut',),
'miljøterapeuten': ('miljøterapeut',),
'miljøterapeutene': ('miljøterapeut',),
'miljøterapeuter': ('miljøterapeut',),
'miljøterapi': ('miljøterapi',),
'miljøterapien': ('miljøterapi',),
'miljøterapiene': ('miljøterapi',),
'miljøterapier': ('miljøterapi',),
'miljøvern': ('miljøvern',),
'miljøverna': ('miljøvern',),
'miljøvernene': ('miljøvern',),
'miljøvernet': ('miljøvern',),
'miljøverndepartement': ('miljøverndepartement',),
'miljøverndepartementa': ('miljøverndepartement',),
'miljøverndepartementene': ('miljøverndepartement',),
'miljøverndepartementer': ('miljøverndepartement',),
'miljøverndepartementet': ('miljøverndepartement',),
'miljøvernminister': ('miljøvernminister',),
'miljøvernministere': ('miljøvernminister',),
'miljøvernministeren': ('miljøvernminister',),
'miljøvernministerer': ('miljøvernminister',),
'miljøvernministerne': ('miljøvernminister',),
'miljøvernministre': ('miljøvernminister',),
'miljøvernministrene': ('miljøvernminister',),
'miljøvernministrer': ('miljøvernminister',),
'milkshake': ('milkshake',),
'milkshaken': ('milkshake',),
'milkshakene': ('milkshake',),
'milkshaker': ('milkshake',),
'mille': ('mille',),
'millen': ('mille',),
'millene': ('mille',),
'miller': ('mille',),
'millennia': ('millennium',),
'millenniene': ('millennium',),
'millennier': ('millennium',),
'millenniet': ('millennium',),
'millennium': ('millennium',),
'milliard': ('milliard',),
'milliarden': ('milliard',),
'milliardene': ('milliard',),
'milliarder': ('milliard',),
'milliarddel': ('milliarddel',),
'milliarddelen': ('milliarddel',),
'milliarddelene': ('milliarddel',),
'milliarddeler': ('milliarddel',),
'milliardær': ('milliardær',),
'milliardæren': ('milliardær',),
'milliardærene': ('milliardær',),
'milliardærer': ('milliardær',),
'millibar': ('millibar',),
'millibaren': ('millibar',),
'millibarene': ('millibar',),
'milligram': ('milligram',),
'milligramma': ('milligram',),
'milligrammene': ('milligram',),
'milligrammet': ('milligram',),
'million': ('million',),
'millionen': ('million',),
'millionene': ('million',),
'millioner': ('million',),
'millionby': ('millionby',),
'millionbyen': ('millionby',),
'millionbyene': ('millionby',),
'millionbyer': ('millionby',),
'milliondel': ('milliondel',),
'milliondelen': ('milliondel',),
'milliondelene': ('milliondel',),
'milliondeler': ('milliondel',),
'millionopplag': ('millionopplag',),
'millionopplaga': ('millionopplag',),
'millionopplagene': ('millionopplag',),
'millionopplaget': ('millionopplag',),
'millionær': ('millionær',),
'millionæren': ('millionær',),
'millionærene': ('millionær',),
'millionærer': ('millionær',),
'millivolt': ('millivolt',),
'millivolten': ('millivolt',),
'millivoltene': ('millivolt',),
'milliwatt': ('milliwatt',),
'milliwatten': ('milliwatt',),
'milliwattene': ('milliwatt',),
'milløper': ('milløper',),
'milløpere': ('milløper',),
'milløperen': ('milløper',),
'milløperer': ('milløper',),
'milløperne': ('milløper',),
'milorgmann': ('milorgmann',),
'milorgmannen': ('milorgmann',),
'milorgmenn': ('milorgmann',),
'milorgmennene': ('milorgmann',),
'milt': ('milt',),
'milten': ('milt',),
'miltene': ('milt',),
'milter': ('milt',),
'miltbrann': ('miltbrann',),
'miltbrannen': ('miltbrann',),
'miltbrannene': ('miltbrann',),
'miltbranner': ('miltbrann',),
'mime': ('mime',),
'mimen': ('mime',),
'mimene': ('mime',),
'mimer': ('mime',),
'mimiker': ('mimiker',),
'mimikere': ('mimiker',),
'mimikeren': ('mimiker',),
'mimikerer': ('mimiker',),
'mimikerne': ('mimiker',),
'mimikk': ('mimikk',),
'mimikken': ('mimikk',),
'mimikkene': ('mimikk',),
'mimikker': ('mimikk',),
'miming': ('miming',),
'miminga': ('miming',),
'mimingen': ('miming',),
'mimingene': ('miming',),
'miminger': ('miming',),
'mimosa': ('mimose',),
'mimose': ('mimose',),
'mimosen': ('mimose',),
'mimosene': ('mimose',),
'mimoser': ('mimose',),
'mimrekveld': ('mimrekveld',),
'mimrekvelden': ('mimrekveld',),
'mimrekveldene': ('mimrekveld',),
'mimrekvelder': ('mimrekveld',),
'minaret': ('minaret',),
'minareten': ('minaret',),
'minaretene': ('minaret',),
'minareter': ('minaret',),
'mindretal': ('mindretal',),
'mindretala': ('mindretal',),
'mindretalene': ('mindretal',),
'mindretalet': ('mindretal',),
'mindretall': ('mindretall',),
'mindretalla': ('mindretall',),
'mindretallene': ('mindretall',),
'mindretallet': ('mindretall',),
'mindretallsregjering': ('mindretallsregjering',),
'mindretallsregjeringa': ('mindretallsregjering',),
'mindretallsregjeringen': ('mindretallsregjering',),
'mindretallsregjeringene': ('mindretallsregjering',),
'mindretallsregjeringer': ('mindretallsregjering',),
'mindretalsregjering': ('mindretalsregjering',),
'mindretalsregjeringa': ('mindretalsregjering',),
'mindretalsregjeringen': ('mindretalsregjering',),
'mindretalsregjeringene': ('mindretalsregjering',),
'mindretalsregjeringer': ('mindretalsregjering',),
'mindreverd': ('mindreverd',),
'mindreverda': ('mindreverd',),
'mindreverdene': ('mindreverd',),
'mindreverdet': ('mindreverd',),
'mindreverdighet': ('mindreverdighet',),
'mindreverdigheta': ('mindreverdighet',),
'mindreverdigheten': ('mindreverdighet',),
'mindreverdighetene': ('mindreverdighet',),
'mindreverdigheter': ('mindreverdighet',),
'mindreverdighetskompleks': ('mindreverdighetskompleks',),
'mindreverdighetskompleksa': ('mindreverdighetskompleks',),
'mindreverdighetskompleksene': ('mindreverdighetskompleks',),
'mindreverdighetskomplekser': ('mindreverdighetskompleks',),
'mindreverdighetskomplekset': ('mindreverdighetskompleks',),
'mindreverdsfølelse': ('mindreverdsfølelse',),
'mindreverdsfølelsen': ('mindreverdsfølelse',),
'mindreverdsfølelsene': ('mindreverdsfølelse',),
'mindreverdsfølelser': ('mindreverdsfølelse',),
'mindreverdskjensla': ('mindreverdskjensle',),
'mindreverdskjensle': ('mindreverdskjensle',),
'mindreverdskjenslen': ('mindreverdskjensle',),
'mindreverdskjenslene': ('mindreverdskjensle',),
'mindreverdskjensler': ('mindreverdskjensle',),
'mina': ('mine',),
'mine': ('mine',),
'minen': ('mine',),
'minene': ('mine',),
'miner': ('mine',),
'mina': ('mine',),
'mine': ('mine',),
'minen': ('mine',),
'minene': ('mine',),
'miner': ('mine',),
'minebelta': ('minebelte',),
'minebelte': ('minebelte',),
'minebeltene': ('minebelte',),
'minebelter': ('minebelte',),
'minebeltet': ('minebelte',),
'minebor': ('minebor',),
'minebora': ('minebor',),
'mineboren': ('minebor',),
'mineborene': ('minebor',),
'mineboret': ('minebor',),
'minedetektor': ('minedetektor',),
'minedetektoren': ('minedetektor',),
'minedetektorene': ('minedetektor',),
'minedetektorer': ('minedetektor',),
'minefelt': ('minefelt',),
'minefelta': ('minefelt',),
'minefeltene': ('minefelt',),
'minefelter': ('minefelt',),
'minefeltet': ('minefelt',),
'minelegger': ('minelegger',),
'mineleggere': ('minelegger',),
'mineleggeren': ('minelegger',),
'mineleggerer': ('minelegger',),
'mineleggerne': ('minelegger',),
'mineral': ('mineral',),
'minerala': ('mineral',),
'mineralene': ('mineral',),
'mineraler': ('mineral',),
'mineralet': ('mineral',),
'mineraljord': ('mineraljord',),
'mineraljorda': ('mineraljord',),
'mineraljorden': ('mineraljord',),
'mineraljordene': ('mineraljord',),
'mineraljorder': ('mineraljord',),
'mineralog': ('mineralog',),
'mineralogen': ('mineralog',),
'mineralogene': ('mineralog',),
'mineraloger': ('mineralog',),
'mineralogi': ('mineralogi',),
'mineralogien': ('mineralogi',),
'mineralogiene': ('mineralogi',),
'mineralogier': ('mineralogi',),
'mineralolja': ('mineralolje',),
'mineralolje': ('mineralolje',),
'mineraloljen': ('mineralolje',),
'mineraloljene': ('mineralolje',),
'mineraloljer': ('mineralolje',),
'mineralrika': ('mineralrike',),
'mineralrike': ('mineralrike',),
'mineralrikene': ('mineralrike',),
'mineralriker': ('mineralrike',),
'mineralriket': ('mineralrike',),
'mineralstoff': ('mineralstoff',),
'mineralstoffa': ('mineralstoff',),
'mineralstoffene': ('mineralstoff',),
'mineralstoffer': ('mineralstoff',),
'mineralstoffet': ('mineralstoff',),
'mineralull': ('mineralull',),
'mineralulla': ('mineralull',),
'mineralullen': ('mineralull',),
'mineralullene': ('mineralull',),
'mineraluller': ('mineralull',),
'mineralvann': ('mineralvann',),
'mineralvanna': ('mineralvann',),
'mineralvannene': ('mineralvann',),
'mineralvannet': ('mineralvann',),
'mineralvatn': ('mineralvatn',),
'mineralvatna': ('mineralvatn',),
'mineralvatnene': ('mineralvatn',),
'mineralvatnet': ('mineralvatn',),
'mineskott': ('mineskott',),
'mineskotta': ('mineskott',),
'mineskottene': ('mineskott',),
'mineskottet': ('mineskott',),
'mineskudd': ('mineskudd',),
'mineskudda': ('mineskudd',),
'mineskuddene': ('mineskudd',),
'mineskuddet': ('mineskudd',),
'minespell': ('minespell',),
'minespella': ('minespell',),
'minespellene': ('minespell',),
'minespellet': ('minespell',),
'minespill': ('minespill',),
'minespilla': ('minespill',),
'minespillene': ('minespill',),
'minespillet': ('minespill',),
'minestronesuppa': ('minestronesuppe',),
'minestronesuppe': ('minestronesuppe',),
'minestronesuppen': ('minestronesuppe',),
'minestronesuppene': ('minestronesuppe',),
'minestronesupper': ('minestronesuppe',),
'minesveiper': ('minesveiper',),
'minesveipere': ('minesveiper',),
'minesveiperen': ('minesveiper',),
'minesveiperer': ('minesveiper',),
'minesveiperne': ('minesveiper',),
'miniatyr': ('miniatyr',),
'miniatyren': ('miniatyr',),
'miniatyrene': ('miniatyr',),
'miniatyrer': ('miniatyr',),
'miniatyrbilda': ('miniatyrbilde',),
'miniatyrbilde': ('miniatyrbilde',),
'miniatyrbildene': ('miniatyrbilde',),
'miniatyrbilder': ('miniatyrbilde',),
'miniatyrbildet': ('miniatyrbilde',),
'miniatyrgevær': ('miniatyrgevær',),
'miniatyrgeværa': ('miniatyrgevær',),
'miniatyrgeværene': ('miniatyrgevær',),
'miniatyrgeværer': ('miniatyrgevær',),
'miniatyrgeværet': ('miniatyrgevær',),
'miniatyrutgava': ('miniatyrutgave',),
'miniatyrutgave': ('miniatyrutgave',),
'miniatyrutgaven': ('miniatyrutgave',),
'miniatyrutgavene': ('miniatyrutgave',),
'miniatyrutgaver': ('miniatyrutgave',),
'minibank': ('minibank',),
'minibanken': ('minibank',),
'minibankene': ('minibank',),
'minibanker': ('minibank',),
'minibil': ('minibil',),
'minibilen': ('minibil',),
'minibilene': ('minibil',),
'minibiler': ('minibil',),
'minibuss': ('minibuss',),
'minibussen': ('minibuss',),
'minibussene': ('minibuss',),
'minibusser': ('minibuss',),
'minidatamaskin': ('minidatamaskin',),
'minidatamaskina': ('minidatamaskin',),
'minidatamaskinen': ('minidatamaskin',),
'minidatamaskinene': ('minidatamaskin',),
'minidatamaskiner': ('minidatamaskin',),
'minigolf': ('minigolf',),
'minigolfen': ('minigolf',),
'minigolfene': ('minigolf',),
'minigolfer': ('minigolf',),
'minikalkulator': ('minikalkulator',),
'minikalkulatoren': ('minikalkulator',),
'minikalkulatorene': ('minikalkulator',),
'minikalkulatorer': ('minikalkulator',),
'minikjole': ('minikjole',),
'minikjolen': ('minikjole',),
'minikjolene': ('minikjole',),
'minikjoler': ('minikjole',),
'minima': ('minimum',),
'minimaene': ('minimum',),
'minimum': ('minimum',),
'minimuma': ('minimum',),
'minimumene': ('minimum',),
'minimumer': ('minimum',),
'minimumet': ('minimum',),
'minimumsgrensa': ('minimumsgrense',),
'minimumsgrense': ('minimumsgrense',),
'minimumsgrensen': ('minimumsgrense',),
'minimumsgrensene': ('minimumsgrense',),
'minimumsgrenser': ('minimumsgrense',),
'minimumskrav': ('minimumskrav',),
'minimumskrava': ('minimumskrav',),
'minimumskravene': ('minimumskrav',),
'minimumskravet': ('minimumskrav',),
'minimumstemperatur': ('minimumstemperatur',),
'minimumstemperaturen': ('minimumstemperatur',),
'minimumstemperaturene': ('minimumstemperatur',),
'minimumstemperaturer': ('minimumstemperatur',),
'minimumstermometer': ('minimumstermometer',),
'minimumstermometeret': ('minimumstermometer',),
'minimumstermometra': ('minimumstermometer',),
'minimumstermometre': ('minimumstermometer',),
'minimumstermometrene': ('minimumstermometer',),
'minimumstermometret': ('minimumstermometer',),
'miniputt': ('miniputt',),
'miniputten': ('miniputt',),
'miniputtene': ('miniputt',),
'miniputter': ('miniputt',),
'miniputtlag': ('miniputtlag',),
'miniputtlaga': ('miniputtlag',),
'miniputtlagene': ('miniputtlag',),
'miniputtlaget': ('miniputtlag',),
'miniski': ('miniski',),
'miniskia': ('miniski',),
'miniskien': ('miniski',),
'miniskiene': ('miniski',),
'miniskier': ('miniski',),
'miniskjørt': ('miniskjørt',),
'miniskjørta': ('miniskjørt',),
'miniskjørtene': ('miniskjørt',),
'miniskjørter': ('miniskjørt',),
'miniskjørtet': ('miniskjørt',),
'minister': ('minister',),
'ministere': ('minister',),
'ministeren': ('minister',),
'ministerer': ('minister',),
'ministerne': ('minister',),
'ministre': ('minister',),
'ministrene': ('minister',),
'ministrer': ('minister',),
'ministerialbok': ('ministerialbok',),
'ministerialboka': ('ministerialbok',),
'ministerialboken': ('ministerialbok',),
'ministerialbøkene': ('ministerialbok',),
'ministerialbøker': ('ministerialbok',),
'ministeria': ('ministerium',),
'ministeriene': ('ministerium',),
'ministerier': ('ministerium',),
'ministeriet': ('ministerium',),
'ministerium': ('ministerium',),
'ministerplan': ('ministerplan',),
'ministerplana': ('ministerplan',),
'ministerplanene': ('ministerplan',),
'ministerplanet': ('ministerplan',),
'ministerpresident': ('ministerpresident',),
'ministerpresidenten': ('ministerpresident',),
'ministerpresidentene': ('ministerpresident',),
'ministerpresidenter': ('ministerpresident',),
'ministerråd': ('ministerråd',),
'ministerråden': ('ministerråd',),
'ministerrådene': ('ministerråd',),
'ministerråder': ('ministerråd',),
'ministerråd': ('ministerråd',),
'ministerråda': ('ministerråd',),
'ministerrådene': ('ministerråd',),
'ministerrådet': ('ministerråd',),
'minjongpæra': ('minjongpære',),
'minjongpære': ('minjongpære',),
'minjongpæren': ('minjongpære',),
'minjongpærene': ('minjongpære',),
'minjongpærer': ('minjongpære',),
'minjongpæra': ('minjongpære',),
'minjongpære': ('minjongpære',),
'minjongpæren': ('minjongpære',),
'minjongpærene': ('minjongpære',),
'minjongpærer': ('minjongpære',),
'mink': ('mink',),
'minken': ('mink',),
'minkene': ('mink',),
'minker': ('mink',),
'minkfarm': ('minkfarm',),
'minkfarmen': ('minkfarm',),
'minkfarmene': ('minkfarm',),
'minkfarmer': ('minkfarm',),
'minking': ('minking',),
'minkinga': ('minking',),
'minkingen': ('minking',),
'minkingene': ('minking',),
'minkinger': ('minking',),
'minkkåpa': ('minkkåpe',),
'minkkåpe': ('minkkåpe',),
'minkkåpen': ('minkkåpe',),
'minkkåpene': ('minkkåpe',),
'minkkåper': ('minkkåpe',),
'minkoppdrett': ('minkoppdrett',),
'minkoppdretta': ('minkoppdrett',),
'minkoppdrettene': ('minkoppdrett',),
'minkoppdrettet': ('minkoppdrett',),
'minkpels': ('minkpels',),
'minkpelsen': ('minkpels',),
'minkpelsene': ('minkpels',),
'minkpelser': ('minkpels',),
'minkskinn': ('minkskinn',),
'minkskinna': ('minkskinn',),
'minkskinnene': ('minkskinn',),
'minkskinnet': ('minkskinn',),
'minna': ('minne',),
'minne': ('minne',),
'minnene': ('minne',),
'minner': ('minne',),
'minnet': ('minne',),
'minnebok': ('minnebok',),
'minneboka': ('minnebok',),
'minneboken': ('minnebok',),
'minnebøkene': ('minnebok',),
'minnebøker': ('minnebok',),
'minnedag': ('minnedag',),
'minnedagen': ('minnedag',),
'minnedagene': ('minnedag',),
'minnedager': ('minnedag',),
'minnefest': ('minnefest',),
'minnefesten': ('minnefest',),
'minnefestene': ('minnefest',),
'minnefester': ('minnefest',),
'minnehøgtid': ('minnehøgtid',),
'minnehøgtida': ('minnehøgtid',),
'minnehøgtiden': ('minnehøgtid',),
'minnehøgtidene': ('minnehøgtid',),
'minnehøgtider': ('minnehøgtid',),
'minnehøytid': ('minnehøytid',),
'minnehøytida': ('minnehøytid',),
'minnehøytiden': ('minnehøytid',),
'minnehøytidene': ('minnehøytid',),
'minnehøytider': ('minnehøytid',),
'minnelighet': ('minnelighet',),
'minneligheta': ('minnelighet',),
'minneligheten': ('minnelighet',),
'minnelighetene': ('minnelighet',),
'minneligheter': ('minnelighet',),
'minnelse': ('minnelse',),
'minnelsen': ('minnelse',),
'minnelsene': ('minnelse',),
'minnelser': ('minnelse',),
'minnemynt': ('minnemynt',),
'minnemynten': ('minnemynt',),
'minnemyntene': ('minnemynt',),
'minnemynter': ('minnemynt',),
'minneord': ('minneord',),
'minneorda': ('minneord',),
'minneordene': ('minneord',),
'minneordet': ('minneord',),
'minnesamvær': ('minnesamvær',),
'minnesamværa': ('minnesamvær',),
'minnesamværene': ('minnesamvær',),
'minnesamværet': ('minnesamvær',),
'minnesang': ('minnesang',),
'minnesangen': ('minnesang',),
'minnesangene': ('minnesang',),
'minnesanger': ('minnesang',),
'minnesmerka': ('minnesmerke',),
'minnesmerke': ('minnesmerke',),
'minnesmerkene': ('minnesmerke',),
'minnesmerker': ('minnesmerke',),
'minnesmerket': ('minnesmerke',),
'minnestein': ('minnestein',),
'minnesteinen': ('minnestein',),
'minnesteinene': ('minnestein',),
'minnesteiner': ('minnestein',),
'minnestund': ('minnestund',),
'minnestunda': ('minnestund',),
'minnestunden': ('minnestund',),
'minnestundene': ('minnestund',),
'minnestunder': ('minnestund',),
'minnetal': ('minnetal',),
'minnetala': ('minnetal',),
'minnetalene': ('minnetal',),
'minnetalet': ('minnetal',),
'minnetale': ('minnetale',),
'minnetalen': ('minnetale',),
'minnetalene': ('minnetale',),
'minnetaler': ('minnetale',),
'minnetall': ('minnetall',),
'minnetalla': ('minnetall',),
'minnetallene': ('minnetall',),
'minnetallet': ('minnetall',),
'minning': ('minning',),
'minninga': ('minning',),
'minningen': ('minning',),
'minningene': ('minning',),
'minninger': ('minning',),
'minoritet': ('minoritet',),
'minoriteten': ('minoritet',),
'minoritetene': ('minoritet',),
'minoriteter': ('minoritet',),
'minoritetsgruppa': ('minoritetsgruppe',),
'minoritetsgruppe': ('minoritetsgruppe',),
'minoritetsgruppen': ('minoritetsgruppe',),
'minoritetsgruppene': ('minoritetsgruppe',),
'minoritetsgrupper': ('minoritetsgruppe',),
'minoritetsspråk': ('minoritetsspråk',),
'minoritetsspråka': ('minoritetsspråk',),
'minoritetsspråkene': ('minoritetsspråk',),
'minoritetsspråket': ('minoritetsspråk',),
'minoritt': ('minoritt',),
'minoritten': ('minoritt',),
'minorittene': ('minoritt',),
'minoritter': ('minoritt',),
'minorittbroder': ('minorittbroder',),
'minorittbroderen': ('minorittbroder',),
'minorittbrødre': ('minorittbroder',),
'minorittbrødrene': ('minorittbroder',),
'minorittbror': ('minorittbror',),
'minorittbroren': ('minorittbror',),
'minorittbrødre': ('minorittbror',),
'minorittbrødrene': ('minorittbror',),
'minorittkloster': ('minorittkloster',),
'minorittklosteret': ('minorittkloster',),
'minorittklostra': ('minorittkloster',),
'minorittklostre': ('minorittkloster',),
'minorittklostrene': ('minorittkloster',),
'minorittklostret': ('minorittkloster',),
'minsking': ('minsking',),
'minskinga': ('minsking',),
'minskingen': ('minsking',),
'minskingene': ('minsking',),
'minskinger': ('minsking',),
'minstealder': ('minstealder',),
'minstealdere': ('minstealder',),
'minstealderen': ('minstealder',),
'minstealderer': ('minstealder',),
'minstealderne': ('minstealder',),
'minstealdre': ('minstealder',),
'minstealdrene': ('minstealder',),
'minstealdrer': ('minstealder',),
'minstebarn': ('minstebarn',),
'minstebarna': ('minstebarn',),
'minstebarnene': ('minstebarn',),
'minstebarnet': ('minstebarn',),
'minstebeløp': ('minstebeløp',),
'minstebeløpa': ('minstebeløp',),
'minstebeløpene': ('minstebeløp',),
'minstebeløpet': ('minstebeløp',),
'minstefradrag': ('minstefradrag',),
'minstefradraga': ('minstefradrag',),
'minstefradragene': ('minstefradrag',),
'minstefradraget': ('minstefradrag',),
'minstekrav': ('minstekrav',),
'minstekrava': ('minstekrav',),
'minstekravene': ('minstekrav',),
'minstekravet': ('minstekrav',),
'minstelønn': ('minstelønn',),
'minstelønna': ('minstelønn',),
'minstelønnen': ('minstelønn',),
'minstelønnene': ('minstelønn',),
'minstelønner': ('minstelønn',),
'minstemann': ('minstemann',),
'minstemannen': ('minstemann',),
'minstemannene': ('minstemann',),
'minstemanner': ('minstemann',),
'minstemål': ('minstemål',),
'minstemåla': ('minstemål',),
'minstemålene': ('minstemål',),
'minstemålet': ('minstemål',),
'minstepensjon': ('minstepensjon',),
'minstepensjonen': ('minstepensjon',),
'minstepensjonene': ('minstepensjon',),
'minstepensjoner': ('minstepensjon',),
'minstepensjonist': ('minstepensjonist',),
'minstepensjonisten': ('minstepensjonist',),
'minstepensjonistene': ('minstepensjonist',),
'minstepensjonister': ('minstepensjonist',),
'minstepris': ('minstepris',),
'minsteprisen': ('minstepris',),
'minsteprisene': ('minstepris',),
'minstepriser': ('minstepris',),
'minstesum': ('minstesum',),
'minstesummen': ('minstesum',),
'minstesummene': ('minstesum',),
'minstesummer': ('minstesum',),
'minstetakst': ('minstetakst',),
'minstetaksten': ('minstetakst',),
'minstetakstene': ('minstetakst',),
'minstetakster': ('minstetakst',),
'minstrel': ('minstrel',),
'minstrelen': ('minstrel',),
'minstrelene': ('minstrel',),
'minstreler': ('minstrel',),
'minuend': ('minuend',),
'minuenden': ('minuend',),
'minuendene': ('minuend',),
'minuender': ('minuend',),
'minus': ('minus',),
'minusa': ('minus',),
'minusene': ('minus',),
'minuser': ('minus',),
'minuset': ('minus',),
'minusfaktor': ('minusfaktor',),
'minusfaktoren': ('minusfaktor',),
'minusfaktorene': ('minusfaktor',),
'minusfaktorer': ('minusfaktor',),
'minusflyktning': ('minusflyktning',),
'minusflyktningen': ('minusflyktning',),
'minusflyktningene': ('minusflyktning',),
'minusflyktninger': ('minusflyktning',),
'minusgrad': ('minusgrad',),
'minusgraden': ('minusgrad',),
'minusgradene': ('minusgrad',),
'minusgrader': ('minusgrad',),
'minuskel': ('minuskel',),
'minuskelen': ('minuskel',),
'minusklene': ('minuskel',),
'minuskler': ('minuskel',),
'minusmål': ('minusmål',),
'minusmåla': ('minusmål',),
'minusmålene': ('minusmål',),
'minusmålet': ('minusmål',),
'minusord': ('minusord',),
'minusorda': ('minusord',),
'minusordene': ('minusord',),
'minusordet': ('minusord',),
'minussida': ('minusside',),
'minusside': ('minusside',),
'minussiden': ('minusside',),
'minussidene': ('minusside',),
'minussider': ('minusside',),
'minustegn': ('minustegn',),
'minustegna': ('minustegn',),
'minustegnene': ('minustegn',),
'minustegnet': ('minustegn',),
'minusvariant': ('minusvariant',),
'minusvarianten': ('minusvariant',),
'minusvariantene': ('minusvariant',),
'minusvarianter': ('minusvariant',),
'minutt': ('minutt',),
'minutta': ('minutt',),
'minuttene': ('minutt',),
'minutter': ('minutt',),
'minuttet': ('minutt',),
'minuttviser': ('minuttviser',),
'minuttvisere': ('minuttviser',),
'minuttviseren': ('minuttviser',),
'minuttviserer': ('minuttviser',),
'minuttviserne': ('minuttviser',),
'mirakel': ('mirakel',),
'mirakelet': ('mirakel',),
'mirakla': ('mirakel',),
'miraklene': ('mirakel',),
'mirakler': ('mirakel',),
'miraklet': ('mirakel',),
'mirakeldoktor': ('mirakeldoktor',),
'mirakeldoktoren': ('mirakeldoktor',),
'mirakeldoktorene': ('mirakeldoktor',),
'mirakeldoktorer': ('mirakeldoktor',),
'misère': ('misère',),
'misèren': ('misère',),
'misèrene': ('misère',),
'misèrer': ('misère',),
'misantrop': ('misantrop',),
'misantropen': ('misantrop',),
'misantropene': ('misantrop',),
'misantroper': ('misantrop',),
'misantropi': ('misantropi',),
'misantropien': ('misantropi',),
'misantropiene': ('misantropi',),
'misantropier': ('misantropi',),
'misbruk': ('misbruk',),
'misbruka': ('misbruk',),
'misbruken': ('misbruk',),
'misbrukene': ('misbruk',),
'misbruker': ('misbruk',),
'misbruket': ('misbruk',),
'misdannelse': ('misdannelse',),
'misdannelsen': ('misdannelse',),
'misdannelsene': ('misdannelse',),
'misdannelser': ('misdannelse',),
'misdanning': ('misdanning',),
'misdanninga': ('misdanning',),
'misdanningen': ('misdanning',),
'misdanningene': ('misdanning',),
'misdanninger': ('misdanning',),
'misdeder': ('misdeder',),
'misdedere': ('misdeder',),
'misdederen': ('misdeder',),
'misdederer': ('misdeder',),
'misdederne': ('misdeder',),
'misforhold': ('misforhold',),
'misforholda': ('misforhold',),
'misforholdene': ('misforhold',),
'misforholdet': ('misforhold',),
'misforståelse': ('misforståelse',),
'misforståelsen': ('misforståelse',),
'misforståelsene': ('misforståelse',),
'misforståelser': ('misforståelse',),
'misfoster': ('misfoster',),
'misfosteret': ('misfoster',),
'misfostra': ('misfoster',),
'misfostre': ('misfoster',),
'misfostrene': ('misfoster',),
'misfostret': ('misfoster',),
'misgjerning': ('misgjerning',),
'misgjerninga': ('misgjerning',),
'misgjerningen': ('misgjerning',),
'misgjerningene': ('misgjerning',),
'misgjerninger': ('misgjerning',),
'misgrep': ('misgrep',),
'misgrepa': ('misgrep',),
'misgrepene': ('misgrep',),
'misgrepet': ('misgrep',),
'mishag': ('mishag',),
'mishaga': ('mishag',),
'mishagene': ('mishag',),
'mishaget': ('mishag',),
'mishagsytring': ('mishagsytring',),
'mishagsytringa': ('mishagsytring',),
'mishagsytringen': ('mishagsytring',),
'mishagsytringene': ('mishagsytring',),
'mishagsytringer': ('mishagsytring',),
'mishandling': ('mishandling',),
'mishandlinga': ('mishandling',),
'mishandlingen': ('mishandling',),
'mishandlingene': ('mishandling',),
'mishandlinger': ('mishandling',),
'mishøva': ('mishøve',),
'mishøve': ('mishøve',),
'mishøvene': ('mishøve',),
'mishøver': ('mishøve',),
'mishøvet': ('mishøve',),
'misjon': ('misjon',),
'misjonen': ('misjon',),
'misjonene': ('misjon',),
'misjoner': ('misjon',),
'misjonsarbeid': ('misjonsarbeid',),
'misjonsarbeida': ('misjonsarbeid',),
'misjonsarbeidene': ('misjonsarbeid',),
'misjonsarbeider': ('misjonsarbeid',),
'misjonsarbeidet': ('misjonsarbeid',),
'misjonsbefaling': ('misjonsbefaling',),
'misjonsbefalinga': ('misjonsbefaling',),
'misjonsbefalingen': ('misjonsbefaling',),
'misjonsbefalingene': ('misjonsbefaling',),
'misjonsbefalinger': ('misjonsbefaling',),
'misjonsforening': ('misjonsforening',),
'misjonsforeninga': ('misjonsforening',),
'misjonsforeningen': ('misjonsforening',),
'misjonsforeningene': ('misjonsforening',),
'misjonsforeninger': ('misjonsforening',),
'misjonshøgskole': ('misjonshøgskole',),
'misjonshøgskolen': ('misjonshøgskole',),
'misjonshøgskolene': ('misjonshøgskole',),
'misjonshøgskoler': ('misjonshøgskole',),
'misjonshøyskole': ('misjonshøyskole',),
'misjonshøyskolen': ('misjonshøyskole',),
'misjonshøyskolene': ('misjonshøyskole',),
'misjonshøyskoler': ('misjonshøyskole',),
'misjonsmark': ('misjonsmark',),
'misjonsmarka': ('misjonsmark',),
'misjonsmarken': ('misjonsmark',),
'misjonsmarkene': ('misjonsmark',),
'misjonsmarker': ('misjonsmark',),
'misjonsselskap': ('misjonsselskap',),
'misjonsselskapa': ('misjonsselskap',),
'misjonsselskapene': ('misjonsselskap',),
'misjonsselskaper': ('misjonsselskap',),
'misjonsselskapet': ('misjonsselskap',),
'misjonsskole': ('misjonsskole',),
'misjonsskolen': ('misjonsskole',),
'misjonsskolene': ('misjonsskole',),
'misjonsskoler': ('misjonsskole',),
'misjonsstasjon': ('misjonsstasjon',),
'misjonsstasjonen': ('misjonsstasjon',),
'misjonsstasjonene': ('misjonsstasjon',),
'misjonsstasjoner': ('misjonsstasjon',),
'misjonær': ('misjonær',),
'misjonæren': ('misjonær',),
'misjonærene': ('misjonær',),
'misjonærer': ('misjonær',),
'misjonærkall': ('misjonærkall',),
'misjonærkalla': ('misjonærkall',),
'misjonærkallene': ('misjonærkall',),
'misjonærkallet': ('misjonærkall',),
'misjonærstilling': ('misjonærstilling',),
'misjonærstillinga': ('misjonærstilling',),
'misjonærstillingen': ('misjonærstilling',),
'misjonærstillingene': ('misjonærstilling',),
'misjonærstillinger': ('misjonærstilling',),
'misklang': ('misklang',),
'misklangen': ('misklang',),
'misklangene': ('misklang',),
'misklanger': ('misklang',),
'miskmask': ('miskmask',),
'miskmaska': ('miskmask',),
'miskmaskene': ('miskmask',),
'miskmasket': ('miskmask',),
'miskreditt': ('miskreditt',),
'miskreditten': ('miskreditt',),
'miskredittene': ('miskreditt',),
'miskreditter': ('miskreditt',),
'miskunn': ('miskunn',),
'miskunnen': ('miskunn',),
'miskunnene': ('miskunn',),
'miskunner': ('miskunn',),
'mislighet': ('mislighet',),
'misligheta': ('mislighet',),
'misligheten': ('mislighet',),
'mislighetene': ('mislighet',),
'misligheter': ('mislighet',),
'mislighold': ('mislighold',),
'misligholda': ('mislighold',),
'misligholdene': ('mislighold',),
'misligholdet': ('mislighold',),
'mislyd': ('mislyd',),
'mislyden': ('mislyd',),
'mislydene': ('mislyd',),
'mislyder': ('mislyd',),
'mislykkethet': ('mislykkethet',),
'mislykketheta': ('mislykkethet',),
'mislykketheten': ('mislykkethet',),
'mislykkethetene': ('mislykkethet',),
'mislykketheter': ('mislykkethet',),
'mislykthet': ('mislykthet',),
'mislyktheta': ('mislykthet',),
'mislyktheten': ('mislykthet',),
'mislykthetene': ('mislykthet',),
'mislyktheter': ('mislykthet',),
'mismodighet': ('mismodighet',),
'mismodigheta': ('mismodighet',),
'mismodigheten': ('mismodighet',),
'mismodighetene': ('mismodighet',),
'mismodigheter': ('mismodighet',),
'mismot': ('mismot',),
'mismota': ('mismot',),
'mismotene': ('mismot',),
'mismotet': ('mismot',),
'misnøye': ('misnøye',),
'misnøyen': ('misnøye',),
'misnøyene': ('misnøye',),
'misnøyer': ('misnøye',),
'misogyn': ('misogyn',),
'misogynen': ('misogyn',),
'misogynene': ('misogyn',),
'misogyner': ('misogyn',),
'misogyni': ('misogyni',),
'misogynien': ('misogyni',),
'misogyniene': ('misogyni',),
'misogynier': ('misogyni',),
'misoppfatning': ('misoppfatning',),
'misoppfatninga': ('misoppfatning',),
'misoppfatningen': ('misoppfatning',),
'misoppfatningene': ('misoppfatning',),
'misoppfatninger': ('misoppfatning',),
'misoppfattelse': ('misoppfattelse',),
'misoppfattelsen': ('misoppfattelse',),
'misoppfattelsene': ('misoppfattelse',),
'misoppfattelser': ('misoppfattelse',),
'mispel': ('mispel',),
'mispelen': ('mispel',),
'misplene': ('mispel',),
'mispler': ('mispel',),
'mispeltre': ('mispeltre',),
'mispeltrea': ('mispeltre',),
'mispeltreet': ('mispeltre',),
'mispeltrær': ('mispeltre',),
'mispeltrærne': ('mispeltre',),
'miss': ('miss',),
'missen': ('miss',),
'missene': ('miss',),
'misser': ('miss',),
'miss': ('miss',),
'missen': ('miss',),
'missene': ('miss',),
'misser': ('miss',),
'miss': ('miss',),
'miss': ('miss',),
'missala': ('missale',),
'missale': ('missale',),
'missalene': ('missale',),
'missaler': ('missale',),
'missalet': ('missale',),
'missekonkurranse': ('missekonkurranse',),
'missekonkurransen': ('missekonkurranse',),
'missekonkurransene': ('missekonkurranse',),
'missekonkurranser': ('missekonkurranse',),
'missekåring': ('missekåring',),
'missekåringa': ('missekåring',),
'missekåringen': ('missekåring',),
'missekåringene': ('missekåring',),
'missekåringer': ('missekåring',),
'misseroman': ('misseroman',),
'misseromanen': ('misseroman',),
'misseromanene': ('misseroman',),
'misseromaner': ('misseroman',),
'missil': ('missil',),
'missila': ('missil',),
'missilene': ('missil',),
'missiler': ('missil',),
'missilet': ('missil',),
'misstemning': ('misstemning',),
'misstemninga': ('misstemning',),
'misstemningen': ('misstemning',),
'misstemningene': ('misstemning',),
'misstemninger': ('misstemning',),
'mist': ('mist',),
'mist': ('mist',),
'mistak': ('mistak',),
'mistaka': ('mistak',),
'mistakene': ('mistak',),
'mistaket': ('mistak',),
'mistanke': ('mistanke',),
'mistanken': ('mistanke',),
'mistankene': ('mistanke',),
'mistanker': ('mistanke',),
'mistbenk': ('mistbenk',),
'mistbenken': ('mistbenk',),
'mistbenkene': ('mistbenk',),
'mistbenker': ('mistbenk',),
'misteltein': ('misteltein',),
'mistelteinen': ('misteltein',),
'mistelteinene': ('misteltein',),
'mistelteiner': ('misteltein',),
'mister': ('mister',),
'mistere': ('mister',),
'misteren': ('mister',),
'misterer': ('mister',),
'misterne': ('mister',),
'mistre': ('mister',),
'mistrene': ('mister',),
'mistrer': ('mister',),
'mistillit': ('mistillit',),
'mistillita': ('mistillit',),
'mistilliten': ('mistillit',),
'mistillitene': ('mistillit',),
'mistilliter': ('mistillit',),
'mistillitsforslag': ('mistillitsforslag',),
'mistillitsforslaga': ('mistillitsforslag',),
'mistillitsforslagene': ('mistillitsforslag',),
'mistillitsforslaget': ('mistillitsforslag',),
'mistillitsvota': ('mistillitsvotum',),
'mistillitsvotaene': ('mistillitsvotum',),
'mistillitsvotum': ('mistillitsvotum',),
'mistillitsvotumet': ('mistillitsvotum',),
'mistrivsel': ('mistrivsel',),
'mistrivselen': ('mistrivsel',),
'mistrivslene': ('mistrivsel',),
'mistrivsler': ('mistrivsel',),
'mistro': ('mistro',),
'mistroa': ('mistro',),
'mistroen': ('mistro',),
'mistroene': ('mistro',),
'mistroer': ('mistro',),
'mistru': ('mistru',),
'mistrua': ('mistru',),
'mistruen': ('mistru',),
'mistruene': ('mistru',),
'mistruer': ('mistru',),
'misunnelse': ('misunnelse',),
'misunnelsen': ('misunnelse',),
'misunnelsene': ('misunnelse',),
'misunnelser': ('misunnelse',),
'misvekst': ('misvekst',),
'misveksten': ('misvekst',),
'misvekstene': ('misvekst',),
'misvekster': ('misvekst',),
'misvising': ('misvising',),
'misvisinga': ('misvising',),
'misvisingen': ('misvising',),
'misvisingene': ('misvising',),
'misvisinger': ('misvising',),
'misvisning': ('misvisning',),
'misvisninga': ('misvisning',),
'misvisningen': ('misvisning',),
'misvisningene': ('misvisning',),
'misvisninger': ('misvisning',),
'misvokster': ('misvokster',),
'misvokstere': ('misvokster',),
'misvoksteren': ('misvokster',),
'misvoksterer': ('misvokster',),
'misvoksterne': ('misvokster',),
'misvokstre': ('misvokster',),
'misvokstrene': ('misvokster',),
'misvokstrer': ('misvokster',),
'mit': ('mit',),
'miten': ('mit',),
'mitene': ('mit',),
'miter': ('mit',),
'mit': ('mit',),
'miten': ('mit',),
'mitene': ('mit',),
'miter': ('mit',),
'mitose': ('mitose',),
'mitosen': ('mitose',),
'mitosene': ('mitose',),
'mitoser': ('mitose',),
'mitra': ('mitra',),
'mitraen': ('mitra',),
'mitraene': ('mitra',),
'mitraer': ('mitra',),
'mitraljøsa': ('mitraljøse',),
'mitraljøse': ('mitraljøse',),
'mitraljøsen': ('mitraljøse',),
'mitraljøsene': ('mitraljøse',),
'mitraljøser': ('mitraljøse',),
'mixed double': ('mixed double',),
'mixed doublen': ('mixed double',),
'mixed doublene': ('mixed double',),
'mixed doubler': ('mixed double',),
'mjau': ('mjau',),
'mjaua': ('mjau',),
'mjauene': ('mjau',),
'mjauet': ('mjau',),
'mjele': ('mjele',),
'mjelen': ('mjele',),
'mjelene': ('mjele',),
'mjeler': ('mjele',),
'mjelejord': ('mjelejord',),
'mjelejorda': ('mjelejord',),
'mjelejorden': ('mjelejord',),
'mjelejordene': ('mjelejord',),
'mjelejorder': ('mjelejord',),
'mjelesand': ('mjelesand',),
'mjelesanden': ('mjelesand',),
'mjelesandene': ('mjelesand',),
'mjelesander': ('mjelesand',),
'mjukis': ('mjukis',),
'mjukisen': ('mjukis',),
'mjukisene': ('mjukis',),
'mjukiser': ('mjukis',),
'mjuklanding': ('mjuklanding',),
'mjuklandinga': ('mjuklanding',),
'mjuklandingen': ('mjuklanding',),
'mjuklandingene': ('mjuklanding',),
'mjuklandinger': ('mjuklanding',),
'mjukner': ('mjukner',),
'mjuknere': ('mjukner',),
'mjukneren': ('mjukner',),
'mjuknerer': ('mjukner',),
'mjuknerne': ('mjukner',),
'mjukplast': ('mjukplast',),
'mjukplasten': ('mjukplast',),
'mjukplastene': ('mjukplast',),
'mjukplaster': ('mjukplast',),
'mjårygg': ('mjårygg',),
'mjåryggen': ('mjårygg',),
'mjåryggene': ('mjårygg',),
'mjårygger': ('mjårygg',),
'mjød': ('mjød',),
'mjøden': ('mjød',),
'mjødene': ('mjød',),
'mjøder': ('mjød',),
'mjødm': ('mjødm',),
'mjødma': ('mjødm',),
'mjødmen': ('mjødm',),
'mjødmene': ('mjødm',),
'mjødmer': ('mjødm',),
'mjødurt': ('mjødurt',),
'mjødurta': ('mjødurt',),
'mjødurten': ('mjødurt',),
'mjødurtene': ('mjødurt',),
'mjødurter': ('mjødurt',),
'mjøl': ('mjøl',),
'mjøla': ('mjøl',),
'mjølene': ('mjøl',),
'mjølet': ('mjøl',),
'mjøldogg': ('mjøldogg',),
'mjøldoggen': ('mjøldogg',),
'mjøldoggene': ('mjøldogg',),
'mjøldogger': ('mjøldogg',),
'mjøldrøya': ('mjøldrøye',),
'mjøldrøye': ('mjøldrøye',),
'mjøldrøyen': ('mjøldrøye',),
'mjøldrøyene': ('mjøldrøye',),
'mjøldrøyer': ('mjøldrøye',),
'mjøldrøyesopp': ('mjøldrøyesopp',),
'mjøldrøyesoppen': ('mjøldrøyesopp',),
'mjøldrøyesoppene': ('mjøldrøyesopp',),
'mjøldrøyesopper': ('mjøldrøyesopp',),
'mjølk': ('mjølk',),
'mjølka': ('mjølk',),
'mjølken': ('mjølk',),
'mjølkene': ('mjølk',),
'mjølker': ('mjølk',),
'mjølke': ('mjølke',),
'mjølken': ('mjølke',),
'mjølkene': ('mjølke',),
'mjølker': ('mjølke',),
'mjølkebil': ('mjølkebil',),
'mjølkebilen': ('mjølkebil',),
'mjølkebilene': ('mjølkebil',),
'mjølkebiler': ('mjølkebil',),
'mjølkebutikk': ('mjølkebutikk',),
'mjølkebutikken': ('mjølkebutikk',),
'mjølkebutikkene': ('mjølkebutikk',),
'mjølkebutikker': ('mjølkebutikk',),
'mjølkebøtta': ('mjølkebøtte',),
'mjølkebøtte': ('mjølkebøtte',),
'mjølkebøtten': ('mjølkebøtte',),
'mjølkebøttene': ('mjølkebøtte',),
'mjølkebøtter': ('mjølkebøtte',),
'mjølkefe': ('mjølkefe',),
'mjølkefea': ('mjølkefe',),
'mjølkefeene': ('mjølkefe',),
'mjølkefeet': ('mjølkefe',),
'mjølkefeber': ('mjølkefeber',),
'mjølkefebere': ('mjølkefeber',),
'mjølkefeberen': ('mjølkefeber',),
'mjølkefeberne': ('mjølkefeber',),
'mjølkefebre': ('mjølkefeber',),
'mjølkefebrene': ('mjølkefeber',),
'mjølkefebrer': ('mjølkefeber',),
'mjølkeflaska': ('mjølkeflaske',),
'mjølkeflaske': ('mjølkeflaske',),
'mjølkeflasken': ('mjølkeflaske',),
'mjølkeflaskene': ('mjølkeflaske',),
'mjølkeflasker': ('mjølkeflaske',),
'mjølkeglas': ('mjølkeglas',),
'mjølkeglasa': ('mjølkeglas',),
'mjølkeglasene': ('mjølkeglas',),
'mjølkeglaset': ('mjølkeglas',),
'mjølkeglass': ('mjølkeglass',),
'mjølkeglassa': ('mjølkeglass',),
'mjølkeglassene': ('mjølkeglass',),
'mjølkeglasset': ('mjølkeglass',),
'mjølkekartong': ('mjølkekartong',),
'mjølkekartongen': ('mjølkekartong',),
'mjølkekartongene': ('mjølkekartong',),
'mjølkekartonger': ('mjølkekartong',),
'mjølkekjertel': ('mjølkekjertel',),
'mjølkekjertelen': ('mjølkekjertel',),
'mjølkekjertlene': ('mjølkekjertel',),
'mjølkekjertler': ('mjølkekjertel',),
'mjølkekolla': ('mjølkekolle',),
'mjølkekolle': ('mjølkekolle',),
'mjølkekollen': ('mjølkekolle',),
'mjølkekollene': ('mjølkekolle',),
'mjølkekoller': ('mjølkekolle',),
'mjølkeku': ('mjølkeku',),
'mjølkekua': ('mjølkeku',),
'mjølkekuen': ('mjølkeku',),
'mjølkekuene': ('mjølkeku',),
'mjølkekuer': ('mjølkeku',),
'mjølkekyr': ('mjølkeku',),
'mjølkekyrne': ('mjølkeku',),
'mjølkemaskin': ('mjølkemaskin',),
'mjølkemaskina': ('mjølkemaskin',),
'mjølkemaskinen': ('mjølkemaskin',),
'mjølkemaskinene': ('mjølkemaskin',),
'mjølkemaskiner': ('mjølkemaskin',),
'mjølkemat': ('mjølkemat',),
'mjølkematen': ('mjølkemat',),
'mjølkematene': ('mjølkemat',),
'mjølkemater': ('mjølkemat',),
'mjølkemugga': ('mjølkemugge',),
'mjølkemugge': ('mjølkemugge',),
'mjølkemuggen': ('mjølkemugge',),
'mjølkemuggene': ('mjølkemugge',),
'mjølkemugger': ('mjølkemugge',),
'mjølkeproduksjon': ('mjølkeproduksjon',),
'mjølkeproduksjonen': ('mjølkeproduksjon',),
'mjølkeproduksjonene': ('mjølkeproduksjon',),
'mjølkeproduksjoner': ('mjølkeproduksjon',),
'mjølkeprodukt': ('mjølkeprodukt',),
'mjølkeprodukta': ('mjølkeprodukt',),
'mjølkeproduktene': ('mjølkeprodukt',),
'mjølkeprodukter': ('mjølkeprodukt',),
'mjølkeproduktet': ('mjølkeprodukt',),
'mjølkeprodusent': ('mjølkeprodusent',),
'mjølkeprodusenten': ('mjølkeprodusent',),
'mjølkeprodusentene': ('mjølkeprodusent',),
'mjølkeprodusenter': ('mjølkeprodusent',),
'mjølkerampa': ('mjølkerampe',),
'mjølkerampe': ('mjølkerampe',),
'mjølkerampen': ('mjølkerampe',),
'mjølkerampene': ('mjølkerampe',),
'mjølkeramper': ('mjølkerampe',),
'mjølkeringa': ('mjølkeringe',),
'mjølkeringe': ('mjølkeringe',),
'mjølkeringen': ('mjølkeringe',),
'mjølkeringene': ('mjølkeringe',),
'mjølkeringer': ('mjølkeringe',),
'mjølkeruta': ('mjølkerute',),
'mjølkerute': ('mjølkerute',),
'mjølkeruten': ('mjølkerute',),
'mjølkerutene': ('mjølkerute',),
'mjølkeruter': ('mjølkerute',),
'mjølkesaft': ('mjølkesaft',),
'mjølkesafta': ('mjølkesaft',),
'mjølkesaften': ('mjølkesaft',),
'mjølkesaftene': ('mjølkesaft',),
'mjølkesafter': ('mjølkesaft',),
'mjølkesentral': ('mjølkesentral',),
'mjølkesentralen': ('mjølkesentral',),
'mjølkesentralene': ('mjølkesentral',),
'mjølkesentraler': ('mjølkesentral',),
'mjølkespann': ('mjølkespann',),
'mjølkespanna': ('mjølkespann',),
'mjølkespannene': ('mjølkespann',),
'mjølkespannet': ('mjølkespann',),
'mjølkespreng': ('mjølkespreng',),
'mjølkesprenga': ('mjølkespreng',),
'mjølkesprengen': ('mjølkespreng',),
'mjølkesprengene': ('mjølkespreng',),
'mjølkesprenger': ('mjølkespreng',),
'mjølkesprenget': ('mjølkespreng',),
'mjølkesukker': ('mjølkesukker',),
'mjølkesukkera': ('mjølkesukker',),
'mjølkesukkere': ('mjølkesukker',),
'mjølkesukkerene': ('mjølkesukker',),
'mjølkesukkeret': ('mjølkesukker',),
'mjølkesukkerne': ('mjølkesukker',),
'mjølkesuppa': ('mjølkesuppe',),
'mjølkesuppe': ('mjølkesuppe',),
'mjølkesuppen': ('mjølkesuppe',),
'mjølkesuppene': ('mjølkesuppe',),
'mjølkesupper': ('mjølkesuppe',),
'mjølkesyra': ('mjølkesyre',),
'mjølkesyre': ('mjølkesyre',),
'mjølkesyren': ('mjølkesyre',),
'mjølkesyrene': ('mjølkesyre',),
'mjølkesyrer': ('mjølkesyre',),
'mjølkesyrebakterie': ('mjølkesyrebakterie',),
'mjølkesyrebakterien': ('mjølkesyrebakterie',),
'mjølkesyrebakteriene': ('mjølkesyrebakterie',),
'mjølkesyrebakterier': ('mjølkesyrebakterie',),
'mjølketann': ('mjølketann',),
'mjølketanna': ('mjølketann',),
'mjølketannen': ('mjølketann',),
'mjølketennene': ('mjølketann',),
'mjølketenner': ('mjølketann',),
'mjøll': ('mjøll',),
'mjølla': ('mjøll',),
'mjøllen': ('mjøll',),
'mjøllene': ('mjøll',),
'mjøller': ('mjøll',),
'ml-er': ('ml-er',),
'ml-ere': ('ml-er',),
'ml-eren': ('ml-er',),
'ml-erer': ('ml-er',),
'ml-erne': ('ml-er',),
'mnemoteknikk': ('mnemoteknikk',),
'mnemoteknikken': ('mnemoteknikk',),
'mnemoteknikkene': ('mnemoteknikk',),
'mnemoteknikker': ('mnemoteknikk',),
'mo': ('mo',),
'moen': ('mo',),
'moene': ('mo',),
'moer': ('mo',),
'mo': ('mo',),
'moa': ('mo',),
'moene': ('mo',),
'moet': ('mo',),
'moabitt': ('moabitt',),
'moabitten': ('moabitt',),
'moabittene': ('moabitt',),
'moabitter': ('moabitt',),
'moafugl': ('moafugl',),
'moafuglen': ('moafugl',),
'moafuglene': ('moafugl',),
'moafugler': ('moafugl',),
'moareen': ('moaré',),
'moareene': ('moaré',),
'moareer': ('moaré',),
'moaré': ('moaré',),
'moaréen': ('moaré',),
'moaréene': ('moaré',),
'moaréer': ('moaré',),
'mobb': ('mobb',),
'mobben': ('mobb',),
'mobbene': ('mobb',),
'mobber': ('mobb',),
'mobbeoffer': ('mobbeoffer',),
'mobbeofferet': ('mobbeoffer',),
'mobbeofra': ('mobbeoffer',),
'mobbeofre': ('mobbeoffer',),
'mobbeofrene': ('mobbeoffer',),
'mobber': ('mobber',),
'mobbere': ('mobber',),
'mobberen': ('mobber',),
'mobberer': ('mobber',),
'mobberne': ('mobber',),
'mobbing': ('mobbing',),
'mobbinga': ('mobbing',),
'mobbingen': ('mobbing',),
'mobbingene': ('mobbing',),
'mobbinger': ('mobbing',),
'mobil': ('mobil',),
'mobilen': ('mobil',),
'mobilene': ('mobil',),
'mobiler': ('mobil',),
'mobiliene': ('mobilier',),
'mobilier': ('mobilier',),
'mobilisering': ('mobilisering',),
'mobiliseringa': ('mobilisering',),
'mobiliseringen': ('mobilisering',),
'mobiliseringene': ('mobilisering',),
'mobiliseringer': ('mobilisering',),
'mobiliseringshær': ('mobiliseringshær',),
'mobiliseringshæren': ('mobiliseringshær',),
'mobiliseringshærene': ('mobiliseringshær',),
'mobiliseringshærer': ('mobiliseringshær',),
'mobiliseringsordre': ('mobiliseringsordre',),
'mobiliseringsordren': ('mobiliseringsordre',),
'mobiliseringsordrene': ('mobiliseringsordre',),
'mobiliseringsordrer': ('mobiliseringsordre',),
'mobilitet': ('mobilitet',),
'mobiliteten': ('mobilitet',),
'mobilitetene': ('mobilitet',),
'mobiliteter': ('mobilitet',),
'mobilkran': ('mobilkran',),
'mobilkrana': ('mobilkran',),
'mobilkranen': ('mobilkran',),
'mobilkranene': ('mobilkran',),
'mobilkraner': ('mobilkran',),
'mobiltelefon': ('mobiltelefon',),
'mobiltelefonen': ('mobiltelefon',),
'mobiltelefonene': ('mobiltelefon',),
'mobiltelefoner': ('mobiltelefon',),
'modal': ('modal',),
'modala': ('modal',),
'modalene': ('modal',),
'modaler': ('modal',),
'modalet': ('modal',),
'modaladverb': ('modaladverb',),
'modaladverba': ('modaladverb',),
'modaladverbene': ('modaladverb',),
'modaladverber': ('modaladverb',),
'modaladverbet': ('modaladverb',),
'modaladverbia': ('modaladverbium',),
'modaladverbiene': ('modaladverbium',),
'modaladverbier': ('modaladverbium',),
'modaladverbiet': ('modaladverbium',),
'modaladverbium': ('modaladverbium',),
'modalitet': ('modalitet',),
'modaliteten': ('modalitet',),
'modalitetene': ('modalitet',),
'modaliteter': ('modalitet',),
'modalverb': ('modalverb',),
'modalverba': ('modalverb',),
'modalverbene': ('modalverb',),
'modalverber': ('modalverb',),
'modalverbet': ('modalverb',),
'modell': ('modell',),
'modellen': ('modell',),
'modellene': ('modell',),
'modeller': ('modell',),
'modellermasse': ('modellermasse',),
'modellermassen': ('modellermasse',),
'modellermassene': ('modellermasse',),
'modellermasser': ('modellermasse',),
'modellfly': ('modellfly',),
'modellflya': ('modellfly',),
'modellflyene': ('modellfly',),
'modellflyet': ('modellfly',),
'modellforsøk': ('modellforsøk',),
'modellforsøka': ('modellforsøk',),
'modellforsøkene': ('modellforsøk',),
'modellforsøket': ('modellforsøk',),
'modellkjole': ('modellkjole',),
'modellkjolen': ('modellkjole',),
'modellkjolene': ('modellkjole',),
'modellkjoler': ('modellkjole',),
'modelltank': ('modelltank',),
'modelltanken': ('modelltank',),
'modelltankene': ('modelltank',),
'modelltanker': ('modelltank',),
'modellør': ('modellør',),
'modelløren': ('modellør',),
'modellørene': ('modellør',),
'modellører': ('modellør',),
'modem': ('modem',),
'modema': ('modem',),
'modemene': ('modem',),
'modemer': ('modem',),
'modemet': ('modem',),
'modenhet': ('modenhet',),
'modenheta': ('modenhet',),
'modenheten': ('modenhet',),
'modenhetene': ('modenhet',),
'modenheter': ('modenhet',),
'modenhetsalder': ('modenhetsalder',),
'modenhetsaldere': ('modenhetsalder',),
'modenhetsalderen': ('modenhetsalder',),
'modenhetsalderer': ('modenhetsalder',),
'modenhetsalderne': ('modenhetsalder',),
'modenhetsaldre': ('modenhetsalder',),
'modenhetsaldrene': ('modenhetsalder',),
'modenhetsaldrer': ('modenhetsalder',),
'modenhetsprøva': ('modenhetsprøve',),
'modenhetsprøve': ('modenhetsprøve',),
'modenhetsprøven': ('modenhetsprøve',),
'modenhetsprøvene': ('modenhetsprøve',),
'modenhetsprøver': ('modenhetsprøve',),
'moder': ('moder',),
'moderen': ('moder',),
'mødre': ('moder',),
'mødrene': ('moder',),
'mødrer': ('moder',),
'moderasjon': ('moderasjon',),
'moderasjonen': ('moderasjon',),
'moderasjonene': ('moderasjon',),
'moderasjoner': ('moderasjon',),
'moderator': ('moderator',),
'moderatoren': ('moderator',),
'moderatorene': ('moderator',),
'moderatorer': ('moderator',),
'moderfang': ('moderfang',),
'moderfanga': ('moderfang',),
'moderfangene': ('moderfang',),
'moderfanget': ('moderfang',),
'moderhjerta': ('moderhjerte',),
'moderhjerte': ('moderhjerte',),
'moderhjertene': ('moderhjerte',),
'moderhjerter': ('moderhjerte',),
'moderhjertet': ('moderhjerte',),
'moderjord': ('moderjord',),
'moderjorda': ('moderjord',),
'moderjorden': ('moderjord',),
'moderjordene': ('moderjord',),
'moderjorder': ('moderjord',),
'moderkirka': ('moderkirke',),
'moderkirke': ('moderkirke',),
'moderkirken': ('moderkirke',),
'moderkirkene': ('moderkirke',),
'moderkirker': ('moderkirke',),
'moderkjerka': ('moderkjerke',),
'moderkjerke': ('moderkjerke',),
'moderkjerken': ('moderkjerke',),
'moderkjerkene': ('moderkjerke',),
'moderkjerker': ('moderkjerke',),
'moderland': ('moderland',),
'moderlanda': ('moderland',),
'moderlandene': ('moderland',),
'moderlandet': ('moderland',),
'modernisme': ('modernisme',),
'modernismen': ('modernisme',),
'modernismene': ('modernisme',),
'modernismer': ('modernisme',),
'modernist': ('modernist',),
'modernisten': ('modernist',),
'modernistene': ('modernist',),
'modernister': ('modernist',),
'modernitet': ('modernitet',),
'moderniteten': ('modernitet',),
'modernitetene': ('modernitet',),
'moderniteter': ('modernitet',),
'moderselskap': ('moderselskap',),
'moderselskapa': ('moderselskap',),
'moderselskapene': ('moderselskap',),
'moderselskaper': ('moderselskap',),
'moderselskapet': ('moderselskap',),
'moderskap': ('moderskap',),
'moderskapa': ('moderskap',),
'moderskapene': ('moderskap',),
'moderskapet': ('moderskap',),
'moderskip': ('moderskip',),
'moderskipa': ('moderskip',),
'moderskipene': ('moderskip',),
'moderskipet': ('moderskip',),
'moderspråk': ('moderspråk',),
'moderspråka': ('moderspråk',),
'moderspråkene': ('moderspråk',),
'moderspråket': ('moderspråk',),
'modifikasjon': ('modifikasjon',),
'modifikasjonen': ('modifikasjon',),
'modifikasjonene': ('modifikasjon',),
'modifikasjoner': ('modifikasjon',),
'modist': ('modist',),
'modisten': ('modist',),
'modistene': ('modist',),
'modister': ('modist',),
'modneri': ('modneri',),
'modneria': ('modneri',),
'modneriene': ('modneri',),
'modnerier': ('modneri',),
'modneriet': ('modneri',),
'modning': ('modning',),
'modninga': ('modning',),
'modningen': ('modning',),
'modningene': ('modning',),
'modninger': ('modning',),
'modningsdeling': ('modningsdeling',),
'modningsdelinga': ('modningsdeling',),
'modningsdelingen': ('modningsdeling',),
'modningsdelingene': ('modningsdeling',),
'modningsdelinger': ('modningsdeling',),
'modningsprosess': ('modningsprosess',),
'modningsprosessen': ('modningsprosess',),
'modningsprosessene': ('modningsprosess',),
'modningsprosesser': ('modningsprosess',),
'modningsprøva': ('modningsprøve',),
'modningsprøve': ('modningsprøve',),
'modningsprøven': ('modningsprøve',),
'modningsprøvene': ('modningsprøve',),
'modningsprøver': ('modningsprøve',),
'modningstid': ('modningstid',),
'modningstida': ('modningstid',),
'modningstiden': ('modningstid',),
'modningstidene': ('modningstid',),
'modningstider': ('modningstid',),
'modul': ('modul',),
'modulen': ('modul',),
'modulene': ('modul',),
'moduler': ('modul',),
'modulasjon': ('modulasjon',),
'modulasjonen': ('modulasjon',),
'modulasjonene': ('modulasjon',),
'modulasjoner': ('modulasjon',),
'modulator': ('modulator',),
'modulatoren': ('modulator',),
'modulatorene': ('modulator',),
'modulatorer': ('modulator',),
'modulering': ('modulering',),
'moduleringa': ('modulering',),
'moduleringen': ('modulering',),
'moduleringene': ('modulering',),
'moduleringer': ('modulering',),
'modi': ('modus',),
'modiene': ('modus',),
'modus': ('modus',),
'modusen': ('modus',),
'modus vivendi': ('modus vivendi',),
'moe': ('moe',),
'moen': ('moe',),
'moene': ('moe',),
'moer': ('moe',),
'mogop': ('mogop',),
'mogopen': ('mogop',),
'mogopene': ('mogop',),
'mogoper': ('mogop',),
'mogul': ('mogul',),
'mogulen': ('mogul',),
'mogulene': ('mogul',),
'moguler': ('mogul',),
'mohair': ('mohair',),
'mohaira': ('mohair',),
'mohairen': ('mohair',),
'mohairene': ('mohair',),
'mohairer': ('mohair',),
'mohairet': ('mohair',),
'mohikaner': ('mohikaner',),
'mohikanere': ('mohikaner',),
'mohikaneren': ('mohikaner',),
'mohikanerer': ('mohikaner',),
'mohikanerne': ('mohikaner',),
'mokasin': ('mokasin',),
'mokasinen': ('mokasin',),
'mokasinene': ('mokasin',),
'mokasiner': ('mokasin',),
'mokett': ('mokett',),
'moketta': ('mokett',),
'moketten': ('mokett',),
'mokettene': ('mokett',),
'moketter': ('mokett',),
'mokettet': ('mokett',),
'mokka': ('mokka',),
'mokkaen': ('mokka',),
'mokkaene': ('mokka',),
'mokkaer': ('mokka',),
'mokkais': ('mokkais',),
'mokkaisen': ('mokkais',),
'mokkaisene': ('mokkais',),
'mokkaiser': ('mokkais',),
'mokkakaffe': ('mokkakaffe',),
'mokkakaffen': ('mokkakaffe',),
'mokkakaffene': ('mokkakaffe',),
'mokkakaffer': ('mokkakaffe',),
'mokkakopp': ('mokkakopp',),
'mokkakoppen': ('mokkakopp',),
'mokkakoppene': ('mokkakopp',),
'mokkakopper': ('mokkakopp',),
'mokkaskei': ('mokkaskei',),
'mokkaskeia': ('mokkaskei',),
'mokkaskeien': ('mokkaskei',),
'mokkaskeiene': ('mokkaskei',),
'mokkaskeier': ('mokkaskei',),
'mokkaskje': ('mokkaskje',),
'mokkaskjea': ('mokkaskje',),
'mokkaskjeen': ('mokkaskje',),
'mokkaskjeene': ('mokkaskje',),
'mokkaskjeer': ('mokkaskje',),
'mol': ('mol',),
'mola': ('mol',),
'molene': ('mol',),
'molet': ('mol',),
'mol': ('mol',),
'mola': ('mol',),
'molen': ('mol',),
'molene': ('mol',),
'moler': ('mol',),
'molbakke': ('molbakke',),
'molbakken': ('molbakke',),
'molbakkene': ('molbakke',),
'molbakker': ('molbakke',),
'molbo': ('molbo',),
'molboen': ('molbo',),
'molboene': ('molbo',),
'molboer': ('molbo',),
'molbohistoria': ('molbohistorie',),
'molbohistorie': ('molbohistorie',),
'molbohistorien': ('molbohistorie',),
'molbohistoriene': ('molbohistorie',),
'molbohistorier': ('molbohistorie',),
'molboland': ('molboland',),
'molbolanda': ('molboland',),
'molbolandene': ('molboland',),
'molbolandet': ('molboland',),
'mold': ('mold',),
'molda': ('mold',),
'molden': ('mold',),
'moldene': ('mold',),
'molder': ('mold',),
'moldjord': ('moldjord',),
'moldjorda': ('moldjord',),
'moldjorden': ('moldjord',),
'moldjordene': ('moldjord',),
'moldjorder': ('moldjord',),
'moldklump': ('moldklump',),
'moldklumpen': ('moldklump',),
'moldklumpene': ('moldklump',),
'moldklumper': ('moldklump',),
'moldover': ('moldover',),
'moldovere': ('moldover',),
'moldoveren': ('moldover',),
'moldoverer': ('moldover',),
'moldoverne': ('moldover',),
'moldvarp': ('moldvarp',),
'moldvarpen': ('moldvarp',),
'moldvarpene': ('moldvarp',),
'moldvarper': ('moldvarp',),
'moldvarparbeid': ('moldvarparbeid',),
'moldvarparbeida': ('moldvarparbeid',),
'moldvarparbeidene': ('moldvarparbeid',),
'moldvarparbeidet': ('moldvarparbeid',),
'mole': ('mole',),
'molen': ('mole',),
'molene': ('mole',),
'moler': ('mole',),
'molekyl': ('molekyl',),
'molekyla': ('molekyl',),
'molekylene': ('molekyl',),
'molekyler': ('molekyl',),
'molekylet': ('molekyl',),
'molekylarbiologi': ('molekylarbiologi',),
'molekylarbiologien': ('molekylarbiologi',),
'molekylarbiologiene': ('molekylarbiologi',),
'molekylarbiologier': ('molekylarbiologi',),
'molekylarkraft': ('molekylarkraft',),
'molekylarkrafta': ('molekylarkraft',),
'molekylarkraften': ('molekylarkraft',),
'molekylarkreftene': ('molekylarkraft',),
'molekylarkrefter': ('molekylarkraft',),
'molekylarstruktur': ('molekylarstruktur',),
'molekylarstrukturen': ('molekylarstruktur',),
'molekylarstrukturene': ('molekylarstruktur',),
'molekylarstrukturer': ('molekylarstruktur',),
'molekylarvekt': ('molekylarvekt',),
'molekylarvekta': ('molekylarvekt',),
'molekylarvekten': ('molekylarvekt',),
'molekylarvektene': ('molekylarvekt',),
'molekylarvekter': ('molekylarvekt',),
'molest': ('molest',),
'molesten': ('molest',),
'molestene': ('molest',),
'molester': ('molest',),
'moll': ('moll',),
'mollen': ('moll',),
'mollene': ('moll',),
'moller': ('moll',),
'mollakkord': ('mollakkord',),
'mollakkorden': ('mollakkord',),
'mollakkordene': ('mollakkord',),
'mollakkorder': ('mollakkord',),
'mollskala': ('mollskala',),
'mollskalaen': ('mollskala',),
'mollskalaene': ('mollskala',),
'mollskalaer': ('mollskala',),
'molltreklang': ('molltreklang',),
'molltreklangen': ('molltreklang',),
'molltreklangene': ('molltreklang',),
'molltreklanger': ('molltreklang',),
'mollusk': ('mollusk',),
'mollusken': ('mollusk',),
'molluskene': ('mollusk',),
'mollusker': ('mollusk',),
'molo': ('molo',),
'moloen': ('molo',),
'moloene': ('molo',),
'moloer': ('molo',),
'molohamn': ('molohamn',),
'molohamna': ('molohamn',),
'molohamnen': ('molohamn',),
'molohamnene': ('molohamn',),
'molohamner': ('molohamn',),
'molohavn': ('molohavn',),
'molohavna': ('molohavn',),
'molohavnen': ('molohavn',),
'molohavnene': ('molohavn',),
'molohavner': ('molohavn',),
'molok': ('molok',),
'moloken': ('molok',),
'molokene': ('molok',),
'moloker': ('molok',),
'molotovcocktail': ('molotovcocktail',),
'molotovcocktailen': ('molotovcocktail',),
'molotovcocktailene': ('molotovcocktail',),
'molotovcocktailer': ('molotovcocktail',),
'molta': ('molte',),
'molte': ('molte',),
'molten': ('molte',),
'moltene': ('molte',),
'molter': ('molte',),
'moltebær': ('moltebær',),
'moltebæra': ('moltebær',),
'moltebærene': ('moltebær',),
'moltebæret': ('moltebær',),
'moltekart': ('moltekart',),
'moltekarten': ('moltekart',),
'moltekartene': ('moltekart',),
'moltekarter': ('moltekart',),
'moltekrem': ('moltekrem',),
'moltekremen': ('moltekrem',),
'moltekremene': ('moltekrem',),
'moltekremer': ('moltekrem',),
'moltemyr': ('moltemyr',),
'moltemyra': ('moltemyr',),
'moltemyren': ('moltemyr',),
'moltemyrene': ('moltemyr',),
'moltemyrer': ('moltemyr',),
'molteplukker': ('molteplukker',),
'molteplukkere': ('molteplukker',),
'molteplukkeren': ('molteplukker',),
'molteplukkerer': ('molteplukker',),
'molteplukkerne': ('molteplukker',),
'molukker': ('molukker',),
'molukkere': ('molukker',),
'molukkeren': ('molukker',),
'molukkerer': ('molukker',),
'molukkerne': ('molukker',),
'molybden': ('molybden',),
'molybdena': ('molybden',),
'molybdenene': ('molybden',),
'molybdenet': ('molybden',),
'moment': ('moment',),
'momenta': ('moment',),
'momentene': ('moment',),
'momenter': ('moment',),
'momentet': ('moment',),
'momp': ('momp',),
'mompen': ('momp',),
'mompene': ('momp',),
'momper': ('momp',),
'moms': ('moms',),
'momsen': ('moms',),
'momsene': ('moms',),
'momser': ('moms',),
'momsfritak': ('momsfritak',),
'momsfritaka': ('momsfritak',),
'momsfritakene': ('momsfritak',),
'momsfritaket': ('momsfritak',),
'monade': ('monade',),
'monaden': ('monade',),
'monadene': ('monade',),
'monader': ('monade',),
'monark': ('monark',),
'monarken': ('monark',),
'monarkene': ('monark',),
'monarker': ('monark',),
'monarki': ('monarki',),
'monarkia': ('monarki',),
'monarkiene': ('monarki',),
'monarkier': ('monarki',),
'monarkiet': ('monarki',),
'monarkist': ('monarkist',),
'monarkisten': ('monarkist',),
'monarkistene': ('monarkist',),
'monarkister': ('monarkist',),
'monegasker': ('monegasker',),
'monegaskere': ('monegasker',),
'monegaskeren': ('monegasker',),
'monegaskerer': ('monegasker',),
'monegaskerne': ('monegasker',),
'monetarisme': ('monetarisme',),
'monetarismen': ('monetarisme',),
'monetarismene': ('monetarisme',),
'monetarismer': ('monetarisme',),
'mongol': ('mongol',),
'mongolen': ('mongol',),
'mongolene': ('mongol',),
'mongoler': ('mongol',),
'mongolisme': ('mongolisme',),
'mongolismen': ('mongolisme',),
'mongolismene': ('mongolisme',),
'mongolismer': ('mongolisme',),
'monisme': ('monisme',),
'monismen': ('monisme',),
'monismene': ('monisme',),
'monismer': ('monisme',),
'monist': ('monist',),
'monisten': ('monist',),
'monistene': ('monist',),
'monister': ('monist',),
'monitor': ('monitor',),
'monitoren': ('monitor',),
'monitorene': ('monitor',),
'monitorer': ('monitor',),
'monn': ('monn',),
'monna': ('monn',),
'monnen': ('monn',),
'monnene': ('monn',),
'monner': ('monn',),
'monnet': ('monn',),
'mono': ('mono',),
'monoen': ('mono',),
'monoene': ('mono',),
'monoer': ('mono',),
'monofoni': ('monofoni',),
'monofonien': ('monofoni',),
'monofoniene': ('monofoni',),
'monofonier': ('monofoni',),
'monoftong': ('monoftong',),
'monoftongen': ('monoftong',),
'monoftongene': ('monoftong',),
'monoftonger': ('monoftong',),
'monoftongering': ('monoftongering',),
'monoftongeringa': ('monoftongering',),
'monoftongeringen': ('monoftongering',),
'monoftongeringene': ('monoftongering',),
'monoftongeringer': ('monoftongering',),
'monogami': ('monogami',),
'monogamia': ('monogami',),
'monogamiene': ('monogami',),
'monogamiet': ('monogami',),
'monografi': ('monografi',),
'monografien': ('monografi',),
'monografiene': ('monografi',),
'monografier': ('monografi',),
'monogram': ('monogram',),
'monogramma': ('monogram',),
'monogrammene': ('monogram',),
'monogrammer': ('monogram',),
'monogrammet': ('monogram',),
'monokkel': ('monokkel',),
'monokkelen': ('monokkel',),
'monoklene': ('monokkel',),
'monokler': ('monokkel',),
'monokultur': ('monokultur',),
'monokulturen': ('monokultur',),
'monokulturene': ('monokultur',),
'monokulturer': ('monokultur',),
'monolitt': ('monolitt',),
'monolitten': ('monolitt',),
'monolittene': ('monolitt',),
'monolitter': ('monolitt',),
'monolog': ('monolog',),
'monologen': ('monolog',),
'monologene': ('monolog',),
'monologer': ('monolog',),
'monom': ('monom',),
'monoma': ('monom',),
'monomene': ('monom',),
'monomer': ('monom',),
'monomet': ('monom',),
'monoman': ('monoman',),
'monomanen': ('monoman',),
'monomanene': ('monoman',),
'monomaner': ('monoman',),
'monomani': ('monomani',),
'monomanien': ('monomani',),
'monomaniene': ('monomani',),
'monomanier': ('monomani',),
'monoplata': ('monoplate',),
'monoplate': ('monoplate',),
'monoplaten': ('monoplate',),
'monoplatene': ('monoplate',),
'monoplater': ('monoplate',),
'monopol': ('monopol',),
'monopola': ('monopol',),
'monopolene': ('monopol',),
'monopoler': ('monopol',),
'monopolet': ('monopol',),
'monopolkapital': ('monopolkapital',),
'monopolkapitalen': ('monopolkapital',),
'monopolkapitalene': ('monopolkapital',),
'monopolkapitaler': ('monopolkapital',),
'monopolkapitalisme': ('monopolkapitalisme',),
'monopolkapitalismen': ('monopolkapitalisme',),
'monopolkapitalismene': ('monopolkapitalisme',),
'monopolkapitalismer': ('monopolkapitalisme',),
'monoski': ('monoski',),
'monoskia': ('monoski',),
'monoskien': ('monoski',),
'monoskiene': ('monoski',),
'monoskier': ('monoski',),
'monoteisme': ('monoteisme',),
'monoteismen': ('monoteisme',),
'monoteismene': ('monoteisme',),
'monoteismer': ('monoteisme',),
'monoteist': ('monoteist',),
'monoteisten': ('monoteist',),
'monoteistene': ('monoteist',),
'monoteister': ('monoteist',),
'monotoni': ('monotoni',),
'monotonien': ('monotoni',),
'monotoniene': ('monotoni',),
'monotonier': ('monotoni',),
'monotype': ('monotype',),
'monotypen': ('monotype',),
'monotypene': ('monotype',),
'monotyper': ('monotype',),
'mons': ('mons',),
'monsen': ('mons',),
'monsene': ('mons',),
'monser': ('mons',),
'messieurs': ('monsieur',),
'monsieur': ('monsieur',),
'monsieuren': ('monsieur',),
'monster': ('monster',),
'monsteret': ('monster',),
'monstra': ('monster',),
'monstre': ('monster',),
'monstrene': ('monster',),
'monstret': ('monster',),
'monstrans': ('monstrans',),
'monstransen': ('monstrans',),
'monstransene': ('monstrans',),
'monstranser': ('monstrans',),
'monstra': ('monstrum',),
'monstre': ('monstrum',),
'monstrene': ('monstrum',),
'monstret': ('monstrum',),
'monstrum': ('monstrum',),
'monstrumet': ('monstrum',),
'monsun': ('monsun',),
'monsunen': ('monsun',),
'monsunene': ('monsun',),
'monsuner': ('monsun',),
'monsunregn': ('monsunregn',),
'monsunregna': ('monsunregn',),
'monsunregnene': ('monsunregn',),
'monsunregnet': ('monsunregn',),
'monsuntid': ('monsuntid',),
'monsuntida': ('monsuntid',),
'monsuntiden': ('monsuntid',),
'monsuntidene': ('monsuntid',),
'monsuntider': ('monsuntid',),
'montasje': ('montasje',),
'montasjen': ('montasje',),
'montasjene': ('montasje',),
'montasjer': ('montasje',),
'montasjeprogram': ('montasjeprogram',),
'montasjeprogramma': ('montasjeprogram',),
'montasjeprogrammene': ('montasjeprogram',),
'montasjeprogrammer': ('montasjeprogram',),
'montasjeprogrammet': ('montasjeprogram',),
'montenegriner': ('montenegriner',),
'montenegrinere': ('montenegriner',),
'montenegrineren': ('montenegriner',),
'montenegrinerer': ('montenegriner',),
'montenegrinerne': ('montenegriner',),
'monter': ('monter',),
'montere': ('monter',),
'monteren': ('monter',),
'monterne': ('monter',),
'montre': ('monter',),
'montrene': ('monter',),
'montrer': ('monter',),
'monter': ('monter',),
'montere': ('monter',),
'monteren': ('monter',),
'monterne': ('monter',),
'montre': ('monter',),
'montrene': ('monter',),
'montrer': ('monter',),
'montre': ('montre',),
'montren': ('montre',),
'montrene': ('montre',),
'montrer': ('montre',),
'montre': ('montre',),
'montren': ('montre',),
'montrene': ('montre',),
'montrer': ('montre',),
'montør': ('montør',),
'montøren': ('montør',),
'montørene': ('montør',),
'montører': ('montør',),
'monument': ('monument',),
'monumenta': ('monument',),
'monumentene': ('monument',),
'monumenter': ('monument',),
'monumentet': ('monument',),
'moped': ('moped',),
'mopeden': ('moped',),
'mopedene': ('moped',),
'mopeder': ('moped',),
'mopedist': ('mopedist',),
'mopedisten': ('mopedist',),
'mopedistene': ('mopedist',),
'mopedister': ('mopedist',),
'mopp': ('mopp',),
'moppen': ('mopp',),
'moppene': ('mopp',),
'mopper': ('mopp',),
'mops': ('mops',),
'mopsen': ('mops',),
'mopsene': ('mops',),
'mopser': ('mops',),
'mor': ('mor',),
'moren': ('mor',),
'morene': ('mor',),
'morer': ('mor',),
'mor': ('mor',),
'mora': ('mor',),
'moren': ('mor',),
'mødre': ('mor',),
'mødrene': ('mor',),
'mødrer': ('mor',),
'mora': ('mora',),
'moraen': ('mora',),
'moraene': ('mora',),
'moraer': ('mora',),
'moral': ('moral',),
'moralen': ('moral',),
'moralene': ('moral',),
'moraler': ('moral',),
'moralisme': ('moralisme',),
'moralismen': ('moralisme',),
'moralismene': ('moralisme',),
'moralismer': ('moralisme',),
'moralist': ('moralist',),
'moralisten': ('moralist',),
'moralistene': ('moralist',),
'moralister': ('moralist',),
'moralitet': ('moralitet',),
'moraliteten': ('moralitet',),
'moralitetene': ('moralitet',),
'moraliteter': ('moralitet',),
'moralkodeks': ('moralkodeks',),
'moralkodeksen': ('moralkodeks',),
'moralkodeksene': ('moralkodeks',),
'moralkodekser': ('moralkodeks',),
'morallæra': ('morallære',),
'morallære': ('morallære',),
'morallæren': ('morallære',),
'morallærene': ('morallære',),
'morallærer': ('morallære',),
'moralpreken': ('moralpreken',),
'moralprekenen': ('moralpreken',),
'moralprekenene': ('moralpreken',),
'moralprekener': ('moralpreken',),
'morarenta': ('morarente',),
'morarente': ('morarente',),
'morarenten': ('morarente',),
'morarentene': ('morarente',),
'morarenter': ('morarente',),
'morass': ('morass',),
'morassa': ('morass',),
'morassene': ('morass',),
'morasser': ('morass',),
'morasset': ('morass',),
'moratorietid': ('moratorietid',),
'moratorietida': ('moratorietid',),
'moratorietiden': ('moratorietid',),
'moratorietidene': ('moratorietid',),
'moratorietider': ('moratorietid',),
'moratoria': ('moratorium',),
'moratoriene': ('moratorium',),
'moratorier': ('moratorium',),
'moratoriet': ('moratorium',),
'moratorium': ('moratorium',),
'morbiditet': ('morbiditet',),
'morbiditeten': ('morbiditet',),
'morbiditetene': ('morbiditet',),
'morbiditeter': ('morbiditet',),
'morbror': ('morbror',),
'morbroren': ('morbror',),
'morbrødre': ('morbror',),
'morbrødrene': ('morbror',),
'morbær': ('morbær',),
'morbæra': ('morbær',),
'morbærene': ('morbær',),
'morbæret': ('morbær',),
'morbær': ('morbær',),
'morbæra': ('morbær',),
'morbærene': ('morbær',),
'morbæret': ('morbær',),
'morbærfamilie': ('morbærfamilie',),
'morbærfamilien': ('morbærfamilie',),
'morbærfamiliene': ('morbærfamilie',),
'morbærfamilier': ('morbærfamilie',),
'morbærtre': ('morbærtre',),
'morbærtrea': ('morbærtre',),
'morbærtreet': ('morbærtre',),
'morbærtrær': ('morbærtre',),
'morbærtrærne': ('morbærtre',),
'morcella': ('morcelle',),
'morcelle': ('morcelle',),
'morcellen': ('morcelle',),
'morcellene': ('morcelle',),
'morceller': ('morcelle',),
'mord': ('mord',),
'morda': ('mord',),
'mordene': ('mord',),
'mordet': ('mord',),
'mordbrann': ('mordbrann',),
'mordbrannen': ('mordbrann',),
'mordbrannene': ('mordbrann',),
'mordbranner': ('mordbrann',),
'morder': ('morder',),
'mordere': ('morder',),
'morderen': ('morder',),
'morderer': ('morder',),
'morderne': ('morder',),
'mordforsøk': ('mordforsøk',),
'mordforsøka': ('mordforsøk',),
'mordforsøkene': ('mordforsøk',),
'mordforsøket': ('mordforsøk',),
'mordkommisjon': ('mordkommisjon',),
'mordkommisjonen': ('mordkommisjon',),
'mordkommisjonene': ('mordkommisjon',),
'mordkommisjoner': ('mordkommisjon',),
'mordvåpen': ('mordvåpen',),
'mordvåpenet': ('mordvåpen',),
'mordvåpna': ('mordvåpen',),
'mordvåpnene': ('mordvåpen',),
'moreld': ('moreld',),
'morelden': ('moreld',),
'moreldene': ('moreld',),
'morelder': ('moreld',),
'moreld': ('moreld',),
'morelden': ('moreld',),
'moreldene': ('moreld',),
'morelder': ('moreld',),
'morell': ('morell',),
'morellen': ('morell',),
'morellene': ('morell',),
'moreller': ('morell',),
'morene': ('morene',),
'morenen': ('morene',),
'morenene': ('morene',),
'morener': ('morene',),
'morenejord': ('morenejord',),
'morenejorda': ('morenejord',),
'morenejorden': ('morenejord',),
'morenejordene': ('morenejord',),
'morenejorder': ('morenejord',),
'morenerygg': ('morenerygg',),
'moreneryggen': ('morenerygg',),
'moreneryggene': ('morenerygg',),
'morenerygger': ('morenerygg',),
'morf': ('morf',),
'morfen': ('morf',),
'morfene': ('morf',),
'morfer': ('morf',),
'morfar': ('morfar',),
'morfaren': ('morfar',),
'morfedre': ('morfar',),
'morfedrene': ('morfar',),
'morfem': ('morfem',),
'morfema': ('morfem',),
'morfemene': ('morfem',),
'morfemer': ('morfem',),
'morfemet': ('morfem',),
'morfin': ('morfin',),
'morfina': ('morfin',),
'morfinen': ('morfin',),
'morfinene': ('morfin',),
'morfiner': ('morfin',),
'morfinet': ('morfin',),
'morfinbase': ('morfinbase',),
'morfinbasen': ('morfinbase',),
'morfinbasene': ('morfinbase',),
'morfinbaser': ('morfinbase',),
'morfinisme': ('morfinisme',),
'morfinismen': ('morfinisme',),
'morfinismene': ('morfinisme',),
'morfinismer': ('morfinisme',),
'morfinist': ('morfinist',),
'morfinisten': ('morfinist',),
'morfinistene': ('morfinist',),
'morfinister': ('morfinist',),
'morfologi': ('morfologi',),
'morfologien': ('morfologi',),
'morfologiene': ('morfologi',),
'morfologier': ('morfologi',),
'morgen': ('morgen',),
'morgenen': ('morgen',),
'morgenene': ('morgen',),
'morgener': ('morgen',),
'morgnene': ('morgen',),
'morgner': ('morgen',),
'morgenandakt': ('morgenandakt',),
'morgenandakta': ('morgenandakt',),
'morgenandakten': ('morgenandakt',),
'morgenandaktene': ('morgenandakt',),
'morgenandakter': ('morgenandakt',),
'morgenavis': ('morgenavis',),
'morgenavisa': ('morgenavis',),
'morgenavisen': ('morgenavis',),
'morgenavisene': ('morgenavis',),
'morgenaviser': ('morgenavis',),
'morgenbønn': ('morgenbønn',),
'morgenbønna': ('morgenbønn',),
'morgenbønnen': ('morgenbønn',),
'morgenbønnene': ('morgenbønn',),
'morgenbønner': ('morgenbønn',),
'morgendag': ('morgendag',),
'morgendagen': ('morgendag',),
'morgendagene': ('morgendag',),
'morgendager': ('morgendag',),
'morgenfugl': ('morgenfugl',),
'morgenfuglen': ('morgenfugl',),
'morgenfuglene': ('morgenfugl',),
'morgenfugler': ('morgenfugl',),
'morgengava': ('morgengave',),
'morgengave': ('morgengave',),
'morgengaven': ('morgengave',),
'morgengavene': ('morgengave',),
'morgengaver': ('morgengave',),
'morgengry': ('morgengry',),
'morgengrya': ('morgengry',),
'morgengryene': ('morgengry',),
'morgengryet': ('morgengry',),
'morgenkaffe': ('morgenkaffe',),
'morgenkaffen': ('morgenkaffe',),
'morgenkaffene': ('morgenkaffe',),
'morgenkaffer': ('morgenkaffe',),
'morgenkjole': ('morgenkjole',),
'morgenkjolen': ('morgenkjole',),
'morgenkjolene': ('morgenkjole',),
'morgenkjoler': ('morgenkjole',),
'morgenkvist': ('morgenkvist',),
'morgenkvisten': ('morgenkvist',),
'morgenkvistene': ('morgenkvist',),
'morgenkvister': ('morgenkvist',),
'morgenkåpa': ('morgenkåpe',),
'morgenkåpe': ('morgenkåpe',),
'morgenkåpen': ('morgenkåpe',),
'morgenkåpene': ('morgenkåpe',),
'morgenkåper': ('morgenkåpe',),
'morgenrøde': ('morgenrøde',),
'morgenrøden': ('morgenrøde',),
'morgenrødene': ('morgenrøde',),
'morgenrøder': ('morgenrøde',),
'morgensida': ('morgenside',),
'morgenside': ('morgenside',),
'morgensiden': ('morgenside',),
'morgensidene': ('morgenside',),
'morgensider': ('morgenside',),
'morgensol': ('morgensol',),
'morgensola': ('morgensol',),
'morgensolen': ('morgensol',),
'morgensolene': ('morgensol',),
'morgensoler': ('morgensol',),
'morgenstell': ('morgenstell',),
'morgenstella': ('morgenstell',),
'morgenstellene': ('morgenstell',),
'morgenstellet': ('morgenstell',),
'morgenstjerna': ('morgenstjerne',),
'morgenstjerne': ('morgenstjerne',),
'morgenstjernen': ('morgenstjerne',),
'morgenstjernene': ('morgenstjerne',),
'morgenstjerner': ('morgenstjerne',),
'morgenstund': ('morgenstund',),
'morgenstunda': ('morgenstund',),
'morgenstunden': ('morgenstund',),
'morgenstundene': ('morgenstund',),
'morgenstunder': ('morgenstund',),
'morges': ('morges',),
'morgning': ('morgning',),
'morgninga': ('morgning',),
'morgningen': ('morgning',),
'morgningene': ('morgning',),
'morgninger': ('morgning',),
'morian': ('morian',),
'morianen': ('morian',),
'morianene': ('morian',),
'morianer': ('morian',),
'morild': ('morild',),
'morilden': ('morild',),
'morildene': ('morild',),
'morilder': ('morild',),
'morild': ('morild',),
'morilden': ('morild',),
'morildene': ('morild',),
'morilder': ('morild',),
'moring': ('moring',),
'moringa': ('moring',),
'moringen': ('moring',),
'moringene': ('moring',),
'moringer': ('moring',),
'morkaka': ('morkake',),
'morkake': ('morkake',),
'morkaken': ('morkake',),
'morkakene': ('morkake',),
'morkaker': ('morkake',),
'morkel': ('morkel',),
'morkelen': ('morkel',),
'morklene': ('morkel',),
'morkler': ('morkel',),
'mormon': ('mormon',),
'mormonen': ('mormon',),
'mormonene': ('mormon',),
'mormoner': ('mormon',),
'mormonisme': ('mormonisme',),
'mormonismen': ('mormonisme',),
'mormonismene': ('mormonisme',),
'mormonismer': ('mormonisme',),
'mormor': ('mormor',),
'mormora': ('mormor',),
'mormoren': ('mormor',),
'mormødre': ('mormor',),
'mormødrene': ('mormor',),
'mormødrer': ('mormor',),
'mormunn': ('mormunn',),
'mormunnen': ('mormunn',),
'mormunnene': ('mormunn',),
'mormunner': ('mormunn',),
'morn': ('morn',),
'morna': ('morn',),
'mornene': ('morn',),
'mornet': ('morn',),
'moro': ('moro',),
'moroa': ('moro',),
'moroen': ('moro',),
'moroene': ('moro',),
'moroer': ('moro',),
'moromann': ('moromann',),
'moromannen': ('moromann',),
'moromenn': ('moromann',),
'moromennene': ('moromann',),
'morosak': ('morosak',),
'morosaka': ('morosak',),
'morosaken': ('morosak',),
'morosakene': ('morosak',),
'morosaker': ('morosak',),
'morr': ('morr',),
'morren': ('morr',),
'morrene': ('morr',),
'morrer': ('morr',),
'morrpølsa': ('morrpølse',),
'morrpølse': ('morrpølse',),
'morrpølsen': ('morrpølse',),
'morrpølsene': ('morrpølse',),
'morrpølser': ('morrpølse',),
'morsarv': ('morsarv',),
'morsarven': ('morsarv',),
'morsarvene': ('morsarv',),
'morsarver': ('morsarv',),
'morsbinding': ('morsbinding',),
'morsbindinga': ('morsbinding',),
'morsbindingen': ('morsbinding',),
'morsbindingene': ('morsbinding',),
'morsbindinger': ('morsbinding',),
'morsdag': ('morsdag',),
'morsdagen': ('morsdag',),
'morsdagene': ('morsdag',),
'morsdager': ('morsdag',),
'morse': ('morse',),
'morsen': ('morse',),
'morsene': ('morse',),
'morser': ('morse',),
'morsealfabet': ('morsealfabet',),
'morsealfabeta': ('morsealfabet',),
'morsealfabetene': ('morsealfabet',),
'morsealfabeter': ('morsealfabet',),
'morsealfabetet': ('morsealfabet',),
'morseapparat': ('morseapparat',),
'morseapparata': ('morseapparat',),
'morseapparatene': ('morseapparat',),
'morseapparater': ('morseapparat',),
'morseapparatet': ('morseapparat',),
'morselskap': ('morselskap',),
'morselskapa': ('morselskap',),
'morselskapene': ('morselskap',),
'morselskaper': ('morselskap',),
'morselskapet': ('morselskap',),
'morsenøkkel': ('morsenøkkel',),
'morsenøkkelen': ('morsenøkkel',),
'morsenøklene': ('morsenøkkel',),
'morsenøkler': ('morsenøkkel',),
'morsesignal': ('morsesignal',),
'morsesignala': ('morsesignal',),
'morsesignalene': ('morsesignal',),
'morsesignaler': ('morsesignal',),
'morsesignalet': ('morsesignal',),
'morsetegn': ('morsetegn',),
'morsetegna': ('morsetegn',),
'morsetegnene': ('morsetegn',),
'morsetegnet': ('morsetegn',),
'morsgleda': ('morsglede',),
'morsglede': ('morsglede',),
'morsgleden': ('morsglede',),
'morsgledene': ('morsglede',),
'morsgleder': ('morsglede',),
'morshjerta': ('morshjerte',),
'morshjerte': ('morshjerte',),
'morshjertene': ('morshjerte',),
'morshjerter': ('morshjerte',),
'morshjertet': ('morshjerte',),
'morsinstinkt': ('morsinstinkt',),
'morsinstinkta': ('morsinstinkt',),
'morsinstinktene': ('morsinstinkt',),
'morsinstinkter': ('morsinstinkt',),
'morsinstinktet': ('morsinstinkt',),
'morskap': ('morskap',),
'morskapen': ('morskap',),
'morskapene': ('morskap',),
'morskaper': ('morskap',),
'morskap': ('morskap',),
'morskapa': ('morskap',),
'morskapene': ('morskap',),
'morskapet': ('morskap',),
'morsmelk': ('morsmelk',),
'morsmelka': ('morsmelk',),
'morsmelken': ('morsmelk',),
'morsmelkene': ('morsmelk',),
'morsmelker': ('morsmelk',),
'morsmelksentral': ('morsmelksentral',),
'morsmelksentralen': ('morsmelksentral',),
'morsmelksentralene': ('morsmelksentral',),
'morsmelksentraler': ('morsmelksentral',),
'morsmelktillegg': ('morsmelktillegg',),
'morsmelktillegga': ('morsmelktillegg',),
'morsmelktilleggene': ('morsmelktillegg',),
'morsmelktillegget': ('morsmelktillegg',),
'morsmjølk': ('morsmjølk',),
'morsmjølka': ('morsmjølk',),
'morsmjølken': ('morsmjølk',),
'morsmjølkene': ('morsmjølk',),
'morsmjølker': ('morsmjølk',),
'morsmjølksentral': ('morsmjølksentral',),
'morsmjølksentralen': ('morsmjølksentral',),
'morsmjølksentralene': ('morsmjølksentral',),
'morsmjølksentraler': ('morsmjølksentral',),
'morsmjølktillegg': ('morsmjølktillegg',),
'morsmjølktillegga': ('morsmjølktillegg',),
'morsmjølktilleggene': ('morsmjølktillegg',),
'morsmjølktillegget': ('morsmjølktillegg',),
'morsmål': ('morsmål',),
'morsmåla': ('morsmål',),
'morsmålene': ('morsmål',),
'morsmålet': ('morsmål',),
'morsmålsundervisning': ('morsmålsundervisning',),
'morsmålsundervisninga': ('morsmålsundervisning',),
'morsmålsundervisningen': ('morsmålsundervisning',),
'morsmålsundervisningene': ('morsmålsundervisning',),
'morsmålsundervisninger': ('morsmålsundervisning',),
'morsnavn': ('morsnavn',),
'morsnavna': ('morsnavn',),
'morsnavnene': ('morsnavn',),
'morsnavnet': ('morsnavn',),
'morsomhet': ('morsomhet',),
'morsomheta': ('morsomhet',),
'morsomheten': ('morsomhet',),
'morsomhetene': ('morsomhet',),
'morsomheter': ('morsomhet',),
'morspermisjon': ('morspermisjon',),
'morspermisjonen': ('morspermisjon',),
'morspermisjonene': ('morspermisjon',),
'morspermisjoner': ('morspermisjon',),
'morsrolla': ('morsrolle',),
'morsrolle': ('morsrolle',),
'morsrollen': ('morsrolle',),
'morsrollene': ('morsrolle',),
'morsroller': ('morsrolle',),
'morssida': ('morsside',),
'morsside': ('morsside',),
'morssiden': ('morsside',),
'morssidene': ('morsside',),
'morssider': ('morsside',),
'morsslekt': ('morsslekt',),
'morsslekta': ('morsslekt',),
'morsslekten': ('morsslekt',),
'morsslektene': ('morsslekt',),
'morsslekter': ('morsslekt',),
'morstrygd': ('morstrygd',),
'morstrygda': ('morstrygd',),
'morstrygden': ('morstrygd',),
'morstrygdene': ('morstrygd',),
'morstrygder': ('morstrygd',),
'morsætt': ('morsætt',),
'morsætta': ('morsætt',),
'morsætten': ('morsætt',),
'morsættene': ('morsætt',),
'morsætter': ('morsætt',),
'mort': ('mort',),
'morten': ('mort',),
'mortene': ('mort',),
'morter': ('mort',),
'mortalitet': ('mortalitet',),
'mortaliteten': ('mortalitet',),
'mortalitetene': ('mortalitet',),
'mortaliteter': ('mortalitet',),
'mortensaften': ('mortensaften',),
'mortensaftenen': ('mortensaften',),
'mortensaftenene': ('mortensaften',),
'mortensaftener': ('mortensaften',),
'mortensdag': ('mortensdag',),
'mortensdagen': ('mortensdag',),
'mortensdagene': ('mortensdag',),
'mortensdager': ('mortensdag',),
'mortensgjess': ('mortensgås',),
'mortensgjessene': ('mortensgås',),
'mortensgjæsene': ('mortensgås',),
'mortensgjæser': ('mortensgås',),
'mortensgås': ('mortensgås',),
'mortensgåsa': ('mortensgås',),
'mortensgåsen': ('mortensgås',),
'mortensmess': ('mortensmess',),
'mortensmesse': ('mortensmesse',),
'morter': ('morter',),
'morteren': ('morter',),
'morterene': ('morter',),
'morterer': ('morter',),
'morter': ('morter',),
'mortere': ('morter',),
'morteren': ('morter',),
'morterer': ('morter',),
'morterne': ('morter',),
'mortifikasjon': ('mortifikasjon',),
'mortifikasjonen': ('mortifikasjon',),
'mortifikasjonene': ('mortifikasjon',),
'mortifikasjoner': ('mortifikasjon',),
'mos': ('mos',),
'mosen': ('mos',),
'mosene': ('mos',),
'moser': ('mos',),
'mosaikk': ('mosaikk',),
'mosaikken': ('mosaikk',),
'mosaikkene': ('mosaikk',),
'mosaikker': ('mosaikk',),
'mosaikk-kunst': ('mosaikk-kunst',),
'mosaikk-kunsten': ('mosaikk-kunst',),
'mosaikk-kunstene': ('mosaikk-kunst',),
'mosaikk-kunster': ('mosaikk-kunst',),
'mosaikkarbeid': ('mosaikkarbeid',),
'mosaikkarbeida': ('mosaikkarbeid',),
'mosaikkarbeidene': ('mosaikkarbeid',),
'mosaikkarbeidet': ('mosaikkarbeid',),
'mosaikkunst': ('mosaikkunst',),
'mosaikkunsten': ('mosaikkunst',),
'mosaikkunstene': ('mosaikkunst',),
'mosaikkunster': ('mosaikkunst',),
'mosaisme': ('mosaisme',),
'mosaismen': ('mosaisme',),
'mosaismene': ('mosaisme',),
'mosaismer': ('mosaisme',),
'mosambiker': ('mosambiker',),
'mosambikere': ('mosambiker',),
'mosambikeren': ('mosambiker',),
'mosambikerer': ('mosambiker',),
'mosambikerne': ('mosambiker',),
'mosdyr': ('mosdyr',),
'mosdyra': ('mosdyr',),
'mosdyrene': ('mosdyr',),
'mosdyret': ('mosdyr',),
'mose': ('mose',),
'mosen': ('mose',),
'mosene': ('mose',),
'moser': ('mose',),
'mosedott': ('mosedott',),
'mosedotten': ('mosedott',),
'mosedottene': ('mosedott',),
'mosedotter': ('mosedott',),
'moselvin': ('moselvin',),
'moselvinen': ('moselvin',),
'moselvinene': ('moselvin',),
'moselviner': ('moselvin',),
'moselyng': ('moselyng',),
'moselynga': ('moselyng',),
'moselyngen': ('moselyng',),
'moselyngene': ('moselyng',),
'moselynger': ('moselyng',),
'moselynget': ('moselyng',),
'mosemyr': ('mosemyr',),
'mosemyra': ('mosemyr',),
'mosemyren': ('mosemyr',),
'mosemyrene': ('mosemyr',),
'mosemyrer': ('mosemyr',),
'mosjon': ('mosjon',),
'mosjonen': ('mosjon',),
'mosjonene': ('mosjon',),
'mosjoner': ('mosjon',),
'mosjonist': ('mosjonist',),
'mosjonisten': ('mosjonist',),
'mosjonistene': ('mosjonist',),
'mosjonister': ('mosjonist',),
'mosjonsgymnastikk': ('mosjonsgymnastikk',),
'mosjonsgymnastikken': ('mosjonsgymnastikk',),
'mosjonsgymnastikkene': ('mosjonsgymnastikk',),
'mosjonsgymnastikker': ('mosjonsgymnastikk',),
'mosjonsidrett': ('mosjonsidrett',),
'mosjonsidretten': ('mosjonsidrett',),
'mosjonsidrettene': ('mosjonsidrett',),
'mosjonsidretter': ('mosjonsidrett',),
'mosjonsparti': ('mosjonsparti',),
'mosjonspartia': ('mosjonsparti',),
'mosjonspartiene': ('mosjonsparti',),
'mosjonspartier': ('mosjonsparti',),
'mosjonspartiet': ('mosjonsparti',),
'mosjonstur': ('mosjonstur',),
'mosjonsturen': ('mosjonstur',),
'mosjonsturene': ('mosjonstur',),
'mosjonsturer': ('mosjonstur',),
'moskeen': ('moské',),
'moskeene': ('moské',),
'moskeer': ('moské',),
'moské': ('moské',),
'moskéen': ('moské',),
'moskéene': ('moské',),
'moskéer': ('moské',),
'moskito': ('moskito',),
'moskitoen': ('moskito',),
'moskitoene': ('moskito',),
'moskitoer': ('moskito',),
'moskitonett': ('moskitonett',),
'moskitonetta': ('moskitonett',),
'moskitonettene': ('moskitonett',),
'moskitonettet': ('moskitonett',),
'moskovitt': ('moskovitt',),
'moskovitten': ('moskovitt',),
'moskovittene': ('moskovitt',),
'moskovitter': ('moskovitt',),
'moskus': ('moskus',),
'moskusen': ('moskus',),
'moskusene': ('moskus',),
'moskuser': ('moskus',),
'moskusdyr': ('moskusdyr',),
'moskusdyra': ('moskusdyr',),
'moskusdyrene': ('moskusdyr',),
'moskusdyret': ('moskusdyr',),
'moskusfe': ('moskusfe',),
'moskusfea': ('moskusfe',),
'moskusfeene': ('moskusfe',),
'moskusfeet': ('moskusfe',),
'moskushjort': ('moskushjort',),
'moskushjorten': ('moskushjort',),
'moskushjortene': ('moskushjort',),
'moskushjorter': ('moskushjort',),
'moskusokse': ('moskusokse',),
'moskusoksen': ('moskusokse',),
'moskusoksene': ('moskusokse',),
'moskusokser': ('moskusokse',),
'moskusrotta': ('moskusrotte',),
'moskusrotte': ('moskusrotte',),
'moskusrotten': ('moskusrotte',),
'moskusrottene': ('moskusrotte',),
'moskusrotter': ('moskusrotte',),
'moskusurt': ('moskusurt',),
'moskusurta': ('moskusurt',),
'moskusurten': ('moskusurt',),
'moskusurtene': ('moskusurt',),
'moskusurter': ('moskusurt',),
'most': ('most',),
'mosten': ('most',),
'mostene': ('most',),
'moster': ('most',),
'moster': ('moster',),
'mosteren': ('moster',),
'mostra': ('moster',),
'mostre': ('moster',),
'mostrene': ('moster',),
'mostrer': ('moster',),
'motaksjon': ('motaksjon',),
'motaksjonen': ('motaksjon',),
'motaksjonene': ('motaksjon',),
'motaksjoner': ('motaksjon',),
'motargument': ('motargument',),
'motargumenta': ('motargument',),
'motargumentene': ('motargument',),
'motargumenter': ('motargument',),
'motargumentet': ('motargument',),
'motbakke': ('motbakke',),
'motbakken': ('motbakke',),
'motbakkene': ('motbakke',),
'motbakker': ('motbakke',),
'motbevis': ('motbevis',),
'motbevisa': ('motbevis',),
'motbevisene': ('motbevis',),
'motbeviser': ('motbevis',),
'motbeviset': ('motbevis',),
'motbør': ('motbør',),
'motbøren': ('motbør',),
'motbørene': ('motbør',),
'motbører': ('motbør',),
'motdagist': ('motdagist',),
'motdagisten': ('motdagist',),
'motdagistene': ('motdagist',),
'motdagister': ('motdagist',),
'motdemonstrasjon': ('motdemonstrasjon',),
'motdemonstrasjonen': ('motdemonstrasjon',),
'motdemonstrasjonene': ('motdemonstrasjon',),
'motdemonstrasjoner': ('motdemonstrasjon',),
'mote': ('mote',),
'moten': ('mote',),
'motene': ('mote',),
'moter': ('mote',),
'mote': ('mote',),
'moten': ('mote',),
'motene': ('mote',),
'moter': ('mote',),
'motebilda': ('motebilde',),
'motebilde': ('motebilde',),
'motebildene': ('motebilde',),
'motebilder': ('motebilde',),
'motebildet': ('motebilde',),
'moteblad': ('moteblad',),
'moteblada': ('moteblad',),
'motebladene': ('moteblad',),
'moteblader': ('moteblad',),
'motebladet': ('moteblad',),
'motehus': ('motehus',),
'motehusa': ('motehus',),
'motehusene': ('motehus',),
'motehuset': ('motehus',),
'moteklær': ('moteklær',),
'moteklærne': ('moteklær',),
'motekspertise': ('motekspertise',),
'motekspertisen': ('motekspertise',),
'motekspertisene': ('motekspertise',),
'motekspertiser': ('motekspertise',),
'moteld': ('moteld',),
'motelden': ('moteld',),
'moteldene': ('moteld',),
'motelder': ('moteld',),
'moteld': ('moteld',),
'motelden': ('moteld',),
'moteldene': ('moteld',),
'motelder': ('moteld',),
'motell': ('motell',),
'motella': ('motell',),
'motellene': ('motell',),
'moteller': ('motell',),
'motellet': ('motell',),
'moteløva': ('moteløve',),
'moteløve': ('moteløve',),
'moteløven': ('moteløve',),
'moteløvene': ('moteløve',),
'moteløver': ('moteløve',),
'moteord': ('moteord',),
'moteorda': ('moteord',),
'moteordene': ('moteord',),
'moteordet': ('moteord',),
'moteretning': ('moteretning',),
'moteretninga': ('moteretning',),
'moteretningen': ('moteretning',),
'moteretningene': ('moteretning',),
'moteretninger': ('moteretning',),
'motesak': ('motesak',),
'motesaka': ('motesak',),
'motesaken': ('motesak',),
'motesakene': ('motesak',),
'motesaker': ('motesak',),
'moteskaper': ('moteskaper',),
'moteskapere': ('moteskaper',),
'moteskaperen': ('moteskaper',),
'moteskaperer': ('moteskaper',),
'moteskaperne': ('moteskaper',),
'moteslave': ('moteslave',),
'moteslaven': ('moteslave',),
'moteslavene': ('moteslave',),
'moteslaver': ('moteslave',),
'motetegner': ('motetegner',),
'motetegnere': ('motetegner',),
'motetegneren': ('motetegner',),
'motetegnerer': ('motetegner',),
'motetegnerne': ('motetegner',),
'motett': ('motett',),
'motetten': ('motett',),
'motettene': ('motett',),
'motetter': ('motett',),
'motettkor': ('motettkor',),
'motettkora': ('motettkor',),
'motettkorene': ('motettkor',),
'motettkoret': ('motettkor',),
'motforestilling': ('motforestilling',),
'motforestillinga': ('motforestilling',),
'motforestillingen': ('motforestilling',),
'motforestillingene': ('motforestilling',),
'motforestillinger': ('motforestilling',),
'motforslag': ('motforslag',),
'motforslaga': ('motforslag',),
'motforslagene': ('motforslag',),
'motforslaget': ('motforslag',),
'motgang': ('motgang',),
'motgangen': ('motgang',),
'motgangene': ('motgang',),
'motganger': ('motgang',),
'motgift': ('motgift',),
'motgifta': ('motgift',),
'motgiften': ('motgift',),
'motgiftene': ('motgift',),
'motgifter': ('motgift',),
'mothake': ('mothake',),
'mothaken': ('mothake',),
'mothakene': ('mothake',),
'mothaker': ('mothake',),
'motild': ('motild',),
'motilden': ('motild',),
'motildene': ('motild',),
'motilder': ('motild',),
'motild': ('motild',),
'motilden': ('motild',),
'motildene': ('motild',),
'motilder': ('motild',),
'motinformasjon': ('motinformasjon',),
'motinformasjonen': ('motinformasjon',),
'motinformasjonene': ('motinformasjon',),
'motinformasjoner': ('motinformasjon',),
'motiv': ('motiv',),
'motiva': ('motiv',),
'motivene': ('motiv',),
'motiver': ('motiv',),
'motivet': ('motiv',),
'motivasjon': ('motivasjon',),
'motivasjonen': ('motivasjon',),
'motivasjonene': ('motivasjon',),
'motivasjoner': ('motivasjon',),
'motivering': ('motivering',),
'motiveringa': ('motivering',),
'motiveringen': ('motivering',),
'motiveringene': ('motivering',),
'motiveringer': ('motivering',),
'motivikk': ('motivikk',),
'motivikken': ('motivikk',),
'motivikkene': ('motivikk',),
'motivikker': ('motivikk',),
'motkandidat': ('motkandidat',),
'motkandidaten': ('motkandidat',),
'motkandidatene': ('motkandidat',),
'motkandidater': ('motkandidat',),
'motkraft': ('motkraft',),
'motkrafta': ('motkraft',),
'motkraften': ('motkraft',),
'motkreftene': ('motkraft',),
'motkrefter': ('motkraft',),
'motkultur': ('motkultur',),
'motkulturen': ('motkultur',),
'motkulturene': ('motkultur',),
'motkulturer': ('motkultur',),
'motkupp': ('motkupp',),
'motkuppa': ('motkupp',),
'motkuppene': ('motkupp',),
'motkuppet': ('motkupp',),
'motlegg': ('motlegg',),
'motlegga': ('motlegg',),
'motleggene': ('motlegg',),
'motlegget': ('motlegg',),
'motlys': ('motlys',),
'motlysa': ('motlys',),
'motlysene': ('motlys',),
'motlyset': ('motlys',),
'motløshet': ('motløshet',),
'motløsheta': ('motløshet',),
'motløsheten': ('motløshet',),
'motløshetene': ('motløshet',),
'motløsheter': ('motløshet',),
'motløysa': ('motløyse',),
'motløyse': ('motløyse',),
'motløysen': ('motløyse',),
'motløysene': ('motløyse',),
'motløyser': ('motløyse',),
'motmann': ('motmann',),
'motmannen': ('motmann',),
'motmenn': ('motmann',),
'motmennene': ('motmann',),
'motmæla': ('motmæle',),
'motmæle': ('motmæle',),
'motmælene': ('motmæle',),
'motmæler': ('motmæle',),
'motmælet': ('motmæle',),
'motocross': ('motocross',),
'motocrossa': ('motocross',),
'motocrossene': ('motocross',),
'motocrosser': ('motocross',),
'motocrosset': ('motocross',),
'motoffensiv': ('motoffensiv',),
'motoffensiven': ('motoffensiv',),
'motoffensivene': ('motoffensiv',),
'motoffensiver': ('motoffensiv',),
'motor': ('motor',),
'motoren': ('motor',),
'motorene': ('motor',),
'motorer': ('motor',),
'motorbåt': ('motorbåt',),
'motorbåten': ('motorbåt',),
'motorbåtene': ('motorbåt',),
'motorbåter': ('motorbåt',),
'motordrift': ('motordrift',),
'motordrifta': ('motordrift',),
'motordriften': ('motordrift',),
'motordriftene': ('motordrift',),
'motordrifter': ('motordrift',),
'motorfartøy': ('motorfartøy',),
'motorfartøya': ('motorfartøy',),
'motorfartøyene': ('motorfartøy',),
'motorfartøyer': ('motorfartøy',),
'motorfartøyet': ('motorfartøy',),
'motorhavari': ('motorhavari',),
'motorhavaria': ('motorhavari',),
'motorhavariene': ('motorhavari',),
'motorhavarier': ('motorhavari',),
'motorhavariet': ('motorhavari',),
'motorikk': ('motorikk',),
'motorikken': ('motorikk',),
'motorikkene': ('motorikk',),
'motorikker': ('motorikk',),
'motorkassa': ('motorkasse',),
'motorkasse': ('motorkasse',),
'motorkassen': ('motorkasse',),
'motorkassene': ('motorkasse',),
'motorkasser': ('motorkasse',),
'motorkjøretøy': ('motorkjøretøy',),
'motorkjøretøya': ('motorkjøretøy',),
'motorkjøretøyene': ('motorkjøretøy',),
'motorkjøretøyer': ('motorkjøretøy',),
'motorkjøretøyet': ('motorkjøretøy',),
'motorkutter': ('motorkutter',),
'motorkuttere': ('motorkutter',),
'motorkutteren': ('motorkutter',),
'motorkutterer': ('motorkutter',),
'motorkutterne': ('motorkutter',),
'motorolja': ('motorolje',),
'motorolje': ('motorolje',),
'motoroljen': ('motorolje',),
'motoroljene': ('motorolje',),
'motoroljer': ('motorolje',),
'motorsag': ('motorsag',),
'motorsaga': ('motorsag',),
'motorsagen': ('motorsag',),
'motorsagene': ('motorsag',),
'motorsager': ('motorsag',),
'motorsenter': ('motorsenter',),
'motorsenteret': ('motorsenter',),
'motorsentra': ('motorsenter',),
'motorsentre': ('motorsenter',),
'motorsentrene': ('motorsenter',),
'motorsentret': ('motorsenter',),
'motorskip': ('motorskip',),
'motorskipa': ('motorskip',),
'motorskipene': ('motorskip',),
'motorskipet': ('motorskip',),
'motorstopp': ('motorstopp',),
'motorstoppa': ('motorstopp',),
'motorstoppen': ('motorstopp',),
'motorstoppene': ('motorstopp',),
'motorstoppet': ('motorstopp',),
'motorsykkel': ('motorsykkel',),
'motorsykkelen': ('motorsykkel',),
'motorsyklene': ('motorsykkel',),
'motorsykler': ('motorsykkel',),
'motortanker': ('motortanker',),
'motortankere': ('motortanker',),
'motortankeren': ('motortanker',),
'motortankerer': ('motortanker',),
'motortankerne': ('motortanker',),
'motortorpedobåt': ('motortorpedobåt',),
'motortorpedobåten': ('motortorpedobåt',),
'motortorpedobåtene': ('motortorpedobåt',),
'motortorpedobåter': ('motortorpedobåt',),
'motorvarmer': ('motorvarmer',),
'motorvarmere': ('motorvarmer',),
'motorvarmeren': ('motorvarmer',),
'motorvarmerer': ('motorvarmer',),
'motorvarmerne': ('motorvarmer',),
'motorveg': ('motorveg',),
'motorvegen': ('motorveg',),
'motorvegene': ('motorveg',),
'motorveger': ('motorveg',),
'motorvei': ('motorvei',),
'motorveien': ('motorvei',),
'motorveiene': ('motorvei',),
'motorveier': ('motorvei',),
'motorvogn': ('motorvogn',),
'motorvogna': ('motorvogn',),
'motorvognen': ('motorvogn',),
'motorvognene': ('motorvogn',),
'motorvogner': ('motorvogn',),
'motpart': ('motpart',),
'motparten': ('motpart',),
'motpartene': ('motpart',),
'motparter': ('motpart',),
'motpol': ('motpol',),
'motpolen': ('motpol',),
'motpolene': ('motpol',),
'motpoler': ('motpol',),
'motreformasjon': ('motreformasjon',),
'motreformasjonen': ('motreformasjon',),
'motreformasjonene': ('motreformasjon',),
'motreformasjoner': ('motreformasjon',),
'motregning': ('motregning',),
'motregninga': ('motregning',),
'motregningen': ('motregning',),
'motregningene': ('motregning',),
'motregninger': ('motregning',),
'motrekning': ('motrekning',),
'motrekninga': ('motrekning',),
'motrekningen': ('motrekning',),
'motrekningene': ('motrekning',),
'motrekninger': ('motrekning',),
'motrevolusjon': ('motrevolusjon',),
'motrevolusjonen': ('motrevolusjon',),
'motrevolusjonene': ('motrevolusjon',),
'motrevolusjoner': ('motrevolusjon',),
'motsetning': ('motsetning',),
'motsetninga': ('motsetning',),
'motsetningen': ('motsetning',),
'motsetningene': ('motsetning',),
'motsetninger': ('motsetning',),
'motsetningsforhold': ('motsetningsforhold',),
'motsetningsforholda': ('motsetningsforhold',),
'motsetningsforholdene': ('motsetningsforhold',),
'motsetningsforholdet': ('motsetningsforhold',),
'motsigelse': ('motsigelse',),
'motsigelsen': ('motsigelse',),
'motsigelsene': ('motsigelse',),
'motsigelser': ('motsigelse',),
'motsigelsesprinsipp': ('motsigelsesprinsipp',),
'motsigelsesprinsippa': ('motsigelsesprinsipp',),
'motsigelsesprinsippene': ('motsigelsesprinsipp',),
'motsigelsesprinsipper': ('motsigelsesprinsipp',),
'motsigelsesprinsippet': ('motsigelsesprinsipp',),
'motspell': ('motspell',),
'motspella': ('motspell',),
'motspellene': ('motspell',),
'motspellet': ('motspell',),
'motspeller': ('motspeller',),
'motspellere': ('motspeller',),
'motspelleren': ('motspeller',),
'motspellerer': ('motspeller',),
'motspellerne': ('motspeller',),
'motspill': ('motspill',),
'motspilla': ('motspill',),
'motspillene': ('motspill',),
'motspillet': ('motspill',),
'motspiller': ('motspiller',),
'motspillere': ('motspiller',),
'motspilleren': ('motspiller',),
'motspillerer': ('motspiller',),
'motspillerne': ('motspiller',),
'motspørsmål': ('motspørsmål',),
'motspørsmåla': ('motspørsmål',),
'motspørsmålene': ('motspørsmål',),
'motspørsmålet': ('motspørsmål',),
'motstand': ('motstand',),
'motstanden': ('motstand',),
'motstandene': ('motstand',),
'motstander': ('motstand',),
'motstander': ('motstander',),
'motstandere': ('motstander',),
'motstanderen': ('motstander',),
'motstanderer': ('motstander',),
'motstanderne': ('motstander',),
'motstandsarbeid': ('motstandsarbeid',),
'motstandsarbeida': ('motstandsarbeid',),
'motstandsarbeidene': ('motstandsarbeid',),
'motstandsarbeider': ('motstandsarbeid',),
'motstandsarbeidet': ('motstandsarbeid',),
'motstandsbevegelse': ('motstandsbevegelse',),
'motstandsbevegelsen': ('motstandsbevegelse',),
'motstandsbevegelsene': ('motstandsbevegelse',),
'motstandsbevegelser': ('motstandsbevegelse',),
'motstandskraft': ('motstandskraft',),
'motstandskrafta': ('motstandskraft',),
'motstandskraften': ('motstandskraft',),
'motstandskreftene': ('motstandskraft',),
'motstandskrefter': ('motstandskraft',),
'motstrev': ('motstrev',),
'motstreva': ('motstrev',),
'motstrevene': ('motstrev',),
'motstrevet': ('motstrev',),
'motstrid': ('motstrid',),
'motstriden': ('motstrid',),
'motstridene': ('motstrid',),
'motstrider': ('motstrid',),
'motstrøm': ('motstrøm',),
'motstrømmen': ('motstrøm',),
'motstrømmene': ('motstrøm',),
'motstrømmer': ('motstrøm',),
'motstykka': ('motstykke',),
'motstykke': ('motstykke',),
'motstykkene': ('motstykke',),
'motstykker': ('motstykke',),
'motstykket': ('motstykke',),
'motsvar': ('motsvar',),
'motsvara': ('motsvar',),
'motsvarene': ('motsvar',),
'motsvaret': ('motsvar',),
'motsvarighet': ('motsvarighet',),
'motsvarigheta': ('motsvarighet',),
'motsvarigheten': ('motsvarighet',),
'motsvarighetene': ('motsvarighet',),
'motsvarigheter': ('motsvarighet',),
'mott': ('mott',),
'motten': ('mott',),
'mottene': ('mott',),
'motter': ('mott',),
'mottaing': ('mottaing',),
'mottainga': ('mottaing',),
'mottaingen': ('mottaing',),
'mottaingene': ('mottaing',),
'mottainger': ('mottaing',),
'mottaingsrom': ('mottaingsrom',),
'mottaingsromma': ('mottaingsrom',),
'mottaingsrommene': ('mottaingsrom',),
'mottaingsrommet': ('mottaingsrom',),
'mottak': ('mottak',),
'mottaka': ('mottak',),
'mottakene': ('mottak',),
'mottaket': ('mottak',),
'mottakelse': ('mottakelse',),
'mottakelsen': ('mottakelse',),
'mottakelsene': ('mottakelse',),
'mottakelser': ('mottakelse',),
'mottaker': ('mottaker',),
'mottakere': ('mottaker',),
'mottakeren': ('mottaker',),
'mottakerer': ('mottaker',),
'mottakerne': ('mottaker',),
'mottakerapparat': ('mottakerapparat',),
'mottakerapparata': ('mottakerapparat',),
'mottakerapparatene': ('mottakerapparat',),
'mottakerapparater': ('mottakerapparat',),
'mottakerapparatet': ('mottakerapparat',),
'mottakerstasjon': ('mottakerstasjon',),
'mottakerstasjonen': ('mottakerstasjon',),
'mottakerstasjonene': ('mottakerstasjon',),
'mottakerstasjoner': ('mottakerstasjon',),
'mottaking': ('mottaking',),
'mottakinga': ('mottaking',),
'mottakingen': ('mottaking',),
'mottakingene': ('mottaking',),
'mottakinger': ('mottaking',),
'mottakingsrom': ('mottakingsrom',),
'mottakingsromma': ('mottakingsrom',),
'mottakingsrommene': ('mottakingsrom',),
'mottakingsrommet': ('mottakingsrom',),
'mottaksanlegg': ('mottaksanlegg',),
'mottaksanlegga': ('mottaksanlegg',),
'mottaksanleggene': ('mottaksanlegg',),
'mottaksanlegget': ('mottaksanlegg',),
'mottaksstasjon': ('mottaksstasjon',),
'mottaksstasjonen': ('mottaksstasjon',),
'mottaksstasjonene': ('mottaksstasjon',),
'mottaksstasjoner': ('mottaksstasjon',),
'mottiltak': ('mottiltak',),
'mottiltaka': ('mottiltak',),
'mottiltakene': ('mottiltak',),
'mottiltaket': ('mottiltak',),
'motto': ('motto',),
'mottoa': ('motto',),
'mottoene': ('motto',),
'mottoer': ('motto',),
'mottoet': ('motto',),
'mottrekk': ('mottrekk',),
'mottrekka': ('mottrekk',),
'mottrekkene': ('mottrekk',),
'mottrekket': ('mottrekk',),
'motvarme': ('motvarme',),
'motvarmen': ('motvarme',),
'motvarmene': ('motvarme',),
'motvarmer': ('motvarme',),
'motvekt': ('motvekt',),
'motvekta': ('motvekt',),
'motvekten': ('motvekt',),
'motvektene': ('motvekt',),
'motvekter': ('motvekt',),
'motvilje': ('motvilje',),
'motviljen': ('motvilje',),
'motviljene': ('motvilje',),
'motviljer': ('motvilje',),
'motvind': ('motvind',),
'motvinden': ('motvind',),
'motvindene': ('motvind',),
'motvinder': ('motvind',),
'moulineen': ('mouliné',),
'moulineene': ('mouliné',),
'moulineer': ('mouliné',),
'mouliné': ('mouliné',),
'moulinéen': ('mouliné',),
'moulinéene': ('mouliné',),
'moulinéer': ('mouliné',),
'moulinégarn': ('moulinégarn',),
'moulinégarna': ('moulinégarn',),
'moulinégarnene': ('moulinégarn',),
'moulinégarnet': ('moulinégarn',),
'moussaka': ('moussaka',),
'moussakaen': ('moussaka',),
'moussakaene': ('moussaka',),
'moussakaer': ('moussaka',),
'mousse': ('mousse',),
'moussen': ('mousse',),
'moussene': ('mousse',),
'mousser': ('mousse',),
'ms-pasient': ('ms-pasient',),
'ms-pasienten': ('ms-pasient',),
'ms-pasientene': ('ms-pasient',),
'ms-pasienter': ('ms-pasient',),
'mudd': ('mudd',),
'mudden': ('mudd',),
'muddene': ('mudd',),
'mudder': ('mudd',),
'mudder': ('mudder',),
'muddera': ('mudder',),
'muddere': ('mudder',),
'mudderet': ('mudder',),
'mudderne': ('mudder',),
'mudder': ('mudder',),
'muddera': ('mudder',),
'muddere': ('mudder',),
'mudderet': ('mudder',),
'mudderne': ('mudder',),
'mudderapparat': ('mudderapparat',),
'mudderapparata': ('mudderapparat',),
'mudderapparatene': ('mudderapparat',),
'mudderapparater': ('mudderapparat',),
'mudderapparatet': ('mudderapparat',),
'mudderpram': ('mudderpram',),
'mudderprammen': ('mudderpram',),
'mudderprammene': ('mudderpram',),
'mudderprammer': ('mudderpram',),
'mudderverk': ('mudderverk',),
'mudderverka': ('mudderverk',),
'mudderverkene': ('mudderverk',),
'mudderverker': ('mudderverk',),
'mudderverket': ('mudderverk',),
'muezzin': ('muezzin',),
'muezzinen': ('muezzin',),
'muezzinene': ('muezzin',),
'muezziner': ('muezzin',),
'muffa': ('muffe',),
'muffe': ('muffe',),
'muffen': ('muffe',),
'muffene': ('muffe',),
'muffer': ('muffe',),
'muffens': ('muffens',),
'mug': ('mug',),
'mugen': ('mug',),
'mugene': ('mug',),
'muger': ('mug',),
'muga': ('muge',),
'muge': ('muge',),
'mugen': ('muge',),
'mugene': ('muge',),
'muger': ('muge',),
'muga': ('muge',),
'muge': ('muge',),
'mugen': ('muge',),
'mugene': ('muge',),
'muger': ('muge',),
'mugg': ('mugg',),
'muggen': ('mugg',),
'muggene': ('mugg',),
'mugger': ('mugg',),
'mugg': ('mugg',),
'muggen': ('mugg',),
'muggene': ('mugg',),
'mugger': ('mugg',),
'mugg': ('mugg',),
'mugga': ('mugg',),
'muggen': ('mugg',),
'muggene': ('mugg',),
'mugger': ('mugg',),
'mugget': ('mugg',),
'mugg': ('mugg',),
'mugga': ('mugg',),
'muggen': ('mugg',),
'muggene': ('mugg',),
'mugger': ('mugg',),
'mugget': ('mugg',),
'mugga': ('mugge',),
'mugge': ('mugge',),
'muggen': ('mugge',),
'muggene': ('mugge',),
'mugger': ('mugge',),
'muggost': ('muggost',),
'muggosten': ('muggost',),
'muggostene': ('muggost',),
'muggoster': ('muggost',),
'muggsmak': ('muggsmak',),
'muggsmaken': ('muggsmak',),
'muggsmakene': ('muggsmak',),
'muggsmaker': ('muggsmak',),
'muggsopp': ('muggsopp',),
'muggsoppen': ('muggsopp',),
'muggsoppene': ('muggsopp',),
'muggsopper': ('muggsopp',),
'muhamedaner': ('muhamedaner',),
'muhamedanere': ('muhamedaner',),
'muhamedaneren': ('muhamedaner',),
'muhamedanerer': ('muhamedaner',),
'muhamedanerne': ('muhamedaner',),
'muhamedanisme': ('muhamedanisme',),
'muhamedanismen': ('muhamedanisme',),
'muhamedanismene': ('muhamedanisme',),
'muhamedanismer': ('muhamedanisme',),
'muhammedaner': ('muhammedaner',),
'muhammedanere': ('muhammedaner',),
'muhammedaneren': ('muhammedaner',),
'muhammedanerer': ('muhammedaner',),
'muhammedanerne': ('muhammedaner',),
'muhammedanisme': ('muhammedanisme',),
'muhammedanismen': ('muhammedanisme',),
'muhammedanismene': ('muhammedanisme',),
'muhammedanismer': ('muhammedanisme',),
'mukk': ('mukk',),
'mukka': ('mukk',),
'mukkene': ('mukk',),
'mukket': ('mukk',),
'mulatt': ('mulatt',),
'mulatten': ('mulatt',),
'mulattene': ('mulatt',),
'mulatter': ('mulatt',),
'muld': ('muld',),
'mulda': ('muld',),
'mulden': ('muld',),
'muldene': ('muld',),
'mulder': ('muld',),
'muldjord': ('muldjord',),
'muldjorda': ('muldjord',),
'muldjorden': ('muldjord',),
'muldjordene': ('muldjord',),
'muldjorder': ('muldjord',),
'muldklump': ('muldklump',),
'muldklumpen': ('muldklump',),
'muldklumpene': ('muldklump',),
'muldklumper': ('muldklump',),
'muldvarp': ('muldvarp',),
'muldvarpen': ('muldvarp',),
'muldvarpene': ('muldvarp',),
'muldvarper': ('muldvarp',),
'muldvarparbeid': ('muldvarparbeid',),
'muldvarparbeida': ('muldvarparbeid',),
'muldvarparbeidene': ('muldvarparbeid',),
'muldvarparbeidet': ('muldvarparbeid',),
'muldyr': ('muldyr',),
'muldyra': ('muldyr',),
'muldyrene': ('muldyr',),
'muldyret': ('muldyr',),
'mule': ('mule',),
'mulen': ('mule',),
'mulene': ('mule',),
'muler': ('mule',),
'muleband': ('muleband',),
'mulebanda': ('muleband',),
'mulebandene': ('muleband',),
'mulebandet': ('muleband',),
'mulebånd': ('mulebånd',),
'mulebånda': ('mulebånd',),
'mulebåndene': ('mulebånd',),
'mulebåndet': ('mulebånd',),
'mulesel': ('mulesel',),
'muleselet': ('mulesel',),
'mulesla': ('mulesel',),
'muleslene': ('mulesel',),
'mulesler': ('mulesel',),
'muleslet': ('mulesel',),
'mulighet': ('mulighet',),
'muligheta': ('mulighet',),
'muligheten': ('mulighet',),
'mulighetene': ('mulighet',),
'muligheter': ('mulighet',),
'mulkt': ('mulkt',),
'mulkta': ('mulkt',),
'mulkten': ('mulkt',),
'mulktene': ('mulkt',),
'mulkter': ('mulkt',),
'mulla': ('mulla',),
'mullaen': ('mulla',),
'mullaene': ('mulla',),
'mullaer': ('mulla',),
'mulm': ('mulm',),
'mulma': ('mulm',),
'mulmene': ('mulm',),
'mulmet': ('mulm',),
'multa': ('multe',),
'multe': ('multe',),
'multen': ('multe',),
'multene': ('multe',),
'multer': ('multe',),
'multebær': ('multebær',),
'multebæra': ('multebær',),
'multebærene': ('multebær',),
'multebæret': ('multebær',),
'multekart': ('multekart',),
'multekarten': ('multekart',),
'multekartene': ('multekart',),
'multekarter': ('multekart',),
'multekrem': ('multekrem',),
'multekremen': ('multekrem',),
'multekremene': ('multekrem',),
'multekremer': ('multekrem',),
'multemyr': ('multemyr',),
'multemyra': ('multemyr',),
'multemyren': ('multemyr',),
'multemyrene': ('multemyr',),
'multemyrer': ('multemyr',),
'multeplukker': ('multeplukker',),
'multeplukkere': ('multeplukker',),
'multeplukkeren': ('multeplukker',),
'multeplukkerer': ('multeplukker',),
'multeplukkerne': ('multeplukker',),
'multigradolja': ('multigradolje',),
'multigradolje': ('multigradolje',),
'multigradoljen': ('multigradolje',),
'multigradoljene': ('multigradolje',),
'multigradoljer': ('multigradolje',),
'multihandikap': ('multihandikap',),
'multihandikapa': ('multihandikap',),
'multihandikapene': ('multihandikap',),
'multihandikaper': ('multihandikap',),
'multihandikapet': ('multihandikap',),
'multiplikand': ('multiplikand',),
'multiplikanden': ('multiplikand',),
'multiplikandene': ('multiplikand',),
'multiplikander': ('multiplikand',),
'multiplikasjon': ('multiplikasjon',),
'multiplikasjonen': ('multiplikasjon',),
'multiplikasjonene': ('multiplikasjon',),
'multiplikasjoner': ('multiplikasjon',),
'multiplikasjonstabell': ('multiplikasjonstabell',),
'multiplikasjonstabellen': ('multiplikasjonstabell',),
'multiplikasjonstabellene': ('multiplikasjonstabell',),
'multiplikasjonstabeller': ('multiplikasjonstabell',),
'multiplikasjonstegn': ('multiplikasjonstegn',),
'multiplikasjonstegna': ('multiplikasjonstegn',),
'multiplikasjonstegnene': ('multiplikasjonstegn',),
'multiplikasjonstegnet': ('multiplikasjonstegn',),
'multiplikator': ('multiplikator',),
'multiplikatoren': ('multiplikator',),
'multiplikatorene': ('multiplikator',),
'multiplikatorer': ('multiplikator',),
'multipla': ('multiplum',),
'multiplaene': ('multiplum',),
'multiplum': ('multiplum',),
'multipluma': ('multiplum',),
'multiplumene': ('multiplum',),
'multiplumer': ('multiplum',),
'multiplumet': ('multiplum',),
'mumie': ('mumie',),
'mumien': ('mumie',),
'mumiene': ('mumie',),
'mumier': ('mumie',),
'mundering': ('mundering',),
'munderinga': ('mundering',),
'munderingen': ('mundering',),
'munderingene': ('mundering',),
'munderinger': ('mundering',),
'mundur': ('mundur',),
'munduren': ('mundur',),
'mundurene': ('mundur',),
'mundurer': ('mundur',),
'mungåt': ('mungåt',),
'mungåta': ('mungåt',),
'mungåtene': ('mungåt',),
'mungåtet': ('mungåt',),
'munk': ('munk',),
'munken': ('munk',),
'munkene': ('munk',),
'munker': ('munk',),
'munke': ('munke',),
'munken': ('munke',),
'munkene': ('munke',),
'munker': ('munke',),
'munkejern': ('munkejern',),
'munkejerna': ('munkejern',),
'munkejernene': ('munkejern',),
'munkejernet': ('munkejern',),
'munkekappa': ('munkekappe',),
'munkekappe': ('munkekappe',),
'munkekappen': ('munkekappe',),
'munkekappene': ('munkekappe',),
'munkekapper': ('munkekappe',),
'munkekutta': ('munkekutte',),
'munkekutte': ('munkekutte',),
'munkekutten': ('munkekutte',),
'munkekuttene': ('munkekutte',),
'munkekutter': ('munkekutte',),
'munkeorden': ('munkeorden',),
'munkeordenen': ('munkeorden',),
'munkeordenene': ('munkeorden',),
'munkeordener': ('munkeorden',),
'munkepanna': ('munkepanne',),
'munkepanne': ('munkepanne',),
'munkepannen': ('munkepanne',),
'munkepannene': ('munkepanne',),
'munkepanner': ('munkepanne',),
'munn': ('munn',),
'munnen': ('munn',),
'munnene': ('munn',),
'munner': ('munn',),
'munn- og klauvsjuka': ('munn- og klauvsjuke',),
'munn- og klauvsjuke': ('munn- og klauvsjuke',),
'munn- og klauvsjuken': ('munn- og klauvsjuke',),
'munn- og klauvsjukene': ('munn- og klauvsjuke',),
'munn- og klauvsjuker': ('munn- og klauvsjuke',),
'munn- og klauvsyka': ('munn- og klauvsyke',),
'munn- og klauvsyke': ('munn- og klauvsyke',),
'munn- og klauvsyken': ('munn- og klauvsyke',),
'munn- og klauvsykene': ('munn- og klauvsyke',),
'munn- og klauvsyker': ('munn- og klauvsyke',),
'munn- og klovsjuka': ('munn- og klovsjuke',),
'munn- og klovsjuke': ('munn- og klovsjuke',),
'munn- og klovsjuken': ('munn- og klovsjuke',),
'munn- og klovsjukene': ('munn- og klovsjuke',),
'munn- og klovsjuker': ('munn- og klovsjuke',),
'munn- og klovsyka': ('munn- og klovsyke',),
'munn- og klovsyke': ('munn- og klovsyke',),
'munn- og klovsyken': ('munn- og klovsyke',),
'munn- og klovsykene': ('munn- og klovsyke',),
'munn- og klovsyker': ('munn- og klovsyke',),
'munn-mot-munn-metoden': ('munn-mot-munn-metoden',),
'munnavlesing': ('munnavlesing',),
'munnavlesinga': ('munnavlesing',),
'munnavlesingen': ('munnavlesing',),
'munnavlesingene': ('munnavlesing',),
'munnavlesinger': ('munnavlesing',),
'munnavlesning': ('munnavlesning',),
'munnavlesninga': ('munnavlesning',),
'munnavlesningen': ('munnavlesning',),
'munnavlesningene': ('munnavlesning',),
'munnavlesninger': ('munnavlesning',),
'munnbitt': ('munnbitt',),
'munnbitta': ('munnbitt',),
'munnbittene': ('munnbitt',),
'munnbittet': ('munnbitt',),
'munnbruk': ('munnbruk',),
'munnbruka': ('munnbruk',),
'munnbruken': ('munnbruk',),
'munnbrukene': ('munnbruk',),
'munnbruker': ('munnbruk',),
'munnbruket': ('munnbruk',),
'munnfull': ('munnfull',),
'munnfullen': ('munnfull',),
'munnfullene': ('munnfull',),
'munnfuller': ('munnfull',),
'munnharmonika': ('munnharmonika',),
'munnharmonikaen': ('munnharmonika',),
'munnharmonikaene': ('munnharmonika',),
'munnharmonikaer': ('munnharmonika',),
'munnharpa': ('munnharpe',),
'munnharpe': ('munnharpe',),
'munnharpen': ('munnharpe',),
'munnharpene': ('munnharpe',),
'munnharper': ('munnharpe',),
'munnhell': ('munnhell',),
'munnhella': ('munnhell',),
'munnhellene': ('munnhell',),
'munnhellet': ('munnhell',),
'munnhoggeri': ('munnhoggeri',),
'munnhoggeria': ('munnhoggeri',),
'munnhoggeriene': ('munnhoggeri',),
'munnhoggerier': ('munnhoggeri',),
'munnhoggeriet': ('munnhoggeri',),
'munnhola': ('munnhole',),
'munnhole': ('munnhole',),
'munnholen': ('munnhole',),
'munnholene': ('munnhole',),
'munnholer': ('munnhole',),
'munnhuggeri': ('munnhuggeri',),
'munnhuggeria': ('munnhuggeri',),
'munnhuggeriene': ('munnhuggeri',),
'munnhuggerier': ('munnhuggeri',),
'munnhuggeriet': ('munnhuggeri',),
'munnhula': ('munnhule',),
'munnhule': ('munnhule',),
'munnhulen': ('munnhule',),
'munnhulene': ('munnhule',),
'munnhuler': ('munnhule',),
'munning': ('munning',),
'munninga': ('munning',),
'munningen': ('munning',),
'munningene': ('munning',),
'munninger': ('munning',),
'munningshetta': ('munningshette',),
'munningshette': ('munningshette',),
'munningshetten': ('munningshette',),
'munningshettene': ('munningshette',),
'munningshetter': ('munningshette',),
'munnkorg': ('munnkorg',),
'munnkorga': ('munnkorg',),
'munnkorgen': ('munnkorg',),
'munnkorgene': ('munnkorg',),
'munnkorger': ('munnkorg',),
'munnkurv': ('munnkurv',),
'munnkurva': ('munnkurv',),
'munnkurven': ('munnkurv',),
'munnkurvene': ('munnkurv',),
'munnkurver': ('munnkurv',),
'munnlader': ('munnlader',),
'munnladere': ('munnlader',),
'munnladeren': ('munnlader',),
'munnladerer': ('munnlader',),
'munnladerne': ('munnlader',),
'munnladning': ('munnladning',),
'munnladninga': ('munnladning',),
'munnladningen': ('munnladning',),
'munnladningene': ('munnladning',),
'munnladninger': ('munnladning',),
'munnladningsbørsa': ('munnladningsbørse',),
'munnladningsbørse': ('munnladningsbørse',),
'munnladningsbørsen': ('munnladningsbørse',),
'munnladningsbørsene': ('munnladningsbørse',),
'munnladningsbørser': ('munnladningsbørse',),
'munnladningsgevær': ('munnladningsgevær',),
'munnladningsgeværa': ('munnladningsgevær',),
'munnladningsgeværene': ('munnladningsgevær',),
'munnladningsgeværer': ('munnladningsgevær',),
'munnladningsgeværet': ('munnladningsgevær',),
'munnlær': ('munnlær',),
'munnlæra': ('munnlær',),
'munnlærene': ('munnlær',),
'munnlæret': ('munnlær',),
'munnparti': ('munnparti',),
'munnpartia': ('munnparti',),
'munnpartiene': ('munnparti',),
'munnpartier': ('munnparti',),
'munnpartiet': ('munnparti',),
'munnskjenk': ('munnskjenk',),
'munnskjenken': ('munnskjenk',),
'munnskjenkene': ('munnskjenk',),
'munnskjenker': ('munnskjenk',),
'munnspell': ('munnspell',),
'munnspella': ('munnspell',),
'munnspellene': ('munnspell',),
'munnspellet': ('munnspell',),
'munnspill': ('munnspill',),
'munnspilla': ('munnspill',),
'munnspillene': ('munnspill',),
'munnspillet': ('munnspill',),
'munnstykka': ('munnstykke',),
'munnstykke': ('munnstykke',),
'munnstykkene': ('munnstykke',),
'munnstykker': ('munnstykke',),
'munnstykket': ('munnstykke',),
'munnsvær': ('munnsvær',),
'munnsværa': ('munnsvær',),
'munnsværene': ('munnsvær',),
'munnsværet': ('munnsvær',),
'munnsår': ('munnsår',),
'munnsåra': ('munnsår',),
'munnsårene': ('munnsår',),
'munnsåret': ('munnsår',),
'munntøy': ('munntøy',),
'munntøya': ('munntøy',),
'munntøyene': ('munntøy',),
'munntøyer': ('munntøy',),
'munntøyet': ('munntøy',),
'munnvann': ('munnvann',),
'munnvanna': ('munnvann',),
'munnvannene': ('munnvann',),
'munnvannet': ('munnvann',),
'munnvatn': ('munnvatn',),
'munnvatna': ('munnvatn',),
'munnvatnene': ('munnvatn',),
'munnvatnet': ('munnvatn',),
'munnvik': ('munnvik',),
'munnvika': ('munnvik',),
'munnviken': ('munnvik',),
'munnvikene': ('munnvik',),
'munnviker': ('munnvik',),
'munterhet': ('munterhet',),
'munterheta': ('munterhet',),
'munterheten': ('munterhet',),
'munterhetene': ('munterhet',),
'munterheter': ('munterhet',),
'muntrasjon': ('muntrasjon',),
'muntrasjonen': ('muntrasjon',),
'muntrasjonene': ('muntrasjon',),
'muntrasjoner': ('muntrasjon',),
'muntrasjonsråd': ('muntrasjonsråd',),
'muntrasjonsråda': ('muntrasjonsråd',),
'muntrasjonsråden': ('muntrasjonsråd',),
'muntrasjonsrådene': ('muntrasjonsråd',),
'muntrasjonsråder': ('muntrasjonsråd',),
'muntrasjonsrådet': ('muntrasjonsråd',),
'mur': ('mur',),
'muren': ('mur',),
'murene': ('mur',),
'murer': ('mur',),
'murbrekker': ('murbrekker',),
'murbrekkere': ('murbrekker',),
'murbrekkeren': ('murbrekker',),
'murbrekkerer': ('murbrekker',),
'murbrekkerne': ('murbrekker',),
'murbygning': ('murbygning',),
'murbygninga': ('murbygning',),
'murbygningen': ('murbygning',),
'murbygningene': ('murbygning',),
'murbygninger': ('murbygning',),
'mura': ('mure',),
'mure': ('mure',),
'muren': ('mure',),
'murene': ('mure',),
'murer': ('mure',),
'murer': ('murer',),
'murere': ('murer',),
'mureren': ('murer',),
'murerer': ('murer',),
'murerne': ('murer',),
'murerlærling': ('murerlærling',),
'murerlærlingen': ('murerlærling',),
'murerlærlingene': ('murerlærling',),
'murerlærlinger': ('murerlærling',),
'murersvenn': ('murersvenn',),
'murersvennen': ('murersvenn',),
'murersvennene': ('murersvenn',),
'murersvenner': ('murersvenn',),
'murkrans': ('murkrans',),
'murkransen': ('murkrans',),
'murkransene': ('murkrans',),
'murkranser': ('murkrans',),
'murkrona': ('murkrone',),
'murkrone': ('murkrone',),
'murkronen': ('murkrone',),
'murkronene': ('murkrone',),
'murkroner': ('murkrone',),
'murmeldyr': ('murmeldyr',),
'murmeldyra': ('murmeldyr',),
'murmeldyrene': ('murmeldyr',),
'murmeldyret': ('murmeldyr',),
'murmester': ('murmester',),
'murmestere': ('murmester',),
'murmesteren': ('murmester',),
'murmesterer': ('murmester',),
'murmesterne': ('murmester',),
'murmestre': ('murmester',),
'murmestrene': ('murmester',),
'murmestrer': ('murmester',),
'murpipa': ('murpipe',),
'murpipe': ('murpipe',),
'murpipen': ('murpipe',),
'murpipene': ('murpipe',),
'murpiper': ('murpipe',),
'murpuss': ('murpuss',),
'murpussen': ('murpuss',),
'murpussene': ('murpuss',),
'murpusser': ('murpuss',),
'murr': ('murr',),
'murra': ('murr',),
'murrene': ('murr',),
'murret': ('murr',),
'mursement': ('mursement',),
'mursementen': ('mursement',),
'mursementene': ('mursement',),
'mursementer': ('mursement',),
'murskei': ('murskei',),
'murskeia': ('murskei',),
'murskeien': ('murskei',),
'murskeiene': ('murskei',),
'murskeier': ('murskei',),
'murskje': ('murskje',),
'murskjea': ('murskje',),
'murskjeen': ('murskje',),
'murskjeene': ('murskje',),
'murskjeer': ('murskje',),
'murstein': ('murstein',),
'mursteinen': ('murstein',),
'mursteinene': ('murstein',),
'mursteiner': ('murstein',),
'murtvang': ('murtvang',),
'murtvangen': ('murtvang',),
'murtvangene': ('murtvang',),
'murtvanger': ('murtvang',),
'murvegg': ('murvegg',),
'murveggen': ('murvegg',),
'murveggene': ('murvegg',),
'murvegger': ('murvegg',),
'murverk': ('murverk',),
'murverka': ('murverk',),
'murverkene': ('murverk',),
'murverker': ('murverk',),
'murverket': ('murverk',),
'mus': ('mus',),
'musa': ('mus',),
'musen': ('mus',),
'musene': ('mus',),
'musea': ('musé',),
'museene': ('musé',),
'museer': ('musé',),
'museet': ('musé',),
'musé': ('musé',),
'muséa': ('musé',),
'muséene': ('musé',),
'muséer': ('musé',),
'muséet': ('musé',),
'musea': ('musé',),
'museene': ('musé',),
'museer': ('musé',),
'museet': ('musé',),
'musé': ('musé',),
'muséa': ('musé',),
'muséene': ('musé',),
'muséer': ('musé',),
'muséet': ('musé',),
'musébygning': ('musébygning',),
'musébygninga': ('musébygning',),
'musébygningen': ('musébygning',),
'musébygningene': ('musébygning',),
'musébygninger': ('musébygning',),
'musédirektør': ('musédirektør',),
'musédirektøren': ('musédirektør',),
'musédirektørene': ('musédirektør',),
'musédirektører': ('musédirektør',),
'musédirektør': ('musédirektør',),
'musédirektøren': ('musédirektør',),
'musédirektørene': ('musédirektør',),
'musédirektører': ('musédirektør',),
'muségjenstand': ('muségjenstand',),
'muségjenstanden': ('muségjenstand',),
'muségjenstandene': ('muségjenstand',),
'muségjenstander': ('muségjenstand',),
'muségjenstand': ('muségjenstand',),
'muségjenstanden': ('muségjenstand',),
'muségjenstandene': ('muségjenstand',),
'muségjenstander': ('muségjenstand',),
'musak': ('musak',),
'musaken': ('musak',),
'musakene': ('musak',),
'musaker': ('musak',),
'musbol': ('musbol',),
'musbola': ('musbol',),
'musbolene': ('musbol',),
'musbolet': ('musbol',),
'musbøla': ('musbøle',),
'musbøle': ('musbøle',),
'musbølene': ('musbøle',),
'musbøler': ('musbøle',),
'musbølet': ('musbøle',),
'muse': ('muse',),
'musen': ('muse',),
'musene': ('muse',),
'muser': ('muse',),
'musebol': ('musebol',),
'musebola': ('musebol',),
'musebolene': ('musebol',),
'musebolet': ('musebol',),
'musebøla': ('musebøle',),
'musebøle': ('musebøle',),
'musebølene': ('musebøle',),
'musebøler': ('musebøle',),
'musebølet': ('musebøle',),
'museert': ('museert',),
'museerta': ('museert',),
'museerten': ('museert',),
'museertene': ('museert',),
'museerter': ('museert',),
'musefamilie': ('musefamilie',),
'musefamilien': ('musefamilie',),
'musefamiliene': ('musefamilie',),
'musefamilier': ('musefamilie',),
'musefella': ('musefelle',),
'musefelle': ('musefelle',),
'musefellen': ('musefelle',),
'musefellene': ('musefelle',),
'musefeller': ('musefelle',),
'musefletta': ('museflette',),
'museflette': ('museflette',),
'musefletten': ('museflette',),
'museflettene': ('museflette',),
'musefletter': ('museflette',),
'musehol': ('musehol',),
'musehola': ('musehol',),
'museholene': ('musehol',),
'museholet': ('musehol',),
'musehull': ('musehull',),
'musehulla': ('musehull',),
'musehullene': ('musehull',),
'musehuller': ('musehull',),
'musehullet': ('musehull',),
'muselman': ('muselman',),
'muselmanen': ('muselman',),
'muselmanene': ('muselman',),
'muselmaner': ('muselman',),
'muselmann': ('muselmann',),
'muselmannen': ('muselmann',),
'muselmenn': ('muselmann',),
'muselmennene': ('muselmann',),
'muselort': ('muselort',),
'muselorten': ('muselort',),
'muselortene': ('muselort',),
'muselorter': ('muselort',),
'musereda': ('muserede',),
'muserede': ('muserede',),
'museredene': ('muserede',),
'musereder': ('muserede',),
'museredet': ('muserede',),
'musereir': ('musereir',),
'musereira': ('musereir',),
'musereirene': ('musereir',),
'musereiret': ('musereir',),
'musert': ('musert',),
'muserta': ('musert',),
'muserten': ('musert',),
'musertene': ('musert',),
'muserter': ('musert',),
'musette': ('musette',),
'musetten': ('musette',),
'musettene': ('musette',),
'musetter': ('musette',),
'musetteorkester': ('musetteorkester',),
'musetteorkesteret': ('musetteorkester',),
'musetteorkestra': ('musetteorkester',),
'musetteorkestre': ('musetteorkester',),
'musetteorkestrene': ('musetteorkester',),
'musetteorkestret': ('musetteorkester',),
'musettetrekkspell': ('musettetrekkspell',),
'musettetrekkspella': ('musettetrekkspell',),
'musettetrekkspellene': ('musettetrekkspell',),
'musettetrekkspellet': ('musettetrekkspell',),
'musettetrekkspill': ('musettetrekkspill',),
'musettetrekkspilla': ('musettetrekkspill',),
'musettetrekkspillene': ('musettetrekkspill',),
'musettetrekkspillet': ('musettetrekkspill',),
'musea': ('museum',),
'museene': ('museum',),
'museer': ('museum',),
'museet': ('museum',),
'museum': ('museum',),
'musea': ('museum',),
'museene': ('museum',),
'museer': ('museum',),
'museet': ('museum',),
'museum': ('museum',),
'museumsbygning': ('museumsbygning',),
'museumsbygninga': ('museumsbygning',),
'museumsbygningen': ('museumsbygning',),
'museumsbygningene': ('museumsbygning',),
'museumsbygninger': ('museumsbygning',),
'museumsbygning': ('museumsbygning',),
'museumsbygninga': ('museumsbygning',),
'museumsbygningen': ('museumsbygning',),
'museumsbygningene': ('museumsbygning',),
'museumsbygninger': ('museumsbygning',),
'museumsdirektør': ('museumsdirektør',),
'museumsdirektøren': ('museumsdirektør',),
'museumsdirektørene': ('museumsdirektør',),
'museumsdirektører': ('museumsdirektør',),
'museumsdirektør': ('museumsdirektør',),
'museumsdirektøren': ('museumsdirektør',),
'museumsdirektørene': ('museumsdirektør',),
'museumsdirektører': ('museumsdirektør',),
'museumsgjenstand': ('museumsgjenstand',),
'museumsgjenstanden': ('museumsgjenstand',),
'museumsgjenstandene': ('museumsgjenstand',),
'museumsgjenstander': ('museumsgjenstand',),
'museumsgjenstand': ('museumsgjenstand',),
'museumsgjenstanden': ('museumsgjenstand',),
'museumsgjenstandene': ('museumsgjenstand',),
'museumsgjenstander': ('museumsgjenstand',),
'museunge': ('museunge',),
'museungen': ('museunge',),
'museungene': ('museunge',),
'museunger': ('museunge',),
'musikal': ('musikal',),
'musikalen': ('musikal',),
'musikalene': ('musikal',),
'musikaler': ('musikal',),
'musikaliene': ('musikalier',),
'musikalier': ('musikalier',),
'musikalitet': ('musikalitet',),
'musikaliteten': ('musikalitet',),
'musikalitetene': ('musikalitet',),
'musikaliteter': ('musikalitet',),
'musikant': ('musikant',),
'musikanten': ('musikant',),
'musikantene': ('musikant',),
'musikanter': ('musikant',),
'musiker': ('musiker',),
'musikere': ('musiker',),
'musikeren': ('musiker',),
'musikerer': ('musiker',),
'musikerne': ('musiker',),
'musikk': ('musikk',),
'musikken': ('musikk',),
'musikkene': ('musikk',),
'musikker': ('musikk',),
'musikk-konservatoria': ('musikk-konservatorium',),
'musikk-konservatoriene': ('musikk-konservatorium',),
'musikk-konservatorier': ('musikk-konservatorium',),
'musikk-konservatoriet': ('musikk-konservatorium',),
'musikk-konservatorium': ('musikk-konservatorium',),
'musikk-korps': ('musikk-korps',),
'musikk-korpsa': ('musikk-korps',),
'musikk-korpsene': ('musikk-korps',),
'musikk-korpset': ('musikk-korps',),
'musikkanmelder': ('musikkanmelder',),
'musikkanmeldere': ('musikkanmelder',),
'musikkanmelderen': ('musikkanmelder',),
'musikkanmelderer': ('musikkanmelder',),
'musikkanmelderne': ('musikkanmelder',),
'musikkhistoria': ('musikkhistorie',),
'musikkhistorie': ('musikkhistorie',),
'musikkhistorien': ('musikkhistorie',),
'musikkhistoriene': ('musikkhistorie',),
'musikkhistorier': ('musikkhistorie',),
'musikkinstrument': ('musikkinstrument',),
'musikkinstrumenta': ('musikkinstrument',),
'musikkinstrumentene': ('musikkinstrument',),
'musikkinstrumenter': ('musikkinstrument',),
'musikkinstrumentet': ('musikkinstrument',),
'musikklinja': ('musikklinje',),
'musikklinje': ('musikklinje',),
'musikklinjen': ('musikklinje',),
'musikklinjene': ('musikklinje',),
'musikklinjer': ('musikklinje',),
'musikklærer': ('musikklærer',),
'musikklærere': ('musikklærer',),
'musikklæreren': ('musikklærer',),
'musikklærerer': ('musikklærer',),
'musikklærerne': ('musikklærer',),
'musikkonservatoria': ('musikkonservatorium',),
'musikkonservatoriene': ('musikkonservatorium',),
'musikkonservatorier': ('musikkonservatorium',),
'musikkonservatoriet': ('musikkonservatorium',),
'musikkonservatorium': ('musikkonservatorium',),
'musikkorps': ('musikkorps',),
'musikkorpsa': ('musikkorps',),
'musikkorpsene': ('musikkorps',),
'musikkorpset': ('musikkorps',),
'musikkpedagog': ('musikkpedagog',),
'musikkpedagogen': ('musikkpedagog',),
'musikkpedagogene': ('musikkpedagog',),
'musikkpedagoger': ('musikkpedagog',),
'musikkskole': ('musikkskole',),
'musikkskolen': ('musikkskole',),
'musikkskolene': ('musikkskole',),
'musikkskoler': ('musikkskole',),
'musikkspell': ('musikkspell',),
'musikkspella': ('musikkspell',),
'musikkspellene': ('musikkspell',),
'musikkspellet': ('musikkspell',),
'musikkspill': ('musikkspill',),
'musikkspilla': ('musikkspill',),
'musikkspillene': ('musikkspill',),
'musikkspillet': ('musikkspill',),
'musikkstykka': ('musikkstykke',),
'musikkstykke': ('musikkstykke',),
'musikkstykkene': ('musikkstykke',),
'musikkstykker': ('musikkstykke',),
'musikkstykket': ('musikkstykke',),
'musikkteori': ('musikkteori',),
'musikkteorien': ('musikkteori',),
'musikkteoriene': ('musikkteori',),
'musikkteorier': ('musikkteori',),
'musikkterapeut': ('musikkterapeut',),
'musikkterapeuten': ('musikkterapeut',),
'musikkterapeutene': ('musikkterapeut',),
'musikkterapeuter': ('musikkterapeut',),
'musikkterapi': ('musikkterapi',),
'musikkterapien': ('musikkterapi',),
'musikkterapiene': ('musikkterapi',),
'musikkterapier': ('musikkterapi',),
'musikkvitenskap': ('musikkvitenskap',),
'musikkvitenskapen': ('musikkvitenskap',),
'musikkvitenskapene': ('musikkvitenskap',),
'musikkvitenskaper': ('musikkvitenskap',),
'musikkvitskap': ('musikkvitskap',),
'musikkvitskapen': ('musikkvitskap',),
'musikkvitskapene': ('musikkvitskap',),
'musikkvitskaper': ('musikkvitskap',),
'musikkøra': ('musikkøre',),
'musikkøre': ('musikkøre',),
'musikkørene': ('musikkøre',),
'musikkører': ('musikkøre',),
'musikkøret': ('musikkøre',),
'musikolog': ('musikolog',),
'musikologen': ('musikolog',),
'musikologene': ('musikolog',),
'musikologer': ('musikolog',),
'musikologi': ('musikologi',),
'musikologien': ('musikologi',),
'musikologiene': ('musikologi',),
'musikologier': ('musikologi',),
'muskat': ('muskat',),
'muskaten': ('muskat',),
'muskatene': ('muskat',),
'muskater': ('muskat',),
'muskatblomme': ('muskatblomme',),
'muskatblommen': ('muskatblomme',),
'muskatblommene': ('muskatblomme',),
'muskatblommer': ('muskatblomme',),
'muskatell': ('muskatell',),
'muskatellen': ('muskatell',),
'muskatellene': ('muskatell',),
'muskateller': ('muskatell',),
'muskatelldrua': ('muskatelldrue',),
'muskatelldrue': ('muskatelldrue',),
'muskatelldruen': ('muskatelldrue',),
'muskatelldruene': ('muskatelldrue',),
'muskatelldruer': ('muskatelldrue',),
'muskateller': ('muskateller',),
'muskatellere': ('muskateller',),
'muskatelleren': ('muskateller',),
'muskatellerer': ('muskateller',),
'muskatellerne': ('muskateller',),
'muskatellerdrua': ('muskatellerdrue',),
'muskatellerdrue': ('muskatellerdrue',),
'muskatellerdruen': ('muskatellerdrue',),
'muskatellerdruene': ('muskatellerdrue',),
'muskatellerdruer': ('muskatellerdrue',),
'muskatellervin': ('muskatellervin',),
'muskatellervinen': ('muskatellervin',),
'muskatellervinene': ('muskatellervin',),
'muskatellerviner': ('muskatellervin',),
'muskatellvin': ('muskatellvin',),
'muskatellvinen': ('muskatellvin',),
'muskatellvinene': ('muskatellvin',),
'muskatellviner': ('muskatellvin',),
'muskatnøtt': ('muskatnøtt',),
'muskatnøtta': ('muskatnøtt',),
'muskatnøtten': ('muskatnøtt',),
'muskatnøttene': ('muskatnøtt',),
'muskatnøtter': ('muskatnøtt',),
'muskatnøtt-tre': ('muskatnøtt-tre',),
'muskatnøtt-trea': ('muskatnøtt-tre',),
'muskatnøtt-treet': ('muskatnøtt-tre',),
'muskatnøtt-trær': ('muskatnøtt-tre',),
'muskatnøtt-trærne': ('muskatnøtt-tre',),
'muskatnøttre': ('muskatnøttre',),
'muskatnøttrea': ('muskatnøttre',),
'muskatnøttreet': ('muskatnøttre',),
'muskatnøttrær': ('muskatnøttre',),
'muskatnøttrærne': ('muskatnøttre',),
'muskedunder': ('muskedunder',),
'muskedundere': ('muskedunder',),
'muskedunderen': ('muskedunder',),
'muskedunderer': ('muskedunder',),
'muskedunderne': ('muskedunder',),
'muskedundra': ('muskedundre',),
'muskedundre': ('muskedundre',),
'muskedundren': ('muskedundre',),
'muskedundrene': ('muskedundre',),
'muskedundrer': ('muskedundre',),
'muskel': ('muskel',),
'muskelen': ('muskel',),
'musklene': ('muskel',),
'muskler': ('muskel',),
'muskelbunt': ('muskelbunt',),
'muskelbunten': ('muskelbunt',),
'muskelbuntene': ('muskelbunt',),
'muskelbunter': ('muskelbunt',),
'muskelcella': ('muskelcelle',),
'muskelcelle': ('muskelcelle',),
'muskelcellen': ('muskelcelle',),
'muskelcellene': ('muskelcelle',),
'muskelceller': ('muskelcelle',),
'muskelfiber': ('muskelfiber',),
'muskelfibere': ('muskelfiber',),
'muskelfiberen': ('muskelfiber',),
'muskelfiberne': ('muskelfiber',),
'muskelfibre': ('muskelfiber',),
'muskelfibrene': ('muskelfiber',),
'muskelfibrer': ('muskelfiber',),
'muskelkraft': ('muskelkraft',),
'muskelkrafta': ('muskelkraft',),
'muskelkraften': ('muskelkraft',),
'muskelkreftene': ('muskelkraft',),
'muskelkrefter': ('muskelkraft',),
'muskelmann': ('muskelmann',),
'muskelmannen': ('muskelmann',),
'muskelmenn': ('muskelmann',),
'muskelmennene': ('muskelmann',),
'muskelsmerte': ('muskelsmerte',),
'muskelsmerten': ('muskelsmerte',),
'muskelsmertene': ('muskelsmerte',),
'muskelsmerter': ('muskelsmerte',),
'muskelstyrke': ('muskelstyrke',),
'muskelstyrken': ('muskelstyrke',),
'muskelstyrkene': ('muskelstyrke',),
'muskelstyrker': ('muskelstyrke',),
'muskelsvinn': ('muskelsvinn',),
'muskelsvinna': ('muskelsvinn',),
'muskelsvinnene': ('muskelsvinn',),
'muskelsvinnet': ('muskelsvinn',),
'muskelvev': ('muskelvev',),
'muskelveva': ('muskelvev',),
'muskelvevene': ('muskelvev',),
'muskelvevet': ('muskelvev',),
'musketer': ('musketer',),
'musketeren': ('musketer',),
'musketerene': ('musketer',),
'musketerer': ('musketer',),
'muskett': ('muskett',),
'musketten': ('muskett',),
'muskettene': ('muskett',),
'musketter': ('muskett',),
'muskulatur': ('muskulatur',),
'muskulaturen': ('muskulatur',),
'muskulaturene': ('muskulatur',),
'muskulaturer': ('muskulatur',),
'muslim': ('muslim',),
'muslimen': ('muslim',),
'muslimene': ('muslim',),
'muslimer': ('muslim',),
'muslimisme': ('muslimisme',),
'muslimismen': ('muslimisme',),
'muslimismene': ('muslimisme',),
'muslimismer': ('muslimisme',),
'musling': ('musling',),
'muslingen': ('musling',),
'muslingene': ('musling',),
'muslinger': ('musling',),
'mussa': ('musse',),
'musse': ('musse',),
'mussen': ('musse',),
'mussene': ('musse',),
'musser': ('musse',),
'mussefiska': ('mussefiske',),
'mussefiske': ('mussefiske',),
'mussefiskene': ('mussefiske',),
'mussefisker': ('mussefiske',),
'mussefisket': ('mussefiske',),
'musselin': ('musselin',),
'musselina': ('musselin',),
'musselinen': ('musselin',),
'musselinene': ('musselin',),
'musseliner': ('musselin',),
'musselinet': ('musselin',),
'musserong': ('musserong',),
'musserongen': ('musserong',),
'musserongene': ('musserong',),
'musseronger': ('musserong',),
'mustang': ('mustang',),
'mustangen': ('mustang',),
'mustangene': ('mustang',),
'mustanger': ('mustang',),
'mustasje': ('mustasje',),
'mustasjen': ('mustasje',),
'mustasjene': ('mustasje',),
'mustasjer': ('mustasje',),
'musunge': ('musunge',),
'musungen': ('musunge',),
'musungene': ('musunge',),
'musunger': ('musunge',),
'musvåk': ('musvåk',),
'musvåken': ('musvåk',),
'musvåkene': ('musvåk',),
'musvåker': ('musvåk',),
'mutagen': ('mutagen',),
'mutagena': ('mutagen',),
'mutagenene': ('mutagen',),
'mutagener': ('mutagen',),
'mutagenet': ('mutagen',),
'mutant': ('mutant',),
'mutanten': ('mutant',),
'mutantene': ('mutant',),
'mutanter': ('mutant',),
'mutasjon': ('mutasjon',),
'mutasjonen': ('mutasjon',),
'mutasjonene': ('mutasjon',),
'mutasjoner': ('mutasjon',),
'muta': ('mute',),
'mute': ('mute',),
'muten': ('mute',),
'mutene': ('mute',),
'muter': ('mute',),
'mutingsbrev': ('mutingsbrev',),
'mutingsbreva': ('mutingsbrev',),
'mutingsbrevene': ('mutingsbrev',),
'mutingsbrever': ('mutingsbrev',),
'mutingsbrevet': ('mutingsbrev',),
'mutt': ('mutt',),
'mutten': ('mutt',),
'muttene': ('mutt',),
'mutter': ('mutt',),
'mutrene': ('mutter',),
'mutrer': ('mutter',),
'mutter': ('mutter',),
'muttere': ('mutter',),
'mutteren': ('mutter',),
'mutterer': ('mutter',),
'mutterne': ('mutter',),
'mutrene': ('mutter',),
'mutrer': ('mutter',),
'mutter': ('mutter',),
'muttere': ('mutter',),
'mutteren': ('mutter',),
'mutterer': ('mutter',),
'mutterne': ('mutter',),
'my': ('my',),
'myen': ('my',),
'myene': ('my',),
'myer': ('my',),
'myalgi': ('myalgi',),
'myalgien': ('myalgi',),
'myalgiene': ('myalgi',),
'myalgier': ('myalgi',),
'myanmarer': ('myanmarer',),
'myanmarere': ('myanmarer',),
'myanmareren': ('myanmarer',),
'myanmarerer': ('myanmarer',),
'myanmarerne': ('myanmarer',),
'mygg': ('mygg',),
'myggen': ('mygg',),
'myggene': ('mygg',),
'myggbitt': ('myggbitt',),
'myggbitta': ('myggbitt',),
'myggbittene': ('myggbitt',),
'myggbittet': ('myggbitt',),
'myggestikk': ('myggestikk',),
'myggestikka': ('myggestikk',),
'myggestikkene': ('myggestikk',),
'myggestikket': ('myggestikk',),
'myggesverm': ('myggesverm',),
'myggesvermen': ('myggesverm',),
'myggesvermene': ('myggesverm',),
'myggesvermer': ('myggesverm',),
'myggnett': ('myggnett',),
'myggnetta': ('myggnett',),
'myggnettene': ('myggnett',),
'myggnettet': ('myggnett',),
'myggolja': ('myggolje',),
'myggolje': ('myggolje',),
'myggoljen': ('myggolje',),
'myggoljene': ('myggolje',),
'myggoljer': ('myggolje',),
'myggstift': ('myggstift',),
'myggstiften': ('myggstift',),
'myggstiftene': ('myggstift',),
'myggstifter': ('myggstift',),
'myggstikk': ('myggstikk',),
'myggstikka': ('myggstikk',),
'myggstikkene': ('myggstikk',),
'myggstikket': ('myggstikk',),
'myggsverm': ('myggsverm',),
'myggsvermen': ('myggsverm',),
'myggsvermene': ('myggsverm',),
'myggsvermer': ('myggsverm',),
'mygl': ('mygl',),
'mygla': ('mygl',),
'myglene': ('mygl',),
'myglet': ('mygl',),
'myhank': ('myhank',),
'myhanken': ('myhank',),
'myhankene': ('myhank',),
'myhanker': ('myhank',),
'myka': ('myke',),
'myke': ('myke',),
'myken': ('myke',),
'mykene': ('myke',),
'myker': ('myke',),
'mykis': ('mykis',),
'mykisen': ('mykis',),
'mykisene': ('mykis',),
'mykiser': ('mykis',),
'myklanding': ('myklanding',),
'myklandinga': ('myklanding',),
'myklandingen': ('myklanding',),
'myklandingene': ('myklanding',),
'myklandinger': ('myklanding',),
'mykner': ('mykner',),
'myknere': ('mykner',),
'mykneren': ('mykner',),
'myknerer': ('mykner',),
'myknerne': ('mykner',),
'mykolog': ('mykolog',),
'mykologen': ('mykolog',),
'mykologene': ('mykolog',),
'mykologer': ('mykolog',),
'mykologi': ('mykologi',),
'mykologien': ('mykologi',),
'mykologiene': ('mykologi',),
'mykologier': ('mykologi',),
'mykplast': ('mykplast',),
'mykplasten': ('mykplast',),
'mykplastene': ('mykplast',),
'mykplaster': ('mykplast',),
'myksødem': ('myksødem',),
'myksødema': ('myksødem',),
'myksødemene': ('myksødem',),
'myksødemer': ('myksødem',),
'myksødemet': ('myksødem',),
'mylder': ('mylder',),
'mylderet': ('mylder',),
'myldra': ('mylder',),
'myldre': ('mylder',),
'myldrene': ('mylder',),
'myldret': ('mylder',),
'myldretid': ('myldretid',),
'myldretida': ('myldretid',),
'myldretiden': ('myldretid',),
'myldretidene': ('myldretid',),
'myldretider': ('myldretid',),
'mynde': ('mynde',),
'mynden': ('mynde',),
'myndene': ('mynde',),
'mynder': ('mynde',),
'myndighet': ('myndighet',),
'myndigheta': ('myndighet',),
'myndigheten': ('myndighet',),
'myndighetene': ('myndighet',),
'myndigheter': ('myndighet',),
'myndighetsalder': ('myndighetsalder',),
'myndighetsaldere': ('myndighetsalder',),
'myndighetsalderen': ('myndighetsalder',),
'myndighetsalderer': ('myndighetsalder',),
'myndighetsalderne': ('myndighetsalder',),
'myndighetsaldre': ('myndighetsalder',),
'myndighetsaldrene': ('myndighetsalder',),
'myndighetsaldrer': ('myndighetsalder',),
'myndling': ('myndling',),
'myndlingen': ('myndling',),
'myndlingene': ('myndling',),
'myndlinger': ('myndling',),
'mynt': ('mynt',),
'mynten': ('mynt',),
'myntene': ('mynt',),
'mynter': ('mynt',),
'myntapparat': ('myntapparat',),
'myntapparata': ('myntapparat',),
'myntapparatene': ('myntapparat',),
'myntapparater': ('myntapparat',),
'myntapparatet': ('myntapparat',),
'mynta': ('mynte',),
'mynte': ('mynte',),
'mynten': ('mynte',),
'myntene': ('mynte',),
'mynter': ('mynte',),
'myntenhet': ('myntenhet',),
'myntenheten': ('myntenhet',),
'myntenhetene': ('myntenhet',),
'myntenheter': ('myntenhet',),
'myntgravør': ('myntgravør',),
'myntgravøren': ('myntgravør',),
'myntgravørene': ('myntgravør',),
'myntgravører': ('myntgravør',),
'mynting': ('mynting',),
'myntinga': ('mynting',),
'myntingen': ('mynting',),
'myntingene': ('mynting',),
'myntinger': ('mynting',),
'myntkabinett': ('myntkabinett',),
'myntkabinetta': ('myntkabinett',),
'myntkabinettene': ('myntkabinett',),
'myntkabinetter': ('myntkabinett',),
'myntkabinettet': ('myntkabinett',),
'myntkonvensjon': ('myntkonvensjon',),
'myntkonvensjonen': ('myntkonvensjon',),
'myntkonvensjonene': ('myntkonvensjon',),
'myntkonvensjoner': ('myntkonvensjon',),
'myntsamler': ('myntsamler',),
'myntsamlere': ('myntsamler',),
'myntsamleren': ('myntsamler',),
'myntsamlerer': ('myntsamler',),
'myntsamlerne': ('myntsamler',),
'myntsamling': ('myntsamling',),
'myntsamlinga': ('myntsamling',),
'myntsamlingen': ('myntsamling',),
'myntsamlingene': ('myntsamling',),
'myntsamlinger': ('myntsamling',),
'myntunion': ('myntunion',),
'myntunionen': ('myntunion',),
'myntunionene': ('myntunion',),
'myntunioner': ('myntunion',),
'myntvesen': ('myntvesen',),
'myntvesena': ('myntvesen',),
'myntvesenene': ('myntvesen',),
'myntvesener': ('myntvesen',),
'myntvesenet': ('myntvesen',),
'myntvitenskap': ('myntvitenskap',),
'myntvitenskapen': ('myntvitenskap',),
'myntvitenskapene': ('myntvitenskap',),
'myntvitenskaper': ('myntvitenskap',),
'myntvitskap': ('myntvitskap',),
'myntvitskapen': ('myntvitskap',),
'myntvitskapene': ('myntvitskap',),
'myntvitskaper': ('myntvitskap',),
'myon': ('myon',),
'myona': ('myon',),
'myonene': ('myon',),
'myoner': ('myon',),
'myonet': ('myon',),
'myopi': ('myopi',),
'myopien': ('myopi',),
'myopiene': ('myopi',),
'myopier': ('myopi',),
'myose': ('myose',),
'myosen': ('myose',),
'myosene': ('myose',),
'myoser': ('myose',),
'myr': ('myr',),
'myra': ('myr',),
'myren': ('myr',),
'myrene': ('myr',),
'myrer': ('myr',),
'myrderi': ('myrderi',),
'myrderia': ('myrderi',),
'myrderiene': ('myrderi',),
'myrderier': ('myrderi',),
'myrderiet': ('myrderi',),
'myrdrag': ('myrdrag',),
'myrdraga': ('myrdrag',),
'myrdragene': ('myrdrag',),
'myrdraget': ('myrdrag',),
'myrdun': ('myrdun',),
'myrduna': ('myrdun',),
'myrdunen': ('myrdun',),
'myrdunene': ('myrdun',),
'myrdunet': ('myrdun',),
'myrfivel': ('myrfivel',),
'myrfivelen': ('myrfivel',),
'myrfivlene': ('myrfivel',),
'myrfivler': ('myrfivel',),
'myrhatt': ('myrhatt',),
'myrhatten': ('myrhatt',),
'myrhattene': ('myrhatt',),
'myrhatter': ('myrhatt',),
'myrhol': ('myrhol',),
'myrhola': ('myrhol',),
'myrholene': ('myrhol',),
'myrholet': ('myrhol',),
'myrhull': ('myrhull',),
'myrhulla': ('myrhull',),
'myrhullene': ('myrhull',),
'myrhuller': ('myrhull',),
'myrhullet': ('myrhull',),
'myriade': ('myriade',),
'myriaden': ('myriade',),
'myriadene': ('myriade',),
'myriader': ('myriade',),
'myrjern': ('myrjern',),
'myrjerna': ('myrjern',),
'myrjernene': ('myrjern',),
'myrjernet': ('myrjern',),
'myrlenda': ('myrlende',),
'myrlende': ('myrlende',),
'myrlendene': ('myrlende',),
'myrlender': ('myrlende',),
'myrlendet': ('myrlende',),
'myrmalm': ('myrmalm',),
'myrmalmen': ('myrmalm',),
'myrmalmene': ('myrmalm',),
'myrmalmer': ('myrmalm',),
'myrplanta': ('myrplante',),
'myrplante': ('myrplante',),
'myrplanten': ('myrplante',),
'myrplantene': ('myrplante',),
'myrplanter': ('myrplante',),
'myrra': ('myrra',),
'myrraen': ('myrra',),
'myrraene': ('myrra',),
'myrraer': ('myrra',),
'myrselskap': ('myrselskap',),
'myrselskapa': ('myrselskap',),
'myrselskapene': ('myrselskap',),
'myrselskaper': ('myrselskap',),
'myrselskapet': ('myrselskap',),
'myrsig': ('myrsig',),
'myrsiga': ('myrsig',),
'myrsigene': ('myrsig',),
'myrsiget': ('myrsig',),
'myrsnipa': ('myrsnipe',),
'myrsnipe': ('myrsnipe',),
'myrsnipen': ('myrsnipe',),
'myrsnipene': ('myrsnipe',),
'myrsniper': ('myrsnipe',),
'myrt': ('myrt',),
'myrten': ('myrt',),
'myrtene': ('myrt',),
'myrter': ('myrt',),
'myrte': ('myrte',),
'myrten': ('myrte',),
'myrtene': ('myrte',),
'myrter': ('myrte',),
'myrtekrans': ('myrtekrans',),
'myrtekransen': ('myrtekrans',),
'myrtekransene': ('myrtekrans',),
'myrtekranser': ('myrtekrans',),
'myrull': ('myrull',),
'myrulla': ('myrull',),
'myrullen': ('myrull',),
'myrullene': ('myrull',),
'myruller': ('myrull',),
'mysa': ('myse',),
'myse': ('myse',),
'mysen': ('myse',),
'mysene': ('myse',),
'myser': ('myse',),
'myseprim': ('myseprim',),
'myseprima': ('myseprim',),
'myseprimen': ('myseprim',),
'myseprimene': ('myseprim',),
'myseprimer': ('myseprim',),
'myseprimet': ('myseprim',),
'myska': ('myske',),
'myske': ('myske',),
'mysken': ('myske',),
'myskene': ('myske',),
'mysker': ('myske',),
'mysli': ('mysli',),
'myslien': ('mysli',),
'mysliene': ('mysli',),
'myslier': ('mysli',),
'mysost': ('mysost',),
'mysosten': ('mysost',),
'mysostene': ('mysost',),
'mysoster': ('mysost',),
'myssmør': ('myssmør',),
'myssmøra': ('myssmør',),
'myssmørene': ('myssmør',),
'myssmøret': ('myssmør',),
'mysteriereligion': ('mysteriereligion',),
'mysteriereligionen': ('mysteriereligion',),
'mysteriereligionene': ('mysteriereligion',),
'mysteriereligioner': ('mysteriereligion',),
'mysteriespell': ('mysteriespell',),
'mysteriespella': ('mysteriespell',),
'mysteriespellene': ('mysteriespell',),
'mysteriespellet': ('mysteriespell',),
'mysteriespill': ('mysteriespill',),
'mysteriespilla': ('mysteriespill',),
'mysteriespillene': ('mysteriespill',),
'mysteriespillet': ('mysteriespill',),
'mysteria': ('mysterium',),
'mysteriene': ('mysterium',),
'mysterier': ('mysterium',),
'mysteriet': ('mysterium',),
'mysterium': ('mysterium',),
'mystifikasjon': ('mystifikasjon',),
'mystifikasjonen': ('mystifikasjon',),
'mystifikasjonene': ('mystifikasjon',),
'mystifikasjoner': ('mystifikasjon',),
'mystifisering': ('mystifisering',),
'mystifiseringa': ('mystifisering',),
'mystifiseringen': ('mystifisering',),
'mystifiseringene': ('mystifisering',),
'mystifiseringer': ('mystifisering',),
'mystiker': ('mystiker',),
'mystikere': ('mystiker',),
'mystikeren': ('mystiker',),
'mystikerer': ('mystiker',),
'mystikerne': ('mystiker',),
'mystikk': ('mystikk',),
'mystikken': ('mystikk',),
'mystikkene': ('mystikk',),
'mystikker': ('mystikk',),
'mystisisme': ('mystisisme',),
'mystisismen': ('mystisisme',),
'mystisismene': ('mystisisme',),
'mystisismer': ('mystisisme',),
'myte': ('myte',),
'myten': ('myte',),
'mytene': ('myte',),
'myter': ('myte',),
'mytedannelse': ('mytedannelse',),
'mytedannelsen': ('mytedannelse',),
'mytedannelsene': ('mytedannelse',),
'mytedannelser': ('mytedannelse',),
'mytedanning': ('mytedanning',),
'mytedanninga': ('mytedanning',),
'mytedanningen': ('mytedanning',),
'mytedanningene': ('mytedanning',),
'mytedanninger': ('mytedanning',),
'mytolog': ('mytolog',),
'mytologen': ('mytolog',),
'mytologene': ('mytolog',),
'mytologer': ('mytolog',),
'mytologi': ('mytologi',),
'mytologien': ('mytologi',),
'mytologiene': ('mytologi',),
'mytologier': ('mytologi',),
'mytteri': ('mytteri',),
'mytteria': ('mytteri',),
'mytteriene': ('mytteri',),
'mytterier': ('mytteri',),
'mytteriet': ('mytteri',),
'mytteriforsøk': ('mytteriforsøk',),
'mytteriforsøka': ('mytteriforsøk',),
'mytteriforsøkene': ('mytteriforsøk',),
'mytteriforsøket': ('mytteriforsøk',),
'mytterist': ('mytterist',),
'mytteristen': ('mytterist',),
'mytteristene': ('mytterist',),
'mytterister': ('mytterist',),
'måfå': ('måfå',),
'måg': ('måg',),
'mågen': ('måg',),
'mågene': ('måg',),
'måger': ('måg',),
'mågskap': ('mågskap',),
'mågskapen': ('mågskap',),
'mågskapene': ('mågskap',),
'mågskaper': ('mågskap',),
'måke': ('måke',),
'måken': ('måke',),
'måkene': ('måke',),
'måker': ('måke',),
'måka': ('måke',),
'måke': ('måke',),
'måken': ('måke',),
'måkene': ('måke',),
'måker': ('måke',),
'måka': ('måke',),
'måke': ('måke',),
'måken': ('måke',),
'måkene': ('måke',),
'måker': ('måke',),
'måkeegg': ('måkeegg',),
'måkeegga': ('måkeegg',),
'måkeeggene': ('måkeegg',),
'måkeegget': ('måkeegg',),
'måkeegg': ('måkeegg',),
'måkeegga': ('måkeegg',),
'måkeeggene': ('måkeegg',),
'måkeegget': ('måkeegg',),
'måkefugl': ('måkefugl',),
'måkefuglen': ('måkefugl',),
'måkefuglene': ('måkefugl',),
'måkefugler': ('måkefugl',),
'måkefugl': ('måkefugl',),
'måkefuglen': ('måkefugl',),
'måkefuglene': ('måkefugl',),
'måkefugler': ('måkefugl',),
'måker': ('måker',),
'måkere': ('måker',),
'måkeren': ('måker',),
'måkerer': ('måker',),
'måkerne': ('måker',),
'mål': ('mål',),
'måla': ('mål',),
'målene': ('mål',),
'målet': ('mål',),
'mål': ('mål',),
'måla': ('mål',),
'målene': ('mål',),
'målet': ('mål',),
'målbruk': ('målbruk',),
'målbruka': ('målbruk',),
'målbruken': ('målbruk',),
'målbrukene': ('målbruk',),
'målbruker': ('målbruk',),
'målbruket': ('målbruk',),
'måldyrking': ('måldyrking',),
'måldyrkinga': ('måldyrking',),
'måldyrkingen': ('måldyrking',),
'måldyrkingene': ('måldyrking',),
'måldyrkinger': ('måldyrking',),
'måleapparat': ('måleapparat',),
'måleapparata': ('måleapparat',),
'måleapparatene': ('måleapparat',),
'måleapparater': ('måleapparat',),
'måleapparatet': ('måleapparat',),
'måleband': ('måleband',),
'målebanda': ('måleband',),
'målebandene': ('måleband',),
'målebandet': ('måleband',),
'målebånd': ('målebånd',),
'målebånda': ('målebånd',),
'målebåndene': ('målebånd',),
'målebåndet': ('målebånd',),
'måleenhet': ('måleenhet',),
'måleenheten': ('måleenhet',),
'måleenhetene': ('måleenhet',),
'måleenheter': ('måleenhet',),
'måleinstrument': ('måleinstrument',),
'måleinstrumenta': ('måleinstrument',),
'måleinstrumentene': ('måleinstrument',),
'måleinstrumenter': ('måleinstrument',),
'måleinstrumentet': ('måleinstrument',),
'målemna': ('målemne',),
'målemne': ('målemne',),
'målemnene': ('målemne',),
'målemner': ('målemne',),
'målemnet': ('målemne',),
'målenhet': ('målenhet',),
'målenheten': ('målenhet',),
'målenhetene': ('målenhet',),
'målenheter': ('målenhet',),
'måler': ('måler',),
'målere': ('måler',),
'måleren': ('måler',),
'målerer': ('måler',),
'målerne': ('måler',),
'målestokk': ('målestokk',),
'målestokken': ('målestokk',),
'målestokkene': ('målestokk',),
'målestokker': ('målestokk',),
'målesystem': ('målesystem',),
'målesystema': ('målesystem',),
'målesystemene': ('målesystem',),
'målesystemer': ('målesystem',),
'målesystemet': ('målesystem',),
'måletal': ('måletal',),
'måletala': ('måletal',),
'måletalene': ('måletal',),
'måletalet': ('måletal',),
'måletall': ('måletall',),
'måletalla': ('måletall',),
'måletallene': ('måletall',),
'måletallet': ('måletall',),
'målfest': ('målfest',),
'målfesten': ('målfest',),
'målfestene': ('målfest',),
'målfester': ('målfest',),
'målfolk': ('målfolk',),
'målfolka': ('målfolk',),
'målfolkene': ('målfolk',),
'målfolket': ('målfolk',),
'målform': ('målform',),
'målforma': ('målform',),
'målformen': ('målform',),
'målformene': ('målform',),
'målformer': ('målform',),
'målforskjell': ('målforskjell',),
'målforskjellen': ('målforskjell',),
'målforskjellene': ('målforskjell',),
'målforskjeller': ('målforskjell',),
'målfoto': ('målfoto',),
'målfotoa': ('målfoto',),
'målfotoene': ('målfoto',),
'målfotoer': ('målfoto',),
'målfotoet': ('målfoto',),
'målføra': ('målføre',),
'målføre': ('målføre',),
'målførene': ('målføre',),
'målfører': ('målføre',),
'målføret': ('målføre',),
'målføregransker': ('målføregransker',),
'målføregranskere': ('målføregransker',),
'målføregranskeren': ('målføregransker',),
'målføregranskerer': ('målføregransker',),
'målføregranskerne': ('målføregransker',),
'målføregransking': ('målføregransking',),
'målføregranskinga': ('målføregransking',),
'målføregranskingen': ('målføregransking',),
'målføregranskingene': ('målføregransking',),
'målføregranskinger': ('målføregransking',),
'målgruppa': ('målgruppe',),
'målgruppe': ('målgruppe',),
'målgruppen': ('målgruppe',),
'målgruppene': ('målgruppe',),
'målgrupper': ('målgruppe',),
'måling': ('måling',),
'målinga': ('måling',),
'målingen': ('måling',),
'målingene': ('måling',),
'målinger': ('måling',),
'mållag': ('mållag',),
'mållaga': ('mållag',),
'mållagene': ('mållag',),
'mållaget': ('mållag',),
'mållinja': ('mållinje',),
'mållinje': ('mållinje',),
'mållinjen': ('mållinje',),
'mållinjene': ('mållinje',),
'mållinjer': ('mållinje',),
'målmann': ('målmann',),
'målmannen': ('målmann',),
'målmenn': ('målmann',),
'målmennene': ('målmann',),
'målmann': ('målmann',),
'målmannen': ('målmann',),
'målmenn': ('målmann',),
'målmennene': ('målmann',),
'målreising': ('målreising',),
'målreisinga': ('målreising',),
'målreisingen': ('målreising',),
'målreisingene': ('målreising',),
'målreisinger': ('målreising',),
'målrøkt': ('målrøkt',),
'målrøkta': ('målrøkt',),
'målrøkten': ('målrøkt',),
'målrøktene': ('målrøkt',),
'målrøkter': ('målrøkt',),
'målrørsla': ('målrørsle',),
'målrørsle': ('målrørsle',),
'målrørslen': ('målrørsle',),
'målrørslene': ('målrørsle',),
'målrørsler': ('målrørsle',),
'målsak': ('målsak',),
'målsaka': ('målsak',),
'målsaken': ('målsak',),
'målsakene': ('målsak',),
'målsaker': ('målsak',),
'målscorer': ('målscorer',),
'målscorere': ('målscorer',),
'målscoreren': ('målscorer',),
'målscorerer': ('målscorer',),
'målscorerne': ('målscorer',),
'målsetting': ('målsetting',),
'målsettinga': ('målsetting',),
'målsettingen': ('målsetting',),
'målsettingene': ('målsetting',),
'målsettinger': ('målsetting',),
'målskårer': ('målskårer',),
'målskårere': ('målskårer',),
'målskåreren': ('målskårer',),
'målskårerer': ('målskårer',),
'målskårerne': ('målskårer',),
'målsmann': ('målsmann',),
'målsmannen': ('målsmann',),
'målsmenn': ('målsmann',),
'målsmennene': ('målsmann',),
'målspråk': ('målspråk',),
'målspråka': ('målspråk',),
'målspråkene': ('målspråk',),
'målspråket': ('målspråk',),
'målstrek': ('målstrek',),
'målstreken': ('målstrek',),
'målstrekene': ('målstrek',),
'målstreker': ('målstrek',),
'målstrev': ('målstrev',),
'målstreva': ('målstrev',),
'målstrevene': ('målstrev',),
'målstrevet': ('målstrev',),
'målstrever': ('målstrever',),
'målstrevere': ('målstrever',),
'målstreveren': ('målstrever',),
'målstreverer': ('målstrever',),
'målstreverne': ('målstrever',),
'målstrid': ('målstrid',),
'målstriden': ('målstrid',),
'målstridene': ('målstrid',),
'målstrider': ('målstrid',),
'målsystem': ('målsystem',),
'målsystema': ('målsystem',),
'målsystemene': ('målsystem',),
'målsystemer': ('målsystem',),
'målsystemet': ('målsystem',),
'målsøker': ('målsøker',),
'målsøkere': ('målsøker',),
'målsøkeren': ('målsøker',),
'målsøkerer': ('målsøker',),
'målsøkerne': ('målsøker',),
'måltal': ('måltal',),
'måltala': ('måltal',),
'måltalene': ('måltal',),
'måltalet': ('måltal',),
'måltall': ('måltall',),
'måltalla': ('måltall',),
'måltallene': ('måltall',),
'måltallet': ('måltall',),
'måltid': ('måltid',),
'måltida': ('måltid',),
'måltidene': ('måltid',),
'måltider': ('måltid',),
'måltidet': ('måltid',),
'måltrast': ('måltrast',),
'måltrasten': ('måltrast',),
'måltrastene': ('måltrast',),
'måltraster': ('måltrast',),
'måltrost': ('måltrost',),
'måltrosten': ('måltrost',),
'måltrostene': ('måltrost',),
'måltroster': ('måltrost',),
'målvakt': ('målvakt',),
'målvakta': ('målvakt',),
'målvakten': ('målvakt',),
'målvaktene': ('målvakt',),
'målvakter': ('målvakt',),
'målvokter': ('målvokter',),
'målvoktere': ('målvokter',),
'målvokteren': ('målvokter',),
'målvokterer': ('målvokter',),
'målvokterne': ('målvokter',),
'måne': ('måne',),
'månen': ('måne',),
'månene': ('måne',),
'måner': ('måne',),
'måneansikt': ('måneansikt',),
'måneansikta': ('måneansikt',),
'måneansiktene': ('måneansikt',),
'måneansikter': ('måneansikt',),
'måneansiktet': ('måneansikt',),
'måned': ('måned',),
'måneden': ('måned',),
'månedene': ('måned',),
'måneder': ('måned',),
'månedsbillett': ('månedsbillett',),
'månedsbilletten': ('månedsbillett',),
'månedsbillettene': ('månedsbillett',),
'månedsbilletter': ('månedsbillett',),
'månedskort': ('månedskort',),
'månedskorta': ('månedskort',),
'månedskortene': ('månedskort',),
'månedskortet': ('månedskort',),
'månedslov': ('månedslov',),
'månedslønn': ('månedslønn',),
'månedslønna': ('månedslønn',),
'månedslønnen': ('månedslønn',),
'månedslønnene': ('månedslønn',),
'månedslønner': ('månedslønn',),
'månedsskifta': ('månedsskifte',),
'månedsskifte': ('månedsskifte',),
'månedsskiftene': ('månedsskifte',),
'månedsskifter': ('månedsskifte',),
'månedsskiftet': ('månedsskifte',),
'månefarer': ('månefarer',),
'månefarere': ('månefarer',),
'månefareren': ('månefarer',),
'månefarerer': ('månefarer',),
'månefarerne': ('månefarer',),
'månefartøy': ('månefartøy',),
'månefartøya': ('månefartøy',),
'månefartøyene': ('månefartøy',),
'månefartøyer': ('månefartøy',),
'månefartøyet': ('månefartøy',),
'månefase': ('månefase',),
'månefasen': ('månefase',),
'månefasene': ('månefase',),
'månefaser': ('månefase',),
'månefisk': ('månefisk',),
'månefisken': ('månefisk',),
'månefiskene': ('månefisk',),
'månefisker': ('månefisk',),
'månefjes': ('månefjes',),
'månefjesa': ('månefjes',),
'månefjesene': ('månefjes',),
'månefjeset': ('månefjes',),
'måneformørkelse': ('måneformørkelse',),
'måneformørkelsen': ('måneformørkelse',),
'måneformørkelsene': ('måneformørkelse',),
'måneformørkelser': ('måneformørkelse',),
'månelanding': ('månelanding',),
'månelandinga': ('månelanding',),
'månelandingen': ('månelanding',),
'månelandingene': ('månelanding',),
'månelandinger': ('månelanding',),
'månelandingsfartøy': ('månelandingsfartøy',),
'månelandingsfartøya': ('månelandingsfartøy',),
'månelandingsfartøyene': ('månelandingsfartøy',),
'månelandingsfartøyer': ('månelandingsfartøy',),
'månelandingsfartøyet': ('månelandingsfartøy',),
'månelys': ('månelys',),
'månelysa': ('månelys',),
'månelysene': ('månelys',),
'månelyset': ('månelys',),
'månelys': ('månelys',),
'månelysa': ('månelys',),
'månelysene': ('månelys',),
'månelyset': ('månelys',),
'månemørka': ('månemørke',),
'månemørke': ('månemørke',),
'månemørkene': ('månemørke',),
'månemørker': ('månemørke',),
'månemørket': ('månemørke',),
'månerakett': ('månerakett',),
'måneraketten': ('månerakett',),
'månerakettene': ('månerakett',),
'måneraketter': ('månerakett',),
'månesigd': ('månesigd',),
'månesigden': ('månesigd',),
'månesigdene': ('månesigd',),
'månesigder': ('månesigd',),
'månesjuka': ('månesjuke',),
'månesjuke': ('månesjuke',),
'månesjuken': ('månesjuke',),
'månesjukene': ('månesjuke',),
'månesjuker': ('månesjuke',),
'måneskalk': ('måneskalk',),
'måneskalken': ('måneskalk',),
'måneskalkene': ('måneskalk',),
'måneskalker': ('måneskalk',),
'måneskifta': ('måneskifte',),
'måneskifte': ('måneskifte',),
'måneskiftene': ('måneskifte',),
'måneskifter': ('måneskifte',),
'måneskiftet': ('måneskifte',),
'måneskinn': ('måneskinn',),
'måneskinna': ('måneskinn',),
'måneskinnene': ('måneskinn',),
'måneskinnet': ('måneskinn',),
'måneskinnslampa': ('måneskinnslampe',),
'måneskinnslampe': ('måneskinnslampe',),
'måneskinnslampen': ('måneskinnslampe',),
'måneskinnslampene': ('måneskinnslampe',),
'måneskinnslamper': ('måneskinnslampe',),
'måneskinnstur': ('måneskinnstur',),
'måneskinnsturen': ('måneskinnstur',),
'måneskinnsturene': ('måneskinnstur',),
'måneskinnsturer': ('måneskinnstur',),
'månestein': ('månestein',),
'månesteinen': ('månestein',),
'månesteinene': ('månestein',),
'månesteiner': ('månestein',),
'månesyka': ('månesyke',),
'månesyke': ('månesyke',),
'månesyken': ('månesyke',),
'månesykene': ('månesyke',),
'månesyker': ('månesyke',),
'måneår': ('måneår',),
'måneåra': ('måneår',),
'måneårene': ('måneår',),
'måneåret': ('måneår',),
'månsing': ('månsing',),
'månsingen': ('månsing',),
'månsingene': ('månsing',),
'månsinger': ('månsing',),
'mår': ('mår',),
'måren': ('mår',),
'mårene': ('mår',),
'mårer': ('mår',),
'mårdyr': ('mårdyr',),
'mårdyra': ('mårdyr',),
'mårdyrene': ('mårdyr',),
'mårdyret': ('mårdyr',),
'mårfamilie': ('mårfamilie',),
'mårfamilien': ('mårfamilie',),
'mårfamiliene': ('mårfamilie',),
'mårfamilier': ('mårfamilie',),
'mårskinn': ('mårskinn',),
'mårskinna': ('mårskinn',),
'mårskinnene': ('mårskinn',),
'mårskinnet': ('mårskinn',),
'måse': ('måse',),
'måsen': ('måse',),
'måsene': ('måse',),
'måser': ('måse',),
'måse': ('måse',),
'måsen': ('måse',),
'måsene': ('måse',),
'måser': ('måse',),
'måseegg': ('måseegg',),
'måseegga': ('måseegg',),
'måseeggene': ('måseegg',),
'måseegget': ('måseegg',),
'måseegg': ('måseegg',),
'måseegga': ('måseegg',),
'måseeggene': ('måseegg',),
'måseegget': ('måseegg',),
'måsefugl': ('måsefugl',),
'måsefuglen': ('måsefugl',),
'måsefuglene': ('måsefugl',),
'måsefugler': ('måsefugl',),
'måsefugl': ('måsefugl',),
'måsefuglen': ('måsefugl',),
'måsefuglene': ('måsefugl',),
'måsefugler': ('måsefugl',),
'måte': ('måte',),
'måten': ('måte',),
'måtene': ('måte',),
'måter': ('måte',),
'måtehold': ('måtehold',),
'måteholda': ('måtehold',),
'måteholdene': ('måtehold',),
'måteholdet': ('måtehold',),
'måteholdsfolk': ('måteholdsfolk',),
'måteholdsfolka': ('måteholdsfolk',),
'måteholdsfolkene': ('måteholdsfolk',),
'måteholdsfolket': ('måteholdsfolk',),
'måteholdsmann': ('måteholdsmann',),
'måteholdsmannen': ('måteholdsmann',),
'måteholdsmenn': ('måteholdsmann',),
'måteholdsmennene': ('måteholdsmann',),
'måtelig': ('måtelig',),
'måteligen': ('måtelig',),
'måteligene': ('måtelig',),
'måteliger': ('måtelig',),
'måtesadverb': ('måtesadverb',),
'måtesadverba': ('måtesadverb',),
'måtesadverbene': ('måtesadverb',),
'måtesadverber': ('måtesadverb',),
'måtesadverbet': ('måtesadverb',),
'måtesadverbia': ('måtesadverbium',),
'måtesadverbiene': ('måtesadverbium',),
'måtesadverbier': ('måtesadverbium',),
'måtesadverbiet': ('måtesadverbium',),
'måtesadverbium': ('måtesadverbium',),
'mædi': ('mædi',),
'mædien': ('mædi',),
'mædiene': ('mædi',),
'mædier': ('mædi',),
'mæle': ('mæle',),
'mælen': ('mæle',),
'mælene': ('mæle',),
'mæler': ('mæle',),
'mæla': ('mæle',),
'mæle': ('mæle',),
'mælene': ('mæle',),
'mæler': ('mæle',),
'mælet': ('mæle',),
'mæling': ('mæling',),
'mælingen': ('mæling',),
'mælingene': ('mæling',),
'mælinger': ('mæling',),
'mæling': ('mæling',),
'mælinga': ('mæling',),
'mælingen': ('mæling',),
'mælingene': ('mæling',),
'mælinger': ('mæling',),
'mø': ('mø',),
'møa': ('mø',),
'møene': ('mø',),
'møet': ('mø',),
'møbel': ('møbel',),
'møbelet': ('møbel',),
'møbla': ('møbel',),
'møblene': ('møbel',),
'møbler': ('møbel',),
'møblet': ('møbel',),
'møbelfabrikk': ('møbelfabrikk',),
'møbelfabrikken': ('møbelfabrikk',),
'møbelfabrikkene': ('møbelfabrikk',),
'møbelfabrikker': ('møbelfabrikk',),
'møbelforretning': ('møbelforretning',),
'møbelforretninga': ('møbelforretning',),
'møbelforretningen': ('møbelforretning',),
'møbelforretningene': ('møbelforretning',),
'møbelforretninger': ('møbelforretning',),
'møbelplata': ('møbelplate',),
'møbelplate': ('møbelplate',),
'møbelplaten': ('møbelplate',),
'møbelplatene': ('møbelplate',),
'møbelplater': ('møbelplate',),
'møbelpolitur': ('møbelpolitur',),
'møbelpolituren': ('møbelpolitur',),
'møbelpoliturene': ('møbelpolitur',),
'møbelpoliturer': ('møbelpolitur',),
'møbelsnekker': ('møbelsnekker',),
'møbelsnekkere': ('møbelsnekker',),
'møbelsnekkeren': ('møbelsnekker',),
'møbelsnekkerer': ('møbelsnekker',),
'møbelsnekkerne': ('møbelsnekker',),
'møbeltapetserer': ('møbeltapetserer',),
'møbeltapetserere': ('møbeltapetserer',),
'møbeltapetsereren': ('møbeltapetserer',),
'møbeltapetsererer': ('møbeltapetserer',),
'møbeltapetsererne': ('møbeltapetserer',),
'møblement': ('møblement',),
'møblementa': ('møblement',),
'møblementene': ('møblement',),
'møblementer': ('møblement',),
'møblementet': ('møblement',),
'mødding': ('mødding',),
'møddingen': ('mødding',),
'møddingene': ('mødding',),
'møddinger': ('mødding',),
'møda': ('møde',),
'møde': ('møde',),
'møden': ('møde',),
'mødene': ('møde',),
'møder': ('møde',),
'mødom': ('mødom',),
'mødommen': ('mødom',),
'mødommene': ('mødom',),
'mødommer': ('mødom',),
'mødreheim': ('mødreheim',),
'mødreheimen': ('mødreheim',),
'mødreheimene': ('mødreheim',),
'mødreheimer': ('mødreheim',),
'mødrehjem': ('mødrehjem',),
'mødrehjemma': ('mødrehjem',),
'mødrehjemmene': ('mødrehjem',),
'mødrehjemmet': ('mødrehjem',),
'mødrehygienekontor': ('mødrehygienekontor',),
'mødrehygienekontora': ('mødrehygienekontor',),
'mødrehygienekontorene': ('mødrehygienekontor',),
'mødrehygienekontorer': ('mødrehygienekontor',),
'mødrehygienekontoret': ('mødrehygienekontor',),
'møkk': ('møkk',),
'møkka': ('møkk',),
'møkken': ('møkk',),
'møkkene': ('møkk',),
'møkker': ('møkk',),
'møkk-kjeller': ('møkk-kjeller',),
'møkk-kjellere': ('møkk-kjeller',),
'møkk-kjelleren': ('møkk-kjeller',),
'møkk-kjellerer': ('møkk-kjeller',),
'møkk-kjellerne': ('møkk-kjeller',),
'møkkavær': ('møkkavær',),
'møkkaværa': ('møkkavær',),
'møkkaværene': ('møkkavær',),
'møkkaværet': ('møkkavær',),
'møkkavær': ('møkkavær',),
'møkkaværa': ('møkkavær',),
'møkkaværene': ('møkkavær',),
'møkkaværet': ('møkkavær',),
'møkkdynga': ('møkkdynge',),
'møkkdynge': ('møkkdynge',),
'møkkdyngen': ('møkkdynge',),
'møkkdyngene': ('møkkdynge',),
'møkkdynger': ('møkkdynge',),
'møkkgreip': ('møkkgreip',),
'møkkgreipa': ('møkkgreip',),
'møkkgreipen': ('møkkgreip',),
'møkkgreipene': ('møkkgreip',),
'møkkgreiper': ('møkkgreip',),
'møkkgreipet': ('møkkgreip',),
'møkkjeller': ('møkkjeller',),
'møkkjellere': ('møkkjeller',),
'møkkjelleren': ('møkkjeller',),
'møkkjellerer': ('møkkjeller',),
'møkkjellerne': ('møkkjeller',),
'møkklass': ('møkklass',),
'møkklassa': ('møkklass',),
'møkklassene': ('møkklass',),
'møkklasset': ('møkklass',),
'møkkrenna': ('møkkrenne',),
'møkkrenne': ('møkkrenne',),
'møkkrennen': ('møkkrenne',),
'møkkrennene': ('møkkrenne',),
'møkkrenner': ('møkkrenne',),
'møkkslede': ('møkkslede',),
'møkksleden': ('møkkslede',),
'møkksledene': ('møkkslede',),
'møkksleder': ('møkkslede',),
'møl': ('møl',),
'møla': ('møl',),
'mølene': ('møl',),
'mølet': ('møl',),
'mølja': ('mølje',),
'mølje': ('mølje',),
'møljen': ('mølje',),
'møljene': ('mølje',),
'møljer': ('mølje',),
'møll': ('møll',),
'mølla': ('møll',),
'møllen': ('møll',),
'møllene': ('møll',),
'møllet': ('møll',),
'mølla': ('mølle',),
'mølle': ('mølle',),
'møllen': ('mølle',),
'møllene': ('mølle',),
'møller': ('mølle',),
'møllebruk': ('møllebruk',),
'møllebruka': ('møllebruk',),
'møllebrukene': ('møllebruk',),
'møllebruket': ('møllebruk',),
'mølledam': ('mølledam',),
'mølledammen': ('mølledam',),
'mølledammene': ('mølledam',),
'mølledammer': ('mølledam',),
'møllehjul': ('møllehjul',),
'møllehjula': ('møllehjul',),
'møllehjulene': ('møllehjul',),
'møllehjulet': ('møllehjul',),
'møller': ('møller',),
'møllere': ('møller',),
'mølleren': ('møller',),
'møllerer': ('møller',),
'møllerne': ('møller',),
'møllestein': ('møllestein',),
'møllesteinen': ('møllestein',),
'møllesteinene': ('møllestein',),
'møllesteiner': ('møllestein',),
'møllkula': ('møllkule',),
'møllkule': ('møllkule',),
'møllkulen': ('møllkule',),
'møllkulene': ('møllkule',),
'møllkuler': ('møllkule',),
'møllmiddel': ('møllmiddel',),
'møllmiddelet': ('møllmiddel',),
'møllmidla': ('møllmiddel',),
'møllmidlene': ('møllmiddel',),
'møllmidler': ('møllmiddel',),
'møllmidlet': ('møllmiddel',),
'møllpose': ('møllpose',),
'møllposen': ('møllpose',),
'møllposene': ('møllpose',),
'møllposer': ('møllpose',),
'møna': ('møne',),
'møne': ('møne',),
'mønene': ('møne',),
'møner': ('møne',),
'mønet': ('møne',),
'møneås': ('møneås',),
'møneåsen': ('møneås',),
'møneåsene': ('møneås',),
'møneåser': ('møneås',),
'mønja': ('mønje',),
'mønje': ('mønje',),
'mønjen': ('mønje',),
'mønjene': ('mønje',),
'mønjer': ('mønje',),
'mønster': ('mønster',),
'mønsteret': ('mønster',),
'mønstra': ('mønster',),
'mønstre': ('mønster',),
'mønstrene': ('mønster',),
'mønstret': ('mønster',),
'mønsterbeskyttelse': ('mønsterbeskyttelse',),
'mønsterbeskyttelsen': ('mønsterbeskyttelse',),
'mønsterbeskyttelsene': ('mønsterbeskyttelse',),
'mønsterbeskyttelser': ('mønsterbeskyttelse',),
'mønsterbruk': ('mønsterbruk',),
'mønsterbruka': ('mønsterbruk',),
'mønsterbrukene': ('mønsterbruk',),
'mønsterbruket': ('mønsterbruk',),
'mønsterdybde': ('mønsterdybde',),
'mønsterdybden': ('mønsterdybde',),
'mønsterdybdene': ('mønsterdybde',),
'mønsterdybder': ('mønsterdybde',),
'mønsterplan': ('mønsterplan',),
'mønsterplanen': ('mønsterplan',),
'mønsterplanene': ('mønsterplan',),
'mønsterplaner': ('mønsterplan',),
'mønsterrett': ('mønsterrett',),
'mønsterretten': ('mønsterrett',),
'mønsterrettene': ('mønsterrett',),
'mønsterretter': ('mønsterrett',),
'mønstring': ('mønstring',),
'mønstringa': ('mønstring',),
'mønstringen': ('mønstring',),
'mønstringene': ('mønstring',),
'mønstringer': ('mønstring',),
'mønstringskontor': ('mønstringskontor',),
'mønstringskontora': ('mønstringskontor',),
'mønstringskontorene': ('mønstringskontor',),
'mønstringskontorer': ('mønstringskontor',),
'mønstringskontoret': ('mønstringskontor',),
'mønstringsrenn': ('mønstringsrenn',),
'mønstringsrenna': ('mønstringsrenn',),
'mønstringsrennene': ('mønstringsrenn',),
'mønstringsrennet': ('mønstringsrenn',),
'mønsås': ('mønsås',),
'mønsåsen': ('mønsås',),
'mønsåsene': ('mønsås',),
'mønsåser': ('mønsås',),
'mørbrad': ('mørbrad',),
'mørbraden': ('mørbrad',),
'mørbradene': ('mørbrad',),
'mørbrader': ('mørbrad',),
'mørdeig': ('mørdeig',),
'mørdeigen': ('mørdeig',),
'mørdeigene': ('mørdeig',),
'mørdeiger': ('mørdeig',),
'møretorsk': ('møretorsk',),
'møretorsken': ('møretorsk',),
'møretorskene': ('møretorsk',),
'møretorsker': ('møretorsk',),
'møring': ('møring',),
'møringen': ('møring',),
'møringene': ('møring',),
'møringer': ('møring',),
'mørja': ('mørje',),
'mørje': ('mørje',),
'mørjen': ('mørje',),
'mørjene': ('mørje',),
'mørjer': ('mørje',),
'mørka': ('mørke',),
'mørke': ('mørke',),
'mørkene': ('mørke',),
'mørker': ('mørke',),
'mørket': ('mørke',),
'mørkekjøring': ('mørkekjøring',),
'mørkekjøringa': ('mørkekjøring',),
'mørkekjøringen': ('mørkekjøring',),
'mørkekjøringene': ('mørkekjøring',),
'mørkekjøringer': ('mørkekjøring',),
'mørkeloft': ('mørkeloft',),
'mørkelofta': ('mørkeloft',),
'mørkeloftene': ('mørkeloft',),
'mørkeloftet': ('mørkeloft',),
'mørkemakt': ('mørkemakt',),
'mørkemakta': ('mørkemakt',),
'mørkemakten': ('mørkemakt',),
'mørkemaktene': ('mørkemakt',),
'mørkemakter': ('mørkemakt',),
'mørkemann': ('mørkemann',),
'mørkemannen': ('mørkemann',),
'mørkemenn': ('mørkemann',),
'mørkemennene': ('mørkemann',),
'mørker': ('mørker',),
'mørkeret': ('mørker',),
'mørkra': ('mørker',),
'mørkre': ('mørker',),
'mørkrene': ('mørker',),
'mørkret': ('mørker',),
'mørkeredsel': ('mørkeredsel',),
'mørkeredselen': ('mørkeredsel',),
'mørkeredslene': ('mørkeredsel',),
'mørkeredsler': ('mørkeredsel',),
'mørkerom': ('mørkerom',),
'mørkeromma': ('mørkerom',),
'mørkerommene': ('mørkerom',),
'mørkerommet': ('mørkerom',),
'mørkeskodda': ('mørkeskodde',),
'mørkeskodde': ('mørkeskodde',),
'mørkeskodden': ('mørkeskodde',),
'mørkeskoddene': ('mørkeskodde',),
'mørkeskodder': ('mørkeskodde',),
'mørketal': ('mørketal',),
'mørketala': ('mørketal',),
'mørketalene': ('mørketal',),
'mørketalet': ('mørketal',),
'mørketall': ('mørketall',),
'mørketalla': ('mørketall',),
'mørketallene': ('mørketall',),
'mørketallet': ('mørketall',),
'mørketid': ('mørketid',),
'mørketida': ('mørketid',),
'mørketiden': ('mørketid',),
'mørketidene': ('mørketid',),
'mørketider': ('mørketid',),
'mørkning': ('mørkning',),
'mørkninga': ('mørkning',),
'mørkningen': ('mørkning',),
'mørkningene': ('mørkning',),
'mørkninger': ('mørkning',),
'mørtel': ('mørtel',),
'mørtelen': ('mørtel',),
'mørtlene': ('mørtel',),
'mørtler': ('mørtel',),
'møta': ('møte',),
'møte': ('møte',),
'møtene': ('møte',),
'møter': ('møte',),
'møtet': ('møte',),
'møteaksjon': ('møteaksjon',),
'møteaksjonen': ('møteaksjon',),
'møteaksjonene': ('møteaksjon',),
'møteaksjoner': ('møteaksjon',),
'møtedeltaker': ('møtedeltaker',),
'møtedeltakere': ('møtedeltaker',),
'møtedeltakeren': ('møtedeltaker',),
'møtedeltakerer': ('møtedeltaker',),
'møtedeltakerne': ('møtedeltaker',),
'møtelokala': ('møtelokale',),
'møtelokale': ('møtelokale',),
'møtelokalene': ('møtelokale',),
'møtelokaler': ('møtelokale',),
'møtelokalet': ('møtelokale',),
'møteplager': ('møteplager',),
'møteplagere': ('møteplager',),
'møteplageren': ('møteplager',),
'møteplagerer': ('møteplager',),
'møteplagerne': ('møteplager',),
'møteplass': ('møteplass',),
'møteplassen': ('møteplass',),
'møteplassene': ('møteplass',),
'møteplasser': ('møteplass',),
'møteplikt': ('møteplikt',),
'møteplikta': ('møteplikt',),
'møteplikten': ('møteplikt',),
'møtepliktene': ('møteplikt',),
'møteplikter': ('møteplikt',),
'møteprogram': ('møteprogram',),
'møteprogramma': ('møteprogram',),
'møteprogrammene': ('møteprogram',),
'møteprogrammer': ('møteprogram',),
'møteprogrammet': ('møteprogram',),
'møteprotokoll': ('møteprotokoll',),
'møteprotokollen': ('møteprotokoll',),
'møteprotokollene': ('møteprotokoll',),
'møteprotokoller': ('møteprotokoll',),
'møtereferat': ('møtereferat',),
'møtereferata': ('møtereferat',),
'møtereferatene': ('møtereferat',),
'møtereferater': ('møtereferat',),
'møtereferatet': ('møtereferat',),
'møterom': ('møterom',),
'møteromma': ('møterom',),
'møterommene': ('møterom',),
'møterommet': ('møterom',),
'møtested': ('møtested',),
'møtestedene': ('møtested',),
'møtesteder': ('møtested',),
'møtestedet': ('møtested',),
'møtetid': ('møtetid',),
'møtetida': ('møtetid',),
'møtetiden': ('møtetid',),
'møtetidene': ('møtetid',),
'møtetider': ('møtetid',),
'møteuka': ('møteuke',),
'møteuke': ('møteuke',),
'møteuken': ('møteuke',),
'møteukene': ('møteuke',),
'møteuker': ('møteuke',),
'møteveka': ('møteveke',),
'møteveke': ('møteveke',),
'møteveken': ('møteveke',),
'møtevekene': ('møteveke',),
'møteveker': ('møteveke',),
'møtrik': ('møtrik',),
'møtriken': ('møtrik',),
'møtrikene': ('møtrik',),
'møtriker': ('møtrik',),
'møy': ('møy',),
'møya': ('møy',),
'møyen': ('møy',),
'møyene': ('møy',),
'møyer': ('møy',),
'møydom': ('møydom',),
'møydommen': ('møydom',),
'møydommene': ('møydom',),
'møydommer': ('møydom',),
'møya': ('møye',),
'møye': ('møye',),
'møyen': ('møye',),
'møyene': ('møye',),
'møyer': ('møye',),
'n': ('n',),
'n\'en': ('n',),
'n-en': ('n',),
'n-ene': ('n',),
'n-er': ('n',),
'nabb': ('nabb',),
'nabben': ('nabb',),
'nabbene': ('nabb',),
'nabber': ('nabb',),
'nabbe': ('nabbe',),
'nabben': ('nabbe',),
'nabbene': ('nabbe',),
'nabber': ('nabbe',),
'nabo': ('nabo',),
'naboen': ('nabo',),
'naboene': ('nabo',),
'naboer': ('nabo',),
'nabob': ('nabob',),
'naboben': ('nabob',),
'nabobene': ('nabob',),
'nabober': ('nabob',),
'naboby': ('naboby',),
'nabobyen': ('naboby',),
'nabobyene': ('naboby',),
'nabobyer': ('naboby',),
'nabokommune': ('nabokommune',),
'nabokommunen': ('nabokommune',),
'nabokommunene': ('nabokommune',),
'nabokommuner': ('nabokommune',),
'nabolag': ('nabolag',),
'nabolaga': ('nabolag',),
'nabolagene': ('nabolag',),
'nabolaget': ('nabolag',),
'naboland': ('naboland',),
'nabolanda': ('naboland',),
'nabolandene': ('naboland',),
'nabolandet': ('naboland',),
'nabosamvirka': ('nabosamvirke',),
'nabosamvirke': ('nabosamvirke',),
'nabosamvirkene': ('nabosamvirke',),
'nabosamvirker': ('nabosamvirke',),
'nabosamvirket': ('nabosamvirke',),
'naboskap': ('naboskap',),
'naboskapa': ('naboskap',),
'naboskapene': ('naboskap',),
'naboskapet': ('naboskap',),
'nabovinkel': ('nabovinkel',),
'nabovinkelen': ('nabovinkel',),
'nabovinklene': ('nabovinkel',),
'nabovinkler': ('nabovinkel',),
'nachspiel': ('nachspiel',),
'nachspiela': ('nachspiel',),
'nachspielene': ('nachspiel',),
'nachspielet': ('nachspiel',),
'nadd': ('nadd',),
'nadden': ('nadd',),
'naddene': ('nadd',),
'nadder': ('nadd',),
'nadir': ('nadir',),
'nadira': ('nadir',),
'nadirene': ('nadir',),
'nadiret': ('nadir',),
'nafta': ('nafta',),
'naftaen': ('nafta',),
'naftaene': ('nafta',),
'naftaer': ('nafta',),
'naftalen': ('naftalen',),
'naftalena': ('naftalen',),
'naftalenene': ('naftalen',),
'naftalenet': ('naftalen',),
'nag': ('nag',),
'naga': ('nag',),
'nagene': ('nag',),
'naget': ('nag',),
'naganasjuka': ('naganasjuke',),
'naganasjuke': ('naganasjuke',),
'naganasjuken': ('naganasjuke',),
'naganasjukene': ('naganasjuke',),
'naganasjuker': ('naganasjuke',),
'naganasyka': ('naganasyke',),
'naganasyke': ('naganasyke',),
'naganasyken': ('naganasyke',),
'naganasykene': ('naganasyke',),
'naganasyker': ('naganasyke',),
'nagle': ('nagle',),
'naglen': ('nagle',),
'naglene': ('nagle',),
'nagler': ('nagle',),
'naglemerka': ('naglemerke',),
'naglemerke': ('naglemerke',),
'naglemerkene': ('naglemerke',),
'naglemerker': ('naglemerke',),
'naglemerket': ('naglemerke',),
'naivisme': ('naivisme',),
'naivismen': ('naivisme',),
'naivismene': ('naivisme',),
'naivismer': ('naivisme',),
'naivist': ('naivist',),
'naivisten': ('naivist',),
'naivistene': ('naivist',),
'naivister': ('naivist',),
'naivitet': ('naivitet',),
'naiviteten': ('naivitet',),
'naivitetene': ('naivitet',),
'naiviteter': ('naivitet',),
'najada': ('najade',),
'najade': ('najade',),
'najaden': ('najade',),
'najadene': ('najade',),
'najader': ('najade',),
'nakenbader': ('nakenbader',),
'nakenbadere': ('nakenbader',),
'nakenbaderen': ('nakenbader',),
'nakenbaderer': ('nakenbader',),
'nakenbaderne': ('nakenbader',),
'nakenbading': ('nakenbading',),
'nakenbadinga': ('nakenbading',),
'nakenbadingen': ('nakenbading',),
'nakenbadingene': ('nakenbading',),
'nakenbadinger': ('nakenbading',),
'nakenfrøing': ('nakenfrøing',),
'nakenfrøingen': ('nakenfrøing',),
'nakenfrøingene': ('nakenfrøing',),
'nakenfrøinger': ('nakenfrøing',),
'nakenkultur': ('nakenkultur',),
'nakenkulturen': ('nakenkultur',),
'nakenkulturene': ('nakenkultur',),
'nakenkulturer': ('nakenkultur',),
'nakenscene': ('nakenscene',),
'nakenscenen': ('nakenscene',),
'nakenscenene': ('nakenscene',),
'nakenscener': ('nakenscene',),
'nakke': ('nakke',),
'nakken': ('nakke',),
'nakkene': ('nakke',),
'nakker': ('nakke',),
'nakkebær': ('nakkebær',),
'nakkebæra': ('nakkebær',),
'nakkebærene': ('nakkebær',),
'nakkebæret': ('nakkebær',),
'nakkedrag': ('nakkedrag',),
'nakkedraga': ('nakkedrag',),
'nakkedragene': ('nakkedrag',),
'nakkedraget': ('nakkedrag',),
'nakkegrop': ('nakkegrop',),
'nakkegropa': ('nakkegrop',),
'nakkegropen': ('nakkegrop',),
'nakkegropene': ('nakkegrop',),
'nakkegroper': ('nakkegrop',),
'nakkekotelett': ('nakkekotelett',),
'nakkekoteletten': ('nakkekotelett',),
'nakkekotelettene': ('nakkekotelett',),
'nakkekoteletter': ('nakkekotelett',),
'nakkeskinn': ('nakkeskinn',),
'nakkeskinna': ('nakkeskinn',),
'nakkeskinnene': ('nakkeskinn',),
'nakkeskinnet': ('nakkeskinn',),
'nakkeskott': ('nakkeskott',),
'nakkeskotta': ('nakkeskott',),
'nakkeskottene': ('nakkeskott',),
'nakkeskottet': ('nakkeskott',),
'nakkeskudd': ('nakkeskudd',),
'nakkeskudda': ('nakkeskudd',),
'nakkeskuddene': ('nakkeskudd',),
'nakkeskuddet': ('nakkeskudd',),
'nakkesleng': ('nakkesleng',),
'nakkeslengen': ('nakkesleng',),
'nakkeslengene': ('nakkesleng',),
'nakkeslenger': ('nakkesleng',),
'nakkeslengskade': ('nakkeslengskade',),
'nakkeslengskaden': ('nakkeslengskade',),
'nakkeslengskadene': ('nakkeslengskade',),
'nakkeslengskader': ('nakkeslengskade',),
'nakkestuss': ('nakkestuss',),
'nakkestussen': ('nakkestuss',),
'nakkestussene': ('nakkestuss',),
'nakkestusser': ('nakkestuss',),
'nakkestøtta': ('nakkestøtte',),
'nakkestøtte': ('nakkestøtte',),
'nakkestøtten': ('nakkestøtte',),
'nakkestøttene': ('nakkestøtte',),
'nakkestøtter': ('nakkestøtte',),
'nal': ('nal',),
'nalen': ('nal',),
'nalene': ('nal',),
'naler': ('nal',),
'namdaling': ('namdaling',),
'namdalingen': ('namdaling',),
'namdalingene': ('namdaling',),
'namdalinger': ('namdaling',),
'namibier': ('namibier',),
'namibiere': ('namibier',),
'namibieren': ('namibier',),
'namibierer': ('namibier',),
'namibierne': ('namibier',),
'namsmann': ('namsmann',),
'namsmannen': ('namsmann',),
'namsmenn': ('namsmann',),
'namsmennene': ('namsmann',),
'namsmyndighet': ('namsmyndighet',),
'namsmyndigheta': ('namsmyndighet',),
'namsmyndigheten': ('namsmyndighet',),
'namsmyndighetene': ('namsmyndighet',),
'namsmyndigheter': ('namsmyndighet',),
'namsrett': ('namsrett',),
'namsretten': ('namsrett',),
'namsrettene': ('namsrett',),
'namsretter': ('namsrett',),
'nanisme': ('nanisme',),
'nanismen': ('nanisme',),
'nanismene': ('nanisme',),
'nanismer': ('nanisme',),
'nanking': ('nanking',),
'nankinga': ('nanking',),
'nankingen': ('nanking',),
'nankingene': ('nanking',),
'nankinger': ('nanking',),
'nankinget': ('nanking',),
'nanometer': ('nanometer',),
'nanometeren': ('nanometer',),
'nanometerne': ('nanometer',),
'nanosekund': ('nanosekund',),
'nanosekunda': ('nanosekund',),
'nanosekundene': ('nanosekund',),
'nanosekunder': ('nanosekund',),
'nanosekundet': ('nanosekund',),
'nansenpass': ('nansenpass',),
'nansenpassa': ('nansenpass',),
'nansenpassene': ('nansenpass',),
'nansenpasset': ('nansenpass',),
'napalm': ('napalm',),
'napalmen': ('napalm',),
'napalmene': ('napalm',),
'napalmer': ('napalm',),
'napalmbomba': ('napalmbombe',),
'napalmbombe': ('napalmbombe',),
'napalmbomben': ('napalmbombe',),
'napalmbombene': ('napalmbombe',),
'napalmbomber': ('napalmbombe',),
'napoleonskaka': ('napoleonskake',),
'napoleonskake': ('napoleonskake',),
'napoleonskaken': ('napoleonskake',),
'napoleonskakene': ('napoleonskake',),
'napoleonskaker': ('napoleonskake',),
'napolitaner': ('napolitaner',),
'napolitanere': ('napolitaner',),
'napolitaneren': ('napolitaner',),
'napolitanerer': ('napolitaner',),
'napolitanerne': ('napolitaner',),
'napp': ('napp',),
'nappa': ('napp',),
'nappene': ('napp',),
'nappet': ('napp',),
'napp': ('napp',),
'nappa': ('napp',),
'nappene': ('napp',),
'nappet': ('napp',),
'nappa': ('nappa',),
'nappaen': ('nappa',),
'nappaene': ('nappa',),
'nappaer': ('nappa',),
'nappajakka': ('nappajakke',),
'nappajakke': ('nappajakke',),
'nappajakken': ('nappajakke',),
'nappajakkene': ('nappajakke',),
'nappajakker': ('nappajakke',),
'nappaskinn': ('nappaskinn',),
'nappaskinna': ('nappaskinn',),
'nappaskinnene': ('nappaskinn',),
'nappaskinnet': ('nappaskinn',),
'nappetak': ('nappetak',),
'nappetaka': ('nappetak',),
'nappetakene': ('nappetak',),
'nappetaket': ('nappetak',),
'napping': ('napping',),
'nappinga': ('napping',),
'nappingen': ('napping',),
'nappingene': ('napping',),
'nappinger': ('napping',),
'narde': ('narde',),
'narden': ('narde',),
'nardene': ('narde',),
'narder': ('narde',),
'nardus': ('nardus',),
'nardusen': ('nardus',),
'nardusene': ('nardus',),
'narduser': ('nardus',),
'nardussalva': ('nardussalve',),
'nardussalve': ('nardussalve',),
'nardussalven': ('nardussalve',),
'nardussalvene': ('nardussalve',),
'nardussalver': ('nardussalve',),
'narhval': ('narhval',),
'narhvalen': ('narhval',),
'narhvalene': ('narhval',),
'narhvaler': ('narhval',),
'narkoman': ('narkoman',),
'narkomanen': ('narkoman',),
'narkomanene': ('narkoman',),
'narkomaner': ('narkoman',),
'narkomani': ('narkomani',),
'narkomanien': ('narkomani',),
'narkomaniene': ('narkomani',),
'narkomanier': ('narkomani',),
'narkose': ('narkose',),
'narkosen': ('narkose',),
'narkosene': ('narkose',),
'narkoser': ('narkose',),
'narkotika': ('narkotika',),
'narkotikaen': ('narkotika',),
'narkotikaene': ('narkotika',),
'narkotikaer': ('narkotika',),
'narkotikahai': ('narkotikahai',),
'narkotikahaien': ('narkotikahai',),
'narkotikahaiene': ('narkotikahai',),
'narkotikahaier': ('narkotikahai',),
'narkotikahund': ('narkotikahund',),
'narkotikahunden': ('narkotikahund',),
'narkotikahundene': ('narkotikahund',),
'narkotikahunder': ('narkotikahund',),
'narkotikamiljø': ('narkotikamiljø',),
'narkotikamiljøa': ('narkotikamiljø',),
'narkotikamiljøene': ('narkotikamiljø',),
'narkotikamiljøer': ('narkotikamiljø',),
'narkotikamiljøet': ('narkotikamiljø',),
'narkotikamisbruk': ('narkotikamisbruk',),
'narkotikamisbruka': ('narkotikamisbruk',),
'narkotikamisbruken': ('narkotikamisbruk',),
'narkotikamisbrukene': ('narkotikamisbruk',),
'narkotikamisbruker': ('narkotikamisbruk',),
'narkotikamisbruket': ('narkotikamisbruk',),
'narkotikapoliti': ('narkotikapoliti',),
'narkotikapolitia': ('narkotikapoliti',),
'narkotikapolitiene': ('narkotikapoliti',),
'narkotikapolitier': ('narkotikapoliti',),
'narkotikapolitiet': ('narkotikapoliti',),
'narkotikareda': ('narkotikarede',),
'narkotikarede': ('narkotikarede',),
'narkotikaredene': ('narkotikarede',),
'narkotikareder': ('narkotikarede',),
'narkotikaredet': ('narkotikarede',),
'narkotikareir': ('narkotikareir',),
'narkotikareira': ('narkotikareir',),
'narkotikareirene': ('narkotikareir',),
'narkotikareiret': ('narkotikareir',),
'narkotikasmugling': ('narkotikasmugling',),
'narkotikasmuglinga': ('narkotikasmugling',),
'narkotikasmuglingen': ('narkotikasmugling',),
'narkotikasmuglingene': ('narkotikasmugling',),
'narkotikasmuglinger': ('narkotikasmugling',),
'narkotikavrak': ('narkotikavrak',),
'narkotikavraka': ('narkotikavrak',),
'narkotikavrakene': ('narkotikavrak',),
'narkotikavraket': ('narkotikavrak',),
'narkotiker': ('narkotiker',),
'narkotikere': ('narkotiker',),
'narkotikeren': ('narkotiker',),
'narkotikerer': ('narkotiker',),
'narkotikerne': ('narkotiker',),
'narkotika': ('narkotikum',),
'narkotikaene': ('narkotikum',),
'narkotikum': ('narkotikum',),
'narkotikumet': ('narkotikum',),
'narkval': ('narkval',),
'narkvalen': ('narkval',),
'narkvalene': ('narkval',),
'narkvaler': ('narkval',),
'narr': ('narr',),
'narren': ('narr',),
'narrene': ('narr',),
'narrer': ('narr',),
'narreri': ('narreri',),
'narreria': ('narreri',),
'narreriene': ('narreri',),
'narrerier': ('narreri',),
'narreriet': ('narreri',),
'narresmokk': ('narresmokk',),
'narresmokken': ('narresmokk',),
'narresmokkene': ('narresmokk',),
'narresmokker': ('narresmokk',),
'narrestrek': ('narrestrek',),
'narrestreken': ('narrestrek',),
'narrestrekene': ('narrestrek',),
'narrestreker': ('narrestrek',),
'narsisme': ('narsisme',),
'narsismen': ('narsisme',),
'narsismene': ('narsisme',),
'narsismer': ('narsisme',),
'narsiss': ('narsiss',),
'narsissen': ('narsiss',),
'narsissene': ('narsiss',),
'narsisser': ('narsiss',),
'narsissisme': ('narsissisme',),
'narsissismen': ('narsissisme',),
'narsissismene': ('narsissisme',),
'narsissismer': ('narsissisme',),
'narv': ('narv',),
'narven': ('narv',),
'narvene': ('narv',),
'narver': ('narv',),
'nasal': ('nasal',),
'nasalen': ('nasal',),
'nasalene': ('nasal',),
'nasaler': ('nasal',),
'nasalitet': ('nasalitet',),
'nasaliteten': ('nasalitet',),
'nasalitetene': ('nasalitet',),
'nasaliteter': ('nasalitet',),
'nasallyd': ('nasallyd',),
'nasallyden': ('nasallyd',),
'nasallydene': ('nasallyd',),
'nasallyder': ('nasallyd',),
'nasareer': ('nasareer',),
'nasareere': ('nasareer',),
'nasareeren': ('nasareer',),
'nasareerer': ('nasareer',),
'nasareerne': ('nasareer',),
'nasjon': ('nasjon',),
'nasjonen': ('nasjon',),
'nasjonene': ('nasjon',),
'nasjoner': ('nasjon',),
'nasjonalbank': ('nasjonalbank',),
'nasjonalbanken': ('nasjonalbank',),
'nasjonalbankene': ('nasjonalbank',),
'nasjonalbanker': ('nasjonalbank',),
'nasjonalbudsjett': ('nasjonalbudsjett',),
'nasjonalbudsjetta': ('nasjonalbudsjett',),
'nasjonalbudsjettene': ('nasjonalbudsjett',),
'nasjonalbudsjetter': ('nasjonalbudsjett',),
'nasjonalbudsjettet': ('nasjonalbudsjett',),
'nasjonaldag': ('nasjonaldag',),
'nasjonaldagen': ('nasjonaldag',),
'nasjonaldagene': ('nasjonaldag',),
'nasjonaldager': ('nasjonaldag',),
'nasjonaldrakt': ('nasjonaldrakt',),
'nasjonaldrakta': ('nasjonaldrakt',),
'nasjonaldrakten': ('nasjonaldrakt',),
'nasjonaldraktene': ('nasjonaldrakt',),
'nasjonaldrakter': ('nasjonaldrakt',),
'nasjonalfarge': ('nasjonalfarge',),
'nasjonalfargen': ('nasjonalfarge',),
'nasjonalfargene': ('nasjonalfarge',),
'nasjonalfarger': ('nasjonalfarge',),
'nasjonalforsamling': ('nasjonalforsamling',),
'nasjonalforsamlinga': ('nasjonalforsamling',),
'nasjonalforsamlingen': ('nasjonalforsamling',),
'nasjonalforsamlingene': ('nasjonalforsamling',),
'nasjonalforsamlinger': ('nasjonalforsamling',),
'nasjonalfølelse': ('nasjonalfølelse',),
'nasjonalfølelsen': ('nasjonalfølelse',),
'nasjonalfølelsene': ('nasjonalfølelse',),
'nasjonalfølelser': ('nasjonalfølelse',),
'nasjonalgalleri': ('nasjonalgalleri',),
'nasjonalgalleria': ('nasjonalgalleri',),
'nasjonalgalleriene': ('nasjonalgalleri',),
'nasjonalgallerier': ('nasjonalgalleri',),
'nasjonalgalleriet': ('nasjonalgalleri',),
'nasjonalgarde': ('nasjonalgarde',),
'nasjonalgarden': ('nasjonalgarde',),
'nasjonalgardene': ('nasjonalgarde',),
'nasjonalgarder': ('nasjonalgarde',),
'nasjonalhymne': ('nasjonalhymne',),
'nasjonalhymnen': ('nasjonalhymne',),
'nasjonalhymnene': ('nasjonalhymne',),
'nasjonalhymner': ('nasjonalhymne',),
'nasjonalisme': ('nasjonalisme',),
'nasjonalismen': ('nasjonalisme',),
'nasjonalismene': ('nasjonalisme',),
'nasjonalismer': ('nasjonalisme',),
'nasjonalist': ('nasjonalist',),
'nasjonalisten': ('nasjonalist',),
'nasjonalistene': ('nasjonalist',),
'nasjonalister': ('nasjonalist',),
'nasjonalitet': ('nasjonalitet',),
'nasjonaliteten': ('nasjonalitet',),
'nasjonalitetene': ('nasjonalitet',),
'nasjonaliteter': ('nasjonalitet',),
'nasjonalitetsmerka': ('nasjonalitetsmerke',),
'nasjonalitetsmerke': ('nasjonalitetsmerke',),
'nasjonalitetsmerkene': ('nasjonalitetsmerke',),
'nasjonalitetsmerker': ('nasjonalitetsmerke',),
'nasjonalitetsmerket': ('nasjonalitetsmerke',),
'nasjonalitetsprinsipp': ('nasjonalitetsprinsipp',),
'nasjonalitetsprinsippa': ('nasjonalitetsprinsipp',),
'nasjonalitetsprinsippene': ('nasjonalitetsprinsipp',),
'nasjonalitetsprinsipper': ('nasjonalitetsprinsipp',),
'nasjonalitetsprinsippet': ('nasjonalitetsprinsipp',),
'nasjonalpark': ('nasjonalpark',),
'nasjonalparken': ('nasjonalpark',),
'nasjonalparkene': ('nasjonalpark',),
'nasjonalparker': ('nasjonalpark',),
'nasjonalprodukt': ('nasjonalprodukt',),
'nasjonalprodukta': ('nasjonalprodukt',),
'nasjonalproduktene': ('nasjonalprodukt',),
'nasjonalprodukter': ('nasjonalprodukt',),
'nasjonalproduktet': ('nasjonalprodukt',),
'nasjonalregnskap': ('nasjonalregnskap',),
'nasjonalregnskapa': ('nasjonalregnskap',),
'nasjonalregnskapene': ('nasjonalregnskap',),
'nasjonalregnskaper': ('nasjonalregnskap',),
'nasjonalregnskapet': ('nasjonalregnskap',),
'nasjonalromantikk': ('nasjonalromantikk',),
'nasjonalromantikken': ('nasjonalromantikk',),
'nasjonalromantikkene': ('nasjonalromantikk',),
'nasjonalromantikker': ('nasjonalromantikk',),
'nasjonalsang': ('nasjonalsang',),
'nasjonalsangen': ('nasjonalsang',),
'nasjonalsangene': ('nasjonalsang',),
'nasjonalsanger': ('nasjonalsang',),
'nasjonalsosialisme': ('nasjonalsosialisme',),
'nasjonalsosialismen': ('nasjonalsosialisme',),
'nasjonalsosialismene': ('nasjonalsosialisme',),
'nasjonalsosialismer': ('nasjonalsosialisme',),
'nasjonalstat': ('nasjonalstat',),
'nasjonalstaten': ('nasjonalstat',),
'nasjonalstatene': ('nasjonalstat',),
'nasjonalstater': ('nasjonalstat',),
'nasjonalteater': ('nasjonalteater',),
'nasjonalteateret': ('nasjonalteater',),
'nasjonalteatra': ('nasjonalteater',),
'nasjonalteatre': ('nasjonalteater',),
'nasjonalteatrene': ('nasjonalteater',),
'nasjonalteatret': ('nasjonalteater',),
'nasjonaløkonomi': ('nasjonaløkonomi',),
'nasjonaløkonomien': ('nasjonaløkonomi',),
'nasjonaløkonomiene': ('nasjonaløkonomi',),
'nasjonaløkonomier': ('nasjonaløkonomi',),
'nasker': ('nasker',),
'naskere': ('nasker',),
'naskeren': ('nasker',),
'naskerer': ('nasker',),
'naskerne': ('nasker',),
'naskeri': ('naskeri',),
'naskeria': ('naskeri',),
'naskeriene': ('naskeri',),
'naskerier': ('naskeri',),
'naskeriet': ('naskeri',),
'nat': ('nat',),
'naten': ('nat',),
'natene': ('nat',),
'nater': ('nat',),
'natalitet': ('natalitet',),
'nataliteten': ('natalitet',),
'natalitetene': ('natalitet',),
'nataliteter': ('natalitet',),
'nativisme': ('nativisme',),
'nativismen': ('nativisme',),
'nativismene': ('nativisme',),
'nativismer': ('nativisme',),
'nativitet': ('nativitet',),
'nativiteten': ('nativitet',),
'nativitetene': ('nativitet',),
'nativiteter': ('nativitet',),
'natrium': ('natrium',),
'natriuma': ('natrium',),
'natriumene': ('natrium',),
'natriumet': ('natrium',),
'natriumhydrogenkarbonat': ('natriumhydrogenkarbonat',),
'natriumhydrogenkarbonata': ('natriumhydrogenkarbonat',),
'natriumhydrogenkarbonatene': ('natriumhydrogenkarbonat',),
'natriumhydrogenkarbonater': ('natriumhydrogenkarbonat',),
'natriumhydrogenkarbonatet': ('natriumhydrogenkarbonat',),
'natriumhydroksid': ('natriumhydroksid',),
'natriumhydroksida': ('natriumhydroksid',),
'natriumhydroksidene': ('natriumhydroksid',),
'natriumhydroksider': ('natriumhydroksid',),
'natriumhydroksidet': ('natriumhydroksid',),
'natriumkarbonat': ('natriumkarbonat',),
'natriumkarbonata': ('natriumkarbonat',),
'natriumkarbonatene': ('natriumkarbonat',),
'natriumkarbonater': ('natriumkarbonat',),
'natriumkarbonatet': ('natriumkarbonat',),
'natriumklorat': ('natriumklorat',),
'natriumklorata': ('natriumklorat',),
'natriumkloratene': ('natriumklorat',),
'natriumklorater': ('natriumklorat',),
'natriumkloratet': ('natriumklorat',),
'natriumklorid': ('natriumklorid',),
'natriumklorida': ('natriumklorid',),
'natriumkloridene': ('natriumklorid',),
'natriumklorider': ('natriumklorid',),
'natriumkloridet': ('natriumklorid',),
'natriumpalmitat': ('natriumpalmitat',),
'natriumpalmitata': ('natriumpalmitat',),
'natriumpalmitatene': ('natriumpalmitat',),
'natriumpalmitater': ('natriumpalmitat',),
'natriumpalmitatet': ('natriumpalmitat',),
'natron': ('natron',),
'natrona': ('natron',),
'natronene': ('natron',),
'natronet': ('natron',),
'natronlut': ('natronlut',),
'natronluta': ('natronlut',),
'natronluten': ('natronlut',),
'natronlutene': ('natronlut',),
'natronluter': ('natronlut',),
'natt': ('natt',),
'natta': ('natt',),
'natten': ('natt',),
'nettene': ('natt',),
'netter': ('natt',),
'natt-og-dag': ('natt-og-dag',),
'natt-og-dagen': ('natt-og-dag',),
'natt-og-dagene': ('natt-og-dag',),
'natt-og-dager': ('natt-og-dag',),
'natt-tillegg': ('natt-tillegg',),
'natt-tillegga': ('natt-tillegg',),
'natt-tilleggene': ('natt-tillegg',),
'natt-tillegget': ('natt-tillegg',),
'natt-tog': ('natt-tog',),
'natt-toga': ('natt-tog',),
'natt-togene': ('natt-tog',),
'natt-toget': ('natt-tog',),
'natt-tøy': ('natt-tøy',),
'natt-tøya': ('natt-tøy',),
'natt-tøyene': ('natt-tøy',),
'natt-tøyer': ('natt-tøy',),
'natt-tøyet': ('natt-tøy',),
'nattarbeid': ('nattarbeid',),
'nattarbeida': ('nattarbeid',),
'nattarbeidene': ('nattarbeid',),
'nattarbeider': ('nattarbeid',),
'nattarbeidet': ('nattarbeid',),
'nattbord': ('nattbord',),
'nattborda': ('nattbord',),
'nattbordene': ('nattbord',),
'nattborder': ('nattbord',),
'nattbordet': ('nattbord',),
'nattbordslampa': ('nattbordslampe',),
'nattbordslampe': ('nattbordslampe',),
'nattbordslampen': ('nattbordslampe',),
'nattbordslampene': ('nattbordslampe',),
'nattbordslamper': ('nattbordslampe',),
'nattdrakt': ('nattdrakt',),
'nattdrakta': ('nattdrakt',),
'nattdrakten': ('nattdrakt',),
'nattdraktene': ('nattdrakt',),
'nattdrakter': ('nattdrakt',),
'nattdyr': ('nattdyr',),
'nattdyra': ('nattdyr',),
'nattdyrene': ('nattdyr',),
'nattdyret': ('nattdyr',),
'nattefrieri': ('nattefrieri',),
'nattefrieria': ('nattefrieri',),
'nattefrieriene': ('nattefrieri',),
'nattefrierier': ('nattefrieri',),
'nattefrieriet': ('nattefrieri',),
'nattefriing': ('nattefriing',),
'nattefriinga': ('nattefriing',),
'nattefriingen': ('nattefriing',),
'nattefriingene': ('nattefriing',),
'nattefriinger': ('nattefriing',),
'nattefrost': ('nattefrost',),
'nattefrosten': ('nattefrost',),
'nattefrostene': ('nattefrost',),
'nattefroster': ('nattefrost',),
'natteliv': ('natteliv',),
'natteliva': ('natteliv',),
'nattelivene': ('natteliv',),
'nattelivet': ('natteliv',),
'nattely': ('nattely',),
'nattelya': ('nattely',),
'nattelyene': ('nattely',),
'nattelyet': ('nattely',),
'natteramn': ('natteramn',),
'natteramnen': ('natteramn',),
'natteramnene': ('natteramn',),
'natteramner': ('natteramn',),
'natteramn': ('natteramn',),
'natteramnen': ('natteramn',),
'natteramnene': ('natteramn',),
'natteramner': ('natteramn',),
'natterangler': ('natterangler',),
'natteranglere': ('natterangler',),
'natterangleren': ('natterangler',),
'natteranglerer': ('natterangler',),
'natteranglerne': ('natterangler',),
'natteravn': ('natteravn',),
'natteravnen': ('natteravn',),
'natteravnene': ('natteravn',),
'natteravner': ('natteravn',),
'natteravn': ('natteravn',),
'natteravnen': ('natteravn',),
'natteravnene': ('natteravn',),
'natteravner': ('natteravn',),
'nattergal': ('nattergal',),
'nattergalen': ('nattergal',),
'nattergalene': ('nattergal',),
'nattergaler': ('nattergal',),
'nattero': ('nattero',),
'natteroa': ('nattero',),
'natteroen': ('nattero',),
'natteroene': ('nattero',),
'natteroer': ('nattero',),
'nattestengning': ('nattestengning',),
'nattestengninga': ('nattestengning',),
'nattestengningen': ('nattestengning',),
'nattestengningene': ('nattestengning',),
'nattestengninger': ('nattestengning',),
'nattesøvn': ('nattesøvn',),
'nattesøvnen': ('nattesøvn',),
'nattesøvnene': ('nattesøvn',),
'nattesøvner': ('nattesøvn',),
'nattetid': ('nattetid',),
'nattetida': ('nattetid',),
'nattetiden': ('nattetid',),
'nattetidene': ('nattetid',),
'nattetider': ('nattetid',),
'nattetime': ('nattetime',),
'nattetimen': ('nattetime',),
'nattetimene': ('nattetime',),
'nattetimer': ('nattetime',),
'nattevakt': ('nattevakt',),
'nattevakta': ('nattevakt',),
'nattevakten': ('nattevakt',),
'nattevaktene': ('nattevakt',),
'nattevakter': ('nattevakt',),
'nattevåk': ('nattevåk',),
'nattevåka': ('nattevåk',),
'nattevåken': ('nattevåk',),
'nattevåkene': ('nattevåk',),
'nattevåker': ('nattevåk',),
'nattevåket': ('nattevåk',),
'nattevåking': ('nattevåking',),
'nattevåkinga': ('nattevåking',),
'nattevåkingen': ('nattevåking',),
'nattevåkingene': ('nattevåking',),
'nattevåkinger': ('nattevåking',),
'nattfiol': ('nattfiol',),
'nattfiolen': ('nattfiol',),
'nattfiolene': ('nattfiol',),
'nattfioler': ('nattfiol',),
'nattfly': ('nattfly',),
'nattflya': ('nattfly',),
'nattflyene': ('nattfly',),
'nattflyet': ('nattfly',),
'nattfly': ('nattfly',),
'nattflya': ('nattfly',),
'nattflyene': ('nattfly',),
'nattflyet': ('nattfly',),
'natthus': ('natthus',),
'natthusa': ('natthus',),
'natthusene': ('natthus',),
'natthuset': ('natthus',),
'nattillegg': ('nattillegg',),
'nattillegga': ('nattillegg',),
'nattilleggene': ('nattillegg',),
'nattillegget': ('nattillegg',),
'nattineen': ('nattiné',),
'nattineene': ('nattiné',),
'nattineer': ('nattiné',),
'nattiné': ('nattiné',),
'nattinéen': ('nattiné',),
'nattinéene': ('nattiné',),
'nattinéer': ('nattiné',),
'nattkikkert': ('nattkikkert',),
'nattkikkerten': ('nattkikkert',),
'nattkikkertene': ('nattkikkert',),
'nattkikkerter': ('nattkikkert',),
'nattkino': ('nattkino',),
'nattkinoen': ('nattkino',),
'nattkinoene': ('nattkino',),
'nattkinoer': ('nattkino',),
'nattkjole': ('nattkjole',),
'nattkjolen': ('nattkjole',),
'nattkjolene': ('nattkjole',),
'nattkjoler': ('nattkjole',),
'nattklubb': ('nattklubb',),
'nattklubben': ('nattklubb',),
'nattklubbene': ('nattklubb',),
'nattklubber': ('nattklubb',),
'nattliv': ('nattliv',),
'nattliva': ('nattliv',),
'nattlivene': ('nattliv',),
'nattlivet': ('nattliv',),
'nattlua': ('nattlue',),
'nattlue': ('nattlue',),
'nattluen': ('nattlue',),
'nattluene': ('nattlue',),
'nattluer': ('nattlue',),
'nattluva': ('nattluve',),
'nattluve': ('nattluve',),
'nattluven': ('nattluve',),
'nattluvene': ('nattluve',),
'nattluver': ('nattluve',),
'nattlys': ('nattlys',),
'nattlysa': ('nattlys',),
'nattlysen': ('nattlys',),
'nattlysene': ('nattlys',),
'nattlyser': ('nattlys',),
'nattlyset': ('nattlys',),
'nattmann': ('nattmann',),
'nattmannen': ('nattmann',),
'nattmenn': ('nattmann',),
'nattmennene': ('nattmann',),
'nattmat': ('nattmat',),
'nattmaten': ('nattmat',),
'nattmatene': ('nattmat',),
'nattmater': ('nattmat',),
'nattmøbel': ('nattmøbel',),
'nattmøbelet': ('nattmøbel',),
'nattmøbla': ('nattmøbel',),
'nattmøblene': ('nattmøbel',),
'nattmøbler': ('nattmøbel',),
'nattmøblet': ('nattmøbel',),
'nattog': ('nattog',),
'nattoga': ('nattog',),
'nattogene': ('nattog',),
'nattoget': ('nattog',),
'nattpotta': ('nattpotte',),
'nattpotte': ('nattpotte',),
'nattpotten': ('nattpotte',),
'nattpottene': ('nattpotte',),
'nattpotter': ('nattpotte',),
'nattradio': ('nattradio',),
'nattradioen': ('nattradio',),
'nattradioene': ('nattradio',),
'nattradioer': ('nattradio',),
'nattramn': ('nattramn',),
'nattramnen': ('nattramn',),
'nattramnene': ('nattramn',),
'nattramner': ('nattramn',),
'nattravn': ('nattravn',),
'nattravnen': ('nattravn',),
'nattravnene': ('nattravn',),
'nattravner': ('nattravn',),
'nattsafe': ('nattsafe',),
'nattsafen': ('nattsafe',),
'nattsafene': ('nattsafe',),
'nattsafer': ('nattsafe',),
'nattsida': ('nattside',),
'nattside': ('nattside',),
'nattsiden': ('nattside',),
'nattsidene': ('nattside',),
'nattsider': ('nattside',),
'nattskift': ('nattskift',),
'nattskifta': ('nattskift',),
'nattskiftene': ('nattskift',),
'nattskiftet': ('nattskift',),
'nattsommerfugl': ('nattsommerfugl',),
'nattsommerfuglen': ('nattsommerfugl',),
'nattsommerfuglene': ('nattsommerfugl',),
'nattsommerfugler': ('nattsommerfugl',),
'nattstengning': ('nattstengning',),
'nattstengninga': ('nattstengning',),
'nattstengningen': ('nattstengning',),
'nattstengningene': ('nattstengning',),
'nattstengninger': ('nattstengning',),
'nattsvermer': ('nattsvermer',),
'nattsvermere': ('nattsvermer',),
'nattsvermeren': ('nattsvermer',),
'nattsvermerer': ('nattsvermer',),
'nattsvermerne': ('nattsvermer',),
'nattsyn': ('nattsyn',),
'nattsyna': ('nattsyn',),
'nattsynene': ('nattsyn',),
'nattsynet': ('nattsyn',),
'nattvakt': ('nattvakt',),
'nattvakta': ('nattvakt',),
'nattvakten': ('nattvakt',),
'nattvaktene': ('nattvakt',),
'nattvakter': ('nattvakt',),
'nattverd': ('nattverd',),
'nattverden': ('nattverd',),
'nattverdene': ('nattverd',),
'nattverder': ('nattverd',),
'nattverdsgjest': ('nattverdsgjest',),
'nattverdsgjesten': ('nattverdsgjest',),
'nattverdsgjestene': ('nattverdsgjest',),
'nattverdsgjester': ('nattverdsgjest',),
'nattøy': ('nattøy',),
'nattøya': ('nattøy',),
'nattøyene': ('nattøy',),
'nattøyer': ('nattøy',),
'nattøyet': ('nattøy',),
'natur': ('natur',),
'naturen': ('natur',),
'naturene': ('natur',),
'naturer': ('natur',),
'naturalhusholdning': ('naturalhusholdning',),
'naturalhusholdninga': ('naturalhusholdning',),
'naturalhusholdningen': ('naturalhusholdning',),
'naturalhusholdningene': ('naturalhusholdning',),
'naturalhusholdninger': ('naturalhusholdning',),
'naturalia': ('naturalia',),
'naturaliene': ('naturalia',),
'naturaliene': ('naturalier',),
'naturalier': ('naturalier',),
'naturalisasjon': ('naturalisasjon',),
'naturalisasjonen': ('naturalisasjon',),
'naturalisasjonene': ('naturalisasjon',),
'naturalisasjoner': ('naturalisasjon',),
'naturalisme': ('naturalisme',),
'naturalismen': ('naturalisme',),
'naturalismene': ('naturalisme',),
'naturalismer': ('naturalisme',),
'naturalist': ('naturalist',),
'naturalisten': ('naturalist',),
'naturalistene': ('naturalist',),
'naturalister': ('naturalist',),
'naturbarn': ('naturbarn',),
'naturbarna': ('naturbarn',),
'naturbarnene': ('naturbarn',),
'naturbarnet': ('naturbarn',),
'naturbegavelse': ('naturbegavelse',),
'naturbegavelsen': ('naturbegavelse',),
'naturbegavelsene': ('naturbegavelse',),
'naturbegavelser': ('naturbegavelse',),
'naturbetong': ('naturbetong',),
'naturbetongen': ('naturbetong',),
'naturbetongene': ('naturbetong',),
'naturbetonger': ('naturbetong',),
'nature morte': ('nature morte',),
'natureng': ('natureng',),
'naturenga': ('natureng',),
'naturengen': ('natureng',),
'naturengene': ('natureng',),
'naturenger': ('natureng',),
'naturfag': ('naturfag',),
'naturfaga': ('naturfag',),
'naturfagene': ('naturfag',),
'naturfaget': ('naturfag',),
'naturfaglinja': ('naturfaglinje',),
'naturfaglinje': ('naturfaglinje',),
'naturfaglinjen': ('naturfaglinje',),
'naturfaglinjene': ('naturfaglinje',),
'naturfaglinjer': ('naturfaglinje',),
'naturfenomen': ('naturfenomen',),
'naturfenomena': ('naturfenomen',),
'naturfenomenene': ('naturfenomen',),
'naturfenomener': ('naturfenomen',),
'naturfenomenet': ('naturfenomen',),
'naturfiber': ('naturfiber',),
'naturfibere': ('naturfiber',),
'naturfiberen': ('naturfiber',),
'naturfiberer': ('naturfiber',),
'naturfiberne': ('naturfiber',),
'naturfibre': ('naturfiber',),
'naturfibrene': ('naturfiber',),
'naturfibrer': ('naturfiber',),
'naturfilosofi': ('naturfilosofi',),
'naturfilosofien': ('naturfilosofi',),
'naturfilosofiene': ('naturfilosofi',),
'naturfilosofier': ('naturfilosofi',),
'naturfolk': ('naturfolk',),
'naturfolka': ('naturfolk',),
'naturfolkene': ('naturfolk',),
'naturfolket': ('naturfolk',),
'naturgass': ('naturgass',),
'naturgassen': ('naturgass',),
'naturgassene': ('naturgass',),
'naturgasser': ('naturgass',),
'naturgjødsel': ('naturgjødsel',),
'naturgjødselen': ('naturgjødsel',),
'naturgjødsla': ('naturgjødsel',),
'naturgjødslene': ('naturgjødsel',),
'naturgjødsler': ('naturgjødsel',),
'naturherlighet': ('naturherlighet',),
'naturherligheta': ('naturherlighet',),
'naturherligheten': ('naturherlighet',),
'naturherlighetene': ('naturherlighet',),
'naturherligheter': ('naturherlighet',),
'naturhistoria': ('naturhistorie',),
'naturhistorie': ('naturhistorie',),
'naturhistorien': ('naturhistorie',),
'naturhistoriene': ('naturhistorie',),
'naturhistorier': ('naturhistorie',),
'naturisme': ('naturisme',),
'naturismen': ('naturisme',),
'naturismene': ('naturisme',),
'naturismer': ('naturisme',),
'naturist': ('naturist',),
'naturisten': ('naturist',),
'naturistene': ('naturist',),
'naturister': ('naturist',),
'naturkatastrofa': ('naturkatastrofe',),
'naturkatastrofe': ('naturkatastrofe',),
'naturkatastrofen': ('naturkatastrofe',),
'naturkatastrofene': ('naturkatastrofe',),
'naturkatastrofer': ('naturkatastrofe',),
'naturkraft': ('naturkraft',),
'naturkrafta': ('naturkraft',),
'naturkraften': ('naturkraft',),
'naturkreftene': ('naturkraft',),
'naturkrefter': ('naturkraft',),
'naturlandskap': ('naturlandskap',),
'naturlandskapa': ('naturlandskap',),
'naturlandskapene': ('naturlandskap',),
'naturlandskaper': ('naturlandskap',),
'naturlandskapet': ('naturlandskap',),
'naturlege': ('naturlege',),
'naturlegen': ('naturlege',),
'naturlegene': ('naturlege',),
'naturleger': ('naturlege',),
'naturlov': ('naturlov',),
'naturloven': ('naturlov',),
'naturlovene': ('naturlov',),
'naturlover': ('naturlov',),
'naturmedisin': ('naturmedisin',),
'naturmedisinen': ('naturmedisin',),
'naturmedisinene': ('naturmedisin',),
'naturmedisiner': ('naturmedisin',),
'naturmetode': ('naturmetode',),
'naturmetoden': ('naturmetode',),
'naturmetodene': ('naturmetode',),
'naturmetoder': ('naturmetode',),
'naturmiljø': ('naturmiljø',),
'naturmiljøa': ('naturmiljø',),
'naturmiljøene': ('naturmiljø',),
'naturmiljøer': ('naturmiljø',),
'naturmiljøet': ('naturmiljø',),
'naturminna': ('naturminne',),
'naturminne': ('naturminne',),
'naturminnene': ('naturminne',),
'naturminner': ('naturminne',),
'naturminnet': ('naturminne',),
'naturnavn': ('naturnavn',),
'naturnavna': ('naturnavn',),
'naturnavnene': ('naturnavn',),
'naturnavnet': ('naturnavn',),
'naturperla': ('naturperle',),
'naturperle': ('naturperle',),
'naturperlen': ('naturperle',),
'naturperlene': ('naturperle',),
'naturperler': ('naturperle',),
'naturprodukt': ('naturprodukt',),
'naturprodukta': ('naturprodukt',),
'naturproduktene': ('naturprodukt',),
'naturprodukter': ('naturprodukt',),
'naturproduktet': ('naturprodukt',),
'naturreligion': ('naturreligion',),
'naturreligionen': ('naturreligion',),
'naturreligionene': ('naturreligion',),
'naturreligioner': ('naturreligion',),
'naturreservat': ('naturreservat',),
'naturreservata': ('naturreservat',),
'naturreservatene': ('naturreservat',),
'naturreservater': ('naturreservat',),
'naturreservatet': ('naturreservat',),
'naturressurs': ('naturressurs',),
'naturressursen': ('naturressurs',),
'naturressursene': ('naturressurs',),
'naturressurser': ('naturressurs',),
'naturresurs': ('naturresurs',),
'naturresursen': ('naturresurs',),
'naturresursene': ('naturresurs',),
'naturresurser': ('naturresurs',),
'naturrett': ('naturrett',),
'naturretten': ('naturrett',),
'naturrettene': ('naturrett',),
'naturretter': ('naturrett',),
'naturrikdom': ('naturrikdom',),
'naturrikdommen': ('naturrikdom',),
'naturrikdommene': ('naturrikdom',),
'naturrikdommer': ('naturrikdom',),
'natursilke': ('natursilke',),
'natursilken': ('natursilke',),
'natursilkene': ('natursilke',),
'natursilker': ('natursilke',),
'naturskade': ('naturskade',),
'naturskaden': ('naturskade',),
'naturskadene': ('naturskade',),
'naturskader': ('naturskade',),
'naturstein': ('naturstein',),
'natursteinen': ('naturstein',),
'natursteinene': ('naturstein',),
'natursteiner': ('naturstein',),
'natursvin': ('natursvin',),
'natursvina': ('natursvin',),
'natursvinene': ('natursvin',),
'natursvinet': ('natursvin',),
'naturtalent': ('naturtalent',),
'naturtalenta': ('naturtalent',),
'naturtalentene': ('naturtalent',),
'naturtalenter': ('naturtalent',),
'naturtalentet': ('naturtalent',),
'naturtone': ('naturtone',),
'naturtonen': ('naturtone',),
'naturtonene': ('naturtone',),
'naturtoner': ('naturtone',),
'naturtrompet': ('naturtrompet',),
'naturtrompeten': ('naturtrompet',),
'naturtrompetene': ('naturtrompet',),
'naturtrompeter': ('naturtrompet',),
'naturvern': ('naturvern',),
'naturverna': ('naturvern',),
'naturvernene': ('naturvern',),
'naturvernet': ('naturvern',),
'naturverner': ('naturverner',),
'naturvernere': ('naturverner',),
'naturverneren': ('naturverner',),
'naturvernerer': ('naturverner',),
'naturvernerne': ('naturverner',),
'naturvett': ('naturvett',),
'naturvetta': ('naturvett',),
'naturvettene': ('naturvett',),
'naturvettet': ('naturvett',),
'naturvitenskap': ('naturvitenskap',),
'naturvitenskapen': ('naturvitenskap',),
'naturvitenskapene': ('naturvitenskap',),
'naturvitenskaper': ('naturvitenskap',),
'naturvitskap': ('naturvitskap',),
'naturvitskapen': ('naturvitskap',),
'naturvitskapene': ('naturvitskap',),
'naturvitskaper': ('naturvitskap',),
'natyrell': ('natyrell',),
'natyrella': ('natyrell',),
'natyrellene': ('natyrell',),
'natyreller': ('natyrell',),
'natyrellet': ('natyrell',),
'naueld': ('naueld',),
'nauelden': ('naueld',),
'naueldene': ('naueld',),
'nauelder': ('naueld',),
'naueld': ('naueld',),
'nauelden': ('naueld',),
'naueldene': ('naueld',),
'nauelder': ('naueld',),
'nauild': ('nauild',),
'nauilden': ('nauild',),
'nauildene': ('nauild',),
'nauilder': ('nauild',),
'nauild': ('nauild',),
'nauilden': ('nauild',),
'nauildene': ('nauild',),
'nauilder': ('nauild',),
'nauruer': ('nauruer',),
'nauruere': ('nauruer',),
'naurueren': ('nauruer',),
'nauruerer': ('nauruer',),
'nauruerne': ('nauruer',),
'naust': ('naust',),
'nausta': ('naust',),
'naustene': ('naust',),
'naustet': ('naust',),
'naut': ('naut',),
'nauta': ('naut',),
'nautene': ('naut',),
'nautet': ('naut',),
'nautefjøs': ('nautefjøs',),
'nautefjøsa': ('nautefjøs',),
'nautefjøsen': ('nautefjøs',),
'nautefjøsene': ('nautefjøs',),
'nautefjøset': ('nautefjøs',),
'nautfall': ('nautfall',),
'nautfalla': ('nautfall',),
'nautfallene': ('nautfall',),
'nautfallet': ('nautfall',),
'nautfjøs': ('nautfjøs',),
'nautfjøsa': ('nautfjøs',),
'nautfjøsen': ('nautfjøs',),
'nautfjøsene': ('nautfjøs',),
'nautfjøset': ('nautfjøs',),
'nautgard': ('nautgard',),
'nautgarden': ('nautgard',),
'nautgardene': ('nautgard',),
'nautgarder': ('nautgard',),
'nautikk': ('nautikk',),
'nautikken': ('nautikk',),
'nautikkene': ('nautikk',),
'nautikker': ('nautikk',),
'nautil': ('nautil',),
'nautilen': ('nautil',),
'nautilene': ('nautil',),
'nautiler': ('nautil',),
'nautilus': ('nautilus',),
'nautilusen': ('nautilus',),
'nautilusene': ('nautilus',),
'nautiluser': ('nautilus',),
'nav': ('nav',),
'nava': ('nav',),
'navene': ('nav',),
'navet': ('nav',),
'navaho': ('navaho',),
'navahoen': ('navaho',),
'navahoene': ('navaho',),
'navahoer': ('navaho',),
'navar': ('navar',),
'navaren': ('navar',),
'navarene': ('navar',),
'navarer': ('navar',),
'navrene': ('navar',),
'navrer': ('navar',),
'navbrems': ('navbrems',),
'navbremsen': ('navbrems',),
'navbremsene': ('navbrems',),
'navbremser': ('navbrems',),
'navbremsa': ('navbremse',),
'navbremse': ('navbremse',),
'navbremsen': ('navbremse',),
'navbremsene': ('navbremse',),
'navbremser': ('navbremse',),
'navigasjon': ('navigasjon',),
'navigasjonen': ('navigasjon',),
'navigasjonene': ('navigasjon',),
'navigasjoner': ('navigasjon',),
'navigasjonssatellitt': ('navigasjonssatellitt',),
'navigasjonssatellitten': ('navigasjonssatellitt',),
'navigasjonssatellittene': ('navigasjonssatellitt',),
'navigasjonssatellitter': ('navigasjonssatellitt',),
'navigatør': ('navigatør',),
'navigatøren': ('navigatør',),
'navigatørene': ('navigatør',),
'navigatører': ('navigatør',),
'navle': ('navle',),
'navlen': ('navle',),
'navlene': ('navle',),
'navler': ('navle',),
'navlebeskuer': ('navlebeskuer',),
'navlebeskuere': ('navlebeskuer',),
'navlebeskueren': ('navlebeskuer',),
'navlebeskuerer': ('navlebeskuer',),
'navlebeskuerne': ('navlebeskuer',),
'navlebrokk': ('navlebrokk',),
'navlebrokka': ('navlebrokk',),
'navlebrokken': ('navlebrokk',),
'navlebrokkene': ('navlebrokk',),
'navlebrokker': ('navlebrokk',),
'navlebrokket': ('navlebrokk',),
'navlesnor': ('navlesnor',),
'navlesnora': ('navlesnor',),
'navlesnoren': ('navlesnor',),
'navlesnorene': ('navlesnor',),
'navlesnorer': ('navlesnor',),
'navlestreng': ('navlestreng',),
'navlestrengen': ('navlestreng',),
'navlestrengene': ('navlestreng',),
'navlestrenger': ('navlestreng',),
'navn': ('navn',),
'navna': ('navn',),
'navnene': ('navn',),
'navnet': ('navn',),
'navne': ('navne',),
'navnen': ('navne',),
'navnene': ('navne',),
'navner': ('navne',),
'navneblekk': ('navneblekk',),
'navneblekka': ('navneblekk',),
'navneblekkene': ('navneblekk',),
'navneblekket': ('navneblekk',),
'navnebror': ('navnebror',),
'navnebroren': ('navnebror',),
'navnebrødre': ('navnebror',),
'navnebrødrene': ('navnebror',),
'navnedag': ('navnedag',),
'navnedagen': ('navnedag',),
'navnedagene': ('navnedag',),
'navnedager': ('navnedag',),
'navneforsking': ('navneforsking',),
'navneforskinga': ('navneforsking',),
'navneforskingen': ('navneforsking',),
'navneforskingene': ('navneforsking',),
'navneforskinger': ('navneforsking',),
'navneforskning': ('navneforskning',),
'navneforskninga': ('navneforskning',),
'navneforskningen': ('navneforskning',),
'navneforskningene': ('navneforskning',),
'navneforskninger': ('navneforskning',),
'navnegransking': ('navnegransking',),
'navnegranskinga': ('navnegransking',),
'navnegranskingen': ('navnegransking',),
'navnegranskingene': ('navnegransking',),
'navnegranskinger': ('navnegransking',),
'navneopprop': ('navneopprop',),
'navneoppropa': ('navneopprop',),
'navneoppropene': ('navneopprop',),
'navneoppropet': ('navneopprop',),
'navnerett': ('navnerett',),
'navneretten': ('navnerett',),
'navnerettene': ('navnerett',),
'navneretter': ('navnerett',),
'navnesøster': ('navnesøster',),
'navnesøstera': ('navnesøster',),
'navnesøsteren': ('navnesøster',),
'navnesøstre': ('navnesøster',),
'navnesøstrene': ('navnesøster',),
'navnesøstrer': ('navnesøster',),
'navnetrekk': ('navnetrekk',),
'navnetrekka': ('navnetrekk',),
'navnetrekkene': ('navnetrekk',),
'navnetrekket': ('navnetrekk',),
'navnord': ('navnord',),
'navnorda': ('navnord',),
'navnordene': ('navnord',),
'navnordet': ('navnord',),
'nazi': ('nazi',),
'nazien': ('nazi',),
'naziene': ('nazi',),
'nazier': ('nazi',),
'nazipropaganda': ('nazipropaganda',),
'nazipropagandaen': ('nazipropaganda',),
'nazipropagandaene': ('nazipropaganda',),
'nazipropagandaer': ('nazipropaganda',),
'nazisme': ('nazisme',),
'nazismen': ('nazisme',),
'nazismene': ('nazisme',),
'nazismer': ('nazisme',),
'nazist': ('nazist',),
'nazisten': ('nazist',),
'nazistene': ('nazist',),
'nazister': ('nazist',),
'ne': ('ne',),
'nea': ('ne',),
'neene': ('ne',),
'neer': ('ne',),
'neet': ('ne',),
'neandertaler': ('neandertaler',),
'neandertalere': ('neandertaler',),
'neandertaleren': ('neandertaler',),
'neandertalerer': ('neandertaler',),
'neandertalerne': ('neandertaler',),
'nebb': ('nebb',),
'nebba': ('nebb',),
'nebben': ('nebb',),
'nebbene': ('nebb',),
'nebbet': ('nebb',),
'nebbdyr': ('nebbdyr',),
'nebbdyra': ('nebbdyr',),
'nebbdyrene': ('nebbdyr',),
'nebbdyret': ('nebbdyr',),
'nebba': ('nebbe',),
'nebbe': ('nebbe',),
'nebben': ('nebbe',),
'nebbene': ('nebbe',),
'nebber': ('nebbe',),
'nebba': ('nebbe',),
'nebbe': ('nebbe',),
'nebben': ('nebbe',),
'nebbene': ('nebbe',),
'nebber': ('nebbe',),
'nebbenosa': ('nebbenose',),
'nebbenose': ('nebbenose',),
'nebbenosen': ('nebbenose',),
'nebbenosene': ('nebbenose',),
'nebbenoser': ('nebbenose',),
'nebbhval': ('nebbhval',),
'nebbhvalen': ('nebbhval',),
'nebbhvalene': ('nebbhval',),
'nebbhvaler': ('nebbhval',),
'nebbkval': ('nebbkval',),
'nebbkvalen': ('nebbkval',),
'nebbkvalene': ('nebbkval',),
'nebbkvaler': ('nebbkval',),
'nebbmunn': ('nebbmunn',),
'nebbmunnen': ('nebbmunn',),
'nebbmunnene': ('nebbmunn',),
'nebbmunner': ('nebbmunn',),
'nebengeskjeft': ('nebengeskjeft',),
'nebengeskjeften': ('nebengeskjeft',),
'nebengeskjeftene': ('nebengeskjeft',),
'nebengeskjefter': ('nebengeskjeft',),
'necessær': ('necessær',),
'necessæren': ('necessær',),
'necessærene': ('necessær',),
'necessærer': ('necessær',),
'nedbygging': ('nedbygging',),
'nedbygginga': ('nedbygging',),
'nedbyggingen': ('nedbygging',),
'nedbyggingene': ('nedbygging',),
'nedbygginger': ('nedbygging',),
'nedbør': ('nedbør',),
'nedbøren': ('nedbør',),
'nedbørene': ('nedbør',),
'nedbører': ('nedbør',),
'nedbørfelt': ('nedbørfelt',),
'nedbørfelta': ('nedbørfelt',),
'nedbørfeltene': ('nedbørfelt',),
'nedbørfelter': ('nedbørfelt',),
'nedbørfeltet': ('nedbørfelt',),
'nedbørhøgd': ('nedbørhøgd',),
'nedbørhøgda': ('nedbørhøgd',),
'nedbørhøgdene': ('nedbørhøgd',),
'nedbørhøgder': ('nedbørhøgd',),
'nedbørhøyde': ('nedbørhøyde',),
'nedbørhøyden': ('nedbørhøyde',),
'nedbørhøydene': ('nedbørhøyde',),
'nedbørhøyder': ('nedbørhøyde',),
'nedbørområda': ('nedbørområde',),
'nedbørområde': ('nedbørområde',),
'nedbørområdene': ('nedbørområde',),
'nedbørområder': ('nedbørområde',),
'nedbørområdet': ('nedbørområde',),
'nedbørsfelt': ('nedbørsfelt',),
'nedbørsfelta': ('nedbørsfelt',),
'nedbørsfeltene': ('nedbørsfelt',),
'nedbørsfelter': ('nedbørsfelt',),
'nedbørsfeltet': ('nedbørsfelt',),
'nedbørshøgd': ('nedbørshøgd',),
'nedbørshøgda': ('nedbørshøgd',),
'nedbørshøgdene': ('nedbørshøgd',),
'nedbørshøgder': ('nedbørshøgd',),
'nedbørshøyde': ('nedbørshøyde',),
'nedbørshøyden': ('nedbørshøyde',),
'nedbørshøydene': ('nedbørshøyde',),
'nedbørshøyder': ('nedbørshøyde',),
'nedbørsområda': ('nedbørsområde',),
'nedbørsområde': ('nedbørsområde',),
'nedbørsområdene': ('nedbørsområde',),
'nedbørsområder': ('nedbørsområde',),
'nedbørsområdet': ('nedbørsområde',),
'nederdel': ('nederdel',),
'nederdelen': ('nederdel',),
'nederdelene': ('nederdel',),
'nederdeler': ('nederdel',),
'nederdrektighet': ('nederdrektighet',),
'nederdrektigheta': ('nederdrektighet',),
'nederdrektigheten': ('nederdrektighet',),
'nederdrektighetene': ('nederdrektighet',),
'nederdrektigheter': ('nederdrektighet',),
'nederlag': ('nederlag',),
'nederlaga': ('nederlag',),
'nederlagene': ('nederlag',),
'nederlaget': ('nederlag',),
'nederlandsk': ('nederlandsk',),
'nederlandsken': ('nederlandsk',),
'nederlandskene': ('nederlandsk',),
'nederlandsker': ('nederlandsk',),
'nederlender': ('nederlender',),
'nederlendere': ('nederlender',),
'nederlenderen': ('nederlender',),
'nederlenderer': ('nederlender',),
'nederlenderne': ('nederlender',),
'nederlending': ('nederlending',),
'nederlendingen': ('nederlending',),
'nederlendingene': ('nederlending',),
'nederlendinger': ('nederlending',),
'nedertysk': ('nedertysk',),
'nedertysken': ('nedertysk',),
'nedertyskene': ('nedertysk',),
'nedertysker': ('nedertysk',),
'nedfall': ('nedfall',),
'nedfalla': ('nedfall',),
'nedfallene': ('nedfall',),
'nedfallet': ('nedfall',),
'nedfallsfrukt': ('nedfallsfrukt',),
'nedfallsfrukta': ('nedfallsfrukt',),
'nedfallsfrukten': ('nedfallsfrukt',),
'nedfallsfruktene': ('nedfallsfrukt',),
'nedfallsfrukter': ('nedfallsfrukt',),
'nedgang': ('nedgang',),
'nedgangen': ('nedgang',),
'nedgangene': ('nedgang',),
'nedganger': ('nedgang',),
'nedgangstid': ('nedgangstid',),
'nedgangstida': ('nedgangstid',),
'nedgangstiden': ('nedgangstid',),
'nedgangstidene': ('nedgangstid',),
'nedgangstider': ('nedgangstid',),
'nedkomst': ('nedkomst',),
'nedkomsten': ('nedkomst',),
'nedkomstene': ('nedkomst',),
'nedkomster': ('nedkomst',),
'nedlatenhet': ('nedlatenhet',),
'nedlatenheta': ('nedlatenhet',),
'nedlatenheten': ('nedlatenhet',),
'nedlatenhetene': ('nedlatenhet',),
'nedlatenheter': ('nedlatenhet',),
'nedleggelse': ('nedleggelse',),
'nedleggelsen': ('nedleggelse',),
'nedleggelsene': ('nedleggelse',),
'nedleggelser': ('nedleggelse',),
'nedlegging': ('nedlegging',),
'nedlegginga': ('nedlegging',),
'nedleggingen': ('nedlegging',),
'nedleggingene': ('nedlegging',),
'nedlegginger': ('nedlegging',),
'nedoverbakke': ('nedoverbakke',),
'nedoverbakken': ('nedoverbakke',),
'nedoverbakkene': ('nedoverbakke',),
'nedoverbakker': ('nedoverbakke',),
'nedrakking': ('nedrakking',),
'nedrakkinga': ('nedrakking',),
'nedrakkingen': ('nedrakking',),
'nedrakkingene': ('nedrakking',),
'nedrakkinger': ('nedrakking',),
'nedringing': ('nedringing',),
'nedringinga': ('nedringing',),
'nedringingen': ('nedringing',),
'nedringingene': ('nedringing',),
'nedringinger': ('nedringing',),
'nedringning': ('nedringning',),
'nedringninga': ('nedringning',),
'nedringningen': ('nedringning',),
'nedringningene': ('nedringning',),
'nedringninger': ('nedringning',),
'nedrusting': ('nedrusting',),
'nedrustinga': ('nedrusting',),
'nedrustingen': ('nedrusting',),
'nedrustingene': ('nedrusting',),
'nedrustinger': ('nedrusting',),
'nedrustingsavtale': ('nedrustingsavtale',),
'nedrustingsavtalen': ('nedrustingsavtale',),
'nedrustingsavtalene': ('nedrustingsavtale',),
'nedrustingsavtaler': ('nedrustingsavtale',),
'nedrustingsforhandling': ('nedrustingsforhandling',),
'nedrustingsforhandlinga': ('nedrustingsforhandling',),
'nedrustingsforhandlingen': ('nedrustingsforhandling',),
'nedrustingsforhandlingene': ('nedrustingsforhandling',),
'nedrustingsforhandlinger': ('nedrustingsforhandling',),
'nedrustning': ('nedrustning',),
'nedrustninga': ('nedrustning',),
'nedrustningen': ('nedrustning',),
'nedrustningene': ('nedrustning',),
'nedrustninger': ('nedrustning',),
'nedrustningsavtale': ('nedrustningsavtale',),
'nedrustningsavtalen': ('nedrustningsavtale',),
'nedrustningsavtalene': ('nedrustningsavtale',),
'nedrustningsavtaler': ('nedrustningsavtale',),
'nedrustningsforhandling': ('nedrustningsforhandling',),
'nedrustningsforhandlinga': ('nedrustningsforhandling',),
'nedrustningsforhandlingen': ('nedrustningsforhandling',),
'nedrustningsforhandlingene': ('nedrustningsforhandling',),
'nedrustningsforhandlinger': ('nedrustningsforhandling',),
'nedrykk': ('nedrykk',),
'nedrykka': ('nedrykk',),
'nedrykkene': ('nedrykk',),
'nedrykket': ('nedrykk',),
'nedrykking': ('nedrykking',),
'nedrykkinga': ('nedrykking',),
'nedrykkingen': ('nedrykking',),
'nedrykkingene': ('nedrykking',),
'nedrykkinger': ('nedrykking',),
'nedrykning': ('nedrykning',),
'nedrykninga': ('nedrykning',),
'nedrykningen': ('nedrykning',),
'nedrykningene': ('nedrykning',),
'nedrykninger': ('nedrykning',),
'nedsettelse': ('nedsettelse',),
'nedsettelsen': ('nedsettelse',),
'nedsettelsene': ('nedsettelse',),
'nedsettelser': ('nedsettelse',),
'nedsetting': ('nedsetting',),
'nedsettinga': ('nedsetting',),
'nedsettingen': ('nedsetting',),
'nedsettingene': ('nedsetting',),
'nedsettinger': ('nedsetting',),
'nedskjæring': ('nedskjæring',),
'nedskjæringa': ('nedskjæring',),
'nedskjæringen': ('nedskjæring',),
'nedskjæringene': ('nedskjæring',),
'nedskjæringer': ('nedskjæring',),
'nedskriving': ('nedskriving',),
'nedskrivinga': ('nedskriving',),
'nedskrivingen': ('nedskriving',),
'nedskrivingene': ('nedskriving',),
'nedskrivinger': ('nedskriving',),
'nedskrivning': ('nedskrivning',),
'nedskrivninga': ('nedskrivning',),
'nedskrivningen': ('nedskrivning',),
'nedskrivningene': ('nedskrivning',),
'nedskrivninger': ('nedskrivning',),
'nedslag': ('nedslag',),
'nedslaga': ('nedslag',),
'nedslagene': ('nedslag',),
'nedslaget': ('nedslag',),
'nedslagning': ('nedslagning',),
'nedslagninga': ('nedslagning',),
'nedslagningen': ('nedslagning',),
'nedslagningene': ('nedslagning',),
'nedslagninger': ('nedslagning',),
'nedslagsfelt': ('nedslagsfelt',),
'nedslagsfelta': ('nedslagsfelt',),
'nedslagsfeltene': ('nedslagsfelt',),
'nedslagsfelter': ('nedslagsfelt',),
'nedslagsfeltet': ('nedslagsfelt',),
'nedslagsområda': ('nedslagsområde',),
'nedslagsområde': ('nedslagsområde',),
'nedslagsområdene': ('nedslagsområde',),
'nedslagsområder': ('nedslagsområde',),
'nedslagsområdet': ('nedslagsområde',),
'nedslåing': ('nedslåing',),
'nedslåinga': ('nedslåing',),
'nedslåingen': ('nedslåing',),
'nedslåingene': ('nedslåing',),
'nedslåinger': ('nedslåing',),
'nedstemthet': ('nedstemthet',),
'nedstemtheta': ('nedstemthet',),
'nedstemtheten': ('nedstemthet',),
'nedstemthetene': ('nedstemthet',),
'nedstemtheter': ('nedstemthet',),
'nedstigning': ('nedstigning',),
'nedstigninga': ('nedstigning',),
'nedstigningen': ('nedstigning',),
'nedstigningene': ('nedstigning',),
'nedstigninger': ('nedstigning',),
'nedstrøk': ('nedstrøk',),
'nedstrøka': ('nedstrøk',),
'nedstrøkene': ('nedstrøk',),
'nedstrøket': ('nedstrøk',),
'nedtegnelse': ('nedtegnelse',),
'nedtegnelsen': ('nedtegnelse',),
'nedtegnelsene': ('nedtegnelse',),
'nedtegnelser': ('nedtegnelse',),
'nedtegning': ('nedtegning',),
'nedtegninga': ('nedtegning',),
'nedtegningen': ('nedtegning',),
'nedtegningene': ('nedtegning',),
'nedtegninger': ('nedtegning',),
'nedtelling': ('nedtelling',),
'nedtellinga': ('nedtelling',),
'nedtellingen': ('nedtelling',),
'nedtellingene': ('nedtelling',),
'nedtellinger': ('nedtelling',),
'nedtur': ('nedtur',),
'nedturen': ('nedtur',),
'nedturene': ('nedtur',),
'nedturer': ('nedtur',),
'nedverdigelse': ('nedverdigelse',),
'nedverdigelsen': ('nedverdigelse',),
'nedverdigelsene': ('nedverdigelse',),
'nedverdigelser': ('nedverdigelse',),
'nefritt': ('nefritt',),
'nefritten': ('nefritt',),
'nefrittene': ('nefritt',),
'nefritter': ('nefritt',),
'negasjon': ('negasjon',),
'negasjonen': ('negasjon',),
'negasjonene': ('negasjon',),
'negasjoner': ('negasjon',),
'negativ': ('negativ',),
'negativa': ('negativ',),
'negativen': ('negativ',),
'negativene': ('negativ',),
'negativer': ('negativ',),
'negativet': ('negativ',),
'negativisme': ('negativisme',),
'negativismen': ('negativisme',),
'negativismene': ('negativisme',),
'negativismer': ('negativisme',),
'negativitet': ('negativitet',),
'negativiteten': ('negativitet',),
'negativitetene': ('negativitet',),
'negativiteter': ('negativitet',),
'negatron': ('negatron',),
'negatrona': ('negatron',),
'negatronene': ('negatron',),
'negatroner': ('negatron',),
'negatronet': ('negatron',),
'neger': ('neger',),
'negere': ('neger',),
'negeren': ('neger',),
'negerer': ('neger',),
'negerne': ('neger',),
'negre': ('neger',),
'negrene': ('neger',),
'negrer': ('neger',),
'negerarbeid': ('negerarbeid',),
'negerarbeida': ('negerarbeid',),
'negerarbeidene': ('negerarbeid',),
'negerarbeider': ('negerarbeid',),
'negerarbeidet': ('negerarbeid',),
'negerkvarter': ('negerkvarter',),
'negerkvartera': ('negerkvarter',),
'negerkvarterene': ('negerkvarter',),
'negerkvarterer': ('negerkvarter',),
'negerkvarteret': ('negerkvarter',),
'negerlandsby': ('negerlandsby',),
'negerlandsbyen': ('negerlandsby',),
'negerlandsbyene': ('negerlandsby',),
'negerlandsbyer': ('negerlandsby',),
'negl': ('negl',),
'neglen': ('negl',),
'neglene': ('negl',),
'negler': ('negl',),
'negleband': ('negleband',),
'neglebanda': ('negleband',),
'neglebandene': ('negleband',),
'neglebandet': ('negleband',),
'neglebit': ('neglebit',),
'neglebita': ('neglebit',),
'neglebitene': ('neglebit',),
'neglebitet': ('neglebit',),
'neglebitt': ('neglebitt',),
'neglebitta': ('neglebitt',),
'neglebittene': ('neglebitt',),
'neglebittet': ('neglebitt',),
'neglebånd': ('neglebånd',),
'neglebånda': ('neglebånd',),
'neglebåndene': ('neglebånd',),
'neglebåndet': ('neglebånd',),
'neglefil': ('neglefil',),
'neglefila': ('neglefil',),
'neglefilen': ('neglefil',),
'neglefilene': ('neglefil',),
'neglefiler': ('neglefil',),
'neglelakk': ('neglelakk',),
'neglelakken': ('neglelakk',),
'neglelakkene': ('neglelakk',),
'neglelakker': ('neglelakk',),
'neglerot': ('neglerot',),
'neglerota': ('neglerot',),
'negleroten': ('neglerot',),
'neglerøttene': ('neglerot',),
'neglerøtter': ('neglerot',),
'neglesprett': ('neglesprett',),
'neglespretten': ('neglesprett',),
'neglesprettene': ('neglesprett',),
'neglespretter': ('neglesprett',),
'neglisjea': ('neglisjé',),
'neglisjeen': ('neglisjé',),
'neglisjeene': ('neglisjé',),
'neglisjeer': ('neglisjé',),
'neglisjeet': ('neglisjé',),
'neglisjé': ('neglisjé',),
'neglisjéa': ('neglisjé',),
'neglisjéen': ('neglisjé',),
'neglisjéene': ('neglisjé',),
'neglisjéer': ('neglisjé',),
'neglisjéet': ('neglisjé',),
'negressa': ('negresse',),
'negresse': ('negresse',),
'negressen': ('negresse',),
'negressene': ('negresse',),
'negresser': ('negresse',),
'negro spiritual': ('negro spiritual',),
'nei': ('nei',),
'neia': ('nei',),
'neiene': ('nei',),
'neiet': ('nei',),
'neimenneska': ('neimenneske',),
'neimenneske': ('neimenneske',),
'neimenneskene': ('neimenneske',),
'neimennesker': ('neimenneske',),
'neimennesket': ('neimenneske',),
'neistemme': ('neistemme',),
'neistemmen': ('neistemme',),
'neistemmene': ('neistemme',),
'neistemmer': ('neistemme',),
'nek': ('nek',),
'neka': ('nek',),
'nekene': ('nek',),
'neket': ('nek',),
'nekrofili': ('nekrofili',),
'nekrofilien': ('nekrofili',),
'nekrofiliene': ('nekrofili',),
'nekrofilier': ('nekrofili',),
'nekrolog': ('nekrolog',),
'nekrologen': ('nekrolog',),
'nekrologene': ('nekrolog',),
'nekrologer': ('nekrolog',),
'nekrose': ('nekrose',),
'nekrosen': ('nekrose',),
'nekrosene': ('nekrose',),
'nekroser': ('nekrose',),
'neksus': ('neksus',),
'neksusen': ('neksus',),
'neksusene': ('neksus',),
'neksuser': ('neksus',),
'nektar': ('nektar',),
'nektaren': ('nektar',),
'nektarene': ('nektar',),
'nektarer': ('nektar',),
'nektarin': ('nektarin',),
'nektarinen': ('nektarin',),
'nektarinene': ('nektarin',),
'nektariner': ('nektarin',),
'nektaria': ('nektarium',),
'nektariene': ('nektarium',),
'nektarier': ('nektarium',),
'nektariet': ('nektarium',),
'nektarium': ('nektarium',),
'nektelse': ('nektelse',),
'nektelsen': ('nektelse',),
'nektelsene': ('nektelse',),
'nektelser': ('nektelse',),
'nekting': ('nekting',),
'nektinga': ('nekting',),
'nektingen': ('nekting',),
'nektingene': ('nekting',),
'nektinger': ('nekting',),
'nellik': ('nellik',),
'nelliken': ('nellik',),
'nellikene': ('nellik',),
'nelliker': ('nellik',),
'nellikfamilie': ('nellikfamilie',),
'nellikfamilien': ('nellikfamilie',),
'nellikfamiliene': ('nellikfamilie',),
'nellikfamilier': ('nellikfamilie',),
'nellikolja': ('nellikolje',),
'nellikolje': ('nellikolje',),
'nellikoljen': ('nellikolje',),
'nellikoljene': ('nellikolje',),
'nellikoljer': ('nellikolje',),
'nellikspiker': ('nellikspiker',),
'nellikspikere': ('nellikspiker',),
'nellikspikeren': ('nellikspiker',),
'nellikspikerne': ('nellikspiker',),
'nellikspikre': ('nellikspiker',),
'nellikspikrene': ('nellikspiker',),
'nellikspikrer': ('nellikspiker',),
'nelson': ('nelson',),
'nelsonen': ('nelson',),
'nelsonene': ('nelson',),
'nelsoner': ('nelson',),
'nemesis': ('nemesis',),
'nemesisen': ('nemesis',),
'nemesisene': ('nemesis',),
'nemesiser': ('nemesis',),
'nemma': ('nemme',),
'nemme': ('nemme',),
'nemmene': ('nemme',),
'nemmer': ('nemme',),
'nemmet': ('nemme',),
'nemnd': ('nemnd',),
'nemnda': ('nemnd',),
'nemnden': ('nemnd',),
'nemndene': ('nemnd',),
'nemnder': ('nemnd',),
'nemåne': ('nemåne',),
'nemånen': ('nemåne',),
'nemånene': ('nemåne',),
'nemåner': ('nemåne',),
'neodym': ('neodym',),
'neodyma': ('neodym',),
'neodymene': ('neodym',),
'neodymet': ('neodym',),
'neoklassisisme': ('neoklassisisme',),
'neoklassisismen': ('neoklassisisme',),
'neoklassisismene': ('neoklassisisme',),
'neoklassisismer': ('neoklassisisme',),
'neologi': ('neologi',),
'neologien': ('neologi',),
'neologiene': ('neologi',),
'neologier': ('neologi',),
'neologisme': ('neologisme',),
'neologismen': ('neologisme',),
'neologismene': ('neologisme',),
'neologismer': ('neologisme',),
'neon': ('neon',),
'neona': ('neon',),
'neonene': ('neon',),
'neonet': ('neon',),
'neonlys': ('neonlys',),
'neonlysa': ('neonlys',),
'neonlysene': ('neonlys',),
'neonlyset': ('neonlys',),
'neonreklame': ('neonreklame',),
'neonreklamen': ('neonreklame',),
'neonreklamene': ('neonreklame',),
'neonreklamer': ('neonreklame',),
'neonrør': ('neonrør',),
'neonrøra': ('neonrør',),
'neonrørene': ('neonrør',),
'neonrøret': ('neonrør',),
'neorealisme': ('neorealisme',),
'neorealismen': ('neorealisme',),
'neorealismene': ('neorealisme',),
'neorealismer': ('neorealisme',),
'nepaler': ('nepaler',),
'nepalere': ('nepaler',),
'nepaleren': ('nepaler',),
'nepalerer': ('nepaler',),
'nepalerne': ('nepaler',),
'nepali': ('nepali',),
'nepalien': ('nepali',),
'nepaliene': ('nepali',),
'nepalier': ('nepali',),
'nepa': ('nepe',),
'nepe': ('nepe',),
'nepen': ('nepe',),
'nepene': ('nepe',),
'neper': ('nepe',),
'nepotisme': ('nepotisme',),
'nepotismen': ('nepotisme',),
'nepotismene': ('nepotisme',),
'nepotismer': ('nepotisme',),
'neptunium': ('neptunium',),
'neptuniuma': ('neptunium',),
'neptuniumene': ('neptunium',),
'neptuniumet': ('neptunium',),
'nereida': ('nereide',),
'nereide': ('nereide',),
'nereiden': ('nereide',),
'nereidene': ('nereide',),
'nereider': ('nereide',),
'nerts': ('nerts',),
'nertsen': ('nerts',),
'nertsene': ('nerts',),
'nertser': ('nerts',),
'nertskåpa': ('nertskåpe',),
'nertskåpe': ('nertskåpe',),
'nertskåpen': ('nertskåpe',),
'nertskåpene': ('nertskåpe',),
'nertskåper': ('nertskåpe',),
'nerve': ('nerve',),
'nerven': ('nerve',),
'nervene': ('nerve',),
'nerver': ('nerve',),
'nervebunt': ('nervebunt',),
'nervebunten': ('nervebunt',),
'nervebuntene': ('nervebunt',),
'nervebunter': ('nervebunt',),
'nervefeber': ('nervefeber',),
'nervefebere': ('nervefeber',),
'nervefeberen': ('nervefeber',),
'nervefeberne': ('nervefeber',),
'nervefebre': ('nervefeber',),
'nervefebrene': ('nervefeber',),
'nervefebrer': ('nervefeber',),
'nervegass': ('nervegass',),
'nervegassen': ('nervegass',),
'nervegassene': ('nervegass',),
'nervegasser': ('nervegass',),
'nerveknute': ('nerveknute',),
'nerveknuten': ('nerveknute',),
'nerveknutene': ('nerveknute',),
'nerveknuter': ('nerveknute',),
'nervekrig': ('nervekrig',),
'nervekrigen': ('nervekrig',),
'nervekrigene': ('nervekrig',),
'nervekriger': ('nervekrig',),
'nervepress': ('nervepress',),
'nervepressa': ('nervepress',),
'nervepressene': ('nervepress',),
'nervepresset': ('nervepress',),
'nervepåkjenning': ('nervepåkjenning',),
'nervepåkjenninga': ('nervepåkjenning',),
'nervepåkjenningen': ('nervepåkjenning',),
'nervepåkjenningene': ('nervepåkjenning',),
'nervepåkjenninger': ('nervepåkjenning',),
'nervesammenbrott': ('nervesammenbrott',),
'nervesammenbrotta': ('nervesammenbrott',),
'nervesammenbrottene': ('nervesammenbrott',),
'nervesammenbrottet': ('nervesammenbrott',),
'nervesammenbrudd': ('nervesammenbrudd',),
'nervesammenbrudda': ('nervesammenbrudd',),
'nervesammenbruddene': ('nervesammenbrudd',),
'nervesammenbruddet': ('nervesammenbrudd',),
'nervesentra': ('nervesentrum',),
'nervesentraene': ('nervesentrum',),
'nervesentre': ('nervesentrum',),
'nervesentrene': ('nervesentrum',),
'nervesentret': ('nervesentrum',),
'nervesentrum': ('nervesentrum',),
'nervesentrumet': ('nervesentrum',),
'nervesjokk': ('nervesjokk',),
'nervesjokka': ('nervesjokk',),
'nervesjokkene': ('nervesjokk',),
'nervesjokket': ('nervesjokk',),
'nerveskjede': ('nerveskjede',),
'nerveskjeden': ('nerveskjede',),
'nerveskjedene': ('nerveskjede',),
'nerveskjeder': ('nerveskjede',),
'nervesmerte': ('nervesmerte',),
'nervesmerten': ('nervesmerte',),
'nervesmertene': ('nervesmerte',),
'nervesmerter': ('nervesmerte',),
'nervesystem': ('nervesystem',),
'nervesystema': ('nervesystem',),
'nervesystemene': ('nervesystem',),
'nervesystemer': ('nervesystem',),
'nervesystemet': ('nervesystem',),
'nervetablett': ('nervetablett',),
'nervetabletten': ('nervetablett',),
'nervetablettene': ('nervetablett',),
'nervetabletter': ('nervetablett',),
'nervevrak': ('nervevrak',),
'nervevraka': ('nervevrak',),
'nervevrakene': ('nervevrak',),
'nervevraket': ('nervevrak',),
'nervøsitet': ('nervøsitet',),
'nervøsiteten': ('nervøsitet',),
'nervøsitetene': ('nervøsitet',),
'nervøsiteter': ('nervøsitet',),
'nes': ('nes',),
'nesa': ('nes',),
'nesene': ('nes',),
'neset': ('nes',),
'nesa': ('nese',),
'nese': ('nese',),
'nesen': ('nese',),
'nesene': ('nese',),
'neser': ('nese',),
'neseblod': ('neseblod',),
'nesebloda': ('neseblod',),
'neseblodene': ('neseblod',),
'neseblodet': ('neseblod',),
'nesebor': ('nesebor',),
'nesebora': ('nesebor',),
'neseborene': ('nesebor',),
'neseboret': ('nesebor',),
'nesedrag': ('nesedrag',),
'nesedraga': ('nesedrag',),
'nesedragene': ('nesedrag',),
'nesedraget': ('nesedrag',),
'neseduk': ('neseduk',),
'neseduken': ('neseduk',),
'nesedukene': ('neseduk',),
'neseduker': ('neseduk',),
'nesegrev': ('nesegrev',),
'nesegreva': ('nesegrev',),
'nesegrevene': ('nesegrev',),
'nesegrevet': ('nesegrev',),
'nesehula': ('nesehule',),
'nesehule': ('nesehule',),
'nesehulen': ('nesehule',),
'nesehulene': ('nesehule',),
'nesehuler': ('nesehule',),
'neselyd': ('neselyd',),
'neselyden': ('neselyd',),
'neselydene': ('neselyd',),
'neselyder': ('neselyd',),
'neseputa': ('nesepute',),
'nesepute': ('nesepute',),
'neseputen': ('nesepute',),
'neseputene': ('nesepute',),
'neseputer': ('nesepute',),
'nesering': ('nesering',),
'neseringen': ('nesering',),
'neseringene': ('nesering',),
'neseringer': ('nesering',),
'neserot': ('neserot',),
'neserota': ('neserot',),
'neseroten': ('neserot',),
'neserøttene': ('neserot',),
'neserøtter': ('neserot',),
'nesestyver': ('nesestyver',),
'nesestyvere': ('nesestyver',),
'nesestyveren': ('nesestyver',),
'nesestyverer': ('nesestyver',),
'nesestyverne': ('nesestyver',),
'nesetipp': ('nesetipp',),
'nesetippen': ('nesetipp',),
'nesetippene': ('nesetipp',),
'nesetipper': ('nesetipp',),
'neseveng': ('neseveng',),
'nesevengen': ('neseveng',),
'nesevengene': ('neseveng',),
'nesevenger': ('neseveng',),
'neseving': ('neseving',),
'nesevingen': ('neseving',),
'nesevingene': ('neseving',),
'nesevinger': ('neseving',),
'nesevinge': ('nesevinge',),
'nesevingen': ('nesevinge',),
'nesevingene': ('nesevinge',),
'nesevinger': ('nesevinge',),
'nesevishet': ('nesevishet',),
'nesevisheten': ('nesevishet',),
'nesevishetene': ('nesevishet',),
'nesevisheter': ('nesevishet',),
'neshorn': ('neshorn',),
'neshorna': ('neshorn',),
'neshornene': ('neshorn',),
'neshornet': ('neshorn',),
'neskonge': ('neskonge',),
'neskongen': ('neskonge',),
'neskongene': ('neskonge',),
'neskonger': ('neskonge',),
'nesla': ('nesle',),
'nesle': ('nesle',),
'neslen': ('nesle',),
'neslene': ('nesle',),
'nesler': ('nesle',),
'neslecella': ('neslecelle',),
'neslecelle': ('neslecelle',),
'neslecellen': ('neslecelle',),
'neslecellene': ('neslecelle',),
'nesleceller': ('neslecelle',),
'nesledyr': ('nesledyr',),
'nesledyra': ('nesledyr',),
'nesledyrene': ('nesledyr',),
'nesledyret': ('nesledyr',),
'neslegraut': ('neslegraut',),
'neslegrauten': ('neslegraut',),
'neslegrautene': ('neslegraut',),
'neslegrauter': ('neslegraut',),
'neslegrøt': ('neslegrøt',),
'neslegrøten': ('neslegrøt',),
'neslegrøtene': ('neslegrøt',),
'neslegrøter': ('neslegrøt',),
'neslesommerfugl': ('neslesommerfugl',),
'neslesommerfuglen': ('neslesommerfugl',),
'neslesommerfuglene': ('neslesommerfugl',),
'neslesommerfugler': ('neslesommerfugl',),
'neslesuppa': ('neslesuppe',),
'neslesuppe': ('neslesuppe',),
'neslesuppen': ('neslesuppe',),
'neslesuppene': ('neslesuppe',),
'neslesupper': ('neslesuppe',),
'nest': ('nest',),
'nesta': ('nest',),
'nestene': ('nest',),
'nestet': ('nest',),
'neste': ('neste',),
'nesten': ('neste',),
'nestene': ('neste',),
'nester': ('neste',),
'nestekjærlighet': ('nestekjærlighet',),
'nestekjærligheta': ('nestekjærlighet',),
'nestekjærligheten': ('nestekjærlighet',),
'nestekjærlighetene': ('nestekjærlighet',),
'nestekjærligheter': ('nestekjærlighet',),
'nestemann': ('nestemann',),
'nestemannen': ('nestemann',),
'nestemenn': ('nestemann',),
'nestemennene': ('nestemann',),
'nestenulykka': ('nestenulykke',),
'nestenulykke': ('nestenulykke',),
'nestenulykken': ('nestenulykke',),
'nestenulykkene': ('nestenulykke',),
'nestenulykker': ('nestenulykke',),
'nestformann': ('nestformann',),
'nestformannen': ('nestformann',),
'nestformenn': ('nestformann',),
'nestformennene': ('nestformann',),
'nestkommanderende': ('nestkommanderende',),
'nestkommanderenden': ('nestkommanderende',),
'nestkommanderendene': ('nestkommanderende',),
'nestkommanderender': ('nestkommanderende',),
'nestleder': ('nestleder',),
'nestledere': ('nestleder',),
'nestlederen': ('nestleder',),
'nestlederer': ('nestleder',),
'nestlederne': ('nestleder',),
'nestor': ('nestor',),
'nestoren': ('nestor',),
'nestorene': ('nestor',),
'nestorer': ('nestor',),
'nett': ('nett',),
'netta': ('nett',),
'nettene': ('nett',),
'nettet': ('nett',),
'nettball': ('nettball',),
'nettballen': ('nettball',),
'nettballene': ('nettball',),
'nettballer': ('nettball',),
'nettelduk': ('nettelduk',),
'nettelduken': ('nettelduk',),
'netteldukene': ('nettelduk',),
'nettelduker': ('nettelduk',),
'netthinna': ('netthinne',),
'netthinne': ('netthinne',),
'netthinnen': ('netthinne',),
'netthinnene': ('netthinne',),
'netthinner': ('netthinne',),
'netting': ('netting',),
'nettingen': ('netting',),
'nettingene': ('netting',),
'nettinger': ('netting',),
'nettingstrømpa': ('nettingstrømpe',),
'nettingstrømpe': ('nettingstrømpe',),
'nettingstrømpen': ('nettingstrømpe',),
'nettingstrømpene': ('nettingstrømpe',),
'nettingstrømper': ('nettingstrømpe',),
'nettingtrøya': ('nettingtrøye',),
'nettingtrøye': ('nettingtrøye',),
'nettingtrøyen': ('nettingtrøye',),
'nettingtrøyene': ('nettingtrøye',),
'nettingtrøyer': ('nettingtrøye',),
'nettkjenning': ('nettkjenning',),
'nettkjenninga': ('nettkjenning',),
'nettkjenningen': ('nettkjenning',),
'nettkjenningene': ('nettkjenning',),
'nettkjenninger': ('nettkjenning',),
'nettmage': ('nettmage',),
'nettmagen': ('nettmage',),
'nettmagene': ('nettmage',),
'nettmager': ('nettmage',),
'nettmave': ('nettmave',),
'nettmaven': ('nettmave',),
'nettmavene': ('nettmave',),
'nettmaver': ('nettmave',),
'netto': ('netto',),
'nettoen': ('netto',),
'nettoene': ('netto',),
'nettoer': ('netto',),
'nettofortjenesta': ('nettofortjeneste',),
'nettofortjeneste': ('nettofortjeneste',),
'nettofortjenesten': ('nettofortjeneste',),
'nettofortjenestene': ('nettofortjeneste',),
'nettofortjenester': ('nettofortjeneste',),
'nettoinntekt': ('nettoinntekt',),
'nettoinntekta': ('nettoinntekt',),
'nettoinntekten': ('nettoinntekt',),
'nettoinntektene': ('nettoinntekt',),
'nettoinntekter': ('nettoinntekt',),
'nettonasjonalprodukt': ('nettonasjonalprodukt',),
'nettonasjonalprodukta': ('nettonasjonalprodukt',),
'nettonasjonalproduktene': ('nettonasjonalprodukt',),
'nettonasjonalprodukter': ('nettonasjonalprodukt',),
'nettonasjonalproduktet': ('nettonasjonalprodukt',),
'nettotonnasje': ('nettotonnasje',),
'nettotonnasjen': ('nettotonnasje',),
'nettotonnasjene': ('nettotonnasje',),
'nettotonnasjer': ('nettotonnasje',),
'nettovekt': ('nettovekt',),
'nettovekta': ('nettovekt',),
'nettovekten': ('nettovekt',),
'nettovektene': ('nettovekt',),
'nettovekter': ('nettovekt',),
'nettveng': ('nettveng',),
'nettvengen': ('nettveng',),
'nettvengene': ('nettveng',),
'nettvenger': ('nettveng',),
'nettverk': ('nettverk',),
'nettverka': ('nettverk',),
'nettverkene': ('nettverk',),
'nettverker': ('nettverk',),
'nettverket': ('nettverk',),
'nettving': ('nettving',),
'nettvingen': ('nettving',),
'nettvingene': ('nettving',),
'nettvinger': ('nettving',),
'nettvinge': ('nettvinge',),
'nettvingen': ('nettvinge',),
'nettvingene': ('nettvinge',),
'nettvinger': ('nettvinge',),
'neuralgi': ('neuralgi',),
'neuralgien': ('neuralgi',),
'neuralgiene': ('neuralgi',),
'neuralgier': ('neuralgi',),
'neurasteni': ('neurasteni',),
'neurastenien': ('neurasteni',),
'neurasteniene': ('neurasteni',),
'neurastenier': ('neurasteni',),
'neurasteniker': ('neurasteniker',),
'neurastenikere': ('neurasteniker',),
'neurastenikeren': ('neurasteniker',),
'neurastenikerer': ('neurasteniker',),
'neurastenikerne': ('neurasteniker',),
'neurolog': ('neurolog',),
'neurologen': ('neurolog',),
'neurologene': ('neurolog',),
'neurologer': ('neurolog',),
'neurose': ('neurose',),
'neurosen': ('neurose',),
'neurosene': ('neurose',),
'neuroser': ('neurose',),
'neurotiker': ('neurotiker',),
'neurotikere': ('neurotiker',),
'neurotikeren': ('neurotiker',),
'neurotikerer': ('neurotiker',),
'neurotikerne': ('neurotiker',),
'neve': ('neve',),
'neven': ('neve',),
'nevene': ('neve',),
'never': ('neve',),
'nevekamp': ('nevekamp',),
'nevekampen': ('nevekamp',),
'nevekampene': ('nevekamp',),
'nevekamper': ('nevekamp',),
'nevekjemper': ('nevekjemper',),
'nevekjempere': ('nevekjemper',),
'nevekjemperen': ('nevekjemper',),
'nevekjemperer': ('nevekjemper',),
'nevekjemperne': ('nevekjemper',),
'never': ('never',),
'neveren': ('never',),
'nevra': ('never',),
'nevre': ('never',),
'nevrene': ('never',),
'nevrer': ('never',),
'neverett': ('neverett',),
'neveretten': ('neverett',),
'neverettene': ('neverett',),
'neveretter': ('neverett',),
'neverkont': ('neverkont',),
'neverkonten': ('neverkont',),
'neverkontene': ('neverkont',),
'neverkonter': ('neverkont',),
'neverlur': ('neverlur',),
'neverluren': ('neverlur',),
'neverlurene': ('neverlur',),
'neverlurer': ('neverlur',),
'neverskrukka': ('neverskrukke',),
'neverskrukke': ('neverskrukke',),
'neverskrukken': ('neverskrukke',),
'neverskrukkene': ('neverskrukke',),
'neverskrukker': ('neverskrukke',),
'nevestein': ('nevestein',),
'nevesteinen': ('nevestein',),
'nevesteinene': ('nevestein',),
'nevesteiner': ('nevestein',),
'nevetak': ('nevetak',),
'nevetaka': ('nevetak',),
'nevetakene': ('nevetak',),
'nevetaket': ('nevetak',),
'nevneform': ('nevneform',),
'nevneforma': ('nevneform',),
'nevneformen': ('nevneform',),
'nevneformene': ('nevneform',),
'nevneformer': ('nevneform',),
'nevnelse': ('nevnelse',),
'nevnelsen': ('nevnelse',),
'nevnelsene': ('nevnelse',),
'nevnelser': ('nevnelse',),
'nevner': ('nevner',),
'nevnere': ('nevner',),
'nevneren': ('nevner',),
'nevnerer': ('nevner',),
'nevnerne': ('nevner',),
'nevning': ('nevning',),
'nevninga': ('nevning',),
'nevningen': ('nevning',),
'nevningene': ('nevning',),
'nevninger': ('nevning',),
'nevralgi': ('nevralgi',),
'nevralgien': ('nevralgi',),
'nevralgiene': ('nevralgi',),
'nevralgier': ('nevralgi',),
'nevrasteni': ('nevrasteni',),
'nevrastenien': ('nevrasteni',),
'nevrasteniene': ('nevrasteni',),
'nevrastenier': ('nevrasteni',),
'nevrasteniker': ('nevrasteniker',),
'nevrastenikere': ('nevrasteniker',),
'nevrastenikeren': ('nevrasteniker',),
'nevrastenikerer': ('nevrasteniker',),
'nevrastenikerne': ('nevrasteniker',),
'nevrolog': ('nevrolog',),
'nevrologen': ('nevrolog',),
'nevrologene': ('nevrolog',),
'nevrologer': ('nevrolog',),
'nevrose': ('nevrose',),
'nevrosen': ('nevrose',),
'nevrosene': ('nevrose',),
'nevroser': ('nevrose',),
'nevrotiker': ('nevrotiker',),
'nevrotikere': ('nevrotiker',),
'nevrotikeren': ('nevrotiker',),
'nevrotikerer': ('nevrotiker',),
'nevrotikerne': ('nevrotiker',),
'nevø': ('nevø',),
'nevøen': ('nevø',),
'nevøene': ('nevø',),
'nevøer': ('nevø',),
'newfoundlandshund': ('newfoundlandshund',),
'newfoundlandshunden': ('newfoundlandshund',),
'newfoundlandshundene': ('newfoundlandshund',),
'newfoundlandshunder': ('newfoundlandshund',),
'newfoundlender': ('newfoundlender',),
'newfoundlendere': ('newfoundlender',),
'newfoundlenderen': ('newfoundlender',),
'newfoundlenderer': ('newfoundlender',),
'newfoundlenderne': ('newfoundlender',),
'newfoundlender': ('newfoundlender',),
'newfoundlendere': ('newfoundlender',),
'newfoundlenderen': ('newfoundlender',),
'newfoundlenderer': ('newfoundlender',),
'newfoundlenderne': ('newfoundlender',),
'newfoundlending': ('newfoundlending',),
'newfoundlendingen': ('newfoundlending',),
'newfoundlendingene': ('newfoundlending',),
'newfoundlendinger': ('newfoundlending',),
'newton': ('newton',),
'newtonen': ('newton',),
'newtonene': ('newton',),
'newyorker': ('newyorker',),
'newyorkere': ('newyorker',),
'newyorkeren': ('newyorker',),
'newyorkerer': ('newyorker',),
'newyorkerne': ('newyorker',),
'newzealender': ('newzealender',),
'newzealendere': ('newzealender',),
'newzealenderen': ('newzealender',),
'newzealenderer': ('newzealender',),
'newzealenderne': ('newzealender',),
'newzealending': ('newzealending',),
'newzealendingen': ('newzealending',),
'newzealendingene': ('newzealending',),
'newzealendinger': ('newzealending',),
'niauge': ('niauge',),
'niaugen': ('niauge',),
'niaugene': ('niauge',),
'niauger': ('niauge',),
'nibba': ('nibbe',),
'nibbe': ('nibbe',),
'nibben': ('nibbe',),
'nibbene': ('nibbe',),
'nibber': ('nibbe',),
'nicaraguaner': ('nicaraguaner',),
'nicaraguanere': ('nicaraguaner',),
'nicaraguaneren': ('nicaraguaner',),
'nicaraguanerer': ('nicaraguaner',),
'nicaraguanerne': ('nicaraguaner',),
'nid': ('nid',),
'nida': ('nid',),
'nidene': ('nid',),
'nidet': ('nid',),
'nidel': ('nidel',),
'nidelen': ('nidel',),
'nidelene': ('nidel',),
'nideler': ('nidel',),
'niding': ('niding',),
'nidingen': ('niding',),
'nidingene': ('niding',),
'nidinger': ('niding',),
'nidingsverk': ('nidingsverk',),
'nidingsverka': ('nidingsverk',),
'nidingsverkene': ('nidingsverk',),
'nidingsverker': ('nidingsverk',),
'nidingsverket': ('nidingsverk',),
'nidskrift': ('nidskrift',),
'nidskrifta': ('nidskrift',),
'nidskriftene': ('nidskrift',),
'nidskrifter': ('nidskrift',),
'nidskriftet': ('nidskrift',),
'nidstang': ('nidstang',),
'nidstanga': ('nidstang',),
'nidstangen': ('nidstang',),
'nidstengene': ('nidstang',),
'nidstenger': ('nidstang',),
'nidvisa': ('nidvise',),
'nidvise': ('nidvise',),
'nidvisen': ('nidvise',),
'nidvisene': ('nidvise',),
'nidviser': ('nidvise',),
'niello': ('niello',),
'nielloa': ('niello',),
'nielloene': ('niello',),
'nielloet': ('niello',),
'niendedel': ('niendedel',),
'niendedelen': ('niendedel',),
'niendedelene': ('niendedel',),
'niendedeler': ('niendedel',),
'nier': ('nier',),
'niere': ('nier',),
'nieren': ('nier',),
'nierer': ('nier',),
'nierne': ('nier',),
'nierprøva': ('nierprøve',),
'nierprøve': ('nierprøve',),
'nierprøven': ('nierprøve',),
'nierprøvene': ('nierprøve',),
'nierprøver': ('nierprøve',),
'niesa': ('niese',),
'niese': ('niese',),
'niesen': ('niese',),
'niesene': ('niese',),
'nieser': ('niese',),
'nigerer': ('nigerer',),
'nigerere': ('nigerer',),
'nigereren': ('nigerer',),
'nigererer': ('nigerer',),
'nigererne': ('nigerer',),
'nigerianer': ('nigerianer',),
'nigerianere': ('nigerianer',),
'nigerianeren': ('nigerianer',),
'nigerianerer': ('nigerianer',),
'nigerianerne': ('nigerianer',),
'nigger': ('nigger',),
'niggere': ('nigger',),
'niggeren': ('nigger',),
'niggerer': ('nigger',),
'niggerne': ('nigger',),
'nihilisme': ('nihilisme',),
'nihilismen': ('nihilisme',),
'nihilismene': ('nihilisme',),
'nihilismer': ('nihilisme',),
'nihilist': ('nihilist',),
'nihilisten': ('nihilist',),
'nihilistene': ('nihilist',),
'nihilister': ('nihilist',),
'nikk': ('nikk',),
'nikka': ('nikk',),
'nikken': ('nikk',),
'nikkene': ('nikk',),
'nikket': ('nikk',),
'nikkedokka': ('nikkedokke',),
'nikkedokke': ('nikkedokke',),
'nikkedokken': ('nikkedokke',),
'nikkedokkene': ('nikkedokke',),
'nikkedokker': ('nikkedokke',),
'nikkedukka': ('nikkedukke',),
'nikkedukke': ('nikkedukke',),
'nikkedukken': ('nikkedukke',),
'nikkedukkene': ('nikkedukke',),
'nikkedukker': ('nikkedukke',),
'nikkel': ('nikkel',),
'nikkela': ('nikkel',),
'nikkelen': ('nikkel',),
'nikkelene': ('nikkel',),
'nikkeler': ('nikkel',),
'nikkelet': ('nikkel',),
'nikkelverk': ('nikkelverk',),
'nikkelverka': ('nikkelverk',),
'nikkelverkene': ('nikkelverk',),
'nikkelverker': ('nikkelverk',),
'nikkelverket': ('nikkelverk',),
'nikkers': ('nikkers',),
'nikkersen': ('nikkers',),
'nikkersene': ('nikkers',),
'nikkerser': ('nikkers',),
'nikotin': ('nikotin',),
'nikotina': ('nikotin',),
'nikotinen': ('nikotin',),
'nikotinene': ('nikotin',),
'nikotiner': ('nikotin',),
'nikotinet': ('nikotin',),
'nikotinist': ('nikotinist',),
'nikotinisten': ('nikotinist',),
'nikotinistene': ('nikotinist',),
'nikotinister': ('nikotinist',),
'nikotinslave': ('nikotinslave',),
'nikotinslaven': ('nikotinslave',),
'nikotinslavene': ('nikotinslave',),
'nikotinslaver': ('nikotinslave',),
'nikotinvrak': ('nikotinvrak',),
'nikotinvraka': ('nikotinvrak',),
'nikotinvrakene': ('nikotinvrak',),
'nikotinvraket': ('nikotinvrak',),
'nikrom': ('nikrom',),
'nikroma': ('nikrom',),
'nikromene': ('nikrom',),
'nikromet': ('nikrom',),
'nimbus': ('nimbus',),
'nimbusen': ('nimbus',),
'nimbusene': ('nimbus',),
'nimbuser': ('nimbus',),
'nimrod': ('nimrod',),
'nimroden': ('nimrod',),
'nimrodene': ('nimrod',),
'nimroder': ('nimrod',),
'niob': ('niob',),
'nioba': ('niob',),
'niobene': ('niob',),
'niobet': ('niob',),
'nip': ('nip',),
'nipen': ('nip',),
'nipene': ('nip',),
'niper': ('nip',),
'nipa': ('nipe',),
'nipe': ('nipe',),
'nipen': ('nipe',),
'nipene': ('nipe',),
'niper': ('nipe',),
'niplene': ('nippel',),
'nipler': ('nippel',),
'nippel': ('nippel',),
'nippelen': ('nippel',),
'nippetang': ('nippetang',),
'nippetanga': ('nippetang',),
'nippetangen': ('nippetang',),
'nippetengene': ('nippetang',),
'nippetenger': ('nippetang',),
'nippflo': ('nippflo',),
'nippfloa': ('nippflo',),
'nippfloen': ('nippflo',),
'nippfloene': ('nippflo',),
'nippfloer': ('nippflo',),
'nipptid': ('nipptid',),
'nipptida': ('nipptid',),
'nipptiden': ('nipptid',),
'nipptidene': ('nipptid',),
'nipptider': ('nipptid',),
'nips': ('nips',),
'nipsen': ('nips',),
'nipsene': ('nips',),
'nipser': ('nips',),
'nipsfigur': ('nipsfigur',),
'nipsfiguren': ('nipsfigur',),
'nipsfigurene': ('nipsfigur',),
'nipsfigurer': ('nipsfigur',),
'nirvana': ('nirvana',),
'nirvanaen': ('nirvana',),
'nirvanaene': ('nirvana',),
'nirvanaer': ('nirvana',),
'nirvanaet': ('nirvana',),
'nisa': ('nise',),
'nise': ('nise',),
'nisen': ('nise',),
'nisene': ('nise',),
'niser': ('nise',),
'nisje': ('nisje',),
'nisjen': ('nisje',),
'nisjene': ('nisje',),
'nisjer': ('nisje',),
'nisse': ('nisse',),
'nissen': ('nisse',),
'nissene': ('nisse',),
'nisser': ('nisse',),
'nissehua': ('nissehue',),
'nissehue': ('nissehue',),
'nissehuen': ('nissehue',),
'nissehuene': ('nissehue',),
'nissehuer': ('nissehue',),
'nissehuva': ('nissehuve',),
'nissehuve': ('nissehuve',),
'nissehuven': ('nissehuve',),
'nissehuvene': ('nissehuve',),
'nissehuver': ('nissehuve',),
'nisseluva': ('nisseluve',),
'nisseluve': ('nisseluve',),
'nisseluven': ('nisseluve',),
'nisseluvene': ('nisseluve',),
'nisseluver': ('nisseluve',),
'nista': ('niste',),
'niste': ('niste',),
'nisten': ('niste',),
'nistene': ('niste',),
'nister': ('niste',),
'nistemat': ('nistemat',),
'nistematen': ('nistemat',),
'nistematene': ('nistemat',),
'nistemater': ('nistemat',),
'nistepakka': ('nistepakke',),
'nistepakke': ('nistepakke',),
'nistepakken': ('nistepakke',),
'nistepakkene': ('nistepakke',),
'nistepakker': ('nistepakke',),
'nitall': ('nitall',),
'nitalla': ('nitall',),
'nitallene': ('nitall',),
'nitallet': ('nitall',),
'nite': ('nite',),
'niten': ('nite',),
'nitene': ('nite',),
'niter': ('nite',),
'nitid': ('nitid',),
'nitida': ('nitid',),
'nitiden': ('nitid',),
'nitidene': ('nitid',),
'nitider': ('nitid',),
'nitiditet': ('nitiditet',),
'nitiditeten': ('nitiditet',),
'nitiditetene': ('nitiditet',),
'nitiditeter': ('nitiditet',),
'nitrat': ('nitrat',),
'nitrata': ('nitrat',),
'nitratene': ('nitrat',),
'nitrater': ('nitrat',),
'nitratet': ('nitrat',),
'nitrid': ('nitrid',),
'nitrida': ('nitrid',),
'nitridene': ('nitrid',),
'nitrider': ('nitrid',),
'nitridet': ('nitrid',),
'nitritt': ('nitritt',),
'nitritta': ('nitritt',),
'nitritten': ('nitritt',),
'nitrittene': ('nitritt',),
'nitritter': ('nitritt',),
'nitrittet': ('nitritt',),
'nitrocellulose': ('nitrocellulose',),
'nitrocellulosen': ('nitrocellulose',),
'nitrocellulosene': ('nitrocellulose',),
'nitrocelluloser': ('nitrocellulose',),
'nitrogen': ('nitrogen',),
'nitrogena': ('nitrogen',),
'nitrogenene': ('nitrogen',),
'nitrogenet': ('nitrogen',),
'nitroglyserin': ('nitroglyserin',),
'nitroglyserinen': ('nitroglyserin',),
'nitroglyserinene': ('nitroglyserin',),
'nitroglyseriner': ('nitroglyserin',),
'nitroglyserol': ('nitroglyserol',),
'nitroglyserolen': ('nitroglyserol',),
'nitroglyserolene': ('nitroglyserol',),
'nitroglyseroler': ('nitroglyserol',),
'nitrogruppa': ('nitrogruppe',),
'nitrogruppe': ('nitrogruppe',),
'nitrogruppen': ('nitrogruppe',),
'nitrogruppene': ('nitrogruppe',),
'nitrogrupper': ('nitrogruppe',),
'nittendel': ('nittendel',),
'nittendelen': ('nittendel',),
'nittendelene': ('nittendel',),
'nittendeler': ('nittendel',),
'nittenhundretall': ('nittenhundretall',),
'nittenhundretalla': ('nittenhundretall',),
'nittenhundretallene': ('nittenhundretall',),
'nittenhundretallet': ('nittenhundretall',),
'nittenåring': ('nittenåring',),
'nittenåringen': ('nittenåring',),
'nittenåringene': ('nittenåring',),
'nittenåringer': ('nittenåring',),
'nittenårsalder': ('nittenårsalder',),
'nittenårsaldere': ('nittenårsalder',),
'nittenårsalderen': ('nittenårsalder',),
'nittenårsalderer': ('nittenårsalder',),
'nittenårsalderne': ('nittenårsalder',),
'nittenårsaldre': ('nittenårsalder',),
'nittenårsaldrene': ('nittenårsalder',),
'nittenårsaldrer': ('nittenårsalder',),
'nittidel': ('nittidel',),
'nittidelen': ('nittidel',),
'nittidelene': ('nittidel',),
'nittideler': ('nittidel',),
'nittiår': ('nittiår',),
'nittiåra': ('nittiår',),
'nittiårene': ('nittiår',),
'nittiåret': ('nittiår',),
'nittiåring': ('nittiåring',),
'nittiåringen': ('nittiåring',),
'nittiåringene': ('nittiåring',),
'nittiåringer': ('nittiåring',),
'nittiårsdag': ('nittiårsdag',),
'nittiårsdagen': ('nittiårsdag',),
'nittiårsdagene': ('nittiårsdag',),
'nittiårsdager': ('nittiårsdag',),
'nivellerinstrument': ('nivellerinstrument',),
'nivellerinstrumenta': ('nivellerinstrument',),
'nivellerinstrumentene': ('nivellerinstrument',),
'nivellerinstrumenter': ('nivellerinstrument',),
'nivellerinstrumentet': ('nivellerinstrument',),
'nivå': ('nivå',),
'nivåa': ('nivå',),
'nivåene': ('nivå',),
'nivåer': ('nivå',),
'nivået': ('nivå',),
'nivåsenking': ('nivåsenking',),
'nivåsenkinga': ('nivåsenking',),
'nivåsenkingen': ('nivåsenking',),
'nivåsenkingene': ('nivåsenking',),
'nivåsenkinger': ('nivåsenking',),
'nivåsenkning': ('nivåsenkning',),
'nivåsenkninga': ('nivåsenkning',),
'nivåsenkningen': ('nivåsenkning',),
'nivåsenkningene': ('nivåsenkning',),
'nivåsenkninger': ('nivåsenkning',),
'niåring': ('niåring',),
'niåringen': ('niåring',),
'niåringene': ('niåring',),
'niåringer': ('niåring',),
'niårsalder': ('niårsalder',),
'niårsaldere': ('niårsalder',),
'niårsalderen': ('niårsalder',),
'niårsalderer': ('niårsalder',),
'niårsalderne': ('niårsalder',),
'niårsaldre': ('niårsalder',),
'niårsaldrene': ('niårsalder',),
'niårsaldrer': ('niårsalder',),
'niøye': ('niøye',),
'niøyen': ('niøye',),
'niøyene': ('niøye',),
'niøyer': ('niøye',),
'noaide': ('noaide',),
'noaiden': ('noaide',),
'noaidene': ('noaide',),
'noaider': ('noaide',),
'noaord': ('noaord',),
'noaorda': ('noaord',),
'noaordene': ('noaord',),
'noaordet': ('noaord',),
'nobelium': ('nobelium',),
'nobeliuma': ('nobelium',),
'nobeliumene': ('nobelium',),
'nobeliumet': ('nobelium',),
'nobelpris': ('nobelpris',),
'nobelprisen': ('nobelpris',),
'nobelprisene': ('nobelpris',),
'nobelpriser': ('nobelpris',),
'nobilitet': ('nobilitet',),
'nobiliteten': ('nobilitet',),
'nobilitetene': ('nobilitet',),
'nobiliteter': ('nobilitet',),
'noblesse': ('noblesse',),
'noblessen': ('noblesse',),
'noblessene': ('noblesse',),
'noblesser': ('noblesse',),
'nodul': ('nodul',),
'nodulen': ('nodul',),
'nodulene': ('nodul',),
'noduler': ('nodul',),
'nogen': ('nogen',),
'nogenen': ('nogen',),
'nogenene': ('nogen',),
'nogener': ('nogen',),
'nokk': ('nokk',),
'nokken': ('nokk',),
'nokkene': ('nokk',),
'nokker': ('nokk',),
'nokke': ('nokke',),
'nokken': ('nokke',),
'nokkene': ('nokke',),
'nokker': ('nokke',),
'noksagt': ('noksagt',),
'noksagten': ('noksagt',),
'noksagtene': ('noksagt',),
'noksagter': ('noksagt',),
'nokturne': ('nokturne',),
'nokturnen': ('nokturne',),
'nokturnene': ('nokturne',),
'nokturner': ('nokturne',),
'nolo': ('nolo',),
'noloen': ('nolo',),
'noloene': ('nolo',),
'noloer': ('nolo',),
'nom de guerre': ('nom de guerre',),
'nomade': ('nomade',),
'nomaden': ('nomade',),
'nomadene': ('nomade',),
'nomader': ('nomade',),
'nomadefolk': ('nomadefolk',),
'nomadefolka': ('nomadefolk',),
'nomadefolkene': ('nomadefolk',),
'nomadefolket': ('nomadefolk',),
'nomadisme': ('nomadisme',),
'nomadismen': ('nomadisme',),
'nomadismene': ('nomadisme',),
'nomadismer': ('nomadisme',),
'nomen': ('nomen',),
'nomena': ('nomen',),
'nomenene': ('nomen',),
'nomener': ('nomen',),
'nomenet': ('nomen',),
'nomen agentis': ('nomen agentis',),
'nomenklatur': ('nomenklatur',),
'nomenklatura': ('nomenklatur',),
'nomenklaturen': ('nomenklatur',),
'nomenklaturene': ('nomenklatur',),
'nomenklaturer': ('nomenklatur',),
'nomenklaturet': ('nomenklatur',),
'nominal': ('nominal',),
'nominala': ('nominal',),
'nominalene': ('nominal',),
'nominaler': ('nominal',),
'nominalet': ('nominal',),
'nominalbøying': ('nominalbøying',),
'nominalbøyinga': ('nominalbøying',),
'nominalbøyingen': ('nominalbøying',),
'nominalbøyingene': ('nominalbøying',),
'nominalbøyinger': ('nominalbøying',),
'nominalbøyning': ('nominalbøyning',),
'nominalbøyninga': ('nominalbøyning',),
'nominalbøyningen': ('nominalbøyning',),
'nominalbøyningene': ('nominalbøyning',),
'nominalbøyninger': ('nominalbøyning',),
'nominalisme': ('nominalisme',),
'nominalismen': ('nominalisme',),
'nominalismene': ('nominalisme',),
'nominalismer': ('nominalisme',),
'nominasjon': ('nominasjon',),
'nominasjonen': ('nominasjon',),
'nominasjonene': ('nominasjon',),
'nominasjoner': ('nominasjon',),
'nominasjonsmøta': ('nominasjonsmøte',),
'nominasjonsmøte': ('nominasjonsmøte',),
'nominasjonsmøtene': ('nominasjonsmøte',),
'nominasjonsmøter': ('nominasjonsmøte',),
'nominasjonsmøtet': ('nominasjonsmøte',),
'nominativ': ('nominativ',),
'nominativen': ('nominativ',),
'nominativene': ('nominativ',),
'nominativer': ('nominativ',),
'non': ('non',),
'nonen': ('non',),
'nonene': ('non',),
'noner': ('non',),
'non': ('non',),
'nona': ('non',),
'nonene': ('non',),
'nonet': ('non',),
'nonchalanse': ('nonchalanse',),
'nonchalansen': ('nonchalanse',),
'nonchalansene': ('nonchalanse',),
'nonchalanser': ('nonchalanse',),
'none': ('none',),
'nonen': ('none',),
'nonene': ('none',),
'noner': ('none',),
'noneakkord': ('noneakkord',),
'noneakkorden': ('noneakkord',),
'noneakkordene': ('noneakkord',),
'noneakkorder': ('noneakkord',),
'nonett': ('nonett',),
'nonetten': ('nonett',),
'nonettene': ('nonett',),
'nonetter': ('nonett',),
'nonintervensjon': ('nonintervensjon',),
'nonintervensjonen': ('nonintervensjon',),
'nonintervensjonene': ('nonintervensjon',),
'nonintervensjoner': ('nonintervensjon',),
'nonkombattant': ('nonkombattant',),
'nonkombattanten': ('nonkombattant',),
'nonkombattantene': ('nonkombattant',),
'nonkombattanter': ('nonkombattant',),
'nonkonformisme': ('nonkonformisme',),
'nonkonformismen': ('nonkonformisme',),
'nonkonformismene': ('nonkonformisme',),
'nonkonformismer': ('nonkonformisme',),
'nonkonformist': ('nonkonformist',),
'nonkonformisten': ('nonkonformist',),
'nonkonformistene': ('nonkonformist',),
'nonkonformister': ('nonkonformist',),
'nonna': ('nonne',),
'nonne': ('nonne',),
'nonnen': ('nonne',),
'nonnene': ('nonne',),
'nonner': ('nonne',),
'nonnekloster': ('nonnekloster',),
'nonneklosteret': ('nonnekloster',),
'nonneklostra': ('nonnekloster',),
'nonneklostre': ('nonnekloster',),
'nonneklostrene': ('nonnekloster',),
'nonneklostret': ('nonnekloster',),
'nonneorden': ('nonneorden',),
'nonneordenen': ('nonneorden',),
'nonneordenene': ('nonneorden',),
'nonneordener': ('nonneorden',),
'nonpareille': ('nonpareille',),
'nonprofitbasis': ('nonprofitbasis',),
'nonprofitbasisen': ('nonprofitbasis',),
'nonprofitbasisene': ('nonprofitbasis',),
'nonprofitbasiser': ('nonprofitbasis',),
'nonprofitorganisasjon': ('nonprofitorganisasjon',),
'nonprofitorganisasjonen': ('nonprofitorganisasjon',),
'nonprofitorganisasjonene': ('nonprofitorganisasjon',),
'nonprofitorganisasjoner': ('nonprofitorganisasjon',),
'nonsblom': ('nonsblom',),
'nonsblommen': ('nonsblom',),
'nonsblommene': ('nonsblom',),
'nonsblommer': ('nonsblom',),
'nonsens': ('nonsens',),
'nonsensa': ('nonsens',),
'nonsensene': ('nonsens',),
'nonsenset': ('nonsens',),
'nonsensdikt': ('nonsensdikt',),
'nonsensdikta': ('nonsensdikt',),
'nonsensdiktene': ('nonsensdikt',),
'nonsensdiktet': ('nonsensdikt',),
'nonstopforestilling': ('nonstopforestilling',),
'nonstopforestillinga': ('nonstopforestilling',),
'nonstopforestillingen': ('nonstopforestilling',),
'nonstopforestillingene': ('nonstopforestilling',),
'nonstopforestillinger': ('nonstopforestilling',),
'nonstopmusikk': ('nonstopmusikk',),
'nonstopmusikken': ('nonstopmusikk',),
'nonstopmusikkene': ('nonstopmusikk',),
'nonstopmusikker': ('nonstopmusikk',),
'nor': ('nor',),
'nora': ('nor',),
'norene': ('nor',),
'noret': ('nor',),
'nor': ('nor',),
'nora': ('nor',),
'norene': ('nor',),
'noret': ('nor',),
'nord': ('nord',),
'nordadrag': ('nordadrag',),
'nordadraga': ('nordadrag',),
'nordadragene': ('nordadrag',),
'nordadraget': ('nordadrag',),
'nordamerikaner': ('nordamerikaner',),
'nordamerikanere': ('nordamerikaner',),
'nordamerikaneren': ('nordamerikaner',),
'nordamerikanerer': ('nordamerikaner',),
'nordamerikanerne': ('nordamerikaner',),
'nordaust': ('nordaust',),
'nordausten': ('nordaust',),
'nordaustene': ('nordaust',),
'nordauster': ('nordaust',),
'nordaust': ('nordaust',),
'nordavind': ('nordavind',),
'nordavinden': ('nordavind',),
'nordavindene': ('nordavind',),
'nordavinder': ('nordavind',),
'nordavær': ('nordavær',),
'nordaværa': ('nordavær',),
'nordaværene': ('nordavær',),
'nordaværet': ('nordavær',),
'nordbagg': ('nordbagg',),
'nordbaggen': ('nordbagg',),
'nordbaggene': ('nordbagg',),
'nordbagger': ('nordbagg',),
'nordbagge': ('nordbagge',),
'nordbaggen': ('nordbagge',),
'nordbaggene': ('nordbagge',),
'nordbagger': ('nordbagge',),
'nordboer': ('nordboer',),
'nordboere': ('nordboer',),
'nordboeren': ('nordboer',),
'nordboerer': ('nordboer',),
'nordboerne': ('nordboer',),
'nordbu': ('nordbu',),
'nordbuen': ('nordbu',),
'nordbuene': ('nordbu',),
'nordbuer': ('nordbu',),
'nordbuer': ('nordbuer',),
'nordbuere': ('nordbuer',),
'nordbueren': ('nordbuer',),
'nordbuerer': ('nordbuer',),
'nordbuerne': ('nordbuer',),
'nordfjording': ('nordfjording',),
'nordfjordingen': ('nordfjording',),
'nordfjordingene': ('nordfjording',),
'nordfjordinger': ('nordfjording',),
'nordhimlene': ('nordhimmel',),
'nordhimler': ('nordhimmel',),
'nordhimmel': ('nordhimmel',),
'nordhimmelen': ('nordhimmel',),
'nordisme': ('nordisme',),
'nordismen': ('nordisme',),
'nordismene': ('nordisme',),
'nordismer': ('nordisme',),
'nordist': ('nordist',),
'nordisten': ('nordist',),
'nordistene': ('nordist',),
'nordister': ('nordist',),
'nordistikk': ('nordistikk',),
'nordistikken': ('nordistikk',),
'nordistikkene': ('nordistikk',),
'nordistikker': ('nordistikk',),
'nordkoreaner': ('nordkoreaner',),
'nordkoreanere': ('nordkoreaner',),
'nordkoreaneren': ('nordkoreaner',),
'nordkoreanerer': ('nordkoreaner',),
'nordkoreanerne': ('nordkoreaner',),
'nordlandsbåt': ('nordlandsbåt',),
'nordlandsbåten': ('nordlandsbåt',),
'nordlandsbåtene': ('nordlandsbåt',),
'nordlandsbåter': ('nordlandsbåt',),
'nordlandshest': ('nordlandshest',),
'nordlandshesten': ('nordlandshest',),
'nordlandshestene': ('nordlandshest',),
'nordlandshester': ('nordlandshest',),
'nordlending': ('nordlending',),
'nordlendingen': ('nordlending',),
'nordlendingene': ('nordlending',),
'nordlendinger': ('nordlending',),
'nordlys': ('nordlys',),
'nordlysa': ('nordlys',),
'nordlysene': ('nordlys',),
'nordlyset': ('nordlys',),
'nordmann': ('nordmann',),
'nordmannen': ('nordmann',),
'nordmenn': ('nordmann',),
'nordmennene': ('nordmann',),
'nordmøring': ('nordmøring',),
'nordmøringen': ('nordmøring',),
'nordmøringene': ('nordmøring',),
'nordmøringer': ('nordmøring',),
'nordnorsk': ('nordnorsk',),
'nordnorsken': ('nordnorsk',),
'nordnorskene': ('nordnorsk',),
'nordnorsker': ('nordnorsk',),
'nordost': ('nordost',),
'nordosten': ('nordost',),
'nordostene': ('nordost',),
'nordoster': ('nordost',),
'nordost': ('nordost',),
'nordpol': ('nordpol',),
'nordpolen': ('nordpol',),
'nordpolene': ('nordpol',),
'nordpoler': ('nordpol',),
'nordpolsekspedisjon': ('nordpolsekspedisjon',),
'nordpolsekspedisjonen': ('nordpolsekspedisjon',),
'nordpolsekspedisjonene': ('nordpolsekspedisjon',),
'nordpolsekspedisjoner': ('nordpolsekspedisjon',),
'nordpolsfarer': ('nordpolsfarer',),
'nordpolsfarere': ('nordpolsfarer',),
'nordpolsfareren': ('nordpolsfarer',),
'nordpolsfarerer': ('nordpolsfarer',),
'nordpolsfarerne': ('nordpolsfarer',),
'nordsamisk': ('nordsamisk',),
'nordsamisken': ('nordsamisk',),
'nordsamiskene': ('nordsamisk',),
'nordsamisker': ('nordsamisk',),
'nordsida': ('nordside',),
'nordside': ('nordside',),
'nordsiden': ('nordside',),
'nordsidene': ('nordside',),
'nordsider': ('nordside',),
'nordsjøolja': ('nordsjøolje',),
'nordsjøolje': ('nordsjøolje',),
'nordsjøoljen': ('nordsjøolje',),
'nordsjøoljene': ('nordsjøolje',),
'nordsjøoljer': ('nordsjøolje',),
'nordsjøsild': ('nordsjøsild',),
'nordsjøsilda': ('nordsjøsild',),
'nordsjøsilden': ('nordsjøsild',),
'nordsjøsildene': ('nordsjøsild',),
'nordsjøsilder': ('nordsjøsild',),
'nordstat': ('nordstat',),
'nordstaten': ('nordstat',),
'nordstatene': ('nordstat',),
'nordstater': ('nordstat',),
'nordstjerna': ('nordstjerne',),
'nordstjerne': ('nordstjerne',),
'nordstjernen': ('nordstjerne',),
'nordstjernene': ('nordstjerne',),
'nordstjerner': ('nordstjerne',),
'nordtrønder': ('nordtrønder',),
'nordtrøndere': ('nordtrønder',),
'nordtrønderen': ('nordtrønder',),
'nordtrønderer': ('nordtrønder',),
'nordtrønderne': ('nordtrønder',),
'nordvest': ('nordvest',),
'nordvesten': ('nordvest',),
'nordvestene': ('nordvest',),
'nordvester': ('nordvest',),
'nordvest': ('nordvest',),
'nordvisjonsprogram': ('nordvisjonsprogram',),
'nordvisjonsprogramma': ('nordvisjonsprogram',),
'nordvisjonsprogrammene': ('nordvisjonsprogram',),
'nordvisjonsprogrammer': ('nordvisjonsprogram',),
'nordvisjonsprogrammet': ('nordvisjonsprogram',),
'nordvisjonssending': ('nordvisjonssending',),
'nordvisjonssendinga': ('nordvisjonssending',),
'nordvisjonssendingen': ('nordvisjonssending',),
'nordvisjonssendingene': ('nordvisjonssending',),
'nordvisjonssendinger': ('nordvisjonssending',),
'nordyemenitt': ('nordyemenitt',),
'nordyemenitten': ('nordyemenitt',),
'nordyemenittene': ('nordyemenitt',),
'nordyemenitter': ('nordyemenitt',),
'nordøst': ('nordøst',),
'nordøsten': ('nordøst',),
'nordøstene': ('nordøst',),
'nordøster': ('nordøst',),
'nordøst': ('nordøst',),
'norgescup': ('norgescup',),
'norgescupen': ('norgescup',),
'norgescupene': ('norgescup',),
'norgescuper': ('norgescup',),
'norgesglas': ('norgesglas',),
'norgesglasa': ('norgesglas',),
'norgesglasene': ('norgesglas',),
'norgesglaset': ('norgesglas',),
'norgesglass': ('norgesglass',),
'norgesglassa': ('norgesglass',),
'norgesglassene': ('norgesglass',),
'norgesglasset': ('norgesglass',),
'norgesmester': ('norgesmester',),
'norgesmestere': ('norgesmester',),
'norgesmesteren': ('norgesmester',),
'norgesmesterer': ('norgesmester',),
'norgesmesterne': ('norgesmester',),
'norgesmestre': ('norgesmester',),
'norgesmestrene': ('norgesmester',),
'norgesmestrer': ('norgesmester',),
'norgesmesterskap': ('norgesmesterskap',),
'norgesmesterskapa': ('norgesmesterskap',),
'norgesmesterskapene': ('norgesmesterskap',),
'norgesmesterskaper': ('norgesmesterskap',),
'norgesmesterskapet': ('norgesmesterskap',),
'norgesrekord': ('norgesrekord',),
'norgesrekorden': ('norgesrekord',),
'norgesrekordene': ('norgesrekord',),
'norgesrekorder': ('norgesrekord',),
'norgessalpeter': ('norgessalpeter',),
'norgessalpetere': ('norgessalpeter',),
'norgessalpeteren': ('norgessalpeter',),
'norgessalpeterer': ('norgessalpeter',),
'norgessalpeterne': ('norgessalpeter',),
'norgessalpetre': ('norgessalpeter',),
'norgessalpetrene': ('norgessalpeter',),
'norgessalpetrer': ('norgessalpeter',),
'norgesvenn': ('norgesvenn',),
'norgesvennen': ('norgesvenn',),
'norgesvennene': ('norgesvenn',),
'norgesvenner': ('norgesvenn',),
'norm': ('norm',),
'normen': ('norm',),
'normene': ('norm',),
'normer': ('norm',),
'normal': ('normal',),
'normalen': ('normal',),
'normalene': ('normal',),
'normaler': ('normal',),
'normalbakke': ('normalbakke',),
'normalbakken': ('normalbakke',),
'normalbakkene': ('normalbakke',),
'normalbakker': ('normalbakke',),
'normalfilm': ('normalfilm',),
'normalfilmen': ('normalfilm',),
'normalfilmene': ('normalfilm',),
'normalfilmer': ('normalfilm',),
'normalfordeling': ('normalfordeling',),
'normalfordelinga': ('normalfordeling',),
'normalfordelingen': ('normalfordeling',),
'normalfordelingene': ('normalfordeling',),
'normalfordelinger': ('normalfordeling',),
'normalfordelingskurve': ('normalfordelingskurve',),
'normalfordelingskurven': ('normalfordelingskurve',),
'normalfordelingskurvene': ('normalfordelingskurve',),
'normalfordelingskurver': ('normalfordelingskurve',),
'normalisering': ('normalisering',),
'normaliseringa': ('normalisering',),
'normaliseringen': ('normalisering',),
'normaliseringene': ('normalisering',),
'normaliseringer': ('normalisering',),
'normalitet': ('normalitet',),
'normaliteten': ('normalitet',),
'normalitetene': ('normalitet',),
'normaliteter': ('normalitet',),
'normallys': ('normallys',),
'normallysa': ('normallys',),
'normallysene': ('normallys',),
'normallyset': ('normallys',),
'normallønn': ('normallønn',),
'normallønna': ('normallønn',),
'normallønnen': ('normallønn',),
'normallønnene': ('normallønn',),
'normallønner': ('normallønn',),
'normalløsning': ('normalløsning',),
'normalløsninga': ('normalløsning',),
'normalløsningen': ('normalløsning',),
'normalløsningene': ('normalløsning',),
'normalløsninger': ('normalløsning',),
'normalmål': ('normalmål',),
'normalmåla': ('normalmål',),
'normalmålene': ('normalmål',),
'normalmålet': ('normalmål',),
'normalplan': ('normalplan',),
'normalplanen': ('normalplan',),
'normalplanene': ('normalplan',),
'normalplaner': ('normalplan',),
'normalplan': ('normalplan',),
'normalplana': ('normalplan',),
'normalplanene': ('normalplan',),
'normalplanet': ('normalplan',),
'normalprosa': ('normalprosa',),
'normalprosaen': ('normalprosa',),
'normalprosaene': ('normalprosa',),
'normalprosaer': ('normalprosa',),
'normalspråk': ('normalspråk',),
'normalspråka': ('normalspråk',),
'normalspråkene': ('normalspråk',),
'normalspråket': ('normalspråk',),
'normaltemperatur': ('normaltemperatur',),
'normaltemperaturen': ('normaltemperatur',),
'normaltemperaturene': ('normaltemperatur',),
'normaltemperaturer': ('normaltemperatur',),
'normaltid': ('normaltid',),
'normaltida': ('normaltid',),
'normaltiden': ('normaltid',),
'normaltidene': ('normaltid',),
'normaltider': ('normaltid',),
'normaltilstand': ('normaltilstand',),
'normaltilstanden': ('normaltilstand',),
'normaltilstandene': ('normaltilstand',),
'normaltilstander': ('normaltilstand',),
'normalår': ('normalår',),
'normalåra': ('normalår',),
'normalårene': ('normalår',),
'normalåret': ('normalår',),
'normannafolk': ('normannafolk',),
'normannafolka': ('normannafolk',),
'normannafolkene': ('normannafolk',),
'normannafolket': ('normannafolk',),
'normannaost': ('normannaost',),
'normannaosten': ('normannaost',),
'normannaostene': ('normannaost',),
'normannaoster': ('normannaost',),
'normanner': ('normanner',),
'normannere': ('normanner',),
'normanneren': ('normanner',),
'normannerer': ('normanner',),
'normannerne': ('normanner',),
'normpunkt': ('normpunkt',),
'normpunkta': ('normpunkt',),
'normpunktene': ('normpunkt',),
'normpunkter': ('normpunkt',),
'normpunktet': ('normpunkt',),
'norn': ('norn',),
'nornen': ('norn',),
'nornene': ('norn',),
'norner': ('norn',),
'norna': ('norne',),
'norne': ('norne',),
'nornen': ('norne',),
'nornene': ('norne',),
'norner': ('norne',),
'norrønafolk': ('norrønafolk',),
'norrønafolka': ('norrønafolk',),
'norrønafolkene': ('norrønafolk',),
'norrønafolket': ('norrønafolk',),
'norrønfilolog': ('norrønfilolog',),
'norrønfilologen': ('norrønfilolog',),
'norrønfilologene': ('norrønfilolog',),
'norrønfilologer': ('norrønfilolog',),
'norrønlinja': ('norrønlinje',),
'norrønlinje': ('norrønlinje',),
'norrønlinjen': ('norrønlinje',),
'norrønlinjene': ('norrønlinje',),
'norrønlinjer': ('norrønlinje',),
'norrønt': ('norrønt',),
'nors': ('nors',),
'norsen': ('nors',),
'norsene': ('nors',),
'norser': ('nors',),
'norsk': ('norsk',),
'norsken': ('norsk',),
'norskene': ('norsk',),
'norsker': ('norsk',),
'norsk-dansk': ('norsk-dansk',),
'norsk-dansken': ('norsk-dansk',),
'norsk-danskene': ('norsk-dansk',),
'norsk-dansker': ('norsk-dansk',),
'norsk-svensk': ('norsk-svensk',),
'norsk-svensken': ('norsk-svensk',),
'norsk-svenskene': ('norsk-svensk',),
'norsk-svensker': ('norsk-svensk',),
'norskamerikaner': ('norskamerikaner',),
'norskamerikanere': ('norskamerikaner',),
'norskamerikaneren': ('norskamerikaner',),
'norskamerikanerer': ('norskamerikaner',),
'norskamerikanerne': ('norskamerikaner',),
'norskdom': ('norskdom',),
'norskdommen': ('norskdom',),
'norskdommene': ('norskdom',),
'norskdommer': ('norskdom',),
'norskhet': ('norskhet',),
'norskheta': ('norskhet',),
'norskheten': ('norskhet',),
'norskhetene': ('norskhet',),
'norskheter': ('norskhet',),
'norskhetsbevegelse': ('norskhetsbevegelse',),
'norskhetsbevegelsen': ('norskhetsbevegelse',),
'norskhetsbevegelsene': ('norskhetsbevegelse',),
'norskhetsbevegelser': ('norskhetsbevegelse',),
'norsklærer': ('norsklærer',),
'norsklærere': ('norsklærer',),
'norsklæreren': ('norsklærer',),
'norsklærerer': ('norsklærer',),
'norsklærerne': ('norsklærer',),
'norvagisme': ('norvagisme',),
'norvagismen': ('norvagisme',),
'norvagismene': ('norvagisme',),
'norvagismer': ('norvagisme',),
'nos': ('nos',),
'nosa': ('nos',),
'nosen': ('nos',),
'nosene': ('nos',),
'noser': ('nos',),
'noss': ('noss',),
'nossa': ('noss',),
'nossene': ('noss',),
'nosset': ('noss',),
'nostalgi': ('nostalgi',),
'nostalgien': ('nostalgi',),
'nostalgiene': ('nostalgi',),
'nostalgier': ('nostalgi',),
'nostalgiker': ('nostalgiker',),
'nostalgikere': ('nostalgiker',),
'nostalgikeren': ('nostalgiker',),
'nostalgikerer': ('nostalgiker',),
'nostalgikerne': ('nostalgiker',),
'nota': ('nota',),
'notaen': ('nota',),
'notaene': ('nota',),
'notaer': ('nota',),
'notabel': ('notabel',),
'notabelen': ('notabel',),
'notablene': ('notabel',),
'notabler': ('notabel',),
'notabelmøta': ('notabelmøte',),
'notabelmøte': ('notabelmøte',),
'notabelmøtene': ('notabelmøte',),
'notabelmøter': ('notabelmøte',),
'notabelmøtet': ('notabelmøte',),
'notabena': ('notabene',),
'notabene': ('notabene',),
'notabenene': ('notabene',),
'notabener': ('notabene',),
'notabenet': ('notabene',),
'notabilitet': ('notabilitet',),
'notabiliteten': ('notabilitet',),
'notabilitetene': ('notabilitet',),
'notabiliteter': ('notabilitet',),
'notar': ('notar',),
'notaren': ('notar',),
'notarene': ('notar',),
'notarer': ('notar',),
'notarius publicus': ('notarius publicus',),
'notasjon': ('notasjon',),
'notasjonen': ('notasjon',),
'notasjonene': ('notasjon',),
'notasjoner': ('notasjon',),
'notat': ('notat',),
'notata': ('notat',),
'notatene': ('notat',),
'notater': ('notat',),
'notatet': ('notat',),
'notatblokk': ('notatblokk',),
'notatblokka': ('notatblokk',),
'notatblokken': ('notatblokk',),
'notatblokkene': ('notatblokk',),
'notatblokker': ('notatblokk',),
'notbas': ('notbas',),
'notbasen': ('notbas',),
'notbasene': ('notbas',),
'notbaser': ('notbas',),
'notbruk': ('notbruk',),
'notbruka': ('notbruk',),
'notbrukene': ('notbruk',),
'notbruket': ('notbruk',),
'notbåt': ('notbåt',),
'notbåten': ('notbåt',),
'notbåtene': ('notbåt',),
'notbåter': ('notbåt',),
'note': ('note',),
'noten': ('note',),
'notene': ('note',),
'noter': ('note',),
'note': ('note',),
'noten': ('note',),
'notene': ('note',),
'noter': ('note',),
'noteapparat': ('noteapparat',),
'noteapparata': ('noteapparat',),
'noteapparatene': ('noteapparat',),
'noteapparater': ('noteapparat',),
'noteapparatet': ('noteapparat',),
'notehefta': ('notehefte',),
'notehefte': ('notehefte',),
'noteheftene': ('notehefte',),
'notehefter': ('notehefte',),
'noteheftet': ('notehefte',),
'notepapir': ('notepapir',),
'notepapira': ('notepapir',),
'notepapirene': ('notepapir',),
'notepapirer': ('notepapir',),
'notepapiret': ('notepapir',),
'notering': ('notering',),
'noteringa': ('notering',),
'noteringen': ('notering',),
'noteringene': ('notering',),
'noteringer': ('notering',),
'noteringsoverføring': ('noteringsoverføring',),
'noteringsoverføringa': ('noteringsoverføring',),
'noteringsoverføringen': ('noteringsoverføring',),
'noteringsoverføringene': ('noteringsoverføring',),
'noteringsoverføringer': ('noteringsoverføring',),
'notestativ': ('notestativ',),
'notestativa': ('notestativ',),
'notestativene': ('notestativ',),
'notestativer': ('notestativ',),
'notestativet': ('notestativ',),
'notestikker': ('notestikker',),
'notestikkere': ('notestikker',),
'notestikkeren': ('notestikker',),
'notestikkerer': ('notestikker',),
'notestikkerne': ('notestikker',),
'notestol': ('notestol',),
'notestolen': ('notestol',),
'notestolene': ('notestol',),
'notestoler': ('notestol',),
'noteveksling': ('noteveksling',),
'notevekslinga': ('noteveksling',),
'notevekslingen': ('noteveksling',),
'notevekslingene': ('noteveksling',),
'notevekslinger': ('noteveksling',),
'noteverdi': ('noteverdi',),
'noteverdien': ('noteverdi',),
'noteverdiene': ('noteverdi',),
'noteverdier': ('noteverdi',),
'notfiska': ('notfiske',),
'notfiske': ('notfiske',),
'notfiskene': ('notfiske',),
'notfisker': ('notfiske',),
'notfisket': ('notfiske',),
'nothøvel': ('nothøvel',),
'nothøvelen': ('nothøvel',),
'nothøvlene': ('nothøvel',),
'nothøvler': ('nothøvel',),
'notifikasjon': ('notifikasjon',),
'notifikasjonen': ('notifikasjon',),
'notifikasjonene': ('notifikasjon',),
'notifikasjoner': ('notifikasjon',),
'notis': ('notis',),
'notisen': ('notis',),
'notisene': ('notis',),
'notiser': ('notis',),
'notlag': ('notlag',),
'notlaga': ('notlag',),
'notlagene': ('notlag',),
'notlaget': ('notlag',),
'notsteng': ('notsteng',),
'notstenga': ('notsteng',),
'notstengene': ('notsteng',),
'notstenget': ('notsteng',),
'notting': ('notting',),
'nottingen': ('notting',),
'nottingene': ('notting',),
'nottinger': ('notting',),
'nottung': ('nottung',),
'nottungen': ('nottung',),
'nottungene': ('nottung',),
'nottunger': ('nottung',),
'notvarp': ('notvarp',),
'notvarpa': ('notvarp',),
'notvarpene': ('notvarp',),
'notvarpet': ('notvarp',),
'nougat': ('nougat',),
'nougaten': ('nougat',),
'nougatene': ('nougat',),
'nougater': ('nougat',),
'nov': ('nov',),
'nova': ('nov',),
'noven': ('nov',),
'novene': ('nov',),
'nover': ('nov',),
'nova': ('nova',),
'novaen': ('nova',),
'novaene': ('nova',),
'novaer': ('nova',),
'novasjon': ('novasjon',),
'novasjonen': ('novasjon',),
'novasjonene': ('novasjon',),
'novasjoner': ('novasjon',),
'novella': ('novelle',),
'novelle': ('novelle',),
'novellen': ('novelle',),
'novellene': ('novelle',),
'noveller': ('novelle',),
'novellette': ('novellette',),
'novelletten': ('novellette',),
'novellettene': ('novellette',),
'novelletter': ('novellette',),
'novellist': ('novellist',),
'novellisten': ('novellist',),
'novellistene': ('novellist',),
'novellister': ('novellist',),
'novellistikk': ('novellistikk',),
'novellistikken': ('novellistikk',),
'novellistikkene': ('novellistikk',),
'novellistikker': ('novellistikk',),
'november': ('november',),
'novemberdag': ('novemberdag',),
'novemberdagen': ('novemberdag',),
'novemberdagene': ('novemberdag',),
'novemberdager': ('novemberdag',),
'novise': ('novise',),
'novisen': ('novise',),
'novisene': ('novise',),
'noviser': ('novise',),
'novisa': ('novise',),
'novise': ('novise',),
'novisen': ('novise',),
'novisene': ('novise',),
'noviser': ('novise',),
'novisiat': ('novisiat',),
'novisiata': ('novisiat',),
'novisiatene': ('novisiat',),
'novisiater': ('novisiat',),
'novisiatet': ('novisiat',),
'novitet': ('novitet',),
'noviteten': ('novitet',),
'novitetene': ('novitet',),
'noviteter': ('novitet',),
'nu': ('nu',),
'nuen': ('nu',),
'nuene': ('nu',),
'nuer': ('nu',),
'nu': ('nu',),
'nua': ('nu',),
'nuene': ('nu',),
'nuet': ('nu',),
'nubb': ('nubb',),
'nubben': ('nubb',),
'nubbene': ('nubb',),
'nubber': ('nubb',),
'nubbesjanse': ('nubbesjanse',),
'nubbesjansen': ('nubbesjanse',),
'nubbesjansene': ('nubbesjanse',),
'nubbesjanser': ('nubbesjanse',),
'nubier': ('nubier',),
'nubiere': ('nubier',),
'nubieren': ('nubier',),
'nubierer': ('nubier',),
'nubierne': ('nubier',),
'nudd': ('nudd',),
'nudden': ('nudd',),
'nuddene': ('nudd',),
'nudder': ('nudd',),
'nudel': ('nudel',),
'nudelen': ('nudel',),
'nudlene': ('nudel',),
'nudler': ('nudel',),
'nudisme': ('nudisme',),
'nudismen': ('nudisme',),
'nudismene': ('nudisme',),
'nudismer': ('nudisme',),
'nudist': ('nudist',),
'nudisten': ('nudist',),
'nudistene': ('nudist',),
'nudister': ('nudist',),
'nudistkoloni': ('nudistkoloni',),
'nudistkolonien': ('nudistkoloni',),
'nudistkoloniene': ('nudistkoloni',),
'nudistkolonier': ('nudistkoloni',),
'nuditet': ('nuditet',),
'nuditeten': ('nuditet',),
'nuditetene': ('nuditet',),
'nuditeter': ('nuditet',),
'nugat': ('nugat',),
'nugaten': ('nugat',),
'nugatene': ('nugat',),
'nugater': ('nugat',),
'nugg': ('nugg',),
'nugga': ('nugg',),
'nuggene': ('nugg',),
'nugget': ('nugg',),
'nukleinsyra': ('nukleinsyre',),
'nukleinsyre': ('nukleinsyre',),
'nukleinsyren': ('nukleinsyre',),
'nukleinsyrene': ('nukleinsyre',),
'nukleinsyrer': ('nukleinsyre',),
'nukleon': ('nukleon',),
'nukleona': ('nukleon',),
'nukleonene': ('nukleon',),
'nukleoner': ('nukleon',),
'nukleonet': ('nukleon',),
'nukleoprotein': ('nukleoprotein',),
'nukleoproteina': ('nukleoprotein',),
'nukleoproteinene': ('nukleoprotein',),
'nukleoproteiner': ('nukleoprotein',),
'nukleoproteinet': ('nukleoprotein',),
'nukleus': ('nukleus',),
'nukleusen': ('nukleus',),
'nukleusene': ('nukleus',),
'nukleuser': ('nukleus',),
'nuklide': ('nuklide',),
'nukliden': ('nuklide',),
'nuklidene': ('nuklide',),
'nuklider': ('nuklide',),
'null': ('null',),
'nulla': ('null',),
'nullen': ('null',),
'nullene': ('null',),
'nuller': ('null',),
'nullet': ('null',),
'nullant': ('nullant',),
'nullanten': ('nullant',),
'nullantene': ('nullant',),
'nullanter': ('nullant',),
'nullavledning': ('nullavledning',),
'nullavledninga': ('nullavledning',),
'nullavledningen': ('nullavledning',),
'nullavledningene': ('nullavledning',),
'nullavledninger': ('nullavledning',),
'nullføra': ('nullføre',),
'nullføre': ('nullføre',),
'nullførene': ('nullføre',),
'nullfører': ('nullføre',),
'nullføret': ('nullføre',),
'nullitet': ('nullitet',),
'nulliteten': ('nullitet',),
'nullitetene': ('nullitet',),
'nulliteter': ('nullitet',),
'nullmeridian': ('nullmeridian',),
'nullmeridianen': ('nullmeridian',),
'nullmeridianene': ('nullmeridian',),
'nullmeridianer': ('nullmeridian',),
'nullpunkt': ('nullpunkt',),
'nullpunkta': ('nullpunkt',),
'nullpunktene': ('nullpunkt',),
'nullpunkter': ('nullpunkt',),
'nullpunktet': ('nullpunkt',),
'nullskatteyter': ('nullskatteyter',),
'nullskatteytere': ('nullskatteyter',),
'nullskatteyteren': ('nullskatteyter',),
'nullskatteyterer': ('nullskatteyter',),
'nullskatteyterne': ('nullskatteyter',),
'nullskattyter': ('nullskattyter',),
'nullskattytere': ('nullskattyter',),
'nullskattyteren': ('nullskattyter',),
'nullskattyterer': ('nullskattyter',),
'nullskattyterne': ('nullskattyter',),
'nullvekst': ('nullvekst',),
'nullveksten': ('nullvekst',),
'nullvekstene': ('nullvekst',),
'nullvekster': ('nullvekst',),
'numedøl': ('numedøl',),
'numedølen': ('numedøl',),
'numedølene': ('numedøl',),
'numedøler': ('numedøl',),
'numeral': ('numeral',),
'numerala': ('numeral',),
'numeralene': ('numeral',),
'numeraler': ('numeral',),
'numeralet': ('numeral',),
'numerala': ('numerale',),
'numerale': ('numerale',),
'numeralene': ('numerale',),
'numeraler': ('numerale',),
'numeralet': ('numerale',),
'numeralia': ('numeralia',),
'numeraliene': ('numeralia',),
'numeraliene': ('numeralier',),
'numeralier': ('numeralier',),
'numerasjon': ('numerasjon',),
'numerasjonen': ('numerasjon',),
'numerasjonene': ('numerasjon',),
'numerasjoner': ('numerasjon',),
'numerologi': ('numerologi',),
'numerologien': ('numerologi',),
'numerologiene': ('numerologi',),
'numerologier': ('numerologi',),
'numeri': ('numerus',),
'numeriene': ('numerus',),
'numerus': ('numerus',),
'numerusen': ('numerus',),
'numerusene': ('numerus',),
'numider': ('numider',),
'numidere': ('numider',),
'numideren': ('numider',),
'numiderer': ('numider',),
'numiderne': ('numider',),
'numismat': ('numismat',),
'numismaten': ('numismat',),
'numismatene': ('numismat',),
'numismater': ('numismat',),
'numismatiker': ('numismatiker',),
'numismatikere': ('numismatiker',),
'numismatikeren': ('numismatiker',),
'numismatikerer': ('numismatiker',),
'numismatikerne': ('numismatiker',),
'numismatikk': ('numismatikk',),
'numismatikken': ('numismatikk',),
'numismatikkene': ('numismatikk',),
'numismatikker': ('numismatikk',),
'nummer': ('nummer',),
'nummeret': ('nummer',),
'numra': ('nummer',),
'numre': ('nummer',),
'numrene': ('nummer',),
'nummerering': ('nummerering',),
'nummereringa': ('nummerering',),
'nummereringen': ('nummerering',),
'nummereringene': ('nummerering',),
'nummereringer': ('nummerering',),
'nummerorden': ('nummerorden',),
'nummerordenen': ('nummerorden',),
'nummerordenene': ('nummerorden',),
'nummerordener': ('nummerorden',),
'nummerskilt': ('nummerskilt',),
'nummerskilta': ('nummerskilt',),
'nummerskiltene': ('nummerskilt',),
'nummerskilter': ('nummerskilt',),
'nummerskiltet': ('nummerskilt',),
'nunatak': ('nunatak',),
'nunataken': ('nunatak',),
'nunatakene': ('nunatak',),
'nunataker': ('nunatak',),
'nuntien': ('nuntius',),
'nuntiene': ('nuntius',),
'nuntier': ('nuntius',),
'nuntius': ('nuntius',),
'nuntiusen': ('nuntius',),
'nup': ('nup',),
'nupen': ('nup',),
'nupene': ('nup',),
'nuper': ('nup',),
'nuperellene': ('nupereller',),
'nupereller': ('nupereller',),
'nupp': ('nupp',),
'nuppen': ('nupp',),
'nuppene': ('nupp',),
'nupper': ('nupp',),
'nupp': ('nupp',),
'nuppa': ('nupp',),
'nuppene': ('nupp',),
'nuppet': ('nupp',),
'nuppe': ('nuppe',),
'nuppen': ('nuppe',),
'nuppene': ('nuppe',),
'nupper': ('nuppe',),
'nupping': ('nupping',),
'nuppingen': ('nupping',),
'nuppingene': ('nupping',),
'nuppinger': ('nupping',),
'nuprejern': ('nuprejern',),
'nuprejerna': ('nuprejern',),
'nuprejernene': ('nuprejern',),
'nuprejernet': ('nuprejern',),
'nurk': ('nurk',),
'nurka': ('nurk',),
'nurken': ('nurk',),
'nurkene': ('nurk',),
'nurker': ('nurk',),
'nurket': ('nurk',),
'nuss': ('nuss',),
'nussa': ('nuss',),
'nussene': ('nuss',),
'nusset': ('nuss',),
'nut': ('nut',),
'nuten': ('nut',),
'nutene': ('nut',),
'nuter': ('nut',),
'nutria': ('nutria',),
'nutriaen': ('nutria',),
'nutriaene': ('nutria',),
'nutriaer': ('nutria',),
'nuv': ('nuv',),
'nuven': ('nuv',),
'nuvene': ('nuv',),
'nuver': ('nuv',),
'nuve': ('nuve',),
'nuven': ('nuve',),
'nuvene': ('nuve',),
'nuver': ('nuve',),
'ny': ('ny',),
'nya': ('ny',),
'nyene': ('ny',),
'nyer': ('ny',),
'nyet': ('ny',),
'nyanlegg': ('nyanlegg',),
'nyanlegga': ('nyanlegg',),
'nyanleggene': ('nyanlegg',),
'nyanlegget': ('nyanlegg',),
'nyanse': ('nyanse',),
'nyansen': ('nyanse',),
'nyansene': ('nyanse',),
'nyanser': ('nyanse',),
'nyanseforskjell': ('nyanseforskjell',),
'nyanseforskjellen': ('nyanseforskjell',),
'nyanseforskjellene': ('nyanseforskjell',),
'nyanseforskjeller': ('nyanseforskjell',),
'nyanskaffelse': ('nyanskaffelse',),
'nyanskaffelsen': ('nyanskaffelse',),
'nyanskaffelsene': ('nyanskaffelse',),
'nyanskaffelser': ('nyanskaffelse',),
'nybegynner': ('nybegynner',),
'nybegynnere': ('nybegynner',),
'nybegynneren': ('nybegynner',),
'nybegynnerer': ('nybegynner',),
'nybegynnerne': ('nybegynner',),
'nybrott': ('nybrott',),
'nybrotta': ('nybrott',),
'nybrottene': ('nybrott',),
'nybrottet': ('nybrott',),
'nybrottsarbeid': ('nybrottsarbeid',),
'nybrottsarbeida': ('nybrottsarbeid',),
'nybrottsarbeidene': ('nybrottsarbeid',),
'nybrottsarbeider': ('nybrottsarbeid',),
'nybrottsarbeidet': ('nybrottsarbeid',),
'nybrottsmann': ('nybrottsmann',),
'nybrottsmannen': ('nybrottsmann',),
'nybrottsmenn': ('nybrottsmann',),
'nybrottsmennene': ('nybrottsmann',),
'nybygg': ('nybygg',),
'nybygga': ('nybygg',),
'nybyggene': ('nybygg',),
'nybygget': ('nybygg',),
'nybygger': ('nybygger',),
'nybyggere': ('nybygger',),
'nybyggeren': ('nybygger',),
'nybyggerer': ('nybygger',),
'nybyggerne': ('nybygger',),
'nybyggerfelt': ('nybyggerfelt',),
'nybyggerfelta': ('nybyggerfelt',),
'nybyggerfeltene': ('nybyggerfelt',),
'nybyggerfelter': ('nybyggerfelt',),
'nybyggerfeltet': ('nybyggerfelt',),
'nybyggerstrøk': ('nybyggerstrøk',),
'nybyggerstrøka': ('nybyggerstrøk',),
'nybyggerstrøkene': ('nybyggerstrøk',),
'nybyggerstrøket': ('nybyggerstrøk',),
'nybygning': ('nybygning',),
'nybygninga': ('nybygning',),
'nybygningen': ('nybygning',),
'nybygningene': ('nybygning',),
'nybygninger': ('nybygning',),
'nydannelse': ('nydannelse',),
'nydannelsen': ('nydannelse',),
'nydannelsene': ('nydannelse',),
'nydannelser': ('nydannelse',),
'nydanning': ('nydanning',),
'nydanninga': ('nydanning',),
'nydanningen': ('nydanning',),
'nydanningene': ('nydanning',),
'nydanninger': ('nydanning',),
'nyemisjon': ('nyemisjon',),
'nyemisjonen': ('nyemisjon',),
'nyemisjonene': ('nyemisjon',),
'nyemisjoner': ('nyemisjon',),
'nyervervelse': ('nyervervelse',),
'nyervervelsen': ('nyervervelse',),
'nyervervelsene': ('nyervervelse',),
'nyervervelser': ('nyervervelse',),
'nyetablering': ('nyetablering',),
'nyetableringa': ('nyetablering',),
'nyetableringen': ('nyetablering',),
'nyetableringene': ('nyetablering',),
'nyetableringer': ('nyetablering',),
'nyfascisme': ('nyfascisme',),
'nyfascismen': ('nyfascisme',),
'nyfascismene': ('nyfascisme',),
'nyfascismer': ('nyfascisme',),
'nyfeminisme': ('nyfeminisme',),
'nyfeminismen': ('nyfeminisme',),
'nyfeminismene': ('nyfeminisme',),
'nyfeminismer': ('nyfeminisme',),
'nygla': ('nygle',),
'nygle': ('nygle',),
'nyglen': ('nygle',),
'nyglene': ('nygle',),
'nygler': ('nygle',),
'nygrad': ('nygrad',),
'nygraden': ('nygrad',),
'nygradene': ('nygrad',),
'nygrader': ('nygrad',),
'nyhet': ('nyhet',),
'nyheta': ('nyhet',),
'nyheten': ('nyhet',),
'nyhetene': ('nyhet',),
'nyheter': ('nyhet',),
'nyhetsbilda': ('nyhetsbilde',),
'nyhetsbilde': ('nyhetsbilde',),
'nyhetsbildene': ('nyhetsbilde',),
'nyhetsbilder': ('nyhetsbilde',),
'nyhetsbildet': ('nyhetsbilde',),
'nyhetsbomba': ('nyhetsbombe',),
'nyhetsbombe': ('nyhetsbombe',),
'nyhetsbomben': ('nyhetsbombe',),
'nyhetsbombene': ('nyhetsbombe',),
'nyhetsbomber': ('nyhetsbombe',),
'nyhetsbyrå': ('nyhetsbyrå',),
'nyhetsbyråa': ('nyhetsbyrå',),
'nyhetsbyråene': ('nyhetsbyrå',),
'nyhetsbyråer': ('nyhetsbyrå',),
'nyhetsbyrået': ('nyhetsbyrå',),
'nyhetstjeneste': ('nyhetstjeneste',),
'nyhetstjenesten': ('nyhetstjeneste',),
'nyhetstjenestene': ('nyhetstjeneste',),
'nyhetstjenester': ('nyhetstjeneste',),
'nying': ('nying',),
'nyingen': ('nying',),
'nyingene': ('nying',),
'nyinger': ('nying',),
'nykk': ('nykk',),
'nykka': ('nykk',),
'nykken': ('nykk',),
'nykkene': ('nykk',),
'nykket': ('nykk',),
'nykka': ('nykke',),
'nykke': ('nykke',),
'nykken': ('nykke',),
'nykkene': ('nykke',),
'nykker': ('nykke',),
'nykket': ('nykke',),
'nyklassisisme': ('nyklassisisme',),
'nyklassisismen': ('nyklassisisme',),
'nyklassisismene': ('nyklassisisme',),
'nyklassisismer': ('nyklassisisme',),
'nykolonialisme': ('nykolonialisme',),
'nykolonialismen': ('nykolonialisme',),
'nykolonialismene': ('nykolonialisme',),
'nykolonialismer': ('nykolonialisme',),
'nykomling': ('nykomling',),
'nykomlingen': ('nykomling',),
'nykomlingene': ('nykomling',),
'nykomlinger': ('nykomling',),
'nykommer': ('nykommer',),
'nykommere': ('nykommer',),
'nykommeren': ('nykommer',),
'nykommerer': ('nykommer',),
'nykommerne': ('nykommer',),
'nykritikk': ('nykritikk',),
'nykritikken': ('nykritikk',),
'nykritikkene': ('nykritikk',),
'nykritikker': ('nykritikk',),
'nylaging': ('nylaging',),
'nylaginga': ('nylaging',),
'nylagingen': ('nylaging',),
'nylagingene': ('nylaging',),
'nylaginger': ('nylaging',),
'nyland': ('nyland',),
'nylanda': ('nyland',),
'nylandene': ('nyland',),
'nylandet': ('nyland',),
'nylatin': ('nylatin',),
'nylatinen': ('nylatin',),
'nylatinene': ('nylatin',),
'nylatiner': ('nylatin',),
'nylenda': ('nylende',),
'nylende': ('nylende',),
'nylendene': ('nylende',),
'nylender': ('nylende',),
'nylendet': ('nylende',),
'nylon': ('nylon',),
'nylona': ('nylon',),
'nylonene': ('nylon',),
'nylonet': ('nylon',),
'nylonskjorta': ('nylonskjorte',),
'nylonskjorte': ('nylonskjorte',),
'nylonskjorten': ('nylonskjorte',),
'nylonskjortene': ('nylonskjorte',),
'nylonskjorter': ('nylonskjorte',),
'nylonstrømpa': ('nylonstrømpe',),
'nylonstrømpe': ('nylonstrømpe',),
'nylonstrømpen': ('nylonstrømpe',),
'nylonstrømpene': ('nylonstrømpe',),
'nylonstrømper': ('nylonstrømpe',),
'nymfa': ('nymfe',),
'nymfe': ('nymfe',),
'nymfen': ('nymfe',),
'nymfene': ('nymfe',),
'nymfer': ('nymfe',),
'nymfoman': ('nymfoman',),
'nymfomanen': ('nymfoman',),
'nymfomanene': ('nymfoman',),
'nymfomaner': ('nymfoman',),
'nymfomani': ('nymfomani',),
'nymfomanien': ('nymfomani',),
'nymfomaniene': ('nymfomani',),
'nymfomanier': ('nymfomani',),
'nymåne': ('nymåne',),
'nymånen': ('nymåne',),
'nymånene': ('nymåne',),
'nymåner': ('nymåne',),
'nynazisme': ('nynazisme',),
'nynazismen': ('nynazisme',),
'nynazismene': ('nynazisme',),
'nynazismer': ('nynazisme',),
'nynazist': ('nynazist',),
'nynazisten': ('nynazist',),
'nynazistene': ('nynazist',),
'nynazister': ('nynazist',),
'nynn': ('nynn',),
'nynna': ('nynn',),
'nynnene': ('nynn',),
'nynnet': ('nynn',),
'nynorsk': ('nynorsk',),
'nynorsken': ('nynorsk',),
'nynorskene': ('nynorsk',),
'nynorsker': ('nynorsk',),
'nynorskkvinna': ('nynorskkvinne',),
'nynorskkvinne': ('nynorskkvinne',),
'nynorskkvinnen': ('nynorskkvinne',),
'nynorskkvinnene': ('nynorskkvinne',),
'nynorskkvinner': ('nynorskkvinne',),
'nynorskmann': ('nynorskmann',),
'nynorskmannen': ('nynorskmann',),
'nynorskmenn': ('nynorskmann',),
'nynorskmennene': ('nynorskmann',),
'nynorskutgava': ('nynorskutgave',),
'nynorskutgave': ('nynorskutgave',),
'nynorskutgaven': ('nynorskutgave',),
'nynorskutgavene': ('nynorskutgave',),
'nynorskutgaver': ('nynorskutgave',),
'nyord': ('nyord',),
'nyorda': ('nyord',),
'nyordene': ('nyord',),
'nyordet': ('nyord',),
'nyordning': ('nyordning',),
'nyordninga': ('nyordning',),
'nyordningen': ('nyordning',),
'nyordningene': ('nyordning',),
'nyordninger': ('nyordning',),
'nyordssamling': ('nyordssamling',),
'nyordssamlinga': ('nyordssamling',),
'nyordssamlingen': ('nyordssamling',),
'nyordssamlingene': ('nyordssamling',),
'nyordssamlinger': ('nyordssamling',),
'nyorientering': ('nyorientering',),
'nyorienteringa': ('nyorientering',),
'nyorienteringen': ('nyorientering',),
'nyorienteringene': ('nyorientering',),
'nyorienteringer': ('nyorientering',),
'nyp': ('nyp',),
'nypa': ('nyp',),
'nypene': ('nyp',),
'nypet': ('nyp',),
'nypa': ('nype',),
'nype': ('nype',),
'nypen': ('nype',),
'nypene': ('nype',),
'nyper': ('nype',),
'nypa': ('nype',),
'nype': ('nype',),
'nypen': ('nype',),
'nypene': ('nype',),
'nyper': ('nype',),
'nyperosa': ('nyperose',),
'nyperose': ('nyperose',),
'nyperosen': ('nyperose',),
'nyperosene': ('nyperose',),
'nyperoser': ('nyperose',),
'nypete': ('nypete',),
'nypeteen': ('nypete',),
'nypeteene': ('nypete',),
'nypeteer': ('nypete',),
'nypetorn': ('nypetorn',),
'nypetornen': ('nypetorn',),
'nypetornene': ('nypetorn',),
'nypetorner': ('nypetorn',),
'nypotet': ('nypotet',),
'nypoteten': ('nypotet',),
'nypotetene': ('nypotet',),
'nypoteter': ('nypotet',),
'nyra': ('nyre',),
'nyre': ('nyre',),
'nyren': ('nyre',),
'nyrene': ('nyre',),
'nyrer': ('nyre',),
'nyret': ('nyre',),
'nyrealisme': ('nyrealisme',),
'nyrealismen': ('nyrealisme',),
'nyrealismene': ('nyrealisme',),
'nyrealismer': ('nyrealisme',),
'nyrebekken': ('nyrebekken',),
'nyrebekkena': ('nyrebekken',),
'nyrebekkenene': ('nyrebekken',),
'nyrebekkener': ('nyrebekken',),
'nyrebekkenet': ('nyrebekken',),
'nyrebelta': ('nyrebelte',),
'nyrebelte': ('nyrebelte',),
'nyrebeltene': ('nyrebelte',),
'nyrebelter': ('nyrebelte',),
'nyrebeltet': ('nyrebelte',),
'nyregrus': ('nyregrus',),
'nyregrusa': ('nyregrus',),
'nyregrusen': ('nyregrus',),
'nyregrusene': ('nyregrus',),
'nyregruser': ('nyregrus',),
'nyregruset': ('nyregrus',),
'nyrestein': ('nyrestein',),
'nyresteinen': ('nyrestein',),
'nyresteinene': ('nyrestein',),
'nyresteiner': ('nyrestein',),
'nyretransplantasjon': ('nyretransplantasjon',),
'nyretransplantasjonen': ('nyretransplantasjon',),
'nyretransplantasjonene': ('nyretransplantasjon',),
'nyretransplantasjoner': ('nyretransplantasjon',),
'nyrydning': ('nyrydning',),
'nyrydninga': ('nyrydning',),
'nyrydningen': ('nyrydning',),
'nyrydningene': ('nyrydning',),
'nyrydninger': ('nyrydning',),
'nys': ('nys',),
'nysa': ('nys',),
'nysen': ('nys',),
'nysene': ('nys',),
'nyset': ('nys',),
'nysepulver': ('nysepulver',),
'nysepulvera': ('nysepulver',),
'nysepulvere': ('nysepulver',),
'nysepulveret': ('nysepulver',),
'nysepulverne': ('nysepulver',),
'nyseryllik': ('nyseryllik',),
'nyserylliken': ('nyseryllik',),
'nyseryllikene': ('nyseryllik',),
'nyserylliker': ('nyseryllik',),
'nyserøllik': ('nyserøllik',),
'nyserølliken': ('nyserøllik',),
'nyserøllikene': ('nyserøllik',),
'nyserølliker': ('nyserøllik',),
'nysgjerrighet': ('nysgjerrighet',),
'nysgjerrigheta': ('nysgjerrighet',),
'nysgjerrigheten': ('nysgjerrighet',),
'nysgjerrighetene': ('nysgjerrighet',),
'nysgjerrigheter': ('nysgjerrighet',),
'nysgjerrigper': ('nysgjerrigper',),
'nysgjerrigperen': ('nysgjerrigper',),
'nysgjerrigperene': ('nysgjerrigper',),
'nysgjerrigperer': ('nysgjerrigper',),
'nyskaper': ('nyskaper',),
'nyskapere': ('nyskaper',),
'nyskaperen': ('nyskaper',),
'nyskaperer': ('nyskaper',),
'nyskaperne': ('nyskaper',),
'nyskapning': ('nyskapning',),
'nyskapninga': ('nyskapning',),
'nyskapningen': ('nyskapning',),
'nyskapningene': ('nyskapning',),
'nyskapninger': ('nyskapning',),
'nysnø': ('nysnø',),
'nysnøen': ('nysnø',),
'nysnøene': ('nysnø',),
'nysnøer': ('nysnø',),
'nyss': ('nyss',),
'nyssen': ('nyss',),
'nyssene': ('nyss',),
'nysser': ('nyss',),
'nyss': ('nyss',),
'nyssa': ('nyss',),
'nyssene': ('nyss',),
'nysset': ('nyss',),
'nystev': ('nystev',),
'nysteva': ('nystev',),
'nystevene': ('nystev',),
'nystevet': ('nystev',),
'nysølv': ('nysølv',),
'nysølva': ('nysølv',),
'nysølvene': ('nysølv',),
'nysølvet': ('nysølv',),
'nytelse': ('nytelse',),
'nytelsen': ('nytelse',),
'nytelsene': ('nytelse',),
'nytelser': ('nytelse',),
'nytelsesmiddel': ('nytelsesmiddel',),
'nytelsesmiddelet': ('nytelsesmiddel',),
'nytelsesmidla': ('nytelsesmiddel',),
'nytelsesmidlene': ('nytelsesmiddel',),
'nytelsesmidler': ('nytelsesmiddel',),
'nytelsesmidlet': ('nytelsesmiddel',),
'nytenking': ('nytenking',),
'nytenkinga': ('nytenking',),
'nytenkingen': ('nytenking',),
'nytenkingene': ('nytenking',),
'nytenkinger': ('nytenking',),
'nytenkning': ('nytenkning',),
'nytenkninga': ('nytenkning',),
'nytenkningen': ('nytenkning',),
'nytenkningene': ('nytenkning',),
'nytenkninger': ('nytenkning',),
'nyter': ('nyter',),
'nytere': ('nyter',),
'nyteren': ('nyter',),
'nyterer': ('nyter',),
'nyterne': ('nyter',),
'nytid': ('nytid',),
'nytida': ('nytid',),
'nytiden': ('nytid',),
'nytidene': ('nytid',),
'nytider': ('nytid',),
'nyting': ('nyting',),
'nytinga': ('nyting',),
'nytingen': ('nyting',),
'nytingene': ('nyting',),
'nytinger': ('nyting',),
'nytingsmiddel': ('nytingsmiddel',),
'nytingsmiddelet': ('nytingsmiddel',),
'nytingsmidla': ('nytingsmiddel',),
'nytingsmidlene': ('nytingsmiddel',),
'nytingsmidler': ('nytingsmiddel',),
'nytingsmidlet': ('nytingsmiddel',),
'nytta': ('nytte',),
'nytte': ('nytte',),
'nytten': ('nytte',),
'nyttene': ('nytte',),
'nytter': ('nytte',),
'nyttedyr': ('nyttedyr',),
'nyttedyra': ('nyttedyr',),
'nyttedyrene': ('nyttedyr',),
'nyttedyret': ('nyttedyr',),
'nytteeffekt': ('nytteeffekt',),
'nytteeffekten': ('nytteeffekt',),
'nytteeffektene': ('nytteeffekt',),
'nytteeffekter': ('nytteeffekt',),
'nytteforskning': ('nytteforskning',),
'nytteforskninga': ('nytteforskning',),
'nytteforskningen': ('nytteforskning',),
'nytteforskningene': ('nytteforskning',),
'nytteforskninger': ('nytteforskning',),
'nyttegjenstand': ('nyttegjenstand',),
'nyttegjenstanden': ('nyttegjenstand',),
'nyttegjenstandene': ('nyttegjenstand',),
'nyttegjenstander': ('nyttegjenstand',),
'nyttehensyn': ('nyttehensyn',),
'nyttehensyna': ('nyttehensyn',),
'nyttehensynene': ('nyttehensyn',),
'nyttehensynet': ('nyttehensyn',),
'nytteinsekt': ('nytteinsekt',),
'nytteinsekta': ('nytteinsekt',),
'nytteinsektene': ('nytteinsekt',),
'nytteinsekter': ('nytteinsekt',),
'nytteinsektet': ('nytteinsekt',),
'nyttelast': ('nyttelast',),
'nyttelasta': ('nyttelast',),
'nyttelasten': ('nyttelast',),
'nyttelastene': ('nyttelast',),
'nyttelaster': ('nyttelast',),
'nyttemoral': ('nyttemoral',),
'nyttemoralen': ('nyttemoral',),
'nyttemoralene': ('nyttemoral',),
'nyttemoraler': ('nyttemoral',),
'nytteplanta': ('nytteplante',),
'nytteplante': ('nytteplante',),
'nytteplanten': ('nytteplante',),
'nytteplantene': ('nytteplante',),
'nytteplanter': ('nytteplante',),
'nyttevekst': ('nyttevekst',),
'nytteveksten': ('nyttevekst',),
'nyttevekstene': ('nyttevekst',),
'nyttevekster': ('nyttevekst',),
'nytteverdi': ('nytteverdi',),
'nytteverdien': ('nytteverdi',),
'nytteverdiene': ('nytteverdi',),
'nytteverdier': ('nytteverdi',),
'nyttevirkning': ('nyttevirkning',),
'nyttevirkninga': ('nyttevirkning',),
'nyttevirkningen': ('nyttevirkning',),
'nyttevirkningene': ('nyttevirkning',),
'nyttevirkninger': ('nyttevirkning',),
'nyttår': ('nyttår',),
'nyttåra': ('nyttår',),
'nyttårene': ('nyttår',),
'nyttåret': ('nyttår',),
'nyttårsaften': ('nyttårsaften',),
'nyttårsaftenen': ('nyttårsaften',),
'nyttårsaftenene': ('nyttårsaften',),
'nyttårsaftener': ('nyttårsaften',),
'nyttårsbarn': ('nyttårsbarn',),
'nyttårsbarna': ('nyttårsbarn',),
'nyttårsbarnene': ('nyttårsbarn',),
'nyttårsbarnet': ('nyttårsbarn',),
'nyttårsdag': ('nyttårsdag',),
'nyttårsdagen': ('nyttårsdag',),
'nyttårsdagene': ('nyttårsdag',),
'nyttårsdager': ('nyttårsdag',),
'nyttårsforsett': ('nyttårsforsett',),
'nyttårsforsetta': ('nyttårsforsett',),
'nyttårsforsettene': ('nyttårsforsett',),
'nyttårsforsetter': ('nyttårsforsett',),
'nyttårsforsettet': ('nyttårsforsett',),
'nyttårshelsing': ('nyttårshelsing',),
'nyttårshelsinga': ('nyttårshelsing',),
'nyttårshelsingen': ('nyttårshelsing',),
'nyttårshelsingene': ('nyttårshelsing',),
'nyttårshelsinger': ('nyttårshelsing',),
'nyttårshilsen': ('nyttårshilsen',),
'nyttårshilsenen': ('nyttårshilsen',),
'nyttårshilsenene': ('nyttårshilsen',),
'nyttårshilsener': ('nyttårshilsen',),
'nyttårsny': ('nyttårsny',),
'nyttårsnya': ('nyttårsny',),
'nyttårsnyene': ('nyttårsny',),
'nyttårsnyer': ('nyttårsny',),
'nyttårsnyet': ('nyttårsny',),
'nyttårsønska': ('nyttårsønske',),
'nyttårsønske': ('nyttårsønske',),
'nyttårsønskene': ('nyttårsønske',),
'nyttårsønsker': ('nyttårsønske',),
'nyttårsønsket': ('nyttårsønske',),
'nyvalg': ('nyvalg',),
'nyvalga': ('nyvalg',),
'nyvalgene': ('nyvalg',),
'nyvalget': ('nyvalg',),
'nyva': ('nyve',),
'nyve': ('nyve',),
'nyven': ('nyve',),
'nyvene': ('nyve',),
'nyver': ('nyve',),
'nyverdiforsikring': ('nyverdiforsikring',),
'nyverdiforsikringa': ('nyverdiforsikring',),
'nyverdiforsikringen': ('nyverdiforsikring',),
'nyverdiforsikringene': ('nyverdiforsikring',),
'nyverdiforsikringer': ('nyverdiforsikring',),
'nyvinning': ('nyvinning',),
'nyvinninga': ('nyvinning',),
'nyvinningen': ('nyvinning',),
'nyvinningene': ('nyvinning',),
'nyvinninger': ('nyvinning',),
'nyvle': ('nyvle',),
'nyvlen': ('nyvle',),
'nyvlene': ('nyvle',),
'nyvler': ('nyvle',),
'nyzealender': ('nyzealender',),
'nyzealendere': ('nyzealender',),
'nyzealenderen': ('nyzealender',),
'nyzealenderer': ('nyzealender',),
'nyzealenderne': ('nyzealender',),
'nyzealending': ('nyzealending',),
'nyzealendingen': ('nyzealending',),
'nyzealendingene': ('nyzealending',),
'nyzealendinger': ('nyzealending',),
'nyår': ('nyår',),
'nyåra': ('nyår',),
'nyårene': ('nyår',),
'nyåret': ('nyår',),
'nyårsaften': ('nyårsaften',),
'nyårsaftenen': ('nyårsaften',),
'nyårsaftenene': ('nyårsaften',),
'nyårsaftener': ('nyårsaften',),
'nyårsbarn': ('nyårsbarn',),
'nyårsbarna': ('nyårsbarn',),
'nyårsbarnene': ('nyårsbarn',),
'nyårsbarnet': ('nyårsbarn',),
'nyårsdag': ('nyårsdag',),
'nyårsdagen': ('nyårsdag',),
'nyårsdagene': ('nyårsdag',),
'nyårsdager': ('nyårsdag',),
'nyårsforsett': ('nyårsforsett',),
'nyårsforsetta': ('nyårsforsett',),
'nyårsforsettene': ('nyårsforsett',),
'nyårsforsetter': ('nyårsforsett',),
'nyårsforsettet': ('nyårsforsett',),
'nyårshelsing': ('nyårshelsing',),
'nyårshelsinga': ('nyårshelsing',),
'nyårshelsingen': ('nyårshelsing',),
'nyårshelsingene': ('nyårshelsing',),
'nyårshelsinger': ('nyårshelsing',),
'nyårshilsen': ('nyårshilsen',),
'nyårshilsenen': ('nyårshilsen',),
'nyårshilsenene': ('nyårshilsen',),
'nyårshilsener': ('nyårshilsen',),
'nyårsny': ('nyårsny',),
'nyårsnya': ('nyårsny',),
'nyårsnyene': ('nyårsny',),
'nyårsnyer': ('nyårsny',),
'nyårsnyet': ('nyårsny',),
'nyårsønska': ('nyårsønske',),
'nyårsønske': ('nyårsønske',),
'nyårsønskene': ('nyårsønske',),
'nyårsønsker': ('nyårsønske',),
'nyårsønsket': ('nyårsønske',),
'nå': ('nå',),
'nåa': ('nå',),
'nåene': ('nå',),
'nået': ('nå',),
'nåde': ('nåde',),
'nåden': ('nåde',),
'nådene': ('nåde',),
'nåder': ('nåde',),
'nådegava': ('nådegave',),
'nådegave': ('nådegave',),
'nådegaven': ('nådegave',),
'nådegavene': ('nådegave',),
'nådegaver': ('nådegave',),
'nådemiddel': ('nådemiddel',),
'nådemiddelet': ('nådemiddel',),
'nådemidla': ('nådemiddel',),
'nådemidlene': ('nådemiddel',),
'nådemidler': ('nådemiddel',),
'nådemidlet': ('nådemiddel',),
'nådesakt': ('nådesakt',),
'nådesakta': ('nådesakt',),
'nådesakten': ('nådesakt',),
'nådesaktene': ('nådesakt',),
'nådesakter': ('nådesakt',),
'nådesbevisning': ('nådesbevisning',),
'nådesbevisninga': ('nådesbevisning',),
'nådesbevisningen': ('nådesbevisning',),
'nådesbevisningene': ('nådesbevisning',),
'nådesbevisninger': ('nådesbevisning',),
'nådeskott': ('nådeskott',),
'nådeskotta': ('nådeskott',),
'nådeskottene': ('nådeskott',),
'nådeskottet': ('nådeskott',),
'nådeskudd': ('nådeskudd',),
'nådeskudda': ('nådeskudd',),
'nådeskuddene': ('nådeskudd',),
'nådeskuddet': ('nådeskudd',),
'nådestøt': ('nådestøt',),
'nådestøta': ('nådestøt',),
'nådestøtene': ('nådestøt',),
'nådestøtet': ('nådestøt',),
'nådsensbrød': ('nådsensbrød',),
'nådsensbrøda': ('nådsensbrød',),
'nådsensbrødene': ('nådsensbrød',),
'nådsensbrødet': ('nådsensbrød',),
'nåe': ('nåe',),
'nåen': ('nåe',),
'nåene': ('nåe',),
'nåer': ('nåe',),
'nål': ('nål',),
'nåla': ('nål',),
'nålen': ('nål',),
'nålene': ('nål',),
'nåler': ('nål',),
'nålarbeid': ('nålarbeid',),
'nålarbeida': ('nålarbeid',),
'nålarbeidene': ('nålarbeid',),
'nålarbeider': ('nålarbeid',),
'nålarbeidet': ('nålarbeid',),
'nålebinding': ('nålebinding',),
'nålebindinga': ('nålebinding',),
'nålebindingen': ('nålebinding',),
'nålebindingene': ('nålebinding',),
'nålebindinger': ('nålebinding',),
'nålebrev': ('nålebrev',),
'nålebreva': ('nålebrev',),
'nålebrevene': ('nålebrev',),
'nålebrever': ('nålebrev',),
'nålebrevet': ('nålebrev',),
'nålefilt': ('nålefilt',),
'nålefilten': ('nålefilt',),
'nålefiltene': ('nålefilt',),
'nålefilter': ('nålefilt',),
'nålefisk': ('nålefisk',),
'nålefisken': ('nålefisk',),
'nålefiskene': ('nålefisk',),
'nålefisker': ('nålefisk',),
'nålelenka': ('nålelenke',),
'nålelenke': ('nålelenke',),
'nålelenken': ('nålelenke',),
'nålelenkene': ('nålelenke',),
'nålelenker': ('nålelenke',),
'nålepengene': ('nålepenger',),
'nålepenger': ('nålepenger',),
'nåleputa': ('nålepute',),
'nålepute': ('nålepute',),
'nåleputen': ('nålepute',),
'nåleputene': ('nålepute',),
'nåleputer': ('nålepute',),
'nåleskog': ('nåleskog',),
'nåleskogen': ('nåleskog',),
'nåleskogene': ('nåleskog',),
'nåleskoger': ('nåleskog',),
'nålespiss': ('nålespiss',),
'nålespissen': ('nålespiss',),
'nålespissene': ('nålespiss',),
'nålespisser': ('nålespiss',),
'nålestikk': ('nålestikk',),
'nålestikka': ('nålestikk',),
'nålestikkene': ('nålestikk',),
'nålestikket': ('nålestikk',),
'nålys': ('nålys',),
'nålysa': ('nålys',),
'nålysene': ('nålys',),
'nålyset': ('nålys',),
'nåløya': ('nåløye',),
'nåløye': ('nåløye',),
'nåløyene': ('nåløye',),
'nåløyer': ('nåløye',),
'nåløyet': ('nåløye',),
'nåløyne': ('nåløye',),
'nåløynene': ('nåløye',),
'nåm': ('nåm',),
'nåma': ('nåm',),
'nåmene': ('nåm',),
'nåmet': ('nåm',),
'nårisla': ('nårisle',),
'nårisle': ('nårisle',),
'nårislen': ('nårisle',),
'nårislene': ('nårisle',),
'nårisler': ('nårisle',),
'nårislegras': ('nårislegras',),
'nårislegrasa': ('nårislegras',),
'nårislegrasene': ('nårislegras',),
'nårislegraset': ('nårislegras',),
'nårislegress': ('nårislegress',),
'nårislegressa': ('nårislegress',),
'nårislegressene': ('nårislegress',),
'nårislegresset': ('nårislegress',),
'nåtid': ('nåtid',),
'nåtida': ('nåtid',),
'nåtiden': ('nåtid',),
'nåtidene': ('nåtid',),
'nåtider': ('nåtid',),
'nåtidshistoria': ('nåtidshistorie',),
'nåtidshistorie': ('nåtidshistorie',),
'nåtidshistorien': ('nåtidshistorie',),
'nåtidshistoriene': ('nåtidshistorie',),
'nåtidshistorier': ('nåtidshistorie',),
'nåtler': ('nåtler',),
'nåtlere': ('nåtler',),
'nåtleren': ('nåtler',),
'nåtlerer': ('nåtler',),
'nåtlerne': ('nåtler',),
'nærbilda': ('nærbilde',),
'nærbilde': ('nærbilde',),
'nærbildene': ('nærbilde',),
'nærbilder': ('nærbilde',),
'nærbildet': ('nærbilde',),
'nærbutikk': ('nærbutikk',),
'nærbutikken': ('nærbutikk',),
'nærbutikkene': ('nærbutikk',),
'nærbutikker': ('nærbutikk',),
'nærdemokrati': ('nærdemokrati',),
'nærdemokratia': ('nærdemokrati',),
'nærdemokratiene': ('nærdemokrati',),
'nærdemokratier': ('nærdemokrati',),
'nærdemokratiet': ('nærdemokrati',),
'nærekspress': ('nærekspress',),
'nærekspressen': ('nærekspress',),
'nærekspressene': ('nærekspress',),
'nærekspresser': ('nærekspress',),
'nærgåenhet': ('nærgåenhet',),
'nærgåenheta': ('nærgåenhet',),
'nærgåenheten': ('nærgåenhet',),
'nærgåenhetene': ('nærgåenhet',),
'nærgåenheter': ('nærgåenhet',),
'nærhet': ('nærhet',),
'nærheta': ('nærhet',),
'nærheten': ('nærhet',),
'nærhetene': ('nærhet',),
'nærheter': ('nærhet',),
'nærhetsprinsipp': ('nærhetsprinsipp',),
'nærhetsprinsippa': ('nærhetsprinsipp',),
'nærhetsprinsippene': ('nærhetsprinsipp',),
'nærhetsprinsipper': ('nærhetsprinsipp',),
'nærhetsprinsippet': ('nærhetsprinsipp',),
'næring': ('næring',),
'næringa': ('næring',),
'næringen': ('næring',),
'næringene': ('næring',),
'næringer': ('næring',),
'næringsbrev': ('næringsbrev',),
'næringsbreva': ('næringsbrev',),
'næringsbrevene': ('næringsbrev',),
'næringsbrever': ('næringsbrev',),
'næringsbrevet': ('næringsbrev',),
'næringsdrift': ('næringsdrift',),
'næringsdrifta': ('næringsdrift',),
'næringsdriften': ('næringsdrift',),
'næringsdriftene': ('næringsdrift',),
'næringsdrifter': ('næringsdrift',),
'næringsfrihet': ('næringsfrihet',),
'næringsfriheta': ('næringsfrihet',),
'næringsfriheten': ('næringsfrihet',),
'næringsfrihetene': ('næringsfrihet',),
'næringsfriheter': ('næringsfrihet',),
'næringsgrein': ('næringsgrein',),
'næringsgreina': ('næringsgrein',),
'næringsgreinen': ('næringsgrein',),
'næringsgreinene': ('næringsgrein',),
'næringsgreiner': ('næringsgrein',),
'næringsgren': ('næringsgren',),
'næringsgrena': ('næringsgren',),
'næringsgrenen': ('næringsgren',),
'næringsgrenene': ('næringsgren',),
'næringsgrener': ('næringsgren',),
'næringsinnhold': ('næringsinnhold',),
'næringsinnholda': ('næringsinnhold',),
'næringsinnholdene': ('næringsinnhold',),
'næringsinnholdet': ('næringsinnhold',),
'næringskilde': ('næringskilde',),
'næringskilden': ('næringskilde',),
'næringskildene': ('næringskilde',),
'næringskilder': ('næringskilde',),
'næringskjede': ('næringskjede',),
'næringskjeden': ('næringskjede',),
'næringskjedene': ('næringskjede',),
'næringskjeder': ('næringskjede',),
'næringskjelda': ('næringskjelde',),
'næringskjelde': ('næringskjelde',),
'næringskjelden': ('næringskjelde',),
'næringskjeldene': ('næringskjelde',),
'næringskjelder': ('næringskjelde',),
'næringsliv': ('næringsliv',),
'næringsliva': ('næringsliv',),
'næringslivene': ('næringsliv',),
'næringslivet': ('næringsliv',),
'næringslivsinteresse': ('næringslivsinteresse',),
'næringslivsinteressen': ('næringslivsinteresse',),
'næringslivsinteressene': ('næringslivsinteresse',),
'næringslivsinteresser': ('næringslivsinteresse',),
'næringsmiddel': ('næringsmiddel',),
'næringsmiddelet': ('næringsmiddel',),
'næringsmidla': ('næringsmiddel',),
'næringsmidlene': ('næringsmiddel',),
'næringsmidler': ('næringsmiddel',),
'næringsmidlet': ('næringsmiddel',),
'næringsmiddelindustri': ('næringsmiddelindustri',),
'næringsmiddelindustrien': ('næringsmiddelindustri',),
'næringsmiddelindustriene': ('næringsmiddelindustri',),
'næringsmiddelindustrier': ('næringsmiddelindustri',),
'næringsoppgava': ('næringsoppgave',),
'næringsoppgave': ('næringsoppgave',),
'næringsoppgaven': ('næringsoppgave',),
'næringsoppgavene': ('næringsoppgave',),
'næringsoppgaver': ('næringsoppgave',),
'næringspolitikk': ('næringspolitikk',),
'næringspolitikken': ('næringspolitikk',),
'næringspolitikkene': ('næringspolitikk',),
'næringspolitikker': ('næringspolitikk',),
'næringspyramide': ('næringspyramide',),
'næringspyramiden': ('næringspyramide',),
'næringspyramidene': ('næringspyramide',),
'næringspyramider': ('næringspyramide',),
'næringssorg': ('næringssorg',),
'næringssorga': ('næringssorg',),
'næringssorgen': ('næringssorg',),
'næringssorgene': ('næringssorg',),
'næringssorger': ('næringssorg',),
'næringsveg': ('næringsveg',),
'næringsvegen': ('næringsveg',),
'næringsvegene': ('næringsveg',),
'næringsveger': ('næringsveg',),
'næringsvei': ('næringsvei',),
'næringsveien': ('næringsvei',),
'næringsveiene': ('næringsvei',),
'næringsveier': ('næringsvei',),
'næringsverdi': ('næringsverdi',),
'næringsverdien': ('næringsverdi',),
'næringsverdiene': ('næringsverdi',),
'næringsverdier': ('næringsverdi',),
'næringsvett': ('næringsvett',),
'næringsvetta': ('næringsvett',),
'næringsvettene': ('næringsvett',),
'næringsvettet': ('næringsvett',),
'næringsvirksomhet': ('næringsvirksomhet',),
'næringsvirksomheta': ('næringsvirksomhet',),
'næringsvirksomheten': ('næringsvirksomhet',),
'næringsvirksomhetene': ('næringsvirksomhet',),
'næringsvirksomheter': ('næringsvirksomhet',),
'nærkamp': ('nærkamp',),
'nærkampen': ('nærkamp',),
'nærkampene': ('nærkamp',),
'nærkamper': ('nærkamp',),
'nærkontakt': ('nærkontakt',),
'nærkontakten': ('nærkontakt',),
'nærkontaktene': ('nærkontakt',),
'nærkontakter': ('nærkontakt',),
'nærkringkasting': ('nærkringkasting',),
'nærkringkastinga': ('nærkringkasting',),
'nærkringkastingen': ('nærkringkasting',),
'nærkringkastingene': ('nærkringkasting',),
'nærkringkastinger': ('nærkringkasting',),
'nærleik': ('nærleik',),
'nærleiken': ('nærleik',),
'nærleikene': ('nærleik',),
'nærleiker': ('nærleik',),
'nærlesing': ('nærlesing',),
'nærlesinga': ('nærlesing',),
'nærlesingen': ('nærlesing',),
'nærlesingene': ('nærlesing',),
'nærlesinger': ('nærlesing',),
'nærlesning': ('nærlesning',),
'nærlesninga': ('nærlesning',),
'nærlesningen': ('nærlesning',),
'nærlesningene': ('nærlesning',),
'nærlesninger': ('nærlesning',),
'nærlys': ('nærlys',),
'nærlysa': ('nærlys',),
'nærlysene': ('nærlys',),
'nærlyset': ('nærlys',),
'nærmiljø': ('nærmiljø',),
'nærmiljøa': ('nærmiljø',),
'nærmiljøene': ('nærmiljø',),
'nærmiljøer': ('nærmiljø',),
'nærmiljøet': ('nærmiljø',),
'nærradio': ('nærradio',),
'nærradioen': ('nærradio',),
'nærradioene': ('nærradio',),
'nærradioer': ('nærradio',),
'nærtagenhet': ('nærtagenhet',),
'nærtagenheta': ('nærtagenhet',),
'nærtagenheten': ('nærtagenhet',),
'nærtagenhetene': ('nærtagenhet',),
'nærtagenheter': ('nærtagenhet',),
'nærtakenhet': ('nærtakenhet',),
'nærtakenheta': ('nærtakenhet',),
'nærtakenheten': ('nærtakenhet',),
'nærtakenhetene': ('nærtakenhet',),
'nærtakenheter': ('nærtakenhet',),
'nærtrafikk': ('nærtrafikk',),
'nærtrafikken': ('nærtrafikk',),
'nærtrafikkene': ('nærtrafikk',),
'nærtrafikker': ('nærtrafikk',),
'nærvær': ('nærvær',),
'nærværa': ('nærvær',),
'nærværene': ('nærvær',),
'nærværet': ('nærvær',),
'nærværelse': ('nærværelse',),
'nærværelsen': ('nærværelse',),
'nærværelsene': ('nærværelse',),
'nærværelser': ('nærværelse',),
'nød': ('nød',),
'nøda': ('nød',),
'nøden': ('nød',),
'nødene': ('nød',),
'nøder': ('nød',),
'nødanker': ('nødanker',),
'nødankera': ('nødanker',),
'nødankere': ('nødanker',),
'nødankeret': ('nødanker',),
'nødankra': ('nødanker',),
'nødankre': ('nødanker',),
'nødankrene': ('nødanker',),
'nødankret': ('nødanker',),
'nødbluss': ('nødbluss',),
'nødblussa': ('nødbluss',),
'nødblussene': ('nødbluss',),
'nødblusset': ('nødbluss',),
'nødbrems': ('nødbrems',),
'nødbremsen': ('nødbrems',),
'nødbremsene': ('nødbrems',),
'nødbremser': ('nødbrems',),
'nødbremsa': ('nødbremse',),
'nødbremse': ('nødbremse',),
'nødbremsen': ('nødbremse',),
'nødbremsene': ('nødbremse',),
'nødbremser': ('nødbremse',),
'nøddåp': ('nøddåp',),
'nøddåpen': ('nøddåp',),
'nøddåpene': ('nøddåp',),
'nøddåper': ('nøddåp',),
'nødeld': ('nødeld',),
'nødelden': ('nødeld',),
'nødeldene': ('nødeld',),
'nødelder': ('nødeld',),
'nødeld': ('nødeld',),
'nødelden': ('nødeld',),
'nødeldene': ('nødeld',),
'nødelder': ('nødeld',),
'nødforbinding': ('nødforbinding',),
'nødforbindinga': ('nødforbinding',),
'nødforbindingen': ('nødforbinding',),
'nødforbindingene': ('nødforbinding',),
'nødforbindinger': ('nødforbinding',),
'nødhamn': ('nødhamn',),
'nødhamna': ('nødhamn',),
'nødhamnen': ('nødhamn',),
'nødhamnene': ('nødhamn',),
'nødhamner': ('nødhamn',),
'nødhavn': ('nødhavn',),
'nødhavna': ('nødhavn',),
'nødhavnen': ('nødhavn',),
'nødhavnene': ('nødhavn',),
'nødhavner': ('nødhavn',),
'nødhjelp': ('nødhjelp',),
'nødhjelpa': ('nødhjelp',),
'nødhjelpen': ('nødhjelp',),
'nødhjelpene': ('nødhjelp',),
'nødhjelper': ('nødhjelp',),
'nødild': ('nødild',),
'nødilden': ('nødild',),
'nødildene': ('nødild',),
'nødilder': ('nødild',),
'nødild': ('nødild',),
'nødilden': ('nødild',),
'nødildene': ('nødild',),
'nødilder': ('nødild',),
'nødløgn': ('nødløgn',),
'nødløgna': ('nødløgn',),
'nødløgnen': ('nødløgn',),
'nødløgnene': ('nødløgn',),
'nødløgner': ('nødløgn',),
'nødløsning': ('nødløsning',),
'nødløsninga': ('nødløsning',),
'nødløsningen': ('nødløsning',),
'nødløsningene': ('nødløsning',),
'nødløsninger': ('nødløsning',),
'nødmelding': ('nødmelding',),
'nødmeldinga': ('nødmelding',),
'nødmeldingen': ('nødmelding',),
'nødmeldingene': ('nødmelding',),
'nødmeldinger': ('nødmelding',),
'nødmynt': ('nødmynt',),
'nødmynten': ('nødmynt',),
'nødmyntene': ('nødmynt',),
'nødmynter': ('nødmynt',),
'nødpeilesender': ('nødpeilesender',),
'nødpeilesendere': ('nødpeilesender',),
'nødpeilesenderen': ('nødpeilesender',),
'nødpeilesenderer': ('nødpeilesender',),
'nødpeilesenderne': ('nødpeilesender',),
'nødrakett': ('nødrakett',),
'nødraketten': ('nødrakett',),
'nødrakettene': ('nødrakett',),
'nødraketter': ('nødrakett',),
'nødrett': ('nødrett',),
'nødretten': ('nødrett',),
'nødrettene': ('nødrett',),
'nødretter': ('nødrett',),
'nødrop': ('nødrop',),
'nødropa': ('nødrop',),
'nødropene': ('nødrop',),
'nødropet': ('nødrop',),
'nødsarbeid': ('nødsarbeid',),
'nødsarbeida': ('nødsarbeid',),
'nødsarbeidene': ('nødsarbeid',),
'nødsarbeider': ('nødsarbeid',),
'nødsarbeidet': ('nødsarbeid',),
'nødsfall': ('nødsfall',),
'nødsfalla': ('nødsfall',),
'nødsfallene': ('nødsfall',),
'nødsfallet': ('nødsfall',),
'nødsforanstaltning': ('nødsforanstaltning',),
'nødsforanstaltninga': ('nødsforanstaltning',),
'nødsforanstaltningen': ('nødsforanstaltning',),
'nødsforanstaltningene': ('nødsforanstaltning',),
'nødsforanstaltninger': ('nødsforanstaltning',),
'nødsignal': ('nødsignal',),
'nødsignala': ('nødsignal',),
'nødsignalene': ('nødsignal',),
'nødsignaler': ('nødsignal',),
'nødsignalet': ('nødsignal',),
'nødskrik': ('nødskrik',),
'nødskrika': ('nødskrik',),
'nødskrikene': ('nødskrik',),
'nødskriket': ('nødskrik',),
'nødssituasjon': ('nødssituasjon',),
'nødssituasjonen': ('nødssituasjon',),
'nødssituasjonene': ('nødssituasjon',),
'nødssituasjoner': ('nødssituasjon',),
'nødstilfella': ('nødstilfelle',),
'nødstilfelle': ('nødstilfelle',),
'nødstilfellene': ('nødstilfelle',),
'nødstilfeller': ('nødstilfelle',),
'nødstilfellet': ('nødstilfelle',),
'nødsår': ('nødsår',),
'nødsåra': ('nødsår',),
'nødsårene': ('nødsår',),
'nødsåret': ('nødsår',),
'nødtelefon': ('nødtelefon',),
'nødtelefonen': ('nødtelefon',),
'nødtelefonene': ('nødtelefon',),
'nødtelefoner': ('nødtelefon',),
'nødtørft': ('nødtørft',),
'nødtørften': ('nødtørft',),
'nødtørftene': ('nødtørft',),
'nødtørfter': ('nødtørft',),
'nødtørftshus': ('nødtørftshus',),
'nødtørftshusa': ('nødtørftshus',),
'nødtørftshusene': ('nødtørftshus',),
'nødtørftshuset': ('nødtørftshus',),
'nødutgang': ('nødutgang',),
'nødutgangen': ('nødutgang',),
'nødutgangene': ('nødutgang',),
'nødutganger': ('nødutgang',),
'nødutveg': ('nødutveg',),
'nødutvegen': ('nødutveg',),
'nødutvegene': ('nødutveg',),
'nødutveger': ('nødutveg',),
'nødutvei': ('nødutvei',),
'nødutveien': ('nødutvei',),
'nødutveiene': ('nødutvei',),
'nødutveier': ('nødutvei',),
'nødvendighet': ('nødvendighet',),
'nødvendigheten': ('nødvendighet',),
'nødvendighetene': ('nødvendighet',),
'nødvendigheter': ('nødvendighet',),
'nødvendighetsvara': ('nødvendighetsvare',),
'nødvendighetsvare': ('nødvendighetsvare',),
'nødvendighetsvaren': ('nødvendighetsvare',),
'nødvendighetsvarene': ('nødvendighetsvare',),
'nødvendighetsvarer': ('nødvendighetsvare',),
'nødverga': ('nødverge',),
'nødverge': ('nødverge',),
'nødvergene': ('nødverge',),
'nødverger': ('nødverge',),
'nødverget': ('nødverge',),
'nødverga': ('nødverge',),
'nødverge': ('nødverge',),
'nødvergene': ('nødverge',),
'nødverger': ('nødverge',),
'nødverget': ('nødverge',),
'nødvergedrap': ('nødvergedrap',),
'nødvergedrapa': ('nødvergedrap',),
'nødvergedrapene': ('nødvergedrap',),
'nødvergedrapet': ('nødvergedrap',),
'nødverja': ('nødverje',),
'nødverje': ('nødverje',),
'nødverjen': ('nødverje',),
'nødverjene': ('nødverje',),
'nødverjer': ('nødverje',),
'nødverjedrap': ('nødverjedrap',),
'nødverjedrapa': ('nødverjedrap',),
'nødverjedrapene': ('nødverjedrap',),
'nødverjedrapet': ('nødverjedrap',),
'nødår': ('nødår',),
'nødåra': ('nødår',),
'nødårene': ('nødår',),
'nødåret': ('nødår',),
'nøff': ('nøff',),
'nøffa': ('nøff',),
'nøffene': ('nøff',),
'nøffet': ('nøff',),
'nøffnøff': ('nøffnøff',),
'nøffnøffen': ('nøffnøff',),
'nøffnøffene': ('nøffnøff',),
'nøffnøffer': ('nøffnøff',),
'nøgd': ('nøgd',),
'nøgda': ('nøgd',),
'nøgden': ('nøgd',),
'nøgdene': ('nøgd',),
'nøgder': ('nøgd',),
'nøkk': ('nøkk',),
'nøkken': ('nøkk',),
'nøkkene': ('nøkk',),
'nøkker': ('nøkk',),
'nøkkeblom': ('nøkkeblom',),
'nøkkeblommen': ('nøkkeblom',),
'nøkkeblommene': ('nøkkeblom',),
'nøkkeblommer': ('nøkkeblom',),
'nøkkeblomst': ('nøkkeblomst',),
'nøkkeblomsten': ('nøkkeblomst',),
'nøkkeblomstene': ('nøkkeblomst',),
'nøkkeblomster': ('nøkkeblomst',),
'nøkkel': ('nøkkel',),
'nøkkelen': ('nøkkel',),
'nøklene': ('nøkkel',),
'nøkler': ('nøkkel',),
'nøkkelbarn': ('nøkkelbarn',),
'nøkkelbarna': ('nøkkelbarn',),
'nøkkelbarnene': ('nøkkelbarn',),
'nøkkelbarnet': ('nøkkelbarn',),
'nøkkelbedrift': ('nøkkelbedrift',),
'nøkkelbedriften': ('nøkkelbedrift',),
'nøkkelbedriftene': ('nøkkelbedrift',),
'nøkkelbedrifter': ('nøkkelbedrift',),
'nøkkelhank': ('nøkkelhank',),
'nøkkelhanka': ('nøkkelhank',),
'nøkkelhanken': ('nøkkelhank',),
'nøkkelhankene': ('nøkkelhank',),
'nøkkelhanker': ('nøkkelhank',),
'nøkkelhol': ('nøkkelhol',),
'nøkkelhola': ('nøkkelhol',),
'nøkkelholene': ('nøkkelhol',),
'nøkkelholet': ('nøkkelhol',),
'nøkkelhull': ('nøkkelhull',),
'nøkkelhulla': ('nøkkelhull',),
'nøkkelhullene': ('nøkkelhull',),
'nøkkelhuller': ('nøkkelhull',),
'nøkkelhullet': ('nøkkelhull',),
'nøkkelindustri': ('nøkkelindustri',),
'nøkkelindustrien': ('nøkkelindustri',),
'nøkkelindustriene': ('nøkkelindustri',),
'nøkkelindustrier': ('nøkkelindustri',),
'nøkkelknippa': ('nøkkelknippe',),
'nøkkelknippe': ('nøkkelknippe',),
'nøkkelknippene': ('nøkkelknippe',),
'nøkkelknipper': ('nøkkelknippe',),
'nøkkelknippet': ('nøkkelknippe',),
'nøkkelkort': ('nøkkelkort',),
'nøkkelkorta': ('nøkkelkort',),
'nøkkelkortene': ('nøkkelkort',),
'nøkkelkortet': ('nøkkelkort',),
'nøkkelmakt': ('nøkkelmakt',),
'nøkkelmakta': ('nøkkelmakt',),
'nøkkelmakten': ('nøkkelmakt',),
'nøkkelmaktene': ('nøkkelmakt',),
'nøkkelmakter': ('nøkkelmakt',),
'nøkkelord': ('nøkkelord',),
'nøkkelorda': ('nøkkelord',),
'nøkkelordene': ('nøkkelord',),
'nøkkelordet': ('nøkkelord',),
'nøkkelost': ('nøkkelost',),
'nøkkelosten': ('nøkkelost',),
'nøkkelostene': ('nøkkelost',),
'nøkkeloster': ('nøkkelost',),
'nøkkelperson': ('nøkkelperson',),
'nøkkelpersonen': ('nøkkelperson',),
'nøkkelpersonene': ('nøkkelperson',),
'nøkkelpersoner': ('nøkkelperson',),
'nøkkelring': ('nøkkelring',),
'nøkkelringen': ('nøkkelring',),
'nøkkelringene': ('nøkkelring',),
'nøkkelringer': ('nøkkelring',),
'nøkkelroman': ('nøkkelroman',),
'nøkkelromanen': ('nøkkelroman',),
'nøkkelromanene': ('nøkkelroman',),
'nøkkelromaner': ('nøkkelroman',),
'nøkkelskilt': ('nøkkelskilt',),
'nøkkelskilta': ('nøkkelskilt',),
'nøkkelskiltene': ('nøkkelskilt',),
'nøkkelskilter': ('nøkkelskilt',),
'nøkkelskiltet': ('nøkkelskilt',),
'nøkkelstilling': ('nøkkelstilling',),
'nøkkelstillinga': ('nøkkelstilling',),
'nøkkelstillingen': ('nøkkelstilling',),
'nøkkelstillingene': ('nøkkelstilling',),
'nøkkelstillinger': ('nøkkelstilling',),
'nøkkerosa': ('nøkkerose',),
'nøkkerose': ('nøkkerose',),
'nøkkerosen': ('nøkkerose',),
'nøkkerosene': ('nøkkerose',),
'nøkkeroser': ('nøkkerose',),
'nøkleband': ('nøkleband',),
'nøklebanda': ('nøkleband',),
'nøklebandene': ('nøkleband',),
'nøklebandet': ('nøkleband',),
'nøklebein': ('nøklebein',),
'nøklebeina': ('nøklebein',),
'nøklebeinene': ('nøklebein',),
'nøklebeinet': ('nøklebein',),
'nøkleben': ('nøkleben',),
'nøklebena': ('nøkleben',),
'nøklebenene': ('nøkleben',),
'nøklebenet': ('nøkleben',),
'nøkleblom': ('nøkleblom',),
'nøkleblommen': ('nøkleblom',),
'nøkleblommene': ('nøkleblom',),
'nøkleblommer': ('nøkleblom',),
'nøkleblomst': ('nøkleblomst',),
'nøkleblomsten': ('nøkleblomst',),
'nøkleblomstene': ('nøkleblomst',),
'nøkleblomster': ('nøkleblomst',),
'nøklebånd': ('nøklebånd',),
'nøklebånda': ('nøklebånd',),
'nøklebåndene': ('nøklebånd',),
'nøklebåndet': ('nøklebånd',),
'nøklehank': ('nøklehank',),
'nøklehanka': ('nøklehank',),
'nøklehanken': ('nøklehank',),
'nøklehankene': ('nøklehank',),
'nøklehanker': ('nøklehank',),
'nøklehol': ('nøklehol',),
'nøklehola': ('nøklehol',),
'nøkleholene': ('nøklehol',),
'nøkleholet': ('nøklehol',),
'nøklehull': ('nøklehull',),
'nøklehulla': ('nøklehull',),
'nøklehullene': ('nøklehull',),
'nøklehuller': ('nøklehull',),
'nøklehullet': ('nøklehull',),
'nøkleknippa': ('nøkleknippe',),
'nøkleknippe': ('nøkleknippe',),
'nøkleknippene': ('nøkleknippe',),
'nøkleknipper': ('nøkleknippe',),
'nøkleknippet': ('nøkleknippe',),
'nøklemakt': ('nøklemakt',),
'nøklemakta': ('nøklemakt',),
'nøklemakten': ('nøklemakt',),
'nøklemaktene': ('nøklemakt',),
'nøklemakter': ('nøklemakt',),
'nøkleskilt': ('nøkleskilt',),
'nøkleskilta': ('nøkleskilt',),
'nøkleskiltene': ('nøkleskilt',),
'nøkleskilter': ('nøkleskilt',),
'nøkleskiltet': ('nøkleskilt',),
'nøla': ('nøle',),
'nøle': ('nøle',),
'nølen': ('nøle',),
'nølene': ('nøle',),
'nøler': ('nøle',),
'nølepolitikk': ('nølepolitikk',),
'nølepolitikken': ('nølepolitikk',),
'nølepolitikkene': ('nølepolitikk',),
'nølepolitikker': ('nølepolitikk',),
'nøler': ('nøler',),
'nølere': ('nøler',),
'nøleren': ('nøler',),
'nølerer': ('nøler',),
'nølerne': ('nøler',),
'nør': ('nør',),
'nøren': ('nør',),
'nørene': ('nør',),
'nører': ('nør',),
'nøreved': ('nøreved',),
'nøreveden': ('nøreved',),
'nørevedene': ('nøreved',),
'nøreveder': ('nøreved',),
'nøsta': ('nøste',),
'nøste': ('nøste',),
'nøstene': ('nøste',),
'nøster': ('nøste',),
'nøstet': ('nøste',),
'nøtt': ('nøtt',),
'nøtta': ('nøtt',),
'nøtten': ('nøtt',),
'nøttene': ('nøtt',),
'nøtter': ('nøtt',),
'nøttekjerne': ('nøttekjerne',),
'nøttekjernen': ('nøttekjerne',),
'nøttekjernene': ('nøttekjerne',),
'nøttekjerner': ('nøttekjerne',),
'nøtteknekker': ('nøtteknekker',),
'nøtteknekkere': ('nøtteknekker',),
'nøtteknekkeren': ('nøtteknekker',),
'nøtteknekkerer': ('nøtteknekker',),
'nøtteknekkerne': ('nøtteknekker',),
'nøttekråka': ('nøttekråke',),
'nøttekråke': ('nøttekråke',),
'nøttekråken': ('nøttekråke',),
'nøttekråkene': ('nøttekråke',),
'nøttekråker': ('nøttekråke',),
'nøtteolja': ('nøtteolje',),
'nøtteolje': ('nøtteolje',),
'nøtteoljen': ('nøtteolje',),
'nøtteoljene': ('nøtteolje',),
'nøtteoljer': ('nøtteolje',),
'nøtteskal': ('nøtteskal',),
'nøtteskala': ('nøtteskal',),
'nøtteskalene': ('nøtteskal',),
'nøtteskalet': ('nøtteskal',),
'nøtteskall': ('nøtteskall',),
'nøtteskalla': ('nøtteskall',),
'nøtteskallene': ('nøtteskall',),
'nøtteskallet': ('nøtteskall',),
'nøtteskrika': ('nøtteskrike',),
'nøtteskrike': ('nøtteskrike',),
'nøtteskriken': ('nøtteskrike',),
'nøtteskrikene': ('nøtteskrike',),
'nøtteskriker': ('nøtteskrike',),
'nøyaktighet': ('nøyaktighet',),
'nøyaktigheta': ('nøyaktighet',),
'nøyaktigheten': ('nøyaktighet',),
'nøyaktighetene': ('nøyaktighet',),
'nøyaktigheter': ('nøyaktighet',),
'nøysomhet': ('nøysomhet',),
'nøysomheta': ('nøysomhet',),
'nøysomheten': ('nøysomhet',),
'nøysomhetene': ('nøysomhet',),
'nøysomheter': ('nøysomhet',),
'nøytralisasjon': ('nøytralisasjon',),
'nøytralisasjonen': ('nøytralisasjon',),
'nøytralisasjonene': ('nøytralisasjon',),
'nøytralisasjoner': ('nøytralisasjon',),
'nøytralisme': ('nøytralisme',),
'nøytralismen': ('nøytralisme',),
'nøytralismene': ('nøytralisme',),
'nøytralismer': ('nøytralisme',),
'nøytralitet': ('nøytralitet',),
'nøytraliteten': ('nøytralitet',),
'nøytralitetene': ('nøytralitet',),
'nøytraliteter': ('nøytralitet',),
'nøytralitetserklæring': ('nøytralitetserklæring',),
'nøytralitetserklæringa': ('nøytralitetserklæring',),
'nøytralitetserklæringen': ('nøytralitetserklæring',),
'nøytralitetserklæringene': ('nøytralitetserklæring',),
'nøytralitetserklæringer': ('nøytralitetserklæring',),
'nøytralitetsforbund': ('nøytralitetsforbund',),
'nøytralitetsforbunda': ('nøytralitetsforbund',),
'nøytralitetsforbundene': ('nøytralitetsforbund',),
'nøytralitetsforbundet': ('nøytralitetsforbund',),
'nøytralitetskrenkelse': ('nøytralitetskrenkelse',),
'nøytralitetskrenkelsen': ('nøytralitetskrenkelse',),
'nøytralitetskrenkelsene': ('nøytralitetskrenkelse',),
'nøytralitetskrenkelser': ('nøytralitetskrenkelse',),
'nøytralitetskrenking': ('nøytralitetskrenking',),
'nøytralitetskrenkinga': ('nøytralitetskrenking',),
'nøytralitetskrenkingen': ('nøytralitetskrenking',),
'nøytralitetskrenkingene': ('nøytralitetskrenking',),
'nøytralitetskrenkinger': ('nøytralitetskrenking',),
'nøytralitetsvakt': ('nøytralitetsvakt',),
'nøytralitetsvakta': ('nøytralitetsvakt',),
'nøytralitetsvakten': ('nøytralitetsvakt',),
'nøytralitetsvaktene': ('nøytralitetsvakt',),
'nøytralitetsvakter': ('nøytralitetsvakt',),
'nøytralitetsvern': ('nøytralitetsvern',),
'nøytralitetsverna': ('nøytralitetsvern',),
'nøytralitetsvernene': ('nøytralitetsvern',),
'nøytralitetsvernet': ('nøytralitetsvern',),
'nøytron': ('nøytron',),
'nøytrona': ('nøytron',),
'nøytronene': ('nøytron',),
'nøytroner': ('nøytron',),
'nøytronet': ('nøytron',),
'nøytronbomba': ('nøytronbombe',),
'nøytronbombe': ('nøytronbombe',),
'nøytronbomben': ('nøytronbombe',),
'nøytronbombene': ('nøytronbombe',),
'nøytronbomber': ('nøytronbombe',),
'nøytra': ('nøytrum',),
'nøytraene': ('nøytrum',),
'nøytrene': ('nøytrum',),
'nøytrer': ('nøytrum',),
'nøytret': ('nøytrum',),
'nøytrum': ('nøytrum',),
'nøytrumet': ('nøytrum',),
'nøytrumsord': ('nøytrumsord',),
'nøytrumsorda': ('nøytrumsord',),
'nøytrumsordene': ('nøytrumsord',),
'nøytrumsordet': ('nøytrumsord',),
'o': ('o',),
'o\'en': ('o',),
'o-en': ('o',),
'o-ene': ('o',),
'o-er': ('o',),
'o-fag': ('o-fag',),
'o-faga': ('o-fag',),
'o-fagene': ('o-fag',),
'o-faget': ('o-fag',),
'o-løp': ('o-løp',),
'o-løpa': ('o-løp',),
'o-løpene': ('o-løp',),
'o-løpet': ('o-løp',),
'o-løper': ('o-løper',),
'o-løpere': ('o-løper',),
'o-løperen': ('o-løper',),
'o-løperer': ('o-løper',),
'o-løperne': ('o-løper',),
'oase': ('oase',),
'oasen': ('oase',),
'oasene': ('oase',),
'oaser': ('oase',),
'obduksjon': ('obduksjon',),
'obduksjonen': ('obduksjon',),
'obduksjonene': ('obduksjon',),
'obduksjoner': ('obduksjon',),
'obdusent': ('obdusent',),
'obdusenten': ('obdusent',),
'obdusentene': ('obdusent',),
'obdusenter': ('obdusent',),
'obelisk': ('obelisk',),
'obelisken': ('obelisk',),
'obeliskene': ('obelisk',),
'obelisker': ('obelisk',),
'oberst': ('oberst',),
'obersten': ('oberst',),
'oberstene': ('oberst',),
'oberster': ('oberst',),
'oberstløytnant': ('oberstløytnant',),
'oberstløytnanten': ('oberstløytnant',),
'oberstløytnantene': ('oberstløytnant',),
'oberstløytnanter': ('oberstløytnant',),
'objekt': ('objekt',),
'objekta': ('objekt',),
'objektene': ('objekt',),
'objekter': ('objekt',),
'objektet': ('objekt',),
'objektiv': ('objektiv',),
'objektiva': ('objektiv',),
'objektivene': ('objektiv',),
'objektiver': ('objektiv',),
'objektivet': ('objektiv',),
'objektivisme': ('objektivisme',),
'objektivismen': ('objektivisme',),
'objektivismene': ('objektivisme',),
'objektivismer': ('objektivisme',),
'objektivitet': ('objektivitet',),
'objektiviteten': ('objektivitet',),
'objektivitetene': ('objektivitet',),
'objektiviteter': ('objektivitet',),
'objektsform': ('objektsform',),
'objektsforma': ('objektsform',),
'objektsformen': ('objektsform',),
'objektsformene': ('objektsform',),
'objektsformer': ('objektsform',),
'objektsgenitiv': ('objektsgenitiv',),
'objektsgenitiven': ('objektsgenitiv',),
'objektsgenitivene': ('objektsgenitiv',),
'objektsgenitiver': ('objektsgenitiv',),
'objektskasus': ('objektskasus',),
'objektskasusen': ('objektskasus',),
'objektskasusene': ('objektskasus',),
'objektskasuser': ('objektskasus',),
'objektsspråk': ('objektsspråk',),
'objektsspråka': ('objektsspråk',),
'objektsspråkene': ('objektsspråk',),
'objektsspråket': ('objektsspråk',),
'oblat': ('oblat',),
'oblaten': ('oblat',),
'oblatene': ('oblat',),
'oblater': ('oblat',),
'obligasjon': ('obligasjon',),
'obligasjonen': ('obligasjon',),
'obligasjonene': ('obligasjon',),
'obligasjoner': ('obligasjon',),
'obligasjonsleilighet': ('obligasjonsleilighet',),
'obligasjonsleiligheta': ('obligasjonsleilighet',),
'obligasjonsleiligheten': ('obligasjonsleilighet',),
'obligasjonsleilighetene': ('obligasjonsleilighet',),
'obligasjonsleiligheter': ('obligasjonsleilighet',),
'obligasjonslån': ('obligasjonslån',),
'obligasjonslåna': ('obligasjonslån',),
'obligasjonslånene': ('obligasjonslån',),
'obligasjonslånet': ('obligasjonslån',),
'obligasjonsrett': ('obligasjonsrett',),
'obligasjonsretten': ('obligasjonsrett',),
'obligasjonsrettene': ('obligasjonsrett',),
'obligasjonsretter': ('obligasjonsrett',),
'obo': ('obo',),
'oboen': ('obo',),
'oboene': ('obo',),
'oboer': ('obo',),
'oboist': ('oboist',),
'oboisten': ('oboist',),
'oboistene': ('oboist',),
'oboister': ('oboist',),
'oboskip': ('oboskip',),
'oboskipa': ('oboskip',),
'oboskipene': ('oboskip',),
'oboskipet': ('oboskip',),
'observand': ('observand',),
'observanden': ('observand',),
'observandene': ('observand',),
'observander': ('observand',),
'observans': ('observans',),
'observansen': ('observans',),
'observansene': ('observans',),
'observanser': ('observans',),
'observasjon': ('observasjon',),
'observasjonen': ('observasjon',),
'observasjonene': ('observasjon',),
'observasjoner': ('observasjon',),
'observator': ('observator',),
'observatoren': ('observator',),
'observatorene': ('observator',),
'observatorer': ('observator',),
'observatoria': ('observatorium',),
'observatoriene': ('observatorium',),
'observatorier': ('observatorium',),
'observatoriet': ('observatorium',),
'observatorium': ('observatorium',),
'observatør': ('observatør',),
'observatøren': ('observatør',),
'observatørene': ('observatør',),
'observatører': ('observatør',),
'obskurant': ('obskurant',),
'obskuranten': ('obskurant',),
'obskurantene': ('obskurant',),
'obskuranter': ('obskurant',),
'obskurantisme': ('obskurantisme',),
'obskurantismen': ('obskurantisme',),
'obskurantismene': ('obskurantisme',),
'obskurantismer': ('obskurantisme',),
'obskurantist': ('obskurantist',),
'obskurantisten': ('obskurantist',),
'obskurantistene': ('obskurantist',),
'obskurantister': ('obskurantist',),
'obskuritet': ('obskuritet',),
'obskuriteten': ('obskuritet',),
'obskuritetene': ('obskuritet',),
'obskuriteter': ('obskuritet',),
'obskønitet': ('obskønitet',),
'obskøniteten': ('obskønitet',),
'obskønitetene': ('obskønitet',),
'obskøniteter': ('obskønitet',),
'obstetrikk': ('obstetrikk',),
'obstetrikken': ('obstetrikk',),
'obstetrikkene': ('obstetrikk',),
'obstetrikker': ('obstetrikk',),
'obstipasjon': ('obstipasjon',),
'obstipasjonen': ('obstipasjon',),
'obstipasjonene': ('obstipasjon',),
'obstipasjoner': ('obstipasjon',),
'obstruksjon': ('obstruksjon',),
'obstruksjonen': ('obstruksjon',),
'obstruksjonene': ('obstruksjon',),
'obstruksjoner': ('obstruksjon',),
'odalisk': ('odalisk',),
'odalisken': ('odalisk',),
'odaliskene': ('odalisk',),
'odalisker': ('odalisk',),
'odd': ('odd',),
'odden': ('odd',),
'oddene': ('odd',),
'odder': ('odd',),
'odde': ('odde',),
'odden': ('odde',),
'oddene': ('odde',),
'odder': ('odde',),
'odde': ('odde',),
'odden': ('odde',),
'oddene': ('odde',),
'odder': ('odde',),
'oddetal': ('oddetal',),
'oddetala': ('oddetal',),
'oddetalene': ('oddetal',),
'oddetalet': ('oddetal',),
'oddetall': ('oddetall',),
'oddetalla': ('oddetall',),
'oddetallene': ('oddetall',),
'oddetallet': ('oddetall',),
'odds': ('odds',),
'oddsen': ('odds',),
'oddsene': ('odds',),
'oddsbomba': ('oddsbombe',),
'oddsbombe': ('oddsbombe',),
'oddsbomben': ('oddsbombe',),
'oddsbombene': ('oddsbombe',),
'oddsbomber': ('oddsbombe',),
'ode': ('ode',),
'oden': ('ode',),
'odene': ('ode',),
'oder': ('ode',),
'odel': ('odel',),
'odelen': ('odel',),
'odlene': ('odel',),
'odler': ('odel',),
'odelsbonde': ('odelsbonde',),
'odelsbonden': ('odelsbonde',),
'odelsbøndene': ('odelsbonde',),
'odelsbønder': ('odelsbonde',),
'odelsgard': ('odelsgard',),
'odelsgarden': ('odelsgard',),
'odelsgardene': ('odelsgard',),
'odelsgarder': ('odelsgard',),
'odelsgutt': ('odelsgutt',),
'odelsgutten': ('odelsgutt',),
'odelsguttene': ('odelsgutt',),
'odelsgutter': ('odelsgutt',),
'odelsgård': ('odelsgård',),
'odelsgården': ('odelsgård',),
'odelsgårdene': ('odelsgård',),
'odelsgårder': ('odelsgård',),
'odelsjenta': ('odelsjente',),
'odelsjente': ('odelsjente',),
'odelsjenten': ('odelsjente',),
'odelsjentene': ('odelsjente',),
'odelsjenter': ('odelsjente',),
'odelsjord': ('odelsjord',),
'odelsjorda': ('odelsjord',),
'odelsjorden': ('odelsjord',),
'odelsjordene': ('odelsjord',),
'odelsjorder': ('odelsjord',),
'odelsrett': ('odelsrett',),
'odelsretten': ('odelsrett',),
'odelsrettene': ('odelsrett',),
'odelsretter': ('odelsrett',),
'odelsting': ('odelsting',),
'odelstinga': ('odelsting',),
'odelstingene': ('odelsting',),
'odelstinget': ('odelsting',),
'odelstingspresident': ('odelstingspresident',),
'odelstingspresidenten': ('odelstingspresident',),
'odelstingspresidentene': ('odelstingspresident',),
'odelstingspresidenter': ('odelstingspresident',),
'odelstingsproposisjon': ('odelstingsproposisjon',),
'odelstingsproposisjonen': ('odelstingsproposisjon',),
'odelstingsproposisjonene': ('odelstingsproposisjon',),
'odelstingsproposisjoner': ('odelstingsproposisjon',),
'odometer': ('odometer',),
'odometeret': ('odometer',),
'odometra': ('odometer',),
'odometre': ('odometer',),
'odometrene': ('odometer',),
'odometret': ('odometer',),
'odontolog': ('odontolog',),
'odontologen': ('odontolog',),
'odontologene': ('odontolog',),
'odontologer': ('odontolog',),
'odontologi': ('odontologi',),
'odontologien': ('odontologi',),
'odontologiene': ('odontologi',),
'odontologier': ('odontologi',),
'odysseen': ('odyssé',),
'odysseene': ('odyssé',),
'odysseer': ('odyssé',),
'odyssé': ('odyssé',),
'odysséen': ('odyssé',),
'odysséene': ('odyssé',),
'odysséer': ('odyssé',),
'odør': ('odør',),
'odøren': ('odør',),
'odørene': ('odør',),
'odører': ('odør',),
'offensiv': ('offensiv',),
'offensiven': ('offensiv',),
'offensivene': ('offensiv',),
'offensiver': ('offensiv',),
'offentlighet': ('offentlighet',),
'offentligheta': ('offentlighet',),
'offentligheten': ('offentlighet',),
'offentlighetene': ('offentlighet',),
'offentligheter': ('offentlighet',),
'offentlighetsprinsipp': ('offentlighetsprinsipp',),
'offentlighetsprinsippa': ('offentlighetsprinsipp',),
'offentlighetsprinsippene': ('offentlighetsprinsipp',),
'offentlighetsprinsipper': ('offentlighetsprinsipp',),
'offentlighetsprinsippet': ('offentlighetsprinsipp',),
'offer': ('offer',),
'offeret': ('offer',),
'ofra': ('offer',),
'ofre': ('offer',),
'ofrene': ('offer',),
'offerdyr': ('offerdyr',),
'offerdyra': ('offerdyr',),
'offerdyrene': ('offerdyr',),
'offerdyret': ('offerdyr',),
'offerfest': ('offerfest',),
'offerfesten': ('offerfest',),
'offerfestene': ('offerfest',),
'offerfester': ('offerfest',),
'offerlam': ('offerlam',),
'offerlamma': ('offerlam',),
'offerlammene': ('offerlam',),
'offerlammet': ('offerlam',),
'offersted': ('offersted',),
'offerstedene': ('offersted',),
'offersteder': ('offersted',),
'offerstedet': ('offersted',),
'offerte': ('offerte',),
'offerten': ('offerte',),
'offertene': ('offerte',),
'offerter': ('offerte',),
'offertoria': ('offertorium',),
'offertoriene': ('offertorium',),
'offertorier': ('offertorium',),
'offertoriet': ('offertorium',),
'offertorium': ('offertorium',),
'offervilje': ('offervilje',),
'offerviljen': ('offervilje',),
'offerviljene': ('offervilje',),
'offerviljer': ('offervilje',),
'officia': ('officium',),
'officiene': ('officium',),
'officier': ('officium',),
'officiet': ('officium',),
'officium': ('officium',),
'offiser': ('offiser',),
'offiseren': ('offiser',),
'offiserene': ('offiser',),
'offiserer': ('offiser',),
'offisersmessa': ('offisersmesse',),
'offisersmesse': ('offisersmesse',),
'offisersmessen': ('offisersmesse',),
'offisersmessene': ('offisersmesse',),
'offisersmesser': ('offisersmesse',),
'offisin': ('offisin',),
'offisina': ('offisin',),
'offisinene': ('offisin',),
'offisiner': ('offisin',),
'offisinet': ('offisin',),
'offset': ('offset',),
'offseten': ('offset',),
'offsetene': ('offset',),
'offseter': ('offset',),
'offsettrykk': ('offsettrykk',),
'offsettrykka': ('offsettrykk',),
'offsettrykkene': ('offsettrykk',),
'offsettrykket': ('offsettrykk',),
'offshoreindustri': ('offshoreindustri',),
'offshoreindustrien': ('offshoreindustri',),
'offshoreindustriene': ('offshoreindustri',),
'offshoreindustrier': ('offshoreindustri',),
'offshorevirksomhet': ('offshorevirksomhet',),
'offshorevirksomheta': ('offshorevirksomhet',),
'offshorevirksomheten': ('offshorevirksomhet',),
'offshorevirksomhetene': ('offshorevirksomhet',),
'offshorevirksomheter': ('offshorevirksomhet',),
'offside': ('offside',),
'offsiden': ('offside',),
'offsidene': ('offside',),
'offsider': ('offside',),
'offsideposisjon': ('offsideposisjon',),
'offsideposisjonen': ('offsideposisjon',),
'offsideposisjonene': ('offsideposisjon',),
'offsideposisjoner': ('offsideposisjon',),
'offsidetaktikk': ('offsidetaktikk',),
'offsidetaktikken': ('offsidetaktikk',),
'offsidetaktikkene': ('offsidetaktikk',),
'offsidetaktikker': ('offsidetaktikk',),
'ofring': ('ofring',),
'ofringa': ('ofring',),
'ofringen': ('ofring',),
'ofringene': ('ofring',),
'ofringer': ('ofring',),
'ofse': ('ofse',),
'ofsen': ('ofse',),
'ofsene': ('ofse',),
'ofser': ('ofse',),
'oftalmolog': ('oftalmolog',),
'oftalmologen': ('oftalmolog',),
'oftalmologene': ('oftalmolog',),
'oftalmologer': ('oftalmolog',),
'oftalmologi': ('oftalmologi',),
'oftalmologien': ('oftalmologi',),
'oftalmologiene': ('oftalmologi',),
'oftalmologier': ('oftalmologi',),
'ohm': ('ohm',),
'ohmen': ('ohm',),
'ohmene': ('ohm',),
'ohmmeter': ('ohmmeter',),
'ohmmeteret': ('ohmmeter',),
'ohmmetra': ('ohmmeter',),
'ohmmetre': ('ohmmeter',),
'ohmmetrene': ('ohmmeter',),
'ohmmetret': ('ohmmeter',),
'okapi': ('okapi',),
'okapien': ('okapi',),
'okapiene': ('okapi',),
'okapier': ('okapi',),
'okarina': ('okarina',),
'okarinaen': ('okarina',),
'okarinaene': ('okarina',),
'okarinaer': ('okarina',),
'oker': ('oker',),
'okere': ('oker',),
'okeren': ('oker',),
'okerer': ('oker',),
'okerne': ('oker',),
'okre': ('oker',),
'okrene': ('oker',),
'okrer': ('oker',),
'okerfarge': ('okerfarge',),
'okerfargen': ('okerfarge',),
'okerfargene': ('okerfarge',),
'okerfarger': ('okerfarge',),
'okklusiv': ('okklusiv',),
'okklusiven': ('okklusiv',),
'okklusivene': ('okklusiv',),
'okklusiver': ('okklusiv',),
'okkultasjon': ('okkultasjon',),
'okkultasjonen': ('okkultasjon',),
'okkultasjonene': ('okkultasjon',),
'okkultasjoner': ('okkultasjon',),
'okkultisme': ('okkultisme',),
'okkultismen': ('okkultisme',),
'okkultismene': ('okkultisme',),
'okkultismer': ('okkultisme',),
'okkultist': ('okkultist',),
'okkultisten': ('okkultist',),
'okkultistene': ('okkultist',),
'okkultister': ('okkultist',),
'okkupant': ('okkupant',),
'okkupanten': ('okkupant',),
'okkupantene': ('okkupant',),
'okkupanter': ('okkupant',),
'okkupasjon': ('okkupasjon',),
'okkupasjonen': ('okkupasjon',),
'okkupasjonene': ('okkupasjon',),
'okkupasjoner': ('okkupasjon',),
'oksalsyra': ('oksalsyre',),
'oksalsyre': ('oksalsyre',),
'oksalsyren': ('oksalsyre',),
'oksalsyrene': ('oksalsyre',),
'oksalsyrer': ('oksalsyre',),
'okse': ('okse',),
'oksen': ('okse',),
'oksene': ('okse',),
'okser': ('okse',),
'oksebryst': ('oksebryst',),
'oksebrysta': ('oksebryst',),
'oksebrystene': ('oksebryst',),
'oksebrystet': ('oksebryst',),
'oksefamilie': ('oksefamilie',),
'oksefamilien': ('oksefamilie',),
'oksefamiliene': ('oksefamilie',),
'oksefamilier': ('oksefamilie',),
'oksehalesuppa': ('oksehalesuppe',),
'oksehalesuppe': ('oksehalesuppe',),
'oksehalesuppen': ('oksehalesuppe',),
'oksehalesuppene': ('oksehalesuppe',),
'oksehalesupper': ('oksehalesuppe',),
'oksehoda': ('oksehode',),
'oksehode': ('oksehode',),
'oksehodene': ('oksehode',),
'oksehoder': ('oksehode',),
'oksehodet': ('oksehode',),
'oksehud': ('oksehud',),
'oksehuda': ('oksehud',),
'oksehuden': ('oksehud',),
'oksehudene': ('oksehud',),
'oksehuder': ('oksehud',),
'oksekarbonade': ('oksekarbonade',),
'oksekarbonaden': ('oksekarbonade',),
'oksekarbonadene': ('oksekarbonade',),
'oksekarbonader': ('oksekarbonade',),
'oksenakke': ('oksenakke',),
'oksenakken': ('oksenakke',),
'oksenakkene': ('oksenakke',),
'oksenakker': ('oksenakke',),
'oksepeis': ('oksepeis',),
'oksepeisen': ('oksepeis',),
'oksepeisene': ('oksepeis',),
'oksepeiser': ('oksepeis',),
'okseslekt': ('okseslekt',),
'okseslekta': ('okseslekt',),
'okseslekten': ('okseslekt',),
'okseslektene': ('okseslekt',),
'okseslekter': ('okseslekt',),
'oksestasjon': ('oksestasjon',),
'oksestasjonen': ('oksestasjon',),
'oksestasjonene': ('oksestasjon',),
'oksestasjoner': ('oksestasjon',),
'oksesteik': ('oksesteik',),
'oksesteika': ('oksesteik',),
'oksesteiken': ('oksesteik',),
'oksesteikene': ('oksesteik',),
'oksesteiker': ('oksesteik',),
'oksestek': ('oksestek',),
'oksesteka': ('oksestek',),
'oksesteken': ('oksestek',),
'oksestekene': ('oksestek',),
'oksesteker': ('oksestek',),
'oksetunga': ('oksetunge',),
'oksetunge': ('oksetunge',),
'oksetungen': ('oksetunge',),
'oksetungene': ('oksetunge',),
'oksetunger': ('oksetunge',),
'oksid': ('oksid',),
'oksida': ('oksid',),
'oksidene': ('oksid',),
'oksider': ('oksid',),
'oksidet': ('oksid',),
'oksidasjon': ('oksidasjon',),
'oksidasjonen': ('oksidasjon',),
'oksidasjonene': ('oksidasjon',),
'oksidasjoner': ('oksidasjon',),
'oksidasjonstall': ('oksidasjonstall',),
'oksidasjonstalla': ('oksidasjonstall',),
'oksidasjonstallene': ('oksidasjonstall',),
'oksidasjonstallet': ('oksidasjonstall',),
'oksidentaler': ('oksidentaler',),
'oksidentalere': ('oksidentaler',),
'oksidentaleren': ('oksidentaler',),
'oksidentalerer': ('oksidentaler',),
'oksidentalerne': ('oksidentaler',),
'oksideringsmiddel': ('oksideringsmiddel',),
'oksideringsmiddelet': ('oksideringsmiddel',),
'oksideringsmidla': ('oksideringsmiddel',),
'oksideringsmidlene': ('oksideringsmiddel',),
'oksideringsmidler': ('oksideringsmiddel',),
'oksideringsmidlet': ('oksideringsmiddel',),
'oksygen': ('oksygen',),
'oksygena': ('oksygen',),
'oksygenene': ('oksygen',),
'oksygenet': ('oksygen',),
'oksygenapparat': ('oksygenapparat',),
'oksygenapparata': ('oksygenapparat',),
'oksygenapparatene': ('oksygenapparat',),
'oksygenapparater': ('oksygenapparat',),
'oksygenapparatet': ('oksygenapparat',),
'oksygengjeld': ('oksygengjeld',),
'oksygengjelda': ('oksygengjeld',),
'oksygengjelden': ('oksygengjeld',),
'oksygengjeldene': ('oksygengjeld',),
'oksygengjelder': ('oksygengjeld',),
'oksygenskjæring': ('oksygenskjæring',),
'oksygenskjæringa': ('oksygenskjæring',),
'oksygenskjæringen': ('oksygenskjæring',),
'oksygenskjæringene': ('oksygenskjæring',),
'oksygenskjæringer': ('oksygenskjæring',),
'oksyhemoglobin': ('oksyhemoglobin',),
'oksyhemoglobina': ('oksyhemoglobin',),
'oksyhemoglobinene': ('oksyhemoglobin',),
'oksyhemoglobinet': ('oksyhemoglobin',),
'oktaeder': ('oktaeder',),
'oktaederet': ('oktaeder',),
'oktaedra': ('oktaeder',),
'oktaedre': ('oktaeder',),
'oktaedrene': ('oktaeder',),
'oktaedret': ('oktaeder',),
'oktan': ('oktan',),
'oktana': ('oktan',),
'oktanene': ('oktan',),
'oktaner': ('oktan',),
'oktanet': ('oktan',),
'oktant': ('oktant',),
'oktanten': ('oktant',),
'oktantene': ('oktant',),
'oktanter': ('oktant',),
'oktantal': ('oktantal',),
'oktantala': ('oktantal',),
'oktantalene': ('oktantal',),
'oktantalet': ('oktantal',),
'oktantall': ('oktantall',),
'oktantalla': ('oktantall',),
'oktantallene': ('oktantall',),
'oktantallet': ('oktantall',),
'oktav': ('oktav',),
'oktaven': ('oktav',),
'oktavene': ('oktav',),
'oktaver': ('oktav',),
'oktavformat': ('oktavformat',),
'oktavformata': ('oktavformat',),
'oktavformatene': ('oktavformat',),
'oktavformater': ('oktavformat',),
'oktavformatet': ('oktavformat',),
'oktett': ('oktett',),
'oktetten': ('oktett',),
'oktettene': ('oktett',),
'oktetter': ('oktett',),
'oktober': ('oktober',),
'oktogon': ('oktogon',),
'oktogonen': ('oktogon',),
'oktogonene': ('oktogon',),
'oktogoner': ('oktogon',),
'okular': ('okular',),
'okulara': ('okular',),
'okularene': ('okular',),
'okularet': ('okular',),
'okulasjon': ('okulasjon',),
'okulasjonen': ('okulasjon',),
'okulasjonene': ('okulasjon',),
'okulasjoner': ('okulasjon',),
'ol': ('ol',),
'olen': ('ol',),
'olene': ('ol',),
'oler': ('ol',),
'olabil': ('olabil',),
'olabilen': ('olabil',),
'olabilene': ('olabil',),
'olabiler': ('olabil',),
'olabuksa': ('olabukse',),
'olabukse': ('olabukse',),
'olabuksen': ('olabukse',),
'olabuksene': ('olabukse',),
'olabukser': ('olabukse',),
'olagutt': ('olagutt',),
'olagutten': ('olagutt',),
'olaguttene': ('olagutt',),
'olagutter': ('olagutt',),
'olavsskjegg': ('olavsskjegg',),
'olavsskjegga': ('olavsskjegg',),
'olavsskjeggen': ('olavsskjegg',),
'olavsskjeggene': ('olavsskjegg',),
'olavsskjegger': ('olavsskjegg',),
'olavsskjegget': ('olavsskjegg',),
'olavsvaka': ('olavsvake',),
'olavsvake': ('olavsvake',),
'olavsvaken': ('olavsvake',),
'olavsvakene': ('olavsvake',),
'olavsvaker': ('olavsvake',),
'old boys': ('old boys',),
'old boysen': ('old boys',),
'old boysene': ('old boys',),
'old boys-klassa': ('old boys-klasse',),
'old boys-klasse': ('old boys-klasse',),
'old boys-klassen': ('old boys-klasse',),
'old boys-klassene': ('old boys-klasse',),
'old boys-klasser': ('old boys-klasse',),
'oldebarn': ('oldebarn',),
'oldebarna': ('oldebarn',),
'oldebarnene': ('oldebarn',),
'oldebarnet': ('oldebarn',),
'oldenborger': ('oldenborger',),
'oldenborgere': ('oldenborger',),
'oldenborgeren': ('oldenborger',),
'oldenborgerer': ('oldenborger',),
'oldenborgerne': ('oldenborger',),
'oldenborra': ('oldenborre',),
'oldenborre': ('oldenborre',),
'oldenborren': ('oldenborre',),
'oldenborrene': ('oldenborre',),
'oldenborrer': ('oldenborre',),
'older': ('older',),
'oldere': ('older',),
'olderen': ('older',),
'olderne': ('older',),
'oldra': ('older',),
'oldre': ('older',),
'oldrene': ('older',),
'oldrer': ('older',),
'olderkratt': ('olderkratt',),
'olderkratta': ('olderkratt',),
'olderkrattene': ('olderkratt',),
'olderkrattet': ('olderkratt',),
'oldermann': ('oldermann',),
'oldermannen': ('oldermann',),
'oldermenn': ('oldermann',),
'oldermennene': ('oldermann',),
'oldfrua': ('oldfrue',),
'oldfrue': ('oldfrue',),
'oldfruen': ('oldfrue',),
'oldfruene': ('oldfrue',),
'oldfruer': ('oldfrue',),
'oldfunn': ('oldfunn',),
'oldfunna': ('oldfunn',),
'oldfunnene': ('oldfunn',),
'oldfunnet': ('oldfunn',),
'olding': ('olding',),
'oldingen': ('olding',),
'oldingene': ('olding',),
'oldinger': ('olding',),
'oldis': ('oldis',),
'oldisen': ('oldis',),
'oldisene': ('oldis',),
'oldiser': ('oldis',),
'oldsak': ('oldsak',),
'oldsaka': ('oldsak',),
'oldsaken': ('oldsak',),
'oldsakene': ('oldsak',),
'oldsaker': ('oldsak',),
'oldsakssamling': ('oldsakssamling',),
'oldsakssamlinga': ('oldsakssamling',),
'oldsakssamlingen': ('oldsakssamling',),
'oldsakssamlingene': ('oldsakssamling',),
'oldsakssamlinger': ('oldsakssamling',),
'oldtid': ('oldtid',),
'oldtida': ('oldtid',),
'oldtiden': ('oldtid',),
'oldtidene': ('oldtid',),
'oldtider': ('oldtid',),
'oldtimer': ('oldtimer',),
'oldtimere': ('oldtimer',),
'oldtimeren': ('oldtimer',),
'oldtimerer': ('oldtimer',),
'oldtimerne': ('oldtimer',),
'ola': ('ole',),
'ole': ('ole',),
'olen': ('ole',),
'olene': ('ole',),
'oler': ('ole',),
'oleander': ('oleander',),
'oleandere': ('oleander',),
'oleanderen': ('oleander',),
'oleanderer': ('oleander',),
'oleanderne': ('oleander',),
'oleandre': ('oleander',),
'oleandrene': ('oleander',),
'oleandrer': ('oleander',),
'olefin': ('olefin',),
'olefina': ('olefin',),
'olefinene': ('olefin',),
'olefiner': ('olefin',),
'olefinet': ('olefin',),
'oligark': ('oligark',),
'oligarken': ('oligark',),
'oligarkene': ('oligark',),
'oligarker': ('oligark',),
'oligarki': ('oligarki',),
'oligarkia': ('oligarki',),
'oligarkiene': ('oligarki',),
'oligarkier': ('oligarki',),
'oligarkiet': ('oligarki',),
'oliven': ('oliven',),
'olivenen': ('oliven',),
'olivenene': ('oliven',),
'olivener': ('oliven',),
'olivenolja': ('olivenolje',),
'olivenolje': ('olivenolje',),
'olivenoljen': ('olivenolje',),
'olivenoljene': ('olivenolje',),
'olivenoljer': ('olivenolje',),
'olivin': ('olivin',),
'olivinen': ('olivin',),
'olivinene': ('olivin',),
'oliviner': ('olivin',),
'olivinsand': ('olivinsand',),
'olivinsanden': ('olivinsand',),
'olivinsandene': ('olivinsand',),
'olivinsander': ('olivinsand',),
'olivinstein': ('olivinstein',),
'olivinsteinen': ('olivinstein',),
'olivinsteinene': ('olivinstein',),
'olivinsteiner': ('olivinstein',),
'olja': ('olje',),
'olje': ('olje',),
'oljen': ('olje',),
'oljene': ('olje',),
'oljer': ('olje',),
'oljeaksje': ('oljeaksje',),
'oljeaksjen': ('oljeaksje',),
'oljeaksjene': ('oljeaksje',),
'oljeaksjer': ('oljeaksje',),
'oljebad': ('oljebad',),
'oljebada': ('oljebad',),
'oljebadene': ('oljebad',),
'oljebadet': ('oljebad',),
'oljebeis': ('oljebeis',),
'oljebeisen': ('oljebeis',),
'oljebeisene': ('oljebeis',),
'oljebeiser': ('oljebeis',),
'oljebille': ('oljebille',),
'oljebillen': ('oljebille',),
'oljebillene': ('oljebille',),
'oljebiller': ('oljebille',),
'oljeboring': ('oljeboring',),
'oljeboringa': ('oljeboring',),
'oljeboringen': ('oljeboring',),
'oljeboringene': ('oljeboring',),
'oljeboringer': ('oljeboring',),
'oljeboringsplattform': ('oljeboringsplattform',),
'oljeboringsplattforma': ('oljeboringsplattform',),
'oljeboringsplattformen': ('oljeboringsplattform',),
'oljeboringsplattformene': ('oljeboringsplattform',),
'oljeboringsplattformer': ('oljeboringsplattform',),
'oljebrenner': ('oljebrenner',),
'oljebrennere': ('oljebrenner',),
'oljebrenneren': ('oljebrenner',),
'oljebrennerer': ('oljebrenner',),
'oljebrennerne': ('oljebrenner',),
'oljebrønn': ('oljebrønn',),
'oljebrønnen': ('oljebrønn',),
'oljebrønnene': ('oljebrønn',),
'oljebrønner': ('oljebrønn',),
'oljedemper': ('oljedemper',),
'oljedempere': ('oljedemper',),
'oljedemperen': ('oljedemper',),
'oljedemperer': ('oljedemper',),
'oljedemperne': ('oljedemper',),
'oljedirektorat': ('oljedirektorat',),
'oljedirektorata': ('oljedirektorat',),
'oljedirektoratene': ('oljedirektorat',),
'oljedirektorater': ('oljedirektorat',),
'oljedirektoratet': ('oljedirektorat',),
'oljefarge': ('oljefarge',),
'oljefargen': ('oljefarge',),
'oljefargene': ('oljefarge',),
'oljefarger': ('oljefarge',),
'oljefilm': ('oljefilm',),
'oljefilmen': ('oljefilm',),
'oljefilmene': ('oljefilm',),
'oljefilmer': ('oljefilm',),
'oljefilter': ('oljefilter',),
'oljefilteret': ('oljefilter',),
'oljefiltra': ('oljefilter',),
'oljefiltre': ('oljefilter',),
'oljefiltrene': ('oljefilter',),
'oljefiltret': ('oljefilter',),
'oljefrø': ('oljefrø',),
'oljefrøa': ('oljefrø',),
'oljefrøene': ('oljefrø',),
'oljefrøet': ('oljefrø',),
'oljefyr': ('oljefyr',),
'oljefyren': ('oljefyr',),
'oljefyrene': ('oljefyr',),
'oljefyrer': ('oljefyr',),
'oljefyring': ('oljefyring',),
'oljefyringa': ('oljefyring',),
'oljefyringen': ('oljefyring',),
'oljefyringene': ('oljefyring',),
'oljefyringer': ('oljefyring',),
'oljefyringsanlegg': ('oljefyringsanlegg',),
'oljefyringsanlegga': ('oljefyringsanlegg',),
'oljefyringsanleggene': ('oljefyringsanlegg',),
'oljefyringsanlegget': ('oljefyringsanlegg',),
'oljegeologi': ('oljegeologi',),
'oljegeologien': ('oljegeologi',),
'oljegeologiene': ('oljegeologi',),
'oljegeologier': ('oljegeologi',),
'oljegrus': ('oljegrus',),
'oljegrusa': ('oljegrus',),
'oljegrusen': ('oljegrus',),
'oljegrusene': ('oljegrus',),
'oljegruser': ('oljegrus',),
'oljegruset': ('oljegrus',),
'oljekaka': ('oljekake',),
'oljekake': ('oljekake',),
'oljekaken': ('oljekake',),
'oljekakene': ('oljekake',),
'oljekaker': ('oljekake',),
'oljeklær': ('oljeklær',),
'oljeklærne': ('oljeklær',),
'oljekritt': ('oljekritt',),
'oljekritta': ('oljekritt',),
'oljekrittene': ('oljekritt',),
'oljekrittet': ('oljekritt',),
'oljeledning': ('oljeledning',),
'oljeledninga': ('oljeledning',),
'oljeledningen': ('oljeledning',),
'oljeledningene': ('oljeledning',),
'oljeledninger': ('oljeledning',),
'oljeleiting': ('oljeleiting',),
'oljeleitinga': ('oljeleiting',),
'oljeleitingen': ('oljeleiting',),
'oljeleitingene': ('oljeleiting',),
'oljeleitinger': ('oljeleiting',),
'oljelensa': ('oljelense',),
'oljelense': ('oljelense',),
'oljelensen': ('oljelense',),
'oljelensene': ('oljelense',),
'oljelenser': ('oljelense',),
'oljeleting': ('oljeleting',),
'oljeletinga': ('oljeleting',),
'oljeletingen': ('oljeleting',),
'oljeletingene': ('oljeleting',),
'oljeletinger': ('oljeleting',),
'oljeløfter': ('oljeløfter',),
'oljeløftere': ('oljeløfter',),
'oljeløfteren': ('oljeløfter',),
'oljeløfterer': ('oljeløfter',),
'oljeløfterne': ('oljeløfter',),
'oljemaleri': ('oljemaleri',),
'oljemaleria': ('oljemaleri',),
'oljemaleriene': ('oljemaleri',),
'oljemalerier': ('oljemaleri',),
'oljemaleriet': ('oljemaleri',),
'oljemaling': ('oljemaling',),
'oljemalinga': ('oljemaling',),
'oljemalingen': ('oljemaling',),
'oljemalingene': ('oljemaling',),
'oljemalinger': ('oljemaling',),
'oljepalme': ('oljepalme',),
'oljepalmen': ('oljepalme',),
'oljepalmene': ('oljepalme',),
'oljepalmer': ('oljepalme',),
'oljeplanta': ('oljeplante',),
'oljeplante': ('oljeplante',),
'oljeplanten': ('oljeplante',),
'oljeplantene': ('oljeplante',),
'oljeplanter': ('oljeplante',),
'oljeplattform': ('oljeplattform',),
'oljeplattforma': ('oljeplattform',),
'oljeplattformen': ('oljeplattform',),
'oljeplattformene': ('oljeplattform',),
'oljeplattformer': ('oljeplattform',),
'oljepumpa': ('oljepumpe',),
'oljepumpe': ('oljepumpe',),
'oljepumpen': ('oljepumpe',),
'oljepumpene': ('oljepumpe',),
'oljepumper': ('oljepumpe',),
'oljeraffineri': ('oljeraffineri',),
'oljeraffineria': ('oljeraffineri',),
'oljeraffineriene': ('oljeraffineri',),
'oljeraffinerier': ('oljeraffineri',),
'oljeraffineriet': ('oljeraffineri',),
'oljeraffinering': ('oljeraffinering',),
'oljeraffineringa': ('oljeraffinering',),
'oljeraffineringen': ('oljeraffinering',),
'oljeraffineringene': ('oljeraffinering',),
'oljeraffineringer': ('oljeraffinering',),
'oljerigg': ('oljerigg',),
'oljeriggen': ('oljerigg',),
'oljeriggene': ('oljerigg',),
'oljerigger': ('oljerigg',),
'oljeselskap': ('oljeselskap',),
'oljeselskapa': ('oljeselskap',),
'oljeselskapene': ('oljeselskap',),
'oljeselskaper': ('oljeselskap',),
'oljeselskapet': ('oljeselskap',),
'oljeskift': ('oljeskift',),
'oljeskifta': ('oljeskift',),
'oljeskiftene': ('oljeskift',),
'oljeskiftet': ('oljeskift',),
'oljeskummer': ('oljeskummer',),
'oljeskummere': ('oljeskummer',),
'oljeskummeren': ('oljeskummer',),
'oljeskummerer': ('oljeskummer',),
'oljeskummerne': ('oljeskummer',),
'oljesøl': ('oljesøl',),
'oljesøla': ('oljesøl',),
'oljesølene': ('oljesøl',),
'oljesølet': ('oljesøl',),
'oljetre': ('oljetre',),
'oljetrea': ('oljetre',),
'oljetreet': ('oljetre',),
'oljetrær': ('oljetre',),
'oljetrærne': ('oljetre',),
'oljetrefamilie': ('oljetrefamilie',),
'oljetrefamilien': ('oljetrefamilie',),
'oljetrefamiliene': ('oljetrefamilie',),
'oljetrefamilier': ('oljetrefamilie',),
'oljetrykk': ('oljetrykk',),
'oljetrykka': ('oljetrykk',),
'oljetrykkene': ('oljetrykk',),
'oljetrykket': ('oljetrykk',),
'oljevekst': ('oljevekst',),
'oljeveksten': ('oljevekst',),
'oljevekstene': ('oljevekst',),
'oljevekster': ('oljevekst',),
'oljevern': ('oljevern',),
'oljeverna': ('oljevern',),
'oljevernene': ('oljevern',),
'oljevernet': ('oljevern',),
'oljevirksomhet': ('oljevirksomhet',),
'oljevirksomheta': ('oljevirksomhet',),
'oljevirksomheten': ('oljevirksomhet',),
'oljevirksomhetene': ('oljevirksomhet',),
'oljevirksomheter': ('oljevirksomhet',),
'olla': ('olle',),
'olle': ('olle',),
'ollen': ('olle',),
'ollene': ('olle',),
'oller': ('olle',),
'olsok': ('olsok',),
'olsoken': ('olsok',),
'olsokene': ('olsok',),
'olsoker': ('olsok',),
'olsokaften': ('olsokaften',),
'olsokaftenen': ('olsokaften',),
'olsokaftenene': ('olsokaften',),
'olsokaftener': ('olsokaften',),
'olsokdag': ('olsokdag',),
'olsokdagen': ('olsokdag',),
'olsokdagene': ('olsokdag',),
'olsokdager': ('olsokdag',),
'olsokfest': ('olsokfest',),
'olsokfesten': ('olsokfest',),
'olsokfestene': ('olsokfest',),
'olsokfester': ('olsokfest',),
'olympiaby': ('olympiaby',),
'olympiabyen': ('olympiaby',),
'olympiabyene': ('olympiaby',),
'olympiabyer': ('olympiaby',),
'olympiade': ('olympiade',),
'olympiaden': ('olympiade',),
'olympiadene': ('olympiade',),
'olympiader': ('olympiade',),
'olympiadeltaker': ('olympiadeltaker',),
'olympiadeltakere': ('olympiadeltaker',),
'olympiadeltakeren': ('olympiadeltaker',),
'olympiadeltakerer': ('olympiadeltaker',),
'olympiadeltakerne': ('olympiadeltaker',),
'olympiamester': ('olympiamester',),
'olympiamestere': ('olympiamester',),
'olympiamesteren': ('olympiamester',),
'olympiamesterer': ('olympiamester',),
'olympiamesterne': ('olympiamester',),
'olympiamestre': ('olympiamester',),
'olympiamestrene': ('olympiamester',),
'olympiamestrer': ('olympiamester',),
'olympiatropp': ('olympiatropp',),
'olympiatroppen': ('olympiatropp',),
'olympiatroppene': ('olympiatropp',),
'olympiatropper': ('olympiatropp',),
'olympier': ('olympier',),
'olympiere': ('olympier',),
'olympieren': ('olympier',),
'olympierer': ('olympier',),
'olympierne': ('olympier',),
'om': ('om',),
'omen': ('om',),
'omene': ('om',),
'omer': ('om',),
'omaner': ('omaner',),
'omanere': ('omaner',),
'omaneren': ('omaner',),
'omanerer': ('omaner',),
'omanerne': ('omaner',),
'omarbeidelse': ('omarbeidelse',),
'omarbeidelsen': ('omarbeidelse',),
'omarbeidelsene': ('omarbeidelse',),
'omarbeidelser': ('omarbeidelse',),
'omarbeiding': ('omarbeiding',),
'omarbeidinga': ('omarbeiding',),
'omarbeidingen': ('omarbeiding',),
'omarbeidingene': ('omarbeiding',),
'omarbeidinger': ('omarbeiding',),
'ombordstigningskort': ('ombordstigningskort',),
'ombordstigningskorta': ('ombordstigningskort',),
'ombordstigningskortene': ('ombordstigningskort',),
'ombordstigningskortet': ('ombordstigningskort',),
'ombot': ('ombot',),
'ombota': ('ombot',),
'omboten': ('ombot',),
'ombøtene': ('ombot',),
'ombøter': ('ombot',),
'ombrekker': ('ombrekker',),
'ombrekkere': ('ombrekker',),
'ombrekkeren': ('ombrekker',),
'ombrekkerer': ('ombrekker',),
'ombrekkerne': ('ombrekker',),
'ombrekking': ('ombrekking',),
'ombrekkinga': ('ombrekking',),
'ombrekkingen': ('ombrekking',),
'ombrekkingene': ('ombrekking',),
'ombrekkinger': ('ombrekking',),
'ombrekning': ('ombrekning',),
'ombrekninga': ('ombrekning',),
'ombrekningen': ('ombrekning',),
'ombrekningene': ('ombrekning',),
'ombrekninger': ('ombrekning',),
'ombruk': ('ombruk',),
'ombruka': ('ombruk',),
'ombruken': ('ombruk',),
'ombrukene': ('ombruk',),
'ombruker': ('ombruk',),
'ombruket': ('ombruk',),
'ombud': ('ombud',),
'ombuda': ('ombud',),
'ombudene': ('ombud',),
'ombudet': ('ombud',),
'ombudsmann': ('ombudsmann',),
'ombudsmannen': ('ombudsmann',),
'ombudsmenn': ('ombudsmann',),
'ombudsmennene': ('ombudsmann',),
'ombygging': ('ombygging',),
'ombygginga': ('ombygging',),
'ombyggingen': ('ombygging',),
'ombyggingene': ('ombygging',),
'ombygginger': ('ombygging',),
'ombygning': ('ombygning',),
'ombygninga': ('ombygning',),
'ombygningen': ('ombygning',),
'ombygningene': ('ombygning',),
'ombygninger': ('ombygning',),
'ombæring': ('ombæring',),
'ombæringa': ('ombæring',),
'ombæringen': ('ombæring',),
'ombæringene': ('ombæring',),
'ombæringer': ('ombæring',),
'omdreiing': ('omdreiing',),
'omdreiinga': ('omdreiing',),
'omdreiingen': ('omdreiing',),
'omdreiingene': ('omdreiing',),
'omdreiinger': ('omdreiing',),
'omdreiingsakse': ('omdreiingsakse',),
'omdreiingsaksen': ('omdreiingsakse',),
'omdreiingsaksene': ('omdreiingsakse',),
'omdreiingsakser': ('omdreiingsakse',),
'omdreiingshastighet': ('omdreiingshastighet',),
'omdreiingshastigheta': ('omdreiingshastighet',),
'omdreiingshastigheten': ('omdreiingshastighet',),
'omdreiingshastighetene': ('omdreiingshastighet',),
'omdreiingshastigheter': ('omdreiingshastighet',),
'omdreiingstall': ('omdreiingstall',),
'omdreiingstalla': ('omdreiingstall',),
'omdreiingstallene': ('omdreiingstall',),
'omdreiingstallet': ('omdreiingstall',),
'omdreining': ('omdreining',),
'omdreininga': ('omdreining',),
'omdreiningen': ('omdreining',),
'omdreiningene': ('omdreining',),
'omdreininger': ('omdreining',),
'omdreiningsakse': ('omdreiningsakse',),
'omdreiningsaksen': ('omdreiningsakse',),
'omdreiningsaksene': ('omdreiningsakse',),
'omdreiningsakser': ('omdreiningsakse',),
'omdreiningshastighet': ('omdreiningshastighet',),
'omdreiningshastigheta': ('omdreiningshastighet',),
'omdreiningshastigheten': ('omdreiningshastighet',),
'omdreiningshastighetene': ('omdreiningshastighet',),
'omdreiningshastigheter': ('omdreiningshastighet',),
'omdreiningstall': ('omdreiningstall',),
'omdreiningstalla': ('omdreiningstall',),
'omdreiningstallene': ('omdreiningstall',),
'omdreiningstallet': ('omdreiningstall',),
'omdømma': ('omdømme',),
'omdømme': ('omdømme',),
'omdømmene': ('omdømme',),
'omdømmer': ('omdømme',),
'omdømmet': ('omdømme',),
'omega': ('omega',),
'omegaen': ('omega',),
'omegaene': ('omega',),
'omegaer': ('omega',),
'omegn': ('omegn',),
'omegnen': ('omegn',),
'omegnene': ('omegn',),
'omegner': ('omegn',),
'omelett': ('omelett',),
'omeletten': ('omelett',),
'omelettene': ('omelett',),
'omeletter': ('omelett',),
'omen': ('omen',),
'omena': ('omen',),
'omenene': ('omen',),
'omener': ('omen',),
'omenet': ('omen',),
'omina': ('omen',),
'ominaene': ('omen',),
'omfang': ('omfang',),
'omfanga': ('omfang',),
'omfangene': ('omfang',),
'omfanget': ('omfang',),
'omfar': ('omfar',),
'omfara': ('omfar',),
'omfarene': ('omfar',),
'omfaret': ('omfar',),
'omfavnelse': ('omfavnelse',),
'omfavnelsen': ('omfavnelse',),
'omfavnelsene': ('omfavnelse',),
'omfavnelser': ('omfavnelse',),
'omflakking': ('omflakking',),
'omflakkinga': ('omflakking',),
'omflakkingen': ('omflakking',),
'omflakkingene': ('omflakking',),
'omflakkinger': ('omflakking',),
'omformer': ('omformer',),
'omformere': ('omformer',),
'omformeren': ('omformer',),
'omformerer': ('omformer',),
'omformerne': ('omformer',),
'omframarbeid': ('omframarbeid',),
'omframarbeida': ('omframarbeid',),
'omframarbeidene': ('omframarbeid',),
'omframarbeider': ('omframarbeid',),
'omframarbeidet': ('omframarbeid',),
'omframtarbeid': ('omframtarbeid',),
'omframtarbeida': ('omframtarbeid',),
'omframtarbeidene': ('omframtarbeid',),
'omframtarbeider': ('omframtarbeid',),
'omframtarbeidet': ('omframtarbeid',),
'omførselshandel': ('omførselshandel',),
'omførselshandelen': ('omførselshandel',),
'omførselshandlene': ('omførselshandel',),
'omførselshandler': ('omførselshandel',),
'omgangsform': ('omgangsform',),
'omgangsforma': ('omgangsform',),
'omgangsformen': ('omgangsform',),
'omgangsformene': ('omgangsform',),
'omgangsformer': ('omgangsform',),
'omgangskrets': ('omgangskrets',),
'omgangskretsen': ('omgangskrets',),
'omgangskretsene': ('omgangskrets',),
'omgangskretser': ('omgangskrets',),
'omgangssjuka': ('omgangssjuke',),
'omgangssjuke': ('omgangssjuke',),
'omgangssjuken': ('omgangssjuke',),
'omgangssjukene': ('omgangssjuke',),
'omgangssjuker': ('omgangssjuke',),
'omgangsskole': ('omgangsskole',),
'omgangsskolen': ('omgangsskole',),
'omgangsskolene': ('omgangsskole',),
'omgangsskoler': ('omgangsskole',),
'omgangssyka': ('omgangssyke',),
'omgangssyke': ('omgangssyke',),
'omgangssyken': ('omgangssyke',),
'omgangssykene': ('omgangssyke',),
'omgangssyker': ('omgangssyke',),
'omgangstone': ('omgangstone',),
'omgangstonen': ('omgangstone',),
'omgangstonene': ('omgangstone',),
'omgangstoner': ('omgangstone',),
'omgangsvenn': ('omgangsvenn',),
'omgangsvennen': ('omgangsvenn',),
'omgangsvennene': ('omgangsvenn',),
'omgangsvenner': ('omgangsvenn',),
'omgivelse': ('omgivelse',),
'omgivelsen': ('omgivelse',),
'omgivelsene': ('omgivelse',),
'omgivelser': ('omgivelse',),
'omgjenga': ('omgjenge',),
'omgjenge': ('omgjenge',),
'omgjengene': ('omgjenge',),
'omgjenger': ('omgjenge',),
'omgjenget': ('omgjenge',),
'omgrep': ('omgrep',),
'omgrepa': ('omgrep',),
'omgrepene': ('omgrep',),
'omgrepet': ('omgrep',),
'omheng': ('omheng',),
'omhenga': ('omheng',),
'omhengene': ('omheng',),
'omhenget': ('omheng',),
'omhu': ('omhu',),
'omhuen': ('omhu',),
'omhuene': ('omhu',),
'omhuer': ('omhu',),
'omhug': ('omhug',),
'omhugen': ('omhug',),
'omhugene': ('omhug',),
'omhuger': ('omhug',),
'omkamp': ('omkamp',),
'omkampen': ('omkamp',),
'omkampene': ('omkamp',),
'omkamper': ('omkamp',),
'omkast': ('omkast',),
'omkasta': ('omkast',),
'omkastene': ('omkast',),
'omkastet': ('omkast',),
'omkjøring': ('omkjøring',),
'omkjøringa': ('omkjøring',),
'omkjøringen': ('omkjøring',),
'omkjøringene': ('omkjøring',),
'omkjøringer': ('omkjøring',),
'omkjøringsveg': ('omkjøringsveg',),
'omkjøringsvegen': ('omkjøringsveg',),
'omkjøringsvegene': ('omkjøringsveg',),
'omkjøringsveger': ('omkjøringsveg',),
'omkjøringsvei': ('omkjøringsvei',),
'omkjøringsveien': ('omkjøringsvei',),
'omkjøringsveiene': ('omkjøringsvei',),
'omkjøringsveier': ('omkjøringsvei',),
'omkledning': ('omkledning',),
'omkledninga': ('omkledning',),
'omkledningen': ('omkledning',),
'omkledningene': ('omkledning',),
'omkledninger': ('omkledning',),
'omkledningsrom': ('omkledningsrom',),
'omkledningsromma': ('omkledningsrom',),
'omkledningsrommene': ('omkledningsrom',),
'omkledningsrommet': ('omkledningsrom',),
'omkostning': ('omkostning',),
'omkostninga': ('omkostning',),
'omkostningen': ('omkostning',),
'omkostningene': ('omkostning',),
'omkostninger': ('omkostning',),
'omkrets': ('omkrets',),
'omkretsen': ('omkrets',),
'omkretsene': ('omkrets',),
'omkretser': ('omkrets',),
'omkvarv': ('omkvarv',),
'omkvarva': ('omkvarv',),
'omkvarvene': ('omkvarv',),
'omkvarvet': ('omkvarv',),
'omkved': ('omkved',),
'omkveda': ('omkved',),
'omkvedene': ('omkved',),
'omkvedet': ('omkved',),
'omlaging': ('omlaging',),
'omlaginga': ('omlaging',),
'omlagingen': ('omlaging',),
'omlagingene': ('omlaging',),
'omlaginger': ('omlaging',),
'omland': ('omland',),
'omlanda': ('omland',),
'omlandene': ('omland',),
'omlandet': ('omland',),
'omlasting': ('omlasting',),
'omlastingen': ('omlasting',),
'omlastingene': ('omlasting',),
'omlastinger': ('omlasting',),
'omlegg': ('omlegg',),
'omlegga': ('omlegg',),
'omleggene': ('omlegg',),
'omlegget': ('omlegg',),
'omlegging': ('omlegging',),
'omlegginga': ('omlegging',),
'omleggingen': ('omlegging',),
'omleggingene': ('omlegging',),
'omlegginger': ('omlegging',),
'omlegning': ('omlegning',),
'omlegninga': ('omlegning',),
'omlegningen': ('omlegning',),
'omlegningene': ('omlegning',),
'omlegninger': ('omlegning',),
'omlyd': ('omlyd',),
'omlyden': ('omlyd',),
'omlydene': ('omlyd',),
'omlyder': ('omlyd',),
'omløp': ('omløp',),
'omløpa': ('omløp',),
'omløpene': ('omløp',),
'omløpet': ('omløp',),
'omløpshastighet': ('omløpshastighet',),
'omløpshastigheta': ('omløpshastighet',),
'omløpshastigheten': ('omløpshastighet',),
'omløpshastighetene': ('omløpshastighet',),
'omløpshastigheter': ('omløpshastighet',),
'omløpstid': ('omløpstid',),
'omløpstida': ('omløpstid',),
'omløpstiden': ('omløpstid',),
'omløpstidene': ('omløpstid',),
'omløpstider': ('omløpstid',),
'omn': ('omn',),
'omnen': ('omn',),
'omnene': ('omn',),
'omner': ('omn',),
'omn': ('omn',),
'omnen': ('omn',),
'omnene': ('omn',),
'omner': ('omn',),
'omnibus': ('omnibus',),
'omnibusen': ('omnibus',),
'omnibusene': ('omnibus',),
'omnibuser': ('omnibus',),
'omnibusundersøkelse': ('omnibusundersøkelse',),
'omnibusundersøkelsen': ('omnibusundersøkelse',),
'omnibusundersøkelsene': ('omnibusundersøkelse',),
'omnibusundersøkelser': ('omnibusundersøkelse',),
'omnibusutgava': ('omnibusutgave',),
'omnibusutgave': ('omnibusutgave',),
'omnibusutgaven': ('omnibusutgave',),
'omnibusutgavene': ('omnibusutgave',),
'omnibusutgaver': ('omnibusutgave',),
'omnipotens': ('omnipotens',),
'omnipotensen': ('omnipotens',),
'omnipotensene': ('omnipotens',),
'omnipotenser': ('omnipotens',),
'omnskrok': ('omnskrok',),
'omnskroken': ('omnskrok',),
'omnskrokene': ('omnskrok',),
'omnskroker': ('omnskrok',),
'omnskrok': ('omnskrok',),
'omnskroken': ('omnskrok',),
'omnskrokene': ('omnskrok',),
'omnskroker': ('omnskrok',),
'omnsrør': ('omnsrør',),
'omnsrøra': ('omnsrør',),
'omnsrørene': ('omnsrør',),
'omnsrøret': ('omnsrør',),
'omnsrør': ('omnsrør',),
'omnsrøra': ('omnsrør',),
'omnsrørene': ('omnsrør',),
'omnsrøret': ('omnsrør',),
'omnssverta': ('omnssverte',),
'omnssverte': ('omnssverte',),
'omnssverten': ('omnssverte',),
'omnssvertene': ('omnssverte',),
'omnssverter': ('omnssverte',),
'omnssverta': ('omnssverte',),
'omnssverte': ('omnssverte',),
'omnssverten': ('omnssverte',),
'omnssvertene': ('omnssverte',),
'omnssverter': ('omnssverte',),
'omregningstal': ('omregningstal',),
'omregningstala': ('omregningstal',),
'omregningstalene': ('omregningstal',),
'omregningstalet': ('omregningstal',),
'omregningstall': ('omregningstall',),
'omregningstalla': ('omregningstall',),
'omregningstallene': ('omregningstall',),
'omregningstallet': ('omregningstall',),
'omrekningstal': ('omrekningstal',),
'omrekningstala': ('omrekningstal',),
'omrekningstalene': ('omrekningstal',),
'omrekningstalet': ('omrekningstal',),
'omrekningstall': ('omrekningstall',),
'omrekningstalla': ('omrekningstall',),
'omrekningstallene': ('omrekningstall',),
'omrekningstallet': ('omrekningstall',),
'omriss': ('omriss',),
'omrissa': ('omriss',),
'omrissene': ('omriss',),
'omrisset': ('omriss',),
'områda': ('område',),
'område': ('område',),
'områdene': ('område',),
'områder': ('område',),
'området': ('område',),
'områdeplanlegging': ('områdeplanlegging',),
'områdeplanlegginga': ('områdeplanlegging',),
'områdeplanleggingen': ('områdeplanlegging',),
'områdeplanleggingene': ('områdeplanlegging',),
'områdeplanlegginger': ('områdeplanlegging',),
'områdesjef': ('områdesjef',),
'områdesjefen': ('områdesjef',),
'områdesjefene': ('områdesjef',),
'områdesjefer': ('områdesjef',),
'oms': ('oms',),
'omsen': ('oms',),
'omsene': ('oms',),
'omser': ('oms',),
'omsetning': ('omsetning',),
'omsetninga': ('omsetning',),
'omsetningen': ('omsetning',),
'omsetningene': ('omsetning',),
'omsetninger': ('omsetning',),
'omsetningsavgift': ('omsetningsavgift',),
'omsetningsavgifta': ('omsetningsavgift',),
'omsetningsavgiften': ('omsetningsavgift',),
'omsetningsavgiftene': ('omsetningsavgift',),
'omsetningsavgifter': ('omsetningsavgift',),
'omsetningsledd': ('omsetningsledd',),
'omsetningsledda': ('omsetningsledd',),
'omsetningsleddene': ('omsetningsledd',),
'omsetningsleddet': ('omsetningsledd',),
'omsetningsskatt': ('omsetningsskatt',),
'omsetningsskatten': ('omsetningsskatt',),
'omsetningsskattene': ('omsetningsskatt',),
'omsetningsskatter': ('omsetningsskatt',),
'omsjalter': ('omsjalter',),
'omsjaltere': ('omsjalter',),
'omsjalteren': ('omsjalter',),
'omsjalterer': ('omsjalter',),
'omsjalterne': ('omsjalter',),
'omskifta': ('omskifte',),
'omskifte': ('omskifte',),
'omskiftene': ('omskifte',),
'omskifter': ('omskifte',),
'omskiftet': ('omskifte',),
'omskiftelse': ('omskiftelse',),
'omskiftelsen': ('omskiftelse',),
'omskiftelsene': ('omskiftelse',),
'omskiftelser': ('omskiftelse',),
'omskrift': ('omskrift',),
'omskrifta': ('omskrift',),
'omskriften': ('omskrift',),
'omskriftene': ('omskrift',),
'omskrifter': ('omskrift',),
'omskriving': ('omskriving',),
'omskrivinga': ('omskriving',),
'omskrivingen': ('omskriving',),
'omskrivingene': ('omskriving',),
'omskrivinger': ('omskriving',),
'omskrivning': ('omskrivning',),
'omskrivninga': ('omskrivning',),
'omskrivningen': ('omskrivning',),
'omskrivningene': ('omskrivning',),
'omskrivninger': ('omskrivning',),
'omslag': ('omslag',),
'omslaga': ('omslag',),
'omslagene': ('omslag',),
'omslaget': ('omslag',),
'omslagstegning': ('omslagstegning',),
'omslagstegninga': ('omslagstegning',),
'omslagstegningen': ('omslagstegning',),
'omslagstegningene': ('omslagstegning',),
'omslagstegninger': ('omslagstegning',),
'omsnøring': ('omsnøring',),
'omsnøringa': ('omsnøring',),
'omsnøringen': ('omsnøring',),
'omsnøringene': ('omsnøring',),
'omsnøringer': ('omsnøring',),
'omsorg': ('omsorg',),
'omsorga': ('omsorg',),
'omsorgen': ('omsorg',),
'omsorgene': ('omsorg',),
'omsorger': ('omsorg',),
'omsorgslønn': ('omsorgslønn',),
'omsorgslønna': ('omsorgslønn',),
'omsorgslønnen': ('omsorgslønn',),
'omsorgslønnene': ('omsorgslønn',),
'omsorgslønner': ('omsorgslønn',),
'omsorgspermisjon': ('omsorgspermisjon',),
'omsorgspermisjonen': ('omsorgspermisjon',),
'omsorgspermisjonene': ('omsorgspermisjon',),
'omsorgspermisjoner': ('omsorgspermisjon',),
'omspell': ('omspell',),
'omspella': ('omspell',),
'omspellene': ('omspell',),
'omspellet': ('omspell',),
'omspill': ('omspill',),
'omspilla': ('omspill',),
'omspillene': ('omspill',),
'omspillet': ('omspill',),
'omstendighet': ('omstendighet',),
'omstendigheta': ('omstendighet',),
'omstendigheten': ('omstendighet',),
'omstendighetene': ('omstendighet',),
'omstendigheter': ('omstendighet',),
'omstendihetsklær': ('omstendihetsklær',),
'omstendihetsklærne': ('omstendihetsklær',),
'omstiging': ('omstiging',),
'omstiginga': ('omstiging',),
'omstigingen': ('omstiging',),
'omstigingene': ('omstiging',),
'omstiginger': ('omstiging',),
'omstigning': ('omstigning',),
'omstigninga': ('omstigning',),
'omstigningen': ('omstigning',),
'omstigningene': ('omstigning',),
'omstigninger': ('omstigning',),
'omstillingsproblem': ('omstillingsproblem',),
'omstillingsproblema': ('omstillingsproblem',),
'omstillingsproblemene': ('omstillingsproblem',),
'omstillingsproblemer': ('omstillingsproblem',),
'omstillingsproblemet': ('omstillingsproblem',),
'omstillingsprosess': ('omstillingsprosess',),
'omstillingsprosessen': ('omstillingsprosess',),
'omstillingsprosessene': ('omstillingsprosess',),
'omstillingsprosesser': ('omstillingsprosess',),
'omstreifer': ('omstreifer',),
'omstreifere': ('omstreifer',),
'omstreiferen': ('omstreifer',),
'omstreiferer': ('omstreifer',),
'omstreiferne': ('omstreifer',),
'omsut': ('omsut',),
'omsuta': ('omsut',),
'omsuten': ('omsut',),
'omsutene': ('omsut',),
'omsuter': ('omsut',),
'omsvøp': ('omsvøp',),
'omsvøpa': ('omsvøp',),
'omsvøpene': ('omsvøp',),
'omsvøpet': ('omsvøp',),
'omsyn': ('omsyn',),
'omsyna': ('omsyn',),
'omsynene': ('omsyn',),
'omsynet': ('omsyn',),
'omtale': ('omtale',),
'omtalen': ('omtale',),
'omtalene': ('omtale',),
'omtaler': ('omtale',),
'omtanke': ('omtanke',),
'omtanken': ('omtanke',),
'omtankene': ('omtanke',),
'omtanker': ('omtanke',),
'omvalg': ('omvalg',),
'omvalga': ('omvalg',),
'omvalgene': ('omvalg',),
'omvalget': ('omvalg',),
'omvandling': ('omvandling',),
'omvandlinga': ('omvandling',),
'omvandlingen': ('omvandling',),
'omvandlingene': ('omvandling',),
'omvandlinger': ('omvandling',),
'omveg': ('omveg',),
'omvegen': ('omveg',),
'omvegene': ('omveg',),
'omveger': ('omveg',),
'omvei': ('omvei',),
'omveien': ('omvei',),
'omveiene': ('omvei',),
'omveier': ('omvei',),
'omveksling': ('omveksling',),
'omvekslinga': ('omveksling',),
'omvekslingen': ('omveksling',),
'omvekslingene': ('omveksling',),
'omvekslinger': ('omveksling',),
'omvelting': ('omvelting',),
'omveltinga': ('omvelting',),
'omveltingen': ('omvelting',),
'omveltingene': ('omvelting',),
'omveltinger': ('omvelting',),
'omveltning': ('omveltning',),
'omveltninga': ('omveltning',),
'omveltningen': ('omveltning',),
'omveltningene': ('omveltning',),
'omveltninger': ('omveltning',),
'omvendelse': ('omvendelse',),
'omvendelsen': ('omvendelse',),
'omvendelsene': ('omvendelse',),
'omvendelser': ('omvendelse',),
'omvending': ('omvending',),
'omvendinga': ('omvending',),
'omvendingen': ('omvending',),
'omvendingene': ('omvending',),
'omvendinger': ('omvending',),
'omverden': ('omverden',),
'omverdenen': ('omverden',),
'omverdenene': ('omverden',),
'omverdener': ('omverden',),
'omviser': ('omviser',),
'omvisere': ('omviser',),
'omviseren': ('omviser',),
'omviserer': ('omviser',),
'omviserne': ('omviser',),
'omvising': ('omvising',),
'omvisinga': ('omvising',),
'omvisingen': ('omvising',),
'omvisingene': ('omvising',),
'omvisinger': ('omvising',),
'omvisning': ('omvisning',),
'omvisninga': ('omvisning',),
'omvisningen': ('omvisning',),
'omvisningene': ('omvisning',),
'omvisninger': ('omvisning',),
'onager': ('onager',),
'onagere': ('onager',),
'onageren': ('onager',),
'onagerer': ('onager',),
'onagerne': ('onager',),
'onani': ('onani',),
'onanien': ('onani',),
'onaniene': ('onani',),
'onanier': ('onani',),
'onanist': ('onanist',),
'onanisten': ('onanist',),
'onanistene': ('onanist',),
'onanister': ('onanist',),
'onda': ('onde',),
'onde': ('onde',),
'ondene': ('onde',),
'onder': ('onde',),
'ondet': ('onde',),
'ondsinn': ('ondsinn',),
'ondsinna': ('ondsinn',),
'ondsinnene': ('ondsinn',),
'ondsinnet': ('ondsinn',),
'ondskap': ('ondskap',),
'ondskapen': ('ondskap',),
'ondskapene': ('ondskap',),
'ondskaper': ('ondskap',),
'ondulasjon': ('ondulasjon',),
'ondulasjonen': ('ondulasjon',),
'ondulasjonene': ('ondulasjon',),
'ondulasjoner': ('ondulasjon',),
'one-man-show': ('one-man-show',),
'one-man-showa': ('one-man-show',),
'one-man-showene': ('one-man-show',),
'one-man-showet': ('one-man-show',),
'one-woman-show': ('one-woman-show',),
'one-woman-showa': ('one-woman-show',),
'one-woman-showene': ('one-woman-show',),
'one-woman-showet': ('one-woman-show',),
'onestep': ('onestep',),
'onestepen': ('onestep',),
'onestepene': ('onestep',),
'onesteper': ('onestep',),
'onkel': ('onkel',),
'onkelen': ('onkel',),
'onklene': ('onkel',),
'onkler': ('onkel',),
'onn': ('onn',),
'onna': ('onn',),
'onnen': ('onn',),
'onnene': ('onn',),
'onner': ('onn',),
'onnefolk': ('onnefolk',),
'onnefolka': ('onnefolk',),
'onnefolkene': ('onnefolk',),
'onnefolket': ('onnefolk',),
'onomatologi': ('onomatologi',),
'onomatologien': ('onomatologi',),
'onomatologiene': ('onomatologi',),
'onomatologier': ('onomatologi',),
'onomatopoetika': ('onomatopoetikon',),
'onomatopoetikaene': ('onomatopoetikon',),
'onomatopoetikon': ('onomatopoetikon',),
'onomatopoetikonet': ('onomatopoetikon',),
'onomatopoetika': ('onomatopoetikum',),
'onomatopoetikaene': ('onomatopoetikum',),
'onomatopoetikum': ('onomatopoetikum',),
'onomatopoetikumet': ('onomatopoetikum',),
'onsdag': ('onsdag',),
'onsdagen': ('onsdag',),
'onsdagene': ('onsdag',),
'onsdager': ('onsdag',),
'onsdagsløper': ('onsdagsløper',),
'onsdagsløpere': ('onsdagsløper',),
'onsdagsløperen': ('onsdagsløper',),
'onsdagsløperer': ('onsdagsløper',),
'onsdagsløperne': ('onsdagsløper',),
'ontogenese': ('ontogenese',),
'ontogenesen': ('ontogenese',),
'ontogenesene': ('ontogenese',),
'ontogeneser': ('ontogenese',),
'ontogeni': ('ontogeni',),
'ontogenin': ('ontogeni',),
'ontogenine': ('ontogeni',),
'ontogenir': ('ontogeni',),
'ontologi': ('ontologi',),
'ontologien': ('ontologi',),
'ontologiene': ('ontologi',),
'ontologier': ('ontologi',),
'onyks': ('onyks',),
'onyksen': ('onyks',),
'onyksene': ('onyks',),
'onykser': ('onyks',),
'opal': ('opal',),
'opalen': ('opal',),
'opalene': ('opal',),
'opaler': ('opal',),
'opart': ('opart',),
'oparten': ('opart',),
'opartene': ('opart',),
'oparter': ('opart',),
'opasitet': ('opasitet',),
'opasiteten': ('opasitet',),
'opasitetene': ('opasitet',),
'opasiteter': ('opasitet',),
'opera': ('opera',),
'operaen': ('opera',),
'operaene': ('opera',),
'operaer': ('opera',),
'operand': ('operand',),
'operanden': ('operand',),
'operandene': ('operand',),
'operander': ('operand',),
'operasanger': ('operasanger',),
'operasangere': ('operasanger',),
'operasangeren': ('operasanger',),
'operasangerer': ('operasanger',),
'operasangerne': ('operasanger',),
'operasangerinna': ('operasangerinne',),
'operasangerinne': ('operasangerinne',),
'operasangerinnen': ('operasangerinne',),
'operasangerinnene': ('operasangerinne',),
'operasangerinner': ('operasangerinne',),
'operasjon': ('operasjon',),
'operasjonen': ('operasjon',),
'operasjonene': ('operasjon',),
'operasjoner': ('operasjon',),
'operasjonsavdeling': ('operasjonsavdeling',),
'operasjonsavdelinga': ('operasjonsavdeling',),
'operasjonsavdelingen': ('operasjonsavdeling',),
'operasjonsavdelingene': ('operasjonsavdeling',),
'operasjonsavdelinger': ('operasjonsavdeling',),
'operasjonsbord': ('operasjonsbord',),
'operasjonsborda': ('operasjonsbord',),
'operasjonsbordene': ('operasjonsbord',),
'operasjonsborder': ('operasjonsbord',),
'operasjonsbordet': ('operasjonsbord',),
'operasjonsfelt': ('operasjonsfelt',),
'operasjonsfelta': ('operasjonsfelt',),
'operasjonsfeltene': ('operasjonsfelt',),
'operasjonsfelter': ('operasjonsfelt',),
'operasjonsfeltet': ('operasjonsfelt',),
'operasjonssjukepleier': ('operasjonssjukepleier',),
'operasjonssjukepleiere': ('operasjonssjukepleier',),
'operasjonssjukepleieren': ('operasjonssjukepleier',),
'operasjonssjukepleierer': ('operasjonssjukepleier',),
'operasjonssjukepleierne': ('operasjonssjukepleier',),
'operasjonsstua': ('operasjonsstue',),
'operasjonsstue': ('operasjonsstue',),
'operasjonsstuen': ('operasjonsstue',),
'operasjonsstuene': ('operasjonsstue',),
'operasjonsstuer': ('operasjonsstue',),
'operasjonssykepleier': ('operasjonssykepleier',),
'operasjonssykepleiere': ('operasjonssykepleier',),
'operasjonssykepleieren': ('operasjonssykepleier',),
'operasjonssykepleierer': ('operasjonssykepleier',),
'operasjonssykepleierne': ('operasjonssykepleier',),
'operasjonssøster': ('operasjonssøster',),
'operasjonssøstera': ('operasjonssøster',),
'operasjonssøsteren': ('operasjonssøster',),
'operasjonssøstre': ('operasjonssøster',),
'operasjonssøstrene': ('operasjonssøster',),
'operasjonssøstrer': ('operasjonssøster',),
'operator': ('operator',),
'operatoren': ('operator',),
'operatorene': ('operator',),
'operatorer': ('operator',),
'operatør': ('operatør',),
'operatøren': ('operatør',),
'operatørene': ('operatør',),
'operatører': ('operatør',),
'operette': ('operette',),
'operetten': ('operette',),
'operettene': ('operette',),
'operetter': ('operette',),
'operettemelodi': ('operettemelodi',),
'operettemelodien': ('operettemelodi',),
'operettemelodiene': ('operettemelodi',),
'operettemelodier': ('operettemelodi',),
'opiat': ('opiat',),
'opiata': ('opiat',),
'opiatene': ('opiat',),
'opiater': ('opiat',),
'opiatet': ('opiat',),
'opinion': ('opinion',),
'opinionen': ('opinion',),
'opinionene': ('opinion',),
'opinioner': ('opinion',),
'opinionsbølga': ('opinionsbølge',),
'opinionsbølge': ('opinionsbølge',),
'opinionsbølgen': ('opinionsbølge',),
'opinionsbølgene': ('opinionsbølge',),
'opinionsbølger': ('opinionsbølge',),
'opinionsbølgja': ('opinionsbølgje',),
'opinionsbølgje': ('opinionsbølgje',),
'opinionsbølgjen': ('opinionsbølgje',),
'opinionsbølgjene': ('opinionsbølgje',),
'opinionsbølgjer': ('opinionsbølgje',),
'opinionsdanner': ('opinionsdanner',),
'opinionsdannere': ('opinionsdanner',),
'opinionsdanneren': ('opinionsdanner',),
'opinionsdannerer': ('opinionsdanner',),
'opinionsdannerne': ('opinionsdanner',),
'opinionsmåling': ('opinionsmåling',),
'opinionsmålinga': ('opinionsmåling',),
'opinionsmålingen': ('opinionsmåling',),
'opinionsmålingene': ('opinionsmåling',),
'opinionsmålinger': ('opinionsmåling',),
'opinionspress': ('opinionspress',),
'opinionspressa': ('opinionspress',),
'opinionspressene': ('opinionspress',),
'opinionspresset': ('opinionspress',),
'opium': ('opium',),
'opiumen': ('opium',),
'opiumene': ('opium',),
'opiumer': ('opium',),
'opiumbula': ('opiumbule',),
'opiumbule': ('opiumbule',),
'opiumbulen': ('opiumbule',),
'opiumbulene': ('opiumbule',),
'opiumbuler': ('opiumbule',),
'opiumsbula': ('opiumsbule',),
'opiumsbule': ('opiumsbule',),
'opiumsbulen': ('opiumsbule',),
'opiumsbulene': ('opiumsbule',),
'opiumsbuler': ('opiumsbule',),
'opiumsvalmue': ('opiumsvalmue',),
'opiumsvalmuen': ('opiumsvalmue',),
'opiumsvalmuene': ('opiumsvalmue',),
'opiumsvalmuer': ('opiumsvalmue',),
'opiumvalmue': ('opiumvalmue',),
'opiumvalmuen': ('opiumvalmue',),
'opiumvalmuene': ('opiumvalmue',),
'opiumvalmuer': ('opiumvalmue',),
'opkunst': ('opkunst',),
'opkunsten': ('opkunst',),
'opkunstene': ('opkunst',),
'opkunster': ('opkunst',),
'opossum': ('opossum',),
'opossumen': ('opossum',),
'opossumene': ('opossum',),
'opossumer': ('opossum',),
'opp-pakning': ('opp-pakning',),
'opp-pakninga': ('opp-pakning',),
'opp-pakningen': ('opp-pakning',),
'opp-pakningene': ('opp-pakning',),
'opp-pakninger': ('opp-pakning',),
'opp-passer': ('opp-passer',),
'opp-passere': ('opp-passer',),
'opp-passeren': ('opp-passer',),
'opp-passerer': ('opp-passer',),
'opp-passerne': ('opp-passer',),
'opp-pusning': ('opp-pusning',),
'opp-pusninga': ('opp-pusning',),
'opp-pusningen': ('opp-pusning',),
'opp-pusningene': ('opp-pusning',),
'opp-pusninger': ('opp-pusning',),
'opp-pussing': ('opp-pussing',),
'opp-pussinga': ('opp-pussing',),
'opp-pussingen': ('opp-pussing',),
'opp-pussingene': ('opp-pussing',),
'opp-pussinger': ('opp-pussing',),
'oppakning': ('oppakning',),
'oppakninga': ('oppakning',),
'oppakningen': ('oppakning',),
'oppakningene': ('oppakning',),
'oppakninger': ('oppakning',),
'oppal': ('oppal',),
'oppala': ('oppal',),
'oppalene': ('oppal',),
'oppalet': ('oppal',),
'opparbeidelse': ('opparbeidelse',),
'opparbeidelsen': ('opparbeidelse',),
'opparbeidelsene': ('opparbeidelse',),
'opparbeidelser': ('opparbeidelse',),
'opparbeiding': ('opparbeiding',),
'opparbeidinga': ('opparbeiding',),
'opparbeidingen': ('opparbeiding',),
'opparbeidingene': ('opparbeiding',),
'opparbeidinger': ('opparbeiding',),
'oppasser': ('oppasser',),
'oppassere': ('oppasser',),
'oppasseren': ('oppasser',),
'oppasserer': ('oppasser',),
'oppasserne': ('oppasser',),
'oppbakking': ('oppbakking',),
'oppbakkinga': ('oppbakking',),
'oppbakkingen': ('oppbakking',),
'oppbakkingene': ('oppbakking',),
'oppbakkinger': ('oppbakking',),
'oppbevaring': ('oppbevaring',),
'oppbevaringa': ('oppbevaring',),
'oppbevaringen': ('oppbevaring',),
'oppbevaringene': ('oppbevaring',),
'oppbevaringer': ('oppbevaring',),
'oppbremsing': ('oppbremsing',),
'oppbremsinga': ('oppbremsing',),
'oppbremsingen': ('oppbremsing',),
'oppbremsingene': ('oppbremsing',),
'oppbremsinger': ('oppbremsing',),
'oppbrett': ('oppbrett',),
'oppbretten': ('oppbrett',),
'oppbrettene': ('oppbrett',),
'oppbretter': ('oppbrett',),
'oppbrott': ('oppbrott',),
'oppbrotta': ('oppbrott',),
'oppbrottene': ('oppbrott',),
'oppbrottet': ('oppbrott',),
'oppbrudd': ('oppbrudd',),
'oppbrudda': ('oppbrudd',),
'oppbruddene': ('oppbrudd',),
'oppbruddet': ('oppbrudd',),
'oppbud': ('oppbud',),
'oppbuda': ('oppbud',),
'oppbudene': ('oppbud',),
'oppbudet': ('oppbud',),
'oppbyggelse': ('oppbyggelse',),
'oppbyggelsen': ('oppbyggelse',),
'oppbyggelsene': ('oppbyggelse',),
'oppbyggelser': ('oppbyggelse',),
'oppbygging': ('oppbygging',),
'oppbygginga': ('oppbygging',),
'oppbyggingen': ('oppbygging',),
'oppbyggingene': ('oppbygging',),
'oppbygginger': ('oppbygging',),
'oppbygning': ('oppbygning',),
'oppbygninga': ('oppbygning',),
'oppbygningen': ('oppbygning',),
'oppbygningene': ('oppbygning',),
'oppbygninger': ('oppbygning',),
'oppdagelse': ('oppdagelse',),
'oppdagelsen': ('oppdagelse',),
'oppdagelsene': ('oppdagelse',),
'oppdagelser': ('oppdagelse',),
'oppdagelsesferd': ('oppdagelsesferd',),
'oppdagelsesferda': ('oppdagelsesferd',),
'oppdagelsesferden': ('oppdagelsesferd',),
'oppdagelsesferdene': ('oppdagelsesferd',),
'oppdagelsesferder': ('oppdagelsesferd',),
'oppdagelsesreisende': ('oppdagelsesreisende',),
'oppdagelsesreisenden': ('oppdagelsesreisende',),
'oppdagelsesreisendene': ('oppdagelsesreisende',),
'oppdagelsesreisender': ('oppdagelsesreisende',),
'oppdager': ('oppdager',),
'oppdagere': ('oppdager',),
'oppdageren': ('oppdager',),
'oppdagerer': ('oppdager',),
'oppdagerne': ('oppdager',),
'oppdaging': ('oppdaging',),
'oppdaginga': ('oppdaging',),
'oppdagingen': ('oppdaging',),
'oppdagingene': ('oppdaging',),
'oppdaginger': ('oppdaging',),
'oppdagingsferd': ('oppdagingsferd',),
'oppdagingsferda': ('oppdagingsferd',),
'oppdagingsferden': ('oppdagingsferd',),
'oppdagingsferdene': ('oppdagingsferd',),
'oppdagingsferder': ('oppdagingsferd',),
'oppdagingsreisende': ('oppdagingsreisende',),
'oppdagingsreisenden': ('oppdagingsreisende',),
'oppdagingsreisendene': ('oppdagingsreisende',),
'oppdagingsreisender': ('oppdagingsreisende',),
'oppdekking': ('oppdekking',),
'oppdekkinga': ('oppdekking',),
'oppdekkingen': ('oppdekking',),
'oppdekkingene': ('oppdekking',),
'oppdekkinger': ('oppdekking',),
'oppdekning': ('oppdekning',),
'oppdekninga': ('oppdekning',),
'oppdekningen': ('oppdekning',),
'oppdekningene': ('oppdekning',),
'oppdekninger': ('oppdekning',),
'oppdikt': ('oppdikt',),
'oppdikta': ('oppdikt',),
'oppdiktene': ('oppdikt',),
'oppdiktet': ('oppdikt',),
'oppdrag': ('oppdrag',),
'oppdraga': ('oppdrag',),
'oppdragene': ('oppdrag',),
'oppdraget': ('oppdrag',),
'oppdragelse': ('oppdragelse',),
'oppdragelsen': ('oppdragelse',),
'oppdragelsene': ('oppdragelse',),
'oppdragelser': ('oppdragelse',),
'oppdrager': ('oppdrager',),
'oppdragere': ('oppdrager',),
'oppdrageren': ('oppdrager',),
'oppdragerer': ('oppdrager',),
'oppdragerne': ('oppdrager',),
'oppdragsgiver': ('oppdragsgiver',),
'oppdragsgivere': ('oppdragsgiver',),
'oppdragsgiveren': ('oppdragsgiver',),
'oppdragsgiverer': ('oppdragsgiver',),
'oppdragsgiverne': ('oppdragsgiver',),
'oppdrett': ('oppdrett',),
'oppdretta': ('oppdrett',),
'oppdrettene': ('oppdrett',),
'oppdrettet': ('oppdrett',),
'oppdretter': ('oppdretter',),
'oppdrettere': ('oppdretter',),
'oppdretteren': ('oppdretter',),
'oppdretterer': ('oppdretter',),
'oppdretterne': ('oppdretter',),
'oppdrift': ('oppdrift',),
'oppdrifta': ('oppdrift',),
'oppdriften': ('oppdrift',),
'oppdriftene': ('oppdrift',),
'oppdrifter': ('oppdrift',),
'oppdyrking': ('oppdyrking',),
'oppdyrkinga': ('oppdyrking',),
'oppdyrkingen': ('oppdyrking',),
'oppdyrkingene': ('oppdyrking',),
'oppdyrkinger': ('oppdyrking',),
'oppebørsel': ('oppebørsel',),
'oppebørselen': ('oppebørsel',),
'oppebørslene': ('oppebørsel',),
'oppebørsler': ('oppebørsel',),
'oppfarenhet': ('oppfarenhet',),
'oppfarenheta': ('oppfarenhet',),
'oppfarenheten': ('oppfarenhet',),
'oppfarenhetene': ('oppfarenhet',),
'oppfarenheter': ('oppfarenhet',),
'oppfatning': ('oppfatning',),
'oppfatninga': ('oppfatning',),
'oppfatningen': ('oppfatning',),
'oppfatningene': ('oppfatning',),
'oppfatninger': ('oppfatning',),
'oppfattelse': ('oppfattelse',),
'oppfattelsen': ('oppfattelse',),
'oppfattelsene': ('oppfattelse',),
'oppfattelser': ('oppfattelse',),
'oppfinnelse': ('oppfinnelse',),
'oppfinnelsen': ('oppfinnelse',),
'oppfinnelsene': ('oppfinnelse',),
'oppfinnelser': ('oppfinnelse',),
'oppfinner': ('oppfinner',),
'oppfinnere': ('oppfinner',),
'oppfinneren': ('oppfinner',),
'oppfinnerer': ('oppfinner',),
'oppfinnerne': ('oppfinner',),
'oppfinning': ('oppfinning',),
'oppfinninga': ('oppfinning',),
'oppfinningen': ('oppfinning',),
'oppfinningene': ('oppfinning',),
'oppfinninger': ('oppfinning',),
'oppforbakke': ('oppforbakke',),
'oppforbakken': ('oppforbakke',),
'oppforbakkene': ('oppforbakke',),
'oppforbakker': ('oppforbakke',),
'oppfordring': ('oppfordring',),
'oppfordringa': ('oppfordring',),
'oppfordringen': ('oppfordring',),
'oppfordringene': ('oppfordring',),
'oppfordringer': ('oppfordring',),
'oppfostringstoll': ('oppfostringstoll',),
'oppfostringstollen': ('oppfostringstoll',),
'oppfostringstollene': ('oppfostringstoll',),
'oppfostringstoller': ('oppfostringstoll',),
'oppfrisking': ('oppfrisking',),
'oppfriskinga': ('oppfrisking',),
'oppfriskingen': ('oppfrisking',),
'oppfriskingene': ('oppfrisking',),
'oppfriskinger': ('oppfrisking',),
'oppfriskning': ('oppfriskning',),
'oppfriskninga': ('oppfriskning',),
'oppfriskningen': ('oppfriskning',),
'oppfriskningene': ('oppfriskning',),
'oppfriskninger': ('oppfriskning',),
'oppfyllelse': ('oppfyllelse',),
'oppfyllelsen': ('oppfyllelse',),
'oppfyllelsene': ('oppfyllelse',),
'oppfyllelser': ('oppfyllelse',),
'oppfylling': ('oppfylling',),
'oppfyllinga': ('oppfylling',),
'oppfyllingen': ('oppfylling',),
'oppfyllingene': ('oppfylling',),
'oppfyllinger': ('oppfylling',),
'oppfølging': ('oppfølging',),
'oppfølginga': ('oppfølging',),
'oppfølgingen': ('oppfølging',),
'oppfølgingene': ('oppfølging',),
'oppfølginger': ('oppfølging',),
'oppfølgning': ('oppfølgning',),
'oppfølgninga': ('oppfølgning',),
'oppfølgningen': ('oppfølgning',),
'oppfølgningene': ('oppfølgning',),
'oppfølgninger': ('oppfølgning',),
'oppførelse': ('oppførelse',),
'oppførelsen': ('oppførelse',),
'oppførelsene': ('oppførelse',),
'oppførelser': ('oppførelse',),
'oppføring': ('oppføring',),
'oppføringa': ('oppføring',),
'oppføringen': ('oppføring',),
'oppføringene': ('oppføring',),
'oppføringer': ('oppføring',),
'oppførsel': ('oppførsel',),
'oppførselen': ('oppførsel',),
'oppførslene': ('oppførsel',),
'oppførsler': ('oppførsel',),
'oppgang': ('oppgang',),
'oppgangen': ('oppgang',),
'oppgangene': ('oppgang',),
'oppganger': ('oppgang',),
'oppgangssag': ('oppgangssag',),
'oppgangssaga': ('oppgangssag',),
'oppgangssagen': ('oppgangssag',),
'oppgangssagene': ('oppgangssag',),
'oppgangssager': ('oppgangssag',),
'oppgangstid': ('oppgangstid',),
'oppgangstida': ('oppgangstid',),
'oppgangstiden': ('oppgangstid',),
'oppgangstidene': ('oppgangstid',),
'oppgangstider': ('oppgangstid',),
'oppgava': ('oppgave',),
'oppgave': ('oppgave',),
'oppgaven': ('oppgave',),
'oppgavene': ('oppgave',),
'oppgaver': ('oppgave',),
'oppgaveløsing': ('oppgaveløsing',),
'oppgaveløsinga': ('oppgaveløsing',),
'oppgaveløsingen': ('oppgaveløsing',),
'oppgaveløsingene': ('oppgaveløsing',),
'oppgaveløsinger': ('oppgaveløsing',),
'oppgaveløsning': ('oppgaveløsning',),
'oppgaveløsninga': ('oppgaveløsning',),
'oppgaveløsningen': ('oppgaveløsning',),
'oppgaveløsningene': ('oppgaveløsning',),
'oppgaveløsninger': ('oppgaveløsning',),
'oppgaveløysing': ('oppgaveløysing',),
'oppgaveløysinga': ('oppgaveløysing',),
'oppgaveløysingen': ('oppgaveløysing',),
'oppgaveløysingene': ('oppgaveløysing',),
'oppgaveløysinger': ('oppgaveløysing',),
'oppgavesamling': ('oppgavesamling',),
'oppgavesamlinga': ('oppgavesamling',),
'oppgavesamlingen': ('oppgavesamling',),
'oppgavesamlingene': ('oppgavesamling',),
'oppgavesamlinger': ('oppgavesamling',),
'oppgjør': ('oppgjør',),
'oppgjøra': ('oppgjør',),
'oppgjørene': ('oppgjør',),
'oppgjøret': ('oppgjør',),
'oppgjørsfradrag': ('oppgjørsfradrag',),
'oppgjørsfradraga': ('oppgjørsfradrag',),
'oppgjørsfradragene': ('oppgjørsfradrag',),
'oppgjørsfradraget': ('oppgjørsfradrag',),
'oppgulp': ('oppgulp',),
'oppgulpa': ('oppgulp',),
'oppgulpene': ('oppgulp',),
'oppgulpet': ('oppgulp',),
'opphav': ('opphav',),
'opphava': ('opphav',),
'opphavene': ('opphav',),
'opphavet': ('opphav',),
'opphavskvinna': ('opphavskvinne',),
'opphavskvinne': ('opphavskvinne',),
'opphavskvinnen': ('opphavskvinne',),
'opphavskvinnene': ('opphavskvinne',),
'opphavskvinner': ('opphavskvinne',),
'opphavsmann': ('opphavsmann',),
'opphavsmannen': ('opphavsmann',),
'opphavsmenn': ('opphavsmann',),
'opphavsmennene': ('opphavsmann',),
'opphavsperson': ('opphavsperson',),
'opphavspersonen': ('opphavsperson',),
'opphavspersonene': ('opphavsperson',),
'opphavspersoner': ('opphavsperson',),
'opphavsrett': ('opphavsrett',),
'opphavsretten': ('opphavsrett',),
'opphavsrettene': ('opphavsrett',),
'opphavsretter': ('opphavsrett',),
'oppheng': ('oppheng',),
'opphenga': ('oppheng',),
'opphengene': ('oppheng',),
'opphenget': ('oppheng',),
'opphenting': ('opphenting',),
'opphentinga': ('opphenting',),
'opphentingen': ('opphenting',),
'opphentingene': ('opphenting',),
'opphentinger': ('opphenting',),
'opphevelse': ('opphevelse',),
'opphevelsen': ('opphevelse',),
'opphevelsene': ('opphevelse',),
'opphevelser': ('opphevelse',),
'oppheving': ('oppheving',),
'opphevinga': ('oppheving',),
'opphevingen': ('oppheving',),
'opphevingene': ('oppheving',),
'opphevinger': ('oppheving',),
'opphisselse': ('opphisselse',),
'opphisselsen': ('opphisselse',),
'opphisselsene': ('opphisselse',),
'opphisselser': ('opphisselse',),
'opphissing': ('opphissing',),
'opphissinga': ('opphissing',),
'opphissingen': ('opphissing',),
'opphissingene': ('opphissing',),
'opphissinger': ('opphissing',),
'opphoggeri': ('opphoggeri',),
'opphoggeria': ('opphoggeri',),
'opphoggeriene': ('opphoggeri',),
'opphoggerier': ('opphoggeri',),
'opphoggeriet': ('opphoggeri',),
'opphogging': ('opphogging',),
'opphogginga': ('opphogging',),
'opphoggingen': ('opphogging',),
'opphoggingene': ('opphogging',),
'opphogginger': ('opphogging',),
'opphogning': ('opphogning',),
'opphogninga': ('opphogning',),
'opphogningen': ('opphogning',),
'opphogningene': ('opphogning',),
'opphogninger': ('opphogning',),
'opphold': ('opphold',),
'oppholda': ('opphold',),
'oppholdene': ('opphold',),
'oppholdet': ('opphold',),
'oppholdsrom': ('oppholdsrom',),
'oppholdsromma': ('oppholdsrom',),
'oppholdsrommene': ('oppholdsrom',),
'oppholdsrommet': ('oppholdsrom',),
'oppholdssted': ('oppholdssted',),
'oppholdsstedene': ('oppholdssted',),
'oppholdssteder': ('oppholdssted',),
'oppholdsstedet': ('oppholdssted',),
'oppholdstillatelse': ('oppholdstillatelse',),
'oppholdstillatelsen': ('oppholdstillatelse',),
'oppholdstillatelsene': ('oppholdstillatelse',),
'oppholdstillatelser': ('oppholdstillatelse',),
'oppholdsvær': ('oppholdsvær',),
'oppholdsværa': ('oppholdsvær',),
'oppholdsværene': ('oppholdsvær',),
'oppholdsværet': ('oppholdsvær',),
'opphoping': ('opphoping',),
'opphopinga': ('opphoping',),
'opphopingen': ('opphoping',),
'opphopingene': ('opphoping',),
'opphopinger': ('opphoping',),
'opphuggeri': ('opphuggeri',),
'opphuggeria': ('opphuggeri',),
'opphuggeriene': ('opphuggeri',),
'opphuggerier': ('opphuggeri',),
'opphuggeriet': ('opphuggeri',),
'opphugging': ('opphugging',),
'opphugginga': ('opphugging',),
'opphuggingen': ('opphugging',),
'opphuggingene': ('opphugging',),
'opphugginger': ('opphugging',),
'opphugning': ('opphugning',),
'opphugninga': ('opphugning',),
'opphugningen': ('opphugning',),
'opphugningene': ('opphugning',),
'opphugninger': ('opphugning',),
'opphør': ('opphør',),
'opphøra': ('opphør',),
'opphørene': ('opphør',),
'opphøret': ('opphør',),
'opphørssalg': ('opphørssalg',),
'opphørssalga': ('opphørssalg',),
'opphørssalgene': ('opphørssalg',),
'opphørssalget': ('opphørssalg',),
'oppkast': ('oppkast',),
'oppkasta': ('oppkast',),
'oppkastene': ('oppkast',),
'oppkastet': ('oppkast',),
'oppkjøp': ('oppkjøp',),
'oppkjøpa': ('oppkjøp',),
'oppkjøpene': ('oppkjøp',),
'oppkjøpet': ('oppkjøp',),
'oppkjøper': ('oppkjøper',),
'oppkjøpere': ('oppkjøper',),
'oppkjøperen': ('oppkjøper',),
'oppkjøperer': ('oppkjøper',),
'oppkjøperne': ('oppkjøper',),
'oppkjøring': ('oppkjøring',),
'oppkjøringa': ('oppkjøring',),
'oppkjøringen': ('oppkjøring',),
'oppkjøringene': ('oppkjøring',),
'oppkjøringer': ('oppkjøring',),
'oppkjørsel': ('oppkjørsel',),
'oppkjørselen': ('oppkjørsel',),
'oppkjørsla': ('oppkjørsel',),
'oppkjørslene': ('oppkjørsel',),
'oppkjørsler': ('oppkjørsel',),
'oppklaring': ('oppklaring',),
'oppklaringa': ('oppklaring',),
'oppklaringen': ('oppklaring',),
'oppklaringene': ('oppklaring',),
'oppklaringer': ('oppklaring',),
'oppklaringspatrulje': ('oppklaringspatrulje',),
'oppklaringspatruljen': ('oppklaringspatrulje',),
'oppklaringspatruljene': ('oppklaringspatrulje',),
'oppklaringspatruljer': ('oppklaringspatrulje',),
'oppklaringsrunde': ('oppklaringsrunde',),
'oppklaringsrunden': ('oppklaringsrunde',),
'oppklaringsrundene': ('oppklaringsrunde',),
'oppklaringsrunder': ('oppklaringsrunde',),
'oppklarning': ('oppklarning',),
'oppklarninga': ('oppklarning',),
'oppklarningen': ('oppklarning',),
'oppklarningene': ('oppklarning',),
'oppklarninger': ('oppklarning',),
'oppkok': ('oppkok',),
'oppkoka': ('oppkok',),
'oppkokene': ('oppkok',),
'oppkoket': ('oppkok',),
'oppkomling': ('oppkomling',),
'oppkomlingen': ('oppkomling',),
'oppkomlingene': ('oppkomling',),
'oppkomlinger': ('oppkomling',),
'oppkomma': ('oppkomme',),
'oppkomme': ('oppkomme',),
'oppkommen': ('oppkomme',),
'oppkommene': ('oppkomme',),
'oppkommer': ('oppkomme',),
'oppkommet': ('oppkomme',),
'oppkomst': ('oppkomst',),
'oppkomsten': ('oppkomst',),
'oppkomstene': ('oppkomst',),
'oppkomster': ('oppkomst',),
'oppkrav': ('oppkrav',),
'oppkrava': ('oppkrav',),
'oppkravene': ('oppkrav',),
'oppkravet': ('oppkrav',),
'oppkrever': ('oppkrever',),
'oppkrevere': ('oppkrever',),
'oppkreveren': ('oppkrever',),
'oppkreverer': ('oppkrever',),
'oppkreverne': ('oppkrever',),
'oppkvikker': ('oppkvikker',),
'oppkvikkere': ('oppkvikker',),
'oppkvikkeren': ('oppkvikker',),
'oppkvikkerer': ('oppkvikker',),
'oppkvikkerne': ('oppkvikker',),
'opplading': ('opplading',),
'oppladinga': ('opplading',),
'oppladingen': ('opplading',),
'oppladingene': ('opplading',),
'oppladinger': ('opplading',),
'oppladning': ('oppladning',),
'oppladninga': ('oppladning',),
'oppladningen': ('oppladning',),
'oppladningene': ('oppladning',),
'oppladninger': ('oppladning',),
'opplag': ('opplag',),
'opplaga': ('opplag',),
'opplagene': ('opplag',),
'opplaget': ('opplag',),
'opplagsbøya': ('opplagsbøye',),
'opplagsbøye': ('opplagsbøye',),
'opplagsbøyen': ('opplagsbøye',),
'opplagsbøyene': ('opplagsbøye',),
'opplagsbøyer': ('opplagsbøye',),
'opplagsnæring': ('opplagsnæring',),
'opplagsnæringa': ('opplagsnæring',),
'opplagsnæringen': ('opplagsnæring',),
'opplagsnæringene': ('opplagsnæring',),
'opplagsnæringer': ('opplagsnæring',),
'opplagsplass': ('opplagsplass',),
'opplagsplassen': ('opplagsplass',),
'opplagsplassene': ('opplagsplass',),
'opplagsplasser': ('opplagsplass',),
'oppland': ('oppland',),
'opplanda': ('oppland',),
'opplandene': ('oppland',),
'opplandet': ('oppland',),
'opplaster': ('opplaster',),
'opplastere': ('opplaster',),
'opplasteren': ('opplaster',),
'opplasterer': ('opplaster',),
'opplasterne': ('opplaster',),
'opplegg': ('opplegg',),
'opplegga': ('opplegg',),
'oppleggene': ('opplegg',),
'opplegget': ('opplegg',),
'opplending': ('opplending',),
'opplendingen': ('opplending',),
'opplendingene': ('opplending',),
'opplendinger': ('opplending',),
'oppleser': ('oppleser',),
'opplesere': ('oppleser',),
'oppleseren': ('oppleser',),
'oppleserer': ('oppleser',),
'oppleserne': ('oppleser',),
'opplesing': ('opplesing',),
'opplesinga': ('opplesing',),
'opplesingen': ('opplesing',),
'opplesingene': ('opplesing',),
'opplesinger': ('opplesing',),
'opplesning': ('opplesning',),
'opplesninga': ('opplesning',),
'opplesningen': ('opplesning',),
'opplesningene': ('opplesning',),
'opplesninger': ('opplesning',),
'opplett': ('opplett',),
'oppletta': ('opplett',),
'opplettene': ('opplett',),
'opplettet': ('opplett',),
'opplevelse': ('opplevelse',),
'opplevelsen': ('opplevelse',),
'opplevelsene': ('opplevelse',),
'opplevelser': ('opplevelse',),
'oppleving': ('oppleving',),
'opplevinga': ('oppleving',),
'opplevingen': ('oppleving',),
'opplevingene': ('oppleving',),
'opplevinger': ('oppleving',),
'oppliving': ('oppliving',),
'opplivinga': ('oppliving',),
'opplivingen': ('oppliving',),
'opplivingene': ('oppliving',),
'opplivinger': ('oppliving',),
'opplivingsforsøk': ('opplivingsforsøk',),
'opplivingsforsøka': ('opplivingsforsøk',),
'opplivingsforsøkene': ('opplivingsforsøk',),
'opplivingsforsøket': ('opplivingsforsøk',),
'opplivning': ('opplivning',),
'opplivninga': ('opplivning',),
'opplivningen': ('opplivning',),
'opplivningene': ('opplivning',),
'opplivninger': ('opplivning',),
'opplivningsforsøk': ('opplivningsforsøk',),
'opplivningsforsøka': ('opplivningsforsøk',),
'opplivningsforsøkene': ('opplivningsforsøk',),
'opplivningsforsøket': ('opplivningsforsøk',),
'opplysning': ('opplysning',),
'opplysninga': ('opplysning',),
'opplysningen': ('opplysning',),
'opplysningene': ('opplysning',),
'opplysninger': ('opplysning',),
'opplysningsskilt': ('opplysningsskilt',),
'opplysningsskilta': ('opplysningsskilt',),
'opplysningsskiltene': ('opplysningsskilt',),
'opplysningsskilter': ('opplysningsskilt',),
'opplysningsskiltet': ('opplysningsskilt',),
'opplysningstid': ('opplysningstid',),
'opplysningstida': ('opplysningstid',),
'opplysningstiden': ('opplysningstid',),
'opplysningstidene': ('opplysningstid',),
'opplysningstider': ('opplysningstid',),
'opplåning': ('opplåning',),
'opplåninga': ('opplåning',),
'opplåningen': ('opplåning',),
'opplåningene': ('opplåning',),
'opplåninger': ('opplåning',),
'opplæring': ('opplæring',),
'opplæringa': ('opplæring',),
'opplæringen': ('opplæring',),
'opplæringene': ('opplæring',),
'opplæringer': ('opplæring',),
'opplæringsmål': ('opplæringsmål',),
'opplæringsmåla': ('opplæringsmål',),
'opplæringsmålene': ('opplæringsmål',),
'opplæringsmålet': ('opplæringsmål',),
'oppløftelse': ('oppløftelse',),
'oppløftelsen': ('oppløftelse',),
'oppløftelsene': ('oppløftelse',),
'oppløftelser': ('oppløftelse',),
'oppløp': ('oppløp',),
'oppløpa': ('oppløp',),
'oppløpene': ('oppløp',),
'oppløpet': ('oppløp',),
'oppløpssida': ('oppløpsside',),
'oppløpsside': ('oppløpsside',),
'oppløpssiden': ('oppløpsside',),
'oppløpssidene': ('oppløpsside',),
'oppløpssider': ('oppløpsside',),
'oppløsning': ('oppløsning',),
'oppløsninga': ('oppløsning',),
'oppløsningen': ('oppløsning',),
'oppløsningene': ('oppløsning',),
'oppløsninger': ('oppløsning',),
'oppløsningsevna': ('oppløsningsevne',),
'oppløsningsevne': ('oppløsningsevne',),
'oppløsningsevnen': ('oppløsningsevne',),
'oppløsningsevnene': ('oppløsningsevne',),
'oppløsningsevner': ('oppløsningsevne',),
'oppløsningsmiddel': ('oppløsningsmiddel',),
'oppløsningsmiddelet': ('oppløsningsmiddel',),
'oppløsningsmidla': ('oppløsningsmiddel',),
'oppløsningsmidlene': ('oppløsningsmiddel',),
'oppløsningsmidler': ('oppløsningsmiddel',),
'oppløsningsmidlet': ('oppløsningsmiddel',),
'oppløsningsrett': ('oppløsningsrett',),
'oppløsningsretten': ('oppløsningsrett',),
'oppløsningsrettene': ('oppløsningsrett',),
'oppløsningsretter': ('oppløsningsrett',),
'oppløsningstegn': ('oppløsningstegn',),
'oppløsningstegna': ('oppløsningstegn',),
'oppløsningstegnene': ('oppløsningstegn',),
'oppløsningstegnet': ('oppløsningstegn',),
'oppløsningstendens': ('oppløsningstendens',),
'oppløsningstendensen': ('oppløsningstendens',),
'oppløsningstendensene': ('oppløsningstendens',),
'oppløsningstendenser': ('oppløsningstendens',),
'oppløysing': ('oppløysing',),
'oppløysinga': ('oppløysing',),
'oppløysingen': ('oppløysing',),
'oppløysingene': ('oppløysing',),
'oppløysinger': ('oppløysing',),
'oppløysingsmiddel': ('oppløysingsmiddel',),
'oppløysingsmiddelet': ('oppløysingsmiddel',),
'oppløysingsmidla': ('oppløysingsmiddel',),
'oppløysingsmidlene': ('oppløysingsmiddel',),
'oppløysingsmidler': ('oppløysingsmiddel',),
'oppløysingsmidlet': ('oppløysingsmiddel',),
'oppløysingsrett': ('oppløysingsrett',),
'oppløysingsretten': ('oppløysingsrett',),
'oppløysingsrettene': ('oppløysingsrett',),
'oppløysingsretter': ('oppløysingsrett',),
'oppløysingstegn': ('oppløysingstegn',),
'oppløysingstegna': ('oppløysingstegn',),
'oppløysingstegnene': ('oppløysingstegn',),
'oppløysingstegnet': ('oppløysingstegn',),
'oppløysingstendens': ('oppløysingstendens',),
'oppløysingstendensen': ('oppløysingstendens',),
'oppløysingstendensene': ('oppløysingstendens',),
'oppløysingstendenser': ('oppløysingstendens',),
'oppmaling': ('oppmaling',),
'oppmalinga': ('oppmaling',),
'oppmalingen': ('oppmaling',),
'oppmalingene': ('oppmaling',),
'oppmalinger': ('oppmaling',),
'oppmann': ('oppmann',),
'oppmannen': ('oppmann',),
'oppmenn': ('oppmann',),
'oppmennene': ('oppmann',),
'oppmarsj': ('oppmarsj',),
'oppmarsjen': ('oppmarsj',),
'oppmarsjene': ('oppmarsj',),
'oppmarsjer': ('oppmarsj',),
'oppmarsjområda': ('oppmarsjområde',),
'oppmarsjområde': ('oppmarsjområde',),
'oppmarsjområdene': ('oppmarsjområde',),
'oppmarsjområder': ('oppmarsjområde',),
'oppmarsjområdet': ('oppmarsjområde',),
'oppmerking': ('oppmerking',),
'oppmerkinga': ('oppmerking',),
'oppmerkingen': ('oppmerking',),
'oppmerkingene': ('oppmerking',),
'oppmerkinger': ('oppmerking',),
'oppmerksomhet': ('oppmerksomhet',),
'oppmerksomheta': ('oppmerksomhet',),
'oppmerksomheten': ('oppmerksomhet',),
'oppmerksomhetene': ('oppmerksomhet',),
'oppmerksomheter': ('oppmerksomhet',),
'oppmjuking': ('oppmjuking',),
'oppmjukinga': ('oppmjuking',),
'oppmjukingen': ('oppmjuking',),
'oppmjukingene': ('oppmjuking',),
'oppmjukinger': ('oppmjuking',),
'oppmjukingsøvelse': ('oppmjukingsøvelse',),
'oppmjukingsøvelsen': ('oppmjukingsøvelse',),
'oppmjukingsøvelsene': ('oppmjukingsøvelse',),
'oppmjukingsøvelser': ('oppmjukingsøvelse',),
'oppmjukingsøving': ('oppmjukingsøving',),
'oppmjukingsøvinga': ('oppmjukingsøving',),
'oppmjukingsøvingen': ('oppmjukingsøving',),
'oppmjukingsøvingene': ('oppmjukingsøving',),
'oppmjukingsøvinger': ('oppmjukingsøving',),
'oppmuntring': ('oppmuntring',),
'oppmuntringa': ('oppmuntring',),
'oppmuntringen': ('oppmuntring',),
'oppmuntringene': ('oppmuntring',),
'oppmuntringer': ('oppmuntring',),
'oppmyking': ('oppmyking',),
'oppmykinga': ('oppmyking',),
'oppmykingen': ('oppmyking',),
'oppmykingene': ('oppmyking',),
'oppmykinger': ('oppmyking',),
'oppmykingsøvelse': ('oppmykingsøvelse',),
'oppmykingsøvelsen': ('oppmykingsøvelse',),
'oppmykingsøvelsene': ('oppmykingsøvelse',),
'oppmykingsøvelser': ('oppmykingsøvelse',),
'oppmykingsøving': ('oppmykingsøving',),
'oppmykingsøvinga': ('oppmykingsøving',),
'oppmykingsøvingen': ('oppmykingsøving',),
'oppmykingsøvingene': ('oppmykingsøving',),
'oppmykingsøvinger': ('oppmykingsøving',),
'oppmykning': ('oppmykning',),
'oppmykninga': ('oppmykning',),
'oppmykningen': ('oppmykning',),
'oppmykningene': ('oppmykning',),
'oppmykninger': ('oppmykning',),
'oppmykningsøvelse': ('oppmykningsøvelse',),
'oppmykningsøvelsen': ('oppmykningsøvelse',),
'oppmykningsøvelsene': ('oppmykningsøvelse',),
'oppmykningsøvelser': ('oppmykningsøvelse',),
'oppmykningsøving': ('oppmykningsøving',),
'oppmykningsøvinga': ('oppmykningsøving',),
'oppmykningsøvingen': ('oppmykningsøving',),
'oppmykningsøvingene': ('oppmykningsøving',),
'oppmykningsøvinger': ('oppmykningsøving',),
'oppmåling': ('oppmåling',),
'oppmålinga': ('oppmåling',),
'oppmålingen': ('oppmåling',),
'oppmålingene': ('oppmåling',),
'oppmålinger': ('oppmåling',),
'oppmøta': ('oppmøte',),
'oppmøte': ('oppmøte',),
'oppmøtene': ('oppmøte',),
'oppmøter': ('oppmøte',),
'oppmøtet': ('oppmøte',),
'oppnavn': ('oppnavn',),
'oppnavna': ('oppnavn',),
'oppnavnene': ('oppnavn',),
'oppnavnet': ('oppnavn',),
'oppnevnelse': ('oppnevnelse',),
'oppnevnelsen': ('oppnevnelse',),
'oppnevnelsene': ('oppnevnelse',),
'oppnevnelser': ('oppnevnelse',),
'oppnevning': ('oppnevning',),
'oppnevninga': ('oppnevning',),
'oppnevningen': ('oppnevning',),
'oppnevningene': ('oppnevning',),
'oppnevninger': ('oppnevning',),
'oppofrelse': ('oppofrelse',),
'oppofrelsen': ('oppofrelse',),
'oppofrelsene': ('oppofrelse',),
'oppofrelser': ('oppofrelse',),
'oppofring': ('oppofring',),
'oppofringa': ('oppofring',),
'oppofringen': ('oppofring',),
'oppofringene': ('oppofring',),
'oppofringer': ('oppofring',),
'opponent': ('opponent',),
'opponenten': ('opponent',),
'opponentene': ('opponent',),
'opponenter': ('opponent',),
'opportunisme': ('opportunisme',),
'opportunismen': ('opportunisme',),
'opportunismene': ('opportunisme',),
'opportunismer': ('opportunisme',),
'opportunist': ('opportunist',),
'opportunisten': ('opportunist',),
'opportunistene': ('opportunist',),
'opportunister': ('opportunist',),
'opportunitet': ('opportunitet',),
'opportuniteten': ('opportunitet',),
'opportunitetene': ('opportunitet',),
'opportuniteter': ('opportunitet',),
'opportunitetsprinsipp': ('opportunitetsprinsipp',),
'opportunitetsprinsippa': ('opportunitetsprinsipp',),
'opportunitetsprinsippene': ('opportunitetsprinsipp',),
'opportunitetsprinsipper': ('opportunitetsprinsipp',),
'opportunitetsprinsippet': ('opportunitetsprinsipp',),
'opposisjon': ('opposisjon',),
'opposisjonen': ('opposisjon',),
'opposisjonene': ('opposisjon',),
'opposisjoner': ('opposisjon',),
'opposisjonsparti': ('opposisjonsparti',),
'opposisjonspartia': ('opposisjonsparti',),
'opposisjonspartiene': ('opposisjonsparti',),
'opposisjonspartier': ('opposisjonsparti',),
'opposisjonspartiet': ('opposisjonsparti',),
'oppoverbakke': ('oppoverbakke',),
'oppoverbakken': ('oppoverbakke',),
'oppoverbakkene': ('oppoverbakke',),
'oppoverbakker': ('oppoverbakke',),
'oppramsing': ('oppramsing',),
'oppramsinga': ('oppramsing',),
'oppramsingen': ('oppramsing',),
'oppramsingene': ('oppramsing',),
'oppramsinger': ('oppramsing',),
'oppreding': ('oppreding',),
'oppredinga': ('oppreding',),
'oppredingen': ('oppreding',),
'oppredingene': ('oppreding',),
'oppredinger': ('oppreding',),
'oppredning': ('oppredning',),
'oppredninga': ('oppredning',),
'oppredningen': ('oppredning',),
'oppredningene': ('oppredning',),
'oppredninger': ('oppredning',),
'oppregning': ('oppregning',),
'oppregninga': ('oppregning',),
'oppregningen': ('oppregning',),
'oppregningene': ('oppregning',),
'oppregninger': ('oppregning',),
'oppregning': ('oppregning',),
'oppregninga': ('oppregning',),
'oppregningen': ('oppregning',),
'oppregningene': ('oppregning',),
'oppregninger': ('oppregning',),
'oppreisning': ('oppreisning',),
'oppreisninga': ('oppreisning',),
'oppreisningen': ('oppreisning',),
'oppreisningene': ('oppreisning',),
'oppreisninger': ('oppreisning',),
'opprekning': ('opprekning',),
'opprekninga': ('opprekning',),
'opprekningen': ('opprekning',),
'opprekningene': ('opprekning',),
'opprekninger': ('opprekning',),
'opprekning': ('opprekning',),
'opprekninga': ('opprekning',),
'opprekningen': ('opprekning',),
'opprekningene': ('opprekning',),
'opprekninger': ('opprekning',),
'opprensking': ('opprensking',),
'opprenskinga': ('opprensking',),
'opprenskingen': ('opprensking',),
'opprenskingene': ('opprensking',),
'opprenskinger': ('opprensking',),
'opprenskning': ('opprenskning',),
'opprenskninga': ('opprenskning',),
'opprenskningen': ('opprenskning',),
'opprenskningene': ('opprenskning',),
'opprenskninger': ('opprenskning',),
'opprettelse': ('opprettelse',),
'opprettelsen': ('opprettelse',),
'opprettelsene': ('opprettelse',),
'opprettelser': ('opprettelse',),
'oppretter': ('oppretter',),
'opprettere': ('oppretter',),
'oppretteren': ('oppretter',),
'oppretterer': ('oppretter',),
'oppretterne': ('oppretter',),
'oppringing': ('oppringing',),
'oppringinga': ('oppringing',),
'oppringingen': ('oppringing',),
'oppringingene': ('oppringing',),
'oppringinger': ('oppringing',),
'oppringning': ('oppringning',),
'oppringninga': ('oppringning',),
'oppringningen': ('oppringning',),
'oppringningene': ('oppringning',),
'oppringninger': ('oppringning',),
'opprinnelse': ('opprinnelse',),
'opprinnelsen': ('opprinnelse',),
'opprinnelsene': ('opprinnelse',),
'opprinnelser': ('opprinnelse',),
'opprinnelsesbevis': ('opprinnelsesbevis',),
'opprinnelsesbevisa': ('opprinnelsesbevis',),
'opprinnelsesbevisene': ('opprinnelsesbevis',),
'opprinnelsesbeviser': ('opprinnelsesbevis',),
'opprinnelsesbeviset': ('opprinnelsesbevis',),
'oppriss': ('oppriss',),
'opprissa': ('oppriss',),
'opprissene': ('oppriss',),
'opprisset': ('oppriss',),
'opprop': ('opprop',),
'oppropa': ('opprop',),
'oppropene': ('opprop',),
'oppropet': ('opprop',),
'opprulling': ('opprulling',),
'opprullinga': ('opprulling',),
'opprullingen': ('opprulling',),
'opprullingene': ('opprulling',),
'opprullinger': ('opprulling',),
'opprusting': ('opprusting',),
'opprustinga': ('opprusting',),
'opprustingen': ('opprusting',),
'opprustingene': ('opprusting',),
'opprustinger': ('opprusting',),
'opprustning': ('opprustning',),
'opprustninga': ('opprustning',),
'opprustningen': ('opprustning',),
'opprustningene': ('opprustning',),
'opprustninger': ('opprustning',),
'opprydding': ('opprydding',),
'oppryddinga': ('opprydding',),
'oppryddingen': ('opprydding',),
'oppryddingene': ('opprydding',),
'oppryddinger': ('opprydding',),
'opprydning': ('opprydning',),
'opprydninga': ('opprydning',),
'opprydningen': ('opprydning',),
'opprydningene': ('opprydning',),
'opprydninger': ('opprydning',),
'opprykk': ('opprykk',),
'opprykka': ('opprykk',),
'opprykken': ('opprykk',),
'opprykkene': ('opprykk',),
'opprykket': ('opprykk',),
'opprykking': ('opprykking',),
'opprykkinga': ('opprykking',),
'opprykkingen': ('opprykking',),
'opprykkingene': ('opprykking',),
'opprykkinger': ('opprykking',),
'opprykning': ('opprykning',),
'opprykninga': ('opprykning',),
'opprykningen': ('opprykning',),
'opprykningene': ('opprykning',),
'opprykninger': ('opprykning',),
'opprør': ('opprør',),
'opprøra': ('opprør',),
'opprørene': ('opprør',),
'opprøret': ('opprør',),
'opprører': ('opprører',),
'opprørere': ('opprører',),
'opprøreren': ('opprører',),
'opprørerer': ('opprører',),
'opprørerne': ('opprører',),
'opprørsfana': ('opprørsfane',),
'opprørsfane': ('opprørsfane',),
'opprørsfanen': ('opprørsfane',),
'opprørsfanene': ('opprørsfane',),
'opprørsfaner': ('opprørsfane',),
'oppsamler': ('oppsamler',),
'oppsamlere': ('oppsamler',),
'oppsamleren': ('oppsamler',),
'oppsamlerer': ('oppsamler',),
'oppsamlerne': ('oppsamler',),
'oppsamling': ('oppsamling',),
'oppsamlinga': ('oppsamling',),
'oppsamlingen': ('oppsamling',),
'oppsamlingene': ('oppsamling',),
'oppsamlinger': ('oppsamling',),
'oppsamlingsheat': ('oppsamlingsheat',),
'oppsamlingsheata': ('oppsamlingsheat',),
'oppsamlingsheatene': ('oppsamlingsheat',),
'oppsamlingsheatet': ('oppsamlingsheat',),
'oppsang': ('oppsang',),
'oppsangen': ('oppsang',),
'oppsangene': ('oppsang',),
'oppsanger': ('oppsang',),
'oppsanger': ('oppsanger',),
'oppsangere': ('oppsanger',),
'oppsangeren': ('oppsanger',),
'oppsangerer': ('oppsanger',),
'oppsangerne': ('oppsanger',),
'oppsats': ('oppsats',),
'oppsatsen': ('oppsats',),
'oppsatsene': ('oppsats',),
'oppsatser': ('oppsats',),
'oppsegling': ('oppsegling',),
'oppseglinga': ('oppsegling',),
'oppseglingen': ('oppsegling',),
'oppseglingene': ('oppsegling',),
'oppseglinger': ('oppsegling',),
'oppseiling': ('oppseiling',),
'oppseilinga': ('oppseiling',),
'oppseilingen': ('oppseiling',),
'oppseilingene': ('oppseiling',),
'oppseilinger': ('oppseiling',),
'oppsetning': ('oppsetning',),
'oppsetninga': ('oppsetning',),
'oppsetningen': ('oppsetning',),
'oppsetningene': ('oppsetning',),
'oppsetninger': ('oppsetning',),
'oppsett': ('oppsett',),
'oppsetta': ('oppsett',),
'oppsettene': ('oppsett',),
'oppsettet': ('oppsett',),
'oppsetting': ('oppsetting',),
'oppsettinga': ('oppsetting',),
'oppsettingen': ('oppsetting',),
'oppsettingene': ('oppsetting',),
'oppsettinger': ('oppsetting',),
'oppsida': ('oppside',),
'oppside': ('oppside',),
'oppsiden': ('oppside',),
'oppsidene': ('oppside',),
'oppsider': ('oppside',),
'oppsigelse': ('oppsigelse',),
'oppsigelsen': ('oppsigelse',),
'oppsigelsene': ('oppsigelse',),
'oppsigelser': ('oppsigelse',),
'oppsigelsestid': ('oppsigelsestid',),
'oppsigelsestida': ('oppsigelsestid',),
'oppsigelsestiden': ('oppsigelsestid',),
'oppsigelsestidene': ('oppsigelsestid',),
'oppsigelsestider': ('oppsigelsestid',),
'oppsiing': ('oppsiing',),
'oppsiinga': ('oppsiing',),
'oppsiingen': ('oppsiing',),
'oppsiingene': ('oppsiing',),
'oppsiinger': ('oppsiing',),
'oppsiingstid': ('oppsiingstid',),
'oppsiingstida': ('oppsiingstid',),
'oppsiingstiden': ('oppsiingstid',),
'oppsiingstidene': ('oppsiingstid',),
'oppsiingstider': ('oppsiingstid',),
'oppsikt': ('oppsikt',),
'oppsikta': ('oppsikt',),
'oppsikten': ('oppsikt',),
'oppsiktene': ('oppsikt',),
'oppsikter': ('oppsikt',),
'oppsitter': ('oppsitter',),
'oppsittere': ('oppsitter',),
'oppsitteren': ('oppsitter',),
'oppsitterer': ('oppsitter',),
'oppsitterne': ('oppsitter',),
'oppskjær': ('oppskjær',),
'oppskjæra': ('oppskjær',),
'oppskjærene': ('oppskjær',),
'oppskjæret': ('oppskjær',),
'oppskrift': ('oppskrift',),
'oppskrifta': ('oppskrift',),
'oppskriften': ('oppskrift',),
'oppskriftene': ('oppskrift',),
'oppskrifter': ('oppskrift',),
'oppskriver': ('oppskriver',),
'oppskrivere': ('oppskriver',),
'oppskriveren': ('oppskriver',),
'oppskriverer': ('oppskriver',),
'oppskriverne': ('oppskriver',),
'oppskyting': ('oppskyting',),
'oppskytinga': ('oppskyting',),
'oppskytingen': ('oppskyting',),
'oppskytingene': ('oppskyting',),
'oppskytinger': ('oppskyting',),
'oppskytning': ('oppskytning',),
'oppskytninga': ('oppskytning',),
'oppskytningen': ('oppskytning',),
'oppskytningene': ('oppskytning',),
'oppskytninger': ('oppskytning',),
'oppslag': ('oppslag',),
'oppslaga': ('oppslag',),
'oppslagene': ('oppslag',),
'oppslaget': ('oppslag',),
'oppslager': ('oppslager',),
'oppslagere': ('oppslager',),
'oppslageren': ('oppslager',),
'oppslagerer': ('oppslager',),
'oppslagerne': ('oppslager',),
'oppslagsbok': ('oppslagsbok',),
'oppslagsboka': ('oppslagsbok',),
'oppslagsboken': ('oppslagsbok',),
'oppslagsbøkene': ('oppslagsbok',),
'oppslagsbøker': ('oppslagsbok',),
'oppslagsord': ('oppslagsord',),
'oppslagsorda': ('oppslagsord',),
'oppslagsordene': ('oppslagsord',),
'oppslagsordet': ('oppslagsord',),
'oppslagstavla': ('oppslagstavle',),
'oppslagstavle': ('oppslagstavle',),
'oppslagstavlen': ('oppslagstavle',),
'oppslagstavlene': ('oppslagstavle',),
'oppslagstavler': ('oppslagstavle',),
'oppslagsverk': ('oppslagsverk',),
'oppslagsverka': ('oppslagsverk',),
'oppslagsverkene': ('oppslagsverk',),
'oppslagsverker': ('oppslagsverk',),
'oppslagsverket': ('oppslagsverk',),
'oppslutning': ('oppslutning',),
'oppslutninga': ('oppslutning',),
'oppslutningen': ('oppslutning',),
'oppslutningene': ('oppslutning',),
'oppslutninger': ('oppslutning',),
'oppsop': ('oppsop',),
'oppsopa': ('oppsop',),
'oppsopene': ('oppsop',),
'oppsopet': ('oppsop',),
'oppspinn': ('oppspinn',),
'oppspinna': ('oppspinn',),
'oppspinnene': ('oppspinn',),
'oppspinnet': ('oppspinn',),
'oppsplitting': ('oppsplitting',),
'oppsplittinga': ('oppsplitting',),
'oppsplittingen': ('oppsplitting',),
'oppsplittingene': ('oppsplitting',),
'oppsplittinger': ('oppsplitting',),
'oppsprang': ('oppsprang',),
'oppspranga': ('oppsprang',),
'oppsprangene': ('oppsprang',),
'oppspranget': ('oppsprang',),
'oppspytt': ('oppspytt',),
'oppspytta': ('oppspytt',),
'oppspyttene': ('oppspytt',),
'oppspyttet': ('oppspytt',),
'oppstadvev': ('oppstadvev',),
'oppstadveven': ('oppstadvev',),
'oppstadvevene': ('oppstadvev',),
'oppstadvever': ('oppstadvev',),
'oppstand': ('oppstand',),
'oppstanden': ('oppstand',),
'oppstandene': ('oppstand',),
'oppstander': ('oppstand',),
'oppstandelse': ('oppstandelse',),
'oppstandelsen': ('oppstandelse',),
'oppstandelsene': ('oppstandelse',),
'oppstandelser': ('oppstandelse',),
'oppstander': ('oppstander',),
'oppstandere': ('oppstander',),
'oppstanderen': ('oppstander',),
'oppstanderer': ('oppstander',),
'oppstanderne': ('oppstander',),
'oppstiging': ('oppstiging',),
'oppstiginga': ('oppstiging',),
'oppstigingen': ('oppstiging',),
'oppstigingene': ('oppstiging',),
'oppstiginger': ('oppstiging',),
'oppstigning': ('oppstigning',),
'oppstigninga': ('oppstigning',),
'oppstigningen': ('oppstigning',),
'oppstigningene': ('oppstigning',),
'oppstigninger': ('oppstigning',),
'oppstilling': ('oppstilling',),
'oppstillinga': ('oppstilling',),
'oppstillingen': ('oppstilling',),
'oppstillingene': ('oppstilling',),
'oppstillinger': ('oppstilling',),
'oppstiver': ('oppstiver',),
'oppstivere': ('oppstiver',),
'oppstiveren': ('oppstiver',),
'oppstiverer': ('oppstiver',),
'oppstiverne': ('oppstiver',),
'oppstopper': ('oppstopper',),
'oppstoppere': ('oppstopper',),
'oppstopperen': ('oppstopper',),
'oppstopperer': ('oppstopper',),
'oppstopperne': ('oppstopper',),
'oppstoppernesa': ('oppstoppernese',),
'oppstoppernese': ('oppstoppernese',),
'oppstoppernesen': ('oppstoppernese',),
'oppstoppernesene': ('oppstoppernese',),
'oppstopperneser': ('oppstoppernese',),
'oppstrammer': ('oppstrammer',),
'oppstrammere': ('oppstrammer',),
'oppstrammeren': ('oppstrammer',),
'oppstrammerer': ('oppstrammer',),
'oppstrammerne': ('oppstrammer',),
'oppstrøk': ('oppstrøk',),
'oppstrøka': ('oppstrøk',),
'oppstrøkene': ('oppstrøk',),
'oppstrøket': ('oppstrøk',),
'oppstuss': ('oppstuss',),
'oppstussa': ('oppstuss',),
'oppstussene': ('oppstuss',),
'oppstusset': ('oppstuss',),
'oppstyr': ('oppstyr',),
'oppstyra': ('oppstyr',),
'oppstyrene': ('oppstyr',),
'oppstyret': ('oppstyr',),
'oppstøt': ('oppstøt',),
'oppstøta': ('oppstøt',),
'oppstøtene': ('oppstøt',),
'oppstøtet': ('oppstøt',),
'oppstøyt': ('oppstøyt',),
'oppstøyten': ('oppstøyt',),
'oppstøytene': ('oppstøyt',),
'oppstøyter': ('oppstøyt',),
'oppsving': ('oppsving',),
'oppsvinga': ('oppsving',),
'oppsvingene': ('oppsving',),
'oppsvinget': ('oppsving',),
'oppsyn': ('oppsyn',),
'oppsyna': ('oppsyn',),
'oppsynene': ('oppsyn',),
'oppsynet': ('oppsyn',),
'oppsynsmann': ('oppsynsmann',),
'oppsynsmannen': ('oppsynsmann',),
'oppsynsmenn': ('oppsynsmann',),
'oppsynsmennene': ('oppsynsmann',),
'oppsynsskip': ('oppsynsskip',),
'oppsynsskipa': ('oppsynsskip',),
'oppsynsskipene': ('oppsynsskip',),
'oppsynsskipet': ('oppsynsskip',),
'opptaing': ('opptaing',),
'opptainga': ('opptaing',),
'opptaingen': ('opptaing',),
'opptaingene': ('opptaing',),
'opptainger': ('opptaing',),
'opptaingsprøva': ('opptaingsprøve',),
'opptaingsprøve': ('opptaingsprøve',),
'opptaingsprøven': ('opptaingsprøve',),
'opptaingsprøvene': ('opptaingsprøve',),
'opptaingsprøver': ('opptaingsprøve',),
'opptak': ('opptak',),
'opptaka': ('opptak',),
'opptakene': ('opptak',),
'opptaket': ('opptak',),
'opptakelse': ('opptakelse',),
'opptakelsen': ('opptakelse',),
'opptakelsene': ('opptakelse',),
'opptakelser': ('opptakelse',),
'opptakelsesprøva': ('opptakelsesprøve',),
'opptakelsesprøve': ('opptakelsesprøve',),
'opptakelsesprøven': ('opptakelsesprøve',),
'opptakelsesprøvene': ('opptakelsesprøve',),
'opptakelsesprøver': ('opptakelsesprøve',),
'opptaker': ('opptaker',),
'opptakere': ('opptaker',),
'opptakeren': ('opptaker',),
'opptakerer': ('opptaker',),
'opptakerne': ('opptaker',),
'opptaking': ('opptaking',),
'opptakinga': ('opptaking',),
'opptakingen': ('opptaking',),
'opptakingene': ('opptaking',),
'opptakinger': ('opptaking',),
'opptakingsprøva': ('opptakingsprøve',),
'opptakingsprøve': ('opptakingsprøve',),
'opptakingsprøven': ('opptakingsprøve',),
'opptakingsprøvene': ('opptakingsprøve',),
'opptakingsprøver': ('opptakingsprøve',),
'opptaksbok': ('opptaksbok',),
'opptaksboka': ('opptaksbok',),
'opptaksboken': ('opptaksbok',),
'opptaksbøkene': ('opptaksbok',),
'opptaksbøker': ('opptaksbok',),
'opptakt': ('opptakt',),
'opptakten': ('opptakt',),
'opptaktene': ('opptakt',),
'opptakter': ('opptakt',),
'opptegnelse': ('opptegnelse',),
'opptegnelsen': ('opptegnelse',),
'opptegnelsene': ('opptegnelse',),
'opptegnelser': ('opptegnelse',),
'opptelling': ('opptelling',),
'opptellinga': ('opptelling',),
'opptellingen': ('opptelling',),
'opptellingene': ('opptelling',),
'opptellinger': ('opptelling',),
'opptenningsved': ('opptenningsved',),
'opptenningsveden': ('opptenningsved',),
'opptenningsvedene': ('opptenningsved',),
'opptenningsveder': ('opptenningsved',),
'opptjeningstid': ('opptjeningstid',),
'opptjeningstida': ('opptjeningstid',),
'opptjeningstiden': ('opptjeningstid',),
'opptjeningstidene': ('opptjeningstid',),
'opptjeningstider': ('opptjeningstid',),
'opptog': ('opptog',),
'opptoga': ('opptog',),
'opptogene': ('opptog',),
'opptoget': ('opptog',),
'opptrapping': ('opptrapping',),
'opptrappinga': ('opptrapping',),
'opptrappingen': ('opptrapping',),
'opptrappingene': ('opptrapping',),
'opptrappinger': ('opptrapping',),
'opptreden': ('opptreden',),
'opptredenen': ('opptreden',),
'opptredenene': ('opptreden',),
'opptredener': ('opptreden',),
'opptrekk': ('opptrekk',),
'opptrekka': ('opptrekk',),
'opptrekkene': ('opptrekk',),
'opptrekket': ('opptrekk',),
'opptrekker': ('opptrekker',),
'opptrekkere': ('opptrekker',),
'opptrekkeren': ('opptrekker',),
'opptrekkerer': ('opptrekker',),
'opptrekkerne': ('opptrekker',),
'opptrekkeri': ('opptrekkeri',),
'opptrekkeria': ('opptrekkeri',),
'opptrekkeriene': ('opptrekkeri',),
'opptrekkerier': ('opptrekkeri',),
'opptrekkeriet': ('opptrekkeri',),
'opptrinn': ('opptrinn',),
'opptrinna': ('opptrinn',),
'opptrinnene': ('opptrinn',),
'opptrinnet': ('opptrinn',),
'opptrinnsrett': ('opptrinnsrett',),
'opptrinnsretten': ('opptrinnsrett',),
'opptrinnsrettene': ('opptrinnsrett',),
'opptrinnsretter': ('opptrinnsrett',),
'opptrykk': ('opptrykk',),
'opptrykka': ('opptrykk',),
'opptrykkene': ('opptrykk',),
'opptrykket': ('opptrykk',),
'opptuktelse': ('opptuktelse',),
'opptuktelsen': ('opptuktelse',),
'opptuktelsene': ('opptuktelse',),
'opptuktelser': ('opptuktelse',),
'opptur': ('opptur',),
'oppturen': ('opptur',),
'oppturene': ('opptur',),
'oppturer': ('opptur',),
'opptøyene': ('opptøyer',),
'opptøyer': ('opptøyer',),
'oppusning': ('oppusning',),
'oppusninga': ('oppusning',),
'oppusningen': ('oppusning',),
'oppusningene': ('oppusning',),
'oppusninger': ('oppusning',),
'oppussing': ('oppussing',),
'oppussinga': ('oppussing',),
'oppussingen': ('oppussing',),
'oppussingene': ('oppussing',),
'oppussinger': ('oppussing',),
'oppvarming': ('oppvarming',),
'oppvarminga': ('oppvarming',),
'oppvarmingen': ('oppvarming',),
'oppvarmingene': ('oppvarming',),
'oppvarminger': ('oppvarming',),
'oppvarter': ('oppvarter',),
'oppvartere': ('oppvarter',),
'oppvarteren': ('oppvarter',),
'oppvarterer': ('oppvarter',),
'oppvarterne': ('oppvarter',),
'oppvartning': ('oppvartning',),
'oppvartninga': ('oppvartning',),
'oppvartningen': ('oppvartning',),
'oppvartningene': ('oppvartning',),
'oppvartninger': ('oppvartning',),
'oppvask': ('oppvask',),
'oppvasken': ('oppvask',),
'oppvaskene': ('oppvask',),
'oppvasker': ('oppvask',),
'oppvaskbenk': ('oppvaskbenk',),
'oppvaskbenken': ('oppvaskbenk',),
'oppvaskbenkene': ('oppvaskbenk',),
'oppvaskbenker': ('oppvaskbenk',),
'oppvasker': ('oppvasker',),
'oppvaskere': ('oppvasker',),
'oppvaskeren': ('oppvasker',),
'oppvaskerer': ('oppvasker',),
'oppvaskerne': ('oppvasker',),
'oppvaskkum': ('oppvaskkum',),
'oppvaskkummen': ('oppvaskkum',),
'oppvaskkummene': ('oppvaskkum',),
'oppvaskkummer': ('oppvaskkum',),
'oppvaskmaskin': ('oppvaskmaskin',),
'oppvaskmaskina': ('oppvaskmaskin',),
'oppvaskmaskinen': ('oppvaskmaskin',),
'oppvaskmaskinene': ('oppvaskmaskin',),
'oppvaskmaskiner': ('oppvaskmaskin',),
'oppveg': ('oppveg',),
'oppvegen': ('oppveg',),
'oppvegene': ('oppveg',),
'oppveger': ('oppveg',),
'oppvei': ('oppvei',),
'oppveien': ('oppvei',),
'oppveiene': ('oppvei',),
'oppveier': ('oppvei',),
'oppvekst': ('oppvekst',),
'oppveksten': ('oppvekst',),
'oppvekstene': ('oppvekst',),
'oppvekster': ('oppvekst',),
'oppvekstmiljø': ('oppvekstmiljø',),
'oppvekstmiljøa': ('oppvekstmiljø',),
'oppvekstmiljøene': ('oppvekstmiljø',),
'oppvekstmiljøer': ('oppvekstmiljø',),
'oppvekstmiljøet': ('oppvekstmiljø',),
'oppvigler': ('oppvigler',),
'oppviglere': ('oppvigler',),
'oppvigleren': ('oppvigler',),
'oppviglerer': ('oppvigler',),
'oppviglerne': ('oppvigler',),
'oppvigleri': ('oppvigleri',),
'oppvigleria': ('oppvigleri',),
'oppvigleriene': ('oppvigleri',),
'oppviglerier': ('oppvigleri',),
'oppvigleriet': ('oppvigleri',),
'oppvind': ('oppvind',),
'oppvinden': ('oppvind',),
'oppvindene': ('oppvind',),
'oppvinder': ('oppvind',),
'oppvisning': ('oppvisning',),
'oppvisninga': ('oppvisning',),
'oppvisningen': ('oppvisning',),
'oppvisningene': ('oppvisning',),
'oppvisninger': ('oppvisning',),
'oppvisningskamp': ('oppvisningskamp',),
'oppvisningskampen': ('oppvisningskamp',),
'oppvisningskampene': ('oppvisningskamp',),
'oppvisningskamper': ('oppvisningskamp',),
'oppvisningsløp': ('oppvisningsløp',),
'oppvisningsløpa': ('oppvisningsløp',),
'oppvisningsløpene': ('oppvisningsløp',),
'oppvisningsløpet': ('oppvisningsløp',),
'oppvokster': ('oppvokster',),
'oppvokstere': ('oppvokster',),
'oppvoksteren': ('oppvokster',),
'oppvoksterer': ('oppvokster',),
'oppvoksterne': ('oppvokster',),
'oppvokstre': ('oppvokster',),
'oppvokstrene': ('oppvokster',),
'oppvokstrer': ('oppvokster',),
'opsjon': ('opsjon',),
'opsjonen': ('opsjon',),
'opsjonene': ('opsjon',),
'opsjoner': ('opsjon',),
'opsjonsrett': ('opsjonsrett',),
'opsjonsretten': ('opsjonsrett',),
'opsjonsrettene': ('opsjonsrett',),
'opsjonsretter': ('opsjonsrett',),
'optant': ('optant',),
'optanten': ('optant',),
'optantene': ('optant',),
'optanter': ('optant',),
'optativ': ('optativ',),
'optativen': ('optativ',),
'optativene': ('optativ',),
'optativer': ('optativ',),
'optiker': ('optiker',),
'optikere': ('optiker',),
'optikeren': ('optiker',),
'optikerer': ('optiker',),
'optikerne': ('optiker',),
'optikk': ('optikk',),
'optikken': ('optikk',),
'optikkene': ('optikk',),
'optikker': ('optikk',),
'optimisme': ('optimisme',),
'optimismen': ('optimisme',),
'optimismene': ('optimisme',),
'optimismer': ('optimisme',),
'optimist': ('optimist',),
'optimisten': ('optimist',),
'optimistene': ('optimist',),
'optimister': ('optimist',),
'optima': ('optimum',),
'optimaene': ('optimum',),
'optimum': ('optimum',),
'optimuma': ('optimum',),
'optimumene': ('optimum',),
'optimumer': ('optimum',),
'optimumet': ('optimum',),
'optometer': ('optometer',),
'optometeret': ('optometer',),
'optometra': ('optometer',),
'optometre': ('optometer',),
'optometrene': ('optometer',),
'optometret': ('optometer',),
'optometri': ('optometri',),
'optometrien': ('optometri',),
'optometriene': ('optometri',),
'optometrier': ('optometri',),
'opulens': ('opulens',),
'opulensen': ('opulens',),
'opulensene': ('opulens',),
'opulenser': ('opulens',),
'opus': ('opus',),
'opusa': ('opus',),
'opusene': ('opus',),
'opuset': ('opus',),
'opusnummer': ('opusnummer',),
'opusnummeret': ('opusnummer',),
'opusnumra': ('opusnummer',),
'opusnumre': ('opusnummer',),
'opusnumrene': ('opusnummer',),
'or': ('or',),
'ora': ('or',),
'oren': ('or',),
'orene': ('or',),
'orer': ('or',),
'orakel': ('orakel',),
'orakelet': ('orakel',),
'orakla': ('orakel',),
'oraklene': ('orakel',),
'orakler': ('orakel',),
'oraklet': ('orakel',),
'orakelsvar': ('orakelsvar',),
'orakelsvara': ('orakelsvar',),
'orakelsvarene': ('orakelsvar',),
'orakelsvaret': ('orakelsvar',),
'orangutang': ('orangutang',),
'orangutangen': ('orangutang',),
'orangutangene': ('orangutang',),
'orangutanger': ('orangutang',),
'oransje': ('oransje',),
'oransjen': ('oransje',),
'oransjene': ('oransje',),
'oransjer': ('oransje',),
'oransjeri': ('oransjeri',),
'oransjeria': ('oransjeri',),
'oransjeriene': ('oransjeri',),
'oransjerier': ('oransjeri',),
'oransjeriet': ('oransjeri',),
'orasjon': ('orasjon',),
'orasjonen': ('orasjon',),
'orasjonene': ('orasjon',),
'orasjoner': ('orasjon',),
'orator': ('orator',),
'oratoren': ('orator',),
'oratorene': ('orator',),
'oratorer': ('orator',),
'oratoria': ('oratorium',),
'oratoriene': ('oratorium',),
'oratorier': ('oratorium',),
'oratoriet': ('oratorium',),
'oratorium': ('oratorium',),
'ord': ('ord',),
'orda': ('ord',),
'ordene': ('ord',),
'ordet': ('ord',),
'ordavledning': ('ordavledning',),
'ordavledninga': ('ordavledning',),
'ordavledningen': ('ordavledning',),
'ordavledningene': ('ordavledning',),
'ordavledninger': ('ordavledning',),
'ordavleiing': ('ordavleiing',),
'ordavleiinga': ('ordavleiing',),
'ordavleiingen': ('ordavleiing',),
'ordavleiingene': ('ordavleiing',),
'ordavleiinger': ('ordavleiing',),
'ordbilda': ('ordbilde',),
'ordbilde': ('ordbilde',),
'ordbildene': ('ordbilde',),
'ordbilder': ('ordbilde',),
'ordbildet': ('ordbilde',),
'ordboksredaktør': ('ordboksredaktør',),
'ordboksredaktøren': ('ordboksredaktør',),
'ordboksredaktørene': ('ordboksredaktør',),
'ordboksredaktører': ('ordboksredaktør',),
'ordboksverk': ('ordboksverk',),
'ordboksverka': ('ordboksverk',),
'ordboksverkene': ('ordboksverk',),
'ordboksverker': ('ordboksverk',),
'ordboksverket': ('ordboksverk',),
'orddannelse': ('orddannelse',),
'orddannelsen': ('orddannelse',),
'orddannelsene': ('orddannelse',),
'orddannelser': ('orddannelse',),
'orddanning': ('orddanning',),
'orddanninga': ('orddanning',),
'orddanningen': ('orddanning',),
'orddanningene': ('orddanning',),
'orddanninger': ('orddanning',),
'ordelag': ('ordelag',),
'ordelaga': ('ordelag',),
'ordelagene': ('ordelag',),
'ordelaget': ('ordelag',),
'orden': ('orden',),
'ordenen': ('orden',),
'ordenene': ('orden',),
'ordener': ('orden',),
'ordensband': ('ordensband',),
'ordensbanda': ('ordensband',),
'ordensbandene': ('ordensband',),
'ordensbandet': ('ordensband',),
'ordensbror': ('ordensbror',),
'ordensbroren': ('ordensbror',),
'ordensbrødre': ('ordensbror',),
'ordensbrødrene': ('ordensbror',),
'ordensbånd': ('ordensbånd',),
'ordensbånda': ('ordensbånd',),
'ordensbåndene': ('ordensbånd',),
'ordensbåndet': ('ordensbånd',),
'ordenskarakter': ('ordenskarakter',),
'ordenskarakteren': ('ordenskarakter',),
'ordenskarakterene': ('ordenskarakter',),
'ordenskarakterer': ('ordenskarakter',),
'ordenskvinna': ('ordenskvinne',),
'ordenskvinne': ('ordenskvinne',),
'ordenskvinnen': ('ordenskvinne',),
'ordenskvinnene': ('ordenskvinne',),
'ordenskvinner': ('ordenskvinne',),
'ordensmann': ('ordensmann',),
'ordensmannen': ('ordensmann',),
'ordensmenn': ('ordensmann',),
'ordensmennene': ('ordensmann',),
'ordensmenneska': ('ordensmenneske',),
'ordensmenneske': ('ordensmenneske',),
'ordensmenneskene': ('ordensmenneske',),
'ordensmennesker': ('ordensmenneske',),
'ordensmennesket': ('ordensmenneske',),
'ordenspoliti': ('ordenspoliti',),
'ordenspolitia': ('ordenspoliti',),
'ordenspolitiene': ('ordenspoliti',),
'ordenspolitier': ('ordenspoliti',),
'ordenspolitiet': ('ordenspoliti',),
'ordensregel': ('ordensregel',),
'ordensregelen': ('ordensregel',),
'ordensreglene': ('ordensregel',),
'ordensregler': ('ordensregel',),
'ordenssans': ('ordenssans',),
'ordenssansen': ('ordenssans',),
'ordenssansene': ('ordenssans',),
'ordenssanser': ('ordenssans',),
'ordenssøster': ('ordenssøster',),
'ordenssøstera': ('ordenssøster',),
'ordenssøsteren': ('ordenssøster',),
'ordenssøstre': ('ordenssøster',),
'ordenssøstrene': ('ordenssøster',),
'ordenssøstrer': ('ordenssøster',),
'ordenstall': ('ordenstall',),
'ordenstalla': ('ordenstall',),
'ordenstallene': ('ordenstall',),
'ordenstallet': ('ordenstall',),
'ordensvern': ('ordensvern',),
'ordensverna': ('ordensvern',),
'ordensvernene': ('ordensvern',),
'ordensvernet': ('ordensvern',),
'ordfamilie': ('ordfamilie',),
'ordfamilien': ('ordfamilie',),
'ordfamiliene': ('ordfamilie',),
'ordfamilier': ('ordfamilie',),
'ordflom': ('ordflom',),
'ordflommen': ('ordflom',),
'ordflommene': ('ordflom',),
'ordflommer': ('ordflom',),
'ordforråd': ('ordforråd',),
'ordforråda': ('ordforråd',),
'ordforrådene': ('ordforråd',),
'ordforrådet': ('ordforråd',),
'ordfører': ('ordfører',),
'ordførere': ('ordfører',),
'ordføreren': ('ordfører',),
'ordførerer': ('ordfører',),
'ordførerne': ('ordfører',),
'ordføying': ('ordføying',),
'ordføyinga': ('ordføying',),
'ordføyingen': ('ordføying',),
'ordføyingene': ('ordføying',),
'ordføyinger': ('ordføying',),
'ordføyning': ('ordføyning',),
'ordføyninga': ('ordføyning',),
'ordføyningen': ('ordføyning',),
'ordføyningene': ('ordføyning',),
'ordføyninger': ('ordføyning',),
'ordgeografi': ('ordgeografi',),
'ordgeografien': ('ordgeografi',),
'ordgeografiene': ('ordgeografi',),
'ordgeografier': ('ordgeografi',),
'ordgyter': ('ordgyter',),
'ordgytere': ('ordgyter',),
'ordgyteren': ('ordgyter',),
'ordgyterer': ('ordgyter',),
'ordgyterne': ('ordgyter',),
'ordgyteri': ('ordgyteri',),
'ordgyteria': ('ordgyteri',),
'ordgyteriene': ('ordgyteri',),
'ordgyterier': ('ordgyteri',),
'ordgyteriet': ('ordgyteri',),
'ordinal': ('ordinal',),
'ordinala': ('ordinal',),
'ordinalene': ('ordinal',),
'ordinaler': ('ordinal',),
'ordinalet': ('ordinal',),
'ordinala': ('ordinale',),
'ordinale': ('ordinale',),
'ordinalene': ('ordinale',),
'ordinaler': ('ordinale',),
'ordinalet': ('ordinale',),
'ordinaltall': ('ordinaltall',),
'ordinaltalla': ('ordinaltall',),
'ordinaltallene': ('ordinaltall',),
'ordinaltallet': ('ordinaltall',),
'ordinand': ('ordinand',),
'ordinanden': ('ordinand',),
'ordinandene': ('ordinand',),
'ordinander': ('ordinand',),
'ordinans': ('ordinans',),
'ordinansen': ('ordinans',),
'ordinansene': ('ordinans',),
'ordinanser': ('ordinans',),
'ordinant': ('ordinant',),
'ordinanten': ('ordinant',),
'ordinantene': ('ordinant',),
'ordinanter': ('ordinant',),
'ordinasjon': ('ordinasjon',),
'ordinasjonen': ('ordinasjon',),
'ordinasjonene': ('ordinasjon',),
'ordinasjoner': ('ordinasjon',),
'ordinat': ('ordinat',),
'ordinaten': ('ordinat',),
'ordinatene': ('ordinat',),
'ordinater': ('ordinat',),
'ordinatakse': ('ordinatakse',),
'ordinataksen': ('ordinatakse',),
'ordinataksene': ('ordinatakse',),
'ordinatakser': ('ordinatakse',),
'ordklassa': ('ordklasse',),
'ordklasse': ('ordklasse',),
'ordklassen': ('ordklasse',),
'ordklassene': ('ordklasse',),
'ordklasser': ('ordklasse',),
'ordkløver': ('ordkløver',),
'ordkløvere': ('ordkløver',),
'ordkløveren': ('ordkløver',),
'ordkløverer': ('ordkløver',),
'ordkløverne': ('ordkløver',),
'ordkløveri': ('ordkløveri',),
'ordkløveria': ('ordkløveri',),
'ordkløveriene': ('ordkløveri',),
'ordkløverier': ('ordkløveri',),
'ordkløveriet': ('ordkløveri',),
'ordkløyver': ('ordkløyver',),
'ordkløyvere': ('ordkløyver',),
'ordkløyveren': ('ordkløyver',),
'ordkløyverer': ('ordkløyver',),
'ordkløyverne': ('ordkløyver',),
'ordkløyveri': ('ordkløyveri',),
'ordkløyveria': ('ordkløyveri',),
'ordkløyveriene': ('ordkløyveri',),
'ordkløyverier': ('ordkløyveri',),
'ordkløyveriet': ('ordkløyveri',),
'ordlaging': ('ordlaging',),
'ordlaginga': ('ordlaging',),
'ordlagingen': ('ordlaging',),
'ordlagingene': ('ordlaging',),
'ordlaginger': ('ordlaging',),
'ordlista': ('ordliste',),
'ordliste': ('ordliste',),
'ordlisten': ('ordliste',),
'ordlistene': ('ordliste',),
'ordlister': ('ordliste',),
'ordlyd': ('ordlyd',),
'ordlyden': ('ordlyd',),
'ordlydene': ('ordlyd',),
'ordlyder': ('ordlyd',),
'ordlæra': ('ordlære',),
'ordlære': ('ordlære',),
'ordlæren': ('ordlære',),
'ordlærene': ('ordlære',),
'ordlærer': ('ordlære',),
'ordmagi': ('ordmagi',),
'ordmagien': ('ordmagi',),
'ordmagiene': ('ordmagi',),
'ordmagier': ('ordmagi',),
'ordning': ('ordning',),
'ordninga': ('ordning',),
'ordningen': ('ordning',),
'ordningene': ('ordning',),
'ordninger': ('ordning',),
'ordonnans': ('ordonnans',),
'ordonnansen': ('ordonnans',),
'ordonnansene': ('ordonnans',),
'ordonnanser': ('ordonnans',),
'ordovicium': ('ordovicium',),
'ordoviciumen': ('ordovicium',),
'ordoviciumene': ('ordovicium',),
'ordoviciumer': ('ordovicium',),
'ordoviciumformasjon': ('ordoviciumformasjon',),
'ordoviciumformasjonen': ('ordoviciumformasjon',),
'ordoviciumformasjonene': ('ordoviciumformasjon',),
'ordoviciumformasjoner': ('ordoviciumformasjon',),
'ordoviciumperiode': ('ordoviciumperiode',),
'ordoviciumperioden': ('ordoviciumperiode',),
'ordoviciumperiodene': ('ordoviciumperiode',),
'ordoviciumperioder': ('ordoviciumperiode',),
'ordoviciumsystem': ('ordoviciumsystem',),
'ordoviciumsystema': ('ordoviciumsystem',),
'ordoviciumsystemene': ('ordoviciumsystem',),
'ordoviciumsystemer': ('ordoviciumsystem',),
'ordoviciumsystemet': ('ordoviciumsystem',),
'ordre': ('ordre',),
'ordren': ('ordre',),
'ordrene': ('ordre',),
'ordrer': ('ordre',),
'ordreinngang': ('ordreinngang',),
'ordreinngangen': ('ordreinngang',),
'ordreinngangene': ('ordreinngang',),
'ordreinnganger': ('ordreinngang',),
'ordreklausul': ('ordreklausul',),
'ordreklausulen': ('ordreklausul',),
'ordreklausulene': ('ordreklausul',),
'ordreklausuler': ('ordreklausul',),
'ordrenekt': ('ordrenekt',),
'ordrenekten': ('ordrenekt',),
'ordrenektene': ('ordrenekt',),
'ordrenekter': ('ordrenekt',),
'ordrenektelse': ('ordrenektelse',),
'ordrenektelsen': ('ordrenektelse',),
'ordrenektelsene': ('ordrenektelse',),
'ordrenektelser': ('ordrenektelse',),
'ordrenekting': ('ordrenekting',),
'ordrenektinga': ('ordrenekting',),
'ordrenektingen': ('ordrenekting',),
'ordrenektingene': ('ordrenekting',),
'ordrenektinger': ('ordrenekting',),
'ordrereserve': ('ordrereserve',),
'ordrereserven': ('ordrereserve',),
'ordrereservene': ('ordrereserve',),
'ordrereserver': ('ordrereserve',),
'ordretilgang': ('ordretilgang',),
'ordretilgangen': ('ordretilgang',),
'ordretilgangene': ('ordretilgang',),
'ordretilganger': ('ordretilgang',),
'ordskifta': ('ordskifte',),
'ordskifte': ('ordskifte',),
'ordskiftene': ('ordskifte',),
'ordskifter': ('ordskifte',),
'ordskiftet': ('ordskifte',),
'ordskrift': ('ordskrift',),
'ordskrifta': ('ordskrift',),
'ordskriften': ('ordskrift',),
'ordskriftene': ('ordskrift',),
'ordskrifter': ('ordskrift',),
'ordspill': ('ordspill',),
'ordspilla': ('ordspill',),
'ordspillene': ('ordspill',),
'ordspillet': ('ordspill',),
'ordspråk': ('ordspråk',),
'ordspråka': ('ordspråk',),
'ordspråkene': ('ordspråk',),
'ordspråket': ('ordspråk',),
'ordstilling': ('ordstilling',),
'ordstillinga': ('ordstilling',),
'ordstillingen': ('ordstilling',),
'ordstillingene': ('ordstilling',),
'ordstillinger': ('ordstilling',),
'ordstyrer': ('ordstyrer',),
'ordstyrere': ('ordstyrer',),
'ordstyreren': ('ordstyrer',),
'ordstyrerer': ('ordstyrer',),
'ordstyrerne': ('ordstyrer',),
'ordtak': ('ordtak',),
'ordtaka': ('ordtak',),
'ordtakene': ('ordtak',),
'ordtaket': ('ordtak',),
'ordtilfang': ('ordtilfang',),
'ordtilfanga': ('ordtilfang',),
'ordtilfangene': ('ordtilfang',),
'ordtilfanget': ('ordtilfang',),
'ordtone': ('ordtone',),
'ordtonen': ('ordtone',),
'ordtonene': ('ordtone',),
'ordtoner': ('ordtone',),
'ordtøka': ('ordtøke',),
'ordtøke': ('ordtøke',),
'ordtøkene': ('ordtøke',),
'ordtøker': ('ordtøke',),
'ordtøket': ('ordtøke',),
'ora': ('ore',),
'ore': ('ore',),
'oren': ('ore',),
'orene': ('ore',),
'orer': ('ore',),
'oregano': ('oregano',),
'oreganoen': ('oregano',),
'oreganoene': ('oregano',),
'oreganoer': ('oregano',),
'oreigning': ('oreigning',),
'oreigninga': ('oreigning',),
'oreigningen': ('oreigning',),
'oreigningene': ('oreigning',),
'oreigninger': ('oreigning',),
'orekratt': ('orekratt',),
'orekratta': ('orekratt',),
'orekrattene': ('orekratt',),
'orekrattet': ('orekratt',),
'organ': ('organ',),
'organa': ('organ',),
'organene': ('organ',),
'organer': ('organ',),
'organet': ('organ',),
'organdi': ('organdi',),
'organdien': ('organdi',),
'organdiene': ('organdi',),
'organdier': ('organdi',),
'organell': ('organell',),
'organellen': ('organell',),
'organellene': ('organell',),
'organeller': ('organell',),
'organiker': ('organiker',),
'organikere': ('organiker',),
'organikeren': ('organiker',),
'organikerer': ('organiker',),
'organikerne': ('organiker',),
'organisasjon': ('organisasjon',),
'organisasjonen': ('organisasjon',),
'organisasjonene': ('organisasjon',),
'organisasjoner': ('organisasjon',),
'organisasjonsapparat': ('organisasjonsapparat',),
'organisasjonsapparata': ('organisasjonsapparat',),
'organisasjonsapparatene': ('organisasjonsapparat',),
'organisasjonsapparater': ('organisasjonsapparat',),
'organisasjonsapparatet': ('organisasjonsapparat',),
'organisasjonsfrihet': ('organisasjonsfrihet',),
'organisasjonsfriheta': ('organisasjonsfrihet',),
'organisasjonsfriheten': ('organisasjonsfrihet',),
'organisasjonsfrihetene': ('organisasjonsfrihet',),
'organisasjonsfriheter': ('organisasjonsfrihet',),
'organisator': ('organisator',),
'organisatoren': ('organisator',),
'organisatorene': ('organisator',),
'organisatorer': ('organisator',),
'organisme': ('organisme',),
'organismen': ('organisme',),
'organismene': ('organisme',),
'organismer': ('organisme',),
'organist': ('organist',),
'organisten': ('organist',),
'organistene': ('organist',),
'organister': ('organist',),
'organsin': ('organsin',),
'organsinen': ('organsin',),
'organsinene': ('organsin',),
'organsiner': ('organsin',),
'organsinsilke': ('organsinsilke',),
'organsinsilken': ('organsinsilke',),
'organsinsilkene': ('organsinsilke',),
'organsinsilker': ('organsinsilke',),
'orgasme': ('orgasme',),
'orgasmen': ('orgasme',),
'orgasmene': ('orgasme',),
'orgasmer': ('orgasme',),
'orgel': ('orgel',),
'orgelet': ('orgel',),
'orgla': ('orgel',),
'orglene': ('orgel',),
'orgler': ('orgel',),
'orglet': ('orgel',),
'orgelbøya': ('orgelbøye',),
'orgelbøye': ('orgelbøye',),
'orgelbøyen': ('orgelbøye',),
'orgelbøyene': ('orgelbøye',),
'orgelbøyer': ('orgelbøye',),
'orgelpunkt': ('orgelpunkt',),
'orgelpunkta': ('orgelpunkt',),
'orgelpunktene': ('orgelpunkt',),
'orgelpunkter': ('orgelpunkt',),
'orgelpunktet': ('orgelpunkt',),
'orgie': ('orgie',),
'orgien': ('orgie',),
'orgiene': ('orgie',),
'orgier': ('orgie',),
'orient': ('orient',),
'orienten': ('orient',),
'orientene': ('orient',),
'orienter': ('orient',),
'orientaler': ('orientaler',),
'orientalere': ('orientaler',),
'orientaleren': ('orientaler',),
'orientalerer': ('orientaler',),
'orientalerne': ('orientaler',),
'orientalist': ('orientalist',),
'orientalisten': ('orientalist',),
'orientalistene': ('orientalist',),
'orientalister': ('orientalist',),
'orienterer': ('orienterer',),
'orienterere': ('orienterer',),
'orientereren': ('orienterer',),
'orientererer': ('orienterer',),
'orientererne': ('orienterer',),
'orientering': ('orientering',),
'orienteringa': ('orientering',),
'orienteringen': ('orientering',),
'orienteringene': ('orientering',),
'orienteringer': ('orientering',),
'orienteringsfag': ('orienteringsfag',),
'orienteringsfaga': ('orienteringsfag',),
'orienteringsfagene': ('orienteringsfag',),
'orienteringsfaget': ('orienteringsfag',),
'orienteringsløp': ('orienteringsløp',),
'orienteringsløpa': ('orienteringsløp',),
'orienteringsløpene': ('orienteringsløp',),
'orienteringsløpet': ('orienteringsløp',),
'orienteringsløper': ('orienteringsløper',),
'orienteringsløpere': ('orienteringsløper',),
'orienteringsløperen': ('orienteringsløper',),
'orienteringsløperer': ('orienteringsløper',),
'orienteringsløperne': ('orienteringsløper',),
'original': ('original',),
'originalen': ('original',),
'originalene': ('original',),
'originaler': ('original',),
'originalitet': ('originalitet',),
'originaliteten': ('originalitet',),
'originalitetene': ('originalitet',),
'originaliteter': ('originalitet',),
'originalspråk': ('originalspråk',),
'originalspråka': ('originalspråk',),
'originalspråkene': ('originalspråk',),
'originalspråket': ('originalspråk',),
'originalutgava': ('originalutgave',),
'originalutgave': ('originalutgave',),
'originalutgaven': ('originalutgave',),
'originalutgavene': ('originalutgave',),
'originalutgaver': ('originalutgave',),
'origo': ('origo',),
'origoen': ('origo',),
'origoene': ('origo',),
'origoer': ('origo',),
'ork': ('ork',),
'orka': ('ork',),
'orkene': ('ork',),
'orket': ('ork',),
'orkan': ('orkan',),
'orkanen': ('orkan',),
'orkanene': ('orkan',),
'orkaner': ('orkan',),
'orkester': ('orkester',),
'orkesteret': ('orkester',),
'orkestra': ('orkester',),
'orkestre': ('orkester',),
'orkestrene': ('orkester',),
'orkestret': ('orkester',),
'orkestergrav': ('orkestergrav',),
'orkestergrava': ('orkestergrav',),
'orkestergraven': ('orkestergrav',),
'orkestergravene': ('orkestergrav',),
'orkestergraver': ('orkestergrav',),
'orkesterplass': ('orkesterplass',),
'orkesterplassen': ('orkesterplass',),
'orkesterplassene': ('orkesterplass',),
'orkesterplasser': ('orkesterplass',),
'orkideen': ('orkidé',),
'orkideene': ('orkidé',),
'orkideer': ('orkidé',),
'orkidé': ('orkidé',),
'orkidéen': ('orkidé',),
'orkidéene': ('orkidé',),
'orkidéer': ('orkidé',),
'orknøying': ('orknøying',),
'orknøyingen': ('orknøying',),
'orknøyingene': ('orknøying',),
'orknøyinger': ('orknøying',),
'orlean': ('orlean',),
'orleanen': ('orlean',),
'orleanene': ('orlean',),
'orleaner': ('orlean',),
'orleantre': ('orleantre',),
'orleantrea': ('orleantre',),
'orleantreet': ('orleantre',),
'orleantrær': ('orleantre',),
'orleantrærne': ('orleantre',),
'orlog': ('orlog',),
'orlogen': ('orlog',),
'orlogene': ('orlog',),
'orloger': ('orlog',),
'orlogsflagg': ('orlogsflagg',),
'orlogsflagga': ('orlogsflagg',),
'orlogsflaggene': ('orlogsflagg',),
'orlogsflagget': ('orlogsflagg',),
'orlogsgast': ('orlogsgast',),
'orlogsgasten': ('orlogsgast',),
'orlogsgastene': ('orlogsgast',),
'orlogsgaster': ('orlogsgast',),
'orlogskaptein': ('orlogskaptein',),
'orlogskapteinen': ('orlogskaptein',),
'orlogskapteinene': ('orlogskaptein',),
'orlogskapteiner': ('orlogskaptein',),
'orlogsskip': ('orlogsskip',),
'orlogsskipa': ('orlogsskip',),
'orlogsskipene': ('orlogsskip',),
'orlogsskipet': ('orlogsskip',),
'orlogsvimpel': ('orlogsvimpel',),
'orlogsvimpelen': ('orlogsvimpel',),
'orlogsvimplene': ('orlogsvimpel',),
'orlogsvimpler': ('orlogsvimpel',),
'orlon': ('orlon',),
'orlona': ('orlon',),
'orlonene': ('orlon',),
'orlonet': ('orlon',),
'orlov': ('orlov',),
'orloven': ('orlov',),
'orlovene': ('orlov',),
'orlover': ('orlov',),
'orm': ('orm',),
'ormen': ('orm',),
'ormene': ('orm',),
'ormer': ('orm',),
'ormebitt': ('ormebitt',),
'ormebitta': ('ormebitt',),
'ormebittene': ('ormebitt',),
'ormebittet': ('ormebitt',),
'ormeblikk': ('ormeblikk',),
'ormeblikka': ('ormeblikk',),
'ormeblikkene': ('ormeblikk',),
'ormeblikket': ('ormeblikk',),
'ormebol': ('ormebol',),
'ormebola': ('ormebol',),
'ormebolene': ('ormebol',),
'ormebolet': ('ormebol',),
'ormebøla': ('ormebøle',),
'ormebøle': ('ormebøle',),
'ormebølene': ('ormebøle',),
'ormebøler': ('ormebøle',),
'ormebølet': ('ormebøle',),
'ormegard': ('ormegard',),
'ormegarden': ('ormegard',),
'ormegardene': ('ormegard',),
'ormegarder': ('ormegard',),
'ormegras': ('ormegras',),
'ormegrasa': ('ormegras',),
'ormegrasene': ('ormegras',),
'ormegraset': ('ormegras',),
'ormegress': ('ormegress',),
'ormegressa': ('ormegress',),
'ormegressene': ('ormegress',),
'ormegresset': ('ormegress',),
'ormegård': ('ormegård',),
'ormegården': ('ormegård',),
'ormegårdene': ('ormegård',),
'ormegårder': ('ormegård',),
'ormetelg': ('ormetelg',),
'ormetelgen': ('ormetelg',),
'ormetelgene': ('ormetelg',),
'ormetelger': ('ormetelg',),
'ormeunge': ('ormeunge',),
'ormeungen': ('ormeunge',),
'ormeungene': ('ormeunge',),
'ormeunger': ('ormeunge',),
'ormunge': ('ormunge',),
'ormungen': ('ormunge',),
'ormungene': ('ormunge',),
'ormunger': ('ormunge',),
'ornament': ('ornament',),
'ornamenta': ('ornament',),
'ornamentene': ('ornament',),
'ornamenter': ('ornament',),
'ornamentet': ('ornament',),
'ornamentikk': ('ornamentikk',),
'ornamentikken': ('ornamentikk',),
'ornamentikkene': ('ornamentikk',),
'ornamentikker': ('ornamentikk',),
'ornat': ('ornat',),
'ornata': ('ornat',),
'ornatene': ('ornat',),
'ornatet': ('ornat',),
'ornitolog': ('ornitolog',),
'ornitologen': ('ornitolog',),
'ornitologene': ('ornitolog',),
'ornitologer': ('ornitolog',),
'ornitologi': ('ornitologi',),
'ornitologien': ('ornitologi',),
'ornitologiene': ('ornitologi',),
'ornitologier': ('ornitologi',),
'orre': ('orre',),
'orren': ('orre',),
'orrene': ('orre',),
'orrer': ('orre',),
'orreleik': ('orreleik',),
'orreleiken': ('orreleik',),
'orreleikene': ('orreleik',),
'orreleiker': ('orreleik',),
'orrfugl': ('orrfugl',),
'orrfuglen': ('orrfugl',),
'orrfuglene': ('orrfugl',),
'orrfugler': ('orrfugl',),
'orrhane': ('orrhane',),
'orrhanen': ('orrhane',),
'orrhanene': ('orrhane',),
'orrhaner': ('orrhane',),
'orrhøna': ('orrhøne',),
'orrhøne': ('orrhøne',),
'orrhønen': ('orrhøne',),
'orrhønene': ('orrhøne',),
'orrhøner': ('orrhøne',),
'orskurd': ('orskurd',),
'orskurden': ('orskurd',),
'orskurdene': ('orskurd',),
'orskurder': ('orskurd',),
'ort': ('ort',),
'orten': ('ort',),
'ortene': ('ort',),
'orter': ('ort',),
'ort': ('ort',),
'orta': ('ort',),
'orten': ('ort',),
'ortene': ('ort',),
'orter': ('ort',),
'ortodoksi': ('ortodoksi',),
'ortodoksien': ('ortodoksi',),
'ortodoksiene': ('ortodoksi',),
'ortodoksier': ('ortodoksi',),
'ortodonti': ('ortodonti',),
'ortodontien': ('ortodonti',),
'ortodontiene': ('ortodonti',),
'ortodontier': ('ortodonti',),
'ortofoni': ('ortofoni',),
'ortofonien': ('ortofoni',),
'ortofoniene': ('ortofoni',),
'ortofonier': ('ortofoni',),
'ortografi': ('ortografi',),
'ortografien': ('ortografi',),
'ortografiene': ('ortografi',),
'ortografier': ('ortografi',),
'ortoped': ('ortoped',),
'ortopeden': ('ortoped',),
'ortopedene': ('ortoped',),
'ortopeder': ('ortoped',),
'ortopedi': ('ortopedi',),
'ortopedien': ('ortopedi',),
'ortopediene': ('ortopedi',),
'ortopedier': ('ortopedi',),
'orv': ('orv',),
'orva': ('orv',),
'orvene': ('orv',),
'orvet': ('orv',),
'os': ('os',),
'osen': ('os',),
'osene': ('os',),
'oser': ('os',),
'os': ('os',),
'osa': ('os',),
'osen': ('os',),
'osene': ('os',),
'oser': ('os',),
'oset': ('os',),
'oscillasjon': ('oscillasjon',),
'oscillasjonen': ('oscillasjon',),
'oscillasjonene': ('oscillasjon',),
'oscillasjoner': ('oscillasjon',),
'oscillator': ('oscillator',),
'oscillatoren': ('oscillator',),
'oscillatorene': ('oscillator',),
'oscillatorer': ('oscillator',),
'oscillograf': ('oscillograf',),
'oscillografen': ('oscillograf',),
'oscillografene': ('oscillograf',),
'oscillografer': ('oscillograf',),
'oscillogram': ('oscillogram',),
'oscillogramma': ('oscillogram',),
'oscillogrammene': ('oscillogram',),
'oscillogrammer': ('oscillogram',),
'oscillogrammet': ('oscillogram',),
'oscilloskop': ('oscilloskop',),
'oscilloskopa': ('oscilloskop',),
'oscilloskopene': ('oscilloskop',),
'oscilloskoper': ('oscilloskop',),
'oscilloskopet': ('oscilloskop',),
'osean': ('osean',),
'oseana': ('osean',),
'oseanene': ('osean',),
'oseaner': ('osean',),
'oseanet': ('osean',),
'oseandamper': ('oseandamper',),
'oseandampere': ('oseandamper',),
'oseandamperen': ('oseandamper',),
'oseandamperer': ('oseandamper',),
'oseandamperne': ('oseandamper',),
'oseanografi': ('oseanografi',),
'oseanografien': ('oseanografi',),
'oseanografiene': ('oseanografi',),
'oseanografier': ('oseanografi',),
'oska': ('oske',),
'oske': ('oske',),
'osken': ('oske',),
'oskene': ('oske',),
'osker': ('oske',),
'oska': ('oske',),
'oske': ('oske',),
'osken': ('oske',),
'oskene': ('oske',),
'osker': ('oske',),
'oskebeger': ('oskebeger',),
'oskebegeret': ('oskebeger',),
'oskebegra': ('oskebeger',),
'oskebegre': ('oskebeger',),
'oskebegrene': ('oskebeger',),
'oskebeger': ('oskebeger',),
'oskebegeret': ('oskebeger',),
'oskebegra': ('oskebeger',),
'oskebegre': ('oskebeger',),
'oskebegrene': ('oskebeger',),
'oskeladd': ('oskeladd',),
'oskeladden': ('oskeladd',),
'oskeladdene': ('oskeladd',),
'oskeladder': ('oskeladd',),
'oskeladd': ('oskeladd',),
'oskeladden': ('oskeladd',),
'oskeladdene': ('oskeladd',),
'oskeladder': ('oskeladd',),
'oskeonsdag': ('oskeonsdag',),
'oskeonsdagen': ('oskeonsdag',),
'oskeonsdagene': ('oskeonsdag',),
'oskeonsdager': ('oskeonsdag',),
'oskeonsdag': ('oskeonsdag',),
'oskeonsdagen': ('oskeonsdag',),
'oskeonsdagene': ('oskeonsdag',),
'oskeonsdager': ('oskeonsdag',),
'oskepott': ('oskepott',),
'oskepotten': ('oskepott',),
'oskepottene': ('oskepott',),
'oskepotter': ('oskepott',),
'oskepott': ('oskepott',),
'oskepotten': ('oskepott',),
'oskepottene': ('oskepott',),
'oskepotter': ('oskepott',),
'oskjell': ('oskjell',),
'oskjella': ('oskjell',),
'oskjellen': ('oskjell',),
'oskjellene': ('oskjell',),
'oskjellet': ('oskjell',),
'oskorei': ('oskorei',),
'oskoreia': ('oskorei',),
'oskoreien': ('oskorei',),
'oskoreiene': ('oskorei',),
'oskoreier': ('oskorei',),
'osloenser': ('osloenser',),
'osloensere': ('osloenser',),
'osloenseren': ('osloenser',),
'osloenserer': ('osloenser',),
'osloenserne': ('osloenser',),
'oslofrokost': ('oslofrokost',),
'oslofrokosten': ('oslofrokost',),
'oslofrokostene': ('oslofrokost',),
'oslofrokoster': ('oslofrokost',),
'osman': ('osman',),
'osmanen': ('osman',),
'osmanene': ('osman',),
'osmaner': ('osman',),
'osmium': ('osmium',),
'osmiuma': ('osmium',),
'osmiumene': ('osmium',),
'osmiumet': ('osmium',),
'osmose': ('osmose',),
'osmosen': ('osmose',),
'osmosene': ('osmose',),
'osmoser': ('osmose',),
'osp': ('osp',),
'ospa': ('osp',),
'ospen': ('osp',),
'ospene': ('osp',),
'osper': ('osp',),
'ospelauv': ('ospelauv',),
'ospelauva': ('ospelauv',),
'ospelauvene': ('ospelauv',),
'ospelauvet': ('ospelauv',),
'ospeløv': ('ospeløv',),
'ospeløva': ('ospeløv',),
'ospeløvene': ('ospeløv',),
'ospeløvet': ('ospeløv',),
'osset': ('osset',),
'osseten': ('osset',),
'ossetene': ('osset',),
'osseter': ('osset',),
'osseter': ('osseter',),
'ossetere': ('osseter',),
'osseteren': ('osseter',),
'osseterer': ('osseter',),
'osseterne': ('osseter',),
'ossetisk': ('ossetisk',),
'ossetisken': ('ossetisk',),
'ossetiskene': ('ossetisk',),
'ossetisker': ('ossetisk',),
'ost': ('ost',),
'osten': ('ost',),
'ostene': ('ost',),
'oster': ('ost',),
'ost': ('ost',),
'ostehøvel': ('ostehøvel',),
'ostehøvelen': ('ostehøvel',),
'ostehøvlene': ('ostehøvel',),
'ostehøvler': ('ostehøvel',),
'osteklokka': ('osteklokke',),
'osteklokke': ('osteklokke',),
'osteklokken': ('osteklokke',),
'osteklokkene': ('osteklokke',),
'osteklokker': ('osteklokke',),
'osteløype': ('osteløype',),
'osteløypen': ('osteløype',),
'osteløypene': ('osteløype',),
'osteløyper': ('osteløype',),
'ostemasse': ('ostemasse',),
'ostemassen': ('ostemasse',),
'ostemassene': ('ostemasse',),
'ostemasser': ('ostemasse',),
'osteologi': ('osteologi',),
'osteologien': ('osteologi',),
'osteologiene': ('osteologi',),
'osteologier': ('osteologi',),
'osteoplastikk': ('osteoplastikk',),
'osteoplastikken': ('osteoplastikk',),
'osteoplastikkene': ('osteoplastikk',),
'osteoplastikker': ('osteoplastikk',),
'osteri': ('osteri',),
'osteria': ('osteri',),
'osteriene': ('osteri',),
'osterier': ('osteri',),
'osteriet': ('osteri',),
'ostestoff': ('ostestoff',),
'ostestoffa': ('ostestoff',),
'ostestoffene': ('ostestoff',),
'ostestoffet': ('ostestoff',),
'ostrakisme': ('ostrakisme',),
'ostrakismen': ('ostrakisme',),
'ostrakismene': ('ostrakisme',),
'ostrakismer': ('ostrakisme',),
'oter': ('oter',),
'otere': ('oter',),
'oteren': ('oter',),
'oterne': ('oter',),
'otre': ('oter',),
'otrene': ('oter',),
'otrer': ('oter',),
'oterfjel': ('oterfjel',),
'oterfjela': ('oterfjel',),
'oterfjelen': ('oterfjel',),
'oterfjelene': ('oterfjel',),
'oterfjeler': ('oterfjel',),
'oterfjøl': ('oterfjøl',),
'oterfjøla': ('oterfjøl',),
'oterfjølen': ('oterfjøl',),
'oterfjølene': ('oterfjøl',),
'oterfjøler': ('oterfjøl',),
'otiatri': ('otiatri',),
'otiatrien': ('otiatri',),
'otiatriene': ('otiatri',),
'otiatrier': ('otiatri',),
'otia': ('otium',),
'otiene': ('otium',),
'otier': ('otium',),
'otiet': ('otium',),
'otium': ('otium',),
'otiumet': ('otium',),
'otologi': ('otologi',),
'otologien': ('otologi',),
'otologiene': ('otologi',),
'otologier': ('otologi',),
'otte': ('otte',),
'otten': ('otte',),
'ottene': ('otte',),
'otter': ('otte',),
'otta': ('otte',),
'otte': ('otte',),
'otten': ('otte',),
'ottene': ('otte',),
'otter': ('otte',),
'ottesang': ('ottesang',),
'ottesangen': ('ottesang',),
'ottesangene': ('ottesang',),
'ottesanger': ('ottesang',),
'ottoman': ('ottoman',),
'ottomanen': ('ottoman',),
'ottomanene': ('ottoman',),
'ottomaner': ('ottoman',),
'ounce': ('ounce',),
'ouncen': ('ounce',),
'ouncene': ('ounce',),
'ouncer': ('ounce',),
'outboard': ('outboard',),
'outboarden': ('outboard',),
'outboardene': ('outboard',),
'outboarder': ('outboard',),
'outboardmotor': ('outboardmotor',),
'outboardmotoren': ('outboardmotor',),
'outboardmotorene': ('outboardmotor',),
'outboardmotorer': ('outboardmotor',),
'output': ('output',),
'outputen': ('output',),
'outputene': ('output',),
'outputer': ('output',),
'outrigger': ('outrigger',),
'outriggere': ('outrigger',),
'outriggeren': ('outrigger',),
'outriggerer': ('outrigger',),
'outriggerne': ('outrigger',),
'outsider': ('outsider',),
'outsidere': ('outsider',),
'outsideren': ('outsider',),
'outsiderer': ('outsider',),
'outsiderne': ('outsider',),
'ouverture': ('ouverture',),
'ouverturen': ('ouverture',),
'ouverturene': ('ouverture',),
'ouverturer': ('ouverture',),
'ouzo': ('ouzo',),
'ouzoen': ('ouzo',),
'ouzoene': ('ouzo',),
'ouzoer': ('ouzo',),
'oval': ('oval',),
'ovalen': ('oval',),
'ovalene': ('oval',),
'ovaler': ('oval',),
'ovarenn': ('ovarenn',),
'ovarenna': ('ovarenn',),
'ovarennene': ('ovarenn',),
'ovarennet': ('ovarenn',),
'ovaria': ('ovarium',),
'ovariene': ('ovarium',),
'ovarier': ('ovarium',),
'ovariet': ('ovarium',),
'ovarium': ('ovarium',),
'ovasjon': ('ovasjon',),
'ovasjonen': ('ovasjon',),
'ovasjonene': ('ovasjon',),
'ovasjoner': ('ovasjon',),
'overall': ('overall',),
'overallen': ('overall',),
'overallene': ('overall',),
'overaller': ('overall',),
'overanstrengelse': ('overanstrengelse',),
'overanstrengelsen': ('overanstrengelse',),
'overanstrengelsene': ('overanstrengelse',),
'overanstrengelser': ('overanstrengelse',),
'overarm': ('overarm',),
'overarmen': ('overarm',),
'overarmene': ('overarm',),
'overarmer': ('overarm',),
'overbalanse': ('overbalanse',),
'overbalansen': ('overbalanse',),
'overbalansene': ('overbalanse',),
'overbalanser': ('overbalanse',),
'overbefolkning': ('overbefolkning',),
'overbefolkninga': ('overbefolkning',),
'overbefolkningen': ('overbefolkning',),
'overbefolkningene': ('overbefolkning',),
'overbefolkninger': ('overbefolkning',),
'overbeskatning': ('overbeskatning',),
'overbeskatninga': ('overbeskatning',),
'overbeskatningen': ('overbeskatning',),
'overbeskatningene': ('overbeskatning',),
'overbeskatninger': ('overbeskatning',),
'overbetjent': ('overbetjent',),
'overbetjenten': ('overbetjent',),
'overbetjentene': ('overbetjent',),
'overbetjenter': ('overbetjent',),
'overbevisning': ('overbevisning',),
'overbevisninga': ('overbevisning',),
'overbevisningen': ('overbevisning',),
'overbevisningene': ('overbevisning',),
'overbevisninger': ('overbevisning',),
'overbitt': ('overbitt',),
'overbitta': ('overbitt',),
'overbittene': ('overbitt',),
'overbittet': ('overbitt',),
'overblikk': ('overblikk',),
'overblikka': ('overblikk',),
'overblikkene': ('overblikk',),
'overblikket': ('overblikk',),
'overbredsel': ('overbredsel',),
'overbredselet': ('overbredsel',),
'overbredsla': ('overbredsel',),
'overbredslene': ('overbredsel',),
'overbredsler': ('overbredsel',),
'overbredslet': ('overbredsel',),
'overbud': ('overbud',),
'overbuda': ('overbud',),
'overbudene': ('overbud',),
'overbudet': ('overbud',),
'overbudspolitikk': ('overbudspolitikk',),
'overbudspolitikken': ('overbudspolitikk',),
'overbudspolitikkene': ('overbudspolitikk',),
'overbudspolitikker': ('overbudspolitikk',),
'overbygg': ('overbygg',),
'overbygga': ('overbygg',),
'overbyggene': ('overbygg',),
'overbygget': ('overbygg',),
'overbygning': ('overbygning',),
'overbygninga': ('overbygning',),
'overbygningen': ('overbygning',),
'overbygningene': ('overbygning',),
'overbygninger': ('overbygning',),
'overbærenhet': ('overbærenhet',),
'overbærenheta': ('overbærenhet',),
'overbærenheten': ('overbærenhet',),
'overbærenhetene': ('overbærenhet',),
'overbærenheter': ('overbærenhet',),
'overdekk': ('overdekk',),
'overdekka': ('overdekk',),
'overdekkene': ('overdekk',),
'overdekket': ('overdekk',),
'overdel': ('overdel',),
'overdelen': ('overdel',),
'overdelene': ('overdel',),
'overdeler': ('overdel',),
'overdommer': ('overdommer',),
'overdommere': ('overdommer',),
'overdommeren': ('overdommer',),
'overdommerer': ('overdommer',),
'overdommerne': ('overdommer',),
'overdose': ('overdose',),
'overdosen': ('overdose',),
'overdosene': ('overdose',),
'overdoser': ('overdose',),
'overdrag': ('overdrag',),
'overdraga': ('overdrag',),
'overdragene': ('overdrag',),
'overdraget': ('overdrag',),
'overdragelse': ('overdragelse',),
'overdragelsen': ('overdragelse',),
'overdragelsene': ('overdragelse',),
'overdragelser': ('overdragelse',),
'overdraging': ('overdraging',),
'overdraginga': ('overdraging',),
'overdragingen': ('overdraging',),
'overdragingene': ('overdraging',),
'overdraginger': ('overdraging',),
'overdraing': ('overdraing',),
'overdrainga': ('overdraing',),
'overdraingen': ('overdraing',),
'overdraingene': ('overdraing',),
'overdrainger': ('overdraing',),
'overdrivelse': ('overdrivelse',),
'overdrivelsen': ('overdrivelse',),
'overdrivelsene': ('overdrivelse',),
'overdrivelser': ('overdrivelse',),
'overdødelighet': ('overdødelighet',),
'overdødeligheta': ('overdødelighet',),
'overdødeligheten': ('overdødelighet',),
'overdødelighetene': ('overdødelighet',),
'overdødeligheter': ('overdødelighet',),
'overenskomst': ('overenskomst',),
'overenskomsten': ('overenskomst',),
'overenskomstene': ('overenskomst',),
'overenskomster': ('overenskomst',),
'overensstemmelse': ('overensstemmelse',),
'overensstemmelsen': ('overensstemmelse',),
'overensstemmelsene': ('overensstemmelse',),
'overensstemmelser': ('overensstemmelse',),
'overfall': ('overfall',),
'overfalla': ('overfall',),
'overfallene': ('overfall',),
'overfallet': ('overfall',),
'overfallshjul': ('overfallshjul',),
'overfallshjula': ('overfallshjul',),
'overfallshjulene': ('overfallshjul',),
'overfallshjulet': ('overfallshjul',),
'overfallsmann': ('overfallsmann',),
'overfallsmannen': ('overfallsmann',),
'overfallsmenn': ('overfallsmann',),
'overfallsmennene': ('overfallsmann',),
'overfart': ('overfart',),
'overfarten': ('overfart',),
'overfartene': ('overfart',),
'overfarter': ('overfart',),
'overflata': ('overflate',),
'overflate': ('overflate',),
'overflaten': ('overflate',),
'overflatene': ('overflate',),
'overflater': ('overflate',),
'overflatepost': ('overflatepost',),
'overflateposten': ('overflatepost',),
'overflatepostene': ('overflatepost',),
'overflateposter': ('overflatepost',),
'overflatespenning': ('overflatespenning',),
'overflatespenninga': ('overflatespenning',),
'overflatespenningen': ('overflatespenning',),
'overflatespenningene': ('overflatespenning',),
'overflatespenninger': ('overflatespenning',),
'overflod': ('overflod',),
'overfloden': ('overflod',),
'overflodene': ('overflod',),
'overfloder': ('overflod',),
'overflodssamfunn': ('overflodssamfunn',),
'overflodssamfunna': ('overflodssamfunn',),
'overflodssamfunnene': ('overflodssamfunn',),
'overflodssamfunnet': ('overflodssamfunn',),
'overflyging': ('overflyging',),
'overflyginga': ('overflyging',),
'overflygingen': ('overflyging',),
'overflygingene': ('overflyging',),
'overflyginger': ('overflyging',),
'overflying': ('overflying',),
'overflyinga': ('overflying',),
'overflyingen': ('overflying',),
'overflyingene': ('overflying',),
'overflyinger': ('overflying',),
'overflødighetshorn': ('overflødighetshorn',),
'overflødighetshorna': ('overflødighetshorn',),
'overflødighetshornene': ('overflødighetshorn',),
'overflødighetshornet': ('overflødighetshorn',),
'overforbruk': ('overforbruk',),
'overforbruka': ('overforbruk',),
'overforbrukene': ('overforbruk',),
'overforbruket': ('overforbruk',),
'overformynder': ('overformynder',),
'overformyndere': ('overformynder',),
'overformynderen': ('overformynder',),
'overformynderer': ('overformynder',),
'overformynderne': ('overformynder',),
'overføring': ('overføring',),
'overføringa': ('overføring',),
'overføringen': ('overføring',),
'overføringene': ('overføring',),
'overføringer': ('overføring',),
'overføringsbilda': ('overføringsbilde',),
'overføringsbilde': ('overføringsbilde',),
'overføringsbildene': ('overføringsbilde',),
'overføringsbilder': ('overføringsbilde',),
'overføringsbildet': ('overføringsbilde',),
'overføringslinja': ('overføringslinje',),
'overføringslinje': ('overføringslinje',),
'overføringslinjen': ('overføringslinje',),
'overføringslinjene': ('overføringslinje',),
'overføringslinjer': ('overføringslinje',),
'overføringsverdi': ('overføringsverdi',),
'overføringsverdien': ('overføringsverdi',),
'overføringsverdiene': ('overføringsverdi',),
'overføringsverdier': ('overføringsverdi',),
'overgang': ('overgang',),
'overgangen': ('overgang',),
'overgangene': ('overgang',),
'overganger': ('overgang',),
'overgangsalder': ('overgangsalder',),
'overgangsaldere': ('overgangsalder',),
'overgangsalderen': ('overgangsalder',),
'overgangsalderer': ('overgangsalder',),
'overgangsalderne': ('overgangsalder',),
'overgangsaldre': ('overgangsalder',),
'overgangsaldrene': ('overgangsalder',),
'overgangsaldrer': ('overgangsalder',),
'overgangsbillett': ('overgangsbillett',),
'overgangsbilletten': ('overgangsbillett',),
'overgangsbillettene': ('overgangsbillett',),
'overgangsbilletter': ('overgangsbillett',),
'overgangsordning': ('overgangsordning',),
'overgangsordninga': ('overgangsordning',),
'overgangsordningen': ('overgangsordning',),
'overgangsordningene': ('overgangsordning',),
'overgangsordninger': ('overgangsordning',),
'overgangssum': ('overgangssum',),
'overgangssummen': ('overgangssum',),
'overgangssummene': ('overgangssum',),
'overgangssummer': ('overgangssum',),
'overgiing': ('overgiing',),
'overgiinga': ('overgiing',),
'overgiingen': ('overgiing',),
'overgiingene': ('overgiing',),
'overgiinger': ('overgiing',),
'overgiing': ('overgiing',),
'overgiinga': ('overgiing',),
'overgiingen': ('overgiing',),
'overgiingene': ('overgiing',),
'overgiinger': ('overgiing',),
'overgiing': ('overgiing',),
'overgiinga': ('overgiing',),
'overgiingen': ('overgiing',),
'overgiingene': ('overgiing',),
'overgiinger': ('overgiing',),
'overgivelse': ('overgivelse',),
'overgivelsen': ('overgivelse',),
'overgivelsene': ('overgivelse',),
'overgivelser': ('overgivelse',),
'overgivelse': ('overgivelse',),
'overgivelsen': ('overgivelse',),
'overgivelsene': ('overgivelse',),
'overgivelser': ('overgivelse',),
'overgivelse': ('overgivelse',),
'overgivelsen': ('overgivelse',),
'overgivelsene': ('overgivelse',),
'overgivelser': ('overgivelse',),
'overgivenhet': ('overgivenhet',),
'overgivenheta': ('overgivenhet',),
'overgivenheten': ('overgivenhet',),
'overgivenhetene': ('overgivenhet',),
'overgivenheter': ('overgivenhet',),
'overgiving': ('overgiving',),
'overgivinga': ('overgiving',),
'overgivingen': ('overgiving',),
'overgivingene': ('overgiving',),
'overgivinger': ('overgiving',),
'overgiving': ('overgiving',),
'overgivinga': ('overgiving',),
'overgivingen': ('overgiving',),
'overgivingene': ('overgiving',),
'overgivinger': ('overgiving',),
'overgiving': ('overgiving',),
'overgivinga': ('overgiving',),
'overgivingen': ('overgiving',),
'overgivingene': ('overgiving',),
'overgivinger': ('overgiving',),
'overgrep': ('overgrep',),
'overgrepa': ('overgrep',),
'overgrepene': ('overgrep',),
'overgrepet': ('overgrep',),
'overhaling': ('overhaling',),
'overhalinga': ('overhaling',),
'overhalingen': ('overhaling',),
'overhalingene': ('overhaling',),
'overhalinger': ('overhaling',),
'overhand': ('overhand',),
'overhead': ('overhead',),
'overheaden': ('overhead',),
'overheadene': ('overhead',),
'overheader': ('overhead',),
'overheadprojektor': ('overheadprojektor',),
'overheadprojektoren': ('overheadprojektor',),
'overheadprojektorene': ('overheadprojektor',),
'overheadprojektorer': ('overheadprojektor',),
'overheng': ('overheng',),
'overhenga': ('overheng',),
'overhengene': ('overheng',),
'overhenget': ('overheng',),
'overherredømma': ('overherredømme',),
'overherredømme': ('overherredømme',),
'overherredømmene': ('overherredømme',),
'overherredømmer': ('overherredømme',),
'overherredømmet': ('overherredømme',),
'overhoda': ('overhode',),
'overhode': ('overhode',),
'overhodene': ('overhode',),
'overhoder': ('overhode',),
'overhodet': ('overhode',),
'overhud': ('overhud',),
'overhuda': ('overhud',),
'overhuden': ('overhud',),
'overhudene': ('overhud',),
'overhuder': ('overhud',),
'overhus': ('overhus',),
'overhusa': ('overhus',),
'overhusene': ('overhus',),
'overhuset': ('overhus',),
'overhånd': ('overhånd',),
'overhøring': ('overhøring',),
'overhøringa': ('overhøring',),
'overhøringen': ('overhøring',),
'overhøringene': ('overhøring',),
'overhøringer': ('overhøring',),
'overhøvling': ('overhøvling',),
'overhøvlinga': ('overhøvling',),
'overhøvlingen': ('overhøvling',),
'overhøvlingene': ('overhøvling',),
'overhøvlinger': ('overhøvling',),
'overhøyhet': ('overhøyhet',),
'overhøyheta': ('overhøyhet',),
'overhøyheten': ('overhøyhet',),
'overhøyhetene': ('overhøyhet',),
'overhøyheter': ('overhøyhet',),
'overilelse': ('overilelse',),
'overilelsen': ('overilelse',),
'overilelsene': ('overilelse',),
'overilelser': ('overilelse',),
'overjeg': ('overjeg',),
'overjega': ('overjeg',),
'overjegene': ('overjeg',),
'overjeger': ('overjeg',),
'overjeget': ('overjeg',),
'overkant': ('overkant',),
'overkanten': ('overkant',),
'overkantene': ('overkant',),
'overkanter': ('overkant',),
'overkikkador': ('overkikkador',),
'overkikkadoren': ('overkikkador',),
'overkikkadorene': ('overkikkador',),
'overkikkadorer': ('overkikkador',),
'overkikkidor': ('overkikkidor',),
'overkikkidoren': ('overkikkidor',),
'overkikkidorene': ('overkikkidor',),
'overkikkidorer': ('overkikkidor',),
'overkikkidorian': ('overkikkidorian',),
'overkikkidorianen': ('overkikkidorian',),
'overkikkidorianene': ('overkikkidorian',),
'overkikkidorianer': ('overkikkidorian',),
'overkjeve': ('overkjeve',),
'overkjeven': ('overkjeve',),
'overkjevene': ('overkjeve',),
'overkjever': ('overkjeve',),
'overkjøring': ('overkjøring',),
'overkjøringa': ('overkjøring',),
'overkjøringen': ('overkjøring',),
'overkjøringene': ('overkjøring',),
'overkjøringer': ('overkjøring',),
'overkjørsel': ('overkjørsel',),
'overkjørselen': ('overkjørsel',),
'overkjørsla': ('overkjørsel',),
'overkjørslene': ('overkjørsel',),
'overkjørsler': ('overkjørsel',),
'overklassa': ('overklasse',),
'overklasse': ('overklasse',),
'overklassen': ('overklasse',),
'overklassene': ('overklasse',),
'overklasser': ('overklasse',),
'overkommando': ('overkommando',),
'overkommandoen': ('overkommando',),
'overkommandoene': ('overkommando',),
'overkommandoer': ('overkommando',),
'overkropp': ('overkropp',),
'overkroppen': ('overkropp',),
'overkroppene': ('overkropp',),
'overkropper': ('overkropp',),
'overkøy': ('overkøy',),
'overkøya': ('overkøy',),
'overkøyen': ('overkøy',),
'overkøyene': ('overkøy',),
'overkøyer': ('overkøy',),
'overkøya': ('overkøye',),
'overkøye': ('overkøye',),
'overkøyen': ('overkøye',),
'overkøyene': ('overkøye',),
'overkøyer': ('overkøye',),
'overlangsyn': ('overlangsyn',),
'overlangsyna': ('overlangsyn',),
'overlangsynene': ('overlangsyn',),
'overlangsynet': ('overlangsyn',),
'overlangsynthet': ('overlangsynthet',),
'overlangsyntheta': ('overlangsynthet',),
'overlangsyntheten': ('overlangsynthet',),
'overlangsynthetene': ('overlangsynthet',),
'overlangsyntheter': ('overlangsynthet',),
'overlast': ('overlast',),
'overlasta': ('overlast',),
'overlasten': ('overlast',),
'overlastene': ('overlast',),
'overlaster': ('overlast',),
'overledd': ('overledd',),
'overledda': ('overledd',),
'overleddene': ('overledd',),
'overleddet': ('overledd',),
'overledning': ('overledning',),
'overledninga': ('overledning',),
'overledningen': ('overledning',),
'overledningene': ('overledning',),
'overledninger': ('overledning',),
'overlege': ('overlege',),
'overlegen': ('overlege',),
'overlegene': ('overlege',),
'overleger': ('overlege',),
'overlegg': ('overlegg',),
'overlegga': ('overlegg',),
'overleggene': ('overlegg',),
'overlegget': ('overlegg',),
'overlegning': ('overlegning',),
'overlegninga': ('overlegning',),
'overlegningen': ('overlegning',),
'overlegningene': ('overlegning',),
'overlegninger': ('overlegning',),
'overleppa': ('overleppe',),
'overleppe': ('overleppe',),
'overleppen': ('overleppe',),
'overleppene': ('overleppe',),
'overlepper': ('overleppe',),
'overlevering': ('overlevering',),
'overleveringa': ('overlevering',),
'overleveringen': ('overlevering',),
'overleveringene': ('overlevering',),
'overleveringer': ('overlevering',),
'overlevingsdrakt': ('overlevingsdrakt',),
'overlevingsdrakta': ('overlevingsdrakt',),
'overlevingsdrakten': ('overlevingsdrakt',),
'overlevingsdraktene': ('overlevingsdrakt',),
'overlevingsdrakter': ('overlevingsdrakt',),
'overligger': ('overligger',),
'overliggere': ('overligger',),
'overliggeren': ('overligger',),
'overliggerer': ('overligger',),
'overliggerne': ('overligger',),
'overligning': ('overligning',),
'overligninga': ('overligning',),
'overligningen': ('overligning',),
'overligningene': ('overligning',),
'overligninger': ('overligning',),
'overligningsnemnd': ('overligningsnemnd',),
'overligningsnemnda': ('overligningsnemnd',),
'overligningsnemnden': ('overligningsnemnd',),
'overligningsnemndene': ('overligningsnemnd',),
'overligningsnemnder': ('overligningsnemnd',),
'overlikning': ('overlikning',),
'overlikninga': ('overlikning',),
'overlikningen': ('overlikning',),
'overlikningene': ('overlikning',),
'overlikninger': ('overlikning',),
'overlydsfly': ('overlydsfly',),
'overlydsflya': ('overlydsfly',),
'overlydsflyene': ('overlydsfly',),
'overlydsflyet': ('overlydsfly',),
'overlydssmell': ('overlydssmell',),
'overlydssmella': ('overlydssmell',),
'overlydssmellen': ('overlydssmell',),
'overlydssmellene': ('overlydssmell',),
'overlydssmeller': ('overlydssmell',),
'overlydssmellet': ('overlydssmell',),
'overlys': ('overlys',),
'overlysa': ('overlys',),
'overlysene': ('overlys',),
'overlyset': ('overlys',),
'overlær': ('overlær',),
'overlæra': ('overlær',),
'overlærene': ('overlær',),
'overlæret': ('overlær',),
'overlærer': ('overlærer',),
'overlærere': ('overlærer',),
'overlæreren': ('overlærer',),
'overlærerer': ('overlærer',),
'overlærerne': ('overlærer',),
'overløp': ('overløp',),
'overløpa': ('overløp',),
'overløpene': ('overløp',),
'overløpet': ('overløp',),
'overløper': ('overløper',),
'overløpere': ('overløper',),
'overløperen': ('overløper',),
'overløperer': ('overløper',),
'overløperne': ('overløper',),
'overmakt': ('overmakt',),
'overmakta': ('overmakt',),
'overmakten': ('overmakt',),
'overmaktene': ('overmakt',),
'overmakter': ('overmakt',),
'overmann': ('overmann',),
'overmannen': ('overmann',),
'overmenn': ('overmann',),
'overmennene': ('overmann',),
'overmenneska': ('overmenneske',),
'overmenneske': ('overmenneske',),
'overmenneskene': ('overmenneske',),
'overmennesker': ('overmenneske',),
'overmennesket': ('overmenneske',),
'overmot': ('overmot',),
'overmota': ('overmot',),
'overmotene': ('overmot',),
'overmotet': ('overmot',),
'overmunn': ('overmunn',),
'overmunnen': ('overmunn',),
'overmunnene': ('overmunn',),
'overmunner': ('overmunn',),
'overmål': ('overmål',),
'overmåla': ('overmål',),
'overmålene': ('overmål',),
'overmålet': ('overmål',),
'overnatting': ('overnatting',),
'overnattinga': ('overnatting',),
'overnattingen': ('overnatting',),
'overnattingene': ('overnatting',),
'overnattinger': ('overnatting',),
'overnattingssted': ('overnattingssted',),
'overnattingsstedene': ('overnattingssted',),
'overnattingssteder': ('overnattingssted',),
'overnattingsstedet': ('overnattingssted',),
'overoppsyn': ('overoppsyn',),
'overoppsyna': ('overoppsyn',),
'overoppsynene': ('overoppsyn',),
'overoppsynet': ('overoppsyn',),
'overpris': ('overpris',),
'overprisen': ('overpris',),
'overprisene': ('overpris',),
'overpriser': ('overpris',),
'overproduksjon': ('overproduksjon',),
'overproduksjonen': ('overproduksjon',),
'overproduksjonene': ('overproduksjon',),
'overproduksjoner': ('overproduksjon',),
'overraskelse': ('overraskelse',),
'overraskelsen': ('overraskelse',),
'overraskelsene': ('overraskelse',),
'overraskelser': ('overraskelse',),
'overrett': ('overrett',),
'overretten': ('overrett',),
'overrettene': ('overrett',),
'overretter': ('overrett',),
'overrettssakfører': ('overrettssakfører',),
'overrettssakførere': ('overrettssakfører',),
'overrettssakføreren': ('overrettssakfører',),
'overrettssakførerer': ('overrettssakfører',),
'overrettssakførerne': ('overrettssakfører',),
'overrislingsanlegg': ('overrislingsanlegg',),
'overrislingsanlegga': ('overrislingsanlegg',),
'overrislingsanleggene': ('overrislingsanlegg',),
'overrislingsanlegget': ('overrislingsanlegg',),
'overs': ('overs',),
'oversetning': ('oversetning',),
'oversetninga': ('oversetning',),
'oversetningen': ('oversetning',),
'oversetningene': ('oversetning',),
'oversetninger': ('oversetning',),
'oversettelse': ('oversettelse',),
'oversettelsen': ('oversettelse',),
'oversettelsene': ('oversettelse',),
'oversettelser': ('oversettelse',),
'oversettelseslån': ('oversettelseslån',),
'oversettelseslåna': ('oversettelseslån',),
'oversettelseslånene': ('oversettelseslån',),
'oversettelseslånet': ('oversettelseslån',),
'oversetter': ('oversetter',),
'oversettere': ('oversetter',),
'oversetteren': ('oversetter',),
'oversetterer': ('oversetter',),
'oversetterne': ('oversetter',),
'oversida': ('overside',),
'overside': ('overside',),
'oversiden': ('overside',),
'oversidene': ('overside',),
'oversider': ('overside',),
'oversikt': ('oversikt',),
'oversikta': ('oversikt',),
'oversikten': ('oversikt',),
'oversiktene': ('oversikt',),
'oversikter': ('oversikt',),
'oversjukepleier': ('oversjukepleier',),
'oversjukepleiere': ('oversjukepleier',),
'oversjukepleieren': ('oversjukepleier',),
'oversjukepleierer': ('oversjukepleier',),
'oversjukepleierne': ('oversjukepleier',),
'overskjønn': ('overskjønn',),
'overskjønna': ('overskjønn',),
'overskjønnene': ('overskjønn',),
'overskjønnet': ('overskjønn',),
'overskott': ('overskott',),
'overskotta': ('overskott',),
'overskottene': ('overskott',),
'overskottet': ('overskott',),
'overskottskraft': ('overskottskraft',),
'overskottskrafta': ('overskottskraft',),
'overskottskraften': ('overskottskraft',),
'overskottskreftene': ('overskottskraft',),
'overskottskrefter': ('overskottskraft',),
'overskottsmenneska': ('overskottsmenneske',),
'overskottsmenneske': ('overskottsmenneske',),
'overskottsmenneskene': ('overskottsmenneske',),
'overskottsmennesker': ('overskottsmenneske',),
'overskottsmennesket': ('overskottsmenneske',),
'overskrift': ('overskrift',),
'overskrifta': ('overskrift',),
'overskriften': ('overskrift',),
'overskriftene': ('overskrift',),
'overskrifter': ('overskrift',),
'overskudd': ('overskudd',),
'overskudda': ('overskudd',),
'overskuddene': ('overskudd',),
'overskuddet': ('overskudd',),
'overskuddskraft': ('overskuddskraft',),
'overskuddskrafta': ('overskuddskraft',),
'overskuddskraften': ('overskuddskraft',),
'overskuddskreftene': ('overskuddskraft',),
'overskuddskrefter': ('overskuddskraft',),
'overskuddsmenneska': ('overskuddsmenneske',),
'overskuddsmenneske': ('overskuddsmenneske',),
'overskuddsmenneskene': ('overskuddsmenneske',),
'overskuddsmennesker': ('overskuddsmenneske',),
'overskuddsmennesket': ('overskuddsmenneske',),
'overslag': ('overslag',),
'overslaga': ('overslag',),
'overslagene': ('overslag',),
'overslaget': ('overslag',),
'overspill': ('overspill',),
'overspilla': ('overspill',),
'overspillene': ('overspill',),
'overspillet': ('overspill',),
'overstemme': ('overstemme',),
'overstemmen': ('overstemme',),
'overstemmene': ('overstemme',),
'overstemmer': ('overstemme',),
'overstiger': ('overstiger',),
'overstigere': ('overstiger',),
'overstigeren': ('overstiger',),
'overstigerer': ('overstiger',),
'overstigerne': ('overstiger',),
'overstikk': ('overstikk',),
'overstikka': ('overstikk',),
'overstikkene': ('overstikk',),
'overstikket': ('overstikk',),
'overstryking': ('overstryking',),
'overstrykinga': ('overstryking',),
'overstrykingen': ('overstryking',),
'overstrykingene': ('overstryking',),
'overstrykinger': ('overstryking',),
'overstrykning': ('overstrykning',),
'overstrykninga': ('overstrykning',),
'overstrykningen': ('overstrykning',),
'overstrykningene': ('overstrykning',),
'overstrykninger': ('overstrykning',),
'overstyrmann': ('overstyrmann',),
'overstyrmannen': ('overstyrmann',),
'overstyrmenn': ('overstyrmann',),
'overstyrmennene': ('overstyrmann',),
'oversvømmelse': ('oversvømmelse',),
'oversvømmelsen': ('oversvømmelse',),
'oversvømmelsene': ('oversvømmelse',),
'oversvømmelser': ('oversvømmelse',),
'oversykepleier': ('oversykepleier',),
'oversykepleiere': ('oversykepleier',),
'oversykepleieren': ('oversykepleier',),
'oversykepleierer': ('oversykepleier',),
'oversykepleierne': ('oversykepleier',),
'oversyn': ('oversyn',),
'oversyna': ('oversyn',),
'oversynene': ('oversyn',),
'oversynet': ('oversyn',),
'overtaing': ('overtaing',),
'overtainga': ('overtaing',),
'overtaingen': ('overtaing',),
'overtaingene': ('overtaing',),
'overtainger': ('overtaing',),
'overtak': ('overtak',),
'overtaka': ('overtak',),
'overtakene': ('overtak',),
'overtaket': ('overtak',),
'overtakelse': ('overtakelse',),
'overtakelsen': ('overtakelse',),
'overtakelsene': ('overtakelse',),
'overtakelser': ('overtakelse',),
'overtaking': ('overtaking',),
'overtakinga': ('overtaking',),
'overtakingen': ('overtaking',),
'overtakingene': ('overtaking',),
'overtakinger': ('overtaking',),
'overtal': ('overtal',),
'overtala': ('overtal',),
'overtalene': ('overtal',),
'overtalet': ('overtal',),
'overtalelse': ('overtalelse',),
'overtalelsen': ('overtalelse',),
'overtalelsene': ('overtalelse',),
'overtalelser': ('overtalelse',),
'overtall': ('overtall',),
'overtalla': ('overtall',),
'overtallene': ('overtall',),
'overtallet': ('overtall',),
'overtann': ('overtann',),
'overtanna': ('overtann',),
'overtannen': ('overtann',),
'overtennene': ('overtann',),
'overtenner': ('overtann',),
'overtid': ('overtid',),
'overtida': ('overtid',),
'overtiden': ('overtid',),
'overtidene': ('overtid',),
'overtider': ('overtid',),
'overtidsarbeid': ('overtidsarbeid',),
'overtidsarbeida': ('overtidsarbeid',),
'overtidsarbeidene': ('overtidsarbeid',),
'overtidsarbeider': ('overtidsarbeid',),
'overtidsarbeidet': ('overtidsarbeid',),
'overtidsbetaling': ('overtidsbetaling',),
'overtidsbetalinga': ('overtidsbetaling',),
'overtidsbetalingen': ('overtidsbetaling',),
'overtidsbetalingene': ('overtidsbetaling',),
'overtidsbetalinger': ('overtidsbetaling',),
'overtone': ('overtone',),
'overtonen': ('overtone',),
'overtonene': ('overtone',),
'overtoner': ('overtone',),
'overtramp': ('overtramp',),
'overtrampen': ('overtramp',),
'overtrampene': ('overtramp',),
'overtramper': ('overtramp',),
'overtramp': ('overtramp',),
'overtrampa': ('overtramp',),
'overtrampene': ('overtramp',),
'overtrampet': ('overtramp',),
'overtredelse': ('overtredelse',),
'overtredelsen': ('overtredelse',),
'overtredelsene': ('overtredelse',),
'overtredelser': ('overtredelse',),
'overtrekk': ('overtrekk',),
'overtrekka': ('overtrekk',),
'overtrekkene': ('overtrekk',),
'overtrekket': ('overtrekk',),
'overtrekksbuksa': ('overtrekksbukse',),
'overtrekksbukse': ('overtrekksbukse',),
'overtrekksbuksen': ('overtrekksbukse',),
'overtrekksbuksene': ('overtrekksbukse',),
'overtrekksbukser': ('overtrekksbukse',),
'overtro': ('overtro',),
'overtroa': ('overtro',),
'overtroen': ('overtro',),
'overtroene': ('overtro',),
'overtroer': ('overtro',),
'overtru': ('overtru',),
'overtrua': ('overtru',),
'overtruen': ('overtru',),
'overtruene': ('overtru',),
'overtruer': ('overtru',),
'overtrykk': ('overtrykk',),
'overtrykka': ('overtrykk',),
'overtrykkene': ('overtrykk',),
'overtrykket': ('overtrykk',),
'overvann': ('overvann',),
'overvanna': ('overvann',),
'overvannene': ('overvann',),
'overvannet': ('overvann',),
'overvarme': ('overvarme',),
'overvarmen': ('overvarme',),
'overvarmene': ('overvarme',),
'overvarmer': ('overvarme',),
'overvatn': ('overvatn',),
'overvatna': ('overvatn',),
'overvatnene': ('overvatn',),
'overvatnet': ('overvatn',),
'overveielse': ('overveielse',),
'overveielsen': ('overveielse',),
'overveielsene': ('overveielse',),
'overveielser': ('overveielse',),
'overvekt': ('overvekt',),
'overvekta': ('overvekt',),
'overvekten': ('overvekt',),
'overvektene': ('overvekt',),
'overvekter': ('overvekt',),
'overvinnelse': ('overvinnelse',),
'overvinnelsen': ('overvinnelse',),
'overvinnelsene': ('overvinnelse',),
'overvinnelser': ('overvinnelse',),
'overvintrer': ('overvintrer',),
'overvintrere': ('overvintrer',),
'overvintreren': ('overvintrer',),
'overvintrerer': ('overvintrer',),
'overvintrerne': ('overvintrer',),
'overvintring': ('overvintring',),
'overvintringa': ('overvintring',),
'overvintringen': ('overvintring',),
'overvintringene': ('overvintring',),
'overvintringer': ('overvintring',),
'overvåker': ('overvåker',),
'overvåkere': ('overvåker',),
'overvåkeren': ('overvåker',),
'overvåkerer': ('overvåker',),
'overvåkerne': ('overvåker',),
'overvåking': ('overvåking',),
'overvåkinga': ('overvåking',),
'overvåkingen': ('overvåking',),
'overvåkingene': ('overvåking',),
'overvåkinger': ('overvåking',),
'overvåkingspoliti': ('overvåkingspoliti',),
'overvåkingspolitia': ('overvåkingspoliti',),
'overvåkingspolitiene': ('overvåkingspoliti',),
'overvåkingspolitier': ('overvåkingspoliti',),
'overvåkingspolitiet': ('overvåkingspoliti',),
'overvåkingssatellitt': ('overvåkingssatellitt',),
'overvåkingssatellitten': ('overvåkingssatellitt',),
'overvåkingssatellittene': ('overvåkingssatellitt',),
'overvåkingssatellitter': ('overvåkingssatellitt',),
'overvåkingstjeneste': ('overvåkingstjeneste',),
'overvåkingstjenesten': ('overvåkingstjeneste',),
'overvåkingstjenestene': ('overvåkingstjeneste',),
'overvåkingstjenester': ('overvåkingstjeneste',),
'overvåkning': ('overvåkning',),
'overvåkninga': ('overvåkning',),
'overvåkningen': ('overvåkning',),
'overvåkningene': ('overvåkning',),
'overvåkninger': ('overvåkning',),
'overvåkningspoliti': ('overvåkningspoliti',),
'overvåkningspolitia': ('overvåkningspoliti',),
'overvåkningspolitiene': ('overvåkningspoliti',),
'overvåkningspolitier': ('overvåkningspoliti',),
'overvåkningspolitiet': ('overvåkningspoliti',),
'overvåkningssatellitt': ('overvåkningssatellitt',),
'overvåkningssatellitten': ('overvåkningssatellitt',),
'overvåkningssatellittene': ('overvåkningssatellitt',),
'overvåkningssatellitter': ('overvåkningssatellitt',),
'overvåkningstjeneste': ('overvåkningstjeneste',),
'overvåkningstjenesten': ('overvåkningstjeneste',),
'overvåkningstjenestene': ('overvåkningstjeneste',),
'overvåkningstjenester': ('overvåkningstjeneste',),
'overåring': ('overåring',),
'overåringen': ('overåring',),
'overåringene': ('overåring',),
'overåringer': ('overåring',),
'ovn': ('ovn',),
'ovnen': ('ovn',),
'ovnene': ('ovn',),
'ovner': ('ovn',),
'ovn': ('ovn',),
'ovnen': ('ovn',),
'ovnene': ('ovn',),
'ovner': ('ovn',),
'ovnskrok': ('ovnskrok',),
'ovnskroken': ('ovnskrok',),
'ovnskrokene': ('ovnskrok',),
'ovnskroker': ('ovnskrok',),
'ovnsrør': ('ovnsrør',),
'ovnsrøra': ('ovnsrør',),
'ovnsrørene': ('ovnsrør',),
'ovnsrøret': ('ovnsrør',),
'ovnsrør': ('ovnsrør',),
'ovnsrøra': ('ovnsrør',),
'ovnsrørene': ('ovnsrør',),
'ovnsrøret': ('ovnsrør',),
'ovnssverta': ('ovnssverte',),
'ovnssverte': ('ovnssverte',),
'ovnssverten': ('ovnssverte',),
'ovnssvertene': ('ovnssverte',),
'ovnssverter': ('ovnssverte',),
'ovnssverta': ('ovnssverte',),
'ovnssverte': ('ovnssverte',),
'ovnssverten': ('ovnssverte',),
'ovnssvertene': ('ovnssverte',),
'ovnssverter': ('ovnssverte',),
'ovulasjon': ('ovulasjon',),
'ovulasjonen': ('ovulasjon',),
'ovulasjonene': ('ovulasjon',),
'ovulasjoner': ('ovulasjon',),
'ozelot': ('ozelot',),
'ozeloten': ('ozelot',),
'ozelotene': ('ozelot',),
'ozeloter': ('ozelot',),
'ozon': ('ozon',),
'ozona': ('ozon',),
'ozonene': ('ozon',),
'ozonet': ('ozon',),
'ozonaldring': ('ozonaldring',),
'ozonaldringa': ('ozonaldring',),
'ozonaldringen': ('ozonaldring',),
'ozonaldringene': ('ozonaldring',),
'ozonaldringer': ('ozonaldring',),
'ozonlag': ('ozonlag',),
'ozonlaga': ('ozonlag',),
'ozonlagene': ('ozonlag',),
'ozonlaget': ('ozonlag',),
'p-pilla': ('p-pille',),
'p-pille': ('p-pille',),
'p-pillen': ('p-pille',),
'p-pillene': ('p-pille',),
'p-piller': ('p-pille',),
'pH': ('pH',),
'pH-en': ('pH',),
'pH-ene': ('pH',),
'pH-verdi': ('pH-verdi',),
'pH-verdien': ('pH-verdi',),
'pH-verdiene': ('pH-verdi',),
'pH-verdier': ('pH-verdi',),
'pace': ('pace',),
'pacen': ('pace',),
'pacene': ('pace',),
'pacer': ('pace',),
'pacemaker': ('pacemaker',),
'pacemakere': ('pacemaker',),
'pacemakeren': ('pacemaker',),
'pacemakerer': ('pacemaker',),
'pacemakerne': ('pacemaker',),
'pacer': ('pacer',),
'pacere': ('pacer',),
'paceren': ('pacer',),
'pacerer': ('pacer',),
'pacerne': ('pacer',),
'padda': ('padde',),
'padde': ('padde',),
'padden': ('padde',),
'paddene': ('padde',),
'padder': ('padde',),
'paddehatt': ('paddehatt',),
'paddehatten': ('paddehatt',),
'paddehattene': ('paddehatt',),
'paddehatter': ('paddehatt',),
'paddel': ('paddel',),
'paddelen': ('paddel',),
'padlene': ('paddel',),
'padler': ('paddel',),
'paddemark': ('paddemark',),
'paddemarka': ('paddemark',),
'paddemarken': ('paddemark',),
'paddemarkene': ('paddemark',),
'paddemarker': ('paddemark',),
'paddesli': ('paddesli',),
'paddeslia': ('paddesli',),
'paddesliene': ('paddesli',),
'paddesliet': ('paddesli',),
'paddesly': ('paddesly',),
'paddeslya': ('paddesly',),
'paddeslyene': ('paddesly',),
'paddeslyet': ('paddesly',),
'paddespytt': ('paddespytt',),
'paddespytta': ('paddespytt',),
'paddespyttene': ('paddespytt',),
'paddespyttet': ('paddespytt',),
'paddetorsk': ('paddetorsk',),
'paddetorsken': ('paddetorsk',),
'paddetorskene': ('paddetorsk',),
'paddetorsker': ('paddetorsk',),
'paddock': ('paddock',),
'paddocken': ('paddock',),
'paddockene': ('paddock',),
'paddocker': ('paddock',),
'padler': ('padler',),
'padlere': ('padler',),
'padleren': ('padler',),
'padlerer': ('padler',),
'padlerne': ('padler',),
'padleåra': ('padleåre',),
'padleåre': ('padleåre',),
'padleåren': ('padleåre',),
'padleårene': ('padleåre',),
'padleårer': ('padleåre',),
'paff': ('paff',),
'paffa': ('paff',),
'paffene': ('paff',),
'paffet': ('paff',),
'pagai': ('pagai',),
'pagaien': ('pagai',),
'pagaiene': ('pagai',),
'pagaier': ('pagai',),
'paganisme': ('paganisme',),
'paganismen': ('paganisme',),
'paganismene': ('paganisme',),
'paganismer': ('paganisme',),
'pagina': ('pagina',),
'paginaen': ('pagina',),
'paginaene': ('pagina',),
'paginaer': ('pagina',),
'pagode': ('pagode',),
'pagoden': ('pagode',),
'pagodene': ('pagode',),
'pagoder': ('pagode',),
'pai': ('pai',),
'paien': ('pai',),
'paiene': ('pai',),
'paier': ('pai',),
'pair': ('pair',),
'pairen': ('pair',),
'pairene': ('pair',),
'pairer': ('pair',),
'pakettbåt': ('pakettbåt',),
'pakettbåten': ('pakettbåt',),
'pakettbåtene': ('pakettbåt',),
'pakettbåter': ('pakettbåt',),
'pakistaner': ('pakistaner',),
'pakistanere': ('pakistaner',),
'pakistaneren': ('pakistaner',),
'pakistanerer': ('pakistaner',),
'pakistanerne': ('pakistaner',),
'pakk': ('pakk',),
'pakka': ('pakk',),
'pakkene': ('pakk',),
'pakket': ('pakk',),
'pakkboks': ('pakkboks',),
'pakkboksen': ('pakkboks',),
'pakkboksene': ('pakkboks',),
'pakkbokser': ('pakkboks',),
'pakkbu': ('pakkbu',),
'pakkbua': ('pakkbu',),
'pakkbuen': ('pakkbu',),
'pakkbuene': ('pakkbu',),
'pakkbuer': ('pakkbu',),
'pakka': ('pakke',),
'pakke': ('pakke',),
'pakken': ('pakke',),
'pakkene': ('pakke',),
'pakker': ('pakke',),
'pakkeavtale': ('pakkeavtale',),
'pakkeavtalen': ('pakkeavtale',),
'pakkeavtalene': ('pakkeavtale',),
'pakkeavtaler': ('pakkeavtale',),
'pakkeløsning': ('pakkeløsning',),
'pakkeløsninga': ('pakkeløsning',),
'pakkeløsningen': ('pakkeløsning',),
'pakkeløsningene': ('pakkeløsning',),
'pakkeløsninger': ('pakkeløsning',),
'pakkenellik': ('pakkenellik',),
'pakkenelliken': ('pakkenellik',),
'pakkenellikene': ('pakkenellik',),
'pakkenelliker': ('pakkenellik',),
'pakkereisa': ('pakkereise',),
'pakkereise': ('pakkereise',),
'pakkereisen': ('pakkereise',),
'pakkereisene': ('pakkereise',),
'pakkereiser': ('pakkereise',),
'pakkesel': ('pakkesel',),
'pakkeselet': ('pakkesel',),
'pakkesla': ('pakkesel',),
'pakkeslene': ('pakkesel',),
'pakkesler': ('pakkesel',),
'pakkeslet': ('pakkesel',),
'pakketilbud': ('pakketilbud',),
'pakketilbuda': ('pakketilbud',),
'pakketilbudene': ('pakketilbud',),
'pakketilbudet': ('pakketilbud',),
'pakketur': ('pakketur',),
'pakketuren': ('pakketur',),
'pakketurene': ('pakketur',),
'pakketurer': ('pakketur',),
'pakkhus': ('pakkhus',),
'pakkhusa': ('pakkhus',),
'pakkhusene': ('pakkhus',),
'pakkhuset': ('pakkhus',),
'pakkis': ('pakkis',),
'pakkisen': ('pakkis',),
'pakkisene': ('pakkis',),
'pakkiser': ('pakkis',),
'pakkmester': ('pakkmester',),
'pakkmestere': ('pakkmester',),
'pakkmesteren': ('pakkmester',),
'pakkmesterer': ('pakkmester',),
'pakkmesterne': ('pakkmester',),
'pakkmestre': ('pakkmester',),
'pakkmestrene': ('pakkmester',),
'pakkmestrer': ('pakkmester',),
'pakkrammesekk': ('pakkrammesekk',),
'pakkrammesekken': ('pakkrammesekk',),
'pakkrammesekkene': ('pakkrammesekk',),
'pakkrammesekker': ('pakkrammesekk',),
'pakkseddel': ('pakkseddel',),
'pakkseddelen': ('pakkseddel',),
'pakksedlene': ('pakkseddel',),
'pakksedler': ('pakkseddel',),
'pakning': ('pakning',),
'pakninga': ('pakning',),
'pakningen': ('pakning',),
'pakningene': ('pakning',),
'pakninger': ('pakning',),
'pakt': ('pakt',),
'pakta': ('pakt',),
'pakten': ('pakt',),
'paktene': ('pakt',),
'pakter': ('pakt',),
'pal': ('pal',),
'palen': ('pal',),
'palene': ('pal',),
'paler': ('pal',),
'palea': ('palé',),
'paleene': ('palé',),
'paleer': ('palé',),
'paleet': ('palé',),
'palé': ('palé',),
'paléa': ('palé',),
'paléene': ('palé',),
'paléer': ('palé',),
'paléet': ('palé',),
'palass': ('palass',),
'palassa': ('palass',),
'palassene': ('palass',),
'palasser': ('palass',),
'palasset': ('palass',),
'palassrevolusjon': ('palassrevolusjon',),
'palassrevolusjonen': ('palassrevolusjon',),
'palassrevolusjonene': ('palassrevolusjon',),
'palassrevolusjoner': ('palassrevolusjon',),
'palatal': ('palatal',),
'palatalen': ('palatal',),
'palatalene': ('palatal',),
'palataler': ('palatal',),
'palaver': ('palaver',),
'palavere': ('palaver',),
'palaveren': ('palaver',),
'palaverer': ('palaver',),
'palaverne': ('palaver',),
'pale': ('pale',),
'palen': ('pale',),
'palene': ('pale',),
'paler': ('pale',),
'paleograf': ('paleograf',),
'paleografen': ('paleograf',),
'paleografene': ('paleograf',),
'paleografer': ('paleograf',),
'paleografi': ('paleografi',),
'paleografien': ('paleografi',),
'paleografiene': ('paleografi',),
'paleografier': ('paleografi',),
'paleolitikum': ('paleolitikum',),
'paleontolog': ('paleontolog',),
'paleontologen': ('paleontolog',),
'paleontologene': ('paleontolog',),
'paleontologer': ('paleontolog',),
'paleontologi': ('paleontologi',),
'paleontologien': ('paleontologi',),
'paleontologiene': ('paleontologi',),
'paleontologier': ('paleontologi',),
'paleotyp': ('paleotyp',),
'paleotypen': ('paleotyp',),
'paleotypene': ('paleotyp',),
'paleotyper': ('paleotyp',),
'paleozoikum': ('paleozoikum',),
'palestiner': ('palestiner',),
'palestinere': ('palestiner',),
'palestineren': ('palestiner',),
'palestinerer': ('palestiner',),
'palestinerne': ('palestiner',),
'paletot': ('paletot',),
'paletoten': ('paletot',),
'paletotene': ('paletot',),
'paletoter': ('paletot',),
'palett': ('palett',),
'paletten': ('palett',),
'palettene': ('palett',),
'paletter': ('palett',),
'pali': ('pali',),
'palien': ('pali',),
'paliene': ('pali',),
'palier': ('pali',),
'palindrom': ('palindrom',),
'palindroma': ('palindrom',),
'palindromene': ('palindrom',),
'palindromer': ('palindrom',),
'palindromet': ('palindrom',),
'palisade': ('palisade',),
'palisaden': ('palisade',),
'palisadene': ('palisade',),
'palisader': ('palisade',),
'palisander': ('palisander',),
'palisandere': ('palisander',),
'palisanderen': ('palisander',),
'palisanderer': ('palisander',),
'palisanderne': ('palisander',),
'palisandre': ('palisander',),
'palisandrene': ('palisander',),
'palisandrer': ('palisander',),
'paljett': ('paljett',),
'paljetten': ('paljett',),
'paljettene': ('paljett',),
'paljetter': ('paljett',),
'pall': ('pall',),
'pallen': ('pall',),
'pallene': ('pall',),
'paller': ('pall',),
'pall-last': ('pall-last',),
'pall-lasta': ('pall-last',),
'pall-lasten': ('pall-last',),
'pall-lastene': ('pall-last',),
'pall-laster': ('pall-last',),
'palladia': ('palladium',),
'palladiene': ('palladium',),
'palladier': ('palladium',),
'palladiet': ('palladium',),
'palladium': ('palladium',),
'pallask': ('pallask',),
'pallasken': ('pallask',),
'pallaskene': ('pallask',),
'pallasker': ('pallask',),
'pallast': ('pallast',),
'pallasta': ('pallast',),
'pallasten': ('pallast',),
'pallastene': ('pallast',),
'pallaster': ('pallast',),
'pallbåt': ('pallbåt',),
'pallbåten': ('pallbåt',),
'pallbåtene': ('pallbåt',),
'pallbåter': ('pallbåt',),
'pallebåt': ('pallebåt',),
'pallebåten': ('pallebåt',),
'pallebåtene': ('pallebåt',),
'pallebåter': ('pallebåt',),
'pallelast': ('pallelast',),
'pallelasta': ('pallelast',),
'pallelasten': ('pallelast',),
'pallelastene': ('pallelast',),
'pallelaster': ('pallelast',),
'palleskip': ('palleskip',),
'palleskipa': ('palleskip',),
'palleskipene': ('palleskip',),
'palleskipet': ('palleskip',),
'palliativ': ('palliativ',),
'palliativa': ('palliativ',),
'palliativene': ('palliativ',),
'palliativer': ('palliativ',),
'palliativet': ('palliativ',),
'pallia': ('pallium',),
'palliene': ('pallium',),
'pallier': ('pallium',),
'palliet': ('pallium',),
'pallium': ('pallium',),
'pallskip': ('pallskip',),
'pallskipa': ('pallskip',),
'pallskipene': ('pallskip',),
'pallskipet': ('pallskip',),
'palltosk': ('palltosk',),
'palltosken': ('palltosk',),
'palltoskene': ('palltosk',),
'palltosker': ('palltosk',),
'palme': ('palme',),
'palmen': ('palme',),
'palmene': ('palme',),
'palmer': ('palme',),
'palmehage': ('palmehage',),
'palmehagen': ('palmehage',),
'palmehagene': ('palmehage',),
'palmehager': ('palmehage',),
'palmeolja': ('palmeolje',),
'palmeolje': ('palmeolje',),
'palmeoljen': ('palmeolje',),
'palmeoljene': ('palmeolje',),
'palmeoljer': ('palmeolje',),
'palmesøndag': ('palmesøndag',),
'palmesøndagen': ('palmesøndag',),
'palmesøndagene': ('palmesøndag',),
'palmesøndager': ('palmesøndag',),
'palmett': ('palmett',),
'palmetten': ('palmett',),
'palmettene': ('palmett',),
'palmetter': ('palmett',),
'palmin': ('palmin',),
'palmina': ('palmin',),
'palminene': ('palmin',),
'palminet': ('palmin',),
'palmitat': ('palmitat',),
'palmitata': ('palmitat',),
'palmitatene': ('palmitat',),
'palmitater': ('palmitat',),
'palmitatet': ('palmitat',),
'palmitin': ('palmitin',),
'palmitina': ('palmitin',),
'palmitinene': ('palmitin',),
'palmitinet': ('palmitin',),
'palmitinsyra': ('palmitinsyre',),
'palmitinsyre': ('palmitinsyre',),
'palmitinsyren': ('palmitinsyre',),
'palmitinsyrene': ('palmitinsyre',),
'palmitinsyrer': ('palmitinsyre',),
'palpasjon': ('palpasjon',),
'palpasjonen': ('palpasjon',),
'palpasjonene': ('palpasjon',),
'palpasjoner': ('palpasjon',),
'palpitasjon': ('palpitasjon',),
'palpitasjonen': ('palpitasjon',),
'palpitasjonene': ('palpitasjon',),
'palpitasjoner': ('palpitasjon',),
'pamfilius': ('pamfilius',),
'pamfiliusen': ('pamfilius',),
'pamfiliusene': ('pamfilius',),
'pamfiliuser': ('pamfilius',),
'pamflett': ('pamflett',),
'pamfletten': ('pamflett',),
'pamflettene': ('pamflett',),
'pamfletter': ('pamflett',),
'pamp': ('pamp',),
'pampen': ('pamp',),
'pampene': ('pamp',),
'pamper': ('pamp',),
'pampas': ('pampas',),
'pampasen': ('pampas',),
'pampasene': ('pampas',),
'pampaser': ('pampas',),
'pampevelda': ('pampevelde',),
'pampevelde': ('pampevelde',),
'pampeveldene': ('pampevelde',),
'pampevelder': ('pampevelde',),
'pampeveldet': ('pampevelde',),
'pampusse': ('pampusse',),
'pampussen': ('pampusse',),
'pampussene': ('pampusse',),
'pampusser': ('pampusse',),
'panamahatt': ('panamahatt',),
'panamahatten': ('panamahatt',),
'panamahattene': ('panamahatt',),
'panamahatter': ('panamahatt',),
'panamaner': ('panamaner',),
'panamanere': ('panamaner',),
'panamaneren': ('panamaner',),
'panamanerer': ('panamaner',),
'panamanerne': ('panamaner',),
'panaseen': ('panasé',),
'panaseene': ('panasé',),
'panaseer': ('panasé',),
'panasé': ('panasé',),
'panaséen': ('panasé',),
'panaséene': ('panasé',),
'panaséer': ('panasé',),
'panasj': ('panasj',),
'panasjen': ('panasj',),
'panasjene': ('panasj',),
'panasjer': ('panasj',),
'panda': ('panda',),
'pandaen': ('panda',),
'pandaene': ('panda',),
'pandaer': ('panda',),
'pandemi': ('pandemi',),
'pandemien': ('pandemi',),
'pandemiene': ('pandemi',),
'pandemier': ('pandemi',),
'pandemonia': ('pandemonium',),
'pandemoniene': ('pandemonium',),
'pandemonier': ('pandemonium',),
'pandemoniet': ('pandemonium',),
'pandemonium': ('pandemonium',),
'pandoraeska': ('pandoraeske',),
'pandoraeske': ('pandoraeske',),
'pandoraesken': ('pandoraeske',),
'pandoraeskene': ('pandoraeske',),
'pandoraesker': ('pandoraeske',),
'pandoragava': ('pandoragave',),
'pandoragave': ('pandoragave',),
'pandoragaven': ('pandoragave',),
'pandoragavene': ('pandoragave',),
'pandoragaver': ('pandoragave',),
'panegyriker': ('panegyriker',),
'panegyrikere': ('panegyriker',),
'panegyrikeren': ('panegyriker',),
'panegyrikerer': ('panegyriker',),
'panegyrikerne': ('panegyriker',),
'panegyrikk': ('panegyrikk',),
'panegyrikken': ('panegyrikk',),
'panegyrikkene': ('panegyrikk',),
'panegyrikker': ('panegyrikk',),
'panel': ('panel',),
'panela': ('panel',),
'panelene': ('panel',),
'paneler': ('panel',),
'panelet': ('panel',),
'paneldebatt': ('paneldebatt',),
'paneldebatten': ('paneldebatt',),
'paneldebattene': ('paneldebatt',),
'paneldebatter': ('paneldebatt',),
'paneling': ('paneling',),
'panelinga': ('paneling',),
'panelingen': ('paneling',),
'panelingene': ('paneling',),
'panelinger': ('paneling',),
'panelomn': ('panelomn',),
'panelomnen': ('panelomn',),
'panelomnene': ('panelomn',),
'panelomner': ('panelomn',),
'panelovn': ('panelovn',),
'panelovnen': ('panelovn',),
'panelovnene': ('panelovn',),
'panelovner': ('panelovn',),
'panelundersøkelse': ('panelundersøkelse',),
'panelundersøkelsen': ('panelundersøkelse',),
'panelundersøkelsene': ('panelundersøkelse',),
'panelundersøkelser': ('panelundersøkelse',),
'panelundersøking': ('panelundersøking',),
'panelundersøkinga': ('panelundersøking',),
'panelundersøkingen': ('panelundersøking',),
'panelundersøkingene': ('panelundersøking',),
'panelundersøkinger': ('panelundersøking',),
'panett': ('panett',),
'panetten': ('panett',),
'panettene': ('panett',),
'panetter': ('panett',),
'panfløyta': ('panfløyte',),
'panfløyte': ('panfløyte',),
'panfløyten': ('panfløyte',),
'panfløytene': ('panfløyte',),
'panfløyter': ('panfløyte',),
'pang': ('pang',),
'panga': ('pang',),
'pangene': ('pang',),
'panget': ('pang',),
'pangavslutning': ('pangavslutning',),
'pangavslutninga': ('pangavslutning',),
'pangavslutningen': ('pangavslutning',),
'pangavslutningene': ('pangavslutning',),
'pangavslutninger': ('pangavslutning',),
'pangdebut': ('pangdebut',),
'pangdebuten': ('pangdebut',),
'pangdebutene': ('pangdebut',),
'pangdebuter': ('pangdebut',),
'pangåpning': ('pangåpning',),
'pangåpninga': ('pangåpning',),
'pangåpningen': ('pangåpning',),
'pangåpningene': ('pangåpning',),
'pangåpninger': ('pangåpning',),
'panikk': ('panikk',),
'panikken': ('panikk',),
'panikkene': ('panikk',),
'panikker': ('panikk',),
'panikkalder': ('panikkalder',),
'panikkaldere': ('panikkalder',),
'panikkalderen': ('panikkalder',),
'panikkalderer': ('panikkalder',),
'panikkalderne': ('panikkalder',),
'panikkaldre': ('panikkalder',),
'panikkaldrene': ('panikkalder',),
'panikkaldrer': ('panikkalder',),
'panikkreaksjon': ('panikkreaksjon',),
'panikkreaksjonen': ('panikkreaksjon',),
'panikkreaksjonene': ('panikkreaksjon',),
'panikkreaksjoner': ('panikkreaksjon',),
'panjabi': ('panjabi',),
'panjabien': ('panjabi',),
'panjabiene': ('panjabi',),
'panjabier': ('panjabi',),
'pank': ('pank',),
'panken': ('pank',),
'pankene': ('pank',),
'panker': ('pank',),
'panna': ('panne',),
'panne': ('panne',),
'pannen': ('panne',),
'pannene': ('panne',),
'panner': ('panne',),
'panna': ('panne',),
'panne': ('panne',),
'pannen': ('panne',),
'pannene': ('panne',),
'panner': ('panne',),
'pannebrask': ('pannebrask',),
'pannebrasken': ('pannebrask',),
'pannebraskene': ('pannebrask',),
'pannebrasker': ('pannebrask',),
'pannehår': ('pannehår',),
'pannehåra': ('pannehår',),
'pannehårene': ('pannehår',),
'pannehåret': ('pannehår',),
'pannekaka': ('pannekake',),
'pannekake': ('pannekake',),
'pannekaken': ('pannekake',),
'pannekakene': ('pannekake',),
'pannekaker': ('pannekake',),
'panoptikon': ('panoptikon',),
'panoptikona': ('panoptikon',),
'panoptikonene': ('panoptikon',),
'panoptikoner': ('panoptikon',),
'panoptikonet': ('panoptikon',),
'panorama': ('panorama',),
'panoramaene': ('panorama',),
'panoramaer': ('panorama',),
'panoramaet': ('panorama',),
'panoramafilm': ('panoramafilm',),
'panoramafilmen': ('panoramafilm',),
'panoramafilmene': ('panoramafilm',),
'panoramafilmer': ('panoramafilm',),
'panoramavindu': ('panoramavindu',),
'panoramavindua': ('panoramavindu',),
'panoramavinduene': ('panoramavindu',),
'panoramavinduer': ('panoramavindu',),
'panoramavinduet': ('panoramavindu',),
'panser': ('panser',),
'pansera': ('panser',),
'pansere': ('panser',),
'panseret': ('panser',),
'panserne': ('panser',),
'panserbil': ('panserbil',),
'panserbilen': ('panserbil',),
'panserbilene': ('panserbil',),
'panserbiler': ('panserbil',),
'panserglass': ('panserglass',),
'panserglassa': ('panserglass',),
'panserglassene': ('panserglass',),
'panserglasset': ('panserglass',),
'panserskip': ('panserskip',),
'panserskipa': ('panserskip',),
'panserskipene': ('panserskip',),
'panserskipet': ('panserskip',),
'pansertropp': ('pansertropp',),
'pansertroppen': ('pansertropp',),
'pansertroppene': ('pansertropp',),
'pansertropper': ('pansertropp',),
'panservern': ('panservern',),
'panserverna': ('panservern',),
'panservernene': ('panservern',),
'panservernet': ('panservern',),
'panservernrakettkaster': ('panservernrakettkaster',),
'panservernrakettkastere': ('panservernrakettkaster',),
'panservernrakettkasteren': ('panservernrakettkaster',),
'panservernrakettkasterer': ('panservernrakettkaster',),
'panservernrakettkasterne': ('panservernrakettkaster',),
'panservogn': ('panservogn',),
'panservogna': ('panservogn',),
'panservognen': ('panservogn',),
'panservognene': ('panservogn',),
'panservogner': ('panservogn',),
'pansring': ('pansring',),
'pansringa': ('pansring',),
'pansringen': ('pansring',),
'pansringene': ('pansring',),
'pansringer': ('pansring',),
'pant': ('pant',),
'panten': ('pant',),
'pantene': ('pant',),
'panter': ('pant',),
'pant': ('pant',),
'panta': ('pant',),
'pantene': ('pant',),
'pantet': ('pant',),
'pantebrev': ('pantebrev',),
'pantebreva': ('pantebrev',),
'pantebrevene': ('pantebrev',),
'pantebrever': ('pantebrev',),
'pantebrevet': ('pantebrev',),
'pantegjeld': ('pantegjeld',),
'pantegjelda': ('pantegjeld',),
'pantegjelden': ('pantegjeld',),
'pantegjeldene': ('pantegjeld',),
'pantegjelder': ('pantegjeld',),
'panteisme': ('panteisme',),
'panteismen': ('panteisme',),
'panteismene': ('panteisme',),
'panteismer': ('panteisme',),
'panteist': ('panteist',),
'panteisten': ('panteist',),
'panteistene': ('panteist',),
'panteister': ('panteist',),
'panteleik': ('panteleik',),
'panteleiken': ('panteleik',),
'panteleikene': ('panteleik',),
'panteleiker': ('panteleik',),
'pantelek': ('pantelek',),
'panteleken': ('pantelek',),
'pantelekene': ('pantelek',),
'panteleker': ('pantelek',),
'pantelån': ('pantelån',),
'pantelåna': ('pantelån',),
'pantelånene': ('pantelån',),
'pantelånet': ('pantelån',),
'pantelåner': ('pantelåner',),
'pantelånere': ('pantelåner',),
'pantelåneren': ('pantelåner',),
'pantelånerer': ('pantelåner',),
'pantelånerne': ('pantelåner',),
'panteon': ('panteon',),
'panteona': ('panteon',),
'panteonene': ('panteon',),
'panteonet': ('panteon',),
'panter': ('panter',),
'pantere': ('panter',),
'panteren': ('panter',),
'panterer': ('panter',),
'panterne': ('panter',),
'panter': ('panter',),
'pantere': ('panter',),
'panteren': ('panter',),
'panterer': ('panter',),
'panterne': ('panter',),
'pantre': ('panter',),
'pantrene': ('panter',),
'pantrer': ('panter',),
'panteregister': ('panteregister',),
'panteregisteret': ('panteregister',),
'panteregistra': ('panteregister',),
'panteregistre': ('panteregister',),
'panteregistrene': ('panteregister',),
'panteregistret': ('panteregister',),
'panterett': ('panterett',),
'panteretten': ('panterett',),
'panterettene': ('panterett',),
'panteretter': ('panterett',),
'panteutlegg': ('panteutlegg',),
'panteutlegga': ('panteutlegg',),
'panteutleggene': ('panteutlegg',),
'panteutlegget': ('panteutlegg',),
'panthaver': ('panthaver',),
'panthavere': ('panthaver',),
'panthaveren': ('panthaver',),
'panthaverer': ('panthaver',),
'panthaverne': ('panthaver',),
'pantobligasjon': ('pantobligasjon',),
'pantobligasjonen': ('pantobligasjon',),
'pantobligasjonene': ('pantobligasjon',),
'pantobligasjoner': ('pantobligasjon',),
'pantograf': ('pantograf',),
'pantografen': ('pantograf',),
'pantografene': ('pantograf',),
'pantografer': ('pantograf',),
'pantomime': ('pantomime',),
'pantomimen': ('pantomime',),
'pantomimene': ('pantomime',),
'pantomimer': ('pantomime',),
'pantomimiker': ('pantomimiker',),
'pantomimikere': ('pantomimiker',),
'pantomimikeren': ('pantomimiker',),
'pantomimikerer': ('pantomimiker',),
'pantomimikerne': ('pantomimiker',),
'pantry': ('pantry',),
'pantrya': ('pantry',),
'pantryene': ('pantry',),
'pantryer': ('pantry',),
'pantryet': ('pantry',),
'pantsetter': ('pantsetter',),
'pantsettere': ('pantsetter',),
'pantsetteren': ('pantsetter',),
'pantsetterer': ('pantsetter',),
'pantsetterne': ('pantsetter',),
'panty': ('panty',),
'pantyen': ('panty',),
'pantyene': ('panty',),
'pantyer': ('panty',),
'papaya': ('papaya',),
'papayaen': ('papaya',),
'papayaene': ('papaya',),
'papayaer': ('papaya',),
'papegøye': ('papegøye',),
'papegøyen': ('papegøye',),
'papegøyene': ('papegøye',),
'papegøyer': ('papegøye',),
'paperback': ('paperback',),
'paperbacken': ('paperback',),
'paperbackene': ('paperback',),
'paperbacks': ('paperback',),
'papiljott': ('papiljott',),
'papiljotten': ('papiljott',),
'papiljottene': ('papiljott',),
'papiljotter': ('papiljott',),
'papill': ('papill',),
'papillen': ('papill',),
'papillene': ('papill',),
'papiller': ('papill',),
'papir': ('papir',),
'papira': ('papir',),
'papirene': ('papir',),
'papirer': ('papir',),
'papiret': ('papir',),
'papirbestemmelse': ('papirbestemmelse',),
'papirbestemmelsen': ('papirbestemmelse',),
'papirbestemmelsene': ('papirbestemmelse',),
'papirbestemmelser': ('papirbestemmelse',),
'papirhandel': ('papirhandel',),
'papirhandelen': ('papirhandel',),
'papirhandlene': ('papirhandel',),
'papirhandler': ('papirhandel',),
'papirkniv': ('papirkniv',),
'papirkniven': ('papirkniv',),
'papirknivene': ('papirkniv',),
'papirkniver': ('papirkniv',),
'papirkorg': ('papirkorg',),
'papirkorga': ('papirkorg',),
'papirkorgen': ('papirkorg',),
'papirkorgene': ('papirkorg',),
'papirkorger': ('papirkorg',),
'papirkurv': ('papirkurv',),
'papirkurva': ('papirkurv',),
'papirkurven': ('papirkurv',),
'papirkurvene': ('papirkurv',),
'papirkurver': ('papirkurv',),
'papirmasjeen': ('papirmasjé',),
'papirmasjeene': ('papirmasjé',),
'papirmasjeer': ('papirmasjé',),
'papirmasjé': ('papirmasjé',),
'papirmasjéen': ('papirmasjé',),
'papirmasjéene': ('papirmasjé',),
'papirmasjéer': ('papirmasjé',),
'papirmasse': ('papirmasse',),
'papirmassen': ('papirmasse',),
'papirmassene': ('papirmasse',),
'papirmasser': ('papirmasse',),
'papirmølla': ('papirmølle',),
'papirmølle': ('papirmølle',),
'papirmøllen': ('papirmølle',),
'papirmøllene': ('papirmølle',),
'papirmøller': ('papirmølle',),
'papirord': ('papirord',),
'papirorda': ('papirord',),
'papirordene': ('papirord',),
'papirordet': ('papirord',),
'papirpengene': ('papirpenger',),
'papirpenger': ('papirpenger',),
'papirtiger': ('papirtiger',),
'papirtigere': ('papirtiger',),
'papirtigeren': ('papirtiger',),
'papirtigerer': ('papirtiger',),
'papirtigerne': ('papirtiger',),
'papirtigre': ('papirtiger',),
'papirtigrene': ('papirtiger',),
'papirtigrer': ('papirtiger',),
'papisme': ('papisme',),
'papismen': ('papisme',),
'papismene': ('papisme',),
'papismer': ('papisme',),
'papist': ('papist',),
'papisten': ('papist',),
'papistene': ('papist',),
'papister': ('papist',),
'papisteri': ('papisteri',),
'papisteria': ('papisteri',),
'papisteriene': ('papisteri',),
'papisterier': ('papisteri',),
'papisteriet': ('papisteri',),
'papp': ('papp',),
'pappen': ('papp',),
'pappene': ('papp',),
'papper': ('papp',),
'papp': ('papp',),
'pappen': ('papp',),
'pappene': ('papp',),
'papper': ('papp',),
'pappa': ('pappa',),
'pappaen': ('pappa',),
'pappaene': ('pappa',),
'pappaer': ('pappa',),
'pappadalt': ('pappadalt',),
'pappadalten': ('pappadalt',),
'pappadaltene': ('pappadalt',),
'pappadalter': ('pappadalt',),
'pappagutt': ('pappagutt',),
'pappagutten': ('pappagutt',),
'pappaguttene': ('pappagutt',),
'pappagutter': ('pappagutt',),
'pappenheimer': ('pappenheimer',),
'pappenheimere': ('pappenheimer',),
'pappenheimeren': ('pappenheimer',),
'pappenheimerer': ('pappenheimer',),
'pappenheimerne': ('pappenheimer',),
'pappkartong': ('pappkartong',),
'pappkartongen': ('pappkartong',),
'pappkartongene': ('pappkartong',),
'pappkartonger': ('pappkartong',),
'pappmasjeen': ('pappmasjé',),
'pappmasjeene': ('pappmasjé',),
'pappmasjeer': ('pappmasjé',),
'pappmasjé': ('pappmasjé',),
'pappmasjéen': ('pappmasjé',),
'pappmasjéene': ('pappmasjé',),
'pappmasjéer': ('pappmasjé',),
'pappmelk': ('pappmelk',),
'pappmelka': ('pappmelk',),
'pappmelken': ('pappmelk',),
'pappmelkene': ('pappmelk',),
'pappmelker': ('pappmelk',),
'pappskalle': ('pappskalle',),
'pappskallen': ('pappskalle',),
'pappskallene': ('pappskalle',),
'pappskaller': ('pappskalle',),
'paprika': ('paprika',),
'paprikaen': ('paprika',),
'paprikaene': ('paprika',),
'paprikaer': ('paprika',),
'papuaner': ('papuaner',),
'papuanere': ('papuaner',),
'papuaneren': ('papuaner',),
'papuanerer': ('papuaner',),
'papuanerne': ('papuaner',),
'papuaspråk': ('papuaspråk',),
'papuaspråka': ('papuaspråk',),
'papuaspråkene': ('papuaspråk',),
'papuaspråket': ('papuaspråk',),
'papyrolog': ('papyrolog',),
'papyrologen': ('papyrolog',),
'papyrologene': ('papyrolog',),
'papyrologer': ('papyrolog',),
'papyrologi': ('papyrologi',),
'papyrologien': ('papyrologi',),
'papyrologiene': ('papyrologi',),
'papyrologier': ('papyrologi',),
'papyren': ('papyrus',),
'papyrene': ('papyrus',),
'papyrer': ('papyrus',),
'papyrus': ('papyrus',),
'papyrusen': ('papyrus',),
'papyrusene': ('papyrus',),
'papyruser': ('papyrus',),
'papyrusrull': ('papyrusrull',),
'papyrusrullen': ('papyrusrull',),
'papyrusrullene': ('papyrusrull',),
'papyrusruller': ('papyrusrull',),
'par': ('par',),
'para': ('par',),
'parene': ('par',),
'paret': ('par',),
'parabel': ('parabel',),
'parabelen': ('parabel',),
'parablene': ('parabel',),
'parabler': ('parabel',),
'parabol': ('parabol',),
'parabolen': ('parabol',),
'parabolene': ('parabol',),
'paraboler': ('parabol',),
'parabolantenna': ('parabolantenne',),
'parabolantenne': ('parabolantenne',),
'parabolantennen': ('parabolantenne',),
'parabolantennene': ('parabolantenne',),
'parabolantenner': ('parabolantenne',),
'paraboloide': ('paraboloide',),
'paraboloiden': ('paraboloide',),
'paraboloidene': ('paraboloide',),
'paraboloider': ('paraboloide',),
'parade': ('parade',),
'paraden': ('parade',),
'paradene': ('parade',),
'parader': ('parade',),
'paradenummer': ('paradenummer',),
'paradenummeret': ('paradenummer',),
'paradenumra': ('paradenummer',),
'paradenumre': ('paradenummer',),
'paradenumrene': ('paradenummer',),
'paradeseng': ('paradeseng',),
'paradesenga': ('paradeseng',),
'paradesengen': ('paradeseng',),
'paradesengene': ('paradeseng',),
'paradesenger': ('paradeseng',),
'paradigma': ('paradigma',),
'paradigmaene': ('paradigma',),
'paradigmaer': ('paradigma',),
'paradigmaet': ('paradigma',),
'paradigma': ('paradigme',),
'paradigme': ('paradigme',),
'paradigmene': ('paradigme',),
'paradigmer': ('paradigme',),
'paradigmet': ('paradigme',),
'paradis': ('paradis',),
'paradisa': ('paradis',),
'paradisene': ('paradis',),
'paradiser': ('paradis',),
'paradiset': ('paradis',),
'paradisfugl': ('paradisfugl',),
'paradisfuglen': ('paradisfugl',),
'paradisfuglene': ('paradisfugl',),
'paradisfugler': ('paradisfugl',),
'paradoks': ('paradoks',),
'paradoksa': ('paradoks',),
'paradoksene': ('paradoks',),
'paradokser': ('paradoks',),
'paradokset': ('paradoks',),
'parafin': ('parafin',),
'parafinen': ('parafin',),
'parafinene': ('parafin',),
'parafiner': ('parafin',),
'parafin': ('parafin',),
'parafina': ('parafin',),
'parafinene': ('parafin',),
'parafiner': ('parafin',),
'parafinet': ('parafin',),
'parafinbrenner': ('parafinbrenner',),
'parafinbrennere': ('parafinbrenner',),
'parafinbrenneren': ('parafinbrenner',),
'parafinbrennerer': ('parafinbrenner',),
'parafinbrennerne': ('parafinbrenner',),
'parafinlampa': ('parafinlampe',),
'parafinlampe': ('parafinlampe',),
'parafinlampen': ('parafinlampe',),
'parafinlampene': ('parafinlampe',),
'parafinlamper': ('parafinlampe',),
'parafinomn': ('parafinomn',),
'parafinomnen': ('parafinomn',),
'parafinomnene': ('parafinomn',),
'parafinomner': ('parafinomn',),
'parafinovn': ('parafinovn',),
'parafinovnen': ('parafinovn',),
'parafinovnene': ('parafinovn',),
'parafinovner': ('parafinovn',),
'parafinvoks': ('parafinvoks',),
'parafinvoksa': ('parafinvoks',),
'parafinvoksen': ('parafinvoks',),
'parafinvoksene': ('parafinvoks',),
'parafinvokser': ('parafinvoks',),
'parafinvokset': ('parafinvoks',),
'parafrase': ('parafrase',),
'parafrasen': ('parafrase',),
'parafrasene': ('parafrase',),
'parafraser': ('parafrase',),
'paragon': ('paragon',),
'paragonen': ('paragon',),
'paragonene': ('paragon',),
'paragoner': ('paragon',),
'paragraf': ('paragraf',),
'paragrafen': ('paragraf',),
'paragrafene': ('paragraf',),
'paragrafer': ('paragraf',),
'paragrafbåt': ('paragrafbåt',),
'paragrafbåten': ('paragrafbåt',),
'paragrafbåtene': ('paragrafbåt',),
'paragrafbåter': ('paragrafbåt',),
'paragrafrytter': ('paragrafrytter',),
'paragrafryttere': ('paragrafrytter',),
'paragrafrytteren': ('paragrafrytter',),
'paragrafrytterer': ('paragrafrytter',),
'paragrafrytterne': ('paragrafrytter',),
'paragrafrytteri': ('paragrafrytteri',),
'paragrafrytteria': ('paragrafrytteri',),
'paragrafrytteriene': ('paragrafrytteri',),
'paragrafrytterier': ('paragrafrytteri',),
'paragrafrytteriet': ('paragrafrytteri',),
'paragraftegn': ('paragraftegn',),
'paragraftegna': ('paragraftegn',),
'paragraftegnene': ('paragraftegn',),
'paragraftegnet': ('paragraftegn',),
'paraguayaner': ('paraguayaner',),
'paraguayanere': ('paraguayaner',),
'paraguayaneren': ('paraguayaner',),
'paraguayanerer': ('paraguayaner',),
'paraguayanerne': ('paraguayaner',),
'parallakse': ('parallakse',),
'parallaksen': ('parallakse',),
'parallaksene': ('parallakse',),
'parallakser': ('parallakse',),
'parallell': ('parallell',),
'parallellen': ('parallell',),
'parallellene': ('parallell',),
'paralleller': ('parallell',),
'parallellisme': ('parallellisme',),
'parallellismen': ('parallellisme',),
'parallellismene': ('parallellisme',),
'parallellismer': ('parallellisme',),
'parallellitet': ('parallellitet',),
'parallelliteten': ('parallellitet',),
'parallellitetene': ('parallellitet',),
'parallelliteter': ('parallellitet',),
'parallellklassa': ('parallellklasse',),
'parallellklasse': ('parallellklasse',),
'parallellklassen': ('parallellklasse',),
'parallellklassene': ('parallellklasse',),
'parallellklasser': ('parallellklasse',),
'parallellkobling': ('parallellkobling',),
'parallellkoblinga': ('parallellkobling',),
'parallellkoblingen': ('parallellkobling',),
'parallellkoblingene': ('parallellkobling',),
'parallellkoblinger': ('parallellkobling',),
'parallellkopling': ('parallellkopling',),
'parallellkoplinga': ('parallellkopling',),
'parallellkoplingen': ('parallellkopling',),
'parallellkoplingene': ('parallellkopling',),
'parallellkoplinger': ('parallellkopling',),
'parallellogram': ('parallellogram',),
'parallellogramma': ('parallellogram',),
'parallellogrammene': ('parallellogram',),
'parallellogrammer': ('parallellogram',),
'parallellogrammet': ('parallellogram',),
'parallellsirkel': ('parallellsirkel',),
'parallellsirkelen': ('parallellsirkel',),
'parallellsirklene': ('parallellsirkel',),
'parallellsirkler': ('parallellsirkel',),
'parallellslalåm': ('parallellslalåm',),
'parallellslalåmen': ('parallellslalåm',),
'parallellslalåmene': ('parallellslalåm',),
'parallellslalåmer': ('parallellslalåm',),
'parallelltekst': ('parallelltekst',),
'parallellteksta': ('parallelltekst',),
'parallellteksten': ('parallelltekst',),
'parallelltekstene': ('parallelltekst',),
'parallelltekster': ('parallelltekst',),
'parallelltoneart': ('parallelltoneart',),
'parallelltonearta': ('parallelltoneart',),
'parallelltonearten': ('parallelltoneart',),
'parallelltoneartene': ('parallelltoneart',),
'parallelltonearter': ('parallelltoneart',),
'parallellutgava': ('parallellutgave',),
'parallellutgave': ('parallellutgave',),
'parallellutgaven': ('parallellutgave',),
'parallellutgavene': ('parallellutgave',),
'parallellutgaver': ('parallellutgave',),
'paralyse': ('paralyse',),
'paralysen': ('paralyse',),
'paralysene': ('paralyse',),
'paralyser': ('paralyse',),
'parament': ('parament',),
'paramenta': ('parament',),
'paramentene': ('parament',),
'paramenter': ('parament',),
'paramentet': ('parament',),
'parameter': ('parameter',),
'parametere': ('parameter',),
'parameteren': ('parameter',),
'parameterer': ('parameter',),
'parameterne': ('parameter',),
'parametre': ('parameter',),
'parametrene': ('parameter',),
'parametrer': ('parameter',),
'paranoia': ('paranoia',),
'paranoiaen': ('paranoia',),
'paranoiaene': ('paranoia',),
'paranoiaer': ('paranoia',),
'paranoiker': ('paranoiker',),
'paranoikere': ('paranoiker',),
'paranoikeren': ('paranoiker',),
'paranoikerer': ('paranoiker',),
'paranoikerne': ('paranoiker',),
'paranøtt': ('paranøtt',),
'paranøtta': ('paranøtt',),
'paranøtten': ('paranøtt',),
'paranøttene': ('paranøtt',),
'paranøtter': ('paranøtt',),
'paraply': ('paraply',),
'paraplyen': ('paraply',),
'paraplyene': ('paraply',),
'paraplyer': ('paraply',),
'paraplydregg': ('paraplydregg',),
'paraplydreggen': ('paraplydregg',),
'paraplydreggene': ('paraplydregg',),
'paraplydregger': ('paraplydregg',),
'paraplyorganisasjon': ('paraplyorganisasjon',),
'paraplyorganisasjonen': ('paraplyorganisasjon',),
'paraplyorganisasjonene': ('paraplyorganisasjon',),
'paraplyorganisasjoner': ('paraplyorganisasjon',),
'parapsykologi': ('parapsykologi',),
'parapsykologien': ('parapsykologi',),
'parapsykologiene': ('parapsykologi',),
'parapsykologier': ('parapsykologi',),
'parasitt': ('parasitt',),
'parasitten': ('parasitt',),
'parasittene': ('parasitt',),
'parasitter': ('parasitt',),
'parasittisme': ('parasittisme',),
'parasittismen': ('parasittisme',),
'parasittismene': ('parasittisme',),
'parasittismer': ('parasittisme',),
'parasoll': ('parasoll',),
'parasollen': ('parasoll',),
'parasollene': ('parasoll',),
'parasoller': ('parasoll',),
'parasollsopp': ('parasollsopp',),
'parasollsoppen': ('parasollsopp',),
'parasollsoppene': ('parasollsopp',),
'parasollsopper': ('parasollsopp',),
'paratagma': ('paratagme',),
'paratagme': ('paratagme',),
'paratagmene': ('paratagme',),
'paratagmer': ('paratagme',),
'paratagmet': ('paratagme',),
'paratakse': ('paratakse',),
'parataksen': ('paratakse',),
'parataksene': ('paratakse',),
'paratakser': ('paratakse',),
'paratyfoidfeber': ('paratyfoidfeber',),
'paratyfoidfebere': ('paratyfoidfeber',),
'paratyfoidfeberen': ('paratyfoidfeber',),
'paratyfoidfeberne': ('paratyfoidfeber',),
'paratyfoidfebre': ('paratyfoidfeber',),
'paratyfoidfebrene': ('paratyfoidfeber',),
'paratyfoidfebrer': ('paratyfoidfeber',),
'paratyfus': ('paratyfus',),
'paratyfusen': ('paratyfus',),
'paratyfusene': ('paratyfus',),
'paratyfuser': ('paratyfus',),
'pardans': ('pardans',),
'pardansen': ('pardans',),
'pardansene': ('pardans',),
'pardanser': ('pardans',),
'pardong': ('pardong',),
'pardongen': ('pardong',),
'pardongene': ('pardong',),
'pardonger': ('pardong',),
'parentes': ('parentes',),
'parentesen': ('parentes',),
'parentesene': ('parentes',),
'parenteser': ('parentes',),
'parentestegn': ('parentestegn',),
'parentestegna': ('parentestegn',),
'parentestegnene': ('parentestegn',),
'parentestegnet': ('parentestegn',),
'parese': ('parese',),
'paresen': ('parese',),
'paresene': ('parese',),
'pareser': ('parese',),
'paretiker': ('paretiker',),
'paretikere': ('paretiker',),
'paretikeren': ('paretiker',),
'paretikerer': ('paretiker',),
'paretikerne': ('paretiker',),
'parforhold': ('parforhold',),
'parforholda': ('parforhold',),
'parforholdene': ('parforhold',),
'parforholdet': ('parforhold',),
'parfyme': ('parfyme',),
'parfymen': ('parfyme',),
'parfymene': ('parfyme',),
'parfymer': ('parfyme',),
'parfymeri': ('parfymeri',),
'parfymeria': ('parfymeri',),
'parfymeriene': ('parfymeri',),
'parfymerier': ('parfymeri',),
'parfymeriet': ('parfymeri',),
'pargas': ('pargas',),
'pargasa': ('pargas',),
'pargasene': ('pargas',),
'pargaset': ('pargas',),
'parhest': ('parhest',),
'parhesten': ('parhest',),
'parhestene': ('parhest',),
'parhester': ('parhest',),
'pari': ('pari',),
'paria': ('paria',),
'pariaen': ('paria',),
'pariaene': ('paria',),
'pariaer': ('paria',),
'pariakaste': ('pariakaste',),
'pariakasten': ('pariakaste',),
'pariakastene': ('pariakaste',),
'pariakaster': ('pariakaste',),
'paring': ('paring',),
'paringa': ('paring',),
'paringen': ('paring',),
'paringene': ('paring',),
'paringer': ('paring',),
'paringsdans': ('paringsdans',),
'paringsdansen': ('paringsdans',),
'paringsdansene': ('paringsdans',),
'paringsdanser': ('paringsdans',),
'parisblått': ('parisblått',),
'pariser': ('pariser',),
'parisere': ('pariser',),
'pariseren': ('pariser',),
'pariserer': ('pariser',),
'pariserne': ('pariser',),
'pariserblått': ('pariserblått',),
'pariserhjul': ('pariserhjul',),
'pariserhjula': ('pariserhjul',),
'pariserhjulene': ('pariserhjul',),
'pariserhjulet': ('pariserhjul',),
'pariserloff': ('pariserloff',),
'pariserloffen': ('pariserloff',),
'pariserloffene': ('pariserloff',),
'pariserloffer': ('pariserloff',),
'parisermodell': ('parisermodell',),
'parisermodellen': ('parisermodell',),
'parisermodellene': ('parisermodell',),
'parisermodeller': ('parisermodell',),
'parisermote': ('parisermote',),
'parisermoten': ('parisermote',),
'parisermotene': ('parisermote',),
'parisermoter': ('parisermote',),
'parismodell': ('parismodell',),
'parismodellen': ('parismodell',),
'parismodellene': ('parismodell',),
'parismodeller': ('parismodell',),
'parismote': ('parismote',),
'parismoten': ('parismote',),
'parismotene': ('parismote',),
'parismoter': ('parismote',),
'paritet': ('paritet',),
'pariteten': ('paritet',),
'paritetene': ('paritet',),
'pariteter': ('paritet',),
'pariverdi': ('pariverdi',),
'pariverdien': ('pariverdi',),
'pariverdiene': ('pariverdi',),
'pariverdier': ('pariverdi',),
'park': ('park',),
'parken': ('park',),
'parkene': ('park',),
'parker': ('park',),
'parkas': ('parkas',),
'parkasen': ('parkas',),
'parkasene': ('parkas',),
'parkaser': ('parkas',),
'parkeringsbot': ('parkeringsbot',),
'parkeringsbota': ('parkeringsbot',),
'parkeringsboten': ('parkeringsbot',),
'parkeringsbøtene': ('parkeringsbot',),
'parkeringsbøter': ('parkeringsbot',),
'parkeringsgebyr': ('parkeringsgebyr',),
'parkeringsgebyra': ('parkeringsgebyr',),
'parkeringsgebyrene': ('parkeringsgebyr',),
'parkeringsgebyrer': ('parkeringsgebyr',),
'parkeringsgebyret': ('parkeringsgebyr',),
'parkeringshus': ('parkeringshus',),
'parkeringshusa': ('parkeringshus',),
'parkeringshusene': ('parkeringshus',),
'parkeringshuset': ('parkeringshus',),
'parkeringslys': ('parkeringslys',),
'parkeringslysa': ('parkeringslys',),
'parkeringslysene': ('parkeringslys',),
'parkeringslyset': ('parkeringslys',),
'parkeringsplass': ('parkeringsplass',),
'parkeringsplassen': ('parkeringsplass',),
'parkeringsplassene': ('parkeringsplass',),
'parkeringsplasser': ('parkeringsplass',),
'parkett': ('parkett',),
'parketten': ('parkett',),
'parkettene': ('parkett',),
'parketter': ('parkett',),
'parkett': ('parkett',),
'parketta': ('parkett',),
'parkettene': ('parkett',),
'parkettet': ('parkett',),
'parkettgolv': ('parkettgolv',),
'parkettgolva': ('parkettgolv',),
'parkettgolvene': ('parkettgolv',),
'parkettgolvet': ('parkettgolv',),
'parkettgulv': ('parkettgulv',),
'parkettgulva': ('parkettgulv',),
'parkettgulvene': ('parkettgulv',),
'parkettgulvet': ('parkettgulv',),
'parkettstav': ('parkettstav',),
'parkettstaven': ('parkettstav',),
'parkettstavene': ('parkettstav',),
'parkettstaver': ('parkettstav',),
'parkinsonisme': ('parkinsonisme',),
'parkinsonismen': ('parkinsonisme',),
'parkinsonismene': ('parkinsonisme',),
'parkinsonismer': ('parkinsonisme',),
'parkomat': ('parkomat',),
'parkomaten': ('parkomat',),
'parkomatene': ('parkomat',),
'parkomater': ('parkomat',),
'parkometer': ('parkometer',),
'parkometeret': ('parkometer',),
'parkometra': ('parkometer',),
'parkometre': ('parkometer',),
'parkometrene': ('parkometer',),
'parkometret': ('parkometer',),
'parkometeravgift': ('parkometeravgift',),
'parkometeravgifta': ('parkometeravgift',),
'parkometeravgiften': ('parkometeravgift',),
'parkometeravgiftene': ('parkometeravgift',),
'parkometeravgifter': ('parkometeravgift',),
'parkometervakt': ('parkometervakt',),
'parkometervakta': ('parkometervakt',),
'parkometervakten': ('parkometervakt',),
'parkometervaktene': ('parkometervakt',),
'parkometervakter': ('parkometervakt',),
'parktanta': ('parktante',),
'parktante': ('parktante',),
'parktanten': ('parktante',),
'parktantene': ('parktante',),
'parktanter': ('parktante',),
'parlament': ('parlament',),
'parlamenta': ('parlament',),
'parlamentene': ('parlament',),
'parlamenter': ('parlament',),
'parlamentet': ('parlament',),
'parlamentariker': ('parlamentariker',),
'parlamentarikere': ('parlamentariker',),
'parlamentarikeren': ('parlamentariker',),
'parlamentarikerer': ('parlamentariker',),
'parlamentarikerne': ('parlamentariker',),
'parlamentarisme': ('parlamentarisme',),
'parlamentarismen': ('parlamentarisme',),
'parlamentarismene': ('parlamentarisme',),
'parlamentarismer': ('parlamentarisme',),
'parlamentsbygning': ('parlamentsbygning',),
'parlamentsbygninga': ('parlamentsbygning',),
'parlamentsbygningen': ('parlamentsbygning',),
'parlamentsbygningene': ('parlamentsbygning',),
'parlamentsbygninger': ('parlamentsbygning',),
'parlamentsmedlem': ('parlamentsmedlem',),
'parlamentsmedlemma': ('parlamentsmedlem',),
'parlamentsmedlemmene': ('parlamentsmedlem',),
'parlamentsmedlemmer': ('parlamentsmedlem',),
'parlamentsmedlemmet': ('parlamentsmedlem',),
'parlamentær': ('parlamentær',),
'parlamentæren': ('parlamentær',),
'parlamentærene': ('parlamentær',),
'parlamentærer': ('parlamentær',),
'parlamentærflagg': ('parlamentærflagg',),
'parlamentærflagga': ('parlamentærflagg',),
'parlamentærflaggene': ('parlamentærflagg',),
'parlamentærflagget': ('parlamentærflagg',),
'parlando': ('parlando',),
'parlandoa': ('parlando',),
'parlandoene': ('parlando',),
'parlandoer': ('parlando',),
'parlandoet': ('parlando',),
'parløp': ('parløp',),
'parløpa': ('parløp',),
'parløpene': ('parløp',),
'parløpet': ('parløp',),
'parlør': ('parlør',),
'parløren': ('parlør',),
'parlørene': ('parlør',),
'parlører': ('parlør',),
'parmesanost': ('parmesanost',),
'parmesanosten': ('parmesanost',),
'parmesanostene': ('parmesanost',),
'parmesanoster': ('parmesanost',),
'parnass': ('parnass',),
'parnassa': ('parnass',),
'parnassene': ('parnass',),
'parnasser': ('parnass',),
'parnasset': ('parnass',),
'parodi': ('parodi',),
'parodien': ('parodi',),
'parodiene': ('parodi',),
'parodier': ('parodi',),
'paroksysme': ('paroksysme',),
'paroksysmen': ('paroksysme',),
'paroksysmene': ('paroksysme',),
'paroksysmer': ('paroksysme',),
'parole': ('parole',),
'parolen': ('parole',),
'parolene': ('parole',),
'paroler': ('parole',),
'parsell': ('parsell',),
'parsellen': ('parsell',),
'parsellene': ('parsell',),
'parseller': ('parsell',),
'parser': ('parser',),
'parsere': ('parser',),
'parseren': ('parser',),
'parserer': ('parser',),
'parserne': ('parser',),
'parsisme': ('parsisme',),
'parsismen': ('parsisme',),
'parsismene': ('parsisme',),
'parsismer': ('parsisme',),
'part': ('part',),
'parten': ('part',),
'partene': ('part',),
'parter': ('part',),
'parterr': ('parterr',),
'parterra': ('parterr',),
'parterrene': ('parterr',),
'parterret': ('parterr',),
'parterra': ('parterre',),
'parterre': ('parterre',),
'parterrene': ('parterre',),
'parterrer': ('parterre',),
'parterret': ('parterre',),
'parti': ('parti',),
'partia': ('parti',),
'partiene': ('parti',),
'partier': ('parti',),
'partiet': ('parti',),
'partialobligasjon': ('partialobligasjon',),
'partialobligasjonen': ('partialobligasjon',),
'partialobligasjonene': ('partialobligasjon',),
'partialobligasjoner': ('partialobligasjon',),
'partiapparat': ('partiapparat',),
'partiapparata': ('partiapparat',),
'partiapparatene': ('partiapparat',),
'partiapparater': ('partiapparat',),
'partiapparatet': ('partiapparat',),
'partibokansettelse': ('partibokansettelse',),
'partibokansettelsen': ('partibokansettelse',),
'partibokansettelsene': ('partibokansettelse',),
'partibokansettelser': ('partibokansettelse',),
'partidisiplin': ('partidisiplin',),
'partidisiplinen': ('partidisiplin',),
'partidisiplinene': ('partidisiplin',),
'partidisipliner': ('partidisiplin',),
'partifelle': ('partifelle',),
'partifellen': ('partifelle',),
'partifellene': ('partifelle',),
'partifeller': ('partifelle',),
'partikkel': ('partikkel',),
'partikkelen': ('partikkel',),
'partiklene': ('partikkel',),
'partikler': ('partikkel',),
'partikularisme': ('partikularisme',),
'partikularismen': ('partikularisme',),
'partikularismene': ('partikularisme',),
'partikularismer': ('partikularisme',),
'partilag': ('partilag',),
'partilaga': ('partilag',),
'partilagene': ('partilag',),
'partilaget': ('partilag',),
'partileder': ('partileder',),
'partiledere': ('partileder',),
'partilederen': ('partileder',),
'partilederer': ('partileder',),
'partilederne': ('partileder',),
'partimaskin': ('partimaskin',),
'partimaskina': ('partimaskin',),
'partimaskinen': ('partimaskin',),
'partimaskinene': ('partimaskin',),
'partimaskiner': ('partimaskin',),
'partiorgan': ('partiorgan',),
'partiorgana': ('partiorgan',),
'partiorganene': ('partiorgan',),
'partiorganer': ('partiorgan',),
'partiorganet': ('partiorgan',),
'partipamp': ('partipamp',),
'partipampen': ('partipamp',),
'partipampene': ('partipamp',),
'partipamper': ('partipamp',),
'partipisk': ('partipisk',),
'partipisken': ('partipisk',),
'partipiskene': ('partipisk',),
'partipisker': ('partipisk',),
'partipolitiker': ('partipolitiker',),
'partipolitikere': ('partipolitiker',),
'partipolitikeren': ('partipolitiker',),
'partipolitikerer': ('partipolitiker',),
'partipolitikerne': ('partipolitiker',),
'partipolitikk': ('partipolitikk',),
'partipolitikken': ('partipolitikk',),
'partipolitikkene': ('partipolitikk',),
'partipolitikker': ('partipolitikk',),
'partipressa': ('partipresse',),
'partipresse': ('partipresse',),
'partipressen': ('partipresse',),
'partipressene': ('partipresse',),
'partipresser': ('partipresse',),
'partiprogram': ('partiprogram',),
'partiprogramma': ('partiprogram',),
'partiprogrammene': ('partiprogram',),
'partiprogrammer': ('partiprogram',),
'partiprogrammet': ('partiprogram',),
'partisan': ('partisan',),
'partisanen': ('partisan',),
'partisanene': ('partisan',),
'partisaner': ('partisan',),
'partisipant': ('partisipant',),
'partisipanten': ('partisipant',),
'partisipantene': ('partisipant',),
'partisipanter': ('partisipant',),
'partisipasjonsforretning': ('partisipasjonsforretning',),
'partisipasjonsforretninga': ('partisipasjonsforretning',),
'partisipasjonsforretningen': ('partisipasjonsforretning',),
'partisipasjonsforretningene': ('partisipasjonsforretning',),
'partisipasjonsforretninger': ('partisipasjonsforretning',),
'partisipp': ('partisipp',),
'partisippa': ('partisipp',),
'partisippene': ('partisipp',),
'partisipper': ('partisipp',),
'partisippet': ('partisipp',),
'partita': ('partita',),
'partitaen': ('partita',),
'partitaene': ('partita',),
'partitaer': ('partita',),
'partitur': ('partitur',),
'partitura': ('partitur',),
'partiturene': ('partitur',),
'partiturer': ('partitur',),
'partituret': ('partitur',),
'partner': ('partner',),
'partnere': ('partner',),
'partneren': ('partner',),
'partnerer': ('partner',),
'partnerne': ('partner',),
'partnerskap': ('partnerskap',),
'partnerskapa': ('partnerskap',),
'partnerskapene': ('partnerskap',),
'partnerskaper': ('partnerskap',),
'partnerskapet': ('partnerskap',),
'partoutkort': ('partoutkort',),
'partoutkorta': ('partoutkort',),
'partoutkortene': ('partoutkort',),
'partoutkortet': ('partoutkort',),
'partrederi': ('partrederi',),
'partrederia': ('partrederi',),
'partrederiene': ('partrederi',),
'partrederier': ('partrederi',),
'partrederiet': ('partrederi',),
'partrål': ('partrål',),
'partrålen': ('partrål',),
'partrålene': ('partrål',),
'partråler': ('partrål',),
'partsinnlegg': ('partsinnlegg',),
'partsinnlegga': ('partsinnlegg',),
'partsinnleggene': ('partsinnlegg',),
'partsinnlegget': ('partsinnlegg',),
'parveny': ('parveny',),
'parvenyen': ('parveny',),
'parvenyene': ('parveny',),
'parvenyer': ('parveny',),
'parykk': ('parykk',),
'parykken': ('parykk',),
'parykkene': ('parykk',),
'parykker': ('parykk',),
'pas': ('pas',),
'pasa': ('pas',),
'pasene': ('pas',),
'paset': ('pas',),
'pas de deux': ('pas de deux',),
'pas de deuxen': ('pas de deux',),
'pas de deuxene': ('pas de deux',),
'pas de deuxer': ('pas de deux',),
'pascal': ('pascal',),
'pascalen': ('pascal',),
'pascalene': ('pascal',),
'pasient': ('pasient',),
'pasienten': ('pasient',),
'pasientene': ('pasient',),
'pasienter': ('pasient',),
'pasientvenn': ('pasientvenn',),
'pasientvennen': ('pasientvenn',),
'pasientvennene': ('pasientvenn',),
'pasientvenner': ('pasientvenn',),
'pasifikasjon': ('pasifikasjon',),
'pasifikasjonen': ('pasifikasjon',),
'pasifikasjonene': ('pasifikasjon',),
'pasifikasjoner': ('pasifikasjon',),
'pasifisme': ('pasifisme',),
'pasifismen': ('pasifisme',),
'pasifismene': ('pasifisme',),
'pasifismer': ('pasifisme',),
'pasifist': ('pasifist',),
'pasifisten': ('pasifist',),
'pasifistene': ('pasifist',),
'pasifister': ('pasifist',),
'pasja': ('pasja',),
'pasjaen': ('pasja',),
'pasjaene': ('pasja',),
'pasjaer': ('pasja',),
'pasje': ('pasje',),
'pasjen': ('pasje',),
'pasjene': ('pasje',),
'pasjer': ('pasje',),
'pasjehår': ('pasjehår',),
'pasjehåra': ('pasjehår',),
'pasjehårene': ('pasjehår',),
'pasjehåret': ('pasjehår',),
'pasjon': ('pasjon',),
'pasjonen': ('pasjon',),
'pasjonene': ('pasjon',),
'pasjoner': ('pasjon',),
'pasjonshistoria': ('pasjonshistorie',),
'pasjonshistorie': ('pasjonshistorie',),
'pasjonshistorien': ('pasjonshistorie',),
'pasjonshistoriene': ('pasjonshistorie',),
'pasjonshistorier': ('pasjonshistorie',),
'pasjonsspill': ('pasjonsspill',),
'pasjonsspilla': ('pasjonsspill',),
'pasjonsspillene': ('pasjonsspill',),
'pasjonsspillet': ('pasjonsspill',),
'pasjonsuka': ('pasjonsuke',),
'pasjonsuke': ('pasjonsuke',),
'pasjonsuken': ('pasjonsuke',),
'pasjonsukene': ('pasjonsuke',),
'pasjonsuker': ('pasjonsuke',),
'pasjonsveka': ('pasjonsveke',),
'pasjonsveke': ('pasjonsveke',),
'pasjonsveken': ('pasjonsveke',),
'pasjonsvekene': ('pasjonsveke',),
'pasjonsveker': ('pasjonsveke',),
'paskvill': ('paskvill',),
'paskvillen': ('paskvill',),
'paskvillene': ('paskvill',),
'paskviller': ('paskvill',),
'pasning': ('pasning',),
'pasninga': ('pasning',),
'pasningen': ('pasning',),
'pasningene': ('pasning',),
'pasninger': ('pasning',),
'pasning': ('pasning',),
'pasninga': ('pasning',),
'pasningen': ('pasning',),
'pasningene': ('pasning',),
'pasninger': ('pasning',),
'pasningsspell': ('pasningsspell',),
'pasningsspella': ('pasningsspell',),
'pasningsspellene': ('pasningsspell',),
'pasningsspellet': ('pasningsspell',),
'pasningsspill': ('pasningsspill',),
'pasningsspilla': ('pasningsspill',),
'pasningsspillene': ('pasningsspill',),
'pasningsspillet': ('pasningsspill',),
'paso doble': ('paso doble',),
'paso doblen': ('paso doble',),
'paso doblene': ('paso doble',),
'paso dobler': ('paso doble',),
'pass': ('pass',),
'passen': ('pass',),
'passene': ('pass',),
'passer': ('pass',),
'passacaglia': ('passacaglia',),
'passacagliaen': ('passacaglia',),
'passacagliaene': ('passacaglia',),
'passacagliaer': ('passacaglia',),
'passasje': ('passasje',),
'passasjen': ('passasje',),
'passasjene': ('passasje',),
'passasjer': ('passasje',),
'passasjer': ('passasjer',),
'passasjeren': ('passasjer',),
'passasjerene': ('passasjer',),
'passasjerer': ('passasjer',),
'passasjerbåt': ('passasjerbåt',),
'passasjerbåten': ('passasjerbåt',),
'passasjerbåtene': ('passasjerbåt',),
'passasjerbåter': ('passasjerbåt',),
'passasjerfly': ('passasjerfly',),
'passasjerflya': ('passasjerfly',),
'passasjerflyene': ('passasjerfly',),
'passasjerflyet': ('passasjerfly',),
'passasjertog': ('passasjertog',),
'passasjertoga': ('passasjertog',),
'passasjertogene': ('passasjertog',),
'passasjertoget': ('passasjertog',),
'passat': ('passat',),
'passaten': ('passat',),
'passatene': ('passat',),
'passater': ('passat',),
'passbåt': ('passbåt',),
'passbåten': ('passbåt',),
'passbåtene': ('passbåt',),
'passbåter': ('passbåt',),
'passe-partout': ('passe-partout',),
'passe-partouten': ('passe-partout',),
'passe-partoutene': ('passe-partout',),
'passe-partouter': ('passe-partout',),
'passer': ('passer',),
'passere': ('passer',),
'passeren': ('passer',),
'passerer': ('passer',),
'passerne': ('passer',),
'passer': ('passer',),
'passere': ('passer',),
'passeren': ('passer',),
'passerer': ('passer',),
'passerne': ('passer',),
'passeringstid': ('passeringstid',),
'passeringstida': ('passeringstid',),
'passeringstiden': ('passeringstid',),
'passeringstidene': ('passeringstid',),
'passeringstider': ('passeringstid',),
'passerseddel': ('passerseddel',),
'passerseddelen': ('passerseddel',),
'passerseddlene': ('passerseddel',),
'passerseddler': ('passerseddel',),
'passform': ('passform',),
'passforma': ('passform',),
'passformen': ('passform',),
'passformene': ('passform',),
'passformer': ('passform',),
'passfoto': ('passfoto',),
'passfotoa': ('passfoto',),
'passfotoene': ('passfoto',),
'passfotoer': ('passfoto',),
'passfotoet': ('passfoto',),
'passgang': ('passgang',),
'passgangen': ('passgang',),
'passgangene': ('passgang',),
'passganger': ('passgang',),
'passgjenger': ('passgjenger',),
'passgjengere': ('passgjenger',),
'passgjengeren': ('passgjenger',),
'passgjengerer': ('passgjenger',),
'passgjengerne': ('passgjenger',),
'passiar': ('passiar',),
'passiaren': ('passiar',),
'passiarene': ('passiar',),
'passiarer': ('passiar',),
'passiv': ('passiv',),
'passiven': ('passiv',),
'passivene': ('passiv',),
'passiver': ('passiv',),
'passivitet': ('passivitet',),
'passiviteten': ('passivitet',),
'passivitetene': ('passivitet',),
'passiviteter': ('passivitet',),
'passiva': ('passivum',),
'passivaene': ('passivum',),
'passivene': ('passivum',),
'passiver': ('passivum',),
'passivum': ('passivum',),
'passivumet': ('passivum',),
'passkontroll': ('passkontroll',),
'passkontrollen': ('passkontroll',),
'passkontrollene': ('passkontroll',),
'passkontroller': ('passkontroll',),
'passord': ('passord',),
'passorda': ('passord',),
'passordene': ('passord',),
'passordet': ('passord',),
'passus': ('passus',),
'passusen': ('passus',),
'passusene': ('passus',),
'passuser': ('passus',),
'pasta': ('pasta',),
'pastaen': ('pasta',),
'pastaene': ('pasta',),
'pastaer': ('pasta',),
'paste-up': ('paste-up',),
'paste-upen': ('paste-up',),
'paste-upene': ('paste-up',),
'paste-uper': ('paste-up',),
'pastell': ('pastell',),
'pastellen': ('pastell',),
'pastellene': ('pastell',),
'pasteller': ('pastell',),
'pastellbilda': ('pastellbilde',),
'pastellbilde': ('pastellbilde',),
'pastellbildene': ('pastellbilde',),
'pastellbilder': ('pastellbilde',),
'pastellbildet': ('pastellbilde',),
'pastellfarge': ('pastellfarge',),
'pastellfargen': ('pastellfarge',),
'pastellfargene': ('pastellfarge',),
'pastellfarger': ('pastellfarge',),
'pastellmaleri': ('pastellmaleri',),
'pastellmaleria': ('pastellmaleri',),
'pastellmaleriene': ('pastellmaleri',),
'pastellmalerier': ('pastellmaleri',),
'pastellmaleriet': ('pastellmaleri',),
'pastellstift': ('pastellstift',),
'pastellstiften': ('pastellstift',),
'pastellstiftene': ('pastellstift',),
'pastellstifter': ('pastellstift',),
'pastill': ('pastill',),
'pastillen': ('pastill',),
'pastillene': ('pastill',),
'pastiller': ('pastill',),
'pastinakk': ('pastinakk',),
'pastinakken': ('pastinakk',),
'pastinakkene': ('pastinakk',),
'pastinakker': ('pastinakk',),
'pastisj': ('pastisj',),
'pastisjen': ('pastisj',),
'pastisjene': ('pastisj',),
'pastisjer': ('pastisj',),
'pastor': ('pastor',),
'pastoren': ('pastor',),
'pastorene': ('pastor',),
'pastorer': ('pastor',),
'pastorale': ('pastorale',),
'pastoralen': ('pastorale',),
'pastoralene': ('pastorale',),
'pastoraler': ('pastorale',),
'pastoralteologi': ('pastoralteologi',),
'pastoralteologien': ('pastoralteologi',),
'pastoralteologiene': ('pastoralteologi',),
'pastoralteologier': ('pastoralteologi',),
'pastorat': ('pastorat',),
'pastorata': ('pastorat',),
'pastoratene': ('pastorat',),
'pastorater': ('pastorat',),
'pastoratet': ('pastorat',),
'pateen': ('paté',),
'pateene': ('paté',),
'pateer': ('paté',),
'paté': ('paté',),
'patéen': ('paté',),
'patéene': ('paté',),
'patéer': ('paté',),
'patent': ('patent',),
'patenta': ('patent',),
'patentene': ('patent',),
'patenter': ('patent',),
'patentet': ('patent',),
'patentfører': ('patentfører',),
'patentførere': ('patentfører',),
'patentføreren': ('patentfører',),
'patentførerer': ('patentfører',),
'patentførerne': ('patentfører',),
'patentkork': ('patentkork',),
'patentkorken': ('patentkork',),
'patentkorkene': ('patentkork',),
'patentkorker': ('patentkork',),
'patentløsning': ('patentløsning',),
'patentløsninga': ('patentløsning',),
'patentløsningen': ('patentløsning',),
'patentløsningene': ('patentløsning',),
'patentløsninger': ('patentløsning',),
'patentmedisin': ('patentmedisin',),
'patentmedisinen': ('patentmedisin',),
'patentmedisinene': ('patentmedisin',),
'patentmedisiner': ('patentmedisin',),
'patentmiddel': ('patentmiddel',),
'patentmiddelet': ('patentmiddel',),
'patentmidla': ('patentmiddel',),
'patentmidlene': ('patentmiddel',),
'patentmidler': ('patentmiddel',),
'patentmidlet': ('patentmiddel',),
'pater': ('pater',),
'patere': ('pater',),
'pateren': ('pater',),
'paterer': ('pater',),
'paterne': ('pater',),
'patre': ('pater',),
'patrene': ('pater',),
'patrer': ('pater',),
'pater familias': ('pater familias',),
'paternalisme': ('paternalisme',),
'paternalismen': ('paternalisme',),
'paternalismene': ('paternalisme',),
'paternalismer': ('paternalisme',),
'paternitet': ('paternitet',),
'paterniteten': ('paternitet',),
'paternitetene': ('paternitet',),
'paterniteter': ('paternitet',),
'paternoster': ('paternoster',),
'paternosteret': ('paternoster',),
'paternostra': ('paternoster',),
'paternostre': ('paternoster',),
'paternostrene': ('paternoster',),
'paternostret': ('paternoster',),
'paternosterheis': ('paternosterheis',),
'paternosterheisen': ('paternosterheis',),
'paternosterheisene': ('paternosterheis',),
'paternosterheiser': ('paternosterheis',),
'paternosterverk': ('paternosterverk',),
'paternosterverka': ('paternosterverk',),
'paternosterverkene': ('paternosterverk',),
'paternosterverker': ('paternosterverk',),
'paternosterverket': ('paternosterverk',),
'patiens': ('patiens',),
'patiensen': ('patiens',),
'patiensene': ('patiens',),
'patienser': ('patiens',),
'patina': ('patina',),
'patinaen': ('patina',),
'patinaene': ('patina',),
'patinaer': ('patina',),
'patogenese': ('patogenese',),
'patogenesen': ('patogenese',),
'patogenesene': ('patogenese',),
'patogeneser': ('patogenese',),
'patografi': ('patografi',),
'patografien': ('patografi',),
'patografiene': ('patografi',),
'patografier': ('patografi',),
'patolog': ('patolog',),
'patologen': ('patolog',),
'patologene': ('patolog',),
'patologer': ('patolog',),
'patologi': ('patologi',),
'patologien': ('patologi',),
'patologiene': ('patologi',),
'patologier': ('patologi',),
'patos': ('patos',),
'patosen': ('patos',),
'patosene': ('patos',),
'patoser': ('patos',),
'patriark': ('patriark',),
'patriarken': ('patriark',),
'patriarkene': ('patriark',),
'patriarker': ('patriark',),
'patriarkat': ('patriarkat',),
'patriarkata': ('patriarkat',),
'patriarkatene': ('patriarkat',),
'patriarkater': ('patriarkat',),
'patriarkatet': ('patriarkat',),
'patriot': ('patriot',),
'patrioten': ('patriot',),
'patriotene': ('patriot',),
'patrioter': ('patriot',),
'patriotisme': ('patriotisme',),
'patriotismen': ('patriotisme',),
'patriotismene': ('patriotisme',),
'patriotismer': ('patriotisme',),
'patrisier': ('patrisier',),
'patrisiere': ('patrisier',),
'patrisieren': ('patrisier',),
'patrisierer': ('patrisier',),
'patrisierne': ('patrisier',),
'patrisierfamilie': ('patrisierfamilie',),
'patrisierfamilien': ('patrisierfamilie',),
'patrisierfamiliene': ('patrisierfamilie',),
'patrisierfamilier': ('patrisierfamilie',),
'patrisierhus': ('patrisierhus',),
'patrisierhusa': ('patrisierhus',),
'patrisierhusene': ('patrisierhus',),
'patrisierhuset': ('patrisierhus',),
'patron': ('patron',),
'patronen': ('patron',),
'patronene': ('patron',),
'patroner': ('patron',),
'patron': ('patron',),
'patronen': ('patron',),
'patronene': ('patron',),
'patroner': ('patron',),
'patronasje': ('patronasje',),
'patronasjen': ('patronasje',),
'patronasjene': ('patronasje',),
'patronasjer': ('patronasje',),
'patronbelta': ('patronbelte',),
'patronbelte': ('patronbelte',),
'patronbeltene': ('patronbelte',),
'patronbelter': ('patronbelte',),
'patronbeltet': ('patronbelte',),
'patronym': ('patronym',),
'patronyma': ('patronym',),
'patronymene': ('patronym',),
'patronymer': ('patronym',),
'patronymet': ('patronym',),
'patronymika': ('patronymikon',),
'patronymikaene': ('patronymikon',),
'patronymikon': ('patronymikon',),
'patronymikonet': ('patronymikon',),
'patrulje': ('patrulje',),
'patruljen': ('patrulje',),
'patruljene': ('patrulje',),
'patruljer': ('patrulje',),
'patruljebil': ('patruljebil',),
'patruljebilen': ('patruljebil',),
'patruljebilene': ('patruljebil',),
'patruljebiler': ('patruljebil',),
'patruljebåt': ('patruljebåt',),
'patruljebåten': ('patruljebåt',),
'patruljebåtene': ('patruljebåt',),
'patruljebåter': ('patruljebåt',),
'patruljeløp': ('patruljeløp',),
'patruljeløpa': ('patruljeløp',),
'patruljeløpene': ('patruljeløp',),
'patruljeløpet': ('patruljeløp',),
'patt': ('patt',),
'patten': ('patt',),
'pattene': ('patt',),
'patter': ('patt',),
'patte': ('patte',),
'patten': ('patte',),
'pattene': ('patte',),
'patter': ('patte',),
'pattebarn': ('pattebarn',),
'pattebarna': ('pattebarn',),
'pattebarnene': ('pattebarn',),
'pattebarnet': ('pattebarn',),
'pattedyr': ('pattedyr',),
'pattedyra': ('pattedyr',),
'pattedyrene': ('pattedyr',),
'pattedyret': ('pattedyr',),
'pauke': ('pauke',),
'pauken': ('pauke',),
'paukene': ('pauke',),
'pauker': ('pauke',),
'paukeslager': ('paukeslager',),
'paukeslagere': ('paukeslager',),
'paukeslageren': ('paukeslager',),
'paukeslagerer': ('paukeslager',),
'paukeslagerne': ('paukeslager',),
'paukist': ('paukist',),
'paukisten': ('paukist',),
'paukistene': ('paukist',),
'paukister': ('paukist',),
'pauli ord': ('pauli ord',),
'paulun': ('paulun',),
'pauluna': ('paulun',),
'paulunene': ('paulun',),
'pauluner': ('paulun',),
'paulunet': ('paulun',),
'pauperisme': ('pauperisme',),
'pauperismen': ('pauperisme',),
'pauperismene': ('pauperisme',),
'pauperismer': ('pauperisme',),
'pause': ('pause',),
'pausen': ('pause',),
'pausene': ('pause',),
'pauser': ('pause',),
'pausemusikk': ('pausemusikk',),
'pausemusikken': ('pausemusikk',),
'pausemusikkene': ('pausemusikk',),
'pausemusikker': ('pausemusikk',),
'pausesignal': ('pausesignal',),
'pausesignala': ('pausesignal',),
'pausesignalene': ('pausesignal',),
'pausesignaler': ('pausesignal',),
'pausesignalet': ('pausesignal',),
'pauvres honteux': ('pauvres honteux',),
'pave': ('pave',),
'paven': ('pave',),
'pavene': ('pave',),
'paver': ('pave',),
'pavedømma': ('pavedømme',),
'pavedømme': ('pavedømme',),
'pavedømmene': ('pavedømme',),
'pavedømmer': ('pavedømme',),
'pavedømmet': ('pavedømme',),
'pavekirka': ('pavekirke',),
'pavekirke': ('pavekirke',),
'pavekirken': ('pavekirke',),
'pavekirkene': ('pavekirke',),
'pavekirker': ('pavekirke',),
'pavekjerka': ('pavekjerke',),
'pavekjerke': ('pavekjerke',),
'pavekjerken': ('pavekjerke',),
'pavekjerkene': ('pavekjerke',),
'pavekjerker': ('pavekjerke',),
'paviljong': ('paviljong',),
'paviljongen': ('paviljong',),
'paviljongene': ('paviljong',),
'paviljonger': ('paviljong',),
'paviljongsystem': ('paviljongsystem',),
'paviljongsystema': ('paviljongsystem',),
'paviljongsystemene': ('paviljongsystem',),
'paviljongsystemer': ('paviljongsystem',),
'paviljongsystemet': ('paviljongsystem',),
'pc': ('pc',),
'pc-en': ('pc',),
'pc-ene': ('pc',),
'pc-er': ('pc',),
'pd': ('pd',),
'pden': ('pd',),
'pdene': ('pd',),
'pder': ('pd',),
'pd-setting': ('pd-setting',),
'pd-settinga': ('pd-setting',),
'pd-settingen': ('pd-setting',),
'pd-settingene': ('pd-setting',),
'pd-settinger': ('pd-setting',),
'peanøtt': ('peanøtt',),
'peanøtta': ('peanøtt',),
'peanøtten': ('peanøtt',),
'peanøttene': ('peanøtt',),
'peanøtter': ('peanøtt',),
'peanøttsmør': ('peanøttsmør',),
'peanøttsmøra': ('peanøttsmør',),
'peanøttsmørene': ('peanøttsmør',),
'peanøttsmøret': ('peanøttsmør',),
'peau de pêche': ('peau de pêche',),
'peau de pêchen': ('peau de pêche',),
'peau de pêchene': ('peau de pêche',),
'peau de pêcher': ('peau de pêche',),
'pedagog': ('pedagog',),
'pedagogen': ('pedagog',),
'pedagogene': ('pedagog',),
'pedagoger': ('pedagog',),
'pedagogi': ('pedagogi',),
'pedagogien': ('pedagogi',),
'pedagogiene': ('pedagogi',),
'pedagogier': ('pedagogi',),
'pedagogikk': ('pedagogikk',),
'pedagogikken': ('pedagogikk',),
'pedagogikkene': ('pedagogikk',),
'pedagogikker': ('pedagogikk',),
'pedal': ('pedal',),
'pedalen': ('pedal',),
'pedalene': ('pedal',),
'pedaler': ('pedal',),
'pedant': ('pedant',),
'pedanten': ('pedant',),
'pedantene': ('pedant',),
'pedanter': ('pedant',),
'pedanteri': ('pedanteri',),
'pedanteria': ('pedanteri',),
'pedanteriene': ('pedanteri',),
'pedanterier': ('pedanteri',),
'pedanteriet': ('pedanteri',),
'peddig': ('peddig',),
'peddigen': ('peddig',),
'peddigene': ('peddig',),
'peddiger': ('peddig',),
'peddigfletning': ('peddigfletning',),
'peddigfletninga': ('peddigfletning',),
'peddigfletningen': ('peddigfletning',),
'peddigfletningene': ('peddigfletning',),
'peddigfletninger': ('peddigfletning',),
'peddigrør': ('peddigrør',),
'peddigrøra': ('peddigrør',),
'peddigrørene': ('peddigrør',),
'peddigrøret': ('peddigrør',),
'pedell': ('pedell',),
'pedellen': ('pedell',),
'pedellene': ('pedell',),
'pedeller': ('pedell',),
'pederast': ('pederast',),
'pederasten': ('pederast',),
'pederastene': ('pederast',),
'pederaster': ('pederast',),
'pederasti': ('pederasti',),
'pederastien': ('pederasti',),
'pederastiene': ('pederasti',),
'pederastier': ('pederasti',),
'pediater': ('pediater',),
'pediatere': ('pediater',),
'pediateren': ('pediater',),
'pediaterer': ('pediater',),
'pediaterne': ('pediater',),
'pediatri': ('pediatri',),
'pediatrien': ('pediatri',),
'pediatriene': ('pediatri',),
'pediatrier': ('pediatri',),
'pedikyr': ('pedikyr',),
'pedikyren': ('pedikyr',),
'pedikyrene': ('pedikyr',),
'pedikyrer': ('pedikyr',),
'pedikyre': ('pedikyre',),
'pedikyren': ('pedikyre',),
'pedikyrene': ('pedikyre',),
'pedikyrer': ('pedikyre',),
'pedikyrist': ('pedikyrist',),
'pedikyristen': ('pedikyrist',),
'pedikyristene': ('pedikyrist',),
'pedikyrister': ('pedikyrist',),
'pedofili': ('pedofili',),
'pedofilien': ('pedofili',),
'pedofiliene': ('pedofili',),
'pedofilier': ('pedofili',),
'pedometer': ('pedometer',),
'pedometeret': ('pedometer',),
'pedometra': ('pedometer',),
'pedometre': ('pedometer',),
'pedometrene': ('pedometer',),
'pedometret': ('pedometer',),
'peer': ('peer',),
'peeren': ('peer',),
'peerene': ('peer',),
'peerer': ('peer',),
'peers': ('peer',),
'pegasus': ('pegasus',),
'pegasusen': ('pegasus',),
'pegasusene': ('pegasus',),
'pegasuser': ('pegasus',),
'peiling': ('peiling',),
'peilinga': ('peiling',),
'peilingen': ('peiling',),
'peilingene': ('peiling',),
'peilinger': ('peiling',),
'peis': ('peis',),
'peisen': ('peis',),
'peisene': ('peis',),
'peiser': ('peis',),
'peis': ('peis',),
'peisen': ('peis',),
'peisene': ('peis',),
'peiser': ('peis',),
'peisestova': ('peisestove',),
'peisestove': ('peisestove',),
'peisestoven': ('peisestove',),
'peisestovene': ('peisestove',),
'peisestover': ('peisestove',),
'peisestua': ('peisestue',),
'peisestue': ('peisestue',),
'peisestuen': ('peisestue',),
'peisestuene': ('peisestue',),
'peisestuer': ('peisestue',),
'peishylla': ('peishylle',),
'peishylle': ('peishylle',),
'peishyllen': ('peishylle',),
'peishyllene': ('peishylle',),
'peishyller': ('peishylle',),
'peiskos': ('peiskos',),
'peiskosen': ('peiskos',),
'peiskosene': ('peiskos',),
'peiskoser': ('peiskos',),
'peispuster': ('peispuster',),
'peispustere': ('peispuster',),
'peispusteren': ('peispuster',),
'peispusterer': ('peispuster',),
'peispusterne': ('peispuster',),
'pek': ('pek',),
'peka': ('pek',),
'pekene': ('pek',),
'peket': ('pek',),
'pekefinger': ('pekefinger',),
'pekefingeren': ('pekefinger',),
'pekefingre': ('pekefinger',),
'pekefingrene': ('pekefinger',),
'pekefingrer': ('pekefinger',),
'pekepinn': ('pekepinn',),
'pekepinnen': ('pekepinn',),
'pekepinnene': ('pekepinn',),
'pekepinner': ('pekepinn',),
'pekingeser': ('pekingeser',),
'pekingesere': ('pekingeser',),
'pekingeseren': ('pekingeser',),
'pekingeserer': ('pekingeser',),
'pekingeserne': ('pekingeser',),
'pektin': ('pektin',),
'pektina': ('pektin',),
'pektinene': ('pektin',),
'pektiner': ('pektin',),
'pektinet': ('pektin',),
'pel': ('pel',),
'pelen': ('pel',),
'pelene': ('pel',),
'peler': ('pel',),
'pelargonia': ('pelargonia',),
'pelargoniaen': ('pelargonia',),
'pelargoniaene': ('pelargonia',),
'pelargoniaer': ('pelargonia',),
'pelargonien': ('pelargonium',),
'pelargoniene': ('pelargonium',),
'pelargonier': ('pelargonium',),
'pelargonium': ('pelargonium',),
'pelargoniumen': ('pelargonium',),
'pelement': ('pelement',),
'pelementa': ('pelement',),
'pelementene': ('pelement',),
'pelementer': ('pelement',),
'pelementet': ('pelement',),
'pelikan': ('pelikan',),
'pelikanen': ('pelikan',),
'pelikanene': ('pelikan',),
'pelikaner': ('pelikan',),
'pell': ('pell',),
'pella': ('pell',),
'pellen': ('pell',),
'pellene': ('pell',),
'peller': ('pell',),
'pellet': ('pell',),
'pellagra': ('pellagra',),
'pellagraen': ('pellagra',),
'pellagraene': ('pellagra',),
'pellagraer': ('pellagra',),
'pellet': ('pellet',),
'pelleten': ('pellet',),
'pelletene': ('pellet',),
'pelleter': ('pellet',),
'pelotong': ('pelotong',),
'pelotongen': ('pelotong',),
'pelotongene': ('pelotong',),
'pelotonger': ('pelotong',),
'pelotte': ('pelotte',),
'pelotten': ('pelotte',),
'pelottene': ('pelotte',),
'pelotter': ('pelotte',),
'pels': ('pels',),
'pelsen': ('pels',),
'pelsene': ('pels',),
'pelser': ('pels',),
'pelsdyr': ('pelsdyr',),
'pelsdyra': ('pelsdyr',),
'pelsdyrene': ('pelsdyr',),
'pelsdyret': ('pelsdyr',),
'pelsdyrfarm': ('pelsdyrfarm',),
'pelsdyrfarmen': ('pelsdyrfarm',),
'pelsdyrfarmene': ('pelsdyrfarm',),
'pelsdyrfarmer': ('pelsdyrfarm',),
'pelsverk': ('pelsverk',),
'pelsverka': ('pelsverk',),
'pelsverkene': ('pelsverk',),
'pelsverker': ('pelsverk',),
'pelsverket': ('pelsverk',),
'pemmikan': ('pemmikan',),
'pemmikanen': ('pemmikan',),
'pemmikanene': ('pemmikan',),
'pemmikaner': ('pemmikan',),
'pendant': ('pendant',),
'pendanten': ('pendant',),
'pendantene': ('pendant',),
'pendanter': ('pendant',),
'pendel': ('pendel',),
'pendelen': ('pendel',),
'pendlene': ('pendel',),
'pendler': ('pendel',),
'pendelsvingning': ('pendelsvingning',),
'pendelsvingninga': ('pendelsvingning',),
'pendelsvingningen': ('pendelsvingning',),
'pendelsvingningene': ('pendelsvingning',),
'pendelsvingninger': ('pendelsvingning',),
'pendeltrafikk': ('pendeltrafikk',),
'pendeltrafikken': ('pendeltrafikk',),
'pendeltrafikkene': ('pendeltrafikk',),
'pendeltrafikker': ('pendeltrafikk',),
'pendler': ('pendler',),
'pendlere': ('pendler',),
'pendleren': ('pendler',),
'pendlerer': ('pendler',),
'pendlerne': ('pendler',),
'pendlerkommune': ('pendlerkommune',),
'pendlerkommunen': ('pendlerkommune',),
'pendlerkommunene': ('pendlerkommune',),
'pendlerkommuner': ('pendlerkommune',),
'peneplan': ('peneplan',),
'peneplana': ('peneplan',),
'peneplanene': ('peneplan',),
'peneplaner': ('peneplan',),
'peneplanet': ('peneplan',),
'penge': ('penge',),
'pengen': ('penge',),
'pengene': ('penge',),
'penger': ('penge',),
'pengebok': ('pengebok',),
'pengeboka': ('pengebok',),
'pengeboken': ('pengebok',),
'pengebøkene': ('pengebok',),
'pengebøker': ('pengebok',),
'pengegras': ('pengegras',),
'pengegrasa': ('pengegras',),
'pengegrasene': ('pengegras',),
'pengegraset': ('pengegras',),
'pengegress': ('pengegress',),
'pengegressa': ('pengegress',),
'pengegressene': ('pengegress',),
'pengegresset': ('pengegress',),
'pengehusholdning': ('pengehusholdning',),
'pengehusholdninga': ('pengehusholdning',),
'pengehusholdningen': ('pengehusholdning',),
'pengehusholdningene': ('pengehusholdning',),
'pengehusholdninger': ('pengehusholdning',),
'pengeplassering': ('pengeplassering',),
'pengeplasseringa': ('pengeplassering',),
'pengeplasseringen': ('pengeplassering',),
'pengeplasseringene': ('pengeplassering',),
'pengeplasseringer': ('pengeplassering',),
'pengepung': ('pengepung',),
'pengepungen': ('pengepung',),
'pengepungene': ('pengepung',),
'pengepunger': ('pengepung',),
'pengesekk': ('pengesekk',),
'pengesekken': ('pengesekk',),
'pengesekkene': ('pengesekk',),
'pengesekker': ('pengesekk',),
'pengeurt': ('pengeurt',),
'pengeurta': ('pengeurt',),
'pengeurten': ('pengeurt',),
'pengeurtene': ('pengeurt',),
'pengeurter': ('pengeurt',),
'penicillin': ('penicillin',),
'penicillina': ('penicillin',),
'penicillinene': ('penicillin',),
'penicillinet': ('penicillin',),
'penicillinkur': ('penicillinkur',),
'penicillinkuren': ('penicillinkur',),
'penicillinkurene': ('penicillinkur',),
'penicillinkurer': ('penicillinkur',),
'penis': ('penis',),
'penisen': ('penis',),
'penisene': ('penis',),
'peniser': ('penis',),
'penn': ('penn',),
'pennen': ('penn',),
'pennene': ('penn',),
'penner': ('penn',),
'penn': ('penn',),
'pennen': ('penn',),
'pennene': ('penn',),
'penner': ('penn',),
'pennal': ('pennal',),
'pennala': ('pennal',),
'pennalene': ('pennal',),
'pennaler': ('pennal',),
'pennalet': ('pennal',),
'penneknekt': ('penneknekt',),
'penneknekten': ('penneknekt',),
'penneknektene': ('penneknekt',),
'penneknekter': ('penneknekt',),
'pennestrøk': ('pennestrøk',),
'pennestrøka': ('pennestrøk',),
'pennestrøkene': ('pennestrøk',),
'pennestrøket': ('pennestrøk',),
'pennevenn': ('pennevenn',),
'pennevennen': ('pennevenn',),
'pennevennene': ('pennevenn',),
'pennevenner': ('pennevenn',),
'pennhammar': ('pennhammar',),
'pennhammaren': ('pennhammar',),
'pennhamrene': ('pennhammar',),
'pennhamrer': ('pennhammar',),
'pennhammer': ('pennhammer',),
'pennhammere': ('pennhammer',),
'pennhammeren': ('pennhammer',),
'pennhammerer': ('pennhammer',),
'pennhammerne': ('pennhammer',),
'pennhamrene': ('pennhammer',),
'pennhamrer': ('pennhammer',),
'penning': ('penning',),
'penningen': ('penning',),
'penningene': ('penning',),
'penninger': ('penning',),
'pence': ('penny',),
'pencene': ('penny',),
'penny': ('penny',),
'pennyen': ('penny',),
'pennyene': ('penny',),
'pennyer': ('penny',),
'pens': ('pens',),
'pensen': ('pens',),
'pensene': ('pens',),
'penser': ('pens',),
'pensel': ('pensel',),
'penselen': ('pensel',),
'penslene': ('pensel',),
'pensler': ('pensel',),
'pensjon': ('pensjon',),
'pensjonen': ('pensjon',),
'pensjonene': ('pensjon',),
'pensjoner': ('pensjon',),
'pensjonat': ('pensjonat',),
'pensjonata': ('pensjonat',),
'pensjonatene': ('pensjonat',),
'pensjonater': ('pensjonat',),
'pensjonatet': ('pensjonat',),
'pensjonatskole': ('pensjonatskole',),
'pensjonatskolen': ('pensjonatskole',),
'pensjonatskolene': ('pensjonatskole',),
'pensjonatskoler': ('pensjonatskole',),
'pensjonist': ('pensjonist',),
'pensjonisten': ('pensjonist',),
'pensjonistene': ('pensjonist',),
'pensjonister': ('pensjonist',),
'pensjonsalder': ('pensjonsalder',),
'pensjonsaldere': ('pensjonsalder',),
'pensjonsalderen': ('pensjonsalder',),
'pensjonsalderer': ('pensjonsalder',),
'pensjonsalderne': ('pensjonsalder',),
'pensjonsaldre': ('pensjonsalder',),
'pensjonsaldrene': ('pensjonsalder',),
'pensjonsaldrer': ('pensjonsalder',),
'pensjonsforsikring': ('pensjonsforsikring',),
'pensjonsforsikringa': ('pensjonsforsikring',),
'pensjonsforsikringen': ('pensjonsforsikring',),
'pensjonsforsikringene': ('pensjonsforsikring',),
'pensjonsforsikringer': ('pensjonsforsikring',),
'pensjonskassa': ('pensjonskasse',),
'pensjonskasse': ('pensjonskasse',),
'pensjonskassen': ('pensjonskasse',),
'pensjonskassene': ('pensjonskasse',),
'pensjonskasser': ('pensjonskasse',),
'pensjonspoeng': ('pensjonspoeng',),
'pensjonspoenga': ('pensjonspoeng',),
'pensjonspoengene': ('pensjonspoeng',),
'pensjonspoenger': ('pensjonspoeng',),
'pensjonspoenget': ('pensjonspoeng',),
'pensjonær': ('pensjonær',),
'pensjonæren': ('pensjonær',),
'pensjonærene': ('pensjonær',),
'pensjonærer': ('pensjonær',),
'pensa': ('pensum',),
'pensaene': ('pensum',),
'pensum': ('pensum',),
'pensuma': ('pensum',),
'pensumene': ('pensum',),
'pensumer': ('pensum',),
'pensumet': ('pensum',),
'pentaeder': ('pentaeder',),
'pentaederet': ('pentaeder',),
'pentaedra': ('pentaeder',),
'pentaedre': ('pentaeder',),
'pentaedrene': ('pentaeder',),
'pentaedret': ('pentaeder',),
'pentagon': ('pentagon',),
'pentagonen': ('pentagon',),
'pentagonene': ('pentagon',),
'pentagoner': ('pentagon',),
'pentagram': ('pentagram',),
'pentagramma': ('pentagram',),
'pentagrammene': ('pentagram',),
'pentagrammer': ('pentagram',),
'pentagrammet': ('pentagram',),
'pentameter': ('pentameter',),
'pentameteret': ('pentameter',),
'pentametra': ('pentameter',),
'pentametre': ('pentameter',),
'pentametrene': ('pentameter',),
'pentametret': ('pentameter',),
'penteri': ('penteri',),
'penteria': ('penteri',),
'penteriene': ('penteri',),
'penterier': ('penteri',),
'penteriet': ('penteri',),
'penultima': ('penultima',),
'penultimaen': ('penultima',),
'penultimaene': ('penultima',),
'penultimaer': ('penultima',),
'peon': ('peon',),
'peonen': ('peon',),
'peonene': ('peon',),
'peoner': ('peon',),
'pep': ('pep',),
'pepen': ('pep',),
'pepene': ('pep',),
'peper': ('pep',),
'pepp': ('pepp',),
'peppen': ('pepp',),
'peppene': ('pepp',),
'pepper': ('pepp',),
'pepper': ('pepper',),
'peppere': ('pepper',),
'pepperen': ('pepper',),
'pepperer': ('pepper',),
'pepperne': ('pepper',),
'peprene': ('pepper',),
'peprer': ('pepper',),
'pepperkaka': ('pepperkake',),
'pepperkake': ('pepperkake',),
'pepperkaken': ('pepperkake',),
'pepperkakene': ('pepperkake',),
'pepperkaker': ('pepperkake',),
'pepperkvern': ('pepperkvern',),
'pepperkverna': ('pepperkvern',),
'pepperkvernen': ('pepperkvern',),
'pepperkvernene': ('pepperkvern',),
'pepperkverner': ('pepperkvern',),
'peppermynta': ('peppermynte',),
'peppermynte': ('peppermynte',),
'peppermynten': ('peppermynte',),
'peppermyntene': ('peppermynte',),
'peppermynter': ('peppermynte',),
'peppermø': ('peppermø',),
'peppermøa': ('peppermø',),
'peppermøen': ('peppermø',),
'peppermøene': ('peppermø',),
'peppermøer': ('peppermø',),
'peppermøy': ('peppermøy',),
'peppermøya': ('peppermøy',),
'peppermøyen': ('peppermøy',),
'peppermøyene': ('peppermøy',),
'peppermøyer': ('peppermøy',),
'peppernøtt': ('peppernøtt',),
'peppernøtta': ('peppernøtt',),
'peppernøtten': ('peppernøtt',),
'peppernøttene': ('peppernøtt',),
'peppernøtter': ('peppernøtt',),
'peppersvenn': ('peppersvenn',),
'peppersvennen': ('peppersvenn',),
'peppersvennene': ('peppersvenn',),
'peppersvenner': ('peppersvenn',),
'pepsin': ('pepsin',),
'pepsina': ('pepsin',),
'pepsinene': ('pepsin',),
'pepsinet': ('pepsin',),
'peptalk': ('peptalk',),
'peptalken': ('peptalk',),
'peptalkene': ('peptalk',),
'peptalker': ('peptalk',),
'perborat': ('perborat',),
'perborata': ('perborat',),
'perboratene': ('perborat',),
'perborater': ('perborat',),
'perboratet': ('perborat',),
'perenn': ('perenn',),
'perennen': ('perenn',),
'perennene': ('perenn',),
'perenner': ('perenn',),
'perestrojka': ('perestrojka',),
'perestrojkaen': ('perestrojka',),
'perestrojkaene': ('perestrojka',),
'perestrojkaer': ('perestrojka',),
'perfeksjon': ('perfeksjon',),
'perfeksjonen': ('perfeksjon',),
'perfeksjonene': ('perfeksjon',),
'perfeksjoner': ('perfeksjon',),
'perfeksjonisme': ('perfeksjonisme',),
'perfeksjonismen': ('perfeksjonisme',),
'perfeksjonismene': ('perfeksjonisme',),
'perfeksjonismer': ('perfeksjonisme',),
'perfeksjonist': ('perfeksjonist',),
'perfeksjonisten': ('perfeksjonist',),
'perfeksjonistene': ('perfeksjonist',),
'perfeksjonister': ('perfeksjonist',),
'perfektibilitet': ('perfektibilitet',),
'perfektibiliteten': ('perfektibilitet',),
'perfektibilitetene': ('perfektibilitet',),
'perfektibiliteter': ('perfektibilitet',),
'perfekta': ('perfektum',),
'perfektaene': ('perfektum',),
'perfektene': ('perfektum',),
'perfekter': ('perfektum',),
'perfektum': ('perfektum',),
'perfektumet': ('perfektum',),
'perfiditet': ('perfiditet',),
'perfiditeten': ('perfiditet',),
'perfiditetene': ('perfiditet',),
'perfiditeter': ('perfiditet',),
'perforasjon': ('perforasjon',),
'perforasjonen': ('perforasjon',),
'perforasjonene': ('perforasjon',),
'perforasjoner': ('perforasjon',),
'perforator': ('perforator',),
'perforatoren': ('perforator',),
'perforatorene': ('perforator',),
'perforatorer': ('perforator',),
'perforatør': ('perforatør',),
'perforatøren': ('perforatør',),
'perforatørene': ('perforatør',),
'perforatører': ('perforatør',),
'perforering': ('perforering',),
'perforeringa': ('perforering',),
'perforeringen': ('perforering',),
'perforeringene': ('perforering',),
'perforeringer': ('perforering',),
'pergament': ('pergament',),
'pergamenta': ('pergament',),
'pergamentene': ('pergament',),
'pergamenter': ('pergament',),
'pergamentet': ('pergament',),
'pergamentpapir': ('pergamentpapir',),
'pergamentpapira': ('pergamentpapir',),
'pergamentpapirene': ('pergamentpapir',),
'pergamentpapirer': ('pergamentpapir',),
'pergamentpapiret': ('pergamentpapir',),
'pergola': ('pergola',),
'pergolaen': ('pergola',),
'pergolaene': ('pergola',),
'pergolaer': ('pergola',),
'perial': ('perial',),
'perialen': ('perial',),
'perialene': ('perial',),
'perialer': ('perial',),
'periferi': ('periferi',),
'periferien': ('periferi',),
'periferiene': ('periferi',),
'periferier': ('periferi',),
'periferivinkel': ('periferivinkel',),
'periferivinkelen': ('periferivinkel',),
'periferivinklene': ('periferivinkel',),
'periferivinkler': ('periferivinkel',),
'perifrase': ('perifrase',),
'perifrasen': ('perifrase',),
'perifrasene': ('perifrase',),
'perifraser': ('perifrase',),
'perigea': ('perigé',),
'perigeene': ('perigé',),
'perigeet': ('perigé',),
'perigé': ('perigé',),
'perigeet': ('perigeum',),
'perigeum': ('perigeum',),
'perigeumet': ('perigeum',),
'perihel': ('perihel',),
'perihela': ('perihel',),
'perihelene': ('perihel',),
'perihelet': ('perihel',),
'periheliet': ('perihelium',),
'perihelium': ('perihelium',),
'perikope': ('perikope',),
'perikopen': ('perikope',),
'perikopene': ('perikope',),
'perikoper': ('perikope',),
'perikum': ('perikum',),
'perikumen': ('perikum',),
'perikumene': ('perikum',),
'perikumer': ('perikum',),
'perikumbrennevin': ('perikumbrennevin',),
'perikumbrennevinene': ('perikumbrennevin',),
'perikumbrenneviner': ('perikumbrennevin',),
'perikumbrennevinet': ('perikumbrennevin',),
'perikumolja': ('perikumolje',),
'perikumolje': ('perikumolje',),
'perikumoljen': ('perikumolje',),
'perikumoljene': ('perikumolje',),
'perikumoljer': ('perikumolje',),
'perimeter': ('perimeter',),
'perimetere': ('perimeter',),
'perimeteren': ('perimeter',),
'perimeterer': ('perimeter',),
'perimeterne': ('perimeter',),
'perimetre': ('perimeter',),
'perimetrene': ('perimeter',),
'perimetrer': ('perimeter',),
'perimeter': ('perimeter',),
'perimeteret': ('perimeter',),
'perimetra': ('perimeter',),
'perimetre': ('perimeter',),
'perimetrene': ('perimeter',),
'perimetret': ('perimeter',),
'periode': ('periode',),
'perioden': ('periode',),
'periodene': ('periode',),
'perioder': ('periode',),
'periodedranker': ('periodedranker',),
'periodedrankere': ('periodedranker',),
'periodedrankeren': ('periodedranker',),
'periodedrankerer': ('periodedranker',),
'periodedrankerne': ('periodedranker',),
'periodeomformer': ('periodeomformer',),
'periodeomformere': ('periodeomformer',),
'periodeomformeren': ('periodeomformer',),
'periodeomformerer': ('periodeomformer',),
'periodeomformerne': ('periodeomformer',),
'periodesystem': ('periodesystem',),
'periodesystema': ('periodesystem',),
'periodesystemene': ('periodesystem',),
'periodesystemer': ('periodesystem',),
'periodesystemet': ('periodesystem',),
'periodetal': ('periodetal',),
'periodetala': ('periodetal',),
'periodetalene': ('periodetal',),
'periodetalet': ('periodetal',),
'periodetall': ('periodetall',),
'periodetalla': ('periodetall',),
'periodetallene': ('periodetall',),
'periodetallet': ('periodetall',),
'periodika': ('periodika',),
'periodikene': ('periodika',),
'periodisitet': ('periodisitet',),
'periodisiteten': ('periodisitet',),
'periodisitetene': ('periodisitet',),
'periodisiteter': ('periodisitet',),
'periodonti': ('periodonti',),
'periodontien': ('periodonti',),
'periodontiene': ('periodonti',),
'periodontier': ('periodonti',),
'periodontitt': ('periodontitt',),
'periodontitten': ('periodontitt',),
'periodontittene': ('periodontitt',),
'periodontitter': ('periodontitt',),
'periskop': ('periskop',),
'periskopa': ('periskop',),
'periskopene': ('periskop',),
'periskoper': ('periskop',),
'periskopet': ('periskop',),
'perkolator': ('perkolator',),
'perkolatoren': ('perkolator',),
'perkolatorene': ('perkolator',),
'perkolatorer': ('perkolator',),
'perkusjon': ('perkusjon',),
'perkusjonen': ('perkusjon',),
'perkusjonene': ('perkusjon',),
'perkusjoner': ('perkusjon',),
'perkusjonist': ('perkusjonist',),
'perkusjonisten': ('perkusjonist',),
'perkusjonistene': ('perkusjonist',),
'perkusjonister': ('perkusjonist',),
'perkusjonsgevær': ('perkusjonsgevær',),
'perkusjonsgeværa': ('perkusjonsgevær',),
'perkusjonsgeværene': ('perkusjonsgevær',),
'perkusjonsgeværer': ('perkusjonsgevær',),
'perkusjonsgeværet': ('perkusjonsgevær',),
'perkusjonsinstrument': ('perkusjonsinstrument',),
'perkusjonsinstrumenta': ('perkusjonsinstrument',),
'perkusjonsinstrumentene': ('perkusjonsinstrument',),
'perkusjonsinstrumenter': ('perkusjonsinstrument',),
'perkusjonsinstrumentet': ('perkusjonsinstrument',),
'perla': ('perle',),
'perle': ('perle',),
'perlen': ('perle',),
'perlene': ('perle',),
'perler': ('perle',),
'perledykker': ('perledykker',),
'perledykkere': ('perledykker',),
'perledykkeren': ('perledykker',),
'perledykkerer': ('perledykker',),
'perledykkerne': ('perledykker',),
'perlefisker': ('perlefisker',),
'perlefiskere': ('perlefisker',),
'perlefiskeren': ('perlefisker',),
'perlefiskerer': ('perlefisker',),
'perlefiskerne': ('perlefisker',),
'perlegarn': ('perlegarn',),
'perlegarna': ('perlegarn',),
'perlegarnene': ('perlegarn',),
'perlegarnet': ('perlegarn',),
'perlehumør': ('perlehumør',),
'perlehumøra': ('perlehumør',),
'perlehumørene': ('perlehumør',),
'perlehumøret': ('perlehumør',),
'perlehøna': ('perlehøne',),
'perlehøne': ('perlehøne',),
'perlehønen': ('perlehøne',),
'perlehønene': ('perlehøne',),
'perlehøner': ('perlehøne',),
'perlehøns': ('perlehøns',),
'perlehønsa': ('perlehøns',),
'perlehønsene': ('perlehøns',),
'perlehønset': ('perlehøns',),
'perlekjeda': ('perlekjede',),
'perlekjede': ('perlekjede',),
'perlekjeden': ('perlekjede',),
'perlekjedene': ('perlekjede',),
'perlekjeder': ('perlekjede',),
'perlekjedet': ('perlekjede',),
'perlemor': ('perlemor',),
'perlemora': ('perlemor',),
'perlemoren': ('perlemor',),
'perlemorene': ('perlemor',),
'perlemorer': ('perlemor',),
'perlemoret': ('perlemor',),
'perlemorsky': ('perlemorsky',),
'perlemorskya': ('perlemorsky',),
'perlemorskyen': ('perlemorsky',),
'perlemorskyene': ('perlemorsky',),
'perlemorskyer': ('perlemorsky',),
'perlemusling': ('perlemusling',),
'perlemuslingen': ('perlemusling',),
'perlemuslingene': ('perlemusling',),
'perlemuslinger': ('perlemusling',),
'perleport': ('perleport',),
'perleporten': ('perleport',),
'perleportene': ('perleport',),
'perleporter': ('perleport',),
'perlestikning': ('perlestikning',),
'perlestikninga': ('perlestikning',),
'perlestikningen': ('perlestikning',),
'perlestikningene': ('perlestikning',),
'perlestikninger': ('perlestikning',),
'perleugla': ('perleugle',),
'perleugle': ('perleugle',),
'perleuglen': ('perleugle',),
'perleuglene': ('perleugle',),
'perleugler': ('perleugle',),
'perlevenn': ('perlevenn',),
'perlevennen': ('perlevenn',),
'perlevennene': ('perlevenn',),
'perlevenner': ('perlevenn',),
'perlon': ('perlon',),
'perlona': ('perlon',),
'perlonene': ('perlon',),
'perlonet': ('perlon',),
'permafrost': ('permafrost',),
'permafrosten': ('permafrost',),
'permafrostene': ('permafrost',),
'permafroster': ('permafrost',),
'permanens': ('permanens',),
'permanensen': ('permanens',),
'permanensene': ('permanens',),
'permanenser': ('permanens',),
'permanent': ('permanent',),
'permanenten': ('permanent',),
'permanentene': ('permanent',),
'permanenter': ('permanent',),
'permformasjon': ('permformasjon',),
'permformasjonen': ('permformasjon',),
'permformasjonene': ('permformasjon',),
'permformasjoner': ('permformasjon',),
'permisjon': ('permisjon',),
'permisjonen': ('permisjon',),
'permisjonene': ('permisjon',),
'permisjoner': ('permisjon',),
'permisjonssøknad': ('permisjonssøknad',),
'permisjonssøknaden': ('permisjonssøknad',),
'permisjonssøknadene': ('permisjonssøknad',),
'permisjonssøknader': ('permisjonssøknad',),
'permisjonsvarsel': ('permisjonsvarsel',),
'permisjonsvarselet': ('permisjonsvarsel',),
'permisjonsvarsla': ('permisjonsvarsel',),
'permisjonsvarslene': ('permisjonsvarsel',),
'permisjonsvarsler': ('permisjonsvarsel',),
'permisjonsvarslet': ('permisjonsvarsel',),
'permittent': ('permittent',),
'permittenten': ('permittent',),
'permittentene': ('permittent',),
'permittenter': ('permittent',),
'permittering': ('permittering',),
'permitteringa': ('permittering',),
'permitteringen': ('permittering',),
'permitteringene': ('permittering',),
'permitteringer': ('permittering',),
'permperiode': ('permperiode',),
'permperioden': ('permperiode',),
'permperiodene': ('permperiode',),
'permperioder': ('permperiode',),
'permsystem': ('permsystem',),
'permsystema': ('permsystem',),
'permsystemene': ('permsystem',),
'permsystemer': ('permsystem',),
'permsystemet': ('permsystem',),
'permutasjon': ('permutasjon',),
'permutasjonen': ('permutasjon',),
'permutasjonene': ('permutasjon',),
'permutasjoner': ('permutasjon',),
'peroksid': ('peroksid',),
'peroksida': ('peroksid',),
'peroksidene': ('peroksid',),
'peroksider': ('peroksid',),
'peroksidet': ('peroksid',),
'perpendikkel': ('perpendikkel',),
'perpendikkelen': ('perpendikkel',),
'perpendiklene': ('perpendikkel',),
'perpendikler': ('perpendikkel',),
'perpendikulær': ('perpendikulær',),
'perpendikulæren': ('perpendikulær',),
'perpendikulærene': ('perpendikulær',),
'perpendikulærer': ('perpendikulær',),
'perpetuum mobile': ('perpetuum mobile',),
'perrong': ('perrong',),
'perrongen': ('perrong',),
'perrongene': ('perrong',),
'perronger': ('perrong',),
'persa': ('perse',),
'perse': ('perse',),
'persen': ('perse',),
'persene': ('perse',),
'perser': ('perse',),
'persejern': ('persejern',),
'persejerna': ('persejern',),
'persejernene': ('persejern',),
'persejernet': ('persejern',),
'persepsjon': ('persepsjon',),
'persepsjonen': ('persepsjon',),
'persepsjonene': ('persepsjon',),
'persepsjoner': ('persepsjon',),
'perser': ('perser',),
'persere': ('perser',),
'perseren': ('perser',),
'perserer': ('perser',),
'perserne': ('perser',),
'persesylta': ('persesylte',),
'persesylte': ('persesylte',),
'persesylten': ('persesylte',),
'persesyltene': ('persesylte',),
'persesylter': ('persesylte',),
'persianer': ('persianer',),
'persianere': ('persianer',),
'persianeren': ('persianer',),
'persianerer': ('persianer',),
'persianerne': ('persianer',),
'persienne': ('persienne',),
'persiennen': ('persienne',),
'persiennene': ('persienne',),
'persienner': ('persienne',),
'persiflasje': ('persiflasje',),
'persiflasjen': ('persiflasje',),
'persiflasjene': ('persiflasje',),
'persiflasjer': ('persiflasje',),
'persilla': ('persille',),
'persille': ('persille',),
'persillen': ('persille',),
'persillene': ('persille',),
'persiller': ('persille',),
'persilleblad': ('persilleblad',),
'persilleblada': ('persilleblad',),
'persillebladene': ('persilleblad',),
'persilleblader': ('persilleblad',),
'persillebladet': ('persilleblad',),
'persillerot': ('persillerot',),
'persillerota': ('persillerot',),
'persilleroten': ('persillerot',),
'persillerøttene': ('persillerot',),
'persillerøtter': ('persillerot',),
'persisk': ('persisk',),
'persisken': ('persisk',),
'persiskene': ('persisk',),
'persisker': ('persisk',),
'persok': ('persok',),
'persoken': ('persok',),
'persokene': ('persok',),
'persoker': ('persok',),
'person': ('person',),
'personen': ('person',),
'personene': ('person',),
'personer': ('person',),
'persona grata': ('persona grata',),
'persona non grata': ('persona non grata',),
'personala': ('personale',),
'personale': ('personale',),
'personalene': ('personale',),
'personaler': ('personale',),
'personalet': ('personale',),
'personalia': ('personalia',),
'personaliene': ('personalia',),
'personalunion': ('personalunion',),
'personalunionen': ('personalunion',),
'personalunionene': ('personalunion',),
'personalunioner': ('personalunion',),
'personasje': ('personasje',),
'personasjen': ('personasje',),
'personasjene': ('personasje',),
'personasjer': ('personasje',),
'personbil': ('personbil',),
'personbilen': ('personbil',),
'personbilene': ('personbil',),
'personbiler': ('personbil',),
'persondata': ('persondata',),
'persondataen': ('persondata',),
'persondataene': ('persondata',),
'persondataet': ('persondata',),
'personell': ('personell',),
'personella': ('personell',),
'personellene': ('personell',),
'personeller': ('personell',),
'personellet': ('personell',),
'persongalleri': ('persongalleri',),
'persongalleria': ('persongalleri',),
'persongalleriene': ('persongalleri',),
'persongallerier': ('persongalleri',),
'persongalleriet': ('persongalleri',),
'personifikasjon': ('personifikasjon',),
'personifikasjonen': ('personifikasjon',),
'personifikasjonene': ('personifikasjon',),
'personifikasjoner': ('personifikasjon',),
'personlighet': ('personlighet',),
'personligheta': ('personlighet',),
'personligheten': ('personlighet',),
'personlighetene': ('personlighet',),
'personligheter': ('personlighet',),
'personlighetsspalting': ('personlighetsspalting',),
'personlighetsspaltinga': ('personlighetsspalting',),
'personlighetsspaltingen': ('personlighetsspalting',),
'personlighetsspaltingene': ('personlighetsspalting',),
'personlighetsspaltinger': ('personlighetsspalting',),
'personlighetsspaltning': ('personlighetsspaltning',),
'personlighetsspaltninga': ('personlighetsspaltning',),
'personlighetsspaltningen': ('personlighetsspaltning',),
'personlighetsspaltningene': ('personlighetsspaltning',),
'personlighetsspaltninger': ('personlighetsspaltning',),
'personnavn': ('personnavn',),
'personnavna': ('personnavn',),
'personnavnene': ('personnavn',),
'personnavnet': ('personnavn',),
'personnummer': ('personnummer',),
'personnummeret': ('personnummer',),
'personnumra': ('personnummer',),
'personnumre': ('personnummer',),
'personnumrene': ('personnummer',),
'personregister': ('personregister',),
'personregisteret': ('personregister',),
'personregistra': ('personregister',),
'personregistre': ('personregister',),
'personregistrene': ('personregister',),
'personregistret': ('personregister',),
'personsystem': ('personsystem',),
'personsystema': ('personsystem',),
'personsystemene': ('personsystem',),
'personsystemer': ('personsystem',),
'personsystemet': ('personsystem',),
'personvern': ('personvern',),
'personverna': ('personvern',),
'personvernene': ('personvern',),
'personvernet': ('personvern',),
'perspektiv': ('perspektiv',),
'perspektiva': ('perspektiv',),
'perspektivene': ('perspektiv',),
'perspektiver': ('perspektiv',),
'perspektivet': ('perspektiv',),
'perspirasjon': ('perspirasjon',),
'perspirasjonen': ('perspirasjon',),
'perspirasjonene': ('perspirasjon',),
'perspirasjoner': ('perspirasjon',),
'pert': ('pert',),
'perten': ('pert',),
'pertene': ('pert',),
'perter': ('pert',),
'pertentlighet': ('pertentlighet',),
'pertentligheta': ('pertentlighet',),
'pertentligheten': ('pertentlighet',),
'pertentlighetene': ('pertentlighet',),
'pertentligheter': ('pertentlighet',),
'perturbasjon': ('perturbasjon',),
'perturbasjonen': ('perturbasjon',),
'perturbasjonene': ('perturbasjon',),
'perturbasjoner': ('perturbasjon',),
'peruaner': ('peruaner',),
'peruanere': ('peruaner',),
'peruaneren': ('peruaner',),
'peruanerer': ('peruaner',),
'peruanerne': ('peruaner',),
'perversitet': ('perversitet',),
'perversiteten': ('perversitet',),
'perversitetene': ('perversitet',),
'perversiteter': ('perversitet',),
'perversjon': ('perversjon',),
'perversjonen': ('perversjon',),
'perversjonene': ('perversjon',),
'perversjoner': ('perversjon',),
'pes': ('pes',),
'pesa': ('pes',),
'pesen': ('pes',),
'pesene': ('pes',),
'peset': ('pes',),
'peseta': ('peseta',),
'pesetaen': ('peseta',),
'pesetaene': ('peseta',),
'pesetas': ('peseta',),
'pesk': ('pesk',),
'pesken': ('pesk',),
'peskene': ('pesk',),
'pesker': ('pesk',),
'peso': ('peso',),
'pesoen': ('peso',),
'pesoene': ('peso',),
'pesos': ('peso',),
'pessar': ('pessar',),
'pessara': ('pessar',),
'pessarene': ('pessar',),
'pessarer': ('pessar',),
'pessaret': ('pessar',),
'pessimisme': ('pessimisme',),
'pessimismen': ('pessimisme',),
'pessimismene': ('pessimisme',),
'pessimismer': ('pessimisme',),
'pessimist': ('pessimist',),
'pessimisten': ('pessimist',),
'pessimistene': ('pessimist',),
'pessimister': ('pessimist',),
'pest': ('pest',),
'pesta': ('pest',),
'pesten': ('pest',),
'pestene': ('pest',),
'pester': ('pest',),
'pesthola': ('pesthole',),
'pesthole': ('pesthole',),
'pestholen': ('pesthole',),
'pestholene': ('pesthole',),
'pestholer': ('pesthole',),
'pesthula': ('pesthule',),
'pesthule': ('pesthule',),
'pesthulen': ('pesthule',),
'pesthulene': ('pesthule',),
'pesthuler': ('pesthule',),
'pesthus': ('pesthus',),
'pesthusa': ('pesthus',),
'pesthusene': ('pesthus',),
'pesthuset': ('pesthus',),
'pesticid': ('pesticid',),
'pesticida': ('pesticid',),
'pesticidene': ('pesticid',),
'pesticider': ('pesticid',),
'pesticidet': ('pesticid',),
'pestilens': ('pestilens',),
'pestilensen': ('pestilens',),
'pestilensene': ('pestilens',),
'pestilenser': ('pestilens',),
'petersfisk': ('petersfisk',),
'petersfisken': ('petersfisk',),
'petersfiskene': ('petersfisk',),
'petersfisker': ('petersfisk',),
'peterspengene': ('peterspenger',),
'peterspenger': ('peterspenger',),
'petimeter': ('petimeter',),
'petimetere': ('petimeter',),
'petimeteren': ('petimeter',),
'petimeterer': ('petimeter',),
'petimeteret': ('petimeter',),
'petimeterne': ('petimeter',),
'petimetra': ('petimeter',),
'petimetre': ('petimeter',),
'petimetrene': ('petimeter',),
'petimetrer': ('petimeter',),
'petimetret': ('petimeter',),
'petisjon': ('petisjon',),
'petisjonen': ('petisjon',),
'petisjonene': ('petisjon',),
'petisjoner': ('petisjon',),
'petit': ('petit',),
'petiten': ('petit',),
'petitene': ('petit',),
'petiter': ('petit',),
'petit mal': ('petit mal',),
'petitartikkel': ('petitartikkel',),
'petitartikkelen': ('petitartikkel',),
'petitartiklene': ('petitartikkel',),
'petitartikler': ('petitartikkel',),
'petitesse': ('petitesse',),
'petitessen': ('petitesse',),
'petitessene': ('petitesse',),
'petitesser': ('petitesse',),
'petitjournalist': ('petitjournalist',),
'petitjournalisten': ('petitjournalist',),
'petitjournalistene': ('petitjournalist',),
'petitjournalister': ('petitjournalist',),
'petrell': ('petrell',),
'petrellen': ('petrell',),
'petrellene': ('petrell',),
'petreller': ('petrell',),
'petring': ('petring',),
'petringen': ('petring',),
'petringene': ('petring',),
'petringer': ('petring',),
'petrografi': ('petrografi',),
'petrografien': ('petrografi',),
'petrografiene': ('petrografi',),
'petrografier': ('petrografi',),
'petrokjemi': ('petrokjemi',),
'petrokjemien': ('petrokjemi',),
'petrokjemiene': ('petrokjemi',),
'petrokjemier': ('petrokjemi',),
'petroleum': ('petroleum',),
'petroleumen': ('petroleum',),
'petroleumene': ('petroleum',),
'petroleumer': ('petroleum',),
'petroleumslampa': ('petroleumslampe',),
'petroleumslampe': ('petroleumslampe',),
'petroleumslampen': ('petroleumslampe',),
'petroleumslampene': ('petroleumslampe',),
'petroleumslamper': ('petroleumslampe',),
'petrologi': ('petrologi',),
'petrologien': ('petrologi',),
'petrologiene': ('petrologi',),
'petrologier': ('petrologi',),
'petting': ('petting',),
'pettinga': ('petting',),
'pettingen': ('petting',),
'pettingene': ('petting',),
'pettinger': ('petting',),
'petum': ('petum',),
'petumen': ('petum',),
'petumene': ('petum',),
'petumer': ('petum',),
'petunia': ('petunia',),
'petuniaen': ('petunia',),
'petuniaene': ('petunia',),
'petuniaer': ('petunia',),
'pfalzgreve': ('pfalzgreve',),
'pfalzgreven': ('pfalzgreve',),
'pfalzgrevene': ('pfalzgreve',),
'pfalzgrever': ('pfalzgreve',),
'pfennig': ('pfennig',),
'pfennigen': ('pfennig',),
'pfennigene': ('pfennig',),
'pfenniger': ('pfennig',),
'phon': ('phon',),
'phonen': ('phon',),
'phonene': ('phon',),
'pi': ('pi',),
'pien': ('pi',),
'piene': ('pi',),
'pier': ('pi',),
'pianissimo': ('pianissimo',),
'pianissimoa': ('pianissimo',),
'pianissimoene': ('pianissimo',),
'pianissimoer': ('pianissimo',),
'pianissimoet': ('pianissimo',),
'pianist': ('pianist',),
'pianisten': ('pianist',),
'pianistene': ('pianist',),
'pianister': ('pianist',),
'pianistinna': ('pianistinne',),
'pianistinne': ('pianistinne',),
'pianistinnen': ('pianistinne',),
'pianistinnene': ('pianistinne',),
'pianistinner': ('pianistinne',),
'piano': ('piano',),
'pianoa': ('piano',),
'pianoene': ('piano',),
'pianoer': ('piano',),
'pianoet': ('piano',),
'pianoforta': ('pianoforte',),
'pianoforte': ('pianoforte',),
'pianofortene': ('pianoforte',),
'pianoforter': ('pianoforte',),
'pianofortet': ('pianoforte',),
'pianokonsert': ('pianokonsert',),
'pianokonserten': ('pianokonsert',),
'pianokonsertene': ('pianokonsert',),
'pianokonserter': ('pianokonsert',),
'pianola': ('pianola',),
'pianolaene': ('pianola',),
'pianolaer': ('pianola',),
'pianolaet': ('pianola',),
'piassava': ('piassava',),
'piassavaen': ('piassava',),
'piassavaene': ('piassava',),
'piassavaer': ('piassava',),
'piassavakost': ('piassavakost',),
'piassavakosten': ('piassavakost',),
'piassavakostene': ('piassavakost',),
'piassavakoster': ('piassavakost',),
'pickup': ('pickup',),
'pickupen': ('pickup',),
'pickupene': ('pickup',),
'pickuper': ('pickup',),
'pidestall': ('pidestall',),
'pidestallen': ('pidestall',),
'pidestallene': ('pidestall',),
'pidestaller': ('pidestall',),
'pidgin': ('pidgin',),
'pidginen': ('pidgin',),
'pidginene': ('pidgin',),
'pidginer': ('pidgin',),
'pidginengelsk': ('pidginengelsk',),
'pidginengelsken': ('pidginengelsk',),
'pidginengelskene': ('pidginengelsk',),
'pidginengelsker': ('pidginengelsk',),
'pidginspråk': ('pidginspråk',),
'pidginspråka': ('pidginspråk',),
'pidginspråkene': ('pidginspråk',),
'pidginspråket': ('pidginspråk',),
'piece': ('piece',),
'piecen': ('piece',),
'piecene': ('piece',),
'piecer': ('piece',),
'pietet': ('pietet',),
'pieteten': ('pietet',),
'pietetene': ('pietet',),
'pieteter': ('pietet',),
'pietetsfølelse': ('pietetsfølelse',),
'pietetsfølelsen': ('pietetsfølelse',),
'pietetsfølelsene': ('pietetsfølelse',),
'pietetsfølelser': ('pietetsfølelse',),
'pietisme': ('pietisme',),
'pietismen': ('pietisme',),
'pietismene': ('pietisme',),
'pietismer': ('pietisme',),
'pietist': ('pietist',),
'pietisten': ('pietist',),
'pietistene': ('pietist',),
'pietister': ('pietist',),
'piff': ('piff',),
'piffa': ('piff',),
'piffen': ('piff',),
'piffene': ('piff',),
'piffet': ('piff',),
'pigg': ('pigg',),
'piggen': ('pigg',),
'piggene': ('pigg',),
'pigger': ('pigg',),
'piggdekk': ('piggdekk',),
'piggdekka': ('piggdekk',),
'piggdekkene': ('piggdekk',),
'piggdekket': ('piggdekk',),
'pigghå': ('pigghå',),
'pigghåen': ('pigghå',),
'pigghåene': ('pigghå',),
'pigghåer': ('pigghå',),
'piggsvin': ('piggsvin',),
'piggsvina': ('piggsvin',),
'piggsvinene': ('piggsvin',),
'piggsvinet': ('piggsvin',),
'piggtråd': ('piggtråd',),
'piggtråden': ('piggtråd',),
'piggtrådene': ('piggtråd',),
'piggtråder': ('piggtråd',),
'piggtrådmusikk': ('piggtrådmusikk',),
'piggtrådmusikken': ('piggtrådmusikk',),
'piggtrådmusikkene': ('piggtrådmusikk',),
'piggtrådmusikker': ('piggtrådmusikk',),
'piggvar': ('piggvar',),
'piggvaren': ('piggvar',),
'piggvarene': ('piggvar',),
'piggvarer': ('piggvar',),
'pigment': ('pigment',),
'pigmenta': ('pigment',),
'pigmentene': ('pigment',),
'pigmenter': ('pigment',),
'pigmentet': ('pigment',),
'pigskin': ('pigskin',),
'pigskina': ('pigskin',),
'pigskinene': ('pigskin',),
'pigskinet': ('pigskin',),
'pik': ('pik',),
'pika': ('pik',),
'pikene': ('pik',),
'piket': ('pik',),
'pik': ('pik',),
'pika': ('pik',),
'pikene': ('pik',),
'piket': ('pik',),
'pikeen': ('piké',),
'pikeene': ('piké',),
'pikeer': ('piké',),
'piké': ('piké',),
'pikéen': ('piké',),
'pikéene': ('piké',),
'pikéer': ('piké',),
'pikador': ('pikador',),
'pikadoren': ('pikador',),
'pikadorene': ('pikador',),
'pikadorer': ('pikador',),
'pikanteri': ('pikanteri',),
'pikanteria': ('pikanteri',),
'pikanteriene': ('pikanteri',),
'pikanterier': ('pikanteri',),
'pikanteriet': ('pikanteri',),
'pika': ('pike',),
'pike': ('pike',),
'piken': ('pike',),
'pikene': ('pike',),
'piker': ('pike',),
'pikekyss': ('pikekyss',),
'pikekyssa': ('pikekyss',),
'pikekyssen': ('pikekyss',),
'pikekyssene': ('pikekyss',),
'pikekysset': ('pikekyss',),
'pikelill': ('pikelill',),
'pikelillen': ('pikelill',),
'pikelillene': ('pikelill',),
'pikeliller': ('pikelill',),
'pikenavn': ('pikenavn',),
'pikenavna': ('pikenavn',),
'pikenavnene': ('pikenavn',),
'pikenavnet': ('pikenavn',),
'pikett': ('pikett',),
'piketten': ('pikett',),
'pikettene': ('pikett',),
'piketter': ('pikett',),
'pikk': ('pikk',),
'pikken': ('pikk',),
'pikkene': ('pikk',),
'pikker': ('pikk',),
'pikka': ('pikke',),
'pikke': ('pikke',),
'pikken': ('pikke',),
'pikkene': ('pikke',),
'pikker': ('pikke',),
'pikkels': ('pikkels',),
'pikkelsen': ('pikkels',),
'pikkelsene': ('pikkels',),
'pikkelser': ('pikkels',),
'pikkolo': ('pikkolo',),
'pikkoloen': ('pikkolo',),
'pikkoloene': ('pikkolo',),
'pikkoloer': ('pikkolo',),
'pikkolofløyta': ('pikkolofløyte',),
'pikkolofløyte': ('pikkolofløyte',),
'pikkolofløyten': ('pikkolofløyte',),
'pikkolofløytene': ('pikkolofløyte',),
'pikkolofløyter': ('pikkolofløyte',),
'pikkpakk': ('pikkpakk',),
'pikkpakka': ('pikkpakk',),
'pikkpakkene': ('pikkpakk',),
'pikkpakket': ('pikkpakk',),
'piknik': ('piknik',),
'pikniken': ('piknik',),
'piknikene': ('piknik',),
'pikniker': ('piknik',),
'piktografi': ('piktografi',),
'piktografien': ('piktografi',),
'piktografiene': ('piktografi',),
'piktografier': ('piktografi',),
'piktogram': ('piktogram',),
'piktogramma': ('piktogram',),
'piktogrammene': ('piktogram',),
'piktogrammer': ('piktogram',),
'piktogrammet': ('piktogram',),
'pil': ('pil',),
'pila': ('pil',),
'pilen': ('pil',),
'pilene': ('pil',),
'piler': ('pil',),
'pil': ('pil',),
'pila': ('pil',),
'pilen': ('pil',),
'pilene': ('pil',),
'piler': ('pil',),
'pilaff': ('pilaff',),
'pilaffen': ('pilaff',),
'pilaffene': ('pilaff',),
'pilaffer': ('pilaff',),
'pilar': ('pilar',),
'pilaren': ('pilar',),
'pilarene': ('pilar',),
'pilarer': ('pilar',),
'pilaster': ('pilaster',),
'pilastere': ('pilaster',),
'pilasteren': ('pilaster',),
'pilasterne': ('pilaster',),
'pilastre': ('pilaster',),
'pilastrene': ('pilaster',),
'pilastrer': ('pilaster',),
'pilegrim': ('pilegrim',),
'pilegrimen': ('pilegrim',),
'pilegrimene': ('pilegrim',),
'pilegrimer': ('pilegrim',),
'pilegrimsreisa': ('pilegrimsreise',),
'pilegrimsreise': ('pilegrimsreise',),
'pilegrimsreisen': ('pilegrimsreise',),
'pilegrimsreisene': ('pilegrimsreise',),
'pilegrimsreiser': ('pilegrimsreise',),
'pilegrimsstav': ('pilegrimsstav',),
'pilegrimsstaven': ('pilegrimsstav',),
'pilegrimsstavene': ('pilegrimsstav',),
'pilegrimsstaver': ('pilegrimsstav',),
'pilekogger': ('pilekogger',),
'pilekoggeret': ('pilekogger',),
'pilekogra': ('pilekogger',),
'pilekogre': ('pilekogger',),
'pilekogrene': ('pilekogger',),
'piletre': ('piletre',),
'piletrea': ('piletre',),
'piletreet': ('piletre',),
'piletrær': ('piletre',),
'piletrærne': ('piletre',),
'pilfamilie': ('pilfamilie',),
'pilfamilien': ('pilfamilie',),
'pilfamiliene': ('pilfamilie',),
'pilfamilier': ('pilfamilie',),
'pilfink': ('pilfink',),
'pilfinken': ('pilfink',),
'pilfinkene': ('pilfink',),
'pilfinker': ('pilfink',),
'pilk': ('pilk',),
'pilken': ('pilk',),
'pilkene': ('pilk',),
'pilker': ('pilk',),
'pille': ('pille',),
'pillen': ('pille',),
'pillene': ('pille',),
'piller': ('pille',),
'pilla': ('pille',),
'pille': ('pille',),
'pillen': ('pille',),
'pillene': ('pille',),
'piller': ('pille',),
'pillemisbruk': ('pillemisbruk',),
'pillemisbruka': ('pillemisbruk',),
'pillemisbruken': ('pillemisbruk',),
'pillemisbrukene': ('pillemisbruk',),
'pillemisbruker': ('pillemisbruk',),
'pillemisbruket': ('pillemisbruk',),
'pillemisbruker': ('pillemisbruker',),
'pillemisbrukere': ('pillemisbruker',),
'pillemisbrukeren': ('pillemisbruker',),
'pillemisbrukerer': ('pillemisbruker',),
'pillemisbrukerne': ('pillemisbruker',),
'pillert': ('pillert',),
'pillerta': ('pillert',),
'pillerten': ('pillert',),
'pillertene': ('pillert',),
'pillerter': ('pillert',),
'pilletriller': ('pilletriller',),
'pilletrillere': ('pilletriller',),
'pilletrilleren': ('pilletriller',),
'pilletrillerer': ('pilletriller',),
'pilletrillerne': ('pilletriller',),
'pilodd': ('pilodd',),
'pilodden': ('pilodd',),
'piloddene': ('pilodd',),
'pilodder': ('pilodd',),
'pilot': ('pilot',),
'piloten': ('pilot',),
'pilotene': ('pilot',),
'piloter': ('pilot',),
'pilotballong': ('pilotballong',),
'pilotballongen': ('pilotballong',),
'pilotballongene': ('pilotballong',),
'pilotballonger': ('pilotballong',),
'pilotfisk': ('pilotfisk',),
'pilotfisken': ('pilotfisk',),
'pilotfiskene': ('pilotfisk',),
'pilotfisker': ('pilotfisk',),
'pilotprosjekt': ('pilotprosjekt',),
'pilotprosjekta': ('pilotprosjekt',),
'pilotprosjektene': ('pilotprosjekt',),
'pilotprosjekter': ('pilotprosjekt',),
'pilotprosjektet': ('pilotprosjekt',),
'pilotundersøkelse': ('pilotundersøkelse',),
'pilotundersøkelsen': ('pilotundersøkelse',),
'pilotundersøkelsene': ('pilotundersøkelse',),
'pilotundersøkelser': ('pilotundersøkelse',),
'pilotundersøking': ('pilotundersøking',),
'pilotundersøkinga': ('pilotundersøking',),
'pilotundersøkingen': ('pilotundersøking',),
'pilotundersøkingene': ('pilotundersøking',),
'pilotundersøkinger': ('pilotundersøking',),
'pils': ('pils',),
'pilsen': ('pils',),
'pilsene': ('pils',),
'pilser': ('pils',),
'pilsner': ('pilsner',),
'pilsnere': ('pilsner',),
'pilsneren': ('pilsner',),
'pilsnerer': ('pilsner',),
'pilsnerne': ('pilsner',),
'pilsnerøl': ('pilsnerøl',),
'pilsnerøla': ('pilsnerøl',),
'pilsnerølet': ('pilsnerøl',),
'pilspiss': ('pilspiss',),
'pilspissen': ('pilspiss',),
'pilspissene': ('pilspiss',),
'pilspisser': ('pilspiss',),
'pilt': ('pilt',),
'pilten': ('pilt',),
'piltene': ('pilt',),
'pilter': ('pilt',),
'pimiento': ('pimiento',),
'pimientoen': ('pimiento',),
'pimientoene': ('pimiento',),
'pimientoer': ('pimiento',),
'pimpernell': ('pimpernell',),
'pimpernellen': ('pimpernell',),
'pimpernellene': ('pimpernell',),
'pimperneller': ('pimpernell',),
'pimpstein': ('pimpstein',),
'pimpsteinen': ('pimpstein',),
'pimpsteinene': ('pimpstein',),
'pimpsteiner': ('pimpstein',),
'pin-up': ('pin-up',),
'pin-upen': ('pin-up',),
'pin-upene': ('pin-up',),
'pin-uper': ('pin-up',),
'pinakkel': ('pinakkel',),
'pinakkelen': ('pinakkel',),
'pinaklene': ('pinakkel',),
'pinakler': ('pinakkel',),
'pinakotek': ('pinakotek',),
'pinakoteka': ('pinakotek',),
'pinakotekene': ('pinakotek',),
'pinakoteker': ('pinakotek',),
'pinakoteket': ('pinakotek',),
'pincenez': ('pincenez',),
'pincenezen': ('pincenez',),
'pincenezene': ('pincenez',),
'pincenezer': ('pincenez',),
'pina': ('pine',),
'pine': ('pine',),
'pinen': ('pine',),
'pinene': ('pine',),
'piner': ('pine',),
'pinebenk': ('pinebenk',),
'pinebenken': ('pinebenk',),
'pinebenkene': ('pinebenk',),
'pinebenker': ('pinebenk',),
'ping-pong': ('ping-pong',),
'ping-pongen': ('ping-pong',),
'ping-pongene': ('ping-pong',),
'ping-ponger': ('ping-pong',),
'ping-pong-ball': ('ping-pong-ball',),
'ping-pong-ballen': ('ping-pong-ball',),
'ping-pong-ballene': ('ping-pong-ball',),
'ping-pong-baller': ('ping-pong-ball',),
'pingvin': ('pingvin',),
'pingvinen': ('pingvin',),
'pingvinene': ('pingvin',),
'pingviner': ('pingvin',),
'pinje': ('pinje',),
'pinjen': ('pinje',),
'pinjene': ('pinje',),
'pinjer': ('pinje',),
'pinjong': ('pinjong',),
'pinjongen': ('pinjong',),
'pinjongene': ('pinjong',),
'pinjonger': ('pinjong',),
'pink': ('pink',),
'pinken': ('pink',),
'pinkene': ('pink',),
'pinker': ('pink',),
'pinlighet': ('pinlighet',),
'pinligheta': ('pinlighet',),
'pinligheten': ('pinlighet',),
'pinlighetene': ('pinlighet',),
'pinligheter': ('pinlighet',),
'pinn': ('pinn',),
'pinnen': ('pinn',),
'pinnene': ('pinn',),
'pinner': ('pinn',),
'pinne': ('pinne',),
'pinnen': ('pinne',),
'pinnene': ('pinne',),
'pinner': ('pinne',),
'pinnekjøtt': ('pinnekjøtt',),
'pinnekjøtta': ('pinnekjøtt',),
'pinnekjøttene': ('pinnekjøtt',),
'pinnekjøttet': ('pinnekjøtt',),
'pinnestol': ('pinnestol',),
'pinnestolen': ('pinnestol',),
'pinnestolene': ('pinnestol',),
'pinnestoler': ('pinnestol',),
'pinneved': ('pinneved',),
'pinneveden': ('pinneved',),
'pinnevedene': ('pinneved',),
'pinneveder': ('pinneved',),
'pinnsvin': ('pinnsvin',),
'pinnsvina': ('pinnsvin',),
'pinnsvinene': ('pinnsvin',),
'pinnsvinet': ('pinnsvin',),
'pins': ('pins',),
'pinsen': ('pins',),
'pinsene': ('pins',),
'pinser': ('pins',),
'pinsa': ('pinse',),
'pinse': ('pinse',),
'pinsen': ('pinse',),
'pinsene': ('pinse',),
'pinser': ('pinse',),
'pinsebevegelse': ('pinsebevegelse',),
'pinsebevegelsen': ('pinsebevegelse',),
'pinsebevegelsene': ('pinsebevegelse',),
'pinsebevegelser': ('pinsebevegelse',),
'pinsedag': ('pinsedag',),
'pinsedagen': ('pinsedag',),
'pinsedagene': ('pinsedag',),
'pinsedager': ('pinsedag',),
'pinsehelg': ('pinsehelg',),
'pinsehelga': ('pinsehelg',),
'pinsehelgen': ('pinsehelg',),
'pinsehelgene': ('pinsehelg',),
'pinsehelger': ('pinsehelg',),
'pinsel': ('pinsel',),
'pinselen': ('pinsel',),
'pinslene': ('pinsel',),
'pinsler': ('pinsel',),
'pinselilja': ('pinselilje',),
'pinselilje': ('pinselilje',),
'pinseliljen': ('pinselilje',),
'pinseliljene': ('pinselilje',),
'pinseliljer': ('pinselilje',),
'pinsesøndag': ('pinsesøndag',),
'pinsesøndagen': ('pinsesøndag',),
'pinsesøndagene': ('pinsesøndag',),
'pinsesøndager': ('pinsesøndag',),
'pinsett': ('pinsett',),
'pinsetten': ('pinsett',),
'pinsettene': ('pinsett',),
'pinsetter': ('pinsett',),
'pinsevenn': ('pinsevenn',),
'pinsevennen': ('pinsevenn',),
'pinsevennene': ('pinsevenn',),
'pinsevenner': ('pinsevenn',),
'pinsjer': ('pinsjer',),
'pinsjere': ('pinsjer',),
'pinsjeren': ('pinsjer',),
'pinsjerer': ('pinsjer',),
'pinsjerne': ('pinsjer',),
'pint': ('pint',),
'pinten': ('pint',),
'pintene': ('pint',),
'pints': ('pint',),
'pion': ('pion',),
'pionen': ('pion',),
'pionene': ('pion',),
'pioner': ('pion',),
'pioner': ('pioner',),
'pioneren': ('pioner',),
'pionerene': ('pioner',),
'pionerer': ('pioner',),
'pip': ('pip',),
'pipa': ('pip',),
'pipen': ('pip',),
'pipene': ('pip',),
'pipet': ('pip',),
'pipa': ('pipe',),
'pipe': ('pipe',),
'pipen': ('pipe',),
'pipene': ('pipe',),
'piper': ('pipe',),
'pipehatt': ('pipehatt',),
'pipehatten': ('pipehatt',),
'pipehattene': ('pipehatt',),
'pipehatter': ('pipehatt',),
'pipekonsert': ('pipekonsert',),
'pipekonserten': ('pipekonsert',),
'pipekonsertene': ('pipekonsert',),
'pipekonserter': ('pipekonsert',),
'pipekrage': ('pipekrage',),
'pipekragen': ('pipekrage',),
'pipekragene': ('pipekrage',),
'pipekrager': ('pipekrage',),
'pipekrave': ('pipekrave',),
'pipekraven': ('pipekrave',),
'pipekravene': ('pipekrave',),
'pipekraver': ('pipekrave',),
'pipeline': ('pipeline',),
'pipelinen': ('pipeline',),
'pipelinene': ('pipeline',),
'pipelines': ('pipeline',),
'pipelort': ('pipelort',),
'pipelorten': ('pipelort',),
'pipelortene': ('pipelort',),
'pipelorter': ('pipelort',),
'pipenøkkel': ('pipenøkkel',),
'pipenøkkelen': ('pipenøkkel',),
'pipenøklene': ('pipenøkkel',),
'pipenøkler': ('pipenøkkel',),
'piperenser': ('piperenser',),
'piperensere': ('piperenser',),
'piperenseren': ('piperenser',),
'piperenserer': ('piperenser',),
'piperenserne': ('piperenser',),
'pipestilk': ('pipestilk',),
'pipestilken': ('pipestilk',),
'pipestilkene': ('pipestilk',),
'pipestilker': ('pipestilk',),
'pipette': ('pipette',),
'pipetten': ('pipette',),
'pipettene': ('pipette',),
'pipetter': ('pipette',),
'pipl': ('pipl',),
'pipla': ('pipl',),
'piplene': ('pipl',),
'piplet': ('pipl',),
'pipp': ('pipp',),
'pippa': ('pipp',),
'pippene': ('pipp',),
'pippet': ('pipp',),
'pippip': ('pippip',),
'pippipen': ('pippip',),
'pippipene': ('pippip',),
'pippiper': ('pippip',),
'pir': ('pir',),
'piren': ('pir',),
'pirene': ('pir',),
'pirer': ('pir',),
'pir': ('pir',),
'piren': ('pir',),
'pirene': ('pir',),
'pirer': ('pir',),
'piraja': ('piraja',),
'pirajaen': ('piraja',),
'pirajaene': ('piraja',),
'pirajaer': ('piraja',),
'pirat': ('pirat',),
'piraten': ('pirat',),
'piratene': ('pirat',),
'pirater': ('pirat',),
'piratopptak': ('piratopptak',),
'piratopptaka': ('piratopptak',),
'piratopptakene': ('piratopptak',),
'piratopptaket': ('piratopptak',),
'piratsender': ('piratsender',),
'piratsendere': ('piratsender',),
'piratsenderen': ('piratsender',),
'piratsenderer': ('piratsender',),
'piratsenderne': ('piratsender',),
'piratutgava': ('piratutgave',),
'piratutgave': ('piratutgave',),
'piratutgaven': ('piratutgave',),
'piratutgavene': ('piratutgave',),
'piratutgaver': ('piratutgave',),
'pirk': ('pirk',),
'pirken': ('pirk',),
'pirkene': ('pirk',),
'pirker': ('pirk',),
'pirk': ('pirk',),
'pirka': ('pirk',),
'pirkene': ('pirk',),
'pirket': ('pirk',),
'pirog': ('pirog',),
'pirogen': ('pirog',),
'pirogene': ('pirog',),
'piroger': ('pirog',),
'pirog': ('pirog',),
'pirogen': ('pirog',),
'pirogene': ('pirog',),
'piroger': ('pirog',),
'pirol': ('pirol',),
'pirolen': ('pirol',),
'pirolene': ('pirol',),
'piroler': ('pirol',),
'pirquetprøva': ('pirquetprøve',),
'pirquetprøve': ('pirquetprøve',),
'pirquetprøven': ('pirquetprøve',),
'pirquetprøvene': ('pirquetprøve',),
'pirquetprøver': ('pirquetprøve',),
'piruett': ('piruett',),
'piruetten': ('piruett',),
'piruettene': ('piruett',),
'piruetter': ('piruett',),
'pirål': ('pirål',),
'pirålen': ('pirål',),
'pirålene': ('pirål',),
'piråler': ('pirål',),
'pisk': ('pisk',),
'pisken': ('pisk',),
'piskene': ('pisk',),
'pisker': ('pisk',),
'pisk': ('pisk',),
'piska': ('pisk',),
'piskene': ('pisk',),
'pisket': ('pisk',),
'piskesnert': ('piskesnert',),
'piskesnerten': ('piskesnert',),
'piskesnertene': ('piskesnert',),
'piskesnerter': ('piskesnert',),
'piss': ('piss',),
'pissa': ('piss',),
'pissene': ('piss',),
'pisset': ('piss',),
'pissemaur': ('pissemaur',),
'pissemauren': ('pissemaur',),
'pissemaurene': ('pissemaur',),
'pisseprat': ('pisseprat',),
'pisseprata': ('pisseprat',),
'pissepraten': ('pisseprat',),
'pissepratene': ('pisseprat',),
'pisseprater': ('pisseprat',),
'pissepratet': ('pisseprat',),
'pissoar': ('pissoar',),
'pissoara': ('pissoar',),
'pissoarene': ('pissoar',),
'pissoarer': ('pissoar',),
'pissoaret': ('pissoar',),
'pist': ('pist',),
'pisten': ('pist',),
'pistene': ('pist',),
'pister': ('pist',),
'pist': ('pist',),
'pisten': ('pist',),
'pistene': ('pist',),
'pister': ('pist',),
'pistasie': ('pistasie',),
'pistasien': ('pistasie',),
'pistasiene': ('pistasie',),
'pistasier': ('pistasie',),
'pistasieis': ('pistasieis',),
'pistasieisen': ('pistasieis',),
'pistasieisene': ('pistasieis',),
'pistasieiser': ('pistasieis',),
'pistasietre': ('pistasietre',),
'pistasietrea': ('pistasietre',),
'pistasietreet': ('pistasietre',),
'pistasietrær': ('pistasietre',),
'pistasietrærne': ('pistasietre',),
'pistol': ('pistol',),
'pistolen': ('pistol',),
'pistolene': ('pistol',),
'pistoler': ('pistol',),
'pistong': ('pistong',),
'pistongen': ('pistong',),
'pistongene': ('pistong',),
'pistonger': ('pistong',),
'pitabrød': ('pitabrød',),
'pitabrøda': ('pitabrød',),
'pitabrødene': ('pitabrød',),
'pitabrødet': ('pitabrød',),
'pitchpine': ('pitchpine',),
'pitchpinen': ('pitchpine',),
'pitchpinene': ('pitchpine',),
'pitchpiner': ('pitchpine',),
'pitprops': ('pitprops',),
'pitpropsen': ('pitprops',),
'pitpropsene': ('pitprops',),
'pitpropser': ('pitprops',),
'pizza': ('pizza',),
'pizzaen': ('pizza',),
'pizzaene': ('pizza',),
'pizzaer': ('pizza',),
'pizzicato': ('pizzicato',),
'pizzicatoa': ('pizzicato',),
'pizzicatoene': ('pizzicato',),
'pizzicatoer': ('pizzicato',),
'pizzicatoet': ('pizzicato',),
'pjalle': ('pjalle',),
'pjallen': ('pjalle',),
'pjallene': ('pjalle',),
'pjaller': ('pjalle',),
'pjalt': ('pjalt',),
'pjalten': ('pjalt',),
'pjaltene': ('pjalt',),
'pjalter': ('pjalt',),
'pjank': ('pjank',),
'pjanka': ('pjank',),
'pjankene': ('pjank',),
'pjanket': ('pjank',),
'pjaster': ('pjaster',),
'pjastere': ('pjaster',),
'pjasteren': ('pjaster',),
'pjasterer': ('pjaster',),
'pjasterne': ('pjaster',),
'pjatt': ('pjatt',),
'pjatta': ('pjatt',),
'pjattene': ('pjatt',),
'pjattet': ('pjatt',),
'pjekkert': ('pjekkert',),
'pjekkerten': ('pjekkert',),
'pjekkertene': ('pjekkert',),
'pjekkerter': ('pjekkert',),
'pjerretta': ('pjerrette',),
'pjerrette': ('pjerrette',),
'pjerretten': ('pjerrette',),
'pjerrettene': ('pjerrette',),
'pjerretter': ('pjerrette',),
'pjerrot': ('pjerrot',),
'pjerroten': ('pjerrot',),
'pjerrotene': ('pjerrot',),
'pjerroter': ('pjerrot',),
'pjokk': ('pjokk',),
'pjokken': ('pjokk',),
'pjokkene': ('pjokk',),
'pjokker': ('pjokk',),
'pjolter': ('pjolter',),
'pjoltere': ('pjolter',),
'pjolteren': ('pjolter',),
'pjolterer': ('pjolter',),
'pjolterne': ('pjolter',),
'pjoltre': ('pjolter',),
'pjoltrene': ('pjolter',),
'pjoltrer': ('pjolter',),
'pjusk': ('pjusk',),
'pjuska': ('pjusk',),
'pjuskene': ('pjusk',),
'pjusket': ('pjusk',),
'placebo': ('placebo',),
'placeboa': ('placebo',),
'placeboene': ('placebo',),
'placeboet': ('placebo',),
'placeboeffekt': ('placeboeffekt',),
'placeboeffekten': ('placeboeffekt',),
'placeboeffektene': ('placeboeffekt',),
'placeboeffekter': ('placeboeffekt',),
'plaff': ('plaff',),
'plaffa': ('plaff',),
'plaffene': ('plaff',),
'plaffet': ('plaff',),
'plafondmaleri': ('plafondmaleri',),
'plafondmaleria': ('plafondmaleri',),
'plafondmaleriene': ('plafondmaleri',),
'plafondmalerier': ('plafondmaleri',),
'plafondmaleriet': ('plafondmaleri',),
'plaga': ('plage',),
'plage': ('plage',),
'plagen': ('plage',),
'plagene': ('plage',),
'plager': ('plage',),
'plager': ('plager',),
'plagere': ('plager',),
'plageren': ('plager',),
'plagerer': ('plager',),
'plagerne': ('plager',),
'plageri': ('plageri',),
'plageria': ('plageri',),
'plageriene': ('plageri',),
'plagerier': ('plageri',),
'plageriet': ('plageri',),
'plageånd': ('plageånd',),
'plageånden': ('plageånd',),
'plageåndene': ('plageånd',),
'plageånder': ('plageånd',),
'plagg': ('plagg',),
'plagga': ('plagg',),
'plaggene': ('plagg',),
'plagget': ('plagg',),
'plagiat': ('plagiat',),
'plagiata': ('plagiat',),
'plagiatene': ('plagiat',),
'plagiater': ('plagiat',),
'plagiatet': ('plagiat',),
'plagiator': ('plagiator',),
'plagiatoren': ('plagiator',),
'plagiatorene': ('plagiator',),
'plagiatorer': ('plagiator',),
'plakat': ('plakat',),
'plakaten': ('plakat',),
'plakatene': ('plakat',),
'plakater': ('plakat',),
'plakett': ('plakett',),
'plaketten': ('plakett',),
'plakettene': ('plakett',),
'plaketter': ('plakett',),
'plakk': ('plakk',),
'plakken': ('plakk',),
'plakkene': ('plakk',),
'plakker': ('plakk',),
'plakk': ('plakk',),
'plakka': ('plakk',),
'plakkene': ('plakk',),
'plakket': ('plakk',),
'plan': ('plan',),
'planen': ('plan',),
'planene': ('plan',),
'planer': ('plan',),
'plan': ('plan',),
'plana': ('plan',),
'planene': ('plan',),
'planet': ('plan',),
'planet': ('planet',),
'planeten': ('planet',),
'planetene': ('planet',),
'planeter': ('planet',),
'planetaria': ('planetarium',),
'planetariene': ('planetarium',),
'planetarier': ('planetarium',),
'planetariet': ('planetarium',),
'planetarium': ('planetarium',),
'planetoide': ('planetoide',),
'planetoiden': ('planetoide',),
'planetoidene': ('planetoide',),
'planetoider': ('planetoide',),
'plank': ('plank',),
'planken': ('plank',),
'plankene': ('plank',),
'planker': ('plank',),
'planke': ('planke',),
'planken': ('planke',),
'plankene': ('planke',),
'planker': ('planke',),
'plankeadel': ('plankeadel',),
'plankeadelen': ('plankeadel',),
'plankeadlene': ('plankeadel',),
'plankeadler': ('plankeadel',),
'plankehud': ('plankehud',),
'plankehuda': ('plankehud',),
'plankehuden': ('plankehud',),
'plankehudene': ('plankehud',),
'plankehuder': ('plankehud',),
'plankekjøring': ('plankekjøring',),
'plankekjøringa': ('plankekjøring',),
'plankekjøringen': ('plankekjøring',),
'plankekjøringene': ('plankekjøring',),
'plankekjøringer': ('plankekjøring',),
'plankryss': ('plankryss',),
'plankryssa': ('plankryss',),
'plankryssene': ('plankryss',),
'plankrysset': ('plankryss',),
'plankton': ('plankton',),
'planktona': ('plankton',),
'planktonene': ('plankton',),
'planktoner': ('plankton',),
'planktonet': ('plankton',),
'planlegger': ('planlegger',),
'planleggere': ('planlegger',),
'planleggeren': ('planlegger',),
'planleggerer': ('planlegger',),
'planleggerne': ('planlegger',),
'planlegging': ('planlegging',),
'planlegginga': ('planlegging',),
'planleggingen': ('planlegging',),
'planleggingene': ('planlegging',),
'planlegginger': ('planlegging',),
'planløsning': ('planløsning',),
'planløsninga': ('planløsning',),
'planløsningen': ('planløsning',),
'planløsningene': ('planløsning',),
'planløsninger': ('planløsning',),
'planløysing': ('planløysing',),
'planløysinga': ('planløysing',),
'planløysingen': ('planløysing',),
'planløysingene': ('planløysing',),
'planløysinger': ('planløysing',),
'planovergang': ('planovergang',),
'planovergangen': ('planovergang',),
'planovergangene': ('planovergang',),
'planoverganger': ('planovergang',),
'plansje': ('plansje',),
'plansjen': ('plansje',),
'plansjene': ('plansje',),
'plansjer': ('plansje',),
'plansjett': ('plansjett',),
'plansjetten': ('plansjett',),
'plansjettene': ('plansjett',),
'plansjetter': ('plansjett',),
'plantasje': ('plantasje',),
'plantasjen': ('plantasje',),
'plantasjene': ('plantasje',),
'plantasjer': ('plantasje',),
'planta': ('plante',),
'plante': ('plante',),
'planten': ('plante',),
'plantene': ('plante',),
'planter': ('plante',),
'planteeter': ('planteeter',),
'planteetere': ('planteeter',),
'planteeteren': ('planteeter',),
'planteeterer': ('planteeter',),
'planteeterne': ('planteeter',),
'plantefarge': ('plantefarge',),
'plantefargen': ('plantefarge',),
'plantefargene': ('plantefarge',),
'plantefarger': ('plantefarge',),
'plantefelt': ('plantefelt',),
'plantefelta': ('plantefelt',),
'plantefeltene': ('plantefelt',),
'plantefelter': ('plantefelt',),
'plantefeltet': ('plantefelt',),
'plantemargarin': ('plantemargarin',),
'plantemargarinen': ('plantemargarin',),
'plantemargarinene': ('plantemargarin',),
'plantemargariner': ('plantemargarin',),
'planterika': ('planterike',),
'planterike': ('planterike',),
'planterikene': ('planterike',),
'planteriker': ('planterike',),
'planteriket': ('planterike',),
'planteskole': ('planteskole',),
'planteskolen': ('planteskole',),
'planteskolene': ('planteskole',),
'planteskoler': ('planteskole',),
'plantesuger': ('plantesuger',),
'plantesugere': ('plantesuger',),
'plantesugeren': ('plantesuger',),
'plantesugerer': ('plantesuger',),
'plantesugerne': ('plantesuger',),
'plantning': ('plantning',),
'plantninga': ('plantning',),
'plantningen': ('plantning',),
'plantningene': ('plantning',),
'plantninger': ('plantning',),
'planøkonomi': ('planøkonomi',),
'planøkonomien': ('planøkonomi',),
'planøkonomiene': ('planøkonomi',),
'planøkonomier': ('planøkonomi',),
'plaser': ('plaser',),
'plaseren': ('plaser',),
'plaserene': ('plaser',),
'plaserer': ('plaser',),
'plask': ('plask',),
'plaska': ('plask',),
'plaskene': ('plask',),
'plasket': ('plask',),
'plaskregn': ('plaskregn',),
'plaskregna': ('plaskregn',),
'plaskregnene': ('plaskregn',),
'plaskregnet': ('plaskregn',),
'plasma': ('plasma',),
'plasmaene': ('plasma',),
'plasmaer': ('plasma',),
'plasmaet': ('plasma',),
'plass': ('plass',),
'plassen': ('plass',),
'plassene': ('plass',),
'plasser': ('plass',),
'plassangst': ('plassangst',),
'plassangsten': ('plassangst',),
'plassangstene': ('plassangst',),
'plassangster': ('plassangst',),
'plassbillett': ('plassbillett',),
'plassbilletten': ('plassbillett',),
'plassbillettene': ('plassbillett',),
'plassbilletter': ('plassbillett',),
'plassering': ('plassering',),
'plasseringa': ('plassering',),
'plasseringen': ('plassering',),
'plasseringene': ('plassering',),
'plasseringer': ('plassering',),
'plassfolk': ('plassfolk',),
'plassfolka': ('plassfolk',),
'plassfolkene': ('plassfolk',),
'plassfolket': ('plassfolk',),
'plasshensyn': ('plasshensyn',),
'plasshensyna': ('plasshensyn',),
'plasshensynene': ('plasshensyn',),
'plasshensynet': ('plasshensyn',),
'plasskommandant': ('plasskommandant',),
'plasskommandanten': ('plasskommandant',),
'plasskommandantene': ('plasskommandant',),
'plasskommandanter': ('plasskommandant',),
'plassmangel': ('plassmangel',),
'plassmangelen': ('plassmangel',),
'plassmanglene': ('plassmangel',),
'plassmangler': ('plassmangel',),
'plassoppsigelse': ('plassoppsigelse',),
'plassoppsigelsen': ('plassoppsigelse',),
'plassoppsigelsene': ('plassoppsigelse',),
'plassoppsigelser': ('plassoppsigelse',),
'plassoppsiing': ('plassoppsiing',),
'plassoppsiinga': ('plassoppsiing',),
'plassoppsiingen': ('plassoppsiing',),
'plassoppsiingene': ('plassoppsiing',),
'plassoppsiinger': ('plassoppsiing',),
'plast': ('plast',),
'plasten': ('plast',),
'plastene': ('plast',),
'plaster': ('plast',),
'plastbakke': ('plastbakke',),
'plastbakken': ('plastbakke',),
'plastbakkene': ('plastbakke',),
'plastbakker': ('plastbakke',),
'plaster': ('plaster',),
'plasteret': ('plaster',),
'plastra': ('plaster',),
'plastre': ('plaster',),
'plastrene': ('plaster',),
'plastret': ('plaster',),
'plastgras': ('plastgras',),
'plastgrasa': ('plastgras',),
'plastgrasene': ('plastgras',),
'plastgraset': ('plastgras',),
'plastgress': ('plastgress',),
'plastgressa': ('plastgress',),
'plastgressene': ('plastgress',),
'plastgresset': ('plastgress',),
'plastikk': ('plastikk',),
'plastikken': ('plastikk',),
'plastikkene': ('plastikk',),
'plastikker': ('plastikk',),
'plastilin': ('plastilin',),
'plastilina': ('plastilin',),
'plastilinene': ('plastilin',),
'plastilinet': ('plastilin',),
'plastisitet': ('plastisitet',),
'plastisiteten': ('plastisitet',),
'plastisitetene': ('plastisitet',),
'plastisiteter': ('plastisitet',),
'plastpose': ('plastpose',),
'plastposen': ('plastpose',),
'plastposene': ('plastpose',),
'plastposer': ('plastpose',),
'platan': ('platan',),
'platanen': ('platan',),
'platanene': ('platan',),
'plataner': ('platan',),
'plata': ('plate',),
'plate': ('plate',),
'platen': ('plate',),
'platene': ('plate',),
'plater': ('plate',),
'platearbeider': ('platearbeider',),
'platearbeidere': ('platearbeider',),
'platearbeideren': ('platearbeider',),
'platearbeiderer': ('platearbeider',),
'platearbeiderne': ('platearbeider',),
'plateartist': ('plateartist',),
'plateartisten': ('plateartist',),
'plateartistene': ('plateartist',),
'plateartister': ('plateartist',),
'platebar': ('platebar',),
'platebaren': ('platebar',),
'platebarene': ('platebar',),
'platebarer': ('platebar',),
'platebarometer': ('platebarometer',),
'platebarometeret': ('platebarometer',),
'platebarometra': ('platebarometer',),
'platebarometre': ('platebarometer',),
'platebarometrene': ('platebarometer',),
'platebarometret': ('platebarometer',),
'platelager': ('platelager',),
'platelageret': ('platelager',),
'platelagra': ('platelager',),
'platelagre': ('platelager',),
'platelagrene': ('platelager',),
'plateprater': ('plateprater',),
'platepratere': ('plateprater',),
'plateprateren': ('plateprater',),
'platepraterer': ('plateprater',),
'platepraterne': ('plateprater',),
'platespeller': ('platespeller',),
'platespellere': ('platespeller',),
'platespelleren': ('platespeller',),
'platespellerer': ('platespeller',),
'platespellerne': ('platespeller',),
'platespiller': ('platespiller',),
'platespillere': ('platespiller',),
'platespilleren': ('platespiller',),
'platespillerer': ('platespiller',),
'platespillerne': ('platespiller',),
'platina': ('platina',),
'platinaa': ('platina',),
'platinaene': ('platina',),
'platinaet': ('platina',),
'platinaplata': ('platinaplate',),
'platinaplate': ('platinaplate',),
'platinaplaten': ('platinaplate',),
'platinaplatene': ('platinaplate',),
'platinaplater': ('platinaplate',),
'platinarev': ('platinarev',),
'platinareven': ('platinarev',),
'platinarevene': ('platinarev',),
'platinarever': ('platinarev',),
'platityde': ('platityde',),
'platityden': ('platityde',),
'platitydene': ('platityde',),
'platityder': ('platityde',),
'platoniker': ('platoniker',),
'platonikere': ('platoniker',),
'platonikeren': ('platoniker',),
'platonikerer': ('platoniker',),
'platonikerne': ('platoniker',),
'platonisme': ('platonisme',),
'platonismen': ('platonisme',),
'platonismene': ('platonisme',),
'platonismer': ('platonisme',),
'platt-tysk': ('platt-tysk',),
'platt-tysken': ('platt-tysk',),
'platt-tyskene': ('platt-tysk',),
'platt-tysker': ('platt-tysk',),
'platte': ('platte',),
'platten': ('platte',),
'plattene': ('platte',),
'platter': ('platte',),
'plattenslager': ('plattenslager',),
'plattenslagere': ('plattenslager',),
'plattenslageren': ('plattenslager',),
'plattenslagerer': ('plattenslager',),
'plattenslagerne': ('plattenslager',),
'plattform': ('plattform',),
'plattforma': ('plattform',),
'plattformen': ('plattform',),
'plattformene': ('plattform',),
'plattformer': ('plattform',),
'plattfot': ('plattfot',),
'plattfoten': ('plattfot',),
'plattfotene': ('plattfot',),
'plattfoter': ('plattfot',),
'plattgatter': ('plattgatter',),
'plattgattere': ('plattgatter',),
'plattgatteren': ('plattgatter',),
'plattgatterer': ('plattgatter',),
'plattgatterne': ('plattgatter',),
'platthet': ('platthet',),
'plattheta': ('platthet',),
'plattheten': ('platthet',),
'platthetene': ('platthet',),
'plattheter': ('platthet',),
'platting': ('platting',),
'plattingen': ('platting',),
'plattingene': ('platting',),
'plattinger': ('platting',),
'plattysk': ('plattysk',),
'plattysken': ('plattysk',),
'plattyskene': ('plattysk',),
'plattysker': ('plattysk',),
'platå': ('platå',),
'platåa': ('platå',),
'platåene': ('platå',),
'platåer': ('platå',),
'platået': ('platå',),
'playback': ('playback',),
'playbacken': ('playback',),
'playbackene': ('playback',),
'playbacks': ('playback',),
'playboy': ('playboy',),
'playboyen': ('playboy',),
'playboyene': ('playboy',),
'playboyer': ('playboy',),
'plebeier': ('plebeier',),
'plebeiere': ('plebeier',),
'plebeieren': ('plebeier',),
'plebeierer': ('plebeier',),
'plebeierne': ('plebeier',),
'plebisitt': ('plebisitt',),
'plebisitta': ('plebisitt',),
'plebisitten': ('plebisitt',),
'plebisittene': ('plebisitt',),
'plebisitter': ('plebisitt',),
'plebisittet': ('plebisitt',),
'plebs': ('plebs',),
'plebsen': ('plebs',),
'plebsene': ('plebs',),
'plebser': ('plebs',),
'pledd': ('pledd',),
'pledda': ('pledd',),
'pleddene': ('pledd',),
'pleddet': ('pledd',),
'pleiade': ('pleiade',),
'pleiaden': ('pleiade',),
'pleiadene': ('pleiade',),
'pleiader': ('pleiade',),
'pleia': ('pleie',),
'pleie': ('pleie',),
'pleien': ('pleie',),
'pleiene': ('pleie',),
'pleier': ('pleie',),
'pleiebarn': ('pleiebarn',),
'pleiebarna': ('pleiebarn',),
'pleiebarnene': ('pleiebarn',),
'pleiebarnet': ('pleiebarn',),
'pleieheim': ('pleieheim',),
'pleieheimen': ('pleieheim',),
'pleieheimene': ('pleieheim',),
'pleieheimer': ('pleieheim',),
'pleiehjem': ('pleiehjem',),
'pleiehjemma': ('pleiehjem',),
'pleiehjemmene': ('pleiehjem',),
'pleiehjemmet': ('pleiehjem',),
'pleier': ('pleier',),
'pleiere': ('pleier',),
'pleieren': ('pleier',),
'pleierer': ('pleier',),
'pleierne': ('pleier',),
'pleksiglass': ('pleksiglass',),
'pleksiglassa': ('pleksiglass',),
'pleksiglassene': ('pleksiglass',),
'pleksiglasset': ('pleksiglass',),
'plekter': ('plekter',),
'plekteret': ('plekter',),
'plektra': ('plekter',),
'plektre': ('plekter',),
'plektrene': ('plekter',),
'plektret': ('plekter',),
'plen': ('plen',),
'plenen': ('plen',),
'plenene': ('plen',),
'plener': ('plen',),
'plenarforsamling': ('plenarforsamling',),
'plenarforsamlinga': ('plenarforsamling',),
'plenarforsamlingen': ('plenarforsamling',),
'plenarforsamlingene': ('plenarforsamling',),
'plenarforsamlinger': ('plenarforsamling',),
'plenfrø': ('plenfrø',),
'plenfrøa': ('plenfrø',),
'plenfrøene': ('plenfrø',),
'plenfrøet': ('plenfrø',),
'plenklipper': ('plenklipper',),
'plenklippere': ('plenklipper',),
'plenklipperen': ('plenklipper',),
'plenklipperer': ('plenklipper',),
'plenklipperne': ('plenklipper',),
'plena': ('plenum',),
'plenaene': ('plenum',),
'plenum': ('plenum',),
'plenumet': ('plenum',),
'plenumsmøta': ('plenumsmøte',),
'plenumsmøte': ('plenumsmøte',),
'plenumsmøtene': ('plenumsmøte',),
'plenumsmøter': ('plenumsmøte',),
'plenumsmøtet': ('plenumsmøte',),
'pleonasme': ('pleonasme',),
'pleonasmen': ('pleonasme',),
'pleonasmene': ('pleonasme',),
'pleonasmer': ('pleonasme',),
'plesken': ('plesken',),
'pleskenen': ('plesken',),
'pleskenene': ('plesken',),
'pleskener': ('plesken',),
'pleti': ('pleti',),
'pleuritt': ('pleuritt',),
'pleuritten': ('pleuritt',),
'pleurittene': ('pleuritt',),
'pleuritter': ('pleuritt',),
'plevritt': ('plevritt',),
'plevritten': ('plevritt',),
'plevrittene': ('plevritt',),
'plevritter': ('plevritt',),
'pli': ('pli',),
'plien': ('pli',),
'pliene': ('pli',),
'plier': ('pli',),
'plikt': ('plikt',),
'plikten': ('plikt',),
'pliktene': ('plikt',),
'plikter': ('plikt',),
'plikt': ('plikt',),
'plikta': ('plikt',),
'plikten': ('plikt',),
'pliktene': ('plikt',),
'plikter': ('plikt',),
'pliktarbeid': ('pliktarbeid',),
'pliktarbeida': ('pliktarbeid',),
'pliktarbeidene': ('pliktarbeid',),
'pliktarbeider': ('pliktarbeid',),
'pliktarbeidet': ('pliktarbeid',),
'pliktløp': ('pliktløp',),
'pliktløpa': ('pliktløp',),
'pliktløpene': ('pliktløp',),
'pliktløpet': ('pliktløp',),
'plikttjeneste': ('plikttjeneste',),
'plikttjenesten': ('plikttjeneste',),
'plikttjenestene': ('plikttjeneste',),
'plikttjenester': ('plikttjeneste',),
'pliktøvelse': ('pliktøvelse',),
'pliktøvelsen': ('pliktøvelse',),
'pliktøvelsene': ('pliktøvelse',),
'pliktøvelser': ('pliktøvelse',),
'pliktøving': ('pliktøving',),
'pliktøvinga': ('pliktøving',),
'pliktøvingen': ('pliktøving',),
'pliktøvingene': ('pliktøving',),
'pliktøvinger': ('pliktøving',),
'plimsoller': ('plimsoller',),
'plimsollere': ('plimsoller',),
'plimsolleren': ('plimsoller',),
'plimsollerer': ('plimsoller',),
'plimsollerne': ('plimsoller',),
'plimsollmerka': ('plimsollmerke',),
'plimsollmerke': ('plimsollmerke',),
'plimsollmerkene': ('plimsollmerke',),
'plimsollmerker': ('plimsollmerke',),
'plimsollmerket': ('plimsollmerke',),
'pling': ('pling',),
'plinga': ('pling',),
'plingene': ('pling',),
'plinget': ('pling',),
'plint': ('plint',),
'plinten': ('plint',),
'plintene': ('plint',),
'plinter': ('plint',),
'plir': ('plir',),
'plira': ('plir',),
'plirene': ('plir',),
'pliret': ('plir',),
'plisseen': ('plissé',),
'plisseene': ('plissé',),
'plisseer': ('plissé',),
'plissé': ('plissé',),
'plisséen': ('plissé',),
'plisséene': ('plissé',),
'plisséer': ('plissé',),
'plisséskjørt': ('plisséskjørt',),
'plisséskjørta': ('plisséskjørt',),
'plisséskjørtene': ('plisséskjørt',),
'plisséskjørter': ('plisséskjørt',),
'plisséskjørtet': ('plisséskjørt',),
'plitt': ('plitt',),
'plitten': ('plitt',),
'plittene': ('plitt',),
'plitter': ('plitt',),
'plog': ('plog',),
'plogen': ('plog',),
'plogene': ('plog',),
'ploger': ('plog',),
'plogfure': ('plogfure',),
'plogfuren': ('plogfure',),
'plogfurene': ('plogfure',),
'plogfurer': ('plogfure',),
'plognad': ('plognad',),
'plognaden': ('plognad',),
'plognadene': ('plognad',),
'plognader': ('plognad',),
'plogskjær': ('plogskjær',),
'plogskjæra': ('plogskjær',),
'plogskjærene': ('plogskjær',),
'plogskjæret': ('plogskjær',),
'plomba': ('plombe',),
'plombe': ('plombe',),
'plomben': ('plombe',),
'plombene': ('plombe',),
'plomber': ('plombe',),
'plomma': ('plomme',),
'plomme': ('plomme',),
'plommen': ('plomme',),
'plommene': ('plomme',),
'plommer': ('plomme',),
'plomma': ('plomme',),
'plomme': ('plomme',),
'plommen': ('plomme',),
'plommene': ('plomme',),
'plommer': ('plomme',),
'plopp': ('plopp',),
'ploppa': ('plopp',),
'ploppene': ('plopp',),
'ploppet': ('plopp',),
'plosiv': ('plosiv',),
'plosiven': ('plosiv',),
'plosivene': ('plosiv',),
'plosiver': ('plosiv',),
'plot': ('plot',),
'plota': ('plot',),
'plotene': ('plot',),
'plotet': ('plot',),
'plott': ('plott',),
'plotta': ('plott',),
'plottene': ('plott',),
'plottet': ('plott',),
'plotter': ('plotter',),
'plottere': ('plotter',),
'plotteren': ('plotter',),
'plotterer': ('plotter',),
'plotterne': ('plotter',),
'pludder': ('pludder',),
'pluddera': ('pludder',),
'pluddere': ('pludder',),
'pludderene': ('pludder',),
'pludderet': ('pludder',),
'pludderne': ('pludder',),
'plugg': ('plugg',),
'pluggen': ('plugg',),
'pluggene': ('plugg',),
'plugger': ('plugg',),
'plukk': ('plukk',),
'plukken': ('plukk',),
'plukkene': ('plukk',),
'plukker': ('plukk',),
'plukk': ('plukk',),
'plukka': ('plukk',),
'plukkene': ('plukk',),
'plukket': ('plukk',),
'plukkfisk': ('plukkfisk',),
'plukkfisken': ('plukkfisk',),
'plukkfiskene': ('plukkfisk',),
'plukkfisker': ('plukkfisk',),
'plukkhogst': ('plukkhogst',),
'plukkhogsten': ('plukkhogst',),
'plukkhogstene': ('plukkhogst',),
'plukkhogster': ('plukkhogst',),
'plukkhugst': ('plukkhugst',),
'plukkhugsten': ('plukkhugst',),
'plukkhugstene': ('plukkhugst',),
'plukkhugster': ('plukkhugst',),
'plumkaka': ('plumkake',),
'plumkake': ('plumkake',),
'plumkaken': ('plumkake',),
'plumkakene': ('plumkake',),
'plumkaker': ('plumkake',),
'plump': ('plump',),
'plumpa': ('plump',),
'plumpene': ('plump',),
'plumpet': ('plump',),
'plumphet': ('plumphet',),
'plumpheta': ('plumphet',),
'plumpheten': ('plumphet',),
'plumphetene': ('plumphet',),
'plumpheter': ('plumphet',),
'plumpudding': ('plumpudding',),
'plumpuddingen': ('plumpudding',),
'plumpuddingene': ('plumpudding',),
'plumpuddinger': ('plumpudding',),
'plunder': ('plunder',),
'plunderet': ('plunder',),
'plundra': ('plunder',),
'plundrene': ('plunder',),
'plundrer': ('plunder',),
'plundret': ('plunder',),
'pluralis': ('pluralis',),
'pluralisen': ('pluralis',),
'pluralisene': ('pluralis',),
'pluraliser': ('pluralis',),
'pluralisme': ('pluralisme',),
'pluralismen': ('pluralisme',),
'pluralismene': ('pluralisme',),
'pluralismer': ('pluralisme',),
'pluralist': ('pluralist',),
'pluralisten': ('pluralist',),
'pluralistene': ('pluralist',),
'pluralister': ('pluralist',),
'pluralitet': ('pluralitet',),
'pluraliteten': ('pluralitet',),
'pluralitetene': ('pluralitet',),
'pluraliteter': ('pluralitet',),
'pluskvamperfekta': ('pluskvamperfektum',),
'pluskvamperfektaene': ('pluskvamperfektum',),
'pluskvamperfektene': ('pluskvamperfektum',),
'pluskvamperfekter': ('pluskvamperfektum',),
'pluskvamperfektum': ('pluskvamperfektum',),
'pluskvamperfektumet': ('pluskvamperfektum',),
'pluss': ('pluss',),
'plussa': ('pluss',),
'plussene': ('pluss',),
'plusser': ('pluss',),
'plusset': ('pluss',),
'pluss-sida': ('pluss-side',),
'pluss-side': ('pluss-side',),
'pluss-siden': ('pluss-side',),
'pluss-sidene': ('pluss-side',),
'pluss-sider': ('pluss-side',),
'plussgrad': ('plussgrad',),
'plussgraden': ('plussgrad',),
'plussgradene': ('plussgrad',),
'plussgrader': ('plussgrad',),
'plussida': ('plusside',),
'plusside': ('plusside',),
'plussiden': ('plusside',),
'plussidene': ('plusside',),
'plussider': ('plusside',),
'plussord': ('plussord',),
'plussorda': ('plussord',),
'plussordene': ('plussord',),
'plussordet': ('plussord',),
'plusstegn': ('plusstegn',),
'plusstegna': ('plusstegn',),
'plusstegnene': ('plusstegn',),
'plusstegnet': ('plusstegn',),
'plutokrat': ('plutokrat',),
'plutokraten': ('plutokrat',),
'plutokratene': ('plutokrat',),
'plutokrater': ('plutokrat',),
'plutokrati': ('plutokrati',),
'plutokratia': ('plutokrati',),
'plutokratiene': ('plutokrati',),
'plutokratier': ('plutokrati',),
'plutokratiet': ('plutokrati',),
'plutonisme': ('plutonisme',),
'plutonismen': ('plutonisme',),
'plutonismene': ('plutonisme',),
'plutonismer': ('plutonisme',),
'plutonist': ('plutonist',),
'plutonisten': ('plutonist',),
'plutonistene': ('plutonist',),
'plutonister': ('plutonist',),
'plutonium': ('plutonium',),
'plutoniuma': ('plutonium',),
'plutoniumene': ('plutonium',),
'plutoniumet': ('plutonium',),
'plutoniumdioksid': ('plutoniumdioksid',),
'plutoniumdioksida': ('plutoniumdioksid',),
'plutoniumdioksidene': ('plutoniumdioksid',),
'plutoniumdioksider': ('plutoniumdioksid',),
'plutoniumdioksidet': ('plutoniumdioksid',),
'pluviograf': ('pluviograf',),
'pluviografen': ('pluviograf',),
'pluviografene': ('pluviograf',),
'pluviografer': ('pluviograf',),
'pluviometer': ('pluviometer',),
'pluviometeret': ('pluviometer',),
'pluviometra': ('pluviometer',),
'pluviometre': ('pluviometer',),
'pluviometrene': ('pluviometer',),
'pluviometret': ('pluviometer',),
'plyndrer': ('plyndrer',),
'plyndrere': ('plyndrer',),
'plyndreren': ('plyndrer',),
'plyndrerer': ('plyndrer',),
'plyndrerne': ('plyndrer',),
'plyndring': ('plyndring',),
'plyndringa': ('plyndring',),
'plyndringen': ('plyndring',),
'plyndringene': ('plyndring',),
'plyndringer': ('plyndring',),
'plyndringstokt': ('plyndringstokt',),
'plyndringstokta': ('plyndringstokt',),
'plyndringstoktene': ('plyndringstokt',),
'plyndringstokter': ('plyndringstokt',),
'plyndringstoktet': ('plyndringstokt',),
'plysj': ('plysj',),
'plysjen': ('plysj',),
'plysjene': ('plysj',),
'plysjer': ('plysj',),
'plysjmøbel': ('plysjmøbel',),
'plysjmøbelet': ('plysjmøbel',),
'plysjmøbla': ('plysjmøbel',),
'plysjmøblene': ('plysjmøbel',),
'plysjmøbler': ('plysjmøbel',),
'plysjmøblet': ('plysjmøbel',),
'pløgsel': ('pløgsel',),
'pløgselen': ('pløgsel',),
'pløgsla': ('pløgsel',),
'pløgslene': ('pløgsel',),
'pløgsler': ('pløgsel',),
'pløgsla': ('pløgsle',),
'pløgsle': ('pløgsle',),
'pløgslen': ('pløgsle',),
'pløgslene': ('pløgsle',),
'pløgsler': ('pløgsle',),
'pløsa': ('pløse',),
'pløse': ('pløse',),
'pløsen': ('pløse',),
'pløsene': ('pløse',),
'pløser': ('pløse',),
'pløya': ('pløye',),
'pløye': ('pløye',),
'pløyen': ('pløye',),
'pløyene': ('pløye',),
'pløyer': ('pløye',),
'pm': ('pm',),
'pma': ('pm',),
'pmene': ('pm',),
'pmer': ('pm',),
'pmet': ('pm',),
'pneumatikk': ('pneumatikk',),
'pneumatikken': ('pneumatikk',),
'pneumatikkene': ('pneumatikk',),
'pneumatikker': ('pneumatikk',),
'pocketbok': ('pocketbok',),
'pocketboka': ('pocketbok',),
'pocketboken': ('pocketbok',),
'pocketbøkene': ('pocketbok',),
'pocketbøker': ('pocketbok',),
'pocketutgava': ('pocketutgave',),
'pocketutgave': ('pocketutgave',),
'pocketutgaven': ('pocketutgave',),
'pocketutgavene': ('pocketutgave',),
'pocketutgaver': ('pocketutgave',),
'podagra': ('podagra',),
'podagraen': ('podagra',),
'podagraene': ('podagra',),
'podagraer': ('podagra',),
'pode': ('pode',),
'poden': ('pode',),
'podene': ('pode',),
'poder': ('pode',),
'podeks': ('podeks',),
'podeksen': ('podeks',),
'podeksene': ('podeks',),
'podekser': ('podeks',),
'podekvist': ('podekvist',),
'podekvisten': ('podekvist',),
'podekvistene': ('podekvist',),
'podekvister': ('podekvist',),
'podevoks': ('podevoks',),
'podevoksa': ('podevoks',),
'podevoksen': ('podevoks',),
'podevoksene': ('podevoks',),
'podevokser': ('podevoks',),
'podevokset': ('podevoks',),
'podia': ('podium',),
'podiene': ('podium',),
'podier': ('podium',),
'podiet': ('podium',),
'podium': ('podium',),
'podsol': ('podsol',),
'podsola': ('podsol',),
'podsolene': ('podsol',),
'podsolet': ('podsol',),
'poem': ('poem',),
'poema': ('poem',),
'poemene': ('poem',),
'poemer': ('poem',),
'poemet': ('poem',),
'poeng': ('poeng',),
'poenga': ('poeng',),
'poengene': ('poeng',),
'poenger': ('poeng',),
'poenget': ('poeng',),
'poengberegning': ('poengberegning',),
'poengberegninga': ('poengberegning',),
'poengberegningen': ('poengberegning',),
'poengberegningene': ('poengberegning',),
'poengberegninger': ('poengberegning',),
'poengberekning': ('poengberekning',),
'poengberekninga': ('poengberekning',),
'poengberekningen': ('poengberekning',),
'poengberekningene': ('poengberekning',),
'poengberekninger': ('poengberekning',),
'poengdeling': ('poengdeling',),
'poengdelinga': ('poengdeling',),
'poengdelingen': ('poengdeling',),
'poengdelingene': ('poengdeling',),
'poengdelinger': ('poengdeling',),
'poengjag': ('poengjag',),
'poengjaga': ('poengjag',),
'poengjagene': ('poengjag',),
'poengjaget': ('poengjag',),
'poengseier': ('poengseier',),
'poengseiere': ('poengseier',),
'poengseieren': ('poengseier',),
'poengseierne': ('poengseier',),
'poengseire': ('poengseier',),
'poengseirene': ('poengseier',),
'poengseirer': ('poengseier',),
'poesi': ('poesi',),
'poesien': ('poesi',),
'poesiene': ('poesi',),
'poesier': ('poesi',),
'poet': ('poet',),
'poeten': ('poet',),
'poetene': ('poet',),
'poeter': ('poet',),
'poetikk': ('poetikk',),
'poetikken': ('poetikk',),
'poetikkene': ('poetikk',),
'poetikker': ('poetikk',),
'pogrom': ('pogrom',),
'pogromen': ('pogrom',),
'pogromene': ('pogrom',),
'pogromer': ('pogrom',),
'pointer': ('pointer',),
'pointere': ('pointer',),
'pointeren': ('pointer',),
'pointerer': ('pointer',),
'pointerne': ('pointer',),
'pointillisme': ('pointillisme',),
'pointillismen': ('pointillisme',),
'pointillismene': ('pointillisme',),
'pointillismer': ('pointillisme',),
'pokal': ('pokal',),
'pokalen': ('pokal',),
'pokalene': ('pokal',),
'pokaler': ('pokal',),
'pokalkamp': ('pokalkamp',),
'pokalkampen': ('pokalkamp',),
'pokalkampene': ('pokalkamp',),
'pokalkamper': ('pokalkamp',),
'poker': ('poker',),
'pokere': ('poker',),
'pokeren': ('poker',),
'pokerer': ('poker',),
'pokerne': ('poker',),
'pokerfjes': ('pokerfjes',),
'pokerfjesa': ('pokerfjes',),
'pokerfjesene': ('pokerfjes',),
'pokerfjeset': ('pokerfjes',),
'pokersjanse': ('pokersjanse',),
'pokersjansen': ('pokersjanse',),
'pokersjansene': ('pokersjanse',),
'pokersjanser': ('pokersjanse',),
'pokerspell': ('pokerspell',),
'pokerspella': ('pokerspell',),
'pokerspellene': ('pokerspell',),
'pokerspellet': ('pokerspell',),
'pokerspill': ('pokerspill',),
'pokerspilla': ('pokerspill',),
'pokerspillene': ('pokerspill',),
'pokerspillet': ('pokerspill',),
'pokker': ('pokker',),
'pokkeren': ('pokker',),
'pokkerene': ('pokker',),
'pokkerer': ('pokker',),
'pol': ('pol',),
'polen': ('pol',),
'polene': ('pol',),
'poler': ('pol',),
'pol': ('pol',),
'pola': ('pol',),
'polene': ('pol',),
'polet': ('pol',),
'polakk': ('polakk',),
'polakken': ('polakk',),
'polakkene': ('polakk',),
'polakker': ('polakk',),
'polarand': ('polarand',),
'polaranda': ('polarand',),
'polaranden': ('polarand',),
'polarendene': ('polarand',),
'polarender': ('polarand',),
'polardag': ('polardag',),
'polardagen': ('polardag',),
'polardagene': ('polardag',),
'polardager': ('polardag',),
'polarekspedisjon': ('polarekspedisjon',),
'polarekspedisjonen': ('polarekspedisjon',),
'polarekspedisjonene': ('polarekspedisjon',),
'polarekspedisjoner': ('polarekspedisjon',),
'polarfront': ('polarfront',),
'polarfronten': ('polarfront',),
'polarfrontene': ('polarfront',),
'polarfronter': ('polarfront',),
'polaris': ('polaris',),
'polarisen': ('polaris',),
'polarisene': ('polaris',),
'polariser': ('polaris',),
'polarisasjon': ('polarisasjon',),
'polarisasjonen': ('polarisasjon',),
'polarisasjonene': ('polarisasjon',),
'polarisasjoner': ('polarisasjon',),
'polarisator': ('polarisator',),
'polarisatoren': ('polarisator',),
'polarisatorene': ('polarisator',),
'polarisatorer': ('polarisator',),
'polarisering': ('polarisering',),
'polariseringa': ('polarisering',),
'polariseringen': ('polarisering',),
'polariseringene': ('polarisering',),
'polariseringer': ('polarisering',),
'polariseringsapparat': ('polariseringsapparat',),
'polariseringsapparata': ('polariseringsapparat',),
'polariseringsapparatene': ('polariseringsapparat',),
'polariseringsapparater': ('polariseringsapparat',),
'polariseringsapparatet': ('polariseringsapparat',),
'polariseringsfilter': ('polariseringsfilter',),
'polariseringsfilteret': ('polariseringsfilter',),
'polariseringsfiltra': ('polariseringsfilter',),
'polariseringsfiltre': ('polariseringsfilter',),
'polariseringsfiltrene': ('polariseringsfilter',),
'polariseringsfiltret': ('polariseringsfilter',),
'polariskop': ('polariskop',),
'polariskopa': ('polariskop',),
'polariskopene': ('polariskop',),
'polariskoper': ('polariskop',),
'polariskopet': ('polariskop',),
'polaritet': ('polaritet',),
'polariteten': ('polaritet',),
'polaritetene': ('polaritet',),
'polariteter': ('polaritet',),
'polarnatt': ('polarnatt',),
'polarnatta': ('polarnatt',),
'polarnatten': ('polarnatt',),
'polarnettene': ('polarnatt',),
'polarnetter': ('polarnatt',),
'polarrev': ('polarrev',),
'polarreven': ('polarrev',),
'polarrevene': ('polarrev',),
'polarrever': ('polarrev',),
'polarsirkel': ('polarsirkel',),
'polarsirkelen': ('polarsirkel',),
'polarsirklene': ('polarsirkel',),
'polarsirkler': ('polarsirkel',),
'polarstjerna': ('polarstjerne',),
'polarstjerne': ('polarstjerne',),
'polarstjernen': ('polarstjerne',),
'polarstjernene': ('polarstjerne',),
'polarstjerner': ('polarstjerne',),
'polarulv': ('polarulv',),
'polarulven': ('polarulv',),
'polarulvene': ('polarulv',),
'polarulver': ('polarulv',),
'polarvinter': ('polarvinter',),
'polarvintere': ('polarvinter',),
'polarvinteren': ('polarvinter',),
'polarvinterne': ('polarvinter',),
'polarvintre': ('polarvinter',),
'polarvintrene': ('polarvinter',),
'polarvintrer': ('polarvinter',),
'polder': ('polder',),
'poldere': ('polder',),
'polderen': ('polder',),
'polderer': ('polder',),
'polderne': ('polder',),
'pole': ('pole',),
'polen': ('pole',),
'polene': ('pole',),
'poler': ('pole',),
'poleball': ('poleball',),
'poleballen': ('poleball',),
'poleballene': ('poleball',),
'poleballer': ('poleball',),
'polemiker': ('polemiker',),
'polemikere': ('polemiker',),
'polemikeren': ('polemiker',),
'polemikerer': ('polemiker',),
'polemikerne': ('polemiker',),
'polemikk': ('polemikk',),
'polemikken': ('polemikk',),
'polemikkene': ('polemikk',),
'polemikker': ('polemikk',),
'polenta': ('polenta',),
'polentaen': ('polenta',),
'polentaene': ('polenta',),
'polentaer': ('polenta',),
'polentagraut': ('polentagraut',),
'polentagrauten': ('polentagraut',),
'polentagrautene': ('polentagraut',),
'polentagrauter': ('polentagraut',),
'polentagryn': ('polentagryn',),
'polentagryna': ('polentagryn',),
'polentagrynene': ('polentagryn',),
'polentagrynet': ('polentagryn',),
'polentagrøt': ('polentagrøt',),
'polentagrøten': ('polentagrøt',),
'polentagrøtene': ('polentagrøt',),
'polentagrøter': ('polentagrøt',),
'polentamel': ('polentamel',),
'polentamela': ('polentamel',),
'polentamelene': ('polentamel',),
'polentamelet': ('polentamel',),
'polentamjøl': ('polentamjøl',),
'polentamjøla': ('polentamjøl',),
'polentamjølene': ('polentamjøl',),
'polentamjølet': ('polentamjøl',),
'polentapudding': ('polentapudding',),
'polentapuddingen': ('polentapudding',),
'polentapuddingene': ('polentapudding',),
'polentapuddinger': ('polentapudding',),
'polering': ('polering',),
'poleringa': ('polering',),
'poleringen': ('polering',),
'poleringene': ('polering',),
'poleringer': ('polering',),
'poleringsmiddel': ('poleringsmiddel',),
'poleringsmiddelet': ('poleringsmiddel',),
'poleringsmidla': ('poleringsmiddel',),
'poleringsmidlene': ('poleringsmiddel',),
'poleringsmidler': ('poleringsmiddel',),
'poleringsmidlet': ('poleringsmiddel',),
'policy': ('policy',),
'policyen': ('policy',),
'policyene': ('policy',),
'policyer': ('policy',),
'poliklinikk': ('poliklinikk',),
'poliklinikken': ('poliklinikk',),
'poliklinikkene': ('poliklinikk',),
'poliklinikker': ('poliklinikk',),
'polio': ('polio',),
'polioen': ('polio',),
'polioene': ('polio',),
'polioer': ('polio',),
'polioepidemi': ('polioepidemi',),
'polioepidemien': ('polioepidemi',),
'polioepidemiene': ('polioepidemi',),
'polioepidemier': ('polioepidemi',),
'poliomyelitt': ('poliomyelitt',),
'poliomyelitten': ('poliomyelitt',),
'poliomyelittene': ('poliomyelitt',),
'poliomyelitter': ('poliomyelitt',),
'poliovaksina': ('poliovaksine',),
'poliovaksine': ('poliovaksine',),
'poliovaksinen': ('poliovaksine',),
'poliovaksinene': ('poliovaksine',),
'poliovaksiner': ('poliovaksine',),
'polis': ('polis',),
'polisen': ('polis',),
'polisene': ('polis',),
'poliser': ('polis',),
'polise': ('polise',),
'polisen': ('polise',),
'polisene': ('polise',),
'poliser': ('polise',),
'polish': ('polish',),
'polishen': ('polish',),
'polishene': ('polish',),
'polisher': ('polish',),
'politbyrå': ('politbyrå',),
'politbyråa': ('politbyrå',),
'politbyråene': ('politbyrå',),
'politbyråer': ('politbyrå',),
'politbyrået': ('politbyrå',),
'politi': ('politi',),
'politien': ('politi',),
'politiene': ('politi',),
'politier': ('politi',),
'politi': ('politi',),
'politia': ('politi',),
'politiene': ('politi',),
'politier': ('politi',),
'politiet': ('politi',),
'politiadjutant': ('politiadjutant',),
'politiadjutanten': ('politiadjutant',),
'politiadjutantene': ('politiadjutant',),
'politiadjutanter': ('politiadjutant',),
'politiattest': ('politiattest',),
'politiattesten': ('politiattest',),
'politiattestene': ('politiattest',),
'politiattester': ('politiattest',),
'politibetjent': ('politibetjent',),
'politibetjenten': ('politibetjent',),
'politibetjentene': ('politibetjent',),
'politibetjenter': ('politibetjent',),
'politifullmektig': ('politifullmektig',),
'politifullmektigen': ('politifullmektig',),
'politifullmektigene': ('politifullmektig',),
'politifullmektiger': ('politifullmektig',),
'politigrep': ('politigrep',),
'politigrepa': ('politigrep',),
'politigrepene': ('politigrep',),
'politigrepet': ('politigrep',),
'politihund': ('politihund',),
'politihunden': ('politihund',),
'politihundene': ('politihund',),
'politihunder': ('politihund',),
'politiinspektør': ('politiinspektør',),
'politiinspektøren': ('politiinspektør',),
'politiinspektørene': ('politiinspektør',),
'politiinspektører': ('politiinspektør',),
'politikammer': ('politikammer',),
'politikammeret': ('politikammer',),
'politikamra': ('politikammer',),
'politikamre': ('politikammer',),
'politikamrene': ('politikammer',),
'politiker': ('politiker',),
'politikere': ('politiker',),
'politikeren': ('politiker',),
'politikerer': ('politiker',),
'politikerne': ('politiker',),
'politikerforakt': ('politikerforakt',),
'politikerforakten': ('politikerforakt',),
'politikerforaktene': ('politikerforakt',),
'politikerforakter': ('politikerforakt',),
'politikerspråk': ('politikerspråk',),
'politikerspråka': ('politikerspråk',),
'politikerspråkene': ('politikerspråk',),
'politikerspråket': ('politikerspråk',),
'politikk': ('politikk',),
'politikken': ('politikk',),
'politikkene': ('politikk',),
'politikker': ('politikk',),
'politikonstabel': ('politikonstabel',),
'politikonstabelen': ('politikonstabel',),
'politikonstablene': ('politikonstabel',),
'politikonstabler': ('politikonstabel',),
'politikorps': ('politikorps',),
'politikorpsa': ('politikorps',),
'politikorpsene': ('politikorps',),
'politikorpset': ('politikorps',),
'politikus': ('politikus',),
'politikusen': ('politikus',),
'politikusene': ('politikus',),
'politikuser': ('politikus',),
'politikvinna': ('politikvinne',),
'politikvinne': ('politikvinne',),
'politikvinnen': ('politikvinne',),
'politikvinnene': ('politikvinne',),
'politikvinner': ('politikvinne',),
'politimann': ('politimann',),
'politimannen': ('politimann',),
'politimenn': ('politimann',),
'politimennene': ('politimann',),
'politimester': ('politimester',),
'politimestere': ('politimester',),
'politimesteren': ('politimester',),
'politimesterer': ('politimester',),
'politimesterne': ('politimester',),
'politimestre': ('politimester',),
'politimestrene': ('politimester',),
'politimestrer': ('politimester',),
'politiskilt': ('politiskilt',),
'politiskilta': ('politiskilt',),
'politiskiltene': ('politiskilt',),
'politiskilter': ('politiskilt',),
'politiskiltet': ('politiskilt',),
'politistasjon': ('politistasjon',),
'politistasjonen': ('politistasjon',),
'politistasjonene': ('politistasjon',),
'politistasjoner': ('politistasjon',),
'politistat': ('politistat',),
'politistaten': ('politistat',),
'politistatene': ('politistat',),
'politistater': ('politistat',),
'politivedtekt': ('politivedtekt',),
'politivedtekta': ('politivedtekt',),
'politivedtekten': ('politivedtekt',),
'politivedtektene': ('politivedtekt',),
'politivedtekter': ('politivedtekt',),
'politivold': ('politivold',),
'politivolden': ('politivold',),
'politivoldene': ('politivold',),
'politivolder': ('politivold',),
'politur': ('politur',),
'polituren': ('politur',),
'politurene': ('politur',),
'politurer': ('politur',),
'polka': ('polka',),
'polkaen': ('polka',),
'polkaene': ('polka',),
'polkaer': ('polka',),
'polkagris': ('polkagris',),
'polkagrisen': ('polkagris',),
'polkagrisene': ('polkagris',),
'polkagriser': ('polkagris',),
'poll': ('poll',),
'pollen': ('poll',),
'pollene': ('poll',),
'poller': ('poll',),
'pollen': ('pollen',),
'pollena': ('pollen',),
'pollenene': ('pollen',),
'pollenet': ('pollen',),
'pollenallergi': ('pollenallergi',),
'pollenallergien': ('pollenallergi',),
'pollenallergiene': ('pollenallergi',),
'pollenallergier': ('pollenallergi',),
'pollenanalysa': ('pollenanalyse',),
'pollenanalyse': ('pollenanalyse',),
'pollenanalysen': ('pollenanalyse',),
'pollenanalysene': ('pollenanalyse',),
'pollenanalyser': ('pollenanalyse',),
'pollenbærer': ('pollenbærer',),
'pollenbærere': ('pollenbærer',),
'pollenbæreren': ('pollenbærer',),
'pollenbærerer': ('pollenbærer',),
'pollenbærerne': ('pollenbærer',),
'pollenknapp': ('pollenknapp',),
'pollenknappen': ('pollenknapp',),
'pollenknappene': ('pollenknapp',),
'pollenknapper': ('pollenknapp',),
'pollenkorn': ('pollenkorn',),
'pollenkorna': ('pollenkorn',),
'pollenkornene': ('pollenkorn',),
'pollenkornet': ('pollenkorn',),
'pollenvarsling': ('pollenvarsling',),
'pollenvarslinga': ('pollenvarsling',),
'pollenvarslingen': ('pollenvarsling',),
'pollenvarslingene': ('pollenvarsling',),
'pollenvarslinger': ('pollenvarsling',),
'pollett': ('pollett',),
'polletten': ('pollett',),
'pollettene': ('pollett',),
'polletter': ('pollett',),
'pollusjon': ('pollusjon',),
'pollusjonen': ('pollusjon',),
'pollusjonene': ('pollusjon',),
'pollusjoner': ('pollusjon',),
'polo': ('polo',),
'poloen': ('polo',),
'poloene': ('polo',),
'poloer': ('polo',),
'polonese': ('polonese',),
'polonesen': ('polonese',),
'polonesene': ('polonese',),
'poloneser': ('polonese',),
'polonium': ('polonium',),
'poloniuma': ('polonium',),
'poloniumene': ('polonium',),
'poloniumet': ('polonium',),
'pols': ('pols',),
'polsen': ('pols',),
'polsene': ('pols',),
'polser': ('pols',),
'polsk': ('polsk',),
'polsken': ('polsk',),
'polskene': ('polsk',),
'polsker': ('polsk',),
'polsko': ('polsko',),
'polskoa': ('polsko',),
'polskoen': ('polsko',),
'polskoene': ('polsko',),
'polskor': ('polsko',),
'polskorne': ('polsko',),
'polstring': ('polstring',),
'polstringa': ('polstring',),
'polstringen': ('polstring',),
'polstringene': ('polstring',),
'polstringer': ('polstring',),
'poltergeist': ('poltergeist',),
'poltergeisten': ('poltergeist',),
'poltergeistene': ('poltergeist',),
'poltergeister': ('poltergeist',),
'polutsalg': ('polutsalg',),
'polutsalga': ('polutsalg',),
'polutsalgene': ('polutsalg',),
'polutsalget': ('polutsalg',),
'polvara': ('polvare',),
'polvare': ('polvare',),
'polvaren': ('polvare',),
'polvarene': ('polvare',),
'polvarer': ('polvare',),
'polyamid': ('polyamid',),
'polyamida': ('polyamid',),
'polyamidene': ('polyamid',),
'polyamider': ('polyamid',),
'polyamidet': ('polyamid',),
'polyandri': ('polyandri',),
'polyandria': ('polyandri',),
'polyandriene': ('polyandri',),
'polyandriet': ('polyandri',),
'polyeder': ('polyeder',),
'polyederet': ('polyeder',),
'polyedra': ('polyeder',),
'polyedre': ('polyeder',),
'polyedrene': ('polyeder',),
'polyedret': ('polyeder',),
'polyester': ('polyester',),
'polyestere': ('polyester',),
'polyesteren': ('polyester',),
'polyesterer': ('polyester',),
'polyesterne': ('polyester',),
'polyesterfiber': ('polyesterfiber',),
'polyesterfibere': ('polyesterfiber',),
'polyesterfiberen': ('polyesterfiber',),
'polyesterfiberer': ('polyesterfiber',),
'polyesterfiberne': ('polyesterfiber',),
'polyesterfibre': ('polyesterfiber',),
'polyesterfibrene': ('polyesterfiber',),
'polyesterfibrer': ('polyesterfiber',),
'polyetylen': ('polyetylen',),
'polyetylena': ('polyetylen',),
'polyetylenene': ('polyetylen',),
'polyetylenet': ('polyetylen',),
'polyfoni': ('polyfoni',),
'polyfonien': ('polyfoni',),
'polyfoniene': ('polyfoni',),
'polyfonier': ('polyfoni',),
'polygami': ('polygami',),
'polygamia': ('polygami',),
'polygamiene': ('polygami',),
'polygamiet': ('polygami',),
'polyglott': ('polyglott',),
'polyglotten': ('polyglott',),
'polyglottene': ('polyglott',),
'polyglotter': ('polyglott',),
'polygon': ('polygon',),
'polygonen': ('polygon',),
'polygonene': ('polygon',),
'polygoner': ('polygon',),
'polygyni': ('polygyni',),
'polygynia': ('polygyni',),
'polygyniene': ('polygyni',),
'polygyniet': ('polygyni',),
'polyhistor': ('polyhistor',),
'polyhistoren': ('polyhistor',),
'polyhistorene': ('polyhistor',),
'polyhistorer': ('polyhistor',),
'polykromi': ('polykromi',),
'polykromien': ('polykromi',),
'polykromiene': ('polykromi',),
'polykromier': ('polykromi',),
'polymer': ('polymer',),
'polymeren': ('polymer',),
'polymerene': ('polymer',),
'polymerer': ('polymer',),
'polymerisasjon': ('polymerisasjon',),
'polymerisasjonen': ('polymerisasjon',),
'polymerisasjonene': ('polymerisasjon',),
'polymerisasjoner': ('polymerisasjon',),
'polymorfi': ('polymorfi',),
'polymorfien': ('polymorfi',),
'polymorfiene': ('polymorfi',),
'polymorfier': ('polymorfi',),
'polymorfisme': ('polymorfisme',),
'polymorfismen': ('polymorfisme',),
'polymorfismene': ('polymorfisme',),
'polymorfismer': ('polymorfisme',),
'polynesier': ('polynesier',),
'polynesiere': ('polynesier',),
'polynesieren': ('polynesier',),
'polynesierer': ('polynesier',),
'polynesierne': ('polynesier',),
'polynom': ('polynom',),
'polynoma': ('polynom',),
'polynomene': ('polynom',),
'polynomer': ('polynom',),
'polynomet': ('polynom',),
'polypp': ('polypp',),
'polyppen': ('polypp',),
'polyppene': ('polypp',),
'polypper': ('polypp',),
'polyppdyr': ('polyppdyr',),
'polyppdyra': ('polyppdyr',),
'polyppdyrene': ('polyppdyr',),
'polyppdyret': ('polyppdyr',),
'polyrytmikk': ('polyrytmikk',),
'polyrytmikken': ('polyrytmikk',),
'polyrytmikkene': ('polyrytmikk',),
'polyrytmikker': ('polyrytmikk',),
'polysemi': ('polysemi',),
'polysemien': ('polysemi',),
'polysemiene': ('polysemi',),
'polysemier': ('polysemi',),
'polysyndese': ('polysyndese',),
'polysyndesen': ('polysyndese',),
'polysyndesene': ('polysyndese',),
'polysyndeser': ('polysyndese',),
'polyteisme': ('polyteisme',),
'polyteismen': ('polyteisme',),
'polyteismene': ('polyteisme',),
'polyteismer': ('polyteisme',),
'polyteist': ('polyteist',),
'polyteisten': ('polyteist',),
'polyteistene': ('polyteist',),
'polyteister': ('polyteist',),
'polyteknikk': ('polyteknikk',),
'polyteknikken': ('polyteknikk',),
'polyteknikkene': ('polyteknikk',),
'polyteknikker': ('polyteknikk',),
'polyuretan': ('polyuretan',),
'polyuretana': ('polyuretan',),
'polyuretanene': ('polyuretan',),
'polyuretanet': ('polyuretan',),
'polyuretangummi': ('polyuretangummi',),
'polyuretangummien': ('polyuretangummi',),
'polyuretangummiene': ('polyuretangummi',),
'polyuretangummier': ('polyuretangummi',),
'polyuretanskumplast': ('polyuretanskumplast',),
'polyuretanskumplasten': ('polyuretanskumplast',),
'polyuretanskumplastene': ('polyuretanskumplast',),
'polyuretanskumplaster': ('polyuretanskumplast',),
'polyvinylklorid': ('polyvinylklorid',),
'polyvinylklorida': ('polyvinylklorid',),
'polyvinylkloridene': ('polyvinylklorid',),
'polyvinylklorider': ('polyvinylklorid',),
'polyvinylkloridet': ('polyvinylklorid',),
'pomade': ('pomade',),
'pomaden': ('pomade',),
'pomadene': ('pomade',),
'pomader': ('pomade',),
'pomerans': ('pomerans',),
'pomeransen': ('pomerans',),
'pomeransene': ('pomerans',),
'pomeranser': ('pomerans',),
'pomeranslikør': ('pomeranslikør',),
'pomeranslikøren': ('pomeranslikør',),
'pomeranslikørene': ('pomeranslikør',),
'pomeranslikører': ('pomeranslikør',),
'pomeranstre': ('pomeranstre',),
'pomeranstrea': ('pomeranstre',),
'pomeranstreet': ('pomeranstre',),
'pomeranstrær': ('pomeranstre',),
'pomeranstrærne': ('pomeranstre',),
'pommes frites': ('pommes frites',),
'pommes fritesen': ('pommes frites',),
'pommes fritesene': ('pommes frites',),
'pommes friteser': ('pommes frites',),
'pomologi': ('pomologi',),
'pomologien': ('pomologi',),
'pomologiene': ('pomologi',),
'pomologier': ('pomologi',),
'pomor': ('pomor',),
'pomoren': ('pomor',),
'pomorene': ('pomor',),
'pomorer': ('pomor',),
'pomorhandel': ('pomorhandel',),
'pomorhandelen': ('pomorhandel',),
'pomorhandlene': ('pomorhandel',),
'pomorhandler': ('pomorhandel',),
'pompadur': ('pompadur',),
'pompaduren': ('pompadur',),
'pompadurene': ('pompadur',),
'pompadurer': ('pompadur',),
'pompong': ('pompong',),
'pompongen': ('pompong',),
'pompongene': ('pompong',),
'pomponger': ('pompong',),
'ponceau': ('ponceau',),
'poncho': ('poncho',),
'ponchoen': ('poncho',),
'ponchoene': ('poncho',),
'ponchoer': ('poncho',),
'pond': ('pond',),
'ponda': ('pond',),
'pondene': ('pond',),
'pondet': ('pond',),
'pondus': ('pondus',),
'pondusen': ('pondus',),
'pondusene': ('pondus',),
'ponduser': ('pondus',),
'pongtong': ('pongtong',),
'pongtongen': ('pongtong',),
'pongtongene': ('pongtong',),
'pongtonger': ('pongtong',),
'pongtongbro': ('pongtongbro',),
'pongtongbroa': ('pongtongbro',),
'pongtongbroen': ('pongtongbro',),
'pongtongbroene': ('pongtongbro',),
'pongtongbroer': ('pongtongbro',),
'pongtongbru': ('pongtongbru',),
'pongtongbrua': ('pongtongbru',),
'pongtongbruen': ('pongtongbru',),
'pongtongbruene': ('pongtongbru',),
'pongtongbruer': ('pongtongbru',),
'ponni': ('ponni',),
'ponnien': ('ponni',),
'ponniene': ('ponni',),
'ponnier': ('ponni',),
'pontifeks': ('pontifeks',),
'pontifeksen': ('pontifeks',),
'pontifeksene': ('pontifeks',),
'pontifekser': ('pontifeks',),
'pontifikaliene': ('pontifikalier',),
'pontifikalier': ('pontifikalier',),
'pontifikalmessa': ('pontifikalmesse',),
'pontifikalmesse': ('pontifikalmesse',),
'pontifikalmessen': ('pontifikalmesse',),
'pontifikalmessene': ('pontifikalmesse',),
'pontifikalmesser': ('pontifikalmesse',),
'pontifikat': ('pontifikat',),
'pontifikata': ('pontifikat',),
'pontifikatene': ('pontifikat',),
'pontifikater': ('pontifikat',),
'pontifikatet': ('pontifikat',),
'pool': ('pool',),
'poolen': ('pool',),
'poolene': ('pool',),
'pooler': ('pool',),
'poop': ('poop',),
'poopen': ('poop',),
'poopene': ('poop',),
'pooper': ('poop',),
'pop': ('pop',),
'popen': ('pop',),
'popene': ('pop',),
'poper': ('pop',),
'popartist': ('popartist',),
'popartisten': ('popartist',),
'popartistene': ('popartist',),
'popartister': ('popartist',),
'popband': ('popband',),
'popbanda': ('popband',),
'popbandene': ('popband',),
'popbandet': ('popband',),
'pope': ('pope',),
'popen': ('pope',),
'popene': ('pope',),
'poper': ('pope',),
'popgruppa': ('popgruppe',),
'popgruppe': ('popgruppe',),
'popgruppen': ('popgruppe',),
'popgruppene': ('popgruppe',),
'popgrupper': ('popgruppe',),
'popkorn': ('popkorn',),
'popkorna': ('popkorn',),
'popkornen': ('popkorn',),
'popkornene': ('popkorn',),
'popkorner': ('popkorn',),
'popkornet': ('popkorn',),
'popkunst': ('popkunst',),
'popkunsten': ('popkunst',),
'popkunstene': ('popkunst',),
'popkunster': ('popkunst',),
'poplin': ('poplin',),
'poplina': ('poplin',),
'poplinene': ('poplin',),
'popliner': ('poplin',),
'poplinet': ('poplin',),
'poplinsfrakk': ('poplinsfrakk',),
'poplinsfrakken': ('poplinsfrakk',),
'poplinsfrakkene': ('poplinsfrakk',),
'poplinsfrakker': ('poplinsfrakk',),
'popmusikk': ('popmusikk',),
'popmusikken': ('popmusikk',),
'popmusikkene': ('popmusikk',),
'popmusikker': ('popmusikk',),
'popp': ('popp',),
'poppen': ('popp',),
'poppene': ('popp',),
'popper': ('popp',),
'poppartist': ('poppartist',),
'poppartisten': ('poppartist',),
'poppartistene': ('poppartist',),
'poppartister': ('poppartist',),
'poppband': ('poppband',),
'poppbanda': ('poppband',),
'poppbandene': ('poppband',),
'poppbandet': ('poppband',),
'poplene': ('poppel',),
'popler': ('poppel',),
'poppel': ('poppel',),
'poppelen': ('poppel',),
'poppeldun': ('poppeldun',),
'poppelduna': ('poppeldun',),
'poppeldunen': ('poppeldun',),
'poppeldunene': ('poppeldun',),
'poppeldunet': ('poppeldun',),
'poppgruppa': ('poppgruppe',),
'poppgruppe': ('poppgruppe',),
'poppgruppen': ('poppgruppe',),
'poppgruppene': ('poppgruppe',),
'poppgrupper': ('poppgruppe',),
'poppkunst': ('poppkunst',),
'poppkunsten': ('poppkunst',),
'poppkunstene': ('poppkunst',),
'poppkunster': ('poppkunst',),
'poppmusikk': ('poppmusikk',),
'poppmusikken': ('poppmusikk',),
'poppmusikkene': ('poppmusikk',),
'poppmusikker': ('poppmusikk',),
'popularisator': ('popularisator',),
'popularisatoren': ('popularisator',),
'popularisatorene': ('popularisator',),
'popularisatorer': ('popularisator',),
'popularitet': ('popularitet',),
'populariteten': ('popularitet',),
'popularitetene': ('popularitet',),
'populariteter': ('popularitet',),
'popularitetsjeger': ('popularitetsjeger',),
'popularitetsjegere': ('popularitetsjeger',),
'popularitetsjegeren': ('popularitetsjeger',),
'popularitetsjegerer': ('popularitetsjeger',),
'popularitetsjegerne': ('popularitetsjeger',),
'populas': ('populas',),
'populasen': ('populas',),
'populasene': ('populas',),
'populaser': ('populas',),
'populasjon': ('populasjon',),
'populasjonen': ('populasjon',),
'populasjonene': ('populasjon',),
'populasjoner': ('populasjon',),
'populasjonsdynamikk': ('populasjonsdynamikk',),
'populasjonsdynamikken': ('populasjonsdynamikk',),
'populasjonsdynamikkene': ('populasjonsdynamikk',),
'populasjonsdynamikker': ('populasjonsdynamikk',),
'populisme': ('populisme',),
'populismen': ('populisme',),
'populismene': ('populisme',),
'populismer': ('populisme',),
'populist': ('populist',),
'populisten': ('populist',),
'populistene': ('populist',),
'populister': ('populist',),
'populærkonsert': ('populærkonsert',),
'populærkonserten': ('populærkonsert',),
'populærkonsertene': ('populærkonsert',),
'populærkonserter': ('populærkonsert',),
'populærmusikk': ('populærmusikk',),
'populærmusikken': ('populærmusikk',),
'populærmusikkene': ('populærmusikk',),
'populærmusikker': ('populærmusikk',),
'populærvitenskap': ('populærvitenskap',),
'populærvitenskapen': ('populærvitenskap',),
'populærvitenskapene': ('populærvitenskap',),
'populærvitenskaper': ('populærvitenskap',),
'populærvitskap': ('populærvitskap',),
'populærvitskapen': ('populærvitskap',),
'populærvitskapene': ('populærvitskap',),
'populærvitskaper': ('populærvitskap',),
'pora': ('pore',),
'pore': ('pore',),
'poren': ('pore',),
'porene': ('pore',),
'porer': ('pore',),
'poresopp': ('poresopp',),
'poresoppen': ('poresopp',),
'poresoppene': ('poresopp',),
'poresopper': ('poresopp',),
'porfyr': ('porfyr',),
'porfyren': ('porfyr',),
'porfyrene': ('porfyr',),
'porfyrer': ('porfyr',),
'porno': ('porno',),
'pornoen': ('porno',),
'pornoene': ('porno',),
'pornoer': ('porno',),
'pornoblad': ('pornoblad',),
'pornoblada': ('pornoblad',),
'pornobladene': ('pornoblad',),
'pornoblader': ('pornoblad',),
'pornobladet': ('pornoblad',),
'pornofilm': ('pornofilm',),
'pornofilmen': ('pornofilm',),
'pornofilmene': ('pornofilm',),
'pornofilmer': ('pornofilm',),
'pornograf': ('pornograf',),
'pornografen': ('pornograf',),
'pornografene': ('pornograf',),
'pornografer': ('pornograf',),
'pornografi': ('pornografi',),
'pornografien': ('pornografi',),
'pornografiene': ('pornografi',),
'pornografier': ('pornografi',),
'pors': ('pors',),
'porsen': ('pors',),
'porsene': ('pors',),
'porser': ('pors',),
'porselen': ('porselen',),
'porselena': ('porselen',),
'porselenene': ('porselen',),
'porselener': ('porselen',),
'porselenet': ('porselen',),
'porselensblått': ('porselensblått',),
'porselensisolator': ('porselensisolator',),
'porselensisolatoren': ('porselensisolator',),
'porselensisolatorene': ('porselensisolator',),
'porselensisolatorer': ('porselensisolator',),
'porselensmaling': ('porselensmaling',),
'porselensmalinga': ('porselensmaling',),
'porselensmalingen': ('porselensmaling',),
'porselensmalingene': ('porselensmaling',),
'porselensmalinger': ('porselensmaling',),
'porselensservisa': ('porselensservise',),
'porselensservise': ('porselensservise',),
'porselensservisene': ('porselensservise',),
'porselensserviser': ('porselensservise',),
'porselensserviset': ('porselensservise',),
'porselenssnegl': ('porselenssnegl',),
'porselenssneglen': ('porselenssnegl',),
'porselenssneglene': ('porselenssnegl',),
'porselenssnegler': ('porselenssnegl',),
'porselenssnile': ('porselenssnile',),
'porselenssnilen': ('porselenssnile',),
'porselenssnilene': ('porselenssnile',),
'porselenssniler': ('porselenssnile',),
'porsjon': ('porsjon',),
'porsjonen': ('porsjon',),
'porsjonene': ('porsjon',),
'porsjoner': ('porsjon',),
'porsjonsmiddag': ('porsjonsmiddag',),
'porsjonsmiddagen': ('porsjonsmiddag',),
'porsjonsmiddagene': ('porsjonsmiddag',),
'porsjonsmiddager': ('porsjonsmiddag',),
'porsjonspakning': ('porsjonspakning',),
'porsjonspakninga': ('porsjonspakning',),
'porsjonspakningen': ('porsjonspakning',),
'porsjonspakningene': ('porsjonspakning',),
'porsjonspakninger': ('porsjonspakning',),
'port': ('port',),
'porten': ('port',),
'portene': ('port',),
'porter': ('port',),
'portal': ('portal',),
'portalen': ('portal',),
'portalene': ('portal',),
'portaler': ('portal',),
'portamento': ('portamento',),
'portamentoa': ('portamento',),
'portamentoene': ('portamento',),
'portamentoer': ('portamento',),
'portamentoet': ('portamento',),
'portato': ('portato',),
'portatoa': ('portato',),
'portatoene': ('portato',),
'portatoer': ('portato',),
'portatoet': ('portato',),
'portechaise': ('portechaise',),
'portechaisen': ('portechaise',),
'portechaisene': ('portechaise',),
'portechaiser': ('portechaise',),
'portefølje': ('portefølje',),
'porteføljen': ('portefølje',),
'porteføljene': ('portefølje',),
'porteføljer': ('portefølje',),
'porteføljeforretning': ('porteføljeforretning',),
'porteføljeforretninga': ('porteføljeforretning',),
'porteføljeforretningen': ('porteføljeforretning',),
'porteføljeforretningene': ('porteføljeforretning',),
'porteføljeforretninger': ('porteføljeforretning',),
'porteføljevara': ('porteføljevare',),
'porteføljevare': ('porteføljevare',),
'porteføljevaren': ('porteføljevare',),
'porteføljevarene': ('porteføljevare',),
'porteføljevarer': ('porteføljevare',),
'portemoneen': ('portemoné',),
'portemoneene': ('portemoné',),
'portemoneer': ('portemoné',),
'portemoné': ('portemoné',),
'portemonéen': ('portemoné',),
'portemonéene': ('portemoné',),
'portemonéer': ('portemoné',),
'porter': ('porter',),
'porteren': ('porter',),
'porterene': ('porter',),
'porterer': ('porter',),
'portforbud': ('portforbud',),
'portforbuda': ('portforbud',),
'portforbudene': ('portforbud',),
'portforbudet': ('portforbud',),
'porthandel': ('porthandel',),
'porthandelen': ('porthandel',),
'porthandlene': ('porthandel',),
'porthandler': ('porthandel',),
'portier': ('portier',),
'portieren': ('portier',),
'portierene': ('portier',),
'portierer': ('portier',),
'portiere': ('portiere',),
'portieren': ('portiere',),
'portierene': ('portiere',),
'portierer': ('portiere',),
'portiko': ('portiko',),
'portikoen': ('portiko',),
'portikoene': ('portiko',),
'portikoer': ('portiko',),
'portikus': ('portikus',),
'portikusen': ('portikus',),
'portikusene': ('portikus',),
'portikuser': ('portikus',),
'portlandsement': ('portlandsement',),
'portlandsementen': ('portlandsement',),
'portlandsementene': ('portlandsement',),
'portlandsementer': ('portlandsement',),
'portner': ('portner',),
'portnere': ('portner',),
'portneren': ('portner',),
'portnerer': ('portner',),
'portnerne': ('portner',),
'portnerkona': ('portnerkone',),
'portnerkone': ('portnerkone',),
'portnerkonen': ('portnerkone',),
'portnerkonene': ('portnerkone',),
'portnerkoner': ('portnerkone',),
'portneråpning': ('portneråpning',),
'portneråpninga': ('portneråpning',),
'portneråpningen': ('portneråpning',),
'portneråpningene': ('portneråpning',),
'portneråpninger': ('portneråpning',),
'porto': ('porto',),
'portoen': ('porto',),
'portoene': ('porto',),
'portoer': ('porto',),
'portotakst': ('portotakst',),
'portotaksten': ('portotakst',),
'portotakstene': ('portotakst',),
'portotakster': ('portotakst',),
'portrett': ('portrett',),
'portretta': ('portrett',),
'portrettene': ('portrett',),
'portretter': ('portrett',),
'portrettet': ('portrett',),
'portrettfotograf': ('portrettfotograf',),
'portrettfotografen': ('portrettfotograf',),
'portrettfotografene': ('portrettfotograf',),
'portrettfotografer': ('portrettfotograf',),
'portrettintervju': ('portrettintervju',),
'portrettintervjua': ('portrettintervju',),
'portrettintervjuene': ('portrettintervju',),
'portrettintervjuer': ('portrettintervju',),
'portrettintervjuet': ('portrettintervju',),
'portrettlikhet': ('portrettlikhet',),
'portrettlikheta': ('portrettlikhet',),
'portrettlikheten': ('portrettlikhet',),
'portrettlikhetene': ('portrettlikhet',),
'portrettlikheter': ('portrettlikhet',),
'portrom': ('portrom',),
'portromma': ('portrom',),
'portrommene': ('portrom',),
'portrommet': ('portrom',),
'portstolpe': ('portstolpe',),
'portstolpen': ('portstolpe',),
'portstolpene': ('portstolpe',),
'portstolper': ('portstolpe',),
'portugiser': ('portugiser',),
'portugisere': ('portugiser',),
'portugiseren': ('portugiser',),
'portugiserer': ('portugiser',),
'portugiserne': ('portugiser',),
'portulakk': ('portulakk',),
'portulakken': ('portulakk',),
'portulakkene': ('portulakk',),
'portulakker': ('portulakk',),
'portvakt': ('portvakt',),
'portvakta': ('portvakt',),
'portvakten': ('portvakt',),
'portvaktene': ('portvakt',),
'portvakter': ('portvakt',),
'portvene': ('portvene',),
'portvenen': ('portvene',),
'portvenene': ('portvene',),
'portvener': ('portvene',),
'portvin': ('portvin',),
'portvinen': ('portvin',),
'portvinene': ('portvin',),
'portviner': ('portvin',),
'portåra': ('portåre',),
'portåre': ('portåre',),
'portåren': ('portåre',),
'portårene': ('portåre',),
'portårer': ('portåre',),
'portør': ('portør',),
'portøren': ('portør',),
'portørene': ('portør',),
'portører': ('portør',),
'porøsitet': ('porøsitet',),
'porøsiteten': ('porøsitet',),
'porøsitetene': ('porøsitet',),
'porøsiteter': ('porøsitet',),
'pose': ('pose',),
'posen': ('pose',),
'posene': ('pose',),
'poser': ('pose',),
'pose': ('pose',),
'posen': ('pose',),
'posene': ('pose',),
'poser': ('pose',),
'posebuksa': ('posebukse',),
'posebukse': ('posebukse',),
'posebuksen': ('posebukse',),
'posebuksene': ('posebukse',),
'posebukser': ('posebukse',),
'posekiker': ('posekiker',),
'posekikere': ('posekiker',),
'posekikeren': ('posekiker',),
'posekikerer': ('posekiker',),
'posekikerne': ('posekiker',),
'posekikker': ('posekikker',),
'posekikkere': ('posekikker',),
'posekikkeren': ('posekikker',),
'posekikkerer': ('posekikker',),
'posekikkerne': ('posekikker',),
'poselyng': ('poselyng',),
'poselynga': ('poselyng',),
'poselyngen': ('poselyng',),
'poselyngene': ('poselyng',),
'poselynger': ('poselyng',),
'poselynget': ('poselyng',),
'posenot': ('posenot',),
'posenota': ('posenot',),
'posenoten': ('posenot',),
'posenøtene': ('posenot',),
'posenøter': ('posenot',),
'posesuppa': ('posesuppe',),
'posesuppe': ('posesuppe',),
'posesuppen': ('posesuppe',),
'posesuppene': ('posesuppe',),
'posesupper': ('posesuppe',),
'posetur': ('posetur',),
'poseturen': ('posetur',),
'poseturene': ('posetur',),
'poseturer': ('posetur',),
'posisjon': ('posisjon',),
'posisjonen': ('posisjon',),
'posisjonene': ('posisjon',),
'posisjoner': ('posisjon',),
'posisjonsskriver': ('posisjonsskriver',),
'posisjonsskrivere': ('posisjonsskriver',),
'posisjonsskriveren': ('posisjonsskriver',),
'posisjonsskriverer': ('posisjonsskriver',),
'posisjonsskriverne': ('posisjonsskriver',),
'positiv': ('positiv',),
'positiven': ('positiv',),
'positivene': ('positiv',),
'positiver': ('positiv',),
'positiv': ('positiv',),
'positiva': ('positiv',),
'positivene': ('positiv',),
'positiver': ('positiv',),
'positivet': ('positiv',),
'positiv': ('positiv',),
'positiva': ('positiv',),
'positiven': ('positiv',),
'positivene': ('positiv',),
'positiver': ('positiv',),
'positivet': ('positiv',),
'positivisme': ('positivisme',),
'positivismen': ('positivisme',),
'positivismene': ('positivisme',),
'positivismer': ('positivisme',),
'positivist': ('positivist',),
'positivisten': ('positivist',),
'positivistene': ('positivist',),
'positivister': ('positivist',),
'positivitet': ('positivitet',),
'positiviteten': ('positivitet',),
'positivitetene': ('positivitet',),
'positiviteter': ('positivitet',),
'positron': ('positron',),
'positrona': ('positron',),
'positronene': ('positron',),
'positroner': ('positron',),
'positronet': ('positron',),
'positur': ('positur',),
'posituren': ('positur',),
'positurene': ('positur',),
'positurer': ('positur',),
'possement': ('possement',),
'possementa': ('possement',),
'possementene': ('possement',),
'possementer': ('possement',),
'possementet': ('possement',),
'possementmaker': ('possementmaker',),
'possementmakere': ('possementmaker',),
'possementmakeren': ('possementmaker',),
'possementmakerer': ('possementmaker',),
'possementmakerne': ('possementmaker',),
'possessiv': ('possessiv',),
'possessiva': ('possessiv',),
'possessivene': ('possessiv',),
'possessiver': ('possessiv',),
'possessivet': ('possessiv',),
'postadressa': ('postadresse',),
'postadresse': ('postadresse',),
'postadressen': ('postadresse',),
'postadressene': ('postadresse',),
'postadresser': ('postadresse',),
'postament': ('postament',),
'postamenta': ('postament',),
'postamentene': ('postament',),
'postamenter': ('postament',),
'postamentet': ('postament',),
'postanvisning': ('postanvisning',),
'postanvisninga': ('postanvisning',),
'postanvisningen': ('postanvisning',),
'postanvisningene': ('postanvisning',),
'postanvisninger': ('postanvisning',),
'postbank': ('postbank',),
'postbanken': ('postbank',),
'postbankene': ('postbank',),
'postbanker': ('postbank',),
'postbetjent': ('postbetjent',),
'postbetjenten': ('postbetjent',),
'postbetjentene': ('postbetjent',),
'postbetjenter': ('postbetjent',),
'postboks': ('postboks',),
'postboksen': ('postboks',),
'postboksene': ('postboks',),
'postbokser': ('postboks',),
'postbrev': ('postbrev',),
'postbreva': ('postbrev',),
'postbrevene': ('postbrev',),
'postbrever': ('postbrev',),
'postbrevet': ('postbrev',),
'postbud': ('postbud',),
'postbuda': ('postbud',),
'postbudene': ('postbud',),
'postbudet': ('postbud',),
'postdistrikt': ('postdistrikt',),
'postdistrikta': ('postdistrikt',),
'postdistriktene': ('postdistrikt',),
'postdistrikter': ('postdistrikt',),
'postdistriktet': ('postdistrikt',),
'postei': ('postei',),
'posteien': ('postei',),
'posteiene': ('postei',),
'posteier': ('postei',),
'postekspedisjon': ('postekspedisjon',),
'postekspedisjonen': ('postekspedisjon',),
'postekspedisjonene': ('postekspedisjon',),
'postekspedisjoner': ('postekspedisjon',),
'postekspeditør': ('postekspeditør',),
'postekspeditøren': ('postekspeditør',),
'postekspeditørene': ('postekspeditør',),
'postekspeditører': ('postekspeditør',),
'poster': ('poster',),
'postere': ('poster',),
'posteren': ('poster',),
'posterer': ('poster',),
'posterne': ('poster',),
'postering': ('postering',),
'posteringa': ('postering',),
'posteringen': ('postering',),
'posteringene': ('postering',),
'posteringer': ('postering',),
'posteringsfeil': ('posteringsfeil',),
'posteringsfeilen': ('posteringsfeil',),
'posteringsfeilene': ('posteringsfeil',),
'posteringsjakt': ('posteringsjakt',),
'posteringsjakta': ('posteringsjakt',),
'posteringsjakten': ('posteringsjakt',),
'posteringsjaktene': ('posteringsjakt',),
'posteringsjakter': ('posteringsjakt',),
'postfaks': ('postfaks',),
'postfaksen': ('postfaks',),
'postfaksene': ('postfaks',),
'postfakser': ('postfaks',),
'postflagg': ('postflagg',),
'postflagga': ('postflagg',),
'postflaggene': ('postflagg',),
'postflagget': ('postflagg',),
'postflagg': ('postflagg',),
'postflagga': ('postflagg',),
'postflaggene': ('postflagg',),
'postflagget': ('postflagg',),
'postfly': ('postfly',),
'postflya': ('postfly',),
'postflyene': ('postfly',),
'postflyet': ('postfly',),
'postfunksjonær': ('postfunksjonær',),
'postfunksjonæren': ('postfunksjonær',),
'postfunksjonærene': ('postfunksjonær',),
'postfunksjonærer': ('postfunksjonær',),
'postfører': ('postfører',),
'postførere': ('postfører',),
'postføreren': ('postfører',),
'postførerer': ('postfører',),
'postførerne': ('postfører',),
'postgang': ('postgang',),
'postgangen': ('postgang',),
'postgangene': ('postgang',),
'postganger': ('postgang',),
'postgiro': ('postgiro',),
'postgiroen': ('postgiro',),
'postgiroene': ('postgiro',),
'postgiroer': ('postgiro',),
'posthorn': ('posthorn',),
'posthorna': ('posthorn',),
'posthornene': ('posthorn',),
'posthornet': ('posthorn',),
'posthus': ('posthus',),
'posthusa': ('posthus',),
'posthusene': ('posthus',),
'posthuset': ('posthus',),
'postiljong': ('postiljong',),
'postiljongen': ('postiljong',),
'postiljongene': ('postiljong',),
'postiljonger': ('postiljong',),
'postill': ('postill',),
'postillen': ('postill',),
'postillene': ('postill',),
'postiller': ('postill',),
'postisj': ('postisj',),
'postisjen': ('postisj',),
'postisjene': ('postisj',),
'postisjer': ('postisj',),
'postkassa': ('postkasse',),
'postkasse': ('postkasse',),
'postkassen': ('postkasse',),
'postkassene': ('postkasse',),
'postkasser': ('postkasse',),
'postkontor': ('postkontor',),
'postkontora': ('postkontor',),
'postkontorene': ('postkontor',),
'postkontorer': ('postkontor',),
'postkontoret': ('postkontor',),
'postkort': ('postkort',),
'postkorta': ('postkort',),
'postkortene': ('postkort',),
'postkortet': ('postkort',),
'postludia': ('postludium',),
'postludiene': ('postludium',),
'postludier': ('postludium',),
'postludiet': ('postludium',),
'postludium': ('postludium',),
'postmann': ('postmann',),
'postmannen': ('postmann',),
'postmenn': ('postmann',),
'postmennene': ('postmann',),
'postmester': ('postmester',),
'postmestere': ('postmester',),
'postmesteren': ('postmester',),
'postmesterer': ('postmester',),
'postmesterne': ('postmester',),
'postmestre': ('postmester',),
'postmestrene': ('postmester',),
'postmestrer': ('postmester',),
'postnummer': ('postnummer',),
'postnummeret': ('postnummer',),
'postnumra': ('postnummer',),
'postnumre': ('postnummer',),
'postnumrene': ('postnummer',),
'postoppkrav': ('postoppkrav',),
'postoppkrava': ('postoppkrav',),
'postoppkravene': ('postoppkrav',),
'postoppkravet': ('postoppkrav',),
'postordre': ('postordre',),
'postordren': ('postordre',),
'postordrene': ('postordre',),
'postordrer': ('postordre',),
'postordreforretning': ('postordreforretning',),
'postordreforretninga': ('postordreforretning',),
'postordreforretningen': ('postordreforretning',),
'postordreforretningene': ('postordreforretning',),
'postordreforretninger': ('postordreforretning',),
'postran': ('postran',),
'postrana': ('postran',),
'postranene': ('postran',),
'postranet': ('postran',),
'postsjakk': ('postsjakk',),
'postsjakken': ('postsjakk',),
'postsjakkene': ('postsjakk',),
'postsjakker': ('postsjakk',),
'postsjef': ('postsjef',),
'postsjefen': ('postsjef',),
'postsjefene': ('postsjef',),
'postsjefer': ('postsjef',),
'postskip': ('postskip',),
'postskipa': ('postskip',),
'postskipene': ('postskip',),
'postskipet': ('postskip',),
'postskripta': ('postskriptum',),
'postskriptaene': ('postskriptum',),
'postskriptum': ('postskriptum',),
'postskriptuma': ('postskriptum',),
'postskriptumene': ('postskriptum',),
'postskriptumer': ('postskriptum',),
'postskriptumet': ('postskriptum',),
'postsparebank': ('postsparebank',),
'postsparebanken': ('postsparebank',),
'postsparebankene': ('postsparebank',),
'postsparebanker': ('postsparebank',),
'poststed': ('poststed',),
'poststedene': ('poststed',),
'poststeder': ('poststed',),
'poststedet': ('poststed',),
'poststemme': ('poststemme',),
'poststemmen': ('poststemme',),
'poststemmene': ('poststemme',),
'poststemmer': ('poststemme',),
'poststempel': ('poststempel',),
'poststempelet': ('poststempel',),
'poststempla': ('poststempel',),
'poststemplene': ('poststempel',),
'poststempler': ('poststempel',),
'poststemplet': ('poststempel',),
'poststyrer': ('poststyrer',),
'poststyrere': ('poststyrer',),
'poststyreren': ('poststyrer',),
'poststyrerer': ('poststyrer',),
'poststyrerne': ('poststyrer',),
'postulat': ('postulat',),
'postulata': ('postulat',),
'postulatene': ('postulat',),
'postulater': ('postulat',),
'postulatet': ('postulat',),
'postverk': ('postverk',),
'postverka': ('postverk',),
'postverkene': ('postverk',),
'postverker': ('postverk',),
'postverket': ('postverk',),
'postvesen': ('postvesen',),
'postvesena': ('postvesen',),
'postvesenene': ('postvesen',),
'postvesener': ('postvesen',),
'postvesenet': ('postvesen',),
'poståpner': ('poståpner',),
'poståpnere': ('poståpner',),
'poståpneren': ('poståpner',),
'poståpnerer': ('poståpner',),
'poståpnerne': ('poståpner',),
'poståpneri': ('poståpneri',),
'poståpneria': ('poståpneri',),
'poståpneriene': ('poståpneri',),
'poståpnerier': ('poståpneri',),
'poståpneriet': ('poståpneri',),
'posør': ('posør',),
'posøren': ('posør',),
'posørene': ('posør',),
'posører': ('posør',),
'pot': ('pot',),
'poten': ('pot',),
'potene': ('pot',),
'poter': ('pot',),
'potasje': ('potasje',),
'potasjen': ('potasje',),
'potasjene': ('potasje',),
'potasjer': ('potasje',),
'potasjeskei': ('potasjeskei',),
'potasjeskeia': ('potasjeskei',),
'potasjeskeien': ('potasjeskei',),
'potasjeskeiene': ('potasjeskei',),
'potasjeskeier': ('potasjeskei',),
'potasjeskje': ('potasjeskje',),
'potasjeskjea': ('potasjeskje',),
'potasjeskjeen': ('potasjeskje',),
'potasjeskjeene': ('potasjeskje',),
'potasjeskjeer': ('potasjeskje',),
'pote': ('pote',),
'poten': ('pote',),
'potene': ('pote',),
'poter': ('pote',),
'potekvist': ('potekvist',),
'potekvisten': ('potekvist',),
'potekvistene': ('potekvist',),
'potekvister': ('potekvist',),
'potens': ('potens',),
'potensen': ('potens',),
'potensene': ('potens',),
'potenser': ('potens',),
'potenseksponent': ('potenseksponent',),
'potenseksponenten': ('potenseksponent',),
'potenseksponentene': ('potenseksponent',),
'potenseksponenter': ('potenseksponent',),
'potensial': ('potensial',),
'potensiala': ('potensial',),
'potensialene': ('potensial',),
'potensialet': ('potensial',),
'potensiometer': ('potensiometer',),
'potensiometeret': ('potensiometer',),
'potensiometra': ('potensiometer',),
'potensiometre': ('potensiometer',),
'potensiometrene': ('potensiometer',),
'potensiometret': ('potensiometer',),
'potentat': ('potentat',),
'potentaten': ('potentat',),
'potentatene': ('potentat',),
'potentater': ('potentat',),
'potentilla': ('potentilla',),
'potentillaen': ('potentilla',),
'potentillaene': ('potentilla',),
'potentillaer': ('potentilla',),
'potet': ('potet',),
'poteten': ('potet',),
'potetene': ('potet',),
'poteter': ('potet',),
'potetbille': ('potetbille',),
'potetbillen': ('potetbille',),
'potetbillene': ('potetbille',),
'potetbiller': ('potetbille',),
'potetchips': ('potetchips',),
'potetchipsen': ('potetchips',),
'potetchipsene': ('potetchips',),
'potetferie': ('potetferie',),
'potetferien': ('potetferie',),
'potetferiene': ('potetferie',),
'potetferier': ('potetferie',),
'potetgras': ('potetgras',),
'potetgrasa': ('potetgras',),
'potetgrasene': ('potetgras',),
'potetgraset': ('potetgras',),
'potetgress': ('potetgress',),
'potetgressa': ('potetgress',),
'potetgressene': ('potetgress',),
'potetgresset': ('potetgress',),
'potetgull': ('potetgull',),
'potetgulla': ('potetgull',),
'potetgullene': ('potetgull',),
'potetgullet': ('potetgull',),
'potetkaka': ('potetkake',),
'potetkake': ('potetkake',),
'potetkaken': ('potetkake',),
'potetkakene': ('potetkake',),
'potetkaker': ('potetkake',),
'potetland': ('potetland',),
'potetlanda': ('potetland',),
'potetlandene': ('potetland',),
'potetlandet': ('potetland',),
'potetlauv': ('potetlauv',),
'potetlauva': ('potetlauv',),
'potetlauvene': ('potetlauv',),
'potetlauvet': ('potetlauv',),
'potetlumpa': ('potetlumpe',),
'potetlumpe': ('potetlumpe',),
'potetlumpen': ('potetlumpe',),
'potetlumpene': ('potetlumpe',),
'potetlumper': ('potetlumpe',),
'potetløp': ('potetløp',),
'potetløpa': ('potetløp',),
'potetløpene': ('potetløp',),
'potetløpet': ('potetløp',),
'potetløv': ('potetløv',),
'potetløva': ('potetløv',),
'potetløvene': ('potetløv',),
'potetløvet': ('potetløv',),
'potetmel': ('potetmel',),
'potetmela': ('potetmel',),
'potetmelene': ('potetmel',),
'potetmelet': ('potetmel',),
'potetmjøl': ('potetmjøl',),
'potetmjøla': ('potetmjøl',),
'potetmjølene': ('potetmjøl',),
'potetmjølet': ('potetmjøl',),
'potetmos': ('potetmos',),
'potetmosen': ('potetmos',),
'potetmosene': ('potetmos',),
'potetmoser': ('potetmos',),
'potetopptaker': ('potetopptaker',),
'potetopptakere': ('potetopptaker',),
'potetopptakeren': ('potetopptaker',),
'potetopptakerer': ('potetopptaker',),
'potetopptakerne': ('potetopptaker',),
'potetplanta': ('potetplante',),
'potetplante': ('potetplante',),
'potetplanten': ('potetplante',),
'potetplantene': ('potetplante',),
'potetplanter': ('potetplante',),
'potetprest': ('potetprest',),
'potetpresten': ('potetprest',),
'potetprestene': ('potetprest',),
'potetprester': ('potetprest',),
'potetris': ('potetris',),
'potetrisa': ('potetris',),
'potetrisene': ('potetris',),
'potetriset': ('potetris',),
'potetsalat': ('potetsalat',),
'potetsalaten': ('potetsalat',),
'potetsalatene': ('potetsalat',),
'potetsalater': ('potetsalat',),
'potetskrell': ('potetskrell',),
'potetskrella': ('potetskrell',),
'potetskrellene': ('potetskrell',),
'potetskrellet': ('potetskrell',),
'potetskreller': ('potetskreller',),
'potetskrellere': ('potetskreller',),
'potetskrelleren': ('potetskreller',),
'potetskrellerer': ('potetskreller',),
'potetskrellerne': ('potetskreller',),
'potetskurv': ('potetskurv',),
'potetskurven': ('potetskurv',),
'potetskurvene': ('potetskurv',),
'potetskurver': ('potetskurv',),
'potetsprit': ('potetsprit',),
'potetspriten': ('potetsprit',),
'potetspritene': ('potetsprit',),
'potetspriter': ('potetsprit',),
'potetstappa': ('potetstappe',),
'potetstappe': ('potetstappe',),
'potetstappen': ('potetstappe',),
'potetstappene': ('potetstappe',),
'potetstapper': ('potetstappe',),
'potetål': ('potetål',),
'potetålen': ('potetål',),
'potetålene': ('potetål',),
'potetåler': ('potetål',),
'potevoks': ('potevoks',),
'potevoksa': ('potevoks',),
'potevoksen': ('potevoks',),
'potevoksene': ('potevoks',),
'potevokser': ('potevoks',),
'potevokset': ('potevoks',),
'potpurri': ('potpurri',),
'potpurria': ('potpurri',),
'potpurrien': ('potpurri',),
'potpurriene': ('potpurri',),
'potpurrier': ('potpurri',),
'potpurriet': ('potpurri',),
'pott': ('pott',),
'potten': ('pott',),
'pottene': ('pott',),
'potter': ('pott',),
'pottaska': ('pottaske',),
'pottaske': ('pottaske',),
'pottasken': ('pottaske',),
'pottaskene': ('pottaske',),
'pottasker': ('pottaske',),
'potta': ('potte',),
'potte': ('potte',),
'potten': ('potte',),
'pottene': ('potte',),
'potter': ('potte',),
'pottebrenner': ('pottebrenner',),
'pottebrennere': ('pottebrenner',),
'pottebrenneren': ('pottebrenner',),
'pottebrennerer': ('pottebrenner',),
'pottebrennerne': ('pottebrenner',),
'pottemaker': ('pottemaker',),
'pottemakere': ('pottemaker',),
'pottemakeren': ('pottemaker',),
'pottemakerer': ('pottemaker',),
'pottemakerne': ('pottemaker',),
'pottemakeri': ('pottemakeri',),
'pottemakeria': ('pottemakeri',),
'pottemakeriene': ('pottemakeri',),
'pottemakerier': ('pottemakeri',),
'pottemakeriet': ('pottemakeri',),
'pottemakeromn': ('pottemakeromn',),
'pottemakeromnen': ('pottemakeromn',),
'pottemakeromnene': ('pottemakeromn',),
'pottemakeromner': ('pottemakeromn',),
'pottemakerovn': ('pottemakerovn',),
'pottemakerovnen': ('pottemakerovn',),
'pottemakerovnene': ('pottemakerovn',),
'pottemakerovner': ('pottemakerovn',),
'pottemakerskiva': ('pottemakerskive',),
'pottemakerskive': ('pottemakerskive',),
'pottemakerskiven': ('pottemakerskive',),
'pottemakerskivene': ('pottemakerskive',),
'pottemakerskiver': ('pottemakerskive',),
'potteplanta': ('potteplante',),
'potteplante': ('potteplante',),
'potteplanten': ('potteplante',),
'potteplantene': ('potteplante',),
'potteplanter': ('potteplante',),
'potteri': ('potteri',),
'potteria': ('potteri',),
'potteriene': ('potteri',),
'potterier': ('potteri',),
'potteriet': ('potteri',),
'potteskår': ('potteskår',),
'potteskåra': ('potteskår',),
'potteskårene': ('potteskår',),
'potteskåret': ('potteskår',),
'pottøl': ('pottøl',),
'pottøla': ('pottøl',),
'pottølet': ('pottøl',),
'prae ceteris': ('prae ceteris',),
'prae ceterisen': ('prae ceteris',),
'prae ceterisene': ('prae ceteris',),
'prae ceteriser': ('prae ceteris',),
'pragmatiker': ('pragmatiker',),
'pragmatikere': ('pragmatiker',),
'pragmatikeren': ('pragmatiker',),
'pragmatikerer': ('pragmatiker',),
'pragmatikerne': ('pragmatiker',),
'pragmatikk': ('pragmatikk',),
'pragmatikken': ('pragmatikk',),
'pragmatikkene': ('pragmatikk',),
'pragmatikker': ('pragmatikk',),
'pragmatisme': ('pragmatisme',),
'pragmatismen': ('pragmatisme',),
'pragmatismene': ('pragmatisme',),
'pragmatismer': ('pragmatisme',),
'prai': ('prai',),
'praia': ('prai',),
'praiene': ('prai',),
'praiet': ('prai',),
'praiehold': ('praiehold',),
'praieholda': ('praiehold',),
'praieholdene': ('praiehold',),
'praieholdet': ('praiehold',),
'prakk': ('prakk',),
'prakka': ('prakk',),
'prakkene': ('prakk',),
'prakket': ('prakk',),
'prakker': ('prakker',),
'prakkere': ('prakker',),
'prakkeren': ('prakker',),
'prakkerer': ('prakker',),
'prakkerne': ('prakker',),
'praksis': ('praksis',),
'praksisen': ('praksis',),
'praksisene': ('praksis',),
'praksiser': ('praksis',),
'prakt': ('prakt',),
'prakta': ('prakt',),
'prakten': ('prakt',),
'praktene': ('prakt',),
'prakter': ('prakt',),
'praktbind': ('praktbind',),
'praktbinda': ('praktbind',),
'praktbindene': ('praktbind',),
'praktbindet': ('praktbind',),
'prakteksemplar': ('prakteksemplar',),
'prakteksemplara': ('prakteksemplar',),
'prakteksemplarene': ('prakteksemplar',),
'prakteksemplarer': ('prakteksemplar',),
'prakteksemplaret': ('prakteksemplar',),
'prakteldkvede': ('prakteldkvede',),
'prakteldkveden': ('prakteldkvede',),
'prakteldkvedene': ('prakteldkvede',),
'prakteldkveder': ('prakteldkvede',),
'prakteldkvede': ('prakteldkvede',),
'prakteldkveden': ('prakteldkvede',),
'prakteldkvedene': ('prakteldkvede',),
'prakteldkveder': ('prakteldkvede',),
'praktikant': ('praktikant',),
'praktikanten': ('praktikant',),
'praktikantene': ('praktikant',),
'praktikanter': ('praktikant',),
'praktiker': ('praktiker',),
'praktikere': ('praktiker',),
'praktikeren': ('praktiker',),
'praktikerer': ('praktiker',),
'praktikerne': ('praktiker',),
'praktikk': ('praktikk',),
'praktikken': ('praktikk',),
'praktikkene': ('praktikk',),
'praktikker': ('praktikk',),
'praktikum': ('praktikum',),
'praktikuma': ('praktikum',),
'praktikumene': ('praktikum',),
'praktikumet': ('praktikum',),
'praktikus': ('praktikus',),
'praktikusen': ('praktikus',),
'praktikusene': ('praktikus',),
'praktikuser': ('praktikus',),
'praktildkvede': ('praktildkvede',),
'praktildkveden': ('praktildkvede',),
'praktildkvedene': ('praktildkvede',),
'praktildkveder': ('praktildkvede',),
'praktildkvede': ('praktildkvede',),
'praktildkveden': ('praktildkvede',),
'praktildkvedene': ('praktildkvede',),
'praktildkveder': ('praktildkvede',),
'praktmenneska': ('praktmenneske',),
'praktmenneske': ('praktmenneske',),
'praktmenneskene': ('praktmenneske',),
'praktmennesker': ('praktmenneske',),
'praktmennesket': ('praktmenneske',),
'praktstjerna': ('praktstjerne',),
'praktstjerne': ('praktstjerne',),
'praktstjernen': ('praktstjerne',),
'praktstjernene': ('praktstjerne',),
'praktstjerner': ('praktstjerne',),
'praktstykka': ('praktstykke',),
'praktstykke': ('praktstykke',),
'praktstykkene': ('praktstykke',),
'praktstykker': ('praktstykke',),
'praktstykket': ('praktstykke',),
'praktverk': ('praktverk',),
'praktverka': ('praktverk',),
'praktverkene': ('praktverk',),
'praktverker': ('praktverk',),
'praktverket': ('praktverk',),
'praktærfugl': ('praktærfugl',),
'praktærfuglen': ('praktærfugl',),
'praktærfuglene': ('praktærfugl',),
'praktærfugler': ('praktærfugl',),
'pral': ('pral',),
'prala': ('pral',),
'pralene': ('pral',),
'pralet': ('pral',),
'pralbønna': ('pralbønne',),
'pralbønne': ('pralbønne',),
'pralbønnen': ('pralbønne',),
'pralbønnene': ('pralbønne',),
'pralbønner': ('pralbønne',),
'praler': ('praler',),
'pralere': ('praler',),
'praleren': ('praler',),
'pralerer': ('praler',),
'pralerne': ('praler',),
'pralhans': ('pralhans',),
'pralhansen': ('pralhans',),
'pralhansene': ('pralhans',),
'pralhanser': ('pralhans',),
'praline': ('praline',),
'pralinen': ('praline',),
'pralinene': ('praline',),
'praliner': ('praline',),
'praltrilla': ('praltrille',),
'praltrille': ('praltrille',),
'praltrillen': ('praltrille',),
'praltrillene': ('praltrille',),
'praltriller': ('praltrille',),
'pram': ('pram',),
'prammen': ('pram',),
'prammene': ('pram',),
'prammer': ('pram',),
'pranger': ('pranger',),
'prangere': ('pranger',),
'prangeren': ('pranger',),
'prangerer': ('pranger',),
'prangerne': ('pranger',),
'praseodym': ('praseodym',),
'praseodyma': ('praseodym',),
'praseodymene': ('praseodym',),
'praseodymet': ('praseodym',),
'prat': ('prat',),
'prata': ('prat',),
'praten': ('prat',),
'pratene': ('prat',),
'prater': ('prat',),
'pratet': ('prat',),
'pratehjørna': ('pratehjørne',),
'pratehjørne': ('pratehjørne',),
'pratehjørnene': ('pratehjørne',),
'pratehjørner': ('pratehjørne',),
'pratehjørnet': ('pratehjørne',),
'prater': ('prater',),
'pratere': ('prater',),
'prateren': ('prater',),
'praterer': ('prater',),
'praterne': ('prater',),
'pratmaker': ('pratmaker',),
'pratmakere': ('pratmaker',),
'pratmakeren': ('pratmaker',),
'pratmakerer': ('pratmaker',),
'pratmakerne': ('pratmaker',),
'pre': ('pre',),
'prea': ('pre',),
'preene': ('pre',),
'preet': ('pre',),
'preambel': ('preambel',),
'preambelen': ('preambel',),
'preambelet': ('preambel',),
'preambla': ('preambel',),
'preamblene': ('preambel',),
'preambler': ('preambel',),
'preamblet': ('preambel',),
'prebende': ('prebende',),
'prebenden': ('prebende',),
'prebendene': ('prebende',),
'prebender': ('prebende',),
'predasjon': ('predasjon',),
'predasjonen': ('predasjon',),
'predasjonene': ('predasjon',),
'predasjoner': ('predasjon',),
'predator': ('predator',),
'predatoren': ('predator',),
'predatorene': ('predator',),
'predatorer': ('predator',),
'predestinasjon': ('predestinasjon',),
'predestinasjonen': ('predestinasjon',),
'predestinasjonene': ('predestinasjon',),
'predestinasjoner': ('predestinasjon',),
'predikant': ('predikant',),
'predikanten': ('predikant',),
'predikantene': ('predikant',),
'predikanter': ('predikant',),
'predikasjon': ('predikasjon',),
'predikasjonen': ('predikasjon',),
'predikasjonene': ('predikasjon',),
'predikasjoner': ('predikasjon',),
'predikat': ('predikat',),
'predikata': ('predikat',),
'predikatene': ('predikat',),
'predikater': ('predikat',),
'predikatet': ('predikat',),
'predikativ': ('predikativ',),
'predikativa': ('predikativ',),
'predikativene': ('predikativ',),
'predikativer': ('predikativ',),
'predikativet': ('predikativ',),
'predikatsdel': ('predikatsdel',),
'predikatsdelen': ('predikatsdel',),
'predikatsdelene': ('predikatsdel',),
'predikatsdeler': ('predikatsdel',),
'predikatsord': ('predikatsord',),
'predikatsorda': ('predikatsord',),
'predikatsordene': ('predikatsord',),
'predikatsordet': ('predikatsord',),
'prediken': ('prediken',),
'predikenen': ('prediken',),
'predikenene': ('prediken',),
'predikener': ('prediken',),
'prediksjon': ('prediksjon',),
'prediksjonen': ('prediksjon',),
'prediksjonene': ('prediksjon',),
'prediksjoner': ('prediksjon',),
'predisposisjon': ('predisposisjon',),
'predisposisjonen': ('predisposisjon',),
'predisposisjonene': ('predisposisjon',),
'predisposisjoner': ('predisposisjon',),
'preeksistens': ('preeksistens',),
'preeksistensen': ('preeksistens',),
'preeksistensene': ('preeksistens',),
'preeksistenser': ('preeksistens',),
'prefabrikasjon': ('prefabrikasjon',),
'prefabrikasjonen': ('prefabrikasjon',),
'prefabrikasjonene': ('prefabrikasjon',),
'prefabrikasjoner': ('prefabrikasjon',),
'prefekt': ('prefekt',),
'prefekten': ('prefekt',),
'prefektene': ('prefekt',),
'prefekter': ('prefekt',),
'prefektembeta': ('prefektembete',),
'prefektembete': ('prefektembete',),
'prefektembetene': ('prefektembete',),
'prefektembeter': ('prefektembete',),
'prefektembetet': ('prefektembete',),
'prefektur': ('prefektur',),
'prefektura': ('prefektur',),
'prefekturene': ('prefektur',),
'prefekturer': ('prefektur',),
'prefekturet': ('prefektur',),
'preferanse': ('preferanse',),
'preferansen': ('preferanse',),
'preferansene': ('preferanse',),
'preferanser': ('preferanse',),
'preferanseaksje': ('preferanseaksje',),
'preferanseaksjen': ('preferanseaksje',),
'preferanseaksjene': ('preferanseaksje',),
'preferanseaksjer': ('preferanseaksje',),
'preferansetoll': ('preferansetoll',),
'preferansetollen': ('preferansetoll',),
'preferansetollene': ('preferansetoll',),
'preferansetoller': ('preferansetoll',),
'prefiks': ('prefiks',),
'prefiksa': ('prefiks',),
'prefiksene': ('prefiks',),
'prefikser': ('prefiks',),
'prefikset': ('prefiks',),
'prefiksnummer': ('prefiksnummer',),
'prefiksnummeret': ('prefiksnummer',),
'prefiksnumra': ('prefiksnummer',),
'prefiksnumre': ('prefiksnummer',),
'prefiksnumrene': ('prefiksnummer',),
'preg': ('preg',),
'prega': ('preg',),
'pregene': ('preg',),
'preget': ('preg',),
'pregehammar': ('pregehammar',),
'pregehammaren': ('pregehammar',),
'pregehamrene': ('pregehammar',),
'pregehamrer': ('pregehammar',),
'pregehammer': ('pregehammer',),
'pregehammere': ('pregehammer',),
'pregehammeren': ('pregehammer',),
'pregehammerer': ('pregehammer',),
'pregehammerne': ('pregehammer',),
'pregehamrene': ('pregehammer',),
'pregehamrer': ('pregehammer',),
'pregnans': ('pregnans',),
'pregnansen': ('pregnans',),
'pregnansene': ('pregnans',),
'pregnanser': ('pregnans',),
'pregning': ('pregning',),
'pregninga': ('pregning',),
'pregningen': ('pregning',),
'pregningene': ('pregning',),
'pregninger': ('pregning',),
'prehistoria': ('prehistorie',),
'prehistorie': ('prehistorie',),
'prehistorien': ('prehistorie',),
'prehistoriene': ('prehistorie',),
'prehistorier': ('prehistorie',),
'prejudikat': ('prejudikat',),
'prejudikata': ('prejudikat',),
'prejudikatene': ('prejudikat',),
'prejudikater': ('prejudikat',),
'prejudikatet': ('prejudikat',),
'prek': ('prek',),
'preka': ('prek',),
'prekene': ('prek',),
'preket': ('prek',),
'prekapp': ('prekapp',),
'prekappen': ('prekapp',),
'prekappene': ('prekapp',),
'prekapper': ('prekapp',),
'preka': ('preke',),
'preke': ('preke',),
'preken': ('preke',),
'prekene': ('preke',),
'preker': ('preke',),
'preken': ('preken',),
'prekenen': ('preken',),
'prekenene': ('preken',),
'prekener': ('preken',),
'prekensamling': ('prekensamling',),
'prekensamlinga': ('prekensamling',),
'prekensamlingen': ('prekensamling',),
'prekensamlingene': ('prekensamling',),
'prekensamlinger': ('prekensamling',),
'prekensøndag': ('prekensøndag',),
'prekensøndagen': ('prekensøndag',),
'prekensøndagene': ('prekensøndag',),
'prekensøndager': ('prekensøndag',),
'prekentekst': ('prekentekst',),
'prekenteksta': ('prekentekst',),
'prekenteksten': ('prekentekst',),
'prekentekstene': ('prekentekst',),
'prekentekster': ('prekentekst',),
'prekentone': ('prekentone',),
'prekentonen': ('prekentone',),
'prekentonene': ('prekentone',),
'prekentoner': ('prekentone',),
'prekestol': ('prekestol',),
'prekestolen': ('prekestol',),
'prekestolene': ('prekestol',),
'prekestoler': ('prekestol',),
'prekutt': ('prekutt',),
'prekutta': ('prekutt',),
'prekuttene': ('prekutt',),
'prekuttet': ('prekutt',),
'prekærhandel': ('prekærhandel',),
'prekærhandelen': ('prekærhandel',),
'prekærhandlene': ('prekærhandel',),
'prekærhandler': ('prekærhandel',),
'prelat': ('prelat',),
'prelaten': ('prelat',),
'prelatene': ('prelat',),
'prelater': ('prelat',),
'preludia': ('preludium',),
'preludiene': ('preludium',),
'preludier': ('preludium',),
'preludiet': ('preludium',),
'preludium': ('preludium',),
'premie': ('premie',),
'premien': ('premie',),
'premiene': ('premie',),
'premier': ('premie',),
'premiebarn': ('premiebarn',),
'premiebarna': ('premiebarn',),
'premiebarnene': ('premiebarn',),
'premiebarnet': ('premiebarn',),
'premiedyr': ('premiedyr',),
'premiedyra': ('premiedyr',),
'premiedyrene': ('premiedyr',),
'premiedyret': ('premiedyr',),
'premieelev': ('premieelev',),
'premieeleven': ('premieelev',),
'premieelevene': ('premieelev',),
'premieelever': ('premieelev',),
'premiefot': ('premiefot',),
'premiefoten': ('premiefot',),
'premieføttene': ('premiefot',),
'premieføtter': ('premiefot',),
'premieidiot': ('premieidiot',),
'premieidioten': ('premieidiot',),
'premieidiotene': ('premieidiot',),
'premieidioter': ('premieidiot',),
'premielån': ('premielån',),
'premielåna': ('premielån',),
'premielånene': ('premielån',),
'premielånet': ('premielån',),
'premielønn': ('premielønn',),
'premielønna': ('premielønn',),
'premielønnen': ('premielønn',),
'premielønnene': ('premielønn',),
'premielønner': ('premielønn',),
'premieobligasjon': ('premieobligasjon',),
'premieobligasjonen': ('premieobligasjon',),
'premieobligasjonene': ('premieobligasjon',),
'premieobligasjoner': ('premieobligasjon',),
'premieobligasjonslån': ('premieobligasjonslån',),
'premieobligasjonslåna': ('premieobligasjonslån',),
'premieobligasjonslånene': ('premieobligasjonslån',),
'premieobligasjonslånet': ('premieobligasjonslån',),
'premiere': ('premiere',),
'premieren': ('premiere',),
'premierene': ('premiere',),
'premierer': ('premiere',),
'premierepublikum': ('premierepublikum',),
'premierepublikuma': ('premierepublikum',),
'premierepublikumene': ('premierepublikum',),
'premierepublikumet': ('premierepublikum',),
'premierepublikumma': ('premierepublikum',),
'premierepublikummene': ('premierepublikum',),
'premierepublikummet': ('premierepublikum',),
'premierestemning': ('premierestemning',),
'premierestemninga': ('premierestemning',),
'premierestemningen': ('premierestemning',),
'premierestemningene': ('premierestemning',),
'premierestemninger': ('premierestemning',),
'premierløytnant': ('premierløytnant',),
'premierløytnanten': ('premierløytnant',),
'premierløytnantene': ('premierløytnant',),
'premierløytnanter': ('premierløytnant',),
'premierminister': ('premierminister',),
'premierministere': ('premierminister',),
'premierministeren': ('premierminister',),
'premierministerer': ('premierminister',),
'premierministerne': ('premierminister',),
'premierministre': ('premierminister',),
'premierministrene': ('premierminister',),
'premierministrer': ('premierminister',),
'premiss': ('premiss',),
'premissa': ('premiss',),
'premissen': ('premiss',),
'premissene': ('premiss',),
'premisser': ('premiss',),
'premisset': ('premiss',),
'premisse': ('premisse',),
'premissen': ('premisse',),
'premissene': ('premisse',),
'premisser': ('premisse',),
'premolar': ('premolar',),
'premolaren': ('premolar',),
'premolarene': ('premolar',),
'premolarer': ('premolar',),
'premturavdeling': ('premturavdeling',),
'premturavdelinga': ('premturavdeling',),
'premturavdelingen': ('premturavdeling',),
'premturavdelingene': ('premturavdeling',),
'premturavdelinger': ('premturavdeling',),
'pren': ('pren',),
'prenen': ('pren',),
'prenene': ('pren',),
'prener': ('pren',),
'prent': ('prent',),
'prenta': ('prent',),
'prentene': ('prent',),
'prentet': ('prent',),
'prentesvarten': ('prentesvarten',),
'prenumerant': ('prenumerant',),
'prenumeranten': ('prenumerant',),
'prenumerantene': ('prenumerant',),
'prenumeranter': ('prenumerant',),
'prenumerasjon': ('prenumerasjon',),
'prenumerasjonen': ('prenumerasjon',),
'prenumerasjonene': ('prenumerasjon',),
'prenumerasjoner': ('prenumerasjon',),
'preparant': ('preparant',),
'preparanten': ('preparant',),
'preparantene': ('preparant',),
'preparanter': ('preparant',),
'preparat': ('preparat',),
'preparata': ('preparat',),
'preparatene': ('preparat',),
'preparater': ('preparat',),
'preparatet': ('preparat',),
'prepareringsmaskin': ('prepareringsmaskin',),
'prepareringsmaskina': ('prepareringsmaskin',),
'prepareringsmaskinen': ('prepareringsmaskin',),
'prepareringsmaskinene': ('prepareringsmaskin',),
'prepareringsmaskiner': ('prepareringsmaskin',),
'preposisjon': ('preposisjon',),
'preposisjonen': ('preposisjon',),
'preposisjonene': ('preposisjon',),
'preposisjoner': ('preposisjon',),
'preposisjonsuttrykk': ('preposisjonsuttrykk',),
'preposisjonsuttrykka': ('preposisjonsuttrykk',),
'preposisjonsuttrykkene': ('preposisjonsuttrykk',),
'preposisjonsuttrykket': ('preposisjonsuttrykk',),
'preppemaskin': ('preppemaskin',),
'preppemaskina': ('preppemaskin',),
'preppemaskinen': ('preppemaskin',),
'preppemaskinene': ('preppemaskin',),
'preppemaskiner': ('preppemaskin',),
'prerogativ': ('prerogativ',),
'prerogativa': ('prerogativ',),
'prerogativene': ('prerogativ',),
'prerogativer': ('prerogativ',),
'prerogativet': ('prerogativ',),
'presang': ('presang',),
'presangen': ('presang',),
'presangene': ('presang',),
'presanger': ('presang',),
'presangkort': ('presangkort',),
'presangkorta': ('presangkort',),
'presangkortene': ('presangkort',),
'presangkortet': ('presangkort',),
'presbyter': ('presbyter',),
'presbytere': ('presbyter',),
'presbyteren': ('presbyter',),
'presbyterer': ('presbyter',),
'presbyterne': ('presbyter',),
'presbyterianer': ('presbyterianer',),
'presbyterianere': ('presbyterianer',),
'presbyterianeren': ('presbyterianer',),
'presbyterianerer': ('presbyterianer',),
'presbyterianerne': ('presbyterianer',),
'presbyteria': ('presbyterium',),
'presbyteriene': ('presbyterium',),
'presbyterier': ('presbyterium',),
'presbyteriet': ('presbyterium',),
'presbyterium': ('presbyterium',),
'presedens': ('presedens',),
'presedensen': ('presedens',),
'presedensene': ('presedens',),
'presedenser': ('presedens',),
'presenning': ('presenning',),
'presenningen': ('presenning',),
'presenningene': ('presenning',),
'presenninger': ('presenning',),
'presens': ('presens',),
'presensform': ('presensform',),
'presensforma': ('presensform',),
'presensformen': ('presensform',),
'presensformene': ('presensform',),
'presensformer': ('presensform',),
'presentasjon': ('presentasjon',),
'presentasjonen': ('presentasjon',),
'presentasjonene': ('presentasjon',),
'presentasjoner': ('presentasjon',),
'presentering': ('presentering',),
'presenteringa': ('presentering',),
'presenteringen': ('presentering',),
'presenteringene': ('presentering',),
'presenteringer': ('presentering',),
'preseptor': ('preseptor',),
'preseptoren': ('preseptor',),
'preseptorene': ('preseptor',),
'preseptorer': ('preseptor',),
'preservativ': ('preservativ',),
'preservativa': ('preservativ',),
'preservativene': ('preservativ',),
'preservativer': ('preservativ',),
'preservativet': ('preservativ',),
'preserve': ('preserve',),
'preserven': ('preserve',),
'preservene': ('preserve',),
'preserver': ('preserve',),
'preses': ('preses',),
'presesen': ('preses',),
'presesene': ('preses',),
'preseser': ('preses',),
'preseterist': ('preseterist',),
'preseteristen': ('preseterist',),
'preseteristene': ('preseterist',),
'preseterister': ('preseterist',),
'president': ('president',),
'presidenten': ('president',),
'presidentene': ('president',),
'presidenter': ('president',),
'presidentperiode': ('presidentperiode',),
'presidentperioden': ('presidentperiode',),
'presidentperiodene': ('presidentperiode',),
'presidentperioder': ('presidentperiode',),
'presidentskap': ('presidentskap',),
'presidentskapa': ('presidentskap',),
'presidentskapene': ('presidentskap',),
'presidentskaper': ('presidentskap',),
'presidentskapet': ('presidentskap',),
'presidia': ('presidium',),
'presidiene': ('presidium',),
'presidier': ('presidium',),
'presidiet': ('presidium',),
'presidium': ('presidium',),
'presisering': ('presisering',),
'presiseringa': ('presisering',),
'presiseringen': ('presisering',),
'presiseringene': ('presisering',),
'presiseringer': ('presisering',),
'presisjon': ('presisjon',),
'presisjonen': ('presisjon',),
'presisjonene': ('presisjon',),
'presisjoner': ('presisjon',),
'presisjonsarbeid': ('presisjonsarbeid',),
'presisjonsarbeida': ('presisjonsarbeid',),
'presisjonsarbeidene': ('presisjonsarbeid',),
'presisjonsarbeider': ('presisjonsarbeid',),
'presisjonsarbeidet': ('presisjonsarbeid',),
'presisjonsinstrument': ('presisjonsinstrument',),
'presisjonsinstrumenta': ('presisjonsinstrument',),
'presisjonsinstrumentene': ('presisjonsinstrument',),
'presisjonsinstrumenter': ('presisjonsinstrument',),
'presisjonsinstrumentet': ('presisjonsinstrument',),
'presisjonsskyting': ('presisjonsskyting',),
'presisjonsskytinga': ('presisjonsskyting',),
'presisjonsskytingen': ('presisjonsskyting',),
'presisjonsskytingene': ('presisjonsskyting',),
'presisjonsskytinger': ('presisjonsskyting',),
'presisjonsur': ('presisjonsur',),
'presisjonsura': ('presisjonsur',),
'presisjonsurene': ('presisjonsur',),
'presisjonsuret': ('presisjonsur',),
'presisjonsverktøy': ('presisjonsverktøy',),
'presisjonsverktøya': ('presisjonsverktøy',),
'presisjonsverktøyene': ('presisjonsverktøy',),
'presisjonsverktøyer': ('presisjonsverktøy',),
'presisjonsverktøyet': ('presisjonsverktøy',),
'presisjonsvåpen': ('presisjonsvåpen',),
'presisjonsvåpenet': ('presisjonsvåpen',),
'presisjonsvåpna': ('presisjonsvåpen',),
'presisjonsvåpnene': ('presisjonsvåpen',),
'preskripsjon': ('preskripsjon',),
'preskripsjonen': ('preskripsjon',),
'preskripsjonene': ('preskripsjon',),
'preskripsjoner': ('preskripsjon',),
'press': ('press',),
'pressen': ('press',),
'pressene': ('press',),
'presser': ('press',),
'press': ('press',),
'pressa': ('press',),
'pressene': ('press',),
'presset': ('press',),
'pressa': ('presse',),
'presse': ('presse',),
'pressen': ('presse',),
'pressene': ('presse',),
'presser': ('presse',),
'pressebyrå': ('pressebyrå',),
'pressebyråa': ('pressebyrå',),
'pressebyråene': ('pressebyrå',),
'pressebyråer': ('pressebyrå',),
'pressebyrået': ('pressebyrå',),
'pressedekning': ('pressedekning',),
'pressedekninga': ('pressedekning',),
'pressedekningen': ('pressedekning',),
'pressedekningene': ('pressedekning',),
'pressedekninger': ('pressedekning',),
'presseetikk': ('presseetikk',),
'presseetikken': ('presseetikk',),
'presseetikkene': ('presseetikk',),
'presseetikker': ('presseetikk',),
'pressefolk': ('pressefolk',),
'pressefolka': ('pressefolk',),
'pressefolkene': ('pressefolk',),
'pressefolket': ('pressefolk',),
'pressefotograf': ('pressefotograf',),
'pressefotografen': ('pressefotograf',),
'pressefotografene': ('pressefotograf',),
'pressefotografer': ('pressefotograf',),
'pressefrihet': ('pressefrihet',),
'pressefriheta': ('pressefrihet',),
'pressefriheten': ('pressefrihet',),
'pressefrihetene': ('pressefrihet',),
'pressefriheter': ('pressefrihet',),
'pressejern': ('pressejern',),
'pressejerna': ('pressejern',),
'pressejernene': ('pressejern',),
'pressejernet': ('pressejern',),
'pressekleda': ('presseklede',),
'presseklede': ('presseklede',),
'pressekledene': ('presseklede',),
'pressekleder': ('presseklede',),
'pressekledet': ('presseklede',),
'pressekommentar': ('pressekommentar',),
'pressekommentaren': ('pressekommentar',),
'pressekommentarene': ('pressekommentar',),
'pressekommentarer': ('pressekommentar',),
'pressekonferanse': ('pressekonferanse',),
'pressekonferansen': ('pressekonferanse',),
'pressekonferansene': ('pressekonferanse',),
'pressekonferanser': ('pressekonferanse',),
'pressekort': ('pressekort',),
'pressekorta': ('pressekort',),
'pressekortene': ('pressekort',),
'pressekortet': ('pressekort',),
'pressemelding': ('pressemelding',),
'pressemeldinga': ('pressemelding',),
'pressemeldingen': ('pressemelding',),
'pressemeldingene': ('pressemelding',),
'pressemeldinger': ('pressemelding',),
'presser': ('presser',),
'pressere': ('presser',),
'presseren': ('presser',),
'presserer': ('presser',),
'presserne': ('presser',),
'presseri': ('presseri',),
'presseria': ('presseri',),
'presseriene': ('presseri',),
'presserier': ('presseri',),
'presseriet': ('presseri',),
'pressesekretær': ('pressesekretær',),
'pressesekretæren': ('pressesekretær',),
'pressesekretærene': ('pressesekretær',),
'pressesekretærer': ('pressesekretær',),
'pressetvang': ('pressetvang',),
'pressetvangen': ('pressetvang',),
'pressetvangene': ('pressetvang',),
'pressetvanger': ('pressetvang',),
'pressgass': ('pressgass',),
'pressgassen': ('pressgass',),
'pressgassene': ('pressgass',),
'pressgasser': ('pressgass',),
'pressgjær': ('pressgjær',),
'pressgjæren': ('pressgjær',),
'pressgjærene': ('pressgjær',),
'pressgjærer': ('pressgjær',),
'pressgruppa': ('pressgruppe',),
'pressgruppe': ('pressgruppe',),
'pressgruppen': ('pressgruppe',),
'pressgruppene': ('pressgruppe',),
'pressgrupper': ('pressgruppe',),
'presskaka': ('presskake',),
'presskake': ('presskake',),
'presskaken': ('presskake',),
'presskakene': ('presskake',),
'presskaker': ('presskake',),
'presskommune': ('presskommune',),
'presskommunen': ('presskommune',),
'presskommunene': ('presskommune',),
'presskommuner': ('presskommune',),
'pressluft': ('pressluft',),
'presslufta': ('pressluft',),
'pressluften': ('pressluft',),
'pressluftene': ('pressluft',),
'presslufter': ('pressluft',),
'pressluftbor': ('pressluftbor',),
'pressluftbora': ('pressluftbor',),
'pressluftboren': ('pressluftbor',),
'pressluftborene': ('pressluftbor',),
'pressluftboret': ('pressluftbor',),
'pressmiddel': ('pressmiddel',),
'pressmiddelet': ('pressmiddel',),
'pressmidla': ('pressmiddel',),
'pressmidlene': ('pressmiddel',),
'pressmidler': ('pressmiddel',),
'pressmidlet': ('pressmiddel',),
'pressområda': ('pressområde',),
'pressområde': ('pressområde',),
'pressområdene': ('pressområde',),
'pressområder': ('pressområde',),
'pressområdet': ('pressområde',),
'pressproblem': ('pressproblem',),
'pressproblema': ('pressproblem',),
'pressproblemene': ('pressproblem',),
'pressproblemer': ('pressproblem',),
'pressproblemet': ('pressproblem',),
'prest': ('prest',),
'presten': ('prest',),
'prestene': ('prest',),
'prester': ('prest',),
'prestasjon': ('prestasjon',),
'prestasjonen': ('prestasjon',),
'prestasjonene': ('prestasjon',),
'prestasjoner': ('prestasjon',),
'prestasjonsevna': ('prestasjonsevne',),
'prestasjonsevne': ('prestasjonsevne',),
'prestasjonsevnen': ('prestasjonsevne',),
'prestasjonsevnene': ('prestasjonsevne',),
'prestasjonsevner': ('prestasjonsevne',),
'prestasjonskrav': ('prestasjonskrav',),
'prestasjonskrava': ('prestasjonskrav',),
'prestasjonskravene': ('prestasjonskrav',),
'prestasjonskravet': ('prestasjonskrav',),
'prestasjonslønn': ('prestasjonslønn',),
'prestasjonslønna': ('prestasjonslønn',),
'prestasjonslønnen': ('prestasjonslønn',),
'prestasjonslønnene': ('prestasjonslønn',),
'prestasjonslønner': ('prestasjonslønn',),
'prestebol': ('prestebol',),
'prestebola': ('prestebol',),
'prestebolene': ('prestebol',),
'prestebolet': ('prestebol',),
'prestebord': ('prestebord',),
'presteborda': ('prestebord',),
'prestebordene': ('prestebord',),
'presteborder': ('prestebord',),
'prestebordet': ('prestebord',),
'prestegjeld': ('prestegjeld',),
'prestegjelda': ('prestegjeld',),
'prestegjeldene': ('prestegjeld',),
'prestegjeldet': ('prestegjeld',),
'prestekall': ('prestekall',),
'prestekalla': ('prestekall',),
'prestekallene': ('prestekall',),
'prestekallet': ('prestekall',),
'prestekjole': ('prestekjole',),
'prestekjolen': ('prestekjole',),
'prestekjolene': ('prestekjole',),
'prestekjoler': ('prestekjole',),
'prestekrage': ('prestekrage',),
'prestekragen': ('prestekrage',),
'prestekragene': ('prestekrage',),
'prestekrager': ('prestekrage',),
'prestekrave': ('prestekrave',),
'prestekraven': ('prestekrave',),
'prestekravene': ('prestekrave',),
'prestekraver': ('prestekrave',),
'prestesjuka': ('prestesjuke',),
'prestesjuke': ('prestesjuke',),
'prestesjuken': ('prestesjuke',),
'prestesjukene': ('prestesjuke',),
'prestesjuker': ('prestesjuke',),
'presteskap': ('presteskap',),
'presteskapa': ('presteskap',),
'presteskapene': ('presteskap',),
'presteskaper': ('presteskap',),
'presteskapet': ('presteskap',),
'presteskrud': ('presteskrud',),
'presteskruda': ('presteskrud',),
'presteskrudene': ('presteskrud',),
'presteskrudet': ('presteskrud',),
'prestestand': ('prestestand',),
'prestestanden': ('prestestand',),
'prestestandene': ('prestestand',),
'prestestander': ('prestestand',),
'prestesyka': ('prestesyke',),
'prestesyke': ('prestesyke',),
'prestesyken': ('prestesyke',),
'prestesykene': ('prestesyke',),
'prestesyker': ('prestesyke',),
'prestinna': ('prestinne',),
'prestinne': ('prestinne',),
'prestinnen': ('prestinne',),
'prestinnene': ('prestinne',),
'prestinner': ('prestinne',),
'prestisje': ('prestisje',),
'prestisjen': ('prestisje',),
'prestisjene': ('prestisje',),
'prestisjer': ('prestisje',),
'prestisjehensyn': ('prestisjehensyn',),
'prestisjehensyna': ('prestisjehensyn',),
'prestisjehensynene': ('prestisjehensyn',),
'prestisjehensynet': ('prestisjehensyn',),
'prestisjesak': ('prestisjesak',),
'prestisjesaka': ('prestisjesak',),
'prestisjesaken': ('prestisjesak',),
'prestisjesakene': ('prestisjesak',),
'prestisjesaker': ('prestisjesak',),
'prestisjetap': ('prestisjetap',),
'prestisjetapa': ('prestisjetap',),
'prestisjetapene': ('prestisjetap',),
'prestisjetapet': ('prestisjetap',),
'prestissimo': ('prestissimo',),
'prestissimoa': ('prestissimo',),
'prestissimoene': ('prestissimo',),
'prestissimoer': ('prestissimo',),
'prestissimoet': ('prestissimo',),
'presto': ('presto',),
'prestoen': ('presto',),
'prestoene': ('presto',),
'prestoer': ('presto',),
'presto': ('presto',),
'prestoa': ('presto',),
'prestoene': ('presto',),
'prestoer': ('presto',),
'prestoet': ('presto',),
'presumpsjon': ('presumpsjon',),
'presumpsjonen': ('presumpsjon',),
'presumpsjonene': ('presumpsjon',),
'presumpsjoner': ('presumpsjon',),
'presumsjon': ('presumsjon',),
'presumsjonen': ('presumsjon',),
'presumsjonene': ('presumsjon',),
'presumsjoner': ('presumsjon',),
'presupposisjon': ('presupposisjon',),
'presupposisjonen': ('presupposisjon',),
'presupposisjonene': ('presupposisjon',),
'presupposisjoner': ('presupposisjon',),
'pretendent': ('pretendent',),
'pretendenten': ('pretendent',),
'pretendentene': ('pretendent',),
'pretendenter': ('pretendent',),
'pretensjon': ('pretensjon',),
'pretensjonen': ('pretensjon',),
'pretensjonene': ('pretensjon',),
'pretensjoner': ('pretensjon',),
'preterita': ('preteritum',),
'preteritaene': ('preteritum',),
'preteritum': ('preteritum',),
'preterituma': ('preteritum',),
'preteritumene': ('preteritum',),
'preteritumer': ('preteritum',),
'preteritumet': ('preteritum',),
'preteritumsform': ('preteritumsform',),
'preteritumsforma': ('preteritumsform',),
'preteritumsformen': ('preteritumsform',),
'preteritumsformene': ('preteritumsform',),
'preteritumsformer': ('preteritumsform',),
'pretiosa': ('pretiosa',),
'pretiosene': ('pretiosa',),
'pretor': ('pretor',),
'pretoren': ('pretor',),
'pretorene': ('pretor',),
'pretorer': ('pretor',),
'pretorianer': ('pretorianer',),
'pretorianere': ('pretorianer',),
'pretorianeren': ('pretorianer',),
'pretorianerer': ('pretorianer',),
'pretorianerne': ('pretorianer',),
'pretta': ('prette',),
'prette': ('prette',),
'pretten': ('prette',),
'prettene': ('prette',),
'pretter': ('prette',),
'prevensjon': ('prevensjon',),
'prevensjonen': ('prevensjon',),
'prevensjonene': ('prevensjon',),
'prevensjoner': ('prevensjon',),
'prevensjonsmetode': ('prevensjonsmetode',),
'prevensjonsmetoden': ('prevensjonsmetode',),
'prevensjonsmetodene': ('prevensjonsmetode',),
'prevensjonsmetoder': ('prevensjonsmetode',),
'prevensjonsmiddel': ('prevensjonsmiddel',),
'prevensjonsmiddelet': ('prevensjonsmiddel',),
'prevensjonsmidla': ('prevensjonsmiddel',),
'prevensjonsmidlene': ('prevensjonsmiddel',),
'prevensjonsmidler': ('prevensjonsmiddel',),
'prevensjonsmidlet': ('prevensjonsmiddel',),
'prevensjonspilla': ('prevensjonspille',),
'prevensjonspille': ('prevensjonspille',),
'prevensjonspillen': ('prevensjonspille',),
'prevensjonspillene': ('prevensjonspille',),
'prevensjonspiller': ('prevensjonspille',),
'preventiv': ('preventiv',),
'preventiva': ('preventiv',),
'preventivene': ('preventiv',),
'preventiver': ('preventiv',),
'preventivet': ('preventiv',),
'priar': ('priar',),
'priaren': ('priar',),
'priarene': ('priar',),
'priarer': ('priar',),
'prikk': ('prikk',),
'prikken': ('prikk',),
'prikkene': ('prikk',),
'prikker': ('prikk',),
'prikk': ('prikk',),
'prikka': ('prikk',),
'prikkene': ('prikk',),
'prikket': ('prikk',),
'prikkbelastning': ('prikkbelastning',),
'prikkbelastninga': ('prikkbelastning',),
'prikkbelastningen': ('prikkbelastning',),
'prikkbelastningene': ('prikkbelastning',),
'prikkbelastninger': ('prikkbelastning',),
'prikke': ('prikke',),
'prikkfisk': ('prikkfisk',),
'prikkfisken': ('prikkfisk',),
'prikkfiskene': ('prikkfisk',),
'prikkfisker': ('prikkfisk',),
'priklepinne': ('priklepinne',),
'priklepinnen': ('priklepinne',),
'priklepinnene': ('priklepinne',),
'priklepinner': ('priklepinne',),
'prillarhorn': ('prillarhorn',),
'prillarhorna': ('prillarhorn',),
'prillarhornene': ('prillarhorn',),
'prillarhornet': ('prillarhorn',),
'prim': ('prim',),
'prima': ('prim',),
'primene': ('prim',),
'primet': ('prim',),
'primaballerina': ('primaballerina',),
'primaballerinaen': ('primaballerina',),
'primaballerinaene': ('primaballerina',),
'primaballerinaer': ('primaballerina',),
'primadonna': ('primadonna',),
'primadonnaen': ('primadonna',),
'primadonnaene': ('primadonna',),
'primadonnaer': ('primadonna',),
'primagris': ('primagris',),
'primagrisen': ('primagris',),
'primagrisene': ('primagris',),
'primagriser': ('primagris',),
'primas': ('primas',),
'primasen': ('primas',),
'primasene': ('primas',),
'primaser': ('primas',),
'primat': ('primat',),
'primaten': ('primat',),
'primatene': ('primat',),
'primater': ('primat',),
'primat': ('primat',),
'primata': ('primat',),
'primatene': ('primat',),
'primatet': ('primat',),
'primaveksel': ('primaveksel',),
'primavekselen': ('primaveksel',),
'primavekslene': ('primaveksel',),
'primaveksler': ('primaveksel',),
'primavistasang': ('primavistasang',),
'primavistasangen': ('primavistasang',),
'primavistasangene': ('primavistasang',),
'primavistasanger': ('primavistasang',),
'primer': ('primer',),
'primere': ('primer',),
'primeren': ('primer',),
'primerer': ('primer',),
'primerne': ('primer',),
'primfaktor': ('primfaktor',),
'primfaktoren': ('primfaktor',),
'primfaktorene': ('primfaktor',),
'primfaktorer': ('primfaktor',),
'primitivisme': ('primitivisme',),
'primitivismen': ('primitivisme',),
'primitivismene': ('primitivisme',),
'primitivismer': ('primitivisme',),
'primitivist': ('primitivist',),
'primitivisten': ('primitivist',),
'primitivistene': ('primitivist',),
'primitivister': ('primitivist',),
'primitivitet': ('primitivitet',),
'primitiviteten': ('primitivitet',),
'primitivitetene': ('primitivitet',),
'primitiviteter': ('primitivitet',),
'primo': ('primo',),
'primoen': ('primo',),
'primoene': ('primo',),
'primoer': ('primo',),
'primstav': ('primstav',),
'primstaven': ('primstav',),
'primstavene': ('primstav',),
'primstaver': ('primstav',),
'primtal': ('primtal',),
'primtala': ('primtal',),
'primtalene': ('primtal',),
'primtalet': ('primtal',),
'primtall': ('primtall',),
'primtalla': ('primtall',),
'primtallene': ('primtall',),
'primtallet': ('primtall',),
'primtalltvilling': ('primtalltvilling',),
'primtalltvillingen': ('primtalltvilling',),
'primtalltvillingene': ('primtalltvilling',),
'primtalltvillinger': ('primtalltvilling',),
'primtaltvilling': ('primtaltvilling',),
'primtaltvillingen': ('primtaltvilling',),
'primtaltvillingene': ('primtaltvilling',),
'primtaltvillinger': ('primtaltvilling',),
'primula': ('primula',),
'primulaen': ('primula',),
'primulaene': ('primula',),
'primulaer': ('primula',),
'primus': ('primus',),
'primusen': ('primus',),
'primusene': ('primus',),
'primuser': ('primus',),
'primus inter pares': ('primus inter pares',),
'primus motor': ('primus motor',),
'primærfarge': ('primærfarge',),
'primærfargen': ('primærfarge',),
'primærfargene': ('primærfarge',),
'primærfarger': ('primærfarge',),
'primærhelsetjeneste': ('primærhelsetjeneste',),
'primærhelsetjenesten': ('primærhelsetjeneste',),
'primærhelsetjenestene': ('primærhelsetjeneste',),
'primærhelsetjenester': ('primærhelsetjeneste',),
'primærkilde': ('primærkilde',),
'primærkilden': ('primærkilde',),
'primærkildene': ('primærkilde',),
'primærkilder': ('primærkilde',),
'primærkjelda': ('primærkjelde',),
'primærkjelde': ('primærkjelde',),
'primærkjelden': ('primærkjelde',),
'primærkjeldene': ('primærkjelde',),
'primærkjelder': ('primærkjelde',),
'primærkommune': ('primærkommune',),
'primærkommunen': ('primærkommune',),
'primærkommunene': ('primærkommune',),
'primærkommuner': ('primærkommune',),
'primærmetall': ('primærmetall',),
'primærmetalla': ('primærmetall',),
'primærmetallene': ('primærmetall',),
'primærmetaller': ('primærmetall',),
'primærmetallet': ('primærmetall',),
'primærnæring': ('primærnæring',),
'primærnæringa': ('primærnæring',),
'primærnæringen': ('primærnæring',),
'primærnæringene': ('primærnæring',),
'primærnæringer': ('primærnæring',),
'primærproduksjon': ('primærproduksjon',),
'primærproduksjonen': ('primærproduksjon',),
'primærproduksjonene': ('primærproduksjon',),
'primærproduksjoner': ('primærproduksjon',),
'primærvalg': ('primærvalg',),
'primærvalga': ('primærvalg',),
'primærvalgene': ('primærvalg',),
'primærvalget': ('primærvalg',),
'prins': ('prins',),
'prinsen': ('prins',),
'prinsene': ('prins',),
'prinser': ('prins',),
'prinsessa': ('prinsesse',),
'prinsesse': ('prinsesse',),
'prinsessen': ('prinsesse',),
'prinsessene': ('prinsesse',),
'prinsesser': ('prinsesse',),
'prinsessebønna': ('prinsessebønne',),
'prinsessebønne': ('prinsessebønne',),
'prinsessebønnen': ('prinsessebønne',),
'prinsessebønnene': ('prinsessebønne',),
'prinsessebønner': ('prinsessebønne',),
'prinsessekaka': ('prinsessekake',),
'prinsessekake': ('prinsessekake',),
'prinsessekaken': ('prinsessekake',),
'prinsessekakene': ('prinsessekake',),
'prinsessekaker': ('prinsessekake',),
'prinsessepudding': ('prinsessepudding',),
'prinsessepuddingen': ('prinsessepudding',),
'prinsessepuddingene': ('prinsessepudding',),
'prinsessepuddinger': ('prinsessepudding',),
'prinsgemal': ('prinsgemal',),
'prinsgemalen': ('prinsgemal',),
'prinsgemalene': ('prinsgemal',),
'prinsgemaler': ('prinsgemal',),
'prinsipal': ('prinsipal',),
'prinsipalen': ('prinsipal',),
'prinsipalene': ('prinsipal',),
'prinsipaler': ('prinsipal',),
'prinsipp': ('prinsipp',),
'prinsippa': ('prinsipp',),
'prinsippene': ('prinsipp',),
'prinsipper': ('prinsipp',),
'prinsippet': ('prinsipp',),
'prinsipp-program': ('prinsipp-program',),
'prinsipp-programma': ('prinsipp-program',),
'prinsipp-programmene': ('prinsipp-program',),
'prinsipp-programmer': ('prinsipp-program',),
'prinsipp-programmet': ('prinsipp-program',),
'prinsippdebatt': ('prinsippdebatt',),
'prinsippdebatten': ('prinsippdebatt',),
'prinsippdebattene': ('prinsippdebatt',),
'prinsippdebatter': ('prinsippdebatt',),
'prinsipprogram': ('prinsipprogram',),
'prinsipprogramma': ('prinsipprogram',),
'prinsipprogrammene': ('prinsipprogram',),
'prinsipprogrammer': ('prinsipprogram',),
'prinsipprogrammet': ('prinsipprogram',),
'prinsipprytter': ('prinsipprytter',),
'prinsippryttere': ('prinsipprytter',),
'prinsipprytteren': ('prinsipprytter',),
'prinsipprytterer': ('prinsipprytter',),
'prinsipprytterne': ('prinsipprytter',),
'prinsippsak': ('prinsippsak',),
'prinsippsaka': ('prinsippsak',),
'prinsippsaken': ('prinsippsak',),
'prinsippsakene': ('prinsippsak',),
'prinsippsaker': ('prinsippsak',),
'prinsippvedtak': ('prinsippvedtak',),
'prinsippvedtaka': ('prinsippvedtak',),
'prinsippvedtakene': ('prinsippvedtak',),
'prinsippvedtaket': ('prinsippvedtak',),
'prinsregent': ('prinsregent',),
'prinsregenten': ('prinsregent',),
'prinsregentene': ('prinsregent',),
'prinsregenter': ('prinsregent',),
'printer': ('printer',),
'printere': ('printer',),
'printeren': ('printer',),
'printerer': ('printer',),
'printerne': ('printer',),
'prior': ('prior',),
'prioren': ('prior',),
'priorene': ('prior',),
'priorer': ('prior',),
'priorinna': ('priorinne',),
'priorinne': ('priorinne',),
'priorinnen': ('priorinne',),
'priorinnene': ('priorinne',),
'priorinner': ('priorinne',),
'prioritering': ('prioritering',),
'prioriteringa': ('prioritering',),
'prioriteringen': ('prioritering',),
'prioriteringene': ('prioritering',),
'prioriteringer': ('prioritering',),
'prioritet': ('prioritet',),
'prioriteten': ('prioritet',),
'prioritetene': ('prioritet',),
'prioriteter': ('prioritet',),
'prioritetsaksje': ('prioritetsaksje',),
'prioritetsaksjen': ('prioritetsaksje',),
'prioritetsaksjene': ('prioritetsaksje',),
'prioritetsaksjer': ('prioritetsaksje',),
'prioritetshaver': ('prioritetshaver',),
'prioritetshavere': ('prioritetshaver',),
'prioritetshaveren': ('prioritetshaver',),
'prioritetshaverer': ('prioritetshaver',),
'prioritetshaverne': ('prioritetshaver',),
'prioritetslista': ('prioritetsliste',),
'prioritetsliste': ('prioritetsliste',),
'prioritetslisten': ('prioritetsliste',),
'prioritetslistene': ('prioritetsliste',),
'prioritetslister': ('prioritetsliste',),
'prioritetsobligasjon': ('prioritetsobligasjon',),
'prioritetsobligasjonen': ('prioritetsobligasjon',),
'prioritetsobligasjonene': ('prioritetsobligasjon',),
'prioritetsobligasjoner': ('prioritetsobligasjon',),
'prioritetsrekka': ('prioritetsrekke',),
'prioritetsrekke': ('prioritetsrekke',),
'prioritetsrekken': ('prioritetsrekke',),
'prioritetsrekkene': ('prioritetsrekke',),
'prioritetsrekker': ('prioritetsrekke',),
'prioritetsvikelse': ('prioritetsvikelse',),
'prioritetsvikelsen': ('prioritetsvikelse',),
'prioritetsvikelsene': ('prioritetsvikelse',),
'prioritetsvikelser': ('prioritetsvikelse',),
'prioritetsvikning': ('prioritetsvikning',),
'prioritetsvikninga': ('prioritetsvikning',),
'prioritetsvikningen': ('prioritetsvikning',),
'prioritetsvikningene': ('prioritetsvikning',),
'prioritetsvikninger': ('prioritetsvikning',),
'pris': ('pris',),
'prisen': ('pris',),
'prisene': ('pris',),
'priser': ('pris',),
'pris': ('pris',),
'prisen': ('pris',),
'prisene': ('pris',),
'priser': ('pris',),
'pris': ('pris',),
'prisavhandling': ('prisavhandling',),
'prisavhandlinga': ('prisavhandling',),
'prisavhandlingen': ('prisavhandling',),
'prisavhandlingene': ('prisavhandling',),
'prisavhandlinger': ('prisavhandling',),
'prisavslag': ('prisavslag',),
'prisavslaga': ('prisavslag',),
'prisavslagene': ('prisavslag',),
'prisavslaget': ('prisavslag',),
'prisa': ('prise',),
'prise': ('prise',),
'prisen': ('prise',),
'prisene': ('prise',),
'priser': ('prise',),
'priserett': ('priserett',),
'priseretten': ('priserett',),
'priserettene': ('priserett',),
'priseretter': ('priserett',),
'prisfall': ('prisfall',),
'prisfalla': ('prisfall',),
'prisfallene': ('prisfall',),
'prisfallet': ('prisfall',),
'prisgalopp': ('prisgalopp',),
'prisgaloppen': ('prisgalopp',),
'prisgaloppene': ('prisgalopp',),
'prisgalopper': ('prisgalopp',),
'prishopp': ('prishopp',),
'prishoppa': ('prishopp',),
'prishoppene': ('prishopp',),
'prishoppet': ('prishopp',),
'prisindeks': ('prisindeks',),
'prisindeksen': ('prisindeks',),
'prisindeksene': ('prisindeks',),
'prisindekser': ('prisindeks',),
'prisklassa': ('prisklasse',),
'prisklasse': ('prisklasse',),
'prisklassen': ('prisklasse',),
'prisklassene': ('prisklasse',),
'prisklasser': ('prisklasse',),
'priskrig': ('priskrig',),
'priskrigen': ('priskrig',),
'priskrigene': ('priskrig',),
'priskriger': ('priskrig',),
'priskurant': ('priskurant',),
'priskuranten': ('priskurant',),
'priskurantene': ('priskurant',),
'priskuranter': ('priskurant',),
'prislapp': ('prislapp',),
'prislappen': ('prislapp',),
'prislappene': ('prislapp',),
'prislapper': ('prislapp',),
'prislista': ('prisliste',),
'prisliste': ('prisliste',),
'prislisten': ('prisliste',),
'prislistene': ('prisliste',),
'prislister': ('prisliste',),
'prismatoide': ('prismatoide',),
'prismatoiden': ('prismatoide',),
'prismatoidene': ('prismatoide',),
'prismatoider': ('prismatoide',),
'prisma': ('prisme',),
'prisme': ('prisme',),
'prismene': ('prisme',),
'prismer': ('prisme',),
'prismet': ('prisme',),
'prismekikkert': ('prismekikkert',),
'prismekikkerten': ('prismekikkert',),
'prismekikkertene': ('prismekikkert',),
'prismekikkerter': ('prismekikkert',),
'prismekrona': ('prismekrone',),
'prismekrone': ('prismekrone',),
'prismekronen': ('prismekrone',),
'prismekronene': ('prismekrone',),
'prismekroner': ('prismekrone',),
'prisnedslag': ('prisnedslag',),
'prisnedslaga': ('prisnedslag',),
'prisnedslagene': ('prisnedslag',),
'prisnedslaget': ('prisnedslag',),
'prisnivå': ('prisnivå',),
'prisnivåa': ('prisnivå',),
'prisnivåene': ('prisnivå',),
'prisnivåer': ('prisnivå',),
'prisnivået': ('prisnivå',),
'prisoppgava': ('prisoppgave',),
'prisoppgave': ('prisoppgave',),
'prisoppgaven': ('prisoppgave',),
'prisoppgavene': ('prisoppgave',),
'prisoppgaver': ('prisoppgave',),
'prispress': ('prispress',),
'prispressa': ('prispress',),
'prispressene': ('prispress',),
'prispresset': ('prispress',),
'prissjokk': ('prissjokk',),
'prissjokka': ('prissjokk',),
'prissjokkene': ('prissjokk',),
'prissjokket': ('prissjokk',),
'prisstiging': ('prisstiging',),
'prisstiginga': ('prisstiging',),
'prisstigingen': ('prisstiging',),
'prisstigingene': ('prisstiging',),
'prisstiginger': ('prisstiging',),
'prisstigning': ('prisstigning',),
'prisstigninga': ('prisstigning',),
'prisstigningen': ('prisstigning',),
'prisstigningene': ('prisstigning',),
'prisstigninger': ('prisstigning',),
'prisstopp': ('prisstopp',),
'prisstoppa': ('prisstopp',),
'prisstoppen': ('prisstopp',),
'prisstoppene': ('prisstopp',),
'prisstoppet': ('prisstopp',),
'prissubsidie': ('prissubsidie',),
'prissubsidien': ('prissubsidie',),
'prissubsidiene': ('prissubsidie',),
'prissubsidier': ('prissubsidie',),
'pristaker': ('pristaker',),
'pristakere': ('pristaker',),
'pristakeren': ('pristaker',),
'pristakerer': ('pristaker',),
'pristakerne': ('pristaker',),
'pristakst': ('pristakst',),
'pristaksten': ('pristakst',),
'pristakstene': ('pristakst',),
'pristakster': ('pristakst',),
'pristilsyn': ('pristilsyn',),
'pristilsyna': ('pristilsyn',),
'pristilsynene': ('pristilsyn',),
'pristilsynet': ('pristilsyn',),
'prisutdeling': ('prisutdeling',),
'prisutdelinga': ('prisutdeling',),
'prisutdelingen': ('prisutdeling',),
'prisutdelingene': ('prisutdeling',),
'prisutdelinger': ('prisutdeling',),
'prisvinner': ('prisvinner',),
'prisvinnere': ('prisvinner',),
'prisvinneren': ('prisvinner',),
'prisvinnerer': ('prisvinner',),
'prisvinnerne': ('prisvinner',),
'privat': ('privat',),
'privaten': ('privat',),
'privatene': ('privat',),
'privater': ('privat',),
'privatbank': ('privatbank',),
'privatbanken': ('privatbank',),
'privatbankene': ('privatbank',),
'privatbanker': ('privatbank',),
'privatbil': ('privatbil',),
'privatbilen': ('privatbil',),
'privatbilene': ('privatbil',),
'privatbiler': ('privatbil',),
'privatbilisme': ('privatbilisme',),
'privatbilismen': ('privatbilisme',),
'privatbilismene': ('privatbilisme',),
'privatbilismer': ('privatbilisme',),
'privatbolig': ('privatbolig',),
'privatboligen': ('privatbolig',),
'privatboligene': ('privatbolig',),
'privatboliger': ('privatbolig',),
'privatbruk': ('privatbruk',),
'privatbruka': ('privatbruk',),
'privatbruken': ('privatbruk',),
'privatbrukene': ('privatbruk',),
'privatbruker': ('privatbruk',),
'privatbruket': ('privatbruk',),
'privatdetektiv': ('privatdetektiv',),
'privatdetektiven': ('privatdetektiv',),
'privatdetektivene': ('privatdetektiv',),
'privatdetektiver': ('privatdetektiv',),
'privatdosent': ('privatdosent',),
'privatdosenten': ('privatdosent',),
'privatdosentene': ('privatdosent',),
'privatdosenter': ('privatdosent',),
'privatdrift': ('privatdrift',),
'privatdrifta': ('privatdrift',),
'privatdriften': ('privatdrift',),
'privatdriftene': ('privatdrift',),
'privatdrifter': ('privatdrift',),
'privateia': ('privateie',),
'privateie': ('privateie',),
'privateiene': ('privateie',),
'privateier': ('privateie',),
'privateiet': ('privateie',),
'privatelev': ('privatelev',),
'privateleven': ('privatelev',),
'privatelevene': ('privatelev',),
'privatelever': ('privatelev',),
'privatfly': ('privatfly',),
'privatflya': ('privatfly',),
'privatflyene': ('privatfly',),
'privatflyet': ('privatfly',),
'privatforbruk': ('privatforbruk',),
'privatforbruka': ('privatforbruk',),
'privatforbrukene': ('privatforbruk',),
'privatforbruket': ('privatforbruk',),
'privatist': ('privatist',),
'privatisten': ('privatist',),
'privatistene': ('privatist',),
'privatister': ('privatist',),
'privatkamp': ('privatkamp',),
'privatkampen': ('privatkamp',),
'privatkampene': ('privatkamp',),
'privatkamper': ('privatkamp',),
'privatkapitalisme': ('privatkapitalisme',),
'privatkapitalismen': ('privatkapitalisme',),
'privatkapitalismene': ('privatkapitalisme',),
'privatkapitalismer': ('privatkapitalisme',),
'privatliv': ('privatliv',),
'privatliva': ('privatliv',),
'privatlivene': ('privatliv',),
'privatlivet': ('privatliv',),
'privatlærer': ('privatlærer',),
'privatlærere': ('privatlærer',),
'privatlæreren': ('privatlærer',),
'privatlærerer': ('privatlærer',),
'privatlærerne': ('privatlærer',),
'privatmann': ('privatmann',),
'privatmannen': ('privatmann',),
'privatmenn': ('privatmann',),
'privatmennene': ('privatmann',),
'privatpasient': ('privatpasient',),
'privatpasienten': ('privatpasient',),
'privatpasientene': ('privatpasient',),
'privatpasienter': ('privatpasient',),
'privatperson': ('privatperson',),
'privatpersonen': ('privatperson',),
'privatpersonene': ('privatperson',),
'privatpersoner': ('privatperson',),
'privatpraksis': ('privatpraksis',),
'privatpraksisen': ('privatpraksis',),
'privatpraksisene': ('privatpraksis',),
'privatpraksiser': ('privatpraksis',),
'privatpreseptor': ('privatpreseptor',),
'privatpreseptoren': ('privatpreseptor',),
'privatpreseptorene': ('privatpreseptor',),
'privatpreseptorer': ('privatpreseptor',),
'privatrett': ('privatrett',),
'privatretten': ('privatrett',),
'privatrettene': ('privatrett',),
'privatretter': ('privatrett',),
'privatsak': ('privatsak',),
'privatsaka': ('privatsak',),
'privatsaken': ('privatsak',),
'privatsakene': ('privatsak',),
'privatsaker': ('privatsak',),
'privatsekretær': ('privatsekretær',),
'privatsekretæren': ('privatsekretær',),
'privatsekretærene': ('privatsekretær',),
'privatsekretærer': ('privatsekretær',),
'privatsjåfør': ('privatsjåfør',),
'privatsjåføren': ('privatsjåfør',),
'privatsjåførene': ('privatsjåfør',),
'privatsjåfører': ('privatsjåfør',),
'privatskole': ('privatskole',),
'privatskolen': ('privatskole',),
'privatskolene': ('privatskole',),
'privatskoler': ('privatskole',),
'privatundervisning': ('privatundervisning',),
'privatundervisninga': ('privatundervisning',),
'privatundervisningen': ('privatundervisning',),
'privatundervisningene': ('privatundervisning',),
'privatundervisninger': ('privatundervisning',),
'privet': ('privet',),
'priveta': ('privet',),
'privetene': ('privet',),
'priveter': ('privet',),
'privetet': ('privet',),
'privileg': ('privileg',),
'privilega': ('privileg',),
'privilegene': ('privileg',),
'privileger': ('privileg',),
'privileget': ('privileg',),
'privilegia': ('privilegium',),
'privilegiene': ('privilegium',),
'privilegier': ('privilegium',),
'privilegiet': ('privilegium',),
'privilegium': ('privilegium',),
'probabilitet': ('probabilitet',),
'probabiliteten': ('probabilitet',),
'probabilitetene': ('probabilitet',),
'probabiliteter': ('probabilitet',),
'probering': ('probering',),
'proberinga': ('probering',),
'proberingen': ('probering',),
'proberingene': ('probering',),
'proberinger': ('probering',),
'probernål': ('probernål',),
'probernåla': ('probernål',),
'probernålen': ('probernål',),
'probernålene': ('probernål',),
'probernåler': ('probernål',),
'problem': ('problem',),
'problema': ('problem',),
'problemene': ('problem',),
'problemer': ('problem',),
'problemet': ('problem',),
'problematikk': ('problematikk',),
'problematikken': ('problematikk',),
'problematikkene': ('problematikk',),
'problematikker': ('problematikk',),
'problembarn': ('problembarn',),
'problembarna': ('problembarn',),
'problembarnene': ('problembarn',),
'problembarnet': ('problembarn',),
'problemdiktning': ('problemdiktning',),
'problemdiktninga': ('problemdiktning',),
'problemdiktningen': ('problemdiktning',),
'problemdiktningene': ('problemdiktning',),
'problemdiktninger': ('problemdiktning',),
'problemkompleks': ('problemkompleks',),
'problemkompleksa': ('problemkompleks',),
'problemkompleksene': ('problemkompleks',),
'problemkomplekser': ('problemkompleks',),
'problemkomplekset': ('problemkompleks',),
'problemstilling': ('problemstilling',),
'problemstillinga': ('problemstilling',),
'problemstillingen': ('problemstilling',),
'problemstillingene': ('problemstilling',),
'problemstillinger': ('problemstilling',),
'producer': ('producer',),
'producere': ('producer',),
'produceren': ('producer',),
'producerer': ('producer',),
'producerne': ('producer',),
'produksjon': ('produksjon',),
'produksjonen': ('produksjon',),
'produksjonene': ('produksjon',),
'produksjoner': ('produksjon',),
'produksjonsapparat': ('produksjonsapparat',),
'produksjonsapparata': ('produksjonsapparat',),
'produksjonsapparatene': ('produksjonsapparat',),
'produksjonsapparater': ('produksjonsapparat',),
'produksjonsapparatet': ('produksjonsapparat',),
'produksjonsfaktor': ('produksjonsfaktor',),
'produksjonsfaktoren': ('produksjonsfaktor',),
'produksjonsfaktorene': ('produksjonsfaktor',),
'produksjonsfaktorer': ('produksjonsfaktor',),
'produksjonsforhold': ('produksjonsforhold',),
'produksjonsforholda': ('produksjonsforhold',),
'produksjonsforholdene': ('produksjonsforhold',),
'produksjonsforholdet': ('produksjonsforhold',),
'produksjonsindeks': ('produksjonsindeks',),
'produksjonsindeksen': ('produksjonsindeks',),
'produksjonsindeksene': ('produksjonsindeks',),
'produksjonsindekser': ('produksjonsindeks',),
'produksjonskapasitet': ('produksjonskapasitet',),
'produksjonskapasiteten': ('produksjonskapasitet',),
'produksjonskapasitetene': ('produksjonskapasitet',),
'produksjonskapasiteter': ('produksjonskapasitet',),
'produksjonskostnad': ('produksjonskostnad',),
'produksjonskostnaden': ('produksjonskostnad',),
'produksjonskostnadene': ('produksjonskostnad',),
'produksjonskostnader': ('produksjonskostnad',),
'produksjonsmelk': ('produksjonsmelk',),
'produksjonsmelka': ('produksjonsmelk',),
'produksjonsmelken': ('produksjonsmelk',),
'produksjonsmelkene': ('produksjonsmelk',),
'produksjonsmelker': ('produksjonsmelk',),
'produksjonsmidler': ('produksjonsmidler',),
'produksjonsmidlere': ('produksjonsmidler',),
'produksjonsmidleren': ('produksjonsmidler',),
'produksjonsmidlerer': ('produksjonsmidler',),
'produksjonsmidlerne': ('produksjonsmidler',),
'produksjonsmjølk': ('produksjonsmjølk',),
'produksjonsmjølka': ('produksjonsmjølk',),
'produksjonsmjølken': ('produksjonsmjølk',),
'produksjonsmjølkene': ('produksjonsmjølk',),
'produksjonsmjølker': ('produksjonsmjølk',),
'produksjonsmåte': ('produksjonsmåte',),
'produksjonsmåten': ('produksjonsmåte',),
'produksjonsmåtene': ('produksjonsmåte',),
'produksjonsmåter': ('produksjonsmåte',),
'produksjonspremie': ('produksjonspremie',),
'produksjonspremien': ('produksjonspremie',),
'produksjonspremiene': ('produksjonspremie',),
'produksjonspremier': ('produksjonspremie',),
'produksjonsprosess': ('produksjonsprosess',),
'produksjonsprosessen': ('produksjonsprosess',),
'produksjonsprosessene': ('produksjonsprosess',),
'produksjonsprosesser': ('produksjonsprosess',),
'produksjonstap': ('produksjonstap',),
'produksjonstapa': ('produksjonstap',),
'produksjonstapene': ('produksjonstap',),
'produksjonstapet': ('produksjonstap',),
'produksjonsvolum': ('produksjonsvolum',),
'produksjonsvoluma': ('produksjonsvolum',),
'produksjonsvolumene': ('produksjonsvolum',),
'produksjonsvolumer': ('produksjonsvolum',),
'produksjonsvolumet': ('produksjonsvolum',),
'produksjonsøking': ('produksjonsøking',),
'produksjonsøkinga': ('produksjonsøking',),
'produksjonsøkingen': ('produksjonsøking',),
'produksjonsøkingene': ('produksjonsøking',),
'produksjonsøkinger': ('produksjonsøking',),
'produksjonsøkning': ('produksjonsøkning',),
'produksjonsøkninga': ('produksjonsøkning',),
'produksjonsøkningen': ('produksjonsøkning',),
'produksjonsøkningene': ('produksjonsøkning',),
'produksjonsøkninger': ('produksjonsøkning',),
'produkt': ('produkt',),
'produkta': ('produkt',),
'produktene': ('produkt',),
'produkter': ('produkt',),
'produktet': ('produkt',),
'produktivitet': ('produktivitet',),
'produktiviteten': ('produktivitet',),
'produktivitetene': ('produktivitet',),
'produktiviteter': ('produktivitet',),
'produktivkreftene': ('produktivkrefter',),
'produktivkrefter': ('produktivkrefter',),
'produktutvikler': ('produktutvikler',),
'produktutviklere': ('produktutvikler',),
'produktutvikleren': ('produktutvikler',),
'produktutviklerer': ('produktutvikler',),
'produktutviklerne': ('produktutvikler',),
'produktutvikling': ('produktutvikling',),
'produktutviklinga': ('produktutvikling',),
'produktutviklingen': ('produktutvikling',),
'produktutviklingene': ('produktutvikling',),
'produktutviklinger': ('produktutvikling',),
'produsent': ('produsent',),
'produsenten': ('produsent',),
'produsentene': ('produsent',),
'produsenter': ('produsent',),
'produsentsamvirka': ('produsentsamvirke',),
'produsentsamvirke': ('produsentsamvirke',),
'produsentsamvirkene': ('produsentsamvirke',),
'produsentsamvirker': ('produsentsamvirke',),
'produsentsamvirket': ('produsentsamvirke',),
'profanasjon': ('profanasjon',),
'profanasjonen': ('profanasjon',),
'profanasjonene': ('profanasjon',),
'profanasjoner': ('profanasjon',),
'profase': ('profase',),
'profasen': ('profase',),
'profasene': ('profase',),
'profaser': ('profase',),
'profesjon': ('profesjon',),
'profesjonen': ('profesjon',),
'profesjonene': ('profesjon',),
'profesjoner': ('profesjon',),
'profesjonalisme': ('profesjonalisme',),
'profesjonalismen': ('profesjonalisme',),
'profesjonalismene': ('profesjonalisme',),
'profesjonalismer': ('profesjonalisme',),
'profesjonalitet': ('profesjonalitet',),
'profesjonaliteten': ('profesjonalitet',),
'profesjonalitetene': ('profesjonalitet',),
'profesjonaliteter': ('profesjonalitet',),
'profesjonisme': ('profesjonisme',),
'profesjonismen': ('profesjonisme',),
'profesjonismene': ('profesjonisme',),
'profesjonismer': ('profesjonisme',),
'profesjonist': ('profesjonist',),
'profesjonisten': ('profesjonist',),
'profesjonistene': ('profesjonist',),
'profesjonister': ('profesjonist',),
'professor': ('professor',),
'professoren': ('professor',),
'professorene': ('professor',),
'professorer': ('professor',),
'professorat': ('professorat',),
'professorata': ('professorat',),
'professoratene': ('professorat',),
'professorater': ('professorat',),
'professoratet': ('professorat',),
'professormina': ('professormine',),
'professormine': ('professormine',),
'professorminen': ('professormine',),
'professorminene': ('professormine',),
'professorminer': ('professormine',),
'professorråd': ('professorråd',),
'professorråda': ('professorråd',),
'professorrådene': ('professorråd',),
'professorrådet': ('professorråd',),
'professortone': ('professortone',),
'professortonen': ('professortone',),
'professortonene': ('professortone',),
'professortoner': ('professortone',),
'professorvelda': ('professorvelde',),
'professorvelde': ('professorvelde',),
'professorveldene': ('professorvelde',),
'professorvelder': ('professorvelde',),
'professorveldet': ('professorvelde',),
'profet': ('profet',),
'profeten': ('profet',),
'profetene': ('profet',),
'profeter': ('profet',),
'profeti': ('profeti',),
'profetien': ('profeti',),
'profetiene': ('profeti',),
'profetier': ('profeti',),
'profetskjegg': ('profetskjegg',),
'profetskjegga': ('profetskjegg',),
'profetskjeggene': ('profetskjegg',),
'profetskjegget': ('profetskjegg',),
'proff': ('proff',),
'proffen': ('proff',),
'proffene': ('proff',),
'proffer': ('proff',),
'proff': ('proff',),
'proffen': ('proff',),
'proffene': ('proff',),
'proffer': ('proff',),
'proffbokser': ('proffbokser',),
'proffboksere': ('proffbokser',),
'proffbokseren': ('proffbokser',),
'proffbokserer': ('proffbokser',),
'proffbokserne': ('proffbokser',),
'proffidrett': ('proffidrett',),
'proffidretten': ('proffidrett',),
'proffidrettene': ('proffidrett',),
'proffidretter': ('proffidrett',),
'proffstemna': ('proffstemne',),
'proffstemne': ('proffstemne',),
'proffstemnen': ('proffstemne',),
'proffstemnene': ('proffstemne',),
'proffstemner': ('proffstemne',),
'proffstemnet': ('proffstemne',),
'proffstevna': ('proffstevne',),
'proffstevne': ('proffstevne',),
'proffstevnene': ('proffstevne',),
'proffstevner': ('proffstevne',),
'proffstevnet': ('proffstevne',),
'profftilbud': ('profftilbud',),
'profftilbuda': ('profftilbud',),
'profftilbudene': ('profftilbud',),
'profftilbudet': ('profftilbud',),
'profil': ('profil',),
'profilen': ('profil',),
'profilene': ('profil',),
'profiler': ('profil',),
'profil': ('profil',),
'profila': ('profil',),
'profilene': ('profil',),
'profiler': ('profil',),
'profilet': ('profil',),
'profilbilda': ('profilbilde',),
'profilbilde': ('profilbilde',),
'profilbildene': ('profilbilde',),
'profilbilder': ('profilbilde',),
'profilbildet': ('profilbilde',),
'profiljern': ('profiljern',),
'profiljerna': ('profiljern',),
'profiljernene': ('profiljern',),
'profiljernet': ('profiljern',),
'profillikhet': ('profillikhet',),
'profillikheta': ('profillikhet',),
'profillikheten': ('profillikhet',),
'profillikhetene': ('profillikhet',),
'profillikheter': ('profillikhet',),
'profilstål': ('profilstål',),
'profilståla': ('profilstål',),
'profilstålene': ('profilstål',),
'profilstålet': ('profilstål',),
'profiltråd': ('profiltråd',),
'profiltråden': ('profiltråd',),
'profiltrådene': ('profiltråd',),
'profiltråder': ('profiltråd',),
'profitt': ('profitt',),
'profitten': ('profitt',),
'profittene': ('profitt',),
'profitter': ('profitt',),
'profittbegjær': ('profittbegjær',),
'profittbegjæra': ('profittbegjær',),
'profittbegjærene': ('profittbegjær',),
'profittbegjæret': ('profittbegjær',),
'profittjakt': ('profittjakt',),
'profittjakta': ('profittjakt',),
'profittjakten': ('profittjakt',),
'profittjaktene': ('profittjakt',),
'profittjakter': ('profittjakt',),
'profittmaksimering': ('profittmaksimering',),
'profittmaksimeringa': ('profittmaksimering',),
'profittmaksimeringen': ('profittmaksimering',),
'profittmaksimeringene': ('profittmaksimering',),
'profittmaksimeringer': ('profittmaksimering',),
'profittrate': ('profittrate',),
'profittraten': ('profittrate',),
'profittratene': ('profittrate',),
'profittrater': ('profittrate',),
'profitør': ('profitør',),
'profitøren': ('profitør',),
'profitørene': ('profitør',),
'profitører': ('profitør',),
'proformaekteskap': ('proformaekteskap',),
'proformaekteskapa': ('proformaekteskap',),
'proformaekteskapene': ('proformaekteskap',),
'proformaekteskaper': ('proformaekteskap',),
'proformaekteskapet': ('proformaekteskap',),
'proformafaktura': ('proformafaktura',),
'proformafakturaen': ('proformafaktura',),
'proformafakturaene': ('proformafaktura',),
'proformafakturaer': ('proformafaktura',),
'proformasak': ('proformasak',),
'proformasaka': ('proformasak',),
'proformasaken': ('proformasak',),
'proformasakene': ('proformasak',),
'proformasaker': ('proformasak',),
'proformaselskap': ('proformaselskap',),
'proformaselskapa': ('proformaselskap',),
'proformaselskapene': ('proformaselskap',),
'proformaselskaper': ('proformaselskap',),
'proformaselskapet': ('proformaselskap',),
'profylakse': ('profylakse',),
'profylaksen': ('profylakse',),
'profylaksene': ('profylakse',),
'profylakser': ('profylakse',),
'progesteron': ('progesteron',),
'progesterona': ('progesteron',),
'progesteronene': ('progesteron',),
'progesteroner': ('progesteron',),
'progesteronet': ('progesteron',),
'prognose': ('prognose',),
'prognosen': ('prognose',),
'prognosene': ('prognose',),
'prognoser': ('prognose',),
'program': ('program',),
'programma': ('program',),
'programmene': ('program',),
'programmer': ('program',),
'programmet': ('program',),
'programblad': ('programblad',),
'programblada': ('programblad',),
'programbladene': ('programblad',),
'programblader': ('programblad',),
'programbladet': ('programblad',),
'programdikting': ('programdikting',),
'programdiktinga': ('programdikting',),
'programdiktingen': ('programdikting',),
'programdiktingene': ('programdikting',),
'programdiktinger': ('programdikting',),
'programdiktning': ('programdiktning',),
'programdiktninga': ('programdiktning',),
'programdiktningen': ('programdiktning',),
'programdiktningene': ('programdiktning',),
'programdiktninger': ('programdiktning',),
'programerklæring': ('programerklæring',),
'programerklæringa': ('programerklæring',),
'programerklæringen': ('programerklæring',),
'programerklæringene': ('programerklæring',),
'programerklæringer': ('programerklæring',),
'programhelt': ('programhelt',),
'programhelten': ('programhelt',),
'programheltene': ('programhelt',),
'programhelter': ('programhelt',),
'programleder': ('programleder',),
'programledere': ('programleder',),
'programlederen': ('programleder',),
'programlederer': ('programleder',),
'programlederne': ('programleder',),
'programløfta': ('programløfte',),
'programløfte': ('programløfte',),
'programløftene': ('programløfte',),
'programløfter': ('programløfte',),
'programløftet': ('programløfte',),
'programmerer': ('programmerer',),
'programmerere': ('programmerer',),
'programmereren': ('programmerer',),
'programmererer': ('programmerer',),
'programmererne': ('programmerer',),
'programmeringsspråk': ('programmeringsspråk',),
'programmeringsspråka': ('programmeringsspråk',),
'programmeringsspråkene': ('programmeringsspråk',),
'programmeringsspråket': ('programmeringsspråk',),
'programmusikk': ('programmusikk',),
'programmusikken': ('programmusikk',),
'programmusikkene': ('programmusikk',),
'programmusikker': ('programmusikk',),
'programpost': ('programpost',),
'programposten': ('programpost',),
'programpostene': ('programpost',),
'programposter': ('programpost',),
'programredaktør': ('programredaktør',),
'programredaktøren': ('programredaktør',),
'programredaktørene': ('programredaktør',),
'programredaktører': ('programredaktør',),
'programsekretær': ('programsekretær',),
'programsekretæren': ('programsekretær',),
'programsekretærene': ('programsekretær',),
'programsekretærer': ('programsekretær',),
'programtjeneste': ('programtjeneste',),
'programtjenesten': ('programtjeneste',),
'programtjenestene': ('programtjeneste',),
'programtjenester': ('programtjeneste',),
'programutstyr': ('programutstyr',),
'programutstyra': ('programutstyr',),
'programutstyrene': ('programutstyr',),
'programutstyret': ('programutstyr',),
'programvara': ('programvare',),
'programvare': ('programvare',),
'programvaren': ('programvare',),
'programvarene': ('programvare',),
'programvarer': ('programvare',),
'progresjon': ('progresjon',),
'progresjonen': ('progresjon',),
'progresjonene': ('progresjon',),
'progresjoner': ('progresjon',),
'progresjonsskatt': ('progresjonsskatt',),
'progresjonsskatten': ('progresjonsskatt',),
'progresjonsskattene': ('progresjonsskatt',),
'progresjonsskatter': ('progresjonsskatt',),
'progresjonstrinn': ('progresjonstrinn',),
'progresjonstrinna': ('progresjonstrinn',),
'progresjonstrinnene': ('progresjonstrinn',),
'progresjonstrinnet': ('progresjonstrinn',),
'progressivist': ('progressivist',),
'progressivisten': ('progressivist',),
'progressivistene': ('progressivist',),
'progressivister': ('progressivist',),
'progressivitet': ('progressivitet',),
'progressiviteten': ('progressivitet',),
'progressivitetene': ('progressivitet',),
'progressiviteter': ('progressivitet',),
'prohibitivsystem': ('prohibitivsystem',),
'prohibitivsystema': ('prohibitivsystem',),
'prohibitivsystemene': ('prohibitivsystem',),
'prohibitivsystemer': ('prohibitivsystem',),
'prohibitivsystemet': ('prohibitivsystem',),
'projeksjon': ('projeksjon',),
'projeksjonen': ('projeksjon',),
'projeksjonene': ('projeksjon',),
'projeksjoner': ('projeksjon',),
'projeksjonsapparat': ('projeksjonsapparat',),
'projeksjonsapparata': ('projeksjonsapparat',),
'projeksjonsapparatene': ('projeksjonsapparat',),
'projeksjonsapparater': ('projeksjonsapparat',),
'projeksjonsapparatet': ('projeksjonsapparat',),
'projeksjonstegning': ('projeksjonstegning',),
'projeksjonstegninga': ('projeksjonstegning',),
'projeksjonstegningen': ('projeksjonstegning',),
'projeksjonstegningene': ('projeksjonstegning',),
'projeksjonstegninger': ('projeksjonstegning',),
'projektor': ('projektor',),
'projektoren': ('projektor',),
'projektorene': ('projektor',),
'projektorer': ('projektor',),
'projisering': ('projisering',),
'projiseringa': ('projisering',),
'projiseringen': ('projisering',),
'projiseringene': ('projisering',),
'projiseringer': ('projisering',),
'proklama': ('proklama',),
'proklamaene': ('proklama',),
'proklamaer': ('proklama',),
'proklamaet': ('proklama',),
'proklamasjon': ('proklamasjon',),
'proklamasjonen': ('proklamasjon',),
'proklamasjonene': ('proklamasjon',),
'proklamasjoner': ('proklamasjon',),
'prokonsul': ('prokonsul',),
'prokonsulen': ('prokonsul',),
'prokonsulene': ('prokonsul',),
'prokonsuler': ('prokonsul',),
'prokrustesseng': ('prokrustesseng',),
'prokrustessenga': ('prokrustesseng',),
'prokrustessengen': ('prokrustesseng',),
'prokrustessengene': ('prokrustesseng',),
'prokrustessenger': ('prokrustesseng',),
'prokura': ('prokura',),
'prokuraen': ('prokura',),
'prokuraene': ('prokura',),
'prokuraer': ('prokura',),
'prokuraet': ('prokura',),
'prokurator': ('prokurator',),
'prokuratoren': ('prokurator',),
'prokuratorene': ('prokurator',),
'prokuratorer': ('prokurator',),
'prokuratorknep': ('prokuratorknep',),
'prokuratorknepa': ('prokuratorknep',),
'prokuratorknepene': ('prokuratorknep',),
'prokuratorknepet': ('prokuratorknep',),
'prokurist': ('prokurist',),
'prokuristen': ('prokurist',),
'prokuristene': ('prokurist',),
'prokurister': ('prokurist',),
'prolaps': ('prolaps',),
'prolapsen': ('prolaps',),
'prolapsene': ('prolaps',),
'prolapser': ('prolaps',),
'proletar': ('proletar',),
'proletaren': ('proletar',),
'proletarene': ('proletar',),
'proletarer': ('proletar',),
'proletarbevegelse': ('proletarbevegelse',),
'proletarbevegelsen': ('proletarbevegelse',),
'proletarbevegelsene': ('proletarbevegelse',),
'proletarbevegelser': ('proletarbevegelse',),
'proletarforfatter': ('proletarforfatter',),
'proletarforfattere': ('proletarforfatter',),
'proletarforfatteren': ('proletarforfatter',),
'proletarforfatterer': ('proletarforfatter',),
'proletarforfatterne': ('proletarforfatter',),
'proletariat': ('proletariat',),
'proletariata': ('proletariat',),
'proletariatene': ('proletariat',),
'proletariater': ('proletariat',),
'proletariatet': ('proletariat',),
'prolog': ('prolog',),
'prologen': ('prolog',),
'prologene': ('prolog',),
'prologer': ('prolog',),
'prolongasjon': ('prolongasjon',),
'prolongasjonen': ('prolongasjon',),
'prolongasjonene': ('prolongasjon',),
'prolongasjoner': ('prolongasjon',),
'promemoria': ('promemoria',),
'promemoriaen': ('promemoria',),
'promemoriaene': ('promemoria',),
'promemoriaer': ('promemoria',),
'promemoriaet': ('promemoria',),
'promemoriene': ('promemoria',),
'promemorier': ('promemoria',),
'promenade': ('promenade',),
'promenaden': ('promenade',),
'promenadene': ('promenade',),
'promenader': ('promenade',),
'promenadedekk': ('promenadedekk',),
'promenadedekka': ('promenadedekk',),
'promenadedekkene': ('promenadedekk',),
'promenadedekket': ('promenadedekk',),
'promethium': ('promethium',),
'promethiuma': ('promethium',),
'promethiumene': ('promethium',),
'promethiumet': ('promethium',),
'promille': ('promille',),
'promillen': ('promille',),
'promillene': ('promille',),
'promiller': ('promille',),
'promilledom': ('promilledom',),
'promilledommen': ('promilledom',),
'promilledommene': ('promilledom',),
'promilledommer': ('promilledom',),
'promillekjører': ('promillekjører',),
'promillekjørere': ('promillekjører',),
'promillekjøreren': ('promillekjører',),
'promillekjørerer': ('promillekjører',),
'promillekjørerne': ('promillekjører',),
'promillekjøring': ('promillekjøring',),
'promillekjøringa': ('promillekjøring',),
'promillekjøringen': ('promillekjøring',),
'promillekjøringene': ('promillekjøring',),
'promillekjøringer': ('promillekjøring',),
'promilleprøva': ('promilleprøve',),
'promilleprøve': ('promilleprøve',),
'promilleprøven': ('promilleprøve',),
'promilleprøvene': ('promilleprøve',),
'promilleprøver': ('promilleprøve',),
'promillist': ('promillist',),
'promillisten': ('promillist',),
'promillistene': ('promillist',),
'promillister': ('promillist',),
'prominens': ('prominens',),
'prominensen': ('prominens',),
'prominensene': ('prominens',),
'prominenser': ('prominens',),
'promiskuitet': ('promiskuitet',),
'promiskuiteten': ('promiskuitet',),
'promiskuitetene': ('promiskuitet',),
'promiskuiteter': ('promiskuitet',),
'promosjon': ('promosjon',),
'promosjonen': ('promosjon',),
'promosjonene': ('promosjon',),
'promosjoner': ('promosjon',),
'promotor': ('promotor',),
'promotoren': ('promotor',),
'promotorene': ('promotor',),
'promotorer': ('promotor',),
'promp': ('promp',),
'prompen': ('promp',),
'prompene': ('promp',),
'promper': ('promp',),
'promulgasjon': ('promulgasjon',),
'promulgasjonen': ('promulgasjon',),
'promulgasjonene': ('promulgasjon',),
'promulgasjoner': ('promulgasjon',),
'pronasjon': ('pronasjon',),
'pronasjonen': ('pronasjon',),
'pronasjonene': ('pronasjon',),
'pronasjoner': ('pronasjon',),
'pronomen': ('pronomen',),
'pronomena': ('pronomen',),
'pronomenene': ('pronomen',),
'pronomener': ('pronomen',),
'pronomenet': ('pronomen',),
'propaganda': ('propaganda',),
'propagandaen': ('propaganda',),
'propagandaene': ('propaganda',),
'propagandaer': ('propaganda',),
'propagandaapparat': ('propagandaapparat',),
'propagandaapparata': ('propagandaapparat',),
'propagandaapparatene': ('propagandaapparat',),
'propagandaapparater': ('propagandaapparat',),
'propagandaapparatet': ('propagandaapparat',),
'propagandist': ('propagandist',),
'propagandisten': ('propagandist',),
'propagandistene': ('propagandist',),
'propagandister': ('propagandist',),
'propan': ('propan',),
'propana': ('propan',),
'propanen': ('propan',),
'propanene': ('propan',),
'propaner': ('propan',),
'propanet': ('propan',),
'propanapparat': ('propanapparat',),
'propanapparata': ('propanapparat',),
'propanapparatene': ('propanapparat',),
'propanapparater': ('propanapparat',),
'propanapparatet': ('propanapparat',),
'propanflaska': ('propanflaske',),
'propanflaske': ('propanflaske',),
'propanflasken': ('propanflaske',),
'propanflaskene': ('propanflaske',),
'propanflasker': ('propanflaske',),
'propangass': ('propangass',),
'propangassen': ('propangass',),
'propangassene': ('propangass',),
'propangasser': ('propangass',),
'propedeutikk': ('propedeutikk',),
'propedeutikken': ('propedeutikk',),
'propedeutikkene': ('propedeutikk',),
'propedeutikker': ('propedeutikk',),
'propedevtikk': ('propedevtikk',),
'propedevtikken': ('propedevtikk',),
'propedevtikkene': ('propedevtikk',),
'propedevtikker': ('propedevtikk',),
'propell': ('propell',),
'propellen': ('propell',),
'propellene': ('propell',),
'propeller': ('propell',),
'propellfly': ('propellfly',),
'propellflya': ('propellfly',),
'propellflyene': ('propellfly',),
'propellflyet': ('propellfly',),
'propellveng': ('propellveng',),
'propellvengen': ('propellveng',),
'propellvengene': ('propellveng',),
'propellvenger': ('propellveng',),
'propellving': ('propellving',),
'propellvingen': ('propellving',),
'propellvingene': ('propellving',),
'propellvinger': ('propellving',),
'propellvinge': ('propellvinge',),
'propellvingen': ('propellvinge',),
'propellvingene': ('propellvinge',),
'propellvinger': ('propellvinge',),
'propionsyra': ('propionsyre',),
'propionsyre': ('propionsyre',),
'propionsyren': ('propionsyre',),
'propionsyrene': ('propionsyre',),
'propionsyrer': ('propionsyre',),
'proponent': ('proponent',),
'proponenten': ('proponent',),
'proponentene': ('proponent',),
'proponenter': ('proponent',),
'proporsjon': ('proporsjon',),
'proporsjonen': ('proporsjon',),
'proporsjonene': ('proporsjon',),
'proporsjoner': ('proporsjon',),
'proporsjonal': ('proporsjonal',),
'proporsjonalen': ('proporsjonal',),
'proporsjonalene': ('proporsjonal',),
'proporsjonaler': ('proporsjonal',),
'proporsjonalitet': ('proporsjonalitet',),
'proporsjonaliteten': ('proporsjonalitet',),
'proporsjonalitetene': ('proporsjonalitet',),
'proporsjonaliteter': ('proporsjonalitet',),
'proposisjon': ('proposisjon',),
'proposisjonen': ('proposisjon',),
'proposisjonene': ('proposisjon',),
'proposisjoner': ('proposisjon',),
'propp': ('propp',),
'proppen': ('propp',),
'proppene': ('propp',),
'propper': ('propp',),
'proprietær': ('proprietær',),
'proprietæren': ('proprietær',),
'proprietærene': ('proprietær',),
'proprietærer': ('proprietær',),
'propria': ('proprium',),
'propriene': ('proprium',),
'proprier': ('proprium',),
'propriet': ('proprium',),
'proprium': ('proprium',),
'props': ('props',),
'propsen': ('props',),
'propsene': ('props',),
'propser': ('props',),
'propulsjon': ('propulsjon',),
'propulsjonen': ('propulsjon',),
'propulsjonene': ('propulsjon',),
'propulsjoner': ('propulsjon',),
'propylea': ('propylé',),
'propyleene': ('propylé',),
'propyleer': ('propylé',),
'propyleet': ('propylé',),
'propylé': ('propylé',),
'propyléa': ('propylé',),
'propyléene': ('propylé',),
'propyléer': ('propylé',),
'propyléet': ('propylé',),
'propylea': ('propyleum',),
'propyleene': ('propyleum',),
'propyleer': ('propyleum',),
'propyleet': ('propyleum',),
'propyleum': ('propyleum',),
'prorektor': ('prorektor',),
'prorektoren': ('prorektor',),
'prorektorene': ('prorektor',),
'prorektorer': ('prorektor',),
'prosa': ('prosa',),
'prosaen': ('prosa',),
'prosaene': ('prosa',),
'prosaer': ('prosa',),
'prosadikt': ('prosadikt',),
'prosadikta': ('prosadikt',),
'prosadiktene': ('prosadikt',),
'prosadiktet': ('prosadikt',),
'prosaforfatter': ('prosaforfatter',),
'prosaforfattere': ('prosaforfatter',),
'prosaforfatteren': ('prosaforfatter',),
'prosaforfatterer': ('prosaforfatter',),
'prosaforfatterne': ('prosaforfatter',),
'prosaiker': ('prosaiker',),
'prosaikere': ('prosaiker',),
'prosaikeren': ('prosaiker',),
'prosaikerer': ('prosaiker',),
'prosaikerne': ('prosaiker',),
'prosaist': ('prosaist',),
'prosaisten': ('prosaist',),
'prosaistene': ('prosaist',),
'prosaister': ('prosaist',),
'prosedyre': ('prosedyre',),
'prosedyren': ('prosedyre',),
'prosedyrene': ('prosedyre',),
'prosedyrer': ('prosedyre',),
'prosektor': ('prosektor',),
'prosektoren': ('prosektor',),
'prosektorene': ('prosektor',),
'prosektorer': ('prosektor',),
'proselytt': ('proselytt',),
'proselytten': ('proselytt',),
'proselyttene': ('proselytt',),
'proselytter': ('proselytt',),
'prosent': ('prosent',),
'prosenten': ('prosent',),
'prosentene': ('prosent',),
'prosenter': ('prosent',),
'prosentbasis': ('prosentbasis',),
'prosentbasisen': ('prosentbasis',),
'prosentbasisene': ('prosentbasis',),
'prosentbasiser': ('prosentbasis',),
'prosentdel': ('prosentdel',),
'prosentdelen': ('prosentdel',),
'prosentdelene': ('prosentdel',),
'prosentdeler': ('prosentdel',),
'prosentenhet': ('prosentenhet',),
'prosentenheten': ('prosentenhet',),
'prosentenhetene': ('prosentenhet',),
'prosentenheter': ('prosentenhet',),
'prosentinnhold': ('prosentinnhold',),
'prosentinnholda': ('prosentinnhold',),
'prosentinnholdene': ('prosentinnhold',),
'prosentinnholdet': ('prosentinnhold',),
'prosentkjører': ('prosentkjører',),
'prosentkjørere': ('prosentkjører',),
'prosentkjøreren': ('prosentkjører',),
'prosentkjørerer': ('prosentkjører',),
'prosentkjørerne': ('prosentkjører',),
'prosentlapp': ('prosentlapp',),
'prosentlappen': ('prosentlapp',),
'prosentlappene': ('prosentlapp',),
'prosentlapper': ('prosentlapp',),
'prosentligning': ('prosentligning',),
'prosentligninga': ('prosentligning',),
'prosentligningen': ('prosentligning',),
'prosentligningene': ('prosentligning',),
'prosentligninger': ('prosentligning',),
'prosentlikning': ('prosentlikning',),
'prosentlikninga': ('prosentlikning',),
'prosentlikningen': ('prosentlikning',),
'prosentlikningene': ('prosentlikning',),
'prosentlikninger': ('prosentlikning',),
'prosentpoeng': ('prosentpoeng',),
'prosentpoenga': ('prosentpoeng',),
'prosentpoengene': ('prosentpoeng',),
'prosentpoenger': ('prosentpoeng',),
'prosentpoenget': ('prosentpoeng',),
'prosentregning': ('prosentregning',),
'prosentregninga': ('prosentregning',),
'prosentregningen': ('prosentregning',),
'prosentregningene': ('prosentregning',),
'prosentregninger': ('prosentregning',),
'prosentrekning': ('prosentrekning',),
'prosentrekninga': ('prosentrekning',),
'prosentrekningen': ('prosentrekning',),
'prosentrekningene': ('prosentrekning',),
'prosentrekninger': ('prosentrekning',),
'prosentsats': ('prosentsats',),
'prosentsatsen': ('prosentsats',),
'prosentsatsene': ('prosentsats',),
'prosentsatser': ('prosentsats',),
'prosentskatt': ('prosentskatt',),
'prosentskatten': ('prosentskatt',),
'prosentskattene': ('prosentskatt',),
'prosentskatter': ('prosentskatt',),
'prosenttall': ('prosenttall',),
'prosenttalla': ('prosenttall',),
'prosenttallene': ('prosenttall',),
'prosenttallet': ('prosenttall',),
'prosenttrekk': ('prosenttrekk',),
'prosenttrekka': ('prosenttrekk',),
'prosenttrekkene': ('prosenttrekk',),
'prosenttrekket': ('prosenttrekk',),
'prosesjon': ('prosesjon',),
'prosesjonen': ('prosesjon',),
'prosesjonene': ('prosesjon',),
'prosesjoner': ('prosesjon',),
'prosess': ('prosess',),
'prosessen': ('prosess',),
'prosessene': ('prosess',),
'prosesser': ('prosess',),
'prosess-skjema': ('prosess-skjema',),
'prosess-skjemaene': ('prosess-skjema',),
'prosess-skjemaer': ('prosess-skjema',),
'prosess-skjemaet': ('prosess-skjema',),
'prosessfullmektig': ('prosessfullmektig',),
'prosessfullmektigen': ('prosessfullmektig',),
'prosessfullmektigene': ('prosessfullmektig',),
'prosessfullmektiger': ('prosessfullmektig',),
'prosessindustri': ('prosessindustri',),
'prosessindustrien': ('prosessindustri',),
'prosessindustriene': ('prosessindustri',),
'prosessindustrier': ('prosessindustri',),
'prosesskjema': ('prosesskjema',),
'prosesskjemaene': ('prosesskjema',),
'prosesskjemaer': ('prosesskjema',),
'prosesskjemaet': ('prosesskjema',),
'prosesskontroll': ('prosesskontroll',),
'prosesskontrollen': ('prosesskontroll',),
'prosesskontrollene': ('prosesskontroll',),
'prosesskontroller': ('prosesskontroll',),
'prosessmaker': ('prosessmaker',),
'prosessmakere': ('prosessmaker',),
'prosessmakeren': ('prosessmaker',),
'prosessmakerer': ('prosessmaker',),
'prosessmakerne': ('prosessmaker',),
'prosessor': ('prosessor',),
'prosessoren': ('prosessor',),
'prosessorene': ('prosessor',),
'prosessorer': ('prosessor',),
'prosjekt': ('prosjekt',),
'prosjekta': ('prosjekt',),
'prosjektene': ('prosjekt',),
'prosjekter': ('prosjekt',),
'prosjektet': ('prosjekt',),
'prosjektil': ('prosjektil',),
'prosjektila': ('prosjektil',),
'prosjektilene': ('prosjektil',),
'prosjektiler': ('prosjektil',),
'prosjektilet': ('prosjektil',),
'prosjektmaker': ('prosjektmaker',),
'prosjektmakere': ('prosjektmaker',),
'prosjektmakeren': ('prosjektmaker',),
'prosjektmakerer': ('prosjektmaker',),
'prosjektmakerne': ('prosjektmaker',),
'prosjektør': ('prosjektør',),
'prosjektøren': ('prosjektør',),
'prosjektørene': ('prosjektør',),
'prosjektører': ('prosjektør',),
'proskripsjon': ('proskripsjon',),
'proskripsjonen': ('proskripsjon',),
'proskripsjonene': ('proskripsjon',),
'proskripsjoner': ('proskripsjon',),
'prosodi': ('prosodi',),
'prosodien': ('prosodi',),
'prosodiene': ('prosodi',),
'prosodier': ('prosodi',),
'prospekt': ('prospekt',),
'prospekta': ('prospekt',),
'prospektene': ('prospekt',),
'prospekter': ('prospekt',),
'prospektet': ('prospekt',),
'prospekter': ('prospekter',),
'prospektere': ('prospekter',),
'prospekteren': ('prospekter',),
'prospekterer': ('prospekter',),
'prospekterne': ('prospekter',),
'prospektkort': ('prospektkort',),
'prospektkorta': ('prospektkort',),
'prospektkortene': ('prospektkort',),
'prospektkortet': ('prospektkort',),
'prost': ('prost',),
'prosten': ('prost',),
'prostene': ('prost',),
'proster': ('prost',),
'prostata': ('prostata',),
'prostataen': ('prostata',),
'prostataene': ('prostata',),
'prostataer': ('prostata',),
'prosti': ('prosti',),
'prostia': ('prosti',),
'prostiene': ('prosti',),
'prostier': ('prosti',),
'prostiet': ('prosti',),
'prostitusjon': ('prostitusjon',),
'prostitusjonen': ('prostitusjon',),
'prostitusjonene': ('prostitusjon',),
'prostitusjoner': ('prostitusjon',),
'protactinium': ('protactinium',),
'protactiniuma': ('protactinium',),
'protactiniumene': ('protactinium',),
'protactiniumet': ('protactinium',),
'protagonist': ('protagonist',),
'protagonisten': ('protagonist',),
'protagonistene': ('protagonist',),
'protagonister': ('protagonist',),
'protein': ('protein',),
'proteina': ('protein',),
'proteinene': ('protein',),
'proteiner': ('protein',),
'proteinet': ('protein',),
'proteinfiber': ('proteinfiber',),
'proteinfibere': ('proteinfiber',),
'proteinfiberen': ('proteinfiber',),
'proteinfiberer': ('proteinfiber',),
'proteinfiberne': ('proteinfiber',),
'proteinfibre': ('proteinfiber',),
'proteinfibrene': ('proteinfiber',),
'proteinfibrer': ('proteinfiber',),
'proteksjon': ('proteksjon',),
'proteksjonen': ('proteksjon',),
'proteksjonene': ('proteksjon',),
'proteksjoner': ('proteksjon',),
'proteksjonisme': ('proteksjonisme',),
'proteksjonismen': ('proteksjonisme',),
'proteksjonismene': ('proteksjonisme',),
'proteksjonismer': ('proteksjonisme',),
'proteksjonist': ('proteksjonist',),
'proteksjonisten': ('proteksjonist',),
'proteksjonistene': ('proteksjonist',),
'proteksjonister': ('proteksjonist',),
'protektor': ('protektor',),
'protektoren': ('protektor',),
'protektorene': ('protektor',),
'protektorer': ('protektor',),
'protektorat': ('protektorat',),
'protektorata': ('protektorat',),
'protektoratene': ('protektorat',),
'protektorater': ('protektorat',),
'protektoratet': ('protektorat',),
'protese': ('protese',),
'protesen': ('protese',),
'protesene': ('protese',),
'proteser': ('protese',),
'protesjeen': ('protesjé',),
'protesjeene': ('protesjé',),
'protesjeer': ('protesjé',),
'protesjé': ('protesjé',),
'protesjéen': ('protesjé',),
'protesjéene': ('protesjé',),
'protesjéer': ('protesjé',),
'protest': ('protest',),
'protesten': ('protest',),
'protestene': ('protest',),
'protester': ('protest',),
'protestaksjon': ('protestaksjon',),
'protestaksjonen': ('protestaksjon',),
'protestaksjonene': ('protestaksjon',),
'protestaksjoner': ('protestaksjon',),
'protestant': ('protestant',),
'protestanten': ('protestant',),
'protestantene': ('protestant',),
'protestanter': ('protestant',),
'protestantisme': ('protestantisme',),
'protestantismen': ('protestantisme',),
'protestantismene': ('protestantisme',),
'protestantismer': ('protestantisme',),
'protestdag': ('protestdag',),
'protestdagen': ('protestdag',),
'protestdagene': ('protestdag',),
'protestdager': ('protestdag',),
'protestflagg': ('protestflagg',),
'protestflagga': ('protestflagg',),
'protestflaggene': ('protestflagg',),
'protestflagget': ('protestflagg',),
'protestmarsj': ('protestmarsj',),
'protestmarsjen': ('protestmarsj',),
'protestmarsjene': ('protestmarsj',),
'protestmarsjer': ('protestmarsj',),
'protestnote': ('protestnote',),
'protestnoten': ('protestnote',),
'protestnotene': ('protestnote',),
'protestnoter': ('protestnote',),
'protestsanger': ('protestsanger',),
'protestsangere': ('protestsanger',),
'protestsangeren': ('protestsanger',),
'protestsangerer': ('protestsanger',),
'protestsangerne': ('protestsanger',),
'protestveksel': ('protestveksel',),
'protestvekselen': ('protestveksel',),
'protestvekslene': ('protestveksel',),
'protestveksler': ('protestveksel',),
'protestvisa': ('protestvise',),
'protestvise': ('protestvise',),
'protestvisen': ('protestvise',),
'protestvisene': ('protestvise',),
'protestviser': ('protestvise',),
'protist': ('protist',),
'protisten': ('protist',),
'protistene': ('protist',),
'protister': ('protist',),
'protokoll': ('protokoll',),
'protokollen': ('protokoll',),
'protokollene': ('protokoll',),
'protokoller': ('protokoll',),
'protokollat': ('protokollat',),
'protokollata': ('protokollat',),
'protokollatene': ('protokollat',),
'protokollater': ('protokollat',),
'protokollatet': ('protokollat',),
'protokollfører': ('protokollfører',),
'protokollførere': ('protokollfører',),
'protokollføreren': ('protokollfører',),
'protokollførerer': ('protokollfører',),
'protokollførerne': ('protokollfører',),
'protokollsekretær': ('protokollsekretær',),
'protokollsekretæren': ('protokollsekretær',),
'protokollsekretærene': ('protokollsekretær',),
'protokollsekretærer': ('protokollsekretær',),
'protokollsjef': ('protokollsjef',),
'protokollsjefen': ('protokollsjef',),
'protokollsjefene': ('protokollsjef',),
'protokollsjefer': ('protokollsjef',),
'protokolltilførsel': ('protokolltilførsel',),
'protokolltilførselen': ('protokolltilførsel',),
'protokolltilførslene': ('protokolltilførsel',),
'protokolltilførsler': ('protokolltilførsel',),
'protokolltjeneste': ('protokolltjeneste',),
'protokolltjenesten': ('protokolltjeneste',),
'protokolltjenestene': ('protokolltjeneste',),
'protokolltjenester': ('protokolltjeneste',),
'protolytt': ('protolytt',),
'protolytten': ('protolytt',),
'protolyttene': ('protolytt',),
'protolytter': ('protolytt',),
'proton': ('proton',),
'protona': ('proton',),
'protonene': ('proton',),
'protoner': ('proton',),
'protonet': ('proton',),
'protoplasma': ('protoplasma',),
'protoplasmaene': ('protoplasma',),
'protoplasmaer': ('protoplasma',),
'protoplasmaet': ('protoplasma',),
'prototyp': ('prototyp',),
'prototypen': ('prototyp',),
'prototypene': ('prototyp',),
'prototyper': ('prototyp',),
'protozo': ('protozo',),
'protozoen': ('protozo',),
'protozoene': ('protozo',),
'protozoer': ('protozo',),
'prov': ('prov',),
'prova': ('prov',),
'provene': ('prov',),
'provet': ('prov',),
'provençaler': ('provençaler',),
'provençalere': ('provençaler',),
'provençaleren': ('provençaler',),
'provençalerer': ('provençaler',),
'provençalerne': ('provençaler',),
'provençalsk': ('provençalsk',),
'provençalsken': ('provençalsk',),
'provençalskene': ('provençalsk',),
'provençalsker': ('provençalsk',),
'proveniens': ('proveniens',),
'proveniensen': ('proveniens',),
'proveniensene': ('proveniens',),
'provenienser': ('proveniens',),
'provent': ('provent',),
'proventa': ('provent',),
'proventene': ('provent',),
'proventer': ('provent',),
'proventet': ('provent',),
'proveny': ('proveny',),
'provenya': ('proveny',),
'provenyene': ('proveny',),
'provenyer': ('proveny',),
'provenyet': ('proveny',),
'proverb': ('proverb',),
'proverba': ('proverb',),
'proverbene': ('proverb',),
'proverber': ('proverb',),
'proverbet': ('proverb',),
'proviant': ('proviant',),
'provianten': ('proviant',),
'proviantene': ('proviant',),
'provianter': ('proviant',),
'provins': ('provins',),
'provinsen': ('provins',),
'provinsene': ('provins',),
'provinser': ('provins',),
'provinsby': ('provinsby',),
'provinsbyen': ('provinsby',),
'provinsbyene': ('provinsby',),
'provinsbyer': ('provinsby',),
'provinsforhold': ('provinsforhold',),
'provinsforholda': ('provinsforhold',),
'provinsforholdene': ('provinsforhold',),
'provinsforholdet': ('provinsforhold',),
'provinsialisme': ('provinsialisme',),
'provinsialismen': ('provinsialisme',),
'provinsialismene': ('provinsialisme',),
'provinsialismer': ('provinsialisme',),
'provisjon': ('provisjon',),
'provisjonen': ('provisjon',),
'provisjonene': ('provisjon',),
'provisjoner': ('provisjon',),
'provisjonsbasis': ('provisjonsbasis',),
'provisjonsbasisen': ('provisjonsbasis',),
'provisjonsbasisene': ('provisjonsbasis',),
'provisjonsbasiser': ('provisjonsbasis',),
'provisor': ('provisor',),
'provisoren': ('provisor',),
'provisorene': ('provisor',),
'provisorer': ('provisor',),
'provisoria': ('provisorium',),
'provisoriene': ('provisorium',),
'provisorier': ('provisorium',),
'provisoriet': ('provisorium',),
'provisorium': ('provisorium',),
'provo': ('provo',),
'provoen': ('provo',),
'provoene': ('provo',),
'provoer': ('provo',),
'provokasjon': ('provokasjon',),
'provokasjonen': ('provokasjon',),
'provokasjonene': ('provokasjon',),
'provokasjoner': ('provokasjon',),
'provokatør': ('provokatør',),
'provokatøren': ('provokatør',),
'provokatørene': ('provokatør',),
'provokatører': ('provokatør',),
'prunk': ('prunk',),
'prunken': ('prunk',),
'prunkene': ('prunk',),
'prunker': ('prunk',),
'prupp': ('prupp',),
'pruppen': ('prupp',),
'pruppene': ('prupp',),
'prupper': ('prupp',),
'prutingsmonn': ('prutingsmonn',),
'prutingsmonna': ('prutingsmonn',),
'prutingsmonnen': ('prutingsmonn',),
'prutingsmonnene': ('prutingsmonn',),
'prutingsmonner': ('prutingsmonn',),
'prutingsmonnet': ('prutingsmonn',),
'prutningsmonn': ('prutningsmonn',),
'prutningsmonna': ('prutningsmonn',),
'prutningsmonnen': ('prutningsmonn',),
'prutningsmonnene': ('prutningsmonn',),
'prutningsmonner': ('prutningsmonn',),
'prutningsmonnet': ('prutningsmonn',),
'pryd': ('pryd',),
'pryden': ('pryd',),
'prydene': ('pryd',),
'pryder': ('pryd',),
'prydbusk': ('prydbusk',),
'prydbusken': ('prydbusk',),
'prydbuskene': ('prydbusk',),
'prydbusker': ('prydbusk',),
'prydbønna': ('prydbønne',),
'prydbønne': ('prydbønne',),
'prydbønnen': ('prydbønne',),
'prydbønnene': ('prydbønne',),
'prydbønner': ('prydbønne',),
'prydelse': ('prydelse',),
'prydelsen': ('prydelse',),
'prydelsene': ('prydelse',),
'prydelser': ('prydelse',),
'prydkvede': ('prydkvede',),
'prydkveden': ('prydkvede',),
'prydkvedene': ('prydkvede',),
'prydkveder': ('prydkvede',),
'prydnad': ('prydnad',),
'prydnaden': ('prydnad',),
'prydnadene': ('prydnad',),
'prydnader': ('prydnad',),
'prydplanta': ('prydplante',),
'prydplante': ('prydplante',),
'prydplanten': ('prydplante',),
'prydplantene': ('prydplante',),
'prydplanter': ('prydplante',),
'prydsøm': ('prydsøm',),
'prydsømmen': ('prydsøm',),
'prydsømmene': ('prydsøm',),
'prydsømmer': ('prydsøm',),
'prygelknabe': ('prygelknabe',),
'prygelknaben': ('prygelknabe',),
'prygelknabene': ('prygelknabe',),
'prygelknaber': ('prygelknabe',),
'pryl': ('pryl',),
'pryla': ('pryl',),
'prylen': ('pryl',),
'prylene': ('pryl',),
'pryler': ('pryl',),
'prylet': ('pryl',),
'prylert': ('prylert',),
'prylerten': ('prylert',),
'prylertene': ('prylert',),
'prylerter': ('prylert',),
'prylestraff': ('prylestraff',),
'prylestraffen': ('prylestraff',),
'prylestraffene': ('prylestraff',),
'prylestraffer': ('prylestraff',),
'prås': ('prås',),
'pråsen': ('prås',),
'pråsene': ('prås',),
'pråser': ('prås',),
'prærie': ('prærie',),
'prærien': ('prærie',),
'præriene': ('prærie',),
'prærier': ('prærie',),
'præriebrann': ('præriebrann',),
'præriebrannen': ('præriebrann',),
'præriebrannene': ('præriebrann',),
'præriebranner': ('præriebrann',),
'præriehund': ('præriehund',),
'præriehunden': ('præriehund',),
'præriehundene': ('præriehund',),
'præriehunder': ('præriehund',),
'prærieulv': ('prærieulv',),
'prærieulven': ('prærieulv',),
'prærieulvene': ('prærieulv',),
'prærieulver': ('prærieulv',),
'prærievogn': ('prærievogn',),
'prærievogna': ('prærievogn',),
'prærievognen': ('prærievogn',),
'prærievognene': ('prærievogn',),
'prærievogner': ('prærievogn',),
'prøva': ('prøve',),
'prøve': ('prøve',),
'prøven': ('prøve',),
'prøvene': ('prøve',),
'prøver': ('prøve',),
'prøveabonnement': ('prøveabonnement',),
'prøveabonnementa': ('prøveabonnement',),
'prøveabonnementene': ('prøveabonnement',),
'prøveabonnementer': ('prøveabonnement',),
'prøveabonnementet': ('prøveabonnement',),
'prøveavstemning': ('prøveavstemning',),
'prøveavstemninga': ('prøveavstemning',),
'prøveavstemningen': ('prøveavstemning',),
'prøveavstemningene': ('prøveavstemning',),
'prøveavstemninger': ('prøveavstemning',),
'prøveballong': ('prøveballong',),
'prøveballongen': ('prøveballong',),
'prøveballongene': ('prøveballong',),
'prøveballonger': ('prøveballong',),
'prøvebilda': ('prøvebilde',),
'prøvebilde': ('prøvebilde',),
'prøvebildene': ('prøvebilde',),
'prøvebilder': ('prøvebilde',),
'prøvebildet': ('prøvebilde',),
'prøvebok': ('prøvebok',),
'prøveboka': ('prøvebok',),
'prøveboken': ('prøvebok',),
'prøvebøkene': ('prøvebok',),
'prøvebøker': ('prøvebok',),
'prøvedrift': ('prøvedrift',),
'prøvedrifta': ('prøvedrift',),
'prøvedriften': ('prøvedrift',),
'prøvedriftene': ('prøvedrift',),
'prøvedrifter': ('prøvedrift',),
'prøveeksemplar': ('prøveeksemplar',),
'prøveeksemplara': ('prøveeksemplar',),
'prøveeksemplarene': ('prøveeksemplar',),
'prøveeksemplarer': ('prøveeksemplar',),
'prøveeksemplaret': ('prøveeksemplar',),
'prøveflyger': ('prøveflyger',),
'prøveflygere': ('prøveflyger',),
'prøveflygeren': ('prøveflyger',),
'prøveflygerer': ('prøveflyger',),
'prøveflygerne': ('prøveflyger',),
'prøveforelesning': ('prøveforelesning',),
'prøveforelesninga': ('prøveforelesning',),
'prøveforelesningen': ('prøveforelesning',),
'prøveforelesningene': ('prøveforelesning',),
'prøveforelesninger': ('prøveforelesning',),
'prøvehopp': ('prøvehopp',),
'prøvehoppa': ('prøvehopp',),
'prøvehoppene': ('prøvehopp',),
'prøvehoppet': ('prøvehopp',),
'prøvehopper': ('prøvehopper',),
'prøvehoppere': ('prøvehopper',),
'prøvehopperen': ('prøvehopper',),
'prøvehopperer': ('prøvehopper',),
'prøvehopperne': ('prøvehopper',),
'prøveklut': ('prøveklut',),
'prøvekluten': ('prøveklut',),
'prøveklutene': ('prøveklut',),
'prøvekluter': ('prøveklut',),
'prøvelse': ('prøvelse',),
'prøvelsen': ('prøvelse',),
'prøvelsene': ('prøvelse',),
'prøvelser': ('prøvelse',),
'prøvelsestid': ('prøvelsestid',),
'prøvelsestida': ('prøvelsestid',),
'prøvelsestiden': ('prøvelsestid',),
'prøvelsestidene': ('prøvelsestid',),
'prøvelsestider': ('prøvelsestid',),
'prøveløslatelse': ('prøveløslatelse',),
'prøveløslatelsen': ('prøveløslatelse',),
'prøveløslatelsene': ('prøveløslatelse',),
'prøveløslatelser': ('prøveløslatelse',),
'prøveløslating': ('prøveløslating',),
'prøveløslatinga': ('prøveløslating',),
'prøveløslatingen': ('prøveløslating',),
'prøveløslatingene': ('prøveløslating',),
'prøveløslatinger': ('prøveløslating',),
'prøvemåltid': ('prøvemåltid',),
'prøvemåltida': ('prøvemåltid',),
'prøvemåltidene': ('prøvemåltid',),
'prøvemåltider': ('prøvemåltid',),
'prøvemåltidet': ('prøvemåltid',),
'prøvenummer': ('prøvenummer',),
'prøvenummeret': ('prøvenummer',),
'prøvenumra': ('prøvenummer',),
'prøvenumre': ('prøvenummer',),
'prøvenumrene': ('prøvenummer',),
'prøverom': ('prøverom',),
'prøveromma': ('prøverom',),
'prøverommene': ('prøverom',),
'prøverommet': ('prøverom',),
'prøverør': ('prøverør',),
'prøverøra': ('prøverør',),
'prøverørene': ('prøverør',),
'prøverøret': ('prøverør',),
'prøverørsbarn': ('prøverørsbarn',),
'prøverørsbarna': ('prøverørsbarn',),
'prøverørsbarnene': ('prøverørsbarn',),
'prøverørsbarnet': ('prøverørsbarn',),
'prøvesak': ('prøvesak',),
'prøvesaka': ('prøvesak',),
'prøvesaken': ('prøvesak',),
'prøvesakene': ('prøvesak',),
'prøvesaker': ('prøvesak',),
'prøvesida': ('prøveside',),
'prøveside': ('prøveside',),
'prøvesiden': ('prøveside',),
'prøvesidene': ('prøveside',),
'prøvesider': ('prøveside',),
'prøveskilt': ('prøveskilt',),
'prøveskilta': ('prøveskilt',),
'prøveskiltene': ('prøveskilt',),
'prøveskilter': ('prøveskilt',),
'prøveskiltet': ('prøveskilt',),
'prøvestans': ('prøvestans',),
'prøvestansen': ('prøvestans',),
'prøvestansene': ('prøvestans',),
'prøvestanser': ('prøvestans',),
'prøvestein': ('prøvestein',),
'prøvesteinen': ('prøvestein',),
'prøvesteinene': ('prøvestein',),
'prøvesteiner': ('prøvestein',),
'prøvetaing': ('prøvetaing',),
'prøvetainga': ('prøvetaing',),
'prøvetaingen': ('prøvetaing',),
'prøvetaingene': ('prøvetaing',),
'prøvetainger': ('prøvetaing',),
'prøvetaking': ('prøvetaking',),
'prøvetakinga': ('prøvetaking',),
'prøvetakingen': ('prøvetaking',),
'prøvetakingene': ('prøvetaking',),
'prøvetakinger': ('prøvetaking',),
'prøvetid': ('prøvetid',),
'prøvetida': ('prøvetid',),
'prøvetiden': ('prøvetid',),
'prøvetidene': ('prøvetid',),
'prøvetider': ('prøvetid',),
'prøvetrykk': ('prøvetrykk',),
'prøvetrykka': ('prøvetrykk',),
'prøvetrykkene': ('prøvetrykk',),
'prøvetrykket': ('prøvetrykk',),
'prøvevotering': ('prøvevotering',),
'prøvevoteringa': ('prøvevotering',),
'prøvevoteringen': ('prøvevotering',),
'prøvevoteringene': ('prøvevotering',),
'prøvevoteringer': ('prøvevotering',),
'prøving': ('prøving',),
'prøvinga': ('prøving',),
'prøvingen': ('prøving',),
'prøvingene': ('prøving',),
'prøvinger': ('prøving',),
'prøysser': ('prøysser',),
'prøyssere': ('prøysser',),
'prøysseren': ('prøysser',),
'prøysserer': ('prøysser',),
'prøysserne': ('prøysser',),
'prøysserånd': ('prøysserånd',),
'prøysserånden': ('prøysserånd',),
'prøysseråndene': ('prøysserånd',),
'prøysserånder': ('prøysserånd',),
'ps': ('ps',),
'psa': ('ps',),
'psene': ('ps',),
'pser': ('ps',),
'pset': ('ps',),
'pseudonym': ('pseudonym',),
'pseudonyma': ('pseudonym',),
'pseudonymene': ('pseudonym',),
'pseudonymer': ('pseudonym',),
'pseudonymet': ('pseudonym',),
'psevdonym': ('psevdonym',),
'psevdonyma': ('psevdonym',),
'psevdonymene': ('psevdonym',),
'psevdonymer': ('psevdonym',),
'psevdonymet': ('psevdonym',),
'psoriasis': ('psoriasis',),
'psoriasisen': ('psoriasis',),
'psoriasisene': ('psoriasis',),
'psoriasiser': ('psoriasis',),
'psoriatiker': ('psoriatiker',),
'psoriatikere': ('psoriatiker',),
'psoriatikeren': ('psoriatiker',),
'psoriatikerer': ('psoriatiker',),
'psoriatikerne': ('psoriatiker',),
'psyke': ('psyke',),
'psyken': ('psyke',),
'psykene': ('psyke',),
'psyker': ('psyke',),
'psykiater': ('psykiater',),
'psykiatere': ('psykiater',),
'psykiateren': ('psykiater',),
'psykiaterer': ('psykiater',),
'psykiaterne': ('psykiater',),
'psykiatri': ('psykiatri',),
'psykiatrien': ('psykiatri',),
'psykiatriene': ('psykiatri',),
'psykiatrier': ('psykiatri',),
'psykoanalysa': ('psykoanalyse',),
'psykoanalyse': ('psykoanalyse',),
'psykoanalysen': ('psykoanalyse',),
'psykoanalysene': ('psykoanalyse',),
'psykoanalyser': ('psykoanalyse',),
'psykoanalytiker': ('psykoanalytiker',),
'psykoanalytikere': ('psykoanalytiker',),
'psykoanalytikeren': ('psykoanalytiker',),
'psykoanalytikerer': ('psykoanalytiker',),
'psykoanalytikerne': ('psykoanalytiker',),
'psykolingvistikk': ('psykolingvistikk',),
'psykolingvistikken': ('psykolingvistikk',),
'psykolingvistikkene': ('psykolingvistikk',),
'psykolingvistikker': ('psykolingvistikk',),
'psykolog': ('psykolog',),
'psykologen': ('psykolog',),
'psykologene': ('psykolog',),
'psykologer': ('psykolog',),
'psykologi': ('psykologi',),
'psykologien': ('psykologi',),
'psykologiene': ('psykologi',),
'psykologier': ('psykologi',),
'psykopat': ('psykopat',),
'psykopaten': ('psykopat',),
'psykopatene': ('psykopat',),
'psykopater': ('psykopat',),
'psykopati': ('psykopati',),
'psykopatien': ('psykopati',),
'psykopatiene': ('psykopati',),
'psykopatier': ('psykopati',),
'psykose': ('psykose',),
'psykosen': ('psykose',),
'psykosene': ('psykose',),
'psykoser': ('psykose',),
'psykotekniker': ('psykotekniker',),
'psykoteknikere': ('psykotekniker',),
'psykoteknikeren': ('psykotekniker',),
'psykoteknikerer': ('psykotekniker',),
'psykoteknikerne': ('psykotekniker',),
'psykoteknikk': ('psykoteknikk',),
'psykoteknikken': ('psykoteknikk',),
'psykoteknikkene': ('psykoteknikk',),
'psykoteknikker': ('psykoteknikk',),
'psykoterapi': ('psykoterapi',),
'psykoterapien': ('psykoterapi',),
'psykoterapiene': ('psykoterapi',),
'psykoterapier': ('psykoterapi',),
'psykrometer': ('psykrometer',),
'psykrometeret': ('psykrometer',),
'psykrometra': ('psykrometer',),
'psykrometre': ('psykrometer',),
'psykrometrene': ('psykrometer',),
'psykrometret': ('psykrometer',),
'ptolemeiker': ('ptolemeiker',),
'ptolemeikere': ('ptolemeiker',),
'ptolemeikeren': ('ptolemeiker',),
'ptolemeikerer': ('ptolemeiker',),
'ptolemeikerne': ('ptolemeiker',),
'pub': ('pub',),
'puben': ('pub',),
'pubene': ('pub',),
'puber': ('pub',),
'pubertet': ('pubertet',),
'puberteten': ('pubertet',),
'pubertetene': ('pubertet',),
'puberteter': ('pubertet',),
'pubertetsalder': ('pubertetsalder',),
'pubertetsaldere': ('pubertetsalder',),
'pubertetsalderen': ('pubertetsalder',),
'pubertetsalderer': ('pubertetsalder',),
'pubertetsalderne': ('pubertetsalder',),
'pubertetsaldre': ('pubertetsalder',),
'pubertetsaldrene': ('pubertetsalder',),
'pubertetsaldrer': ('pubertetsalder',),
'pubes': ('pubes',),
'public relations': ('public relations',),
'publikasjon': ('publikasjon',),
'publikasjonen': ('publikasjon',),
'publikasjonene': ('publikasjon',),
'publikasjoner': ('publikasjon',),
'publikum': ('publikum',),
'publikuma': ('publikum',),
'publikumene': ('publikum',),
'publikumet': ('publikum',),
'publikumma': ('publikum',),
'publikummene': ('publikum',),
'publikummet': ('publikum',),
'publikummer': ('publikummer',),
'publikummere': ('publikummer',),
'publikummeren': ('publikummer',),
'publikummerer': ('publikummer',),
'publikummerne': ('publikummer',),
'publikumsfrieri': ('publikumsfrieri',),
'publikumsfrieria': ('publikumsfrieri',),
'publikumsfrieriene': ('publikumsfrieri',),
'publikumsfrierier': ('publikumsfrieri',),
'publikumsfrieriet': ('publikumsfrieri',),
'publisist': ('publisist',),
'publisisten': ('publisist',),
'publisistene': ('publisist',),
'publisister': ('publisist',),
'publisitet': ('publisitet',),
'publisiteten': ('publisitet',),
'publisitetene': ('publisitet',),
'publisiteter': ('publisitet',),
'puck': ('puck',),
'pucken': ('puck',),
'puckene': ('puck',),
'pucker': ('puck',),
'puddel': ('puddel',),
'puddelen': ('puddel',),
'pudlene': ('puddel',),
'pudler': ('puddel',),
'pudder': ('pudder',),
'puddera': ('pudder',),
'puddere': ('pudder',),
'pudderet': ('pudder',),
'pudderne': ('pudder',),
'pudderdåsa': ('pudderdåse',),
'pudderdåse': ('pudderdåse',),
'pudderdåsen': ('pudderdåse',),
'pudderdåsene': ('pudderdåse',),
'pudderdåser': ('pudderdåse',),
'puddersnø': ('puddersnø',),
'puddersnøen': ('puddersnø',),
'puddersnøene': ('puddersnø',),
'puddersnøer': ('puddersnø',),
'pudding': ('pudding',),
'puddingen': ('pudding',),
'puddingene': ('pudding',),
'puddinger': ('pudding',),
'pudrett': ('pudrett',),
'pudretten': ('pudrett',),
'pudrettene': ('pudrett',),
'pudretter': ('pudrett',),
'puerilitet': ('puerilitet',),
'pueriliteten': ('puerilitet',),
'puerilitetene': ('puerilitet',),
'pueriliteter': ('puerilitet',),
'puertoricaner': ('puertoricaner',),
'puertoricanere': ('puertoricaner',),
'puertoricaneren': ('puertoricaner',),
'puertoricanerer': ('puertoricaner',),
'puertoricanerne': ('puertoricaner',),
'puertorikaner': ('puertorikaner',),
'puertorikanere': ('puertorikaner',),
'puertorikaneren': ('puertorikaner',),
'puertorikanerer': ('puertorikaner',),
'puertorikanerne': ('puertorikaner',),
'puff': ('puff',),
'puffen': ('puff',),
'puffene': ('puff',),
'puffer': ('puff',),
'puff': ('puff',),
'puffen': ('puff',),
'puffene': ('puff',),
'puffer': ('puff',),
'puff': ('puff',),
'puffa': ('puff',),
'puffen': ('puff',),
'puffene': ('puff',),
'puffet': ('puff',),
'puger': ('puger',),
'pugere': ('puger',),
'pugeren': ('puger',),
'pugerer': ('puger',),
'pugerne': ('puger',),
'pugg': ('pugg',),
'pugga': ('pugg',),
'puggene': ('pugg',),
'pugget': ('pugg',),
'pugghest': ('pugghest',),
'pugghesten': ('pugghest',),
'pugghestene': ('pugghest',),
'pugghester': ('pugghest',),
'pugilist': ('pugilist',),
'pugilisten': ('pugilist',),
'pugilistene': ('pugilist',),
'pugilister': ('pugilist',),
'puke': ('puke',),
'puken': ('puke',),
'pukene': ('puke',),
'puker': ('puke',),
'pukk': ('pukk',),
'pukken': ('pukk',),
'pukkene': ('pukk',),
'pukker': ('pukk',),
'pukkel': ('pukkel',),
'pukkelen': ('pukkel',),
'puklene': ('pukkel',),
'pukler': ('pukkel',),
'pukkelrygg': ('pukkelrygg',),
'pukkelryggen': ('pukkelrygg',),
'pukkelryggene': ('pukkelrygg',),
'pukkelrygger': ('pukkelrygg',),
'pukkstein': ('pukkstein',),
'pukksteinen': ('pukkstein',),
'pukksteinene': ('pukkstein',),
'pukksteiner': ('pukkstein',),
'pukkverk': ('pukkverk',),
'pukkverka': ('pukkverk',),
'pukkverkene': ('pukkverk',),
'pukkverker': ('pukkverk',),
'pukkverket': ('pukkverk',),
'pulder': ('pulder',),
'puldere': ('pulder',),
'pulderen': ('pulder',),
'pulderne': ('pulder',),
'puldre': ('pulder',),
'puldrene': ('pulder',),
'puldrer': ('pulder',),
'pulje': ('pulje',),
'puljen': ('pulje',),
'puljene': ('pulje',),
'puljer': ('pulje',),
'pulk': ('pulk',),
'pulken': ('pulk',),
'pulkene': ('pulk',),
'pulker': ('pulk',),
'pull': ('pull',),
'pullen': ('pull',),
'pullene': ('pull',),
'puller': ('pull',),
'puller': ('puller',),
'pulleren': ('puller',),
'pullerene': ('puller',),
'pullerer': ('puller',),
'pullert': ('pullert',),
'pullerten': ('pullert',),
'pullertene': ('pullert',),
'pullerter': ('pullert',),
'pullover': ('pullover',),
'pullovere': ('pullover',),
'pulloveren': ('pullover',),
'pulloverer': ('pullover',),
'pulloverne': ('pullover',),
'pulp': ('pulp',),
'pulpen': ('pulp',),
'pulpene': ('pulp',),
'pulper': ('pulp',),
'pulpa': ('pulpa',),
'pulpaen': ('pulpa',),
'pulpaene': ('pulpa',),
'pulpaer': ('pulpa',),
'pulpitt': ('pulpitt',),
'pulpitten': ('pulpitt',),
'pulpittene': ('pulpitt',),
'pulpitter': ('pulpitt',),
'puls': ('puls',),
'pulsen': ('puls',),
'pulsene': ('puls',),
'pulser': ('puls',),
'pulsar': ('pulsar',),
'pulsaren': ('pulsar',),
'pulsarene': ('pulsar',),
'pulsarer': ('pulsar',),
'pulsator': ('pulsator',),
'pulsatoren': ('pulsator',),
'pulsatorene': ('pulsator',),
'pulsatorer': ('pulsator',),
'pulsslag': ('pulsslag',),
'pulsslaga': ('pulsslag',),
'pulsslagene': ('pulsslag',),
'pulsslaget': ('pulsslag',),
'pulsvante': ('pulsvante',),
'pulsvanten': ('pulsvante',),
'pulsvantene': ('pulsvante',),
'pulsvanter': ('pulsvante',),
'pulsåra': ('pulsåre',),
'pulsåre': ('pulsåre',),
'pulsåren': ('pulsåre',),
'pulsårene': ('pulsåre',),
'pulsårer': ('pulsåre',),
'pult': ('pult',),
'pulten': ('pult',),
'pultene': ('pult',),
'pulter': ('pult',),
'pulterkammer': ('pulterkammer',),
'pulterkammeret': ('pulterkammer',),
'pulterkamra': ('pulterkammer',),
'pulterkamre': ('pulterkammer',),
'pulterkamrene': ('pulterkammer',),
'pultost': ('pultost',),
'pultosten': ('pultost',),
'pultostene': ('pultost',),
'pultoster': ('pultost',),
'pulttak': ('pulttak',),
'pulttaka': ('pulttak',),
'pulttakene': ('pulttak',),
'pulttaket': ('pulttak',),
'pulver': ('pulver',),
'pulvera': ('pulver',),
'pulvere': ('pulver',),
'pulveret': ('pulver',),
'pulverne': ('pulver',),
'pulverkaffe': ('pulverkaffe',),
'pulverkaffen': ('pulverkaffe',),
'pulverkaffene': ('pulverkaffe',),
'pulverkaffer': ('pulverkaffe',),
'puma': ('puma',),
'pumaen': ('puma',),
'pumaene': ('puma',),
'pumaer': ('puma',),
'pumpa': ('pumpe',),
'pumpe': ('pumpe',),
'pumpen': ('pumpe',),
'pumpene': ('pumpe',),
'pumper': ('pumpe',),
'pumpemann': ('pumpemann',),
'pumpemannen': ('pumpemann',),
'pumpemenn': ('pumpemann',),
'pumpemennene': ('pumpemann',),
'pumpernikkel': ('pumpernikkel',),
'pumpernikkelen': ('pumpernikkel',),
'pumperniklene': ('pumpernikkel',),
'pumpernikler': ('pumpernikkel',),
'pumps': ('pumps',),
'pumpsen': ('pumps',),
'pumpsene': ('pumps',),
'punch': ('punch',),
'punchen': ('punch',),
'punchene': ('punch',),
'puncher': ('punch',),
'punch': ('punch',),
'punchen': ('punch',),
'punchene': ('punch',),
'puncher': ('punch',),
'punchemaskin': ('punchemaskin',),
'punchemaskina': ('punchemaskin',),
'punchemaskinen': ('punchemaskin',),
'punchemaskinene': ('punchemaskin',),
'punchemaskiner': ('punchemaskin',),
'puncheoperatør': ('puncheoperatør',),
'puncheoperatøren': ('puncheoperatør',),
'puncheoperatørene': ('puncheoperatør',),
'puncheoperatører': ('puncheoperatør',),
'punchingball': ('punchingball',),
'punchingballen': ('punchingball',),
'punchingballene': ('punchingball',),
'punchingballer': ('punchingball',),
'pund': ('pund',),
'punda': ('pund',),
'pundene': ('pund',),
'pundet': ('pund',),
'puner': ('puner',),
'punere': ('puner',),
'puneren': ('puner',),
'punerer': ('puner',),
'punerne': ('puner',),
'pung': ('pung',),
'pungen': ('pung',),
'pungene': ('pung',),
'punger': ('pung',),
'pungdyr': ('pungdyr',),
'pungdyra': ('pungdyr',),
'pungdyrene': ('pungdyr',),
'pungdyret': ('pungdyr',),
'pungrotta': ('pungrotte',),
'pungrotte': ('pungrotte',),
'pungrotten': ('pungrotte',),
'pungrottene': ('pungrotte',),
'pungrotter': ('pungrotte',),
'punksjon': ('punksjon',),
'punksjonen': ('punksjon',),
'punksjonene': ('punksjon',),
'punksjoner': ('punksjon',),
'punkt': ('punkt',),
'punkta': ('punkt',),
'punktene': ('punkt',),
'punkter': ('punkt',),
'punktet': ('punkt',),
'punkthus': ('punkthus',),
'punkthusa': ('punkthus',),
'punkthusene': ('punkthus',),
'punkthuset': ('punkthus',),
'punktskrift': ('punktskrift',),
'punktskrifta': ('punktskrift',),
'punktskriften': ('punktskrift',),
'punktskriftene': ('punktskrift',),
'punktskrifter': ('punktskrift',),
'punktstreik': ('punktstreik',),
'punktstreiken': ('punktstreik',),
'punktstreikene': ('punktstreik',),
'punktstreiker': ('punktstreik',),
'punktum': ('punktum',),
'punktuma': ('punktum',),
'punktumene': ('punktum',),
'punktumer': ('punktum',),
'punktumet': ('punktum',),
'punktur': ('punktur',),
'punkturen': ('punktur',),
'punkturene': ('punktur',),
'punkturer': ('punktur',),
'punsj': ('punsj',),
'punsjen': ('punsj',),
'punsjene': ('punsj',),
'punsjer': ('punsj',),
'punsjbolle': ('punsjbolle',),
'punsjbollen': ('punsjbolle',),
'punsjbollene': ('punsjbolle',),
'punsjboller': ('punsjbolle',),
'punsjebolle': ('punsjebolle',),
'punsjebollen': ('punsjebolle',),
'punsjebollene': ('punsjebolle',),
'punsjeboller': ('punsjebolle',),
'puntlær': ('puntlær',),
'puntlæra': ('puntlær',),
'puntlærene': ('puntlær',),
'puntlæret': ('puntlær',),
'puntlærsmage': ('puntlærsmage',),
'puntlærsmagen': ('puntlærsmage',),
'puntlærsmagene': ('puntlærsmage',),
'puntlærsmager': ('puntlærsmage',),
'puntlærsmave': ('puntlærsmave',),
'puntlærsmaven': ('puntlærsmave',),
'puntlærsmavene': ('puntlærsmave',),
'puntlærsmaver': ('puntlærsmave',),
'pupill': ('pupill',),
'pupillen': ('pupill',),
'pupillene': ('pupill',),
'pupiller': ('pupill',),
'pupp': ('pupp',),
'puppen': ('pupp',),
'puppene': ('pupp',),
'pupper': ('pupp',),
'puppa': ('puppe',),
'puppe': ('puppe',),
'puppen': ('puppe',),
'puppene': ('puppe',),
'pupper': ('puppe',),
'puppestadia': ('puppestadium',),
'puppestadiene': ('puppestadium',),
'puppestadier': ('puppestadium',),
'puppestadiet': ('puppestadium',),
'puppestadium': ('puppestadium',),
'pureen': ('puré',),
'pureene': ('puré',),
'pureer': ('puré',),
'puré': ('puré',),
'puréen': ('puré',),
'puréene': ('puré',),
'puréer': ('puré',),
'purgatoria': ('purgatorium',),
'purgatoriene': ('purgatorium',),
'purgatorier': ('purgatorium',),
'purgatoriet': ('purgatorium',),
'purgatorium': ('purgatorium',),
'purisme': ('purisme',),
'purismen': ('purisme',),
'purismene': ('purisme',),
'purismer': ('purisme',),
'purist': ('purist',),
'puristen': ('purist',),
'puristene': ('purist',),
'purister': ('purist',),
'puritaner': ('puritaner',),
'puritanere': ('puritaner',),
'puritaneren': ('puritaner',),
'puritanerer': ('puritaner',),
'puritanerne': ('puritaner',),
'puritanisme': ('puritanisme',),
'puritanismen': ('puritanisme',),
'puritanismene': ('puritanisme',),
'puritanismer': ('puritanisme',),
'purk': ('purk',),
'purken': ('purk',),
'purkene': ('purk',),
'purker': ('purk',),
'purka': ('purke',),
'purke': ('purke',),
'purken': ('purke',),
'purkene': ('purke',),
'purker': ('purke',),
'purl': ('purl',),
'purla': ('purl',),
'purlene': ('purl',),
'purlet': ('purl',),
'purpur': ('purpur',),
'purpura': ('purpur',),
'purpurene': ('purpur',),
'purpuret': ('purpur',),
'purpurkåpa': ('purpurkåpe',),
'purpurkåpe': ('purpurkåpe',),
'purpurkåpen': ('purpurkåpe',),
'purpurkåpene': ('purpurkåpe',),
'purpurkåper': ('purpurkåpe',),
'purre': ('purre',),
'purren': ('purre',),
'purrene': ('purre',),
'purrer': ('purre',),
'purrebrev': ('purrebrev',),
'purrebreva': ('purrebrev',),
'purrebrevene': ('purrebrev',),
'purrebrever': ('purrebrev',),
'purrebrevet': ('purrebrev',),
'purreløk': ('purreløk',),
'purreløken': ('purreløk',),
'purreløkene': ('purreløk',),
'purreløker': ('purreløk',),
'purreløksuppa': ('purreløksuppe',),
'purreløksuppe': ('purreløksuppe',),
'purreløksuppen': ('purreløksuppe',),
'purreløksuppene': ('purreløksuppe',),
'purreløksupper': ('purreløksuppe',),
'purser': ('purser',),
'pursere': ('purser',),
'purseren': ('purser',),
'purserer': ('purser',),
'purserne': ('purser',),
'pus': ('pus',),
'pusen': ('pus',),
'pusene': ('pus',),
'puser': ('pus',),
'pusekatt': ('pusekatt',),
'pusekatten': ('pusekatt',),
'pusekattene': ('pusekatt',),
'pusekatter': ('pusekatt',),
'puselanke': ('puselanke',),
'puselanken': ('puselanke',),
'puselankene': ('puselanke',),
'puselanker': ('puselanke',),
'push': ('push',),
'pusha': ('push',),
'pushen': ('push',),
'pushene': ('push',),
'pusher': ('push',),
'pushet': ('push',),
'pusher': ('pusher',),
'pushere': ('pusher',),
'pusheren': ('pusher',),
'pusherer': ('pusher',),
'pusherne': ('pusher',),
'pusleri': ('pusleri',),
'pusleria': ('pusleri',),
'pusleriene': ('pusleri',),
'puslerier': ('pusleri',),
'pusleriet': ('pusleri',),
'puslespell': ('puslespell',),
'puslespella': ('puslespell',),
'puslespellene': ('puslespell',),
'puslespellet': ('puslespell',),
'puslespill': ('puslespill',),
'puslespilla': ('puslespill',),
'puslespillene': ('puslespill',),
'puslespillet': ('puslespill',),
'pusling': ('pusling',),
'puslingen': ('pusling',),
'puslingene': ('pusling',),
'puslinger': ('pusling',),
'puss': ('puss',),
'pussen': ('puss',),
'pussene': ('puss',),
'pusser': ('puss',),
'puss': ('puss',),
'pussa': ('puss',),
'pussene': ('puss',),
'pusset': ('puss',),
'puss': ('puss',),
'pussa': ('puss',),
'pussen': ('puss',),
'pussene': ('puss',),
'pusser': ('puss',),
'pusset': ('puss',),
'pussegarn': ('pussegarn',),
'pussegarna': ('pussegarn',),
'pussegarnene': ('pussegarn',),
'pussegarnet': ('pussegarn',),
'pussekloss': ('pussekloss',),
'pusseklossen': ('pussekloss',),
'pusseklossene': ('pussekloss',),
'pusseklosser': ('pussekloss',),
'pusser': ('pusser',),
'pussere': ('pusser',),
'pusseren': ('pusser',),
'pusserer': ('pusser',),
'pusserne': ('pusser',),
'pusshøvel': ('pusshøvel',),
'pusshøvelen': ('pusshøvel',),
'pusshøvlene': ('pusshøvel',),
'pusshøvler': ('pusshøvel',),
'pust': ('pust',),
'pusten': ('pust',),
'pustene': ('pust',),
'puster': ('pust',),
'pust': ('pust',),
'pusta': ('pust',),
'pustene': ('pust',),
'pustet': ('pust',),
'pusterom': ('pusterom',),
'pusteromma': ('pusterom',),
'pusterommene': ('pusterom',),
'pusterommet': ('pusterom',),
'puszta': ('puszta',),
'pusztaen': ('puszta',),
'pusztaene': ('puszta',),
'pusztaer': ('puszta',),
'puta': ('pute',),
'pute': ('pute',),
'puten': ('pute',),
'putene': ('pute',),
'puter': ('pute',),
'putevar': ('putevar',),
'putevara': ('putevar',),
'putevarene': ('putevar',),
'putevaret': ('putevar',),
'putt': ('putt',),
'putten': ('putt',),
'puttene': ('putt',),
'putter': ('putt',),
'puttis': ('puttis',),
'puttisen': ('puttis',),
'puttisene': ('puttis',),
'puttiser': ('puttis',),
'pygmeen': ('pygmé',),
'pygmeene': ('pygmé',),
'pygmeer': ('pygmé',),
'pygmé': ('pygmé',),
'pygméen': ('pygmé',),
'pygméene': ('pygmé',),
'pygméer': ('pygmé',),
'pyjamas': ('pyjamas',),
'pyjamasen': ('pyjamas',),
'pyjamasene': ('pyjamas',),
'pyjamaser': ('pyjamas',),
'pykniker': ('pykniker',),
'pyknikere': ('pykniker',),
'pyknikeren': ('pykniker',),
'pyknikerer': ('pykniker',),
'pyknikerne': ('pykniker',),
'pyknometer': ('pyknometer',),
'pyknometeret': ('pyknometer',),
'pyknometra': ('pyknometer',),
'pyknometre': ('pyknometer',),
'pyknometrene': ('pyknometer',),
'pyknometret': ('pyknometer',),
'pyntedokka': ('pyntedokke',),
'pyntedokke': ('pyntedokke',),
'pyntedokken': ('pyntedokke',),
'pyntedokkene': ('pyntedokke',),
'pyntedokker': ('pyntedokke',),
'pyntedukka': ('pyntedukke',),
'pyntedukke': ('pyntedukke',),
'pyntedukken': ('pyntedukke',),
'pyntedukkene': ('pyntedukke',),
'pyntedukker': ('pyntedukke',),
'pyntelist': ('pyntelist',),
'pyntelista': ('pyntelist',),
'pyntelisten': ('pyntelist',),
'pyntelistene': ('pyntelist',),
'pyntelister': ('pyntelist',),
'pyoreen': ('pyoré',),
'pyoreene': ('pyoré',),
'pyoreer': ('pyoré',),
'pyoré': ('pyoré',),
'pyoréen': ('pyoré',),
'pyoréene': ('pyoré',),
'pyoréer': ('pyoré',),
'pyorea': ('pyorea',),
'pyoreaen': ('pyorea',),
'pyoreaene': ('pyorea',),
'pyoreaer': ('pyorea',),
'pyramide': ('pyramide',),
'pyramiden': ('pyramide',),
'pyramidene': ('pyramide',),
'pyramider': ('pyramide',),
'pyramideblokk': ('pyramideblokk',),
'pyramideblokka': ('pyramideblokk',),
'pyramideblokken': ('pyramideblokk',),
'pyramideblokkene': ('pyramideblokk',),
'pyramideblokker': ('pyramideblokk',),
'pyramidespell': ('pyramidespell',),
'pyramidespella': ('pyramidespell',),
'pyramidespellene': ('pyramidespell',),
'pyramidespellet': ('pyramidespell',),
'pyramidespill': ('pyramidespill',),
'pyramidespilla': ('pyramidespill',),
'pyramidespillene': ('pyramidespill',),
'pyramidespillet': ('pyramidespill',),
'pyramidetelt': ('pyramidetelt',),
'pyramidetelta': ('pyramidetelt',),
'pyramideteltene': ('pyramidetelt',),
'pyramidetelter': ('pyramidetelt',),
'pyramideteltet': ('pyramidetelt',),
'pyroman': ('pyroman',),
'pyromanen': ('pyroman',),
'pyromanene': ('pyroman',),
'pyromaner': ('pyroman',),
'pyromani': ('pyromani',),
'pyromanien': ('pyromani',),
'pyromaniene': ('pyromani',),
'pyromanier': ('pyromani',),
'pyrometer': ('pyrometer',),
'pyrometeret': ('pyrometer',),
'pyrometra': ('pyrometer',),
'pyrometre': ('pyrometer',),
'pyrometrene': ('pyrometer',),
'pyrometret': ('pyrometer',),
'pyroteknikk': ('pyroteknikk',),
'pyroteknikken': ('pyroteknikk',),
'pyroteknikkene': ('pyroteknikk',),
'pyroteknikker': ('pyroteknikk',),
'pyrrhosseier': ('pyrrhosseier',),
'pyrrhosseiere': ('pyrrhosseier',),
'pyrrhosseieren': ('pyrrhosseier',),
'pyrrhosseierne': ('pyrrhosseier',),
'pyrrhosseire': ('pyrrhosseier',),
'pyrrhosseirene': ('pyrrhosseier',),
'pyrrhosseirer': ('pyrrhosseier',),
'pysa': ('pyse',),
'pyse': ('pyse',),
'pysen': ('pyse',),
'pysene': ('pyse',),
'pyser': ('pyse',),
'pysj': ('pysj',),
'pysjen': ('pysj',),
'pysjene': ('pysj',),
'pysjer': ('pysj',),
'pytagoreer': ('pytagoreer',),
'pytagoreere': ('pytagoreer',),
'pytagoreeren': ('pytagoreer',),
'pytagoreerer': ('pytagoreer',),
'pytagoreerne': ('pytagoreer',),
'pyton': ('pyton',),
'pytonen': ('pyton',),
'pytonene': ('pyton',),
'pytoner': ('pyton',),
'pytonslange': ('pytonslange',),
'pytonslangen': ('pytonslange',),
'pytonslangene': ('pytonslange',),
'pytonslanger': ('pytonslange',),
'pytt': ('pytt',),
'pytten': ('pytt',),
'pyttene': ('pytt',),
'pytter': ('pytt',),
'pytt-i-panne': ('pytt-i-panne',),
'pytt-i-pannen': ('pytt-i-panne',),
'pytt-i-pannene': ('pytt-i-panne',),
'pytt-i-panner': ('pytt-i-panne',),
'pyttand': ('pyttand',),
'pyttanda': ('pyttand',),
'pyttanden': ('pyttand',),
'pyttendene': ('pyttand',),
'pyttender': ('pyttand',),
'pyttipanne': ('pyttipanne',),
'pyttipannen': ('pyttipanne',),
'pyttipannene': ('pyttipanne',),
'pyttipanner': ('pyttipanne',),
'påbud': ('påbud',),
'påbuda': ('påbud',),
'påbudene': ('påbud',),
'påbudet': ('påbud',),
'påbygg': ('påbygg',),
'påbygga': ('påbygg',),
'påbyggene': ('påbygg',),
'påbygget': ('påbygg',),
'påbyggingskurs': ('påbyggingskurs',),
'påbyggingskursa': ('påbyggingskurs',),
'påbyggingskursene': ('påbyggingskurs',),
'påbyggingskurser': ('påbyggingskurs',),
'påbyggingskurset': ('påbyggingskurs',),
'påbyggingskursene': ('påbyggingskursus',),
'påbyggingskurser': ('påbyggingskursus',),
'påbyggingskursus': ('påbyggingskursus',),
'påbyggingskursuset': ('påbyggingskursus',),
'pådriver': ('pådriver',),
'pådrivere': ('pådriver',),
'pådriveren': ('pådriver',),
'pådriverer': ('pådriver',),
'pådriverne': ('pådriver',),
'påfugl': ('påfugl',),
'påfuglen': ('påfugl',),
'påfuglene': ('påfugl',),
'påfugler': ('påfugl',),
'påfuglfjær': ('påfuglfjær',),
'påfuglfjæra': ('påfuglfjær',),
'påfuglfjæren': ('påfuglfjær',),
'påfuglfjærene': ('påfuglfjær',),
'påfuglfjærer': ('påfuglfjær',),
'påfuglfjør': ('påfuglfjør',),
'påfuglfjøra': ('påfuglfjør',),
'påfuglfjøren': ('påfuglfjør',),
'påfuglfjørene': ('påfuglfjør',),
'påfuglfjører': ('påfuglfjør',),
'påfunn': ('påfunn',),
'påfunna': ('påfunn',),
'påfunnene': ('påfunn',),
'påfunnet': ('påfunn',),
'påfyll': ('påfyll',),
'påfylla': ('påfyll',),
'påfyllene': ('påfyll',),
'påfyllet': ('påfyll',),
'pågang': ('pågang',),
'pågangen': ('pågang',),
'pågangene': ('pågang',),
'påganger': ('pågang',),
'pågangsmot': ('pågangsmot',),
'pågangsmota': ('pågangsmot',),
'pågangsmotene': ('pågangsmot',),
'pågangsmotet': ('pågangsmot',),
'pågåenhet': ('pågåenhet',),
'pågåenheta': ('pågåenhet',),
'pågåenheten': ('pågåenhet',),
'pågåenhetene': ('pågåenhet',),
'pågåenheter': ('pågåenhet',),
'påheng': ('påheng',),
'påhenga': ('påheng',),
'påhengene': ('påheng',),
'påhenget': ('påheng',),
'påhengsmotor': ('påhengsmotor',),
'påhengsmotoren': ('påhengsmotor',),
'påhengsmotorene': ('påhengsmotor',),
'påhengsmotorer': ('påhengsmotor',),
'påhitt': ('påhitt',),
'påhitta': ('påhitt',),
'påhittene': ('påhitt',),
'påhittet': ('påhitt',),
'påholdenhet': ('påholdenhet',),
'påholdenheta': ('påholdenhet',),
'påholdenheten': ('påholdenhet',),
'påholdenhetene': ('påholdenhet',),
'påholdenheter': ('påholdenhet',),
'påhør': ('påhør',),
'påhøra': ('påhør',),
'påhørene': ('påhør',),
'påhøret': ('påhør',),
'påk': ('påk',),
'påken': ('påk',),
'påkene': ('påk',),
'påker': ('påk',),
'påkjenning': ('påkjenning',),
'påkjenninga': ('påkjenning',),
'påkjenningen': ('påkjenning',),
'påkjenningene': ('påkjenning',),
'påkjenninger': ('påkjenning',),
'påkjøring': ('påkjøring',),
'påkjøringa': ('påkjøring',),
'påkjøringen': ('påkjøring',),
'påkjøringene': ('påkjøring',),
'påkjøringer': ('påkjøring',),
'påkjørsel': ('påkjørsel',),
'påkjørselen': ('påkjørsel',),
'påkjørsla': ('påkjørsel',),
'påkjørslene': ('påkjørsel',),
'påkjørsler': ('påkjørsel',),
'påkledning': ('påkledning',),
'påkledninga': ('påkledning',),
'påkledningen': ('påkledning',),
'påkledningene': ('påkledning',),
'påkledninger': ('påkledning',),
'påkrav': ('påkrav',),
'påkrava': ('påkrav',),
'påkravene': ('påkrav',),
'påkravet': ('påkrav',),
'pålandsvind': ('pålandsvind',),
'pålandsvinden': ('pålandsvind',),
'pålandsvindene': ('pålandsvind',),
'pålandsvinder': ('pålandsvind',),
'påle': ('påle',),
'pålen': ('påle',),
'pålene': ('påle',),
'påler': ('påle',),
'pålegg': ('pålegg',),
'pålegga': ('pålegg',),
'påleggene': ('pålegg',),
'pålegget': ('pålegg',),
'pålsmesse': ('pålsmesse',),
'pålydende': ('pålydende',),
'pålydendene': ('pålydende',),
'pålydender': ('pålydende',),
'pålydendet': ('pålydende',),
'påmelding': ('påmelding',),
'påmeldinga': ('påmelding',),
'påmeldingen': ('påmelding',),
'påmeldingene': ('påmelding',),
'påmeldinger': ('påmelding',),
'påminnelse': ('påminnelse',),
'påminnelsen': ('påminnelse',),
'påminnelsene': ('påminnelse',),
'påminnelser': ('påminnelse',),
'påminning': ('påminning',),
'påminninga': ('påminning',),
'påminningen': ('påminning',),
'påminningene': ('påminning',),
'påminninger': ('påminning',),
'påpakning': ('påpakning',),
'påpakninga': ('påpakning',),
'påpakningen': ('påpakning',),
'påpakningene': ('påpakning',),
'påpakninger': ('påpakning',),
'påplussing': ('påplussing',),
'påplussinga': ('påplussing',),
'påplussingen': ('påplussing',),
'påplussingene': ('påplussing',),
'påplussinger': ('påplussing',),
'pårørende': ('pårørende',),
'pårørenden': ('pårørende',),
'pårørendene': ('pårørende',),
'pårørender': ('pårørende',),
'påska': ('påske',),
'påske': ('påske',),
'påsken': ('påske',),
'påskene': ('påske',),
'påsker': ('påske',),
'påskeaften': ('påskeaften',),
'påskeaftenen': ('påskeaften',),
'påskeaftenene': ('påskeaften',),
'påskeaftener': ('påskeaften',),
'påskedag': ('påskedag',),
'påskedagen': ('påskedag',),
'påskedagene': ('påskedag',),
'påskedager': ('påskedag',),
'påskeegg': ('påskeegg',),
'påskeegga': ('påskeegg',),
'påskeeggene': ('påskeegg',),
'påskeegget': ('påskeegg',),
'påskefjell': ('påskefjell',),
'påskefjella': ('påskefjell',),
'påskefjellene': ('påskefjell',),
'påskefjellet': ('påskefjell',),
'påskelilja': ('påskelilje',),
'påskelilje': ('påskelilje',),
'påskeliljen': ('påskelilje',),
'påskeliljene': ('påskelilje',),
'påskeliljer': ('påskelilje',),
'påskemorgen': ('påskemorgen',),
'påskemorgenen': ('påskemorgen',),
'påskemorgenene': ('påskemorgen',),
'påskemorgener': ('påskemorgen',),
'påskemorgnene': ('påskemorgen',),
'påskemorgner': ('påskemorgen',),
'påskeuka': ('påskeuke',),
'påskeuke': ('påskeuke',),
'påskeuken': ('påskeuke',),
'påskeukene': ('påskeuke',),
'påskeuker': ('påskeuke',),
'påskeveka': ('påskeveke',),
'påskeveke': ('påskeveke',),
'påskeveken': ('påskeveke',),
'påskevekene': ('påskeveke',),
'påskeveker': ('påskeveke',),
'påskjønnelse': ('påskjønnelse',),
'påskjønnelsen': ('påskjønnelse',),
'påskjønnelsene': ('påskjønnelse',),
'påskjønnelser': ('påskjønnelse',),
'påskott': ('påskott',),
'påskotta': ('påskott',),
'påskottene': ('påskott',),
'påskottet': ('påskott',),
'påskrift': ('påskrift',),
'påskrifta': ('påskrift',),
'påskriften': ('påskrift',),
'påskriftene': ('påskrift',),
'påskrifter': ('påskrift',),
'påskudd': ('påskudd',),
'påskudda': ('påskudd',),
'påskuddene': ('påskudd',),
'påskuddet': ('påskudd',),
'påslag': ('påslag',),
'påslaga': ('påslag',),
'påslagene': ('påslag',),
'påslaget': ('påslag',),
'påstand': ('påstand',),
'påstanden': ('påstand',),
'påstandene': ('påstand',),
'påstander': ('påstand',),
'påstiging': ('påstiging',),
'påstiginga': ('påstiging',),
'påstigingen': ('påstiging',),
'påstigingene': ('påstiging',),
'påstiginger': ('påstiging',),
'påstigning': ('påstigning',),
'påstigninga': ('påstigning',),
'påstigningen': ('påstigning',),
'påstigningene': ('påstigning',),
'påstigninger': ('påstigning',),
'påsyn': ('påsyn',),
'påsyna': ('påsyn',),
'påsynene': ('påsyn',),
'påsynet': ('påsyn',),
'påtale': ('påtale',),
'påtalen': ('påtale',),
'påtalene': ('påtale',),
'påtaler': ('påtale',),
'påtalemyndighet': ('påtalemyndighet',),
'påtalemyndigheta': ('påtalemyndighet',),
'påtalemyndigheten': ('påtalemyndighet',),
'påtalemyndighetene': ('påtalemyndighet',),
'påtalemyndigheter': ('påtalemyndighet',),
'påtaleunnlatelse': ('påtaleunnlatelse',),
'påtaleunnlatelsen': ('påtaleunnlatelse',),
'påtaleunnlatelsene': ('påtaleunnlatelse',),
'påtaleunnlatelser': ('påtaleunnlatelse',),
'påtrykk': ('påtrykk',),
'påtrykka': ('påtrykk',),
'påtrykkene': ('påtrykk',),
'påtrykket': ('påtrykk',),
'påtår': ('påtår',),
'påtåren': ('påtår',),
'påtårene': ('påtår',),
'påtårer': ('påtår',),
'påvente': ('påvente',),
'påvirkningsagent': ('påvirkningsagent',),
'påvirkningsagenten': ('påvirkningsagent',),
'påvirkningsagentene': ('påvirkningsagent',),
'påvirkningsagenter': ('påvirkningsagent',),
'pæl': ('pæl',),
'pælen': ('pæl',),
'pælene': ('pæl',),
'pæler': ('pæl',),
'pæra': ('pære',),
'pære': ('pære',),
'pæren': ('pære',),
'pærene': ('pære',),
'pærer': ('pære',),
'pæretre': ('pæretre',),
'pæretrea': ('pæretre',),
'pæretreet': ('pæretre',),
'pæretrær': ('pæretre',),
'pæretrærne': ('pæretre',),
'pøbel': ('pøbel',),
'pøbelen': ('pøbel',),
'pøblene': ('pøbel',),
'pøbler': ('pøbel',),
'pøl': ('pøl',),
'pølen': ('pøl',),
'pølene': ('pøl',),
'pøler': ('pøl',),
'pølla': ('pølle',),
'pølle': ('pølle',),
'pøllen': ('pølle',),
'pøllene': ('pølle',),
'pøller': ('pølle',),
'pølsa': ('pølse',),
'pølse': ('pølse',),
'pølsen': ('pølse',),
'pølsene': ('pølse',),
'pølser': ('pølse',),
'pølsebu': ('pølsebu',),
'pølsebua': ('pølsebu',),
'pølsebuen': ('pølsebu',),
'pølsebuene': ('pølsebu',),
'pølsebuer': ('pølsebu',),
'pølsesnakk': ('pølsesnakk',),
'pølsesnakka': ('pølsesnakk',),
'pølsesnakken': ('pølsesnakk',),
'pølsesnakkene': ('pølsesnakk',),
'pølsesnakker': ('pølsesnakk',),
'pølsesnakket': ('pølsesnakk',),
'pølsevev': ('pølsevev',),
'pølseveva': ('pølsevev',),
'pølsevevene': ('pølsevev',),
'pølsevevet': ('pølsevev',),
'pønitens': ('pønitens',),
'pønitensen': ('pønitens',),
'pønitensene': ('pønitens',),
'pønitenser': ('pønitens',),
'pønitent': ('pønitent',),
'pønitenten': ('pønitent',),
'pønitentene': ('pønitent',),
'pønitenter': ('pønitent',),
'pønk': ('pønk',),
'pønken': ('pønk',),
'pønkene': ('pønk',),
'pønker': ('pønk',),
'pønker': ('pønker',),
'pønkere': ('pønker',),
'pønkeren': ('pønker',),
'pønkerer': ('pønker',),
'pønkerne': ('pønker',),
'pønkrock': ('pønkrock',),
'pønkrocken': ('pønkrock',),
'pønkrockene': ('pønkrock',),
'pønkrocker': ('pønkrock',),
'pøs': ('pøs',),
'pøsen': ('pøs',),
'pøsene': ('pøs',),
'pøser': ('pøs',),
'q': ('q',),
'q\'en': ('q',),
'q-en': ('q',),
'q-ene': ('q',),
'q-er': ('q',),
'qatarer': ('qatarer',),
'qatarere': ('qatarer',),
'qatareren': ('qatarer',),
'qatarerer': ('qatarer',),
'qatarerne': ('qatarer',),
'quadriceps': ('quadriceps',),
'quadricepsen': ('quadriceps',),
'quadricepsene': ('quadriceps',),
'quadricepser': ('quadriceps',),
'quart': ('quart',),
'quarten': ('quart',),
'quartene': ('quart',),
'quarts': ('quart',),
'quarter': ('quarter',),
'quartera': ('quarter',),
'quartere': ('quarter',),
'quarteret': ('quarter',),
'quarterne': ('quarter',),
'quarto': ('quarto',),
'quartoen': ('quarto',),
'quartoene': ('quarto',),
'quartoer': ('quarto',),
'quebracho': ('quebracho',),
'quebrachoen': ('quebracho',),
'quebrachoene': ('quebracho',),
'quebrachoer': ('quebracho',),
'quechua': ('quechua',),
'quechuaen': ('quechua',),
'quechuaene': ('quechua',),
'quechuaer': ('quechua',),
'quechua': ('quechua',),
'quickstep': ('quickstep',),
'quickstepen': ('quickstep',),
'quickstepene': ('quickstep',),
'quicksteper': ('quickstep',),
'quipu': ('quipu',),
'quipua': ('quipu',),
'quipuene': ('quipu',),
'quipuet': ('quipu',),
'quisling': ('quisling',),
'quislingen': ('quisling',),
'quislingene': ('quisling',),
'quislinger': ('quisling',),
'quislingstyra': ('quislingstyre',),
'quislingstyre': ('quislingstyre',),
'quislingstyrene': ('quislingstyre',),
'quislingstyrer': ('quislingstyre',),
'quislingstyret': ('quislingstyre',),
'quiz': ('quiz',),
'quizen': ('quiz',),
'quizene': ('quiz',),
'quizer': ('quiz',),
'quodlibet': ('quodlibet',),
'r': ('r',),
'r\'en': ('r',),
'r-en': ('r',),
'r-ene': ('r',),
'r-er': ('r',),
'réaumurgrad': ('réaumurgrad',),
'réaumurgraden': ('réaumurgrad',),
'réaumurgradene': ('réaumurgrad',),
'réaumurgrader': ('réaumurgrad',),
'réaumurskala': ('réaumurskala',),
'réaumurskalaen': ('réaumurskala',),
'réaumurskalaene': ('réaumurskala',),
'réaumurskalaer': ('réaumurskala',),
'ra': ('ra',),
'raa': ('ra',),
'raene': ('ra',),
'raet': ('ra',),
'rabagast': ('rabagast',),
'rabagasten': ('rabagast',),
'rabagastene': ('rabagast',),
'rabagaster': ('rabagast',),
'rabalder': ('rabalder',),
'rabalderet': ('rabalder',),
'rabaldra': ('rabalder',),
'rabaldre': ('rabalder',),
'rabaldrene': ('rabalder',),
'rabaldret': ('rabalder',),
'rabaldermøta': ('rabaldermøte',),
'rabaldermøte': ('rabaldermøte',),
'rabaldermøtene': ('rabaldermøte',),
'rabaldermøter': ('rabaldermøte',),
'rabaldermøtet': ('rabaldermøte',),
'rabarbra': ('rabarbra',),
'rabarbraen': ('rabarbra',),
'rabarbraene': ('rabarbra',),
'rabarbraer': ('rabarbra',),
'rabarbrasuppa': ('rabarbrasuppe',),
'rabarbrasuppe': ('rabarbrasuppe',),
'rabarbrasuppen': ('rabarbrasuppe',),
'rabarbrasuppene': ('rabarbrasuppe',),
'rabarbrasupper': ('rabarbrasuppe',),
'rabatt': ('rabatt',),
'rabatten': ('rabatt',),
'rabattene': ('rabatt',),
'rabatter': ('rabatt',),
'rabatt': ('rabatt',),
'rabatten': ('rabatt',),
'rabattene': ('rabatt',),
'rabatter': ('rabatt',),
'rabattbutikk': ('rabattbutikk',),
'rabattbutikken': ('rabattbutikk',),
'rabattbutikkene': ('rabattbutikk',),
'rabattbutikker': ('rabattbutikk',),
'rabattkjøp': ('rabattkjøp',),
'rabattkjøpa': ('rabattkjøp',),
'rabattkjøpene': ('rabattkjøp',),
'rabattkjøpet': ('rabattkjøp',),
'rabb': ('rabb',),
'rabben': ('rabb',),
'rabbene': ('rabb',),
'rabber': ('rabb',),
'rabbe': ('rabbe',),
'rabben': ('rabbe',),
'rabbene': ('rabbe',),
'rabber': ('rabbe',),
'rabbel': ('rabbel',),
'rabbelet': ('rabbel',),
'rabla': ('rabbel',),
'rablene': ('rabbel',),
'rabler': ('rabbel',),
'rablet': ('rabbel',),
'rabbi': ('rabbi',),
'rabbien': ('rabbi',),
'rabbiene': ('rabbi',),
'rabbier': ('rabbi',),
'rabbiner': ('rabbiner',),
'rabbinere': ('rabbiner',),
'rabbineren': ('rabbiner',),
'rabbinerer': ('rabbiner',),
'rabbinerne': ('rabbiner',),
'rabbinisme': ('rabbinisme',),
'rabbinismen': ('rabbinisme',),
'rabbinismene': ('rabbinisme',),
'rabbinismer': ('rabbinisme',),
'rabies': ('rabies',),
'rabiesen': ('rabies',),
'rabiesene': ('rabies',),
'rabieser': ('rabies',),
'rabulisme': ('rabulisme',),
'rabulismen': ('rabulisme',),
'rabulismene': ('rabulisme',),
'rabulismer': ('rabulisme',),
'rabulist': ('rabulist',),
'rabulisten': ('rabulist',),
'rabulistene': ('rabulist',),
'rabulister': ('rabulist',),
'raca': ('race',),
'race': ('race',),
'racene': ('race',),
'racet': ('race',),
'racer': ('racer',),
'racere': ('racer',),
'raceren': ('racer',),
'racerer': ('racer',),
'racerne': ('racer',),
'racerbil': ('racerbil',),
'racerbilen': ('racerbil',),
'racerbilene': ('racerbil',),
'racerbiler': ('racerbil',),
'racerbåt': ('racerbåt',),
'racerbåten': ('racerbåt',),
'racerbåtene': ('racerbåt',),
'racerbåter': ('racerbåt',),
'racersykkel': ('racersykkel',),
'racersykkelen': ('racersykkel',),
'racersyklene': ('racersykkel',),
'racersykler': ('racersykkel',),
'rack': ('rack',),
'racka': ('rack',),
'racken': ('rack',),
'rackene': ('rack',),
'racker': ('rack',),
'racket': ('rack',),
'racket': ('racket',),
'racketen': ('racket',),
'racketene': ('racket',),
'racketer': ('racket',),
'rad': ('rad',),
'rada': ('rad',),
'raden': ('rad',),
'radene': ('rad',),
'rader': ('rad',),
'radar': ('radar',),
'radaren': ('radar',),
'radarene': ('radar',),
'radarer': ('radar',),
'radarkontroll': ('radarkontroll',),
'radarkontrollen': ('radarkontroll',),
'radarkontrollene': ('radarkontroll',),
'radarkontroller': ('radarkontroll',),
'radarpar': ('radarpar',),
'radarpara': ('radarpar',),
'radarparene': ('radarpar',),
'radarparet': ('radarpar',),
'radarskjerm': ('radarskjerm',),
'radarskjermen': ('radarskjerm',),
'radarskjermene': ('radarskjerm',),
'radarskjermer': ('radarskjerm',),
'radarstasjon': ('radarstasjon',),
'radarstasjonen': ('radarstasjon',),
'radarstasjonene': ('radarstasjon',),
'radarstasjoner': ('radarstasjon',),
'radd': ('radd',),
'radden': ('radd',),
'raddene': ('radd',),
'radder': ('radd',),
'radering': ('radering',),
'raderinga': ('radering',),
'raderingen': ('radering',),
'raderingene': ('radering',),
'raderinger': ('radering',),
'raderkniv': ('raderkniv',),
'raderkniven': ('raderkniv',),
'raderknivene': ('raderkniv',),
'raderkniver': ('raderkniv',),
'radernål': ('radernål',),
'radernåla': ('radernål',),
'radernålen': ('radernål',),
'radernålene': ('radernål',),
'radernåler': ('radernål',),
'radialdekk': ('radialdekk',),
'radialdekka': ('radialdekk',),
'radialdekkene': ('radialdekk',),
'radialdekket': ('radialdekk',),
'radiasjon': ('radiasjon',),
'radiasjonen': ('radiasjon',),
'radiasjonene': ('radiasjon',),
'radiasjoner': ('radiasjon',),
'radiator': ('radiator',),
'radiatoren': ('radiator',),
'radiatorene': ('radiator',),
'radiatorer': ('radiator',),
'radikal': ('radikal',),
'radikala': ('radikal',),
'radikalene': ('radikal',),
'radikaler': ('radikal',),
'radikalet': ('radikal',),
'radikaler': ('radikaler',),
'radikalere': ('radikaler',),
'radikaleren': ('radikaler',),
'radikalerer': ('radikaler',),
'radikalerne': ('radikaler',),
'radikalisme': ('radikalisme',),
'radikalismen': ('radikalisme',),
'radikalismene': ('radikalisme',),
'radikalismer': ('radikalisme',),
'radikalist': ('radikalist',),
'radikalisten': ('radikalist',),
'radikalistene': ('radikalist',),
'radikalister': ('radikalist',),
'radikalitet': ('radikalitet',),
'radikaliteten': ('radikalitet',),
'radikalitetene': ('radikalitet',),
'radikaliteter': ('radikalitet',),
'radikand': ('radikand',),
'radikanden': ('radikand',),
'radikandene': ('radikand',),
'radikander': ('radikand',),
'radio': ('radio',),
'radioen': ('radio',),
'radioene': ('radio',),
'radioer': ('radio',),
'radioaktivitet': ('radioaktivitet',),
'radioaktiviteten': ('radioaktivitet',),
'radioaktivitetene': ('radioaktivitet',),
'radioaktiviteter': ('radioaktivitet',),
'radioapparat': ('radioapparat',),
'radioapparata': ('radioapparat',),
'radioapparatene': ('radioapparat',),
'radioapparater': ('radioapparat',),
'radioapparatet': ('radioapparat',),
'radiobil': ('radiobil',),
'radiobilen': ('radiobil',),
'radiobilene': ('radiobil',),
'radiobiler': ('radiobil',),
'radiobølga': ('radiobølge',),
'radiobølge': ('radiobølge',),
'radiobølgen': ('radiobølge',),
'radiobølgene': ('radiobølge',),
'radiobølger': ('radiobølge',),
'radiofyr': ('radiofyr',),
'radiofyra': ('radiofyr',),
'radiofyrene': ('radiofyr',),
'radiofyret': ('radiofyr',),
'radiograf': ('radiograf',),
'radiografen': ('radiograf',),
'radiografene': ('radiograf',),
'radiografer': ('radiograf',),
'radiografi': ('radiografi',),
'radiografien': ('radiografi',),
'radiografiene': ('radiografi',),
'radiografier': ('radiografi',),
'radiogram': ('radiogram',),
'radiogramma': ('radiogram',),
'radiogrammene': ('radiogram',),
'radiogrammer': ('radiogram',),
'radiogrammet': ('radiogram',),
'radiolinja': ('radiolinje',),
'radiolinje': ('radiolinje',),
'radiolinjen': ('radiolinje',),
'radiolinjene': ('radiolinje',),
'radiolinjer': ('radiolinje',),
'radiolink': ('radiolink',),
'radiolinken': ('radiolink',),
'radiolinkene': ('radiolink',),
'radiolinker': ('radiolink',),
'radiolog': ('radiolog',),
'radiologen': ('radiolog',),
'radiologene': ('radiolog',),
'radiologer': ('radiolog',),
'radiologi': ('radiologi',),
'radiologien': ('radiologi',),
'radiologiene': ('radiologi',),
'radiologier': ('radiologi',),
'radiometer': ('radiometer',),
'radiometeret': ('radiometer',),
'radiometra': ('radiometer',),
'radiometre': ('radiometer',),
'radiometrene': ('radiometer',),
'radiometret': ('radiometer',),
'radiomottaker': ('radiomottaker',),
'radiomottakere': ('radiomottaker',),
'radiomottakeren': ('radiomottaker',),
'radiomottakerer': ('radiomottaker',),
'radiomottakerne': ('radiomottaker',),
'radiorør': ('radiorør',),
'radiorøra': ('radiorør',),
'radiorørene': ('radiorør',),
'radiorøret': ('radiorør',),
'radiosender': ('radiosender',),
'radiosendere': ('radiosender',),
'radiosenderen': ('radiosender',),
'radiosenderer': ('radiosender',),
'radiosenderne': ('radiosender',),
'radiosonde': ('radiosonde',),
'radiosonden': ('radiosonde',),
'radiosondene': ('radiosonde',),
'radiosonder': ('radiosonde',),
'radiostasjon': ('radiostasjon',),
'radiostasjonen': ('radiostasjon',),
'radiostasjonene': ('radiostasjon',),
'radiostasjoner': ('radiostasjon',),
'radioteknikk': ('radioteknikk',),
'radioteknikken': ('radioteknikk',),
'radioteknikkene': ('radioteknikk',),
'radioteknikker': ('radioteknikk',),
'radiotelefoni': ('radiotelefoni',),
'radiotelefonien': ('radiotelefoni',),
'radiotelefoniene': ('radiotelefoni',),
'radiotelefonier': ('radiotelefoni',),
'radiotelegrafi': ('radiotelegrafi',),
'radiotelegrafien': ('radiotelegrafi',),
'radiotelegrafiene': ('radiotelegrafi',),
'radiotelegrafier': ('radiotelegrafi',),
'radioterapi': ('radioterapi',),
'radioterapien': ('radioterapi',),
'radioterapiene': ('radioterapi',),
'radioterapier': ('radioterapi',),
'radium': ('radium',),
'radiuma': ('radium',),
'radiumene': ('radium',),
'radiumet': ('radium',),
'radiumbehandling': ('radiumbehandling',),
'radiumbehandlinga': ('radiumbehandling',),
'radiumbehandlingen': ('radiumbehandling',),
'radiumbehandlingene': ('radiumbehandling',),
'radiumbehandlinger': ('radiumbehandling',),
'radiumterapi': ('radiumterapi',),
'radiumterapien': ('radiumterapi',),
'radiumterapiene': ('radiumterapi',),
'radiumterapier': ('radiumterapi',),
'radien': ('radius',),
'radiene': ('radius',),
'radier': ('radius',),
'radius': ('radius',),
'radiusen': ('radius',),
'radom': ('radom',),
'radomen': ('radom',),
'radomene': ('radom',),
'radomer': ('radom',),
'radon': ('radon',),
'radona': ('radon',),
'radonene': ('radon',),
'radonet': ('radon',),
'raffinade': ('raffinade',),
'raffinaden': ('raffinade',),
'raffinadene': ('raffinade',),
'raffinader': ('raffinade',),
'raffinaderi': ('raffinaderi',),
'raffinaderia': ('raffinaderi',),
'raffinaderiene': ('raffinaderi',),
'raffinaderier': ('raffinaderi',),
'raffinaderiet': ('raffinaderi',),
'raffinement': ('raffinement',),
'raffinementa': ('raffinement',),
'raffinementene': ('raffinement',),
'raffinementer': ('raffinement',),
'raffinementet': ('raffinement',),
'raffineri': ('raffineri',),
'raffineria': ('raffineri',),
'raffineriene': ('raffineri',),
'raffinerier': ('raffineri',),
'raffineriet': ('raffineri',),
'raft': ('raft',),
'rafta': ('raft',),
'raften': ('raft',),
'raftene': ('raft',),
'rafter': ('raft',),
'raftestokk': ('raftestokk',),
'raftestokken': ('raftestokk',),
'raftestokkene': ('raftestokk',),
'raftestokker': ('raftestokk',),
'rafting': ('rafting',),
'raftinga': ('rafting',),
'raftingen': ('rafting',),
'raftingene': ('rafting',),
'raftinger': ('rafting',),
'raftstokk': ('raftstokk',),
'raftstokken': ('raftstokk',),
'raftstokkene': ('raftstokk',),
'raftstokker': ('raftstokk',),
'ragg': ('ragg',),
'ragga': ('ragg',),
'raggene': ('ragg',),
'ragget': ('ragg',),
'raggar': ('raggar',),
'raggaren': ('raggar',),
'raggarene': ('raggar',),
'raggarer': ('raggar',),
'raggarbil': ('raggarbil',),
'raggarbilen': ('raggarbil',),
'raggarbilene': ('raggarbil',),
'raggarbiler': ('raggarbil',),
'raggesokk': ('raggesokk',),
'raggesokken': ('raggesokk',),
'raggesokkene': ('raggesokk',),
'raggesokker': ('raggesokk',),
'raggsokk': ('raggsokk',),
'raggsokken': ('raggsokk',),
'raggsokkene': ('raggsokk',),
'raggsokker': ('raggsokk',),
'raglan': ('raglan',),
'raglanen': ('raglan',),
'raglanene': ('raglan',),
'raglaner': ('raglan',),
'raglanerma': ('raglanerme',),
'raglanerme': ('raglanerme',),
'raglanermene': ('raglanerme',),
'raglanermer': ('raglanerme',),
'raglanermet': ('raglanerme',),
'raglanfelling': ('raglanfelling',),
'raglanfellinga': ('raglanfelling',),
'raglanfellingen': ('raglanfelling',),
'raglanfellingene': ('raglanfelling',),
'raglanfellinger': ('raglanfelling',),
'raglanfrakk': ('raglanfrakk',),
'raglanfrakken': ('raglanfrakk',),
'raglanfrakkene': ('raglanfrakk',),
'raglanfrakker': ('raglanfrakk',),
'ragnarok': ('ragnarok',),
'ragnaroka': ('ragnarok',),
'ragnarokene': ('ragnarok',),
'ragnaroket': ('ragnarok',),
'ragtime': ('ragtime',),
'ragtimen': ('ragtime',),
'ragtimene': ('ragtime',),
'ragtimer': ('ragtime',),
'ragu': ('ragu',),
'raguen': ('ragu',),
'raguene': ('ragu',),
'raguer': ('ragu',),
'raid': ('raid',),
'raida': ('raid',),
'raidene': ('raid',),
'raidet': ('raid',),
'raide': ('raide',),
'raiden': ('raide',),
'raidene': ('raide',),
'raider': ('raide',),
'raigras': ('raigras',),
'raigrasa': ('raigras',),
'raigrasene': ('raigras',),
'raigraset': ('raigras',),
'raigress': ('raigress',),
'raigressa': ('raigress',),
'raigressene': ('raigress',),
'raigresset': ('raigress',),
'raja': ('raja',),
'rajaen': ('raja',),
'rajaene': ('raja',),
'rajaer': ('raja',),
'raja': ('raje',),
'raje': ('raje',),
'rajen': ('raje',),
'rajene': ('raje',),
'rajer': ('raje',),
'rak': ('rak',),
'raka': ('rak',),
'rakene': ('rak',),
'raket': ('rak',),
'rakaure': ('rakaure',),
'rakauren': ('rakaure',),
'rakaurene': ('rakaure',),
'rakaurer': ('rakaure',),
'rakaure': ('rakaure',),
'rakauren': ('rakaure',),
'rakaurene': ('rakaure',),
'rakaurer': ('rakaure',),
'raka': ('rake',),
'rake': ('rake',),
'raken': ('rake',),
'rakene': ('rake',),
'raker': ('rake',),
'rake': ('rake',),
'rakefisk': ('rakefisk',),
'rakefisken': ('rakefisk',),
'rakefiskene': ('rakefisk',),
'rakefisker': ('rakefisk',),
'rakekniv': ('rakekniv',),
'rakekniven': ('rakekniv',),
'rakeknivene': ('rakekniv',),
'rakekniver': ('rakekniv',),
'rakett': ('rakett',),
'raketten': ('rakett',),
'rakettene': ('rakett',),
'raketter': ('rakett',),
'rakettmotor': ('rakettmotor',),
'rakettmotoren': ('rakettmotor',),
'rakettmotorene': ('rakettmotor',),
'rakettmotorer': ('rakettmotor',),
'rakettvåpen': ('rakettvåpen',),
'rakettvåpenet': ('rakettvåpen',),
'rakettvåpna': ('rakettvåpen',),
'rakettvåpnene': ('rakettvåpen',),
'rakitis': ('rakitis',),
'rakitisen': ('rakitis',),
'rakitisene': ('rakitis',),
'rakitiser': ('rakitis',),
'rakitt': ('rakitt',),
'rakitten': ('rakitt',),
'rakittene': ('rakitt',),
'rakitter': ('rakitt',),
'rakk': ('rakk',),
'rakka': ('rakk',),
'rakkene': ('rakk',),
'rakket': ('rakk',),
'rakke': ('rakke',),
'rakken': ('rakke',),
'rakkene': ('rakke',),
'rakker': ('rakke',),
'rakkel': ('rakkel',),
'rakkelet': ('rakkel',),
'rakla': ('rakkel',),
'raklene': ('rakkel',),
'rakler': ('rakkel',),
'raklet': ('rakkel',),
'rakker': ('rakker',),
'rakkere': ('rakker',),
'rakkeren': ('rakker',),
'rakkerer': ('rakker',),
'rakkerne': ('rakker',),
'rakkerpakk': ('rakkerpakk',),
'rakkerpakka': ('rakkerpakk',),
'rakkerpakkene': ('rakkerpakk',),
'rakkerpakket': ('rakkerpakk',),
'rakkerunge': ('rakkerunge',),
'rakkerungen': ('rakkerunge',),
'rakkerungene': ('rakkerunge',),
'rakkerunger': ('rakkerunge',),
'rakle': ('rakle',),
'raklen': ('rakle',),
'raklene': ('rakle',),
'rakler': ('rakle',),
'raklefugl': ('raklefugl',),
'raklefuglen': ('raklefugl',),
'raklefuglene': ('raklefugl',),
'raklefugler': ('raklefugl',),
'raklehane': ('raklehane',),
'raklehanen': ('raklehane',),
'raklehanene': ('raklehane',),
'raklehaner': ('raklehane',),
'raklehøna': ('raklehøne',),
'raklehøne': ('raklehøne',),
'raklehønen': ('raklehøne',),
'raklehønene': ('raklehøne',),
'raklehøner': ('raklehøne',),
'rakletre': ('rakletre',),
'rakletrea': ('rakletre',),
'rakletreet': ('rakletre',),
'rakletrær': ('rakletre',),
'rakletrærne': ('rakletre',),
'rakst': ('rakst',),
'raksten': ('rakst',),
'rakstene': ('rakst',),
'rakster': ('rakst',),
'rakstejenta': ('rakstejente',),
'rakstejente': ('rakstejente',),
'rakstejenten': ('rakstejente',),
'rakstejentene': ('rakstejente',),
'rakstejenter': ('rakstejente',),
'rakster': ('rakster',),
'raksteren': ('rakster',),
'rakstre': ('rakster',),
'rakstrene': ('rakster',),
'rakstrer': ('rakster',),
'raku': ('raku',),
'rakuen': ('raku',),
'rakuene': ('raku',),
'rakuer': ('raku',),
'rakørret': ('rakørret',),
'rakørreten': ('rakørret',),
'rakørretene': ('rakørret',),
'rakørreter': ('rakørret',),
'rakørret': ('rakørret',),
'rakørreten': ('rakørret',),
'rakørretene': ('rakørret',),
'rakørreter': ('rakørret',),
'rallar': ('rallar',),
'rallaren': ('rallar',),
'rallarene': ('rallar',),
'rallarer': ('rallar',),
'rally': ('rally',),
'rallya': ('rally',),
'rallyene': ('rally',),
'rallyer': ('rally',),
'rallyet': ('rally',),
'rallycross': ('rallycross',),
'rallycrossa': ('rallycross',),
'rallycrossene': ('rallycross',),
'rallycrosset': ('rallycross',),
'ram': ('ram',),
'rammen': ('ram',),
'rammene': ('ram',),
'rammer': ('ram',),
'ram': ('ram',),
'rammen': ('ram',),
'rammene': ('ram',),
'rammer': ('ram',),
'ram': ('ram',),
'ramma': ('ram',),
'rammene': ('ram',),
'rammet': ('ram',),
'ramadan': ('ramadan',),
'ramadanen': ('ramadan',),
'ramadanene': ('ramadan',),
'ramadaner': ('ramadan',),
'ramaskrik': ('ramaskrik',),
'ramaskrika': ('ramaskrik',),
'ramaskrikene': ('ramaskrik',),
'ramaskriket': ('ramaskrik',),
'rambukk': ('rambukk',),
'rambukken': ('rambukk',),
'rambukkene': ('rambukk',),
'rambukker': ('rambukk',),
'ramma': ('ramme',),
'ramme': ('ramme',),
'rammen': ('ramme',),
'rammene': ('ramme',),
'rammer': ('ramme',),
'rammeavtale': ('rammeavtale',),
'rammeavtalen': ('rammeavtale',),
'rammeavtalene': ('rammeavtale',),
'rammeavtaler': ('rammeavtale',),
'rammefortelling': ('rammefortelling',),
'rammefortellinga': ('rammefortelling',),
'rammefortellingen': ('rammefortelling',),
'rammefortellingene': ('rammefortelling',),
'rammefortellinger': ('rammefortelling',),
'ramla': ('rammel',),
'ramlene': ('rammel',),
'ramler': ('rammel',),
'ramlet': ('rammel',),
'rammel': ('rammel',),
'rammelen': ('rammel',),
'rammelet': ('rammel',),
'rammeplan': ('rammeplan',),
'rammeplanen': ('rammeplan',),
'rammeplanene': ('rammeplan',),
'rammeplaner': ('rammeplan',),
'rammestyring': ('rammestyring',),
'rammestyringa': ('rammestyring',),
'rammestyringen': ('rammestyring',),
'rammestyringene': ('rammestyring',),
'rammestyringer': ('rammestyring',),
'rammetimetall': ('rammetimetall',),
'rammetimetalla': ('rammetimetall',),
'rammetimetallene': ('rammetimetall',),
'rammetimetallet': ('rammetimetall',),
'rammetraktor': ('rammetraktor',),
'rammetraktoren': ('rammetraktor',),
'rammetraktorene': ('rammetraktor',),
'rammetraktorer': ('rammetraktor',),
'ramn': ('ramn',),
'ramnen': ('ramn',),
'ramnene': ('ramn',),
'ramner': ('ramn',),
'ramn': ('ramn',),
'ramnen': ('ramn',),
'ramnene': ('ramn',),
'ramner': ('ramn',),
'ramnekrok': ('ramnekrok',),
'ramnekroken': ('ramnekrok',),
'ramnekrokene': ('ramnekrok',),
'ramnekroker': ('ramnekrok',),
'ramnekrok': ('ramnekrok',),
'ramnekroken': ('ramnekrok',),
'ramnekrokene': ('ramnekrok',),
'ramnekroker': ('ramnekrok',),
'ramost': ('ramost',),
'ramosten': ('ramost',),
'ramostene': ('ramost',),
'ramoster': ('ramost',),
'ramp': ('ramp',),
'rampen': ('ramp',),
'rampene': ('ramp',),
'ramper': ('ramp',),
'rampa': ('rampe',),
'rampe': ('rampe',),
'rampen': ('rampe',),
'rampene': ('rampe',),
'ramper': ('rampe',),
'rampegutt': ('rampegutt',),
'rampegutten': ('rampegutt',),
'rampeguttene': ('rampegutt',),
'rampegutter': ('rampegutt',),
'rampelys': ('rampelys',),
'rampelysa': ('rampelys',),
'rampelysene': ('rampelys',),
'rampelyset': ('rampelys',),
'rampestrek': ('rampestrek',),
'rampestreken': ('rampestrek',),
'rampestrekene': ('rampestrek',),
'rampestreker': ('rampestrek',),
'rampunge': ('rampunge',),
'rampungen': ('rampunge',),
'rampungene': ('rampunge',),
'rampunger': ('rampunge',),
'rams': ('rams',),
'ramsen': ('rams',),
'ramsene': ('rams',),
'ramser': ('rams',),
'rams': ('rams',),
'ramsa': ('ramse',),
'ramse': ('ramse',),
'ramsen': ('ramse',),
'ramsene': ('ramse',),
'ramser': ('ramse',),
'ramsløk': ('ramsløk',),
'ramsløken': ('ramsløk',),
'ramsløkene': ('ramsløk',),
'ramsløker': ('ramsløk',),
'ran': ('ran',),
'rana': ('ran',),
'ranene': ('ran',),
'ranet': ('ran',),
'ranch': ('ranch',),
'ranchen': ('ranch',),
'ranchene': ('ranch',),
'rancher': ('ranch',),
'rand': ('rand',),
'randen': ('rand',),
'randene': ('rand',),
'rand': ('rand',),
'randa': ('rand',),
'randen': ('rand',),
'rendene': ('rand',),
'render': ('rand',),
'randbemerkning': ('randbemerkning',),
'randbemerkninga': ('randbemerkning',),
'randbemerkningen': ('randbemerkning',),
'randbemerkningene': ('randbemerkning',),
'randbemerkninger': ('randbemerkning',),
'randfjell': ('randfjell',),
'randfjella': ('randfjell',),
'randfjellene': ('randfjell',),
'randfjellet': ('randfjell',),
'randstat': ('randstat',),
'randstaten': ('randstat',),
'randstatene': ('randstat',),
'randstater': ('randstat',),
'raner': ('raner',),
'ranere': ('raner',),
'raneren': ('raner',),
'ranerer': ('raner',),
'ranerne': ('raner',),
'rang': ('rang',),
'rangen': ('rang',),
'rangene': ('rang',),
'ranger': ('rang',),
'rangel': ('rangel',),
'rangelen': ('rangel',),
'ranglene': ('rangel',),
'rangler': ('rangel',),
'rangel': ('rangel',),
'rangelet': ('rangel',),
'rangla': ('rangel',),
'ranglene': ('rangel',),
'rangler': ('rangel',),
'ranglet': ('rangel',),
'ranger': ('ranger',),
'rangere': ('ranger',),
'rangeren': ('ranger',),
'rangerer': ('ranger',),
'rangerne': ('ranger',),
'rangerstasjon': ('rangerstasjon',),
'rangerstasjonen': ('rangerstasjon',),
'rangerstasjonene': ('rangerstasjon',),
'rangerstasjoner': ('rangerstasjon',),
'rangklassa': ('rangklasse',),
'rangklasse': ('rangklasse',),
'rangklassen': ('rangklasse',),
'rangklassene': ('rangklasse',),
'rangklasser': ('rangklasse',),
'rangla': ('rangle',),
'rangle': ('rangle',),
'ranglen': ('rangle',),
'ranglene': ('rangle',),
'rangler': ('rangle',),
'ranglefant': ('ranglefant',),
'ranglefanten': ('ranglefant',),
'ranglefantene': ('ranglefant',),
'ranglefanter': ('ranglefant',),
'ranglepave': ('ranglepave',),
'ranglepaven': ('ranglepave',),
'ranglepavene': ('ranglepave',),
'ranglepaver': ('ranglepave',),
'rangler': ('rangler',),
'ranglere': ('rangler',),
'rangleren': ('rangler',),
'ranglerer': ('rangler',),
'ranglerne': ('rangler',),
'rangordning': ('rangordning',),
'rangordninga': ('rangordning',),
'rangordningen': ('rangordning',),
'rangordningene': ('rangordning',),
'rangordninger': ('rangordning',),
'rangsforskjell': ('rangsforskjell',),
'rangsforskjellen': ('rangsforskjell',),
'rangsforskjellene': ('rangsforskjell',),
'rangsforskjeller': ('rangsforskjell',),
'rangsperson': ('rangsperson',),
'rangspersonen': ('rangsperson',),
'rangspersonene': ('rangsperson',),
'rangspersoner': ('rangsperson',),
'rangstige': ('rangstige',),
'rangstigen': ('rangstige',),
'rangstigene': ('rangstige',),
'rangstiger': ('rangstige',),
'ranke': ('ranke',),
'ranken': ('ranke',),
'rankene': ('ranke',),
'ranker': ('ranke',),
'ranke': ('ranke',),
'ranking': ('ranking',),
'rankinga': ('ranking',),
'rankingen': ('ranking',),
'rankingene': ('ranking',),
'rankinger': ('ranking',),
'rankinglista': ('rankingliste',),
'rankingliste': ('rankingliste',),
'rankinglisten': ('rankingliste',),
'rankinglistene': ('rankingliste',),
'rankinglister': ('rankingliste',),
'rankingrenn': ('rankingrenn',),
'rankingrenna': ('rankingrenn',),
'rankingrennene': ('rankingrenn',),
'rankingrennet': ('rankingrenn',),
'ransakelse': ('ransakelse',),
'ransakelsen': ('ransakelse',),
'ransakelsene': ('ransakelse',),
'ransakelser': ('ransakelse',),
'ransaking': ('ransaking',),
'ransakinga': ('ransaking',),
'ransakingen': ('ransaking',),
'ransakingene': ('ransaking',),
'ransakinger': ('ransaking',),
'ransel': ('ransel',),
'ranselen': ('ransel',),
'ranslene': ('ransel',),
'ransler': ('ransel',),
'ransmann': ('ransmann',),
'ransmannen': ('ransmann',),
'ransmenn': ('ransmann',),
'ransmennene': ('ransmann',),
'ranunkel': ('ranunkel',),
'ranunkelen': ('ranunkel',),
'ranunklene': ('ranunkel',),
'ranunkler': ('ranunkel',),
'ranværing': ('ranværing',),
'ranværingen': ('ranværing',),
'ranværingene': ('ranværing',),
'ranværinger': ('ranværing',),
'rape': ('rape',),
'rapen': ('rape',),
'rapene': ('rape',),
'raper': ('rape',),
'rapiditet': ('rapiditet',),
'rapiditeten': ('rapiditet',),
'rapiditetene': ('rapiditet',),
'rapiditeter': ('rapiditet',),
'rapp': ('rapp',),
'rappen': ('rapp',),
'rappene': ('rapp',),
'rapper': ('rapp',),
'rapp': ('rapp',),
'rappen': ('rapp',),
'rappene': ('rapp',),
'rapper': ('rapp',),
'rapp': ('rapp',),
'rappen': ('rapp',),
'rappene': ('rapp',),
'rapper': ('rapp',),
'rapp': ('rapp',),
'rappa': ('rapp',),
'rappene': ('rapp',),
'rappet': ('rapp',),
'rapp': ('rapp',),
'rappa': ('rapp',),
'rappen': ('rapp',),
'rappene': ('rapp',),
'rapper': ('rapp',),
'rappet': ('rapp',),
'rappell': ('rappell',),
'rappellen': ('rappell',),
'rappellene': ('rappell',),
'rappeller': ('rappell',),
'rapphøna': ('rapphøne',),
'rapphøne': ('rapphøne',),
'rapphønen': ('rapphøne',),
'rapphønene': ('rapphøne',),
'rapphøner': ('rapphøne',),
'rapping': ('rapping',),
'rappingen': ('rapping',),
'rappingene': ('rapping',),
'rappinger': ('rapping',),
'rapport': ('rapport',),
'rapporten': ('rapport',),
'rapportene': ('rapport',),
'rapporter': ('rapport',),
'rapportør': ('rapportør',),
'rapportøren': ('rapportør',),
'rapportørene': ('rapportør',),
'rapportører': ('rapportør',),
'rappsekk': ('rappsekk',),
'rappsekken': ('rappsekk',),
'rappsekkene': ('rappsekk',),
'rappsekker': ('rappsekk',),
'raps': ('raps',),
'rapsen': ('raps',),
'rapsene': ('raps',),
'rapser': ('raps',),
'rapseri': ('rapseri',),
'rapseria': ('rapseri',),
'rapseriene': ('rapseri',),
'rapserier': ('rapseri',),
'rapseriet': ('rapseri',),
'rapsing': ('rapsing',),
'rapsinga': ('rapsing',),
'rapsingen': ('rapsing',),
'rapsingene': ('rapsing',),
'rapsinger': ('rapsing',),
'rapsode': ('rapsode',),
'rapsoden': ('rapsode',),
'rapsodene': ('rapsode',),
'rapsoder': ('rapsode',),
'rapsodi': ('rapsodi',),
'rapsodien': ('rapsodi',),
'rapsodiene': ('rapsodi',),
'rapsodier': ('rapsodi',),
'raptus': ('raptus',),
'raptusen': ('raptus',),
'raptusene': ('raptus',),
'raptuser': ('raptus',),
'raring': ('raring',),
'raringen': ('raring',),
'raringene': ('raring',),
'raringer': ('raring',),
'raritet': ('raritet',),
'rariteten': ('raritet',),
'raritetene': ('raritet',),
'rariteter': ('raritet',),
'ras': ('ras',),
'rasa': ('ras',),
'rasene': ('ras',),
'raset': ('ras',),
'rase': ('rase',),
'rasen': ('rase',),
'rasene': ('rase',),
'raser': ('rase',),
'rasebiologi': ('rasebiologi',),
'rasebiologien': ('rasebiologi',),
'rasebiologiene': ('rasebiologi',),
'rasebiologier': ('rasebiologi',),
'raseblanding': ('raseblanding',),
'raseblandinga': ('raseblanding',),
'raseblandingen': ('raseblanding',),
'raseblandingene': ('raseblanding',),
'raseblandinger': ('raseblanding',),
'rasediskriminering': ('rasediskriminering',),
'rasediskrimineringa': ('rasediskriminering',),
'rasediskrimineringen': ('rasediskriminering',),
'rasediskrimineringene': ('rasediskriminering',),
'rasediskrimineringer': ('rasediskriminering',),
'rasedyr': ('rasedyr',),
'rasedyra': ('rasedyr',),
'rasedyrene': ('rasedyr',),
'rasedyret': ('rasedyr',),
'rasefordom': ('rasefordom',),
'rasefordommen': ('rasefordom',),
'rasefordommene': ('rasefordom',),
'rasefordommer': ('rasefordom',),
'rasehat': ('rasehat',),
'rasehata': ('rasehat',),
'rasehatene': ('rasehat',),
'rasehatet': ('rasehat',),
'rasehygiene': ('rasehygiene',),
'rasehygienen': ('rasehygiene',),
'rasehygienene': ('rasehygiene',),
'rasehygiener': ('rasehygiene',),
'raseideologi': ('raseideologi',),
'raseideologien': ('raseideologi',),
'raseideologiene': ('raseideologi',),
'raseideologier': ('raseideologi',),
'rasekamp': ('rasekamp',),
'rasekampen': ('rasekamp',),
'rasekampene': ('rasekamp',),
'rasekamper': ('rasekamp',),
'raseopptøyene': ('raseopptøyer',),
'raseopptøyer': ('raseopptøyer',),
'raseri': ('raseri',),
'raseria': ('raseri',),
'raseriene': ('raseri',),
'raserier': ('raseri',),
'raseriet': ('raseri',),
'raseskilla': ('raseskille',),
'raseskille': ('raseskille',),
'raseskillene': ('raseskille',),
'raseskiller': ('raseskille',),
'raseskillet': ('raseskille',),
'raseskillepolitikk': ('raseskillepolitikk',),
'raseskillepolitikken': ('raseskillepolitikk',),
'raseskillepolitikkene': ('raseskillepolitikk',),
'raseskillepolitikker': ('raseskillepolitikk',),
'rasisme': ('rasisme',),
'rasismen': ('rasisme',),
'rasismene': ('rasisme',),
'rasismer': ('rasisme',),
'rasist': ('rasist',),
'rasisten': ('rasist',),
'rasistene': ('rasist',),
'rasister': ('rasist',),
'rasjon': ('rasjon',),
'rasjonen': ('rasjon',),
'rasjonene': ('rasjon',),
'rasjoner': ('rasjon',),
'rasjonaliseringsekspert': ('rasjonaliseringsekspert',),
'rasjonaliseringseksperten': ('rasjonaliseringsekspert',),
'rasjonaliseringsekspertene': ('rasjonaliseringsekspert',),
'rasjonaliseringseksperter': ('rasjonaliseringsekspert',),
'rasjonalisme': ('rasjonalisme',),
'rasjonalismen': ('rasjonalisme',),
'rasjonalismene': ('rasjonalisme',),
'rasjonalismer': ('rasjonalisme',),
'rasjonalist': ('rasjonalist',),
'rasjonalisten': ('rasjonalist',),
'rasjonalistene': ('rasjonalist',),
'rasjonalister': ('rasjonalist',),
'rasjonalitet': ('rasjonalitet',),
'rasjonaliteten': ('rasjonalitet',),
'rasjonalitetene': ('rasjonalitet',),
'rasjonaliteter': ('rasjonalitet',),
'rasjoneringskort': ('rasjoneringskort',),
'rasjoneringskorta': ('rasjoneringskort',),
'rasjoneringskortene': ('rasjoneringskort',),
'rasjoneringskortet': ('rasjoneringskort',),
'rask': ('rask',),
'raska': ('rask',),
'raskene': ('rask',),
'rasket': ('rask',),
'rasmus': ('rasmus',),
'rasmusen': ('rasmus',),
'rasmusene': ('rasmus',),
'rasmuser': ('rasmus',),
'rasp': ('rasp',),
'raspa': ('rasp',),
'raspene': ('rasp',),
'raspet': ('rasp',),
'rasp': ('rasp',),
'raspa': ('rasp',),
'raspen': ('rasp',),
'raspene': ('rasp',),
'rasper': ('rasp',),
'raspeball': ('raspeball',),
'raspeballen': ('raspeball',),
'raspeballene': ('raspeball',),
'raspeballer': ('raspeball',),
'rasla': ('rassel',),
'raslene': ('rassel',),
'rasler': ('rassel',),
'raslet': ('rassel',),
'rassel': ('rassel',),
'rasselet': ('rassel',),
'rasshol': ('rasshol',),
'rasshola': ('rasshol',),
'rassholene': ('rasshol',),
'rassholet': ('rasshol',),
'rassia': ('rassia',),
'rassiaen': ('rassia',),
'rassiaene': ('rassia',),
'rassiaer': ('rassia',),
'rast': ('rast',),
'rasten': ('rast',),
'rastene': ('rast',),
'raster': ('rast',),
'rast': ('rast',),
'rasta': ('rast',),
'rasten': ('rast',),
'rastene': ('rast',),
'raster': ('rast',),
'rastafari': ('rastafari',),
'rastafarien': ('rastafari',),
'rastafariene': ('rastafari',),
'rastafarier': ('rastafari',),
'rasteplass': ('rasteplass',),
'rasteplassen': ('rasteplass',),
'rasteplassene': ('rasteplass',),
'rasteplasser': ('rasteplass',),
'raster': ('raster',),
'rasteret': ('raster',),
'rastra': ('raster',),
'rastre': ('raster',),
'rastrene': ('raster',),
'rastret': ('raster',),
'ratata': ('ratata',),
'ratataen': ('ratata',),
'ratataene': ('ratata',),
'ratataer': ('ratata',),
'rate': ('rate',),
'raten': ('rate',),
'ratene': ('rate',),
'rater': ('rate',),
'ratebetaling': ('ratebetaling',),
'ratebetalinga': ('ratebetaling',),
'ratebetalingen': ('ratebetaling',),
'ratebetalingene': ('ratebetaling',),
'ratebetalinger': ('ratebetaling',),
'ratesalg': ('ratesalg',),
'ratesalga': ('ratesalg',),
'ratesalgene': ('ratesalg',),
'ratesalget': ('ratesalg',),
'ratifikasjon': ('ratifikasjon',),
'ratifikasjonen': ('ratifikasjon',),
'ratifikasjonene': ('ratifikasjon',),
'ratifikasjoner': ('ratifikasjon',),
'ratio': ('ratio',),
'ratioen': ('ratio',),
'ratioene': ('ratio',),
'ratioer': ('ratio',),
'ratt': ('ratt',),
'ratta': ('ratt',),
'rattene': ('ratt',),
'rattet': ('ratt',),
'rattfyll': ('rattfyll',),
'rattfylla': ('rattfyll',),
'rattfyllen': ('rattfyll',),
'rattfyllene': ('rattfyll',),
'rattfyller': ('rattfyll',),
'rattgir': ('rattgir',),
'rattgira': ('rattgir',),
'rattgirene': ('rattgir',),
'rattgiret': ('rattgir',),
'rattkjelke': ('rattkjelke',),
'rattkjelken': ('rattkjelke',),
'rattkjelkene': ('rattkjelke',),
'rattkjelker': ('rattkjelke',),
'rattlås': ('rattlås',),
'rattlåsa': ('rattlås',),
'rattlåsen': ('rattlås',),
'rattlåsene': ('rattlås',),
'rattlåser': ('rattlås',),
'rattlåset': ('rattlås',),
'rauda': ('rauda',),
'raudalge': ('raudalge',),
'raudalgen': ('raudalge',),
'raudalgene': ('raudalge',),
'raudalger': ('raudalge',),
'raudeik': ('raudeik',),
'raudeika': ('raudeik',),
'raudeiken': ('raudeik',),
'raudeikene': ('raudeik',),
'raudeiker': ('raudeik',),
'rauden': ('rauden',),
'raudfisk': ('raudfisk',),
'raudfisken': ('raudfisk',),
'raudfiskene': ('raudfisk',),
'raudfisker': ('raudfisk',),
'raudfuru': ('raudfuru',),
'raudfurua': ('raudfuru',),
'raudfuruen': ('raudfuru',),
'raudfuruene': ('raudfuru',),
'raudfuruer': ('raudfuru',),
'raudkjelk': ('raudkjelk',),
'raudkjelken': ('raudkjelk',),
'raudkjelkene': ('raudkjelk',),
'raudkjelker': ('raudkjelk',),
'raudkløver': ('raudkløver',),
'raudkløvere': ('raudkløver',),
'raudkløveren': ('raudkløver',),
'raudkløverer': ('raudkløver',),
'raudkløverne': ('raudkløver',),
'raudkolla': ('raudkolle',),
'raudkolle': ('raudkolle',),
'raudkollen': ('raudkolle',),
'raudkollene': ('raudkolle',),
'raudkoller': ('raudkolle',),
'raudkål': ('raudkål',),
'raudkålen': ('raudkål',),
'raudkålene': ('raudkål',),
'raudkåler': ('raudkål',),
'raudmose': ('raudmose',),
'raudmosen': ('raudmose',),
'raudmosene': ('raudmose',),
'raudmoser': ('raudmose',),
'raudrev': ('raudrev',),
'raudreven': ('raudrev',),
'raudrevene': ('raudrev',),
'raudrever': ('raudrev',),
'raudsott': ('raudsott',),
'raudsotta': ('raudsott',),
'raudsotten': ('raudsott',),
'raudsottene': ('raudsott',),
'raudsotter': ('raudsott',),
'raudspetta': ('raudspette',),
'raudspette': ('raudspette',),
'raudspetten': ('raudspette',),
'raudspettene': ('raudspette',),
'raudspetter': ('raudspette',),
'raudstilk': ('raudstilk',),
'raudstilken': ('raudstilk',),
'raudstilkene': ('raudstilk',),
'raudstilker': ('raudstilk',),
'raudstjert': ('raudstjert',),
'raudstjerten': ('raudstjert',),
'raudstjertene': ('raudstjert',),
'raudstjerter': ('raudstjert',),
'raudstrupe': ('raudstrupe',),
'raudstrupen': ('raudstrupe',),
'raudstrupene': ('raudstrupe',),
'raudstruper': ('raudstrupe',),
'raudveng': ('raudveng',),
'raudvengen': ('raudveng',),
'raudvengene': ('raudveng',),
'raudvenger': ('raudveng',),
'raudving': ('raudving',),
'raudvingen': ('raudving',),
'raudvingene': ('raudving',),
'raudvinger': ('raudving',),
'raudvinge': ('raudvinge',),
'raudvingen': ('raudvinge',),
'raudvingene': ('raudvinge',),
'raudvinger': ('raudvinge',),
'raudåta': ('raudåte',),
'raudåte': ('raudåte',),
'raudåten': ('raudåte',),
'raudåtene': ('raudåte',),
'raudåter': ('raudåte',),
'raudåtet': ('raudåte',),
'rauk': ('rauk',),
'rauka': ('rauk',),
'rauken': ('rauk',),
'raukene': ('rauk',),
'rauker': ('rauk',),
'rauket': ('rauk',),
'raus': ('raus',),
'rausa': ('raus',),
'rausen': ('raus',),
'rausene': ('raus',),
'rauser': ('raus',),
'rauset': ('raus',),
'raut': ('raut',),
'rauta': ('raut',),
'rauten': ('raut',),
'rautene': ('raut',),
'rautet': ('raut',),
'rauv': ('rauv',),
'rauva': ('rauv',),
'rauven': ('rauv',),
'rauvene': ('rauv',),
'rauver': ('rauv',),
'rav': ('rav',),
'rava': ('rav',),
'ravene': ('rav',),
'ravet': ('rav',),
'rav': ('rav',),
'rava': ('rav',),
'raven': ('rav',),
'ravene': ('rav',),
'raver': ('rav',),
'ravet': ('rav',),
'ravasje': ('ravasje',),
'ravasjen': ('ravasje',),
'ravasjene': ('ravasje',),
'ravasjer': ('ravasje',),
'ravina': ('ravine',),
'ravine': ('ravine',),
'ravinen': ('ravine',),
'ravinene': ('ravine',),
'raviner': ('ravine',),
'ravioli': ('ravioli',),
'raviolien': ('ravioli',),
'ravioliene': ('ravioli',),
'raviolier': ('ravioli',),
'ravn': ('ravn',),
'ravnen': ('ravn',),
'ravnene': ('ravn',),
'ravner': ('ravn',),
'ravn': ('ravn',),
'ravnen': ('ravn',),
'ravnene': ('ravn',),
'ravner': ('ravn',),
'ravnekrok': ('ravnekrok',),
'ravnekroken': ('ravnekrok',),
'ravnekrokene': ('ravnekrok',),
'ravnekroker': ('ravnekrok',),
'ravnekrok': ('ravnekrok',),
'ravnekroken': ('ravnekrok',),
'ravnekrokene': ('ravnekrok',),
'ravnekroker': ('ravnekrok',),
'rayon': ('rayon',),
'rayona': ('rayon',),
'rayonene': ('rayon',),
'rayonet': ('rayon',),
'razzia': ('razzia',),
'razziaen': ('razzia',),
'razziaene': ('razzia',),
'razziaer': ('razzia',),
're': ('re',),
'ren': ('re',),
'rene': ('re',),
'rer': ('re',),
'reagens': ('reagens',),
'reagensa': ('reagens',),
'reagensen': ('reagens',),
'reagensene': ('reagens',),
'reagenser': ('reagens',),
'reagenset': ('reagens',),
'reagensglass': ('reagensglass',),
'reagensglassa': ('reagensglass',),
'reagensglassene': ('reagensglass',),
'reagensglasset': ('reagensglass',),
'reagensrør': ('reagensrør',),
'reagensrøra': ('reagensrør',),
'reagensrørene': ('reagensrør',),
'reagensrøret': ('reagensrør',),
'reaksjon': ('reaksjon',),
'reaksjonen': ('reaksjon',),
'reaksjonene': ('reaksjon',),
'reaksjoner': ('reaksjon',),
'reaksjonsevna': ('reaksjonsevne',),
'reaksjonsevne': ('reaksjonsevne',),
'reaksjonsevnen': ('reaksjonsevne',),
'reaksjonsevnene': ('reaksjonsevne',),
'reaksjonsevner': ('reaksjonsevne',),
'reaksjonsmotor': ('reaksjonsmotor',),
'reaksjonsmotoren': ('reaksjonsmotor',),
'reaksjonsmotorene': ('reaksjonsmotor',),
'reaksjonsmotorer': ('reaksjonsmotor',),
'reaksjonstid': ('reaksjonstid',),
'reaksjonstida': ('reaksjonstid',),
'reaksjonstiden': ('reaksjonstid',),
'reaksjonstidene': ('reaksjonstid',),
'reaksjonstider': ('reaksjonstid',),
'reaktans': ('reaktans',),
'reaktansen': ('reaktans',),
'reaktansene': ('reaktans',),
'reaktanser': ('reaktans',),
'reaktor': ('reaktor',),
'reaktoren': ('reaktor',),
'reaktorene': ('reaktor',),
'reaktorer': ('reaktor',),
'real': ('real',),
'realartium': ('realartium',),
'realartiumen': ('realartium',),
'realartiumene': ('realartium',),
'realartiumer': ('realartium',),
'realfag': ('realfag',),
'realfaga': ('realfag',),
'realfagene': ('realfag',),
'realfaget': ('realfag',),
'realia': ('realia',),
'realiene': ('realia',),
'realiene': ('realier',),
'realier': ('realier',),
'realisasjon': ('realisasjon',),
'realisasjonen': ('realisasjon',),
'realisasjonene': ('realisasjon',),
'realisasjoner': ('realisasjon',),
'realisasjonspris': ('realisasjonspris',),
'realisasjonsprisen': ('realisasjonspris',),
'realisasjonsprisene': ('realisasjonspris',),
'realisasjonspriser': ('realisasjonspris',),
'realisme': ('realisme',),
'realismen': ('realisme',),
'realismene': ('realisme',),
'realismer': ('realisme',),
'realist': ('realist',),
'realisten': ('realist',),
'realistene': ('realist',),
'realister': ('realist',),
'realitet': ('realitet',),
'realiteten': ('realitet',),
'realitetene': ('realitet',),
'realiteter': ('realitet',),
'realitetsavgjørelse': ('realitetsavgjørelse',),
'realitetsavgjørelsen': ('realitetsavgjørelse',),
'realitetsavgjørelsene': ('realitetsavgjørelse',),
'realitetsavgjørelser': ('realitetsavgjørelse',),
'realitetsforhandling': ('realitetsforhandling',),
'realitetsforhandlinga': ('realitetsforhandling',),
'realitetsforhandlingen': ('realitetsforhandling',),
'realitetsforhandlingene': ('realitetsforhandling',),
'realitetsforhandlinger': ('realitetsforhandling',),
'realkapital': ('realkapital',),
'realkapitalen': ('realkapital',),
'realkapitalene': ('realkapital',),
'realkapitaler': ('realkapital',),
'realkommentar': ('realkommentar',),
'realkommentaren': ('realkommentar',),
'realkommentarene': ('realkommentar',),
'realkommentarer': ('realkommentar',),
'realkreditt': ('realkreditt',),
'realkreditten': ('realkreditt',),
'realkredittene': ('realkreditt',),
'realkreditter': ('realkreditt',),
'realleksika': ('realleksikon',),
'realleksikaene': ('realleksikon',),
'realleksikon': ('realleksikon',),
'realleksikona': ('realleksikon',),
'realleksikonene': ('realleksikon',),
'realleksikoner': ('realleksikon',),
'realleksikonet': ('realleksikon',),
'reallinja': ('reallinje',),
'reallinje': ('reallinje',),
'reallinjen': ('reallinje',),
'reallinjene': ('reallinje',),
'reallinjer': ('reallinje',),
'reallønn': ('reallønn',),
'reallønna': ('reallønn',),
'reallønnen': ('reallønn',),
'reallønnene': ('reallønn',),
'reallønner': ('reallønn',),
'realpolitiker': ('realpolitiker',),
'realpolitikere': ('realpolitiker',),
'realpolitikeren': ('realpolitiker',),
'realpolitikerer': ('realpolitiker',),
'realpolitikerne': ('realpolitiker',),
'realpolitikk': ('realpolitikk',),
'realpolitikken': ('realpolitikk',),
'realpolitikkene': ('realpolitikk',),
'realpolitikker': ('realpolitikk',),
'realskole': ('realskole',),
'realskolen': ('realskole',),
'realskolene': ('realskole',),
'realskoler': ('realskole',),
'realverdi': ('realverdi',),
'realverdien': ('realverdi',),
'realverdiene': ('realverdi',),
'realverdier': ('realverdi',),
'realvitenskap': ('realvitenskap',),
'realvitenskapen': ('realvitenskap',),
'realvitenskapene': ('realvitenskap',),
'realvitenskaper': ('realvitenskap',),
'reassuranse': ('reassuranse',),
'reassuransen': ('reassuranse',),
'reassuransene': ('reassuranse',),
'reassuranser': ('reassuranse',),
'reaumur': ('reaumur',),
'rebell': ('rebell',),
'rebellen': ('rebell',),
'rebellene': ('rebell',),
'rebeller': ('rebell',),
'rebus': ('rebus',),
'rebusen': ('rebus',),
'rebusene': ('rebus',),
'rebuser': ('rebus',),
'rebusløp': ('rebusløp',),
'rebusløpa': ('rebusløp',),
'rebusløpene': ('rebusløp',),
'rebusløpet': ('rebusløp',),
'recensent': ('recensent',),
'recensenten': ('recensent',),
'recensentene': ('recensent',),
'recensenter': ('recensent',),
'recensjon': ('recensjon',),
'recensjonen': ('recensjon',),
'recensjonene': ('recensjon',),
'recensjoner': ('recensjon',),
'recess': ('recess',),
'recessen': ('recess',),
'recessene': ('recess',),
'recesser': ('recess',),
'recessivitet': ('recessivitet',),
'recessiviteten': ('recessivitet',),
'recessivitetene': ('recessivitet',),
'recessiviteter': ('recessivitet',),
'red': ('red',),
'reden': ('red',),
'redene': ('red',),
'reder': ('red',),
'redaksjon': ('redaksjon',),
'redaksjonen': ('redaksjon',),
'redaksjonene': ('redaksjon',),
'redaksjoner': ('redaksjon',),
'redaksjonssekretær': ('redaksjonssekretær',),
'redaksjonssekretæren': ('redaksjonssekretær',),
'redaksjonssekretærene': ('redaksjonssekretær',),
'redaksjonssekretærer': ('redaksjonssekretær',),
'redaktør': ('redaktør',),
'redaktøren': ('redaktør',),
'redaktørene': ('redaktør',),
'redaktører': ('redaktør',),
'redaktørkrakk': ('redaktørkrakk',),
'redaktørkrakken': ('redaktørkrakk',),
'redaktørkrakkene': ('redaktørkrakk',),
'redaktørkrakker': ('redaktørkrakk',),
'reddhare': ('reddhare',),
'reddharen': ('reddhare',),
'reddharene': ('reddhare',),
'reddharer': ('reddhare',),
'reddhug': ('reddhug',),
'reddhugen': ('reddhug',),
'reddhugene': ('reddhug',),
'reddhuger': ('reddhug',),
'reddik': ('reddik',),
'reddiken': ('reddik',),
'reddikene': ('reddik',),
'reddiker': ('reddik',),
'rede': ('rede',),
'reda': ('rede',),
'rede': ('rede',),
'redene': ('rede',),
'reder': ('rede',),
'redet': ('rede',),
'redegjørelse': ('redegjørelse',),
'redegjørelsen': ('redegjørelse',),
'redegjørelsene': ('redegjørelse',),
'redegjørelser': ('redegjørelse',),
'redelighet': ('redelighet',),
'redeligheta': ('redelighet',),
'redeligheten': ('redelighet',),
'redelighetene': ('redelighet',),
'redeligheter': ('redelighet',),
'reder': ('reder',),
'redere': ('reder',),
'rederen': ('reder',),
'rederer': ('reder',),
'rederne': ('reder',),
'rederi': ('rederi',),
'rederia': ('rederi',),
'rederiene': ('rederi',),
'rederier': ('rederi',),
'rederiet': ('rederi',),
'redingot': ('redingot',),
'redingoten': ('redingot',),
'redingotene': ('redingot',),
'redingoter': ('redingot',),
'redline': ('redline',),
'redning': ('redning',),
'redninga': ('redning',),
'redningen': ('redning',),
'redningene': ('redning',),
'redninger': ('redning',),
'redningsbelta': ('redningsbelte',),
'redningsbelte': ('redningsbelte',),
'redningsbeltene': ('redningsbelte',),
'redningsbelter': ('redningsbelte',),
'redningsbeltet': ('redningsbelte',),
'redningskorps': ('redningskorps',),
'redningskorpsa': ('redningskorps',),
'redningskorpsene': ('redningskorps',),
'redningskorpset': ('redningskorps',),
'redningsplanke': ('redningsplanke',),
'redningsplanken': ('redningsplanke',),
'redningsplankene': ('redningsplanke',),
'redningsplanker': ('redningsplanke',),
'redningssentral': ('redningssentral',),
'redningssentralen': ('redningssentral',),
'redningssentralene': ('redningssentral',),
'redningssentraler': ('redningssentral',),
'redningsskøyta': ('redningsskøyte',),
'redningsskøyte': ('redningsskøyte',),
'redningsskøyten': ('redningsskøyte',),
'redningsskøytene': ('redningsskøyte',),
'redningsskøyter': ('redningsskøyte',),
'redningstjeneste': ('redningstjeneste',),
'redningstjenesten': ('redningstjeneste',),
'redningstjenestene': ('redningstjeneste',),
'redningstjenester': ('redningstjeneste',),
'redningsvest': ('redningsvest',),
'redningsvesten': ('redningsvest',),
'redningsvestene': ('redningsvest',),
'redningsvester': ('redningsvest',),
'redoksreaksjon': ('redoksreaksjon',),
'redoksreaksjonen': ('redoksreaksjon',),
'redoksreaksjonene': ('redoksreaksjon',),
'redoksreaksjoner': ('redoksreaksjon',),
'redsel': ('redsel',),
'redselen': ('redsel',),
'redslene': ('redsel',),
'redsler': ('redsel',),
'redselstid': ('redselstid',),
'redselstida': ('redselstid',),
'redselstiden': ('redselstid',),
'redselstidene': ('redselstid',),
'redselstider': ('redselstid',),
'redskap': ('redskap',),
'redskapa': ('redskap',),
'redskapen': ('redskap',),
'redskapene': ('redskap',),
'redskaper': ('redskap',),
'redskapet': ('redskap',),
'redskapsbod': ('redskapsbod',),
'redskapsboden': ('redskapsbod',),
'redskapsbodene': ('redskapsbod',),
'redskapsboder': ('redskapsbod',),
'redskapsbu': ('redskapsbu',),
'redskapsbua': ('redskapsbu',),
'redskapsbuen': ('redskapsbu',),
'redskapsbuene': ('redskapsbu',),
'redskapsbuer': ('redskapsbu',),
'reduksjon': ('reduksjon',),
'reduksjonen': ('reduksjon',),
'reduksjonene': ('reduksjon',),
'reduksjoner': ('reduksjon',),
'reduksjonisme': ('reduksjonisme',),
'reduksjonismen': ('reduksjonisme',),
'reduksjonismene': ('reduksjonisme',),
'reduksjonismer': ('reduksjonisme',),
'reduksjonsdeling': ('reduksjonsdeling',),
'reduksjonsdelinga': ('reduksjonsdeling',),
'reduksjonsdelingen': ('reduksjonsdeling',),
'reduksjonsdelingene': ('reduksjonsdeling',),
'reduksjonsdelinger': ('reduksjonsdeling',),
'reduksjonsmiddel': ('reduksjonsmiddel',),
'reduksjonsmiddelet': ('reduksjonsmiddel',),
'reduksjonsmidla': ('reduksjonsmiddel',),
'reduksjonsmidlene': ('reduksjonsmiddel',),
'reduksjonsmidler': ('reduksjonsmiddel',),
'reduksjonsmidlet': ('reduksjonsmiddel',),
'reduksjonstabell': ('reduksjonstabell',),
'reduksjonstabellen': ('reduksjonstabell',),
'reduksjonstabellene': ('reduksjonstabell',),
'reduksjonstabeller': ('reduksjonstabell',),
'reduksjonsventil': ('reduksjonsventil',),
'reduksjonsventilen': ('reduksjonsventil',),
'reduksjonsventilene': ('reduksjonsventil',),
'reduksjonsventiler': ('reduksjonsventil',),
'redundans': ('redundans',),
'redundansen': ('redundans',),
'redundansene': ('redundans',),
'redundanser': ('redundans',),
'reduplikasjon': ('reduplikasjon',),
'reduplikasjonen': ('reduplikasjon',),
'reduplikasjonene': ('reduplikasjon',),
'reduplikasjoner': ('reduplikasjon',),
'reel': ('reel',),
'reelen': ('reel',),
'reelene': ('reel',),
'reeler': ('reel',),
'refektoria': ('refektorium',),
'refektoriene': ('refektorium',),
'refektorier': ('refektorium',),
'refektoriet': ('refektorium',),
'refektorium': ('refektorium',),
'referanse': ('referanse',),
'referansen': ('referanse',),
'referansene': ('referanse',),
'referanser': ('referanse',),
'referansebibliotek': ('referansebibliotek',),
'referansebiblioteka': ('referansebibliotek',),
'referansebibliotekene': ('referansebibliotek',),
'referansebiblioteker': ('referansebibliotek',),
'referansebiblioteket': ('referansebibliotek',),
'referanseramma': ('referanseramme',),
'referanseramme': ('referanseramme',),
'referanserammen': ('referanseramme',),
'referanserammene': ('referanseramme',),
'referanserammer': ('referanseramme',),
'referat': ('referat',),
'referata': ('referat',),
'referatene': ('referat',),
'referater': ('referat',),
'referatet': ('referat',),
'referenda': ('referendum',),
'referendaene': ('referendum',),
'referendum': ('referendum',),
'referenduma': ('referendum',),
'referendumene': ('referendum',),
'referendumer': ('referendum',),
'referendumet': ('referendum',),
'referent': ('referent',),
'referenten': ('referent',),
'referentene': ('referent',),
'referenter': ('referent',),
'refill': ('refill',),
'refillen': ('refill',),
'refillene': ('refill',),
'refiller': ('refill',),
'refleks': ('refleks',),
'refleksen': ('refleks',),
'refleksene': ('refleks',),
'reflekser': ('refleks',),
'refleksbevegelse': ('refleksbevegelse',),
'refleksbevegelsen': ('refleksbevegelse',),
'refleksbevegelsene': ('refleksbevegelse',),
'refleksbevegelser': ('refleksbevegelse',),
'refleksbrikka': ('refleksbrikke',),
'refleksbrikke': ('refleksbrikke',),
'refleksbrikken': ('refleksbrikke',),
'refleksbrikkene': ('refleksbrikke',),
'refleksbrikker': ('refleksbrikke',),
'refleksiv': ('refleksiv',),
'refleksiva': ('refleksiv',),
'refleksivene': ('refleksiv',),
'refleksiver': ('refleksiv',),
'refleksivet': ('refleksiv',),
'refleksjon': ('refleksjon',),
'refleksjonen': ('refleksjon',),
'refleksjonene': ('refleksjon',),
'refleksjoner': ('refleksjon',),
'refleksjonskikkert': ('refleksjonskikkert',),
'refleksjonskikkerten': ('refleksjonskikkert',),
'refleksjonskikkertene': ('refleksjonskikkert',),
'refleksjonskikkerter': ('refleksjonskikkert',),
'reflektant': ('reflektant',),
'reflektanten': ('reflektant',),
'reflektantene': ('reflektant',),
'reflektanter': ('reflektant',),
'reflektor': ('reflektor',),
'reflektoren': ('reflektor',),
'reflektorene': ('reflektor',),
'reflektorer': ('reflektor',),
'reflektoromn': ('reflektoromn',),
'reflektoromnen': ('reflektoromn',),
'reflektoromnene': ('reflektoromn',),
'reflektoromner': ('reflektoromn',),
'reflektorovn': ('reflektorovn',),
'reflektorovnen': ('reflektorovn',),
'reflektorovnene': ('reflektorovn',),
'reflektorovner': ('reflektorovn',),
'reform': ('reform',),
'reformen': ('reform',),
'reformene': ('reform',),
'reformer': ('reform',),
'reformasjon': ('reformasjon',),
'reformasjonen': ('reformasjon',),
'reformasjonene': ('reformasjon',),
'reformasjoner': ('reformasjon',),
'reformator': ('reformator',),
'reformatoren': ('reformator',),
'reformatorene': ('reformator',),
'reformatorer': ('reformator',),
'reformgymnas': ('reformgymnas',),
'reformgymnasa': ('reformgymnas',),
'reformgymnasene': ('reformgymnas',),
'reformgymnaser': ('reformgymnas',),
'reformgymnaset': ('reformgymnas',),
'reformisme': ('reformisme',),
'reformismen': ('reformisme',),
'reformismene': ('reformisme',),
'reformismer': ('reformisme',),
'reformist': ('reformist',),
'reformisten': ('reformist',),
'reformistene': ('reformist',),
'reformister': ('reformist',),
'reformparti': ('reformparti',),
'reformpartia': ('reformparti',),
'reformpartiene': ('reformparti',),
'reformpartier': ('reformparti',),
'reformpartiet': ('reformparti',),
'refraksjon': ('refraksjon',),
'refraksjonen': ('refraksjon',),
'refraksjonene': ('refraksjon',),
'refraksjoner': ('refraksjon',),
'refreng': ('refreng',),
'refrenga': ('refreng',),
'refrengene': ('refreng',),
'refrenger': ('refreng',),
'refrenget': ('refreng',),
'refs': ('refs',),
'refsen': ('refs',),
'refsene': ('refs',),
'refser': ('refs',),
'refselse': ('refselse',),
'refselsen': ('refselse',),
'refselsene': ('refselse',),
'refselser': ('refselse',),
'refser': ('refser',),
'refsere': ('refser',),
'refseren': ('refser',),
'refserer': ('refser',),
'refserne': ('refser',),
'refuge': ('refuge',),
'refugen': ('refuge',),
'refugene': ('refuge',),
'refuger': ('refuge',),
'refusjon': ('refusjon',),
'refusjonen': ('refusjon',),
'refusjonene': ('refusjon',),
'refusjoner': ('refusjon',),
'refusnik': ('refusnik',),
'refusniken': ('refusnik',),
'refusnikene': ('refusnik',),
'refusniker': ('refusnik',),
'regala': ('regale',),
'regale': ('regale',),
'regalene': ('regale',),
'regaler': ('regale',),
'regalet': ('regale',),
'regaliene': ('regalier',),
'regalier': ('regalier',),
'regatta': ('regatta',),
'regattaen': ('regatta',),
'regattaene': ('regatta',),
'regattaer': ('regatta',),
'regel': ('regel',),
'regelen': ('regel',),
'reglene': ('regel',),
'regler': ('regel',),
'regelverk': ('regelverk',),
'regelverka': ('regelverk',),
'regelverkene': ('regelverk',),
'regelverker': ('regelverk',),
'regelverket': ('regelverk',),
'regenerasjon': ('regenerasjon',),
'regenerasjonen': ('regenerasjon',),
'regenerasjonene': ('regenerasjon',),
'regenerasjoner': ('regenerasjon',),
'regent': ('regent',),
'regenten': ('regent',),
'regentene': ('regent',),
'regenter': ('regent',),
'regentskap': ('regentskap',),
'regentskapa': ('regentskap',),
'regentskapene': ('regentskap',),
'regentskaper': ('regentskap',),
'regentskapet': ('regentskap',),
'regest': ('regest',),
'regesten': ('regest',),
'regestene': ('regest',),
'regester': ('regest',),
'reggae': ('reggae',),
'reggaen': ('reggae',),
'reggaene': ('reggae',),
'reggaer': ('reggae',),
'regi': ('regi',),
'regien': ('regi',),
'regiene': ('regi',),
'regier': ('regi',),
'regima': ('regime',),
'regime': ('regime',),
'regimene': ('regime',),
'regimer': ('regime',),
'regimet': ('regime',),
'regiment': ('regiment',),
'regimenta': ('regiment',),
'regimentene': ('regiment',),
'regimenter': ('regiment',),
'regimentet': ('regiment',),
'regimenta': ('regimente',),
'regimente': ('regimente',),
'regimentene': ('regimente',),
'regimenter': ('regimente',),
'regimentet': ('regimente',),
'regina': ('regina',),
'reginaen': ('regina',),
'reginaene': ('regina',),
'reginaer': ('regina',),
'region': ('region',),
'regionen': ('region',),
'regionene': ('region',),
'regioner': ('region',),
'regionalisme': ('regionalisme',),
'regionalismen': ('regionalisme',),
'regionalismene': ('regionalisme',),
'regionalismer': ('regionalisme',),
'regionplan': ('regionplan',),
'regionplanen': ('regionplan',),
'regionplanene': ('regionplan',),
'regionplaner': ('regionplan',),
'regionsjukehus': ('regionsjukehus',),
'regionsjukehusa': ('regionsjukehus',),
'regionsjukehusene': ('regionsjukehus',),
'regionsjukehuset': ('regionsjukehus',),
'regionsplan': ('regionsplan',),
'regionsplanen': ('regionsplan',),
'regionsplanene': ('regionsplan',),
'regionsplaner': ('regionsplan',),
'regionssjukehus': ('regionssjukehus',),
'regionssjukehusa': ('regionssjukehus',),
'regionssjukehusene': ('regionssjukehus',),
'regionssjukehuset': ('regionssjukehus',),
'regionssykehus': ('regionssykehus',),
'regionssykehusa': ('regionssykehus',),
'regionssykehusene': ('regionssykehus',),
'regionssykehuset': ('regionssykehus',),
'regionsteater': ('regionsteater',),
'regionsteateret': ('regionsteater',),
'regionsteatra': ('regionsteater',),
'regionsteatre': ('regionsteater',),
'regionsteatrene': ('regionsteater',),
'regionsteatret': ('regionsteater',),
'regionsykehus': ('regionsykehus',),
'regionsykehusa': ('regionsykehus',),
'regionsykehusene': ('regionsykehus',),
'regionsykehuset': ('regionsykehus',),
'regionteater': ('regionteater',),
'regionteateret': ('regionteater',),
'regionteatra': ('regionteater',),
'regionteatre': ('regionteater',),
'regionteatrene': ('regionteater',),
'regionteatret': ('regionteater',),
'regissør': ('regissør',),
'regissøren': ('regissør',),
'regissørene': ('regissør',),
'regissører': ('regissør',),
'register': ('register',),
'registeret': ('register',),
'registra': ('register',),
'registre': ('register',),
'registrene': ('register',),
'registret': ('register',),
'registertonn': ('registertonn',),
'registertonna': ('registertonn',),
'registertonnene': ('registertonn',),
'registertonnet': ('registertonn',),
'registrant': ('registrant',),
'registranten': ('registrant',),
'registrantene': ('registrant',),
'registranter': ('registrant',),
'registrator': ('registrator',),
'registratoren': ('registrator',),
'registratorene': ('registrator',),
'registratorer': ('registrator',),
'regjering': ('regjering',),
'regjeringa': ('regjering',),
'regjeringen': ('regjering',),
'regjeringene': ('regjering',),
'regjeringer': ('regjering',),
'regjeringsadvokat': ('regjeringsadvokat',),
'regjeringsadvokaten': ('regjeringsadvokat',),
'regjeringsadvokatene': ('regjeringsadvokat',),
'regjeringsadvokater': ('regjeringsadvokat',),
'regjeringsflertall': ('regjeringsflertall',),
'regjeringsflertalla': ('regjeringsflertall',),
'regjeringsflertallene': ('regjeringsflertall',),
'regjeringsflertallet': ('regjeringsflertall',),
'regjeringsparti': ('regjeringsparti',),
'regjeringspartia': ('regjeringsparti',),
'regjeringspartiene': ('regjeringsparti',),
'regjeringspartier': ('regjeringsparti',),
'regjeringspartiet': ('regjeringsparti',),
'regla': ('regle',),
'regle': ('regle',),
'reglen': ('regle',),
'reglene': ('regle',),
'regler': ('regle',),
'reglement': ('reglement',),
'reglementa': ('reglement',),
'reglementene': ('reglement',),
'reglementer': ('reglement',),
'reglementet': ('reglement',),
'reglesmed': ('reglesmed',),
'reglesmeden': ('reglesmed',),
'reglesmedene': ('reglesmed',),
'reglesmeder': ('reglesmed',),
'regn': ('regn',),
'regna': ('regn',),
'regnene': ('regn',),
'regnet': ('regn',),
'regnboge': ('regnboge',),
'regnbogen': ('regnboge',),
'regnbogene': ('regnboge',),
'regnboger': ('regnboge',),
'regnbogeaure': ('regnbogeaure',),
'regnbogeauren': ('regnbogeaure',),
'regnbogeaurene': ('regnbogeaure',),
'regnbogeaurer': ('regnbogeaure',),
'regnbogeørret': ('regnbogeørret',),
'regnbogeørreten': ('regnbogeørret',),
'regnbogeørretene': ('regnbogeørret',),
'regnbogeørreter': ('regnbogeørret',),
'regnbue': ('regnbue',),
'regnbuen': ('regnbue',),
'regnbuene': ('regnbue',),
'regnbuer': ('regnbue',),
'regnbueaure': ('regnbueaure',),
'regnbueauren': ('regnbueaure',),
'regnbueaurene': ('regnbueaure',),
'regnbueaurer': ('regnbueaure',),
'regnbueørret': ('regnbueørret',),
'regnbueørreten': ('regnbueørret',),
'regnbueørretene': ('regnbueørret',),
'regnbueørreter': ('regnbueørret',),
'regnbya': ('regnbye',),
'regnbye': ('regnbye',),
'regnbyen': ('regnbye',),
'regnbyene': ('regnbye',),
'regnbyer': ('regnbye',),
'regnbyga': ('regnbyge',),
'regnbyge': ('regnbyge',),
'regnbygen': ('regnbyge',),
'regnbygene': ('regnbyge',),
'regnbyger': ('regnbyge',),
'regnbøya': ('regnbøye',),
'regnbøye': ('regnbøye',),
'regnbøyen': ('regnbøye',),
'regnbøyene': ('regnbøye',),
'regnbøyer': ('regnbøye',),
'regndråpe': ('regndråpe',),
'regndråpen': ('regndråpe',),
'regndråpene': ('regndråpe',),
'regndråper': ('regndråpe',),
'regneark': ('regneark',),
'regnearka': ('regneark',),
'regnearkene': ('regneark',),
'regnearket': ('regneark',),
'regneark': ('regneark',),
'regnearka': ('regneark',),
'regnearkene': ('regneark',),
'regnearket': ('regneark',),
'regneart': ('regneart',),
'regnearta': ('regneart',),
'regnearten': ('regneart',),
'regneartene': ('regneart',),
'regnearter': ('regneart',),
'regneart': ('regneart',),
'regnearta': ('regneart',),
'regnearten': ('regneart',),
'regneartene': ('regneart',),
'regnearter': ('regneart',),
'regnemaskin': ('regnemaskin',),
'regnemaskina': ('regnemaskin',),
'regnemaskinen': ('regnemaskin',),
'regnemaskinene': ('regnemaskin',),
'regnemaskiner': ('regnemaskin',),
'regnemaskin': ('regnemaskin',),
'regnemaskina': ('regnemaskin',),
'regnemaskinen': ('regnemaskin',),
'regnemaskinene': ('regnemaskin',),
'regnemaskiner': ('regnemaskin',),
'regnemester': ('regnemester',),
'regnemestere': ('regnemester',),
'regnemesteren': ('regnemester',),
'regnemesterer': ('regnemester',),
'regnemesterne': ('regnemester',),
'regnemestre': ('regnemester',),
'regnemestrene': ('regnemester',),
'regnemestrer': ('regnemester',),
'regnemester': ('regnemester',),
'regnemestere': ('regnemester',),
'regnemesteren': ('regnemester',),
'regnemesterer': ('regnemester',),
'regnemesterne': ('regnemester',),
'regnemestre': ('regnemester',),
'regnemestrene': ('regnemester',),
'regnemestrer': ('regnemester',),
'regnestav': ('regnestav',),
'regnestaven': ('regnestav',),
'regnestavene': ('regnestav',),
'regnestaver': ('regnestav',),
'regnestav': ('regnestav',),
'regnestaven': ('regnestav',),
'regnestavene': ('regnestav',),
'regnestaver': ('regnestav',),
'regnestykka': ('regnestykke',),
'regnestykke': ('regnestykke',),
'regnestykkene': ('regnestykke',),
'regnestykker': ('regnestykke',),
'regnestykket': ('regnestykke',),
'regnestykka': ('regnestykke',),
'regnestykke': ('regnestykke',),
'regnestykkene': ('regnestykke',),
'regnestykker': ('regnestykke',),
'regnestykket': ('regnestykke',),
'regnfrakk': ('regnfrakk',),
'regnfrakken': ('regnfrakk',),
'regnfrakkene': ('regnfrakk',),
'regnfrakker': ('regnfrakk',),
'regning': ('regning',),
'regninga': ('regning',),
'regningen': ('regning',),
'regningene': ('regning',),
'regninger': ('regning',),
'regning': ('regning',),
'regninga': ('regning',),
'regningen': ('regning',),
'regningene': ('regning',),
'regninger': ('regning',),
'regningsart': ('regningsart',),
'regningsarta': ('regningsart',),
'regningsarten': ('regningsart',),
'regningsartene': ('regningsart',),
'regningsarter': ('regningsart',),
'regningsart': ('regningsart',),
'regningsarta': ('regningsart',),
'regningsarten': ('regningsart',),
'regningsartene': ('regningsart',),
'regningsarter': ('regningsart',),
'regnkappa': ('regnkappe',),
'regnkappe': ('regnkappe',),
'regnkappen': ('regnkappe',),
'regnkappene': ('regnkappe',),
'regnkapper': ('regnkappe',),
'regnklær': ('regnklær',),
'regnklærne': ('regnklær',),
'regnskap': ('regnskap',),
'regnskapa': ('regnskap',),
'regnskapene': ('regnskap',),
'regnskaper': ('regnskap',),
'regnskapet': ('regnskap',),
'regnskap': ('regnskap',),
'regnskapa': ('regnskap',),
'regnskapene': ('regnskap',),
'regnskaper': ('regnskap',),
'regnskapet': ('regnskap',),
'regnskapsfører': ('regnskapsfører',),
'regnskapsførere': ('regnskapsfører',),
'regnskapsføreren': ('regnskapsfører',),
'regnskapsførerer': ('regnskapsfører',),
'regnskapsførerne': ('regnskapsfører',),
'regnskapsfører': ('regnskapsfører',),
'regnskapsførere': ('regnskapsfører',),
'regnskapsføreren': ('regnskapsfører',),
'regnskapsførerer': ('regnskapsfører',),
'regnskapsførerne': ('regnskapsfører',),
'regnskapsførsel': ('regnskapsførsel',),
'regnskapsførselen': ('regnskapsførsel',),
'regnskapsførslene': ('regnskapsførsel',),
'regnskapsførsler': ('regnskapsførsel',),
'regnskapsførsel': ('regnskapsførsel',),
'regnskapsførselen': ('regnskapsførsel',),
'regnskapsførslene': ('regnskapsførsel',),
'regnskapsførsler': ('regnskapsførsel',),
'regnskog': ('regnskog',),
'regnskogen': ('regnskog',),
'regnskogene': ('regnskog',),
'regnskoger': ('regnskog',),
'regnskur': ('regnskur',),
'regnskura': ('regnskur',),
'regnskuren': ('regnskur',),
'regnskurene': ('regnskur',),
'regnskurer': ('regnskur',),
'regnskygge': ('regnskygge',),
'regnskyggen': ('regnskygge',),
'regnskyggene': ('regnskygge',),
'regnskygger': ('regnskygge',),
'regnskyll': ('regnskyll',),
'regnskylla': ('regnskyll',),
'regnskyllene': ('regnskyll',),
'regnskyllet': ('regnskyll',),
'regnslag': ('regnslag',),
'regnslaga': ('regnslag',),
'regnslagene': ('regnslag',),
'regnslaget': ('regnslag',),
'regntid': ('regntid',),
'regntida': ('regntid',),
'regntiden': ('regntid',),
'regntidene': ('regntid',),
'regntider': ('regntid',),
'regntøy': ('regntøy',),
'regntøya': ('regntøy',),
'regntøyene': ('regntøy',),
'regntøyet': ('regntøy',),
'regnvær': ('regnvær',),
'regnværa': ('regnvær',),
'regnværene': ('regnvær',),
'regnværet': ('regnvær',),
'regresjon': ('regresjon',),
'regresjonen': ('regresjon',),
'regresjonene': ('regresjon',),
'regresjoner': ('regresjon',),
'regress': ('regress',),
'regressen': ('regress',),
'regressene': ('regress',),
'regresser': ('regress',),
'reguladetri': ('reguladetri',),
'reguladetrien': ('reguladetri',),
'reguladetriene': ('reguladetri',),
'reguladetrier': ('reguladetri',),
'regulant': ('regulant',),
'regulanten': ('regulant',),
'regulantene': ('regulant',),
'regulanter': ('regulant',),
'regularitet': ('regularitet',),
'regulariteten': ('regularitet',),
'regularitetene': ('regularitet',),
'regulariteter': ('regularitet',),
'regulativ': ('regulativ',),
'regulativa': ('regulativ',),
'regulativene': ('regulativ',),
'regulativer': ('regulativ',),
'regulativet': ('regulativ',),
'regulator': ('regulator',),
'regulatoren': ('regulator',),
'regulatorene': ('regulator',),
'regulatorer': ('regulator',),
'reguleringsplan': ('reguleringsplan',),
'reguleringsplanen': ('reguleringsplan',),
'reguleringsplanene': ('reguleringsplan',),
'reguleringsplaner': ('reguleringsplan',),
'regulær': ('regulær',),
'regulæra': ('regulær',),
'regulæren': ('regulær',),
'regulærene': ('regulær',),
'regulærer': ('regulær',),
'rehabilitering': ('rehabilitering',),
'rehabiliteringa': ('rehabilitering',),
'rehabiliteringen': ('rehabilitering',),
'rehabiliteringene': ('rehabilitering',),
'rehabiliteringer': ('rehabilitering',),
'rei': ('rei',),
'reia': ('rei',),
'reien': ('rei',),
'reiene': ('rei',),
'reier': ('rei',),
'reik': ('reik',),
'reika': ('reik',),
'reiken': ('reik',),
'reikene': ('reik',),
'reiker': ('reik',),
'reil': ('reil',),
'reilen': ('reil',),
'reilene': ('reil',),
'reiler': ('reil',),
'reile': ('reile',),
'reilen': ('reile',),
'reilene': ('reile',),
'reiler': ('reile',),
'reim': ('reim',),
'reima': ('reim',),
'reimen': ('reim',),
'reimene': ('reim',),
'reimer': ('reim',),
'reimskiva': ('reimskive',),
'reimskive': ('reimskive',),
'reimskiven': ('reimskive',),
'reimskivene': ('reimskive',),
'reimskiver': ('reimskive',),
'reinblom': ('reinblom',),
'reinblommen': ('reinblom',),
'reinblommene': ('reinblom',),
'reinblommer': ('reinblom',),
'reinbukk': ('reinbukk',),
'reinbukken': ('reinbukk',),
'reinbukkene': ('reinbukk',),
'reinbukker': ('reinbukk',),
'reindrift': ('reindrift',),
'reindrifta': ('reindrift',),
'reindriften': ('reindrift',),
'reindriftene': ('reindrift',),
'reindrifter': ('reindrift',),
'reindriftsagronom': ('reindriftsagronom',),
'reindriftsagronomen': ('reindriftsagronom',),
'reindriftsagronomene': ('reindriftsagronom',),
'reindriftsagronomer': ('reindriftsagronom',),
'reineclaude': ('reineclaude',),
'reineclauden': ('reineclaude',),
'reineclaudene': ('reineclaude',),
'reineclauder': ('reineclaude',),
'reinfann': ('reinfann',),
'reinfannen': ('reinfann',),
'reinfannene': ('reinfann',),
'reinfanner': ('reinfann',),
'reingjøringsbyrå': ('reingjøringsbyrå',),
'reingjøringsbyråa': ('reingjøringsbyrå',),
'reingjøringsbyråene': ('reingjøringsbyrå',),
'reingjøringsbyråer': ('reingjøringsbyrå',),
'reingjøringsbyrået': ('reingjøringsbyrå',),
'reingrav': ('reingrav',),
'reingrava': ('reingrav',),
'reingraven': ('reingrav',),
'reingravene': ('reingrav',),
'reingraver': ('reingrav',),
'reinhet': ('reinhet',),
'reinheta': ('reinhet',),
'reinheten': ('reinhet',),
'reinhetene': ('reinhet',),
'reinheter': ('reinhet',),
'reinhold': ('reinhold',),
'reinholda': ('reinhold',),
'reinholdene': ('reinhold',),
'reinholdet': ('reinhold',),
'reinkarnasjon': ('reinkarnasjon',),
'reinkarnasjonen': ('reinkarnasjon',),
'reinkarnasjonene': ('reinkarnasjon',),
'reinkarnasjoner': ('reinkarnasjon',),
'reinlav': ('reinlav',),
'reinlava': ('reinlav',),
'reinlaven': ('reinlav',),
'reinlavene': ('reinlav',),
'reinlaver': ('reinlav',),
'reinlavet': ('reinlav',),
'reinlender': ('reinlender',),
'reinlendere': ('reinlender',),
'reinlenderen': ('reinlender',),
'reinlenderer': ('reinlender',),
'reinlenderne': ('reinlender',),
'reinmose': ('reinmose',),
'reinmosen': ('reinmose',),
'reinmosene': ('reinmose',),
'reinmoser': ('reinmose',),
'reinrosa': ('reinrose',),
'reinrose': ('reinrose',),
'reinrosen': ('reinrose',),
'reinrosene': ('reinrose',),
'reinroser': ('reinrose',),
'reinsdyr': ('reinsdyr',),
'reinsdyra': ('reinsdyr',),
'reinsdyrene': ('reinsdyr',),
'reinsdyret': ('reinsdyr',),
'reinslighet': ('reinslighet',),
'reinsligheta': ('reinslighet',),
'reinsligheten': ('reinslighet',),
'reinslighetene': ('reinslighet',),
'reinsligheter': ('reinslighet',),
'reip': ('reip',),
'reipa': ('reip',),
'reipene': ('reip',),
'reipet': ('reip',),
'reiphelda': ('reiphelde',),
'reiphelde': ('reiphelde',),
'reiphelden': ('reiphelde',),
'reipheldene': ('reiphelde',),
'reiphelder': ('reiphelde',),
'reipslager': ('reipslager',),
'reipslagere': ('reipslager',),
'reipslageren': ('reipslager',),
'reipslagerer': ('reipslager',),
'reipslagerne': ('reipslager',),
'reir': ('reir',),
'reira': ('reir',),
'reirene': ('reir',),
'reiret': ('reir',),
'reis': ('reis',),
'reisa': ('reis',),
'reisene': ('reis',),
'reiset': ('reis',),
'reis': ('reis',),
'reisa': ('reis',),
'reisen': ('reis',),
'reisene': ('reis',),
'reiser': ('reis',),
'reisa': ('reise',),
'reise': ('reise',),
'reisen': ('reise',),
'reisene': ('reise',),
'reiser': ('reise',),
'reisebyrå': ('reisebyrå',),
'reisebyråa': ('reisebyrå',),
'reisebyråene': ('reisebyrå',),
'reisebyråer': ('reisebyrå',),
'reisebyrået': ('reisebyrå',),
'reisefeber': ('reisefeber',),
'reisefebere': ('reisefeber',),
'reisefeberen': ('reisefeber',),
'reisefeberer': ('reisefeber',),
'reisefeberne': ('reisefeber',),
'reisefebre': ('reisefeber',),
'reisefebrene': ('reisefeber',),
'reisefebrer': ('reisefeber',),
'reisefelle': ('reisefelle',),
'reisefellen': ('reisefelle',),
'reisefellene': ('reisefelle',),
'reisefeller': ('reisefelle',),
'reisefjernsyn': ('reisefjernsyn',),
'reisefjernsyna': ('reisefjernsyn',),
'reisefjernsynene': ('reisefjernsyn',),
'reisefjernsynet': ('reisefjernsyn',),
'reisegods': ('reisegods',),
'reisegodsa': ('reisegods',),
'reisegodsene': ('reisegods',),
'reisegodset': ('reisegods',),
'reiseleder': ('reiseleder',),
'reiseledere': ('reiseleder',),
'reiselederen': ('reiseleder',),
'reiselederer': ('reiseleder',),
'reiselederne': ('reiseleder',),
'reisemål': ('reisemål',),
'reisemåla': ('reisemål',),
'reisemålene': ('reisemål',),
'reisemålet': ('reisemål',),
'reisende': ('reisende',),
'reisenden': ('reisende',),
'reisendene': ('reisende',),
'reisender': ('reisende',),
'reisepass': ('reisepass',),
'reiseradio': ('reiseradio',),
'reiseradioen': ('reiseradio',),
'reiseradioene': ('reiseradio',),
'reiseradioer': ('reiseradio',),
'reisesjekk': ('reisesjekk',),
'reisesjekken': ('reisesjekk',),
'reisesjekkene': ('reisesjekk',),
'reisesjekker': ('reisesjekk',),
'reiseskildring': ('reiseskildring',),
'reiseskildringa': ('reiseskildring',),
'reiseskildringen': ('reiseskildring',),
'reiseskildringene': ('reiseskildring',),
'reiseskildringer': ('reiseskildring',),
'reisning': ('reisning',),
'reisninga': ('reisning',),
'reisningen': ('reisning',),
'reisningene': ('reisning',),
'reisninger': ('reisning',),
'reisved': ('reisved',),
'reisveden': ('reisved',),
'reisvedene': ('reisved',),
'reisveder': ('reisved',),
'reisverk': ('reisverk',),
'reisverka': ('reisverk',),
'reisverkene': ('reisverk',),
'reisverker': ('reisverk',),
'reisverket': ('reisverk',),
'reit': ('reit',),
'reiten': ('reit',),
'reitene': ('reit',),
'reiter': ('reit',),
'reit': ('reit',),
'reita': ('reit',),
'reiten': ('reit',),
'reitene': ('reit',),
'reiter': ('reit',),
'reiv': ('reiv',),
'reiven': ('reiv',),
'reivene': ('reiv',),
'reiver': ('reiv',),
'reiv': ('reiv',),
'reiven': ('reiv',),
'reivene': ('reiv',),
'reiver': ('reiv',),
'reivebarn': ('reivebarn',),
'reivebarna': ('reivebarn',),
'reivebarnene': ('reivebarn',),
'reivebarnet': ('reivebarn',),
'reivunge': ('reivunge',),
'reivungen': ('reivunge',),
'reivungene': ('reivunge',),
'reivunger': ('reivunge',),
'rejeksjon': ('rejeksjon',),
'rejeksjonen': ('rejeksjon',),
'rejeksjonene': ('rejeksjon',),
'rejeksjoner': ('rejeksjon',),
'rek': ('rek',),
'reka': ('rek',),
'rekene': ('rek',),
'reket': ('rek',),
'rekambio': ('rekambio',),
'rekambioen': ('rekambio',),
'rekambioene': ('rekambio',),
'rekambioer': ('rekambio',),
'rekambiokonti': ('rekambiokonto',),
'rekambiokontiene': ('rekambiokonto',),
'rekambiokonto': ('rekambiokonto',),
'rekambiokontoen': ('rekambiokonto',),
'rekambiokontoene': ('rekambiokonto',),
'rekambiokontoer': ('rekambiokonto',),
'rekambioveksel': ('rekambioveksel',),
'rekambiovekselen': ('rekambioveksel',),
'rekambiovekslene': ('rekambioveksel',),
'rekambioveksler': ('rekambioveksel',),
'rekapitulasjon': ('rekapitulasjon',),
'rekapitulasjonen': ('rekapitulasjon',),
'rekapitulasjonene': ('rekapitulasjon',),
'rekapitulasjoner': ('rekapitulasjon',),
'reka': ('reke',),
'reke': ('reke',),
'reken': ('reke',),
'rekene': ('reke',),
'reker': ('reke',),
'reka': ('reke',),
'reke': ('reke',),
'reken': ('reke',),
'rekene': ('reke',),
'reker': ('reke',),
'rekel': ('rekel',),
'rekelen': ('rekel',),
'rekelet': ('rekel',),
'rekla': ('rekel',),
'reklene': ('rekel',),
'rekler': ('rekel',),
'reklet': ('rekel',),
'reketråler': ('reketråler',),
'reketrålere': ('reketråler',),
'reketråleren': ('reketråler',),
'reketrålerer': ('reketråler',),
'reketrålerne': ('reketråler',),
'rekka': ('rekke',),
'rekke': ('rekke',),
'rekken': ('rekke',),
'rekkene': ('rekke',),
'rekker': ('rekke',),
'rekka': ('rekke',),
'rekke': ('rekke',),
'rekken': ('rekke',),
'rekkene': ('rekke',),
'rekker': ('rekke',),
'rekkefølga': ('rekkefølge',),
'rekkefølge': ('rekkefølge',),
'rekkefølgen': ('rekkefølge',),
'rekkefølgene': ('rekkefølge',),
'rekkefølger': ('rekkefølge',),
'rekkehus': ('rekkehus',),
'rekkehusa': ('rekkehus',),
'rekkehusene': ('rekkehus',),
'rekkehuset': ('rekkehus',),
'rekketall': ('rekketall',),
'rekketalla': ('rekketall',),
'rekketallene': ('rekketall',),
'rekketallet': ('rekketall',),
'rekkevidda': ('rekkevidde',),
'rekkevidde': ('rekkevidde',),
'rekkevidden': ('rekkevidde',),
'rekkeviddene': ('rekkevidde',),
'rekkevidder': ('rekkevidde',),
'rekkverk': ('rekkverk',),
'rekkverka': ('rekkverk',),
'rekkverkene': ('rekkverk',),
'rekkverket': ('rekkverk',),
'reklamasjon': ('reklamasjon',),
'reklamasjonen': ('reklamasjon',),
'reklamasjonene': ('reklamasjon',),
'reklamasjoner': ('reklamasjon',),
'reklamasjonrett': ('reklamasjonrett',),
'reklamasjonretten': ('reklamasjonrett',),
'reklamasjonrettene': ('reklamasjonrett',),
'reklamasjonretter': ('reklamasjonrett',),
'reklame': ('reklame',),
'reklamen': ('reklame',),
'reklamene': ('reklame',),
'reklamer': ('reklame',),
'reklamebyrå': ('reklamebyrå',),
'reklamebyråa': ('reklamebyrå',),
'reklamebyråene': ('reklamebyrå',),
'reklamebyråer': ('reklamebyrå',),
'reklamebyrået': ('reklamebyrå',),
'reklamemateriell': ('reklamemateriell',),
'reklamemateriella': ('reklamemateriell',),
'reklamemateriellene': ('reklamemateriell',),
'reklamemateriellet': ('reklamemateriell',),
'rekling': ('rekling',),
'reklingen': ('rekling',),
'reklingene': ('rekling',),
'reklinger': ('rekling',),
'rekneark': ('rekneark',),
'reknearka': ('rekneark',),
'reknearkene': ('rekneark',),
'reknearket': ('rekneark',),
'rekneark': ('rekneark',),
'reknearka': ('rekneark',),
'reknearkene': ('rekneark',),
'reknearket': ('rekneark',),
'rekneart': ('rekneart',),
'reknearta': ('rekneart',),
'reknearten': ('rekneart',),
'rekneartene': ('rekneart',),
'reknearter': ('rekneart',),
'rekneart': ('rekneart',),
'reknearta': ('rekneart',),
'reknearten': ('rekneart',),
'rekneartene': ('rekneart',),
'reknearter': ('rekneart',),
'reknemaskin': ('reknemaskin',),
'reknemaskina': ('reknemaskin',),
'reknemaskinen': ('reknemaskin',),
'reknemaskinene': ('reknemaskin',),
'reknemaskiner': ('reknemaskin',),
'reknemaskin': ('reknemaskin',),
'reknemaskina': ('reknemaskin',),
'reknemaskinen': ('reknemaskin',),
'reknemaskinene': ('reknemaskin',),
'reknemaskiner': ('reknemaskin',),
'reknemester': ('reknemester',),
'reknemestere': ('reknemester',),
'reknemesteren': ('reknemester',),
'reknemesterer': ('reknemester',),
'reknemesterne': ('reknemester',),
'reknemestre': ('reknemester',),
'reknemestrene': ('reknemester',),
'reknemestrer': ('reknemester',),
'reknemester': ('reknemester',),
'reknemestere': ('reknemester',),
'reknemesteren': ('reknemester',),
'reknemesterer': ('reknemester',),
'reknemesterne': ('reknemester',),
'reknemestre': ('reknemester',),
'reknemestrene': ('reknemester',),
'reknemestrer': ('reknemester',),
'rekneskap': ('rekneskap',),
'rekneskapen': ('rekneskap',),
'rekneskapene': ('rekneskap',),
'rekneskaper': ('rekneskap',),
'rekneskap': ('rekneskap',),
'rekneskapen': ('rekneskap',),
'rekneskapene': ('rekneskap',),
'rekneskaper': ('rekneskap',),
'rekneskapsfører': ('rekneskapsfører',),
'rekneskapsførere': ('rekneskapsfører',),
'rekneskapsføreren': ('rekneskapsfører',),
'rekneskapsførerer': ('rekneskapsfører',),
'rekneskapsførerne': ('rekneskapsfører',),
'rekneskapsfører': ('rekneskapsfører',),
'rekneskapsførere': ('rekneskapsfører',),
'rekneskapsføreren': ('rekneskapsfører',),
'rekneskapsførerer': ('rekneskapsfører',),
'rekneskapsførerne': ('rekneskapsfører',),
'rekneskapsførsel': ('rekneskapsførsel',),
'rekneskapsførselen': ('rekneskapsførsel',),
'rekneskapsførslene': ('rekneskapsførsel',),
'rekneskapsførsler': ('rekneskapsførsel',),
'rekneskapsførsel': ('rekneskapsførsel',),
'rekneskapsførselen': ('rekneskapsførsel',),
'rekneskapsførslene': ('rekneskapsførsel',),
'rekneskapsførsler': ('rekneskapsførsel',),
'reknestav': ('reknestav',),
'reknestaven': ('reknestav',),
'reknestavene': ('reknestav',),
'reknestaver': ('reknestav',),
'reknestav': ('reknestav',),
'reknestaven': ('reknestav',),
'reknestavene': ('reknestav',),
'reknestaver': ('reknestav',),
'reknestykka': ('reknestykke',),
'reknestykke': ('reknestykke',),
'reknestykkene': ('reknestykke',),
'reknestykker': ('reknestykke',),
'reknestykket': ('reknestykke',),
'reknestykka': ('reknestykke',),
'reknestykke': ('reknestykke',),
'reknestykkene': ('reknestykke',),
'reknestykker': ('reknestykke',),
'reknestykket': ('reknestykke',),
'rekning': ('rekning',),
'rekninga': ('rekning',),
'rekningen': ('rekning',),
'rekningene': ('rekning',),
'rekninger': ('rekning',),
'rekning': ('rekning',),
'rekninga': ('rekning',),
'rekningen': ('rekning',),
'rekningene': ('rekning',),
'rekninger': ('rekning',),
'rekningsart': ('rekningsart',),
'rekningsarta': ('rekningsart',),
'rekningsarten': ('rekningsart',),
'rekningsartene': ('rekningsart',),
'rekningsarter': ('rekningsart',),
'rekningsart': ('rekningsart',),
'rekningsarta': ('rekningsart',),
'rekningsarten': ('rekningsart',),
'rekningsartene': ('rekningsart',),
'rekningsarter': ('rekningsart',),
'rekognoseringsfly': ('rekognoseringsfly',),
'rekognoseringsflya': ('rekognoseringsfly',),
'rekognoseringsflyene': ('rekognoseringsfly',),
'rekognoseringsflyet': ('rekognoseringsfly',),
'rekognoseringspatrulje': ('rekognoseringspatrulje',),
'rekognoseringspatruljen': ('rekognoseringspatrulje',),
'rekognoseringspatruljene': ('rekognoseringspatrulje',),
'rekognoseringspatruljer': ('rekognoseringspatrulje',),
'rekognosør': ('rekognosør',),
'rekognosøren': ('rekognosør',),
'rekognosørene': ('rekognosør',),
'rekognosører': ('rekognosør',),
'rekommandasjon': ('rekommandasjon',),
'rekommandasjonen': ('rekommandasjon',),
'rekommandasjonene': ('rekommandasjon',),
'rekommandasjoner': ('rekommandasjon',),
'rekonstruksjon': ('rekonstruksjon',),
'rekonstruksjonen': ('rekonstruksjon',),
'rekonstruksjonene': ('rekonstruksjon',),
'rekonstruksjoner': ('rekonstruksjon',),
'rekonvalesens': ('rekonvalesens',),
'rekonvalesensen': ('rekonvalesens',),
'rekonvalesensene': ('rekonvalesens',),
'rekonvalesenser': ('rekonvalesens',),
'rekonvalesent': ('rekonvalesent',),
'rekonvalesenten': ('rekonvalesent',),
'rekonvalesentene': ('rekonvalesent',),
'rekonvalesenter': ('rekonvalesent',),
'rekonvalesentheim': ('rekonvalesentheim',),
'rekonvalesentheimen': ('rekonvalesentheim',),
'rekonvalesentheimene': ('rekonvalesentheim',),
'rekonvalesentheimer': ('rekonvalesentheim',),
'rekonvalesenthjem': ('rekonvalesenthjem',),
'rekonvalesenthjemma': ('rekonvalesenthjem',),
'rekonvalesenthjemmene': ('rekonvalesenthjem',),
'rekonvalesenthjemmet': ('rekonvalesenthjem',),
'rekord': ('rekord',),
'rekorden': ('rekord',),
'rekordene': ('rekord',),
'rekorder': ('rekord',),
'rekordforbedring': ('rekordforbedring',),
'rekordforbedringa': ('rekordforbedring',),
'rekordforbedringen': ('rekordforbedring',),
'rekordforbedringene': ('rekordforbedring',),
'rekordforbedringer': ('rekordforbedring',),
'rekordholder': ('rekordholder',),
'rekordholdere': ('rekordholder',),
'rekordholderen': ('rekordholder',),
'rekordholderer': ('rekordholder',),
'rekordholderne': ('rekordholder',),
'rekordtid': ('rekordtid',),
'rekordtida': ('rekordtid',),
'rekordtiden': ('rekordtid',),
'rekordtidene': ('rekordtid',),
'rekordtider': ('rekordtid',),
'rekortandekka': ('rekortandekke',),
'rekortandekke': ('rekortandekke',),
'rekortandekkene': ('rekortandekke',),
'rekortandekker': ('rekortandekke',),
'rekortandekket': ('rekortandekke',),
'rekreasjon': ('rekreasjon',),
'rekreasjonen': ('rekreasjon',),
'rekreasjonene': ('rekreasjon',),
'rekreasjoner': ('rekreasjon',),
'rekreasjonsområda': ('rekreasjonsområde',),
'rekreasjonsområde': ('rekreasjonsområde',),
'rekreasjonsområdene': ('rekreasjonsområde',),
'rekreasjonsområder': ('rekreasjonsområde',),
'rekreasjonsområdet': ('rekreasjonsområde',),
'rekrutt': ('rekrutt',),
'rekrutten': ('rekrutt',),
'rekruttene': ('rekrutt',),
'rekrutter': ('rekrutt',),
'rekruttering': ('rekruttering',),
'rekrutteringa': ('rekruttering',),
'rekrutteringen': ('rekruttering',),
'rekrutteringene': ('rekruttering',),
'rekrutteringer': ('rekruttering',),
'rekruttskole': ('rekruttskole',),
'rekruttskolen': ('rekruttskole',),
'rekruttskolene': ('rekruttskole',),
'rekruttskoler': ('rekruttskole',),
'redskapskassa': ('redskapskasse',),
'redskapskasse': ('redskapskasse',),
'redskapskassen': ('redskapskasse',),
'redskapskassene': ('redskapskasse',),
'redskapskasser': ('redskapskasse',),
'rekst': ('rekst',),
'reksten': ('rekst',),
'rekstene': ('rekst',),
'rekster': ('rekst',),
'rekster': ('rekster',),
'reksteren': ('rekster',),
'rekstre': ('rekster',),
'rekstrene': ('rekster',),
'rekstrer': ('rekster',),
'rektaklausul': ('rektaklausul',),
'rektaklausulen': ('rektaklausul',),
'rektaklausulene': ('rektaklausul',),
'rektaklausuler': ('rektaklausul',),
'rektangel': ('rektangel',),
'rektangelet': ('rektangel',),
'rektangla': ('rektangel',),
'rektanglene': ('rektangel',),
'rektangler': ('rektangel',),
'rektanglet': ('rektangel',),
'rektangelkart': ('rektangelkart',),
'rektangelkarta': ('rektangelkart',),
'rektangelkartene': ('rektangelkart',),
'rektangelkarter': ('rektangelkart',),
'rektangelkartet': ('rektangelkart',),
'rektaveksel': ('rektaveksel',),
'rektavekselen': ('rektaveksel',),
'rektavekslene': ('rektaveksel',),
'rektaveksler': ('rektaveksel',),
'rektor': ('rektor',),
'rektoren': ('rektor',),
'rektorene': ('rektor',),
'rektorer': ('rektor',),
'rektorat': ('rektorat',),
'rektorata': ('rektorat',),
'rektoratene': ('rektorat',),
'rektorater': ('rektorat',),
'rektoratet': ('rektorat',),
'rektum': ('rektum',),
'rektuma': ('rektum',),
'rektumene': ('rektum',),
'rektumet': ('rektum',),
'rekursivitet': ('rekursivitet',),
'rekursiviteten': ('rekursivitet',),
'rekursivitetene': ('rekursivitet',),
'rekursiviteter': ('rekursivitet',),
'rekursjon': ('rekursjon',),
'rekursjonen': ('rekursjon',),
'rekursjonene': ('rekursjon',),
'rekursjoner': ('rekursjon',),
'rekved': ('rekved',),
'rekveden': ('rekved',),
'rekvedene': ('rekved',),
'rekveder': ('rekved',),
'rekviem': ('rekviem',),
'rekviema': ('rekviem',),
'rekviemene': ('rekviem',),
'rekviemer': ('rekviem',),
'rekviemet': ('rekviem',),
'rekvirent': ('rekvirent',),
'rekvirenten': ('rekvirent',),
'rekvirentene': ('rekvirent',),
'rekvirenter': ('rekvirent',),
'rekvisisjon': ('rekvisisjon',),
'rekvisisjonen': ('rekvisisjon',),
'rekvisisjonene': ('rekvisisjon',),
'rekvisisjoner': ('rekvisisjon',),
'rekvisita': ('rekvisita',),
'rekvisitaene': ('rekvisita',),
'rekvisitt': ('rekvisitt',),
'rekvisitta': ('rekvisitt',),
'rekvisittene': ('rekvisitt',),
'rekvisitter': ('rekvisitt',),
'rekvisittet': ('rekvisitt',),
'rekvisitør': ('rekvisitør',),
'rekvisitøren': ('rekvisitør',),
'rekvisitørene': ('rekvisitør',),
'rekvisitører': ('rekvisitør',),
'rekyl': ('rekyl',),
'rekylen': ('rekyl',),
'rekylene': ('rekyl',),
'rekyler': ('rekyl',),
'rekylgevær': ('rekylgevær',),
'rekylgeværa': ('rekylgevær',),
'rekylgeværene': ('rekylgevær',),
'rekylgeværer': ('rekylgevær',),
'rekylgeværet': ('rekylgevær',),
'relea': ('relé',),
'releene': ('relé',),
'releer': ('relé',),
'releet': ('relé',),
'relé': ('relé',),
'reléa': ('relé',),
'reléene': ('relé',),
'reléer': ('relé',),
'reléet': ('relé',),
'reléstasjon': ('reléstasjon',),
'reléstasjonen': ('reléstasjon',),
'reléstasjonene': ('reléstasjon',),
'reléstasjoner': ('reléstasjon',),
'relasjon': ('relasjon',),
'relasjonen': ('relasjon',),
'relasjonene': ('relasjon',),
'relasjoner': ('relasjon',),
'relativ': ('relativ',),
'relativa': ('relativ',),
'relativene': ('relativ',),
'relativer': ('relativ',),
'relativet': ('relativ',),
'relativisme': ('relativisme',),
'relativismen': ('relativisme',),
'relativismene': ('relativisme',),
'relativismer': ('relativisme',),
'relativist': ('relativist',),
'relativisten': ('relativist',),
'relativistene': ('relativist',),
'relativister': ('relativist',),
'relativitet': ('relativitet',),
'relativiteten': ('relativitet',),
'relativitetene': ('relativitet',),
'relativiteter': ('relativitet',),
'relativivitetsteori': ('relativivitetsteori',),
'relativivitetsteorien': ('relativivitetsteori',),
'relativivitetsteoriene': ('relativivitetsteori',),
'relativivitetsteorier': ('relativivitetsteori',),
'relativsetning': ('relativsetning',),
'relativsetninga': ('relativsetning',),
'relativsetningen': ('relativsetning',),
'relativsetningene': ('relativsetning',),
'relativsetninger': ('relativsetning',),
'relegasjon': ('relegasjon',),
'relegasjonen': ('relegasjon',),
'relegasjonene': ('relegasjon',),
'relegasjoner': ('relegasjon',),
'relevans': ('relevans',),
'relevansen': ('relevans',),
'relevansene': ('relevans',),
'relevanser': ('relevans',),
'relieff': ('relieff',),
'relieffa': ('relieff',),
'relieffene': ('relieff',),
'relieffer': ('relieff',),
'relieffet': ('relieff',),
'relieffkart': ('relieffkart',),
'relieffkarta': ('relieffkart',),
'relieffkartene': ('relieffkart',),
'relieffkarter': ('relieffkart',),
'relieffkartet': ('relieffkart',),
'religion': ('religion',),
'religionen': ('religion',),
'religionene': ('religion',),
'religioner': ('religion',),
'religionsfilosofi': ('religionsfilosofi',),
'religionsfilosofien': ('religionsfilosofi',),
'religionsfilosofiene': ('religionsfilosofi',),
'religionsfilosofier': ('religionsfilosofi',),
'religionsfrihet': ('religionsfrihet',),
'religionsfriheta': ('religionsfrihet',),
'religionsfriheten': ('religionsfrihet',),
'religionsfrihetene': ('religionsfrihet',),
'religionsfriheter': ('religionsfrihet',),
'religionshistoria': ('religionshistorie',),
'religionshistorie': ('religionshistorie',),
'religionshistorien': ('religionshistorie',),
'religionshistoriene': ('religionshistorie',),
'religionshistorier': ('religionshistorie',),
'religionskrig': ('religionskrig',),
'religionskrigen': ('religionskrig',),
'religionskrigene': ('religionskrig',),
'religionskriger': ('religionskrig',),
'religiøsitet': ('religiøsitet',),
'religiøsiteten': ('religiøsitet',),
'religiøsitetene': ('religiøsitet',),
'religiøsiteter': ('religiøsitet',),
'relikt': ('relikt',),
'relikta': ('relikt',),
'reliktene': ('relikt',),
'relikter': ('relikt',),
'reliktet': ('relikt',),
'reliktfauna': ('reliktfauna',),
'reliktfaunaen': ('reliktfauna',),
'reliktfaunaene': ('reliktfauna',),
'reliktfaunaer': ('reliktfauna',),
'reliktflora': ('reliktflora',),
'reliktfloraen': ('reliktflora',),
'reliktfloraene': ('reliktflora',),
'reliktfloraer': ('reliktflora',),
'reliktområda': ('reliktområde',),
'reliktområde': ('reliktområde',),
'reliktområdene': ('reliktområde',),
'reliktområder': ('reliktområde',),
'reliktområdet': ('reliktområde',),
'relikvie': ('relikvie',),
'relikvien': ('relikvie',),
'relikviene': ('relikvie',),
'relikvier': ('relikvie',),
'reling': ('reling',),
'relinga': ('reling',),
'relingen': ('reling',),
'relingene': ('reling',),
'relinger': ('reling',),
'relokasjon': ('relokasjon',),
'relokasjonen': ('relokasjon',),
'relokasjonene': ('relokasjon',),
'relokasjoner': ('relokasjon',),
'rem': ('rem',),
'remen': ('rem',),
'remene': ('rem',),
'rem': ('rem',),
'remma': ('rem',),
'remmen': ('rem',),
'remmene': ('rem',),
'remmer': ('rem',),
'remburs': ('remburs',),
'rembursen': ('remburs',),
'rembursene': ('remburs',),
'remburser': ('remburs',),
'remedie': ('remedie',),
'remedien': ('remedie',),
'remediene': ('remedie',),
'remedier': ('remedie',),
'remedia': ('remedium',),
'remediene': ('remedium',),
'remedier': ('remedium',),
'remediet': ('remedium',),
'remedium': ('remedium',),
'remington': ('remington',),
'remingtonen': ('remington',),
'remingtonene': ('remington',),
'remingtoner': ('remington',),
'remingtongevær': ('remingtongevær',),
'remingtongeværa': ('remingtongevær',),
'remingtongeværene': ('remingtongevær',),
'remingtongeværer': ('remingtongevær',),
'remingtongeværet': ('remingtongevær',),
'reminisens': ('reminisens',),
'reminisensen': ('reminisens',),
'reminisensene': ('reminisens',),
'reminisenser': ('reminisens',),
'remis': ('remis',),
'remisen': ('remis',),
'remisene': ('remis',),
'remiser': ('remis',),
'remise': ('remise',),
'remisen': ('remise',),
'remisene': ('remise',),
'remiser': ('remise',),
'remisse': ('remisse',),
'remissen': ('remisse',),
'remissene': ('remisse',),
'remisser': ('remisse',),
'remittent': ('remittent',),
'remittenten': ('remittent',),
'remittentene': ('remittent',),
'remittenter': ('remittent',),
'remonte': ('remonte',),
'remonten': ('remonte',),
'remontene': ('remonte',),
'remonter': ('remonte',),
'rempling': ('rempling',),
'remplingen': ('rempling',),
'remplingene': ('rempling',),
'remplinger': ('rempling',),
'remsa': ('remse',),
'remse': ('remse',),
'remsen': ('remse',),
'remsene': ('remse',),
'remser': ('remse',),
'remsa': ('remse',),
'remse': ('remse',),
'remsen': ('remse',),
'remsene': ('remse',),
'remser': ('remse',),
'remskiva': ('remskive',),
'remskive': ('remskive',),
'remskiven': ('remskive',),
'remskivene': ('remskive',),
'remskiver': ('remskive',),
'remulade': ('remulade',),
'remuladen': ('remulade',),
'remuladene': ('remulade',),
'remulader': ('remulade',),
'rendezvous': ('rendezvous',),
'rendezvousa': ('rendezvous',),
'rendezvousene': ('rendezvous',),
'rendezvouser': ('rendezvous',),
'rendezvouset': ('rendezvous',),
'renegat': ('renegat',),
'renegaten': ('renegat',),
'renegatene': ('renegat',),
'renegater': ('renegat',),
'renessanse': ('renessanse',),
'renessansen': ('renessanse',),
'renessansene': ('renessanse',),
'renessanser': ('renessanse',),
'renessansekunst': ('renessansekunst',),
'renessansekunsten': ('renessansekunst',),
'renessansekunstene': ('renessansekunst',),
'renessansekunster': ('renessansekunst',),
'renessansestil': ('renessansestil',),
'renessansestilen': ('renessansestil',),
'renessansestilene': ('renessansestil',),
'renessansestiler': ('renessansestil',),
'rengjøringsbyrå': ('rengjøringsbyrå',),
'rengjøringsbyråa': ('rengjøringsbyrå',),
'rengjøringsbyråene': ('rengjøringsbyrå',),
'rengjøringsbyråer': ('rengjøringsbyrå',),
'rengjøringsbyrået': ('rengjøringsbyrå',),
'renhet': ('renhet',),
'renheta': ('renhet',),
'renheten': ('renhet',),
'renhetene': ('renhet',),
'renheter': ('renhet',),
'renhold': ('renhold',),
'renholda': ('renhold',),
'renholdene': ('renhold',),
'renholdet': ('renhold',),
'renke': ('renke',),
'renken': ('renke',),
'renkene': ('renke',),
'renker': ('renke',),
'renkesmed': ('renkesmed',),
'renkesmeden': ('renkesmed',),
'renkesmedene': ('renkesmed',),
'renkesmeder': ('renkesmed',),
'renkespell': ('renkespell',),
'renkespella': ('renkespell',),
'renkespellene': ('renkespell',),
'renkespellet': ('renkespell',),
'renkespill': ('renkespill',),
'renkespilla': ('renkespill',),
'renkespillene': ('renkespill',),
'renkespillet': ('renkespill',),
'renn': ('renn',),
'renna': ('renn',),
'rennene': ('renn',),
'rennet': ('renn',),
'renna': ('renne',),
'renne': ('renne',),
'rennen': ('renne',),
'rennene': ('renne',),
'renner': ('renne',),
'rennebom': ('rennebom',),
'rennebommen': ('rennebom',),
'rennebommene': ('rennebom',),
'rennebommer': ('rennebom',),
'rennefart': ('rennefart',),
'rennefarten': ('rennefart',),
'rennefartene': ('rennefart',),
'rennefarter': ('rennefart',),
'rennegarn': ('rennegarn',),
'rennegarna': ('rennegarn',),
'rennegarnene': ('rennegarn',),
'rennegarnet': ('rennegarn',),
'renneløkka': ('renneløkke',),
'renneløkke': ('renneløkke',),
'renneløkken': ('renneløkke',),
'renneløkkene': ('renneløkke',),
'renneløkker': ('renneløkke',),
'rennesnara': ('rennesnare',),
'rennesnare': ('rennesnare',),
'rennesnaren': ('rennesnare',),
'rennesnarene': ('rennesnare',),
'rennesnarer': ('rennesnare',),
'rennestein': ('rennestein',),
'rennesteinen': ('rennestein',),
'rennesteinene': ('rennestein',),
'rennesteiner': ('rennestein',),
'renning': ('renning',),
'renninga': ('renning',),
'renningen': ('renning',),
'renningene': ('renning',),
'renninger': ('renning',),
'renning': ('renning',),
'renninga': ('renning',),
'renningen': ('renning',),
'renningene': ('renning',),
'renninger': ('renning',),
'renommea': ('renommé',),
'renommeene': ('renommé',),
'renommeer': ('renommé',),
'renommeet': ('renommé',),
'renommé': ('renommé',),
'renomméa': ('renommé',),
'renomméene': ('renommé',),
'renomméer': ('renommé',),
'renomméet': ('renommé',),
'renons': ('renons',),
'renonsen': ('renons',),
'renonsene': ('renons',),
'renonser': ('renons',),
'renovasjon': ('renovasjon',),
'renovasjonen': ('renovasjon',),
'renovasjonene': ('renovasjon',),
'renovasjoner': ('renovasjon',),
'renovasjonsarbeider': ('renovasjonsarbeider',),
'renovasjonsarbeidere': ('renovasjonsarbeider',),
'renovasjonsarbeideren': ('renovasjonsarbeider',),
'renovasjonsarbeiderer': ('renovasjonsarbeider',),
'renovasjonsarbeiderne': ('renovasjonsarbeider',),
'renovatør': ('renovatør',),
'renovatøren': ('renovatør',),
'renovatørene': ('renovatør',),
'renovatører': ('renovatør',),
'rens': ('rens',),
'rensen': ('rens',),
'rensene': ('rens',),
'renser': ('rens',),
'renselse': ('renselse',),
'renselsen': ('renselse',),
'renselsene': ('renselse',),
'renselser': ('renselse',),
'renselsesfest': ('renselsesfest',),
'renselsesfesten': ('renselsesfest',),
'renselsesfestene': ('renselsesfest',),
'renselsesfester': ('renselsesfest',),
'rensemiddel': ('rensemiddel',),
'rensemiddelet': ('rensemiddel',),
'rensemidla': ('rensemiddel',),
'rensemidlene': ('rensemiddel',),
'rensemidler': ('rensemiddel',),
'rensemidlet': ('rensemiddel',),
'renser': ('renser',),
'rensere': ('renser',),
'renseren': ('renser',),
'renserer': ('renser',),
'renserne': ('renser',),
'renseri': ('renseri',),
'renseria': ('renseri',),
'renseriene': ('renseri',),
'renserier': ('renseri',),
'renseriet': ('renseri',),
'rensing': ('rensing',),
'rensinga': ('rensing',),
'rensingen': ('rensing',),
'rensingene': ('rensing',),
'rensinger': ('rensing',),
'rensk': ('rensk',),
'rensken': ('rensk',),
'renskene': ('rensk',),
'rensker': ('rensk',),
'rensla': ('rensle',),
'rensle': ('rensle',),
'renslen': ('rensle',),
'renslene': ('rensle',),
'rensler': ('rensle',),
'renslighet': ('renslighet',),
'rensligheta': ('renslighet',),
'rensligheten': ('renslighet',),
'renslighetene': ('renslighet',),
'rensligheter': ('renslighet',),
'rensning': ('rensning',),
'rensninga': ('rensning',),
'rensningen': ('rensning',),
'rensningene': ('rensning',),
'rensninger': ('rensning',),
'rentabilitet': ('rentabilitet',),
'rentabiliteten': ('rentabilitet',),
'rentabilitetene': ('rentabilitet',),
'rentabiliteter': ('rentabilitet',),
'renta': ('rente',),
'rente': ('rente',),
'renten': ('rente',),
'rentene': ('rente',),
'renter': ('rente',),
'rentefot': ('rentefot',),
'rentefoten': ('rentefot',),
'renteføttene': ('rentefot',),
'renteføtter': ('rentefot',),
'rentemargin': ('rentemargin',),
'rentemarginen': ('rentemargin',),
'rentemarginene': ('rentemargin',),
'rentemarginer': ('rentemargin',),
'rentenist': ('rentenist',),
'rentenisten': ('rentenist',),
'rentenistene': ('rentenist',),
'rentenister': ('rentenist',),
'renteregning': ('renteregning',),
'renteregninga': ('renteregning',),
'renteregningen': ('renteregning',),
'renteregningene': ('renteregning',),
'renteregninger': ('renteregning',),
'renterekning': ('renterekning',),
'renterekninga': ('renterekning',),
'renterekningen': ('renterekning',),
'renterekningene': ('renterekning',),
'renterekninger': ('renterekning',),
'rentesats': ('rentesats',),
'rentesatsen': ('rentesats',),
'rentesatsene': ('rentesats',),
'rentesatser': ('rentesats',),
'rentesrenta': ('rentesrente',),
'rentesrente': ('rentesrente',),
'rentesrenten': ('rentesrente',),
'rentesrentene': ('rentesrente',),
'rentesrenter': ('rentesrente',),
'rentetak': ('rentetak',),
'rentetaka': ('rentetak',),
'rentetakene': ('rentetak',),
'rentetaket': ('rentetak',),
'rentier': ('rentier',),
'rentieren': ('rentier',),
'rentierene': ('rentier',),
'rentierer': ('rentier',),
'reol': ('reol',),
'reolen': ('reol',),
'reolene': ('reol',),
'reoler': ('reol',),
'reorganisasjon': ('reorganisasjon',),
'reorganisasjonen': ('reorganisasjon',),
'reorganisasjonene': ('reorganisasjon',),
'reorganisasjoner': ('reorganisasjon',),
'rep': ('rep',),
'repen': ('rep',),
'repene': ('rep',),
'reper': ('rep',),
'reparasjon': ('reparasjon',),
'reparasjonen': ('reparasjon',),
'reparasjonene': ('reparasjon',),
'reparasjoner': ('reparasjon',),
'reparatør': ('reparatør',),
'reparatøren': ('reparatør',),
'reparatørene': ('reparatør',),
'reparatører': ('reparatør',),
'repatriant': ('repatriant',),
'repatrianten': ('repatriant',),
'repatriantene': ('repatriant',),
'repatrianter': ('repatriant',),
'reperbane': ('reperbane',),
'reperbanen': ('reperbane',),
'reperbanene': ('reperbane',),
'reperbaner': ('reperbane',),
'repertoar': ('repertoar',),
'repertoara': ('repertoar',),
'repertoarene': ('repertoar',),
'repertoarer': ('repertoar',),
'repertoaret': ('repertoar',),
'repetisjon': ('repetisjon',),
'repetisjonen': ('repetisjon',),
'repetisjonene': ('repetisjon',),
'repetisjoner': ('repetisjon',),
'repetisjonsøvelse': ('repetisjonsøvelse',),
'repetisjonsøvelsen': ('repetisjonsøvelse',),
'repetisjonsøvelsene': ('repetisjonsøvelse',),
'repetisjonsøvelser': ('repetisjonsøvelse',),
'repetisjonsøving': ('repetisjonsøving',),
'repetisjonsøvinga': ('repetisjonsøving',),
'repetisjonsøvingen': ('repetisjonsøving',),
'repetisjonsøvingene': ('repetisjonsøving',),
'repetisjonsøvinger': ('repetisjonsøving',),
'repetitør': ('repetitør',),
'repetitøren': ('repetitør',),
'repetitørene': ('repetitør',),
'repetitører': ('repetitør',),
'replikk': ('replikk',),
'replikken': ('replikk',),
'replikkene': ('replikk',),
'replikker': ('replikk',),
'replikkordskifta': ('replikkordskifte',),
'replikkordskifte': ('replikkordskifte',),
'replikkordskiftene': ('replikkordskifte',),
'replikkordskifter': ('replikkordskifte',),
'replikkordskiftet': ('replikkordskifte',),
'replikkveksling': ('replikkveksling',),
'replikkvekslinga': ('replikkveksling',),
'replikkvekslingen': ('replikkveksling',),
'replikkvekslingene': ('replikkveksling',),
'replikkvekslinger': ('replikkveksling',),
'reportasje': ('reportasje',),
'reportasjen': ('reportasje',),
'reportasjene': ('reportasje',),
'reportasjer': ('reportasje',),
'reporter': ('reporter',),
'reportere': ('reporter',),
'reporteren': ('reporter',),
'reporterer': ('reporter',),
'reporterne': ('reporter',),
'repos': ('repos',),
'reposa': ('repos',),
'reposene': ('repos',),
'reposer': ('repos',),
'reposet': ('repos',),
'repp': ('repp',),
'reppen': ('repp',),
'reppene': ('repp',),
'repper': ('repp',),
'represalie': ('represalie',),
'represalien': ('represalie',),
'represaliene': ('represalie',),
'represalier': ('represalie',),
'representant': ('representant',),
'representanten': ('representant',),
'representantene': ('representant',),
'representanter': ('representant',),
'representantskap': ('representantskap',),
'representantskapa': ('representantskap',),
'representantskapene': ('representantskap',),
'representantskaper': ('representantskap',),
'representantskapet': ('representantskap',),
'representasjon': ('representasjon',),
'representasjonen': ('representasjon',),
'representasjonene': ('representasjon',),
'representasjoner': ('representasjon',),
'represjon': ('represjon',),
'represjonen': ('represjon',),
'represjonene': ('represjon',),
'represjoner': ('represjon',),
'reprimande': ('reprimande',),
'reprimanden': ('reprimande',),
'reprimandene': ('reprimande',),
'reprimander': ('reprimande',),
'reprise': ('reprise',),
'reprisen': ('reprise',),
'reprisene': ('reprise',),
'repriser': ('reprise',),
'repro': ('repro',),
'reproen': ('repro',),
'reproene': ('repro',),
'reproer': ('repro',),
'reproavdeling': ('reproavdeling',),
'reproavdelinga': ('reproavdeling',),
'reproavdelingen': ('reproavdeling',),
'reproavdelingene': ('reproavdeling',),
'reproavdelinger': ('reproavdeling',),
'reproduksjon': ('reproduksjon',),
'reproduksjonen': ('reproduksjon',),
'reproduksjonene': ('reproduksjon',),
'reproduksjoner': ('reproduksjon',),
'reprodusør': ('reprodusør',),
'reprodusøren': ('reprodusør',),
'reprodusørene': ('reprodusør',),
'reprodusører': ('reprodusør',),
'repromontør': ('repromontør',),
'repromontøren': ('repromontør',),
'repromontørene': ('repromontør',),
'repromontører': ('repromontør',),
'reprotekniker': ('reprotekniker',),
'reproteknikere': ('reprotekniker',),
'reproteknikeren': ('reprotekniker',),
'reproteknikerer': ('reprotekniker',),
'reproteknikerne': ('reprotekniker',),
'reproteknikk': ('reproteknikk',),
'reproteknikken': ('reproteknikk',),
'reproteknikkene': ('reproteknikk',),
'reproteknikker': ('reproteknikk',),
'repslager': ('repslager',),
'repslagere': ('repslager',),
'repslageren': ('repslager',),
'repslagerer': ('repslager',),
'repslagerne': ('repslager',),
'reptil': ('reptil',),
'reptila': ('reptil',),
'reptilene': ('reptil',),
'reptiler': ('reptil',),
'reptilet': ('reptil',),
'republikaner': ('republikaner',),
'republikanere': ('republikaner',),
'republikaneren': ('republikaner',),
'republikanerer': ('republikaner',),
'republikanerne': ('republikaner',),
'republikk': ('republikk',),
'republikken': ('republikk',),
'republikkene': ('republikk',),
'republikker': ('republikk',),
'reputasjon': ('reputasjon',),
'reputasjonen': ('reputasjon',),
'reputasjonene': ('reputasjon',),
'reputasjoner': ('reputasjon',),
'repøvelse': ('repøvelse',),
'repøvelsen': ('repøvelse',),
'repøvelsene': ('repøvelse',),
'repøvelser': ('repøvelse',),
'repøving': ('repøving',),
'repøvinga': ('repøving',),
'repøvingen': ('repøving',),
'repøvingene': ('repøving',),
'repøvinger': ('repøving',),
'reseda': ('reseda',),
'resedaen': ('reseda',),
'resedaene': ('reseda',),
'resedaer': ('reseda',),
'resepsjon': ('resepsjon',),
'resepsjonen': ('resepsjon',),
'resepsjonene': ('resepsjon',),
'resepsjoner': ('resepsjon',),
'resepsjonist': ('resepsjonist',),
'resepsjonisten': ('resepsjonist',),
'resepsjonistene': ('resepsjonist',),
'resepsjonister': ('resepsjonist',),
'resept': ('resept',),
'resepten': ('resept',),
'reseptene': ('resept',),
'resepter': ('resept',),
'reseptar': ('reseptar',),
'reseptaren': ('reseptar',),
'reseptarene': ('reseptar',),
'reseptarer': ('reseptar',),
'reseptivitet': ('reseptivitet',),
'reseptiviteten': ('reseptivitet',),
'reseptivitetene': ('reseptivitet',),
'reseptiviteter': ('reseptivitet',),
'reservasjon': ('reservasjon',),
'reservasjonen': ('reservasjon',),
'reservasjonene': ('reservasjon',),
'reservasjoner': ('reservasjon',),
'reservat': ('reservat',),
'reservata': ('reservat',),
'reservatene': ('reservat',),
'reservater': ('reservat',),
'reservatet': ('reservat',),
'reserve': ('reserve',),
'reserven': ('reserve',),
'reservene': ('reserve',),
'reserver': ('reserve',),
'reservedel': ('reservedel',),
'reservedelen': ('reservedel',),
'reservedelene': ('reservedel',),
'reservedeler': ('reservedel',),
'reservedelslager': ('reservedelslager',),
'reservedelslageret': ('reservedelslager',),
'reservedelslagra': ('reservedelslager',),
'reservedelslagre': ('reservedelslager',),
'reservedelslagrene': ('reservedelslager',),
'reservelager': ('reservelager',),
'reservelageret': ('reservelager',),
'reservelagra': ('reservelager',),
'reservelagre': ('reservelager',),
'reservelagrene': ('reservelager',),
'reservelege': ('reservelege',),
'reservelegen': ('reservelege',),
'reservelegene': ('reservelege',),
'reserveleger': ('reservelege',),
'reservist': ('reservist',),
'reservisten': ('reservist',),
'reservistene': ('reservist',),
'reservister': ('reservist',),
'reservoar': ('reservoar',),
'reservoara': ('reservoar',),
'reservoarene': ('reservoar',),
'reservoarer': ('reservoar',),
'reservoaret': ('reservoar',),
'resesjon': ('resesjon',),
'resesjonen': ('resesjon',),
'resesjonene': ('resesjon',),
'resesjoner': ('resesjon',),
'residens': ('residens',),
'residensen': ('residens',),
'residensene': ('residens',),
'residenser': ('residens',),
'residensby': ('residensby',),
'residensbyen': ('residensby',),
'residensbyene': ('residensby',),
'residensbyer': ('residensby',),
'resident': ('resident',),
'residenten': ('resident',),
'residentene': ('resident',),
'residenter': ('resident',),
'residiv': ('residiv',),
'residiva': ('residiv',),
'residivene': ('residiv',),
'residiver': ('residiv',),
'residivet': ('residiv',),
'residivist': ('residivist',),
'residivisten': ('residivist',),
'residivistene': ('residivist',),
'residivister': ('residivist',),
'residu': ('residu',),
'residua': ('residu',),
'residuene': ('residu',),
'residuer': ('residu',),
'residuet': ('residu',),
'residua': ('residuum',),
'residuaene': ('residuum',),
'residuum': ('residuum',),
'residuumet': ('residuum',),
'resignasjon': ('resignasjon',),
'resignasjonen': ('resignasjon',),
'resignasjonene': ('resignasjon',),
'resignasjoner': ('resignasjon',),
'resin': ('resin',),
'resina': ('resin',),
'resinene': ('resin',),
'resiner': ('resin',),
'resinet': ('resin',),
'resina': ('resina',),
'resinaen': ('resina',),
'resinaene': ('resina',),
'resinaer': ('resina',),
'resinat': ('resinat',),
'resinata': ('resinat',),
'resinatene': ('resinat',),
'resinater': ('resinat',),
'resinatet': ('resinat',),
'resipient': ('resipient',),
'resipienten': ('resipient',),
'resipientene': ('resipient',),
'resipienter': ('resipient',),
'resiprositet': ('resiprositet',),
'resiprositeten': ('resiprositet',),
'resiprositetene': ('resiprositet',),
'resiprositeter': ('resiprositet',),
'resirkulasjon': ('resirkulasjon',),
'resirkulasjonen': ('resirkulasjon',),
'resirkulasjonene': ('resirkulasjon',),
'resirkulasjoner': ('resirkulasjon',),
'resistans': ('resistans',),
'resistansen': ('resistans',),
'resistansene': ('resistans',),
'resistanser': ('resistans',),
'resistens': ('resistens',),
'resistensen': ('resistens',),
'resistensene': ('resistens',),
'resistenser': ('resistens',),
'resistivitet': ('resistivitet',),
'resistiviteten': ('resistivitet',),
'resistivitetene': ('resistivitet',),
'resistiviteter': ('resistivitet',),
'resitasjon': ('resitasjon',),
'resitasjonen': ('resitasjon',),
'resitasjonene': ('resitasjon',),
'resitasjoner': ('resitasjon',),
'resitativ': ('resitativ',),
'resitativa': ('resitativ',),
'resitativene': ('resitativ',),
'resitativer': ('resitativ',),
'resitativet': ('resitativ',),
'reskontro': ('reskontro',),
'reskontroen': ('reskontro',),
'reskontroene': ('reskontro',),
'reskontroer': ('reskontro',),
'reskript': ('reskript',),
'reskripta': ('reskript',),
'reskriptene': ('reskript',),
'reskripter': ('reskript',),
'reskriptet': ('reskript',),
'resolusjon': ('resolusjon',),
'resolusjonen': ('resolusjon',),
'resolusjonene': ('resolusjon',),
'resolusjoner': ('resolusjon',),
'resonans': ('resonans',),
'resonansen': ('resonans',),
'resonansene': ('resonans',),
'resonanser': ('resonans',),
'resonansbotn': ('resonansbotn',),
'resonansbotnen': ('resonansbotn',),
'resonansbotnene': ('resonansbotn',),
'resonansbotner': ('resonansbotn',),
'resonansbunn': ('resonansbunn',),
'resonansbunnen': ('resonansbunn',),
'resonansbunnene': ('resonansbunn',),
'resonansbunner': ('resonansbunn',),
'resonanskassa': ('resonanskasse',),
'resonanskasse': ('resonanskasse',),
'resonanskassen': ('resonanskasse',),
'resonanskassene': ('resonanskasse',),
'resonanskasser': ('resonanskasse',),
'resong': ('resong',),
'resongen': ('resong',),
'resongene': ('resong',),
'resonger': ('resong',),
'resonnement': ('resonnement',),
'resonnementa': ('resonnement',),
'resonnementene': ('resonnement',),
'resonnementer': ('resonnement',),
'resonnementet': ('resonnement',),
'resorpsjon': ('resorpsjon',),
'resorpsjonen': ('resorpsjon',),
'resorpsjonene': ('resorpsjon',),
'resorpsjoner': ('resorpsjon',),
'respatex': ('respatex',),
'respatexen': ('respatex',),
'respatexene': ('respatex',),
'respatexer': ('respatex',),
'respekt': ('respekt',),
'respekten': ('respekt',),
'respektene': ('respekt',),
'respekter': ('respekt',),
'respirasjon': ('respirasjon',),
'respirasjonen': ('respirasjon',),
'respirasjonene': ('respirasjon',),
'respirasjoner': ('respirasjon',),
'respirator': ('respirator',),
'respiratoren': ('respirator',),
'respiratorene': ('respirator',),
'respiratorer': ('respirator',),
'respitt': ('respitt',),
'respitten': ('respitt',),
'respittene': ('respitt',),
'respitter': ('respitt',),
'respondent': ('respondent',),
'respondenten': ('respondent',),
'respondentene': ('respondent',),
'respondenter': ('respondent',),
'respons': ('respons',),
'responsen': ('respons',),
'responsene': ('respons',),
'responser': ('respons',),
'responsa': ('responsum',),
'responsaene': ('responsum',),
'responsum': ('responsum',),
'responsuma': ('responsum',),
'responsumene': ('responsum',),
'responsumer': ('responsum',),
'responsumet': ('responsum',),
'ressurs': ('ressurs',),
'ressursen': ('ressurs',),
'ressursene': ('ressurs',),
'ressurser': ('ressurs',),
'rest': ('rest',),
'resten': ('rest',),
'restene': ('rest',),
'rester': ('rest',),
'restanse': ('restanse',),
'restansen': ('restanse',),
'restansene': ('restanse',),
'restanser': ('restanse',),
'restant': ('restant',),
'restanten': ('restant',),
'restantene': ('restant',),
'restanter': ('restant',),
'restaurant': ('restaurant',),
'restauranten': ('restaurant',),
'restaurantene': ('restaurant',),
'restauranter': ('restaurant',),
'restaurasjon': ('restaurasjon',),
'restaurasjonen': ('restaurasjon',),
'restaurasjonene': ('restaurasjon',),
'restaurasjoner': ('restaurasjon',),
'restauratør': ('restauratør',),
'restauratøren': ('restauratør',),
'restauratørene': ('restauratør',),
'restauratører': ('restauratør',),
'restaurering': ('restaurering',),
'restaureringa': ('restaurering',),
'restaureringen': ('restaurering',),
'restaureringene': ('restaurering',),
'restaureringer': ('restaurering',),
'restitusjon': ('restitusjon',),
'restitusjonen': ('restitusjon',),
'restitusjonene': ('restitusjon',),
'restitusjoner': ('restitusjon',),
'restriksjon': ('restriksjon',),
'restriksjonen': ('restriksjon',),
'restriksjonene': ('restriksjon',),
'restriksjoner': ('restriksjon',),
'restriktivitet': ('restriktivitet',),
'restriktiviteten': ('restriktivitet',),
'restriktivitetene': ('restriktivitet',),
'restriktiviteter': ('restriktivitet',),
'restskatt': ('restskatt',),
'restskatten': ('restskatt',),
'restskattene': ('restskatt',),
'restskatter': ('restskatt',),
'resultant': ('resultant',),
'resultanten': ('resultant',),
'resultantene': ('resultant',),
'resultanter': ('resultant',),
'resultat': ('resultat',),
'resultata': ('resultat',),
'resultatene': ('resultat',),
'resultater': ('resultat',),
'resultatet': ('resultat',),
'resurs': ('resurs',),
'resursen': ('resurs',),
'resursene': ('resurs',),
'resurser': ('resurs',),
'resymea': ('resymé',),
'resymeene': ('resymé',),
'resymeer': ('resymé',),
'resymeet': ('resymé',),
'resymé': ('resymé',),
'resyméa': ('resymé',),
'resyméene': ('resymé',),
'resyméer': ('resymé',),
'resyméet': ('resymé',),
'retardasjon': ('retardasjon',),
'retardasjonen': ('retardasjon',),
'retardasjonene': ('retardasjon',),
'retardasjoner': ('retardasjon',),
'retensjon': ('retensjon',),
'retensjonen': ('retensjon',),
'retensjonene': ('retensjon',),
'retensjoner': ('retensjon',),
'retensjonsrett': ('retensjonsrett',),
'retensjonsretten': ('retensjonsrett',),
'retensjonsrettene': ('retensjonsrett',),
'retensjonsretter': ('retensjonsrett',),
'retina': ('retina',),
'retinaen': ('retina',),
'retinaene': ('retina',),
'retinaer': ('retina',),
'retinent': ('retinent',),
'retinenten': ('retinent',),
'retinentene': ('retinent',),
'retinenter': ('retinent',),
'retning': ('retning',),
'retninga': ('retning',),
'retningen': ('retning',),
'retningene': ('retning',),
'retninger': ('retning',),
'retningslinja': ('retningslinje',),
'retningslinje': ('retningslinje',),
'retningslinjen': ('retningslinje',),
'retningslinjene': ('retningslinje',),
'retningslinjer': ('retningslinje',),
'retningsnummer': ('retningsnummer',),
'retningsnummeret': ('retningsnummer',),
'retningsnumra': ('retningsnummer',),
'retningsnumre': ('retningsnummer',),
'retningsnumrene': ('retningsnummer',),
'retningsviser': ('retningsviser',),
'retningsvisere': ('retningsviser',),
'retningsviseren': ('retningsviser',),
'retningsviserer': ('retningsviser',),
'retningsviserne': ('retningsviser',),
'retor': ('retor',),
'retoren': ('retor',),
'retorene': ('retor',),
'retorer': ('retor',),
'retoriker': ('retoriker',),
'retorikere': ('retoriker',),
'retorikeren': ('retoriker',),
'retorikerer': ('retoriker',),
'retorikerne': ('retoriker',),
'retorikk': ('retorikk',),
'retorikken': ('retorikk',),
'retorikkene': ('retorikk',),
'retorikker': ('retorikk',),
'retorsjon': ('retorsjon',),
'retorsjonen': ('retorsjon',),
'retorsjonene': ('retorsjon',),
'retorsjoner': ('retorsjon',),
'retorte': ('retorte',),
'retorten': ('retorte',),
'retortene': ('retorte',),
'retorter': ('retorte',),
'retreat': ('retreat',),
'retreata': ('retreat',),
'retreaten': ('retreat',),
'retreatene': ('retreat',),
'retreater': ('retreat',),
'retreatet': ('retreat',),
'retreatheim': ('retreatheim',),
'retreatheimen': ('retreatheim',),
'retreatheimene': ('retreatheim',),
'retreatheimer': ('retreatheim',),
'retreathjem': ('retreathjem',),
'retreathjemma': ('retreathjem',),
'retreathjemmene': ('retreathjem',),
'retreathjemmet': ('retreathjem',),
'retrett': ('retrett',),
'retretten': ('retrett',),
'retrettene': ('retrett',),
'retretter': ('retrett',),
'retrettstilling': ('retrettstilling',),
'retrettstillinga': ('retrettstilling',),
'retrettstillingen': ('retrettstilling',),
'retrettstillingene': ('retrettstilling',),
'retrettstillinger': ('retrettstilling',),
'retriever': ('retriever',),
'retrievere': ('retriever',),
'retrieveren': ('retriever',),
'retrieverer': ('retriever',),
'retrieverne': ('retriever',),
'retrofleks': ('retrofleks',),
'retrofleksen': ('retrofleks',),
'retrofleksene': ('retrofleks',),
'retroflekser': ('retrofleks',),
'retrogradering': ('retrogradering',),
'retrograderinga': ('retrogradering',),
'retrograderingen': ('retrogradering',),
'retrograderingene': ('retrogradering',),
'retrograderinger': ('retrogradering',),
'retroversjon': ('retroversjon',),
'retroversjonen': ('retroversjon',),
'retroversjonene': ('retroversjon',),
'retroversjoner': ('retroversjon',),
'retsina': ('retsina',),
'retsinaen': ('retsina',),
'retsinaene': ('retsina',),
'retsinaer': ('retsina',),
'rett': ('rett',),
'retten': ('rett',),
'rettene': ('rett',),
'retter': ('rett',),
'rett': ('rett',),
'retten': ('rett',),
'rettene': ('rett',),
'retter': ('rett',),
'rett-troenhet': ('rett-troenhet',),
'rett-troenheta': ('rett-troenhet',),
'rett-troenheten': ('rett-troenhet',),
'rett-troenhetene': ('rett-troenhet',),
'rett-troenheter': ('rett-troenhet',),
'retta': ('rette',),
'rette': ('rette',),
'retten': ('rette',),
'rettene': ('rette',),
'retter': ('rette',),
'rettelse': ('rettelse',),
'rettelsen': ('rettelse',),
'rettelsene': ('rettelse',),
'rettelser': ('rettelse',),
'retterbot': ('retterbot',),
'retterbota': ('retterbot',),
'retterboten': ('retterbot',),
'retterbøtene': ('retterbot',),
'retterbøter': ('retterbot',),
'rettergang': ('rettergang',),
'rettergangen': ('rettergang',),
'rettergangene': ('rettergang',),
'retterganger': ('rettergang',),
'rettersted': ('rettersted',),
'retterstedene': ('rettersted',),
'rettersteder': ('rettersted',),
'retterstedet': ('rettersted',),
'rettesnor': ('rettesnor',),
'rettesnora': ('rettesnor',),
'rettesnoren': ('rettesnor',),
'rettesnorene': ('rettesnor',),
'rettesnorer': ('rettesnor',),
'rettferd': ('rettferd',),
'rettferda': ('rettferd',),
'rettferden': ('rettferd',),
'rettferdene': ('rettferd',),
'rettferder': ('rettferd',),
'rettferdighet': ('rettferdighet',),
'rettferdigheta': ('rettferdighet',),
'rettferdigheten': ('rettferdighet',),
'rettferdighetene': ('rettferdighet',),
'rettferdigheter': ('rettferdighet',),
'rettferdighetssans': ('rettferdighetssans',),
'rettferdighetssansen': ('rettferdighetssans',),
'rettferdighetssansene': ('rettferdighetssans',),
'rettferdighetssanser': ('rettferdighetssans',),
'retthaveri': ('retthaveri',),
'retthaveria': ('retthaveri',),
'retthaveriene': ('retthaveri',),
'retthaverier': ('retthaveri',),
'retthaveriet': ('retthaveri',),
'rettholt': ('rettholt',),
'rettholta': ('rettholt',),
'rettholten': ('rettholt',),
'rettholtene': ('rettholt',),
'rettholter': ('rettholt',),
'rettholtet': ('rettholt',),
'retthval': ('retthval',),
'retthvalen': ('retthval',),
'retthvalene': ('retthval',),
'retthvaler': ('retthval',),
'rettighet': ('rettighet',),
'rettigheta': ('rettighet',),
'rettigheten': ('rettighet',),
'rettighetene': ('rettighet',),
'rettigheter': ('rettighet',),
'rettighetshaver': ('rettighetshaver',),
'rettighetshavere': ('rettighetshaver',),
'rettighetshaveren': ('rettighetshaver',),
'rettighetshaverer': ('rettighetshaver',),
'rettighetshaverne': ('rettighetshaver',),
'retting': ('retting',),
'rettinga': ('retting',),
'rettingen': ('retting',),
'rettingene': ('retting',),
'rettinger': ('retting',),
'rettkval': ('rettkval',),
'rettkvalen': ('rettkval',),
'rettkvalene': ('rettkval',),
'rettkvaler': ('rettkval',),
'rettleder': ('rettleder',),
'rettledere': ('rettleder',),
'rettlederen': ('rettleder',),
'rettlederer': ('rettleder',),
'rettlederne': ('rettleder',),
'rettledning': ('rettledning',),
'rettledninga': ('rettledning',),
'rettledningen': ('rettledning',),
'rettledningene': ('rettledning',),
'rettledninger': ('rettledning',),
'rettleiing': ('rettleiing',),
'rettleiinga': ('rettleiing',),
'rettleiingen': ('rettleiing',),
'rettleiingene': ('rettleiing',),
'rettleiinger': ('rettleiing',),
'rettroenhet': ('rettroenhet',),
'rettroenheta': ('rettroenhet',),
'rettroenheten': ('rettroenhet',),
'rettroenhetene': ('rettroenhet',),
'rettroenheter': ('rettroenhet',),
'rettsbelæring': ('rettsbelæring',),
'rettsbelæringa': ('rettsbelæring',),
'rettsbelæringen': ('rettsbelæring',),
'rettsbelæringene': ('rettsbelæring',),
'rettsbelæringer': ('rettsbelæring',),
'rettsbevissthet': ('rettsbevissthet',),
'rettsbevisstheta': ('rettsbevissthet',),
'rettsbevisstheten': ('rettsbevissthet',),
'rettsbevissthetene': ('rettsbevissthet',),
'rettsbevisstheter': ('rettsbevissthet',),
'rettshaver': ('rettshaver',),
'rettshavere': ('rettshaver',),
'rettshaveren': ('rettshaver',),
'rettshaverer': ('rettshaver',),
'rettshaverne': ('rettshaver',),
'rettshjelp': ('rettshjelp',),
'rettshjelpa': ('rettshjelp',),
'rettshjelpen': ('rettshjelp',),
'rettshjelpene': ('rettshjelp',),
'rettshjelper': ('rettshjelp',),
'rettsinn': ('rettsinn',),
'rettsinna': ('rettsinn',),
'rettsinnene': ('rettsinn',),
'rettsinnet': ('rettsinn',),
'rettskraft': ('rettskraft',),
'rettskrafta': ('rettskraft',),
'rettskraften': ('rettskraft',),
'rettskreftene': ('rettskraft',),
'rettskrefter': ('rettskraft',),
'rettskriving': ('rettskriving',),
'rettskrivinga': ('rettskriving',),
'rettskrivingen': ('rettskriving',),
'rettskrivingene': ('rettskriving',),
'rettskrivinger': ('rettskriving',),
'rettskrivingsordlista': ('rettskrivingsordliste',),
'rettskrivingsordliste': ('rettskrivingsordliste',),
'rettskrivingsordlisten': ('rettskrivingsordliste',),
'rettskrivingsordlistene': ('rettskrivingsordliste',),
'rettskrivingsordlister': ('rettskrivingsordliste',),
'rettskrivingsregel': ('rettskrivingsregel',),
'rettskrivingsregelen': ('rettskrivingsregel',),
'rettskrivingsreglene': ('rettskrivingsregel',),
'rettskrivingsregler': ('rettskrivingsregel',),
'rettskrivning': ('rettskrivning',),
'rettskrivninga': ('rettskrivning',),
'rettskrivningen': ('rettskrivning',),
'rettskrivningene': ('rettskrivning',),
'rettskrivninger': ('rettskrivning',),
'rettskrivningsordlista': ('rettskrivningsordliste',),
'rettskrivningsordliste': ('rettskrivningsordliste',),
'rettskrivningsordlisten': ('rettskrivningsordliste',),
'rettskrivningsordlistene': ('rettskrivningsordliste',),
'rettskrivningsordlister': ('rettskrivningsordliste',),
'rettskrivningsregel': ('rettskrivningsregel',),
'rettskrivningsregelen': ('rettskrivningsregel',),
'rettskrivningsreglene': ('rettskrivningsregel',),
'rettskrivningsregler': ('rettskrivningsregel',),
'rettslæra': ('rettslære',),
'rettslære': ('rettslære',),
'rettslæren': ('rettslære',),
'rettslærene': ('rettslære',),
'rettslærer': ('rettslære',),
'rettsmedisin': ('rettsmedisin',),
'rettsmedisinen': ('rettsmedisin',),
'rettsmedisinene': ('rettsmedisin',),
'rettsmedisiner': ('rettsmedisin',),
'rettsmøta': ('rettsmøte',),
'rettsmøte': ('rettsmøte',),
'rettsmøtene': ('rettsmøte',),
'rettsmøter': ('rettsmøte',),
'rettsmøtet': ('rettsmøte',),
'rettspleia': ('rettspleie',),
'rettspleie': ('rettspleie',),
'rettspleien': ('rettspleie',),
'rettspleiene': ('rettspleie',),
'rettspleier': ('rettspleie',),
'rettssak': ('rettssak',),
'rettssaka': ('rettssak',),
'rettssaken': ('rettssak',),
'rettssakene': ('rettssak',),
'rettssaker': ('rettssak',),
'rettssal': ('rettssal',),
'rettssalen': ('rettssal',),
'rettssalene': ('rettssal',),
'rettssaler': ('rettssal',),
'rettssikkerhet': ('rettssikkerhet',),
'rettssikkerheta': ('rettssikkerhet',),
'rettssikkerheten': ('rettssikkerhet',),
'rettssikkerhetene': ('rettssikkerhet',),
'rettssikkerheter': ('rettssikkerhet',),
'rettsstat': ('rettsstat',),
'rettsstaten': ('rettsstat',),
'rettsstatene': ('rettsstat',),
'rettsstater': ('rettsstat',),
'rettstvist': ('rettstvist',),
'rettstvisten': ('rettstvist',),
'rettstvistene': ('rettstvist',),
'rettstvister': ('rettstvist',),
'rettsvesen': ('rettsvesen',),
'rettsvesena': ('rettsvesen',),
'rettsvesenene': ('rettsvesen',),
'rettsvesener': ('rettsvesen',),
'rettsvesenet': ('rettsvesen',),
'rettsvillfarelse': ('rettsvillfarelse',),
'rettsvillfarelsen': ('rettsvillfarelse',),
'rettsvillfarelsene': ('rettsvillfarelse',),
'rettsvillfarelser': ('rettsvillfarelse',),
'retur': ('retur',),
'returen': ('retur',),
'returene': ('retur',),
'returer': ('retur',),
'returbillett': ('returbillett',),
'returbilletten': ('returbillett',),
'returbillettene': ('returbillett',),
'returbilletter': ('returbillett',),
'returkamp': ('returkamp',),
'returkampen': ('returkamp',),
'returkampene': ('returkamp',),
'returkamper': ('returkamp',),
'retusj': ('retusj',),
'retusjen': ('retusj',),
'retusjene': ('retusj',),
'retusjer': ('retusj',),
'retusjør': ('retusjør',),
'retusjøren': ('retusjør',),
'retusjørene': ('retusjør',),
'retusjører': ('retusjør',),
'reumatiker': ('reumatiker',),
'reumatikere': ('reumatiker',),
'reumatikeren': ('reumatiker',),
'reumatikerer': ('reumatiker',),
'reumatikerne': ('reumatiker',),
'rev': ('rev',),
'reven': ('rev',),
'revene': ('rev',),
'rever': ('rev',),
'rev': ('rev',),
'reva': ('rev',),
'revene': ('rev',),
'revet': ('rev',),
'rev': ('rev',),
'reva': ('rev',),
'revene': ('rev',),
'revet': ('rev',),
'revansj': ('revansj',),
'revansjen': ('revansj',),
'revansjene': ('revansj',),
'revansjer': ('revansj',),
'revansje': ('revansje',),
'revansjen': ('revansje',),
'revansjene': ('revansje',),
'revansjer': ('revansje',),
'revansjeoppgjør': ('revansjeoppgjør',),
'revansjeoppgjøra': ('revansjeoppgjør',),
'revansjeoppgjørene': ('revansjeoppgjør',),
'revansjeoppgjøret': ('revansjeoppgjør',),
'revansjisme': ('revansjisme',),
'revansjismen': ('revansjisme',),
'revansjismene': ('revansjisme',),
'revansjismer': ('revansjisme',),
'revansjist': ('revansjist',),
'revansjisten': ('revansjist',),
'revansjistene': ('revansjist',),
'revansjister': ('revansjist',),
'revansjoppgjør': ('revansjoppgjør',),
'revansjoppgjøra': ('revansjoppgjør',),
'revansjoppgjørene': ('revansjoppgjør',),
'revansjoppgjøret': ('revansjoppgjør',),
'revebjella': ('revebjelle',),
'revebjelle': ('revebjelle',),
'revebjellen': ('revebjelle',),
'revebjellene': ('revebjelle',),
'revebjeller': ('revebjelle',),
'revebjølla': ('revebjølle',),
'revebjølle': ('revebjølle',),
'revebjøllen': ('revebjølle',),
'revebjøllene': ('revebjølle',),
'revebjøller': ('revebjølle',),
'revelje': ('revelje',),
'reveljen': ('revelje',),
'reveljene': ('revelje',),
'reveljer': ('revelje',),
'reverens': ('reverens',),
'reverensen': ('reverens',),
'reverensene': ('reverens',),
'reverenser': ('reverens',),
'revers': ('revers',),
'reversen': ('revers',),
'reversene': ('revers',),
'reverser': ('revers',),
'revestrek': ('revestrek',),
'revestreken': ('revestrek',),
'revestrekene': ('revestrek',),
'revestreker': ('revestrek',),
'revier': ('revier',),
'reviera': ('revier',),
'revierene': ('revier',),
'revierer': ('revier',),
'revieret': ('revier',),
'revir': ('revir',),
'revira': ('revir',),
'revirene': ('revir',),
'revirer': ('revir',),
'reviret': ('revir',),
'revisjon': ('revisjon',),
'revisjonen': ('revisjon',),
'revisjonene': ('revisjon',),
'revisjoner': ('revisjon',),
'revisjonisme': ('revisjonisme',),
'revisjonismen': ('revisjonisme',),
'revisjonismene': ('revisjonisme',),
'revisjonismer': ('revisjonisme',),
'revisjonist': ('revisjonist',),
'revisjonisten': ('revisjonist',),
'revisjonistene': ('revisjonist',),
'revisjonister': ('revisjonist',),
'revisor': ('revisor',),
'revisoren': ('revisor',),
'revisorene': ('revisor',),
'revisorer': ('revisor',),
'revkrok': ('revkrok',),
'revkroken': ('revkrok',),
'revkrokene': ('revkrok',),
'revkroker': ('revkrok',),
'revle': ('revle',),
'revlen': ('revle',),
'revlene': ('revle',),
'revler': ('revle',),
'revle': ('revle',),
'revlen': ('revle',),
'revlene': ('revle',),
'revler': ('revle',),
'revmatiker': ('revmatiker',),
'revmatikere': ('revmatiker',),
'revmatikeren': ('revmatiker',),
'revmatikerer': ('revmatiker',),
'revmatikerne': ('revmatiker',),
'revna': ('revne',),
'revne': ('revne',),
'revnen': ('revne',),
'revnene': ('revne',),
'revner': ('revne',),
'revna': ('revne',),
'revne': ('revne',),
'revnen': ('revne',),
'revnene': ('revne',),
'revner': ('revne',),
'revolt': ('revolt',),
'revolten': ('revolt',),
'revoltene': ('revolt',),
'revolter': ('revolt',),
'revolte': ('revolte',),
'revolten': ('revolte',),
'revoltene': ('revolte',),
'revolter': ('revolte',),
'revolusjon': ('revolusjon',),
'revolusjonen': ('revolusjon',),
'revolusjonene': ('revolusjon',),
'revolusjoner': ('revolusjon',),
'revolusjonist': ('revolusjonist',),
'revolusjonisten': ('revolusjonist',),
'revolusjonistene': ('revolusjonist',),
'revolusjonister': ('revolusjonist',),
'revolusjonsdomstol': ('revolusjonsdomstol',),
'revolusjonsdomstolen': ('revolusjonsdomstol',),
'revolusjonsdomstolene': ('revolusjonsdomstol',),
'revolusjonsdomstoler': ('revolusjonsdomstol',),
'revolusjonær': ('revolusjonær',),
'revolusjonæren': ('revolusjonær',),
'revolusjonærene': ('revolusjonær',),
'revolusjonærer': ('revolusjonær',),
'revolver': ('revolver',),
'revolvere': ('revolver',),
'revolveren': ('revolver',),
'revolverer': ('revolver',),
'revolverne': ('revolver',),
'revolverintervju': ('revolverintervju',),
'revolverintervjua': ('revolverintervju',),
'revolverintervjuene': ('revolverintervju',),
'revolverintervjuer': ('revolverintervju',),
'revolverintervjuet': ('revolverintervju',),
'revolverjournalistikk': ('revolverjournalistikk',),
'revolverjournalistikken': ('revolverjournalistikk',),
'revolverjournalistikkene': ('revolverjournalistikk',),
'revolverjournalistikker': ('revolverjournalistikk',),
'revolvermann': ('revolvermann',),
'revolvermannen': ('revolvermann',),
'revolvermenn': ('revolvermann',),
'revolvermennene': ('revolvermann',),
'revy': ('revy',),
'revyen': ('revy',),
'revyene': ('revy',),
'revyer': ('revy',),
'rex': ('rex',),
'rhenium': ('rhenium',),
'rheniuma': ('rhenium',),
'rheniumene': ('rhenium',),
'rheniumet': ('rhenium',),
'rhesusfaktor': ('rhesusfaktor',),
'rhesusfaktoren': ('rhesusfaktor',),
'rhesusfaktorene': ('rhesusfaktor',),
'rhesusfaktorer': ('rhesusfaktor',),
'rhinskvin': ('rhinskvin',),
'rhinskvinen': ('rhinskvin',),
'rhinskvinene': ('rhinskvin',),
'rhinskviner': ('rhinskvin',),
'rhodesier': ('rhodesier',),
'rhodesiere': ('rhodesier',),
'rhodesieren': ('rhodesier',),
'rhodesierer': ('rhodesier',),
'rhodesierne': ('rhodesier',),
'rhodium': ('rhodium',),
'rhodiuma': ('rhodium',),
'rhodiumene': ('rhodium',),
'rhodiumet': ('rhodium',),
'ri': ('ri',),
'ria': ('ri',),
'rien': ('ri',),
'riene': ('ri',),
'rier': ('ri',),
'rial': ('rial',),
'rialen': ('rial',),
'rialene': ('rial',),
'rialer': ('rial',),
'ribb-bein': ('ribb-bein',),
'ribb-beina': ('ribb-bein',),
'ribb-beinene': ('ribb-bein',),
'ribb-beinet': ('ribb-bein',),
'ribb-beinsbrott': ('ribb-beinsbrott',),
'ribb-beinsbrotta': ('ribb-beinsbrott',),
'ribb-beinsbrottene': ('ribb-beinsbrott',),
'ribb-beinsbrottet': ('ribb-beinsbrott',),
'ribb-beinsbrudd': ('ribb-beinsbrudd',),
'ribb-beinsbrudda': ('ribb-beinsbrudd',),
'ribb-beinsbruddene': ('ribb-beinsbrudd',),
'ribb-beinsbruddet': ('ribb-beinsbrudd',),
'ribb-ben': ('ribb-ben',),
'ribb-bena': ('ribb-ben',),
'ribb-benene': ('ribb-ben',),
'ribb-benet': ('ribb-ben',),
'ribb-bensbrott': ('ribb-bensbrott',),
'ribb-bensbrotta': ('ribb-bensbrott',),
'ribb-bensbrottene': ('ribb-bensbrott',),
'ribb-bensbrottet': ('ribb-bensbrott',),
'ribb-bensbrudd': ('ribb-bensbrudd',),
'ribb-bensbrudda': ('ribb-bensbrudd',),
'ribb-bensbruddene': ('ribb-bensbrudd',),
'ribb-bensbruddet': ('ribb-bensbrudd',),
'ribba': ('ribbe',),
'ribbe': ('ribbe',),
'ribben': ('ribbe',),
'ribbene': ('ribbe',),
'ribber': ('ribbe',),
'ribbein': ('ribbein',),
'ribbeina': ('ribbein',),
'ribbeinene': ('ribbein',),
'ribbeinet': ('ribbein',),
'ribbeinsbrott': ('ribbeinsbrott',),
'ribbeinsbrotta': ('ribbeinsbrott',),
'ribbeinsbrottene': ('ribbeinsbrott',),
'ribbeinsbrottet': ('ribbeinsbrott',),
'ribbeinsbrudd': ('ribbeinsbrudd',),
'ribbeinsbrudda': ('ribbeinsbrudd',),
'ribbeinsbruddene': ('ribbeinsbrudd',),
'ribbeinsbruddet': ('ribbeinsbrudd',),
'ribben': ('ribben',),
'ribbena': ('ribben',),
'ribbenene': ('ribben',),
'ribbenet': ('ribben',),
'ribbensbrott': ('ribbensbrott',),
'ribbensbrotta': ('ribbensbrott',),
'ribbensbrottene': ('ribbensbrott',),
'ribbensbrottet': ('ribbensbrott',),
'ribbensbrudd': ('ribbensbrudd',),
'ribbensbrudda': ('ribbensbrudd',),
'ribbensbruddene': ('ribbensbrudd',),
'ribbensbruddet': ('ribbensbrudd',),
'ribbestrikking': ('ribbestrikking',),
'ribbestrikkinga': ('ribbestrikking',),
'ribbestrikkingen': ('ribbestrikking',),
'ribbestrikkingene': ('ribbestrikking',),
'ribbestrikkinger': ('ribbestrikking',),
'ribbevegg': ('ribbevegg',),
'ribbeveggen': ('ribbevegg',),
'ribbeveggene': ('ribbevegg',),
'ribbevegger': ('ribbevegg',),
'ribbung': ('ribbung',),
'ribbungen': ('ribbung',),
'ribbungene': ('ribbung',),
'ribbunger': ('ribbung',),
'ricinusolja': ('ricinusolje',),
'ricinusolje': ('ricinusolje',),
'ricinusoljen': ('ricinusolje',),
'ricinusoljene': ('ricinusolje',),
'ricinusoljer': ('ricinusolje',),
'rickshaw': ('rickshaw',),
'rickshawen': ('rickshaw',),
'rickshawene': ('rickshaw',),
'rickshawer': ('rickshaw',),
'ridder': ('ridder',),
'riddere': ('ridder',),
'ridderen': ('ridder',),
'ridderer': ('ridder',),
'ridderne': ('ridder',),
'ridderdikting': ('ridderdikting',),
'ridderdiktinga': ('ridderdikting',),
'ridderdiktingen': ('ridderdikting',),
'ridderdiktingene': ('ridderdikting',),
'ridderdiktinger': ('ridderdikting',),
'ridderdiktning': ('ridderdiktning',),
'ridderdiktninga': ('ridderdiktning',),
'ridderdiktningen': ('ridderdiktning',),
'ridderdiktningene': ('ridderdiktning',),
'ridderdiktninger': ('ridderdiktning',),
'ridderlighet': ('ridderlighet',),
'ridderligheta': ('ridderlighet',),
'ridderligheten': ('ridderlighet',),
'ridderlighetene': ('ridderlighet',),
'ridderligheter': ('ridderlighet',),
'ridderorden': ('ridderorden',),
'ridderordenen': ('ridderorden',),
'ridderordenene': ('ridderorden',),
'ridderordener': ('ridderorden',),
'ridderost': ('ridderost',),
'ridderosten': ('ridderost',),
'ridderostene': ('ridderost',),
'ridderoster': ('ridderost',),
'ridderslag': ('ridderslag',),
'ridderslaga': ('ridderslag',),
'ridderslagene': ('ridderslag',),
'ridderslaget': ('ridderslag',),
'riddersmann': ('riddersmann',),
'riddersmannen': ('riddersmann',),
'riddersmenn': ('riddersmann',),
'riddersmennene': ('riddersmann',),
'ridehest': ('ridehest',),
'ridehesten': ('ridehest',),
'ridehestene': ('ridehest',),
'ridehester': ('ridehest',),
'ridepisk': ('ridepisk',),
'ridepisken': ('ridepisk',),
'ridepiskene': ('ridepisk',),
'ridepisker': ('ridepisk',),
'ridesadel': ('ridesadel',),
'ridesadelen': ('ridesadel',),
'ridesadlene': ('ridesadel',),
'ridesadler': ('ridesadel',),
'ridesal': ('ridesal',),
'ridesalen': ('ridesal',),
'ridesalene': ('ridesal',),
'ridesaler': ('ridesal',),
'rideskole': ('rideskole',),
'rideskolen': ('rideskole',),
'rideskolene': ('rideskole',),
'rideskoler': ('rideskole',),
'ridestøvel': ('ridestøvel',),
'ridestøvelen': ('ridestøvel',),
'ridestøvlene': ('ridestøvel',),
'ridestøvler': ('ridestøvel',),
'riding': ('riding',),
'ridinga': ('riding',),
'ridingen': ('riding',),
'ridingene': ('riding',),
'ridinger': ('riding',),
'ridning': ('ridning',),
'ridninga': ('ridning',),
'ridningen': ('ridning',),
'ridningene': ('ridning',),
'ridninger': ('ridning',),
'riesenschnauzer': ('riesenschnauzer',),
'riesenschnauzere': ('riesenschnauzer',),
'riesenschnauzeren': ('riesenschnauzer',),
'riesenschnauzerer': ('riesenschnauzer',),
'riesenschnauzerne': ('riesenschnauzer',),
'riesling': ('riesling',),
'rieslingen': ('riesling',),
'rieslingene': ('riesling',),
'rieslinger': ('riesling',),
'riff': ('riff',),
'riffa': ('riff',),
'riffene': ('riff',),
'riffet': ('riff',),
'rifla': ('rifle',),
'rifle': ('rifle',),
'riflen': ('rifle',),
'riflene': ('rifle',),
'rifler': ('rifle',),
'rift': ('rift',),
'rifta': ('rift',),
'riften': ('rift',),
'riftene': ('rift',),
'rifter': ('rift',),
'rigabalsam': ('rigabalsam',),
'rigabalsamen': ('rigabalsam',),
'rigabalsamene': ('rigabalsam',),
'rigabalsamer': ('rigabalsam',),
'rigel': ('rigel',),
'rigelen': ('rigel',),
'riglene': ('rigel',),
'rigler': ('rigel',),
'rigg': ('rigg',),
'riggen': ('rigg',),
'riggene': ('rigg',),
'rigger': ('rigg',),
'rigger': ('rigger',),
'riggere': ('rigger',),
'riggeren': ('rigger',),
'riggerer': ('rigger',),
'riggerne': ('rigger',),
'riggerverksted': ('riggerverksted',),
'riggerverkstedene': ('riggerverksted',),
'riggerverksteder': ('riggerverksted',),
'riggerverkstedet': ('riggerverksted',),
'rigiditet': ('rigiditet',),
'rigiditeten': ('rigiditet',),
'rigiditetene': ('rigiditet',),
'rigiditeter': ('rigiditet',),
'rigorisme': ('rigorisme',),
'rigorismen': ('rigorisme',),
'rigorismene': ('rigorisme',),
'rigorismer': ('rigorisme',),
'riing': ('riing',),
'riinga': ('riing',),
'riingen': ('riing',),
'riingene': ('riing',),
'riinger': ('riing',),
'rikdom': ('rikdom',),
'rikdommen': ('rikdom',),
'rikdommene': ('rikdom',),
'rikdommer': ('rikdom',),
'rika': ('rike',),
'rike': ('rike',),
'rikene': ('rike',),
'riker': ('rike',),
'riket': ('rike',),
'rikfolk': ('rikfolk',),
'rikfolka': ('rikfolk',),
'rikfolkene': ('rikfolk',),
'rikfolket': ('rikfolk',),
'riking': ('riking',),
'rikingen': ('riking',),
'rikingene': ('riking',),
'rikinger': ('riking',),
'rikmann': ('rikmann',),
'rikmannen': ('rikmann',),
'rikmenn': ('rikmann',),
'rikmennene': ('rikmann',),
'rikmannsklubb': ('rikmannsklubb',),
'rikmannsklubben': ('rikmannsklubb',),
'rikmannsklubbene': ('rikmannsklubb',),
'rikmannsklubber': ('rikmannsklubb',),
'rikosjett': ('rikosjett',),
'rikosjetten': ('rikosjett',),
'rikosjettene': ('rikosjett',),
'rikosjetter': ('rikosjett',),
'riksadvokat': ('riksadvokat',),
'riksadvokaten': ('riksadvokat',),
'riksadvokatene': ('riksadvokat',),
'riksadvokater': ('riksadvokat',),
'riksantikvar': ('riksantikvar',),
'riksantikvaren': ('riksantikvar',),
'riksantikvarene': ('riksantikvar',),
'riksantikvarer': ('riksantikvar',),
'riksarkiv': ('riksarkiv',),
'riksarkiva': ('riksarkiv',),
'riksarkivene': ('riksarkiv',),
'riksarkiver': ('riksarkiv',),
'riksarkivet': ('riksarkiv',),
'riksarkivar': ('riksarkivar',),
'riksarkivaren': ('riksarkivar',),
'riksarkivarene': ('riksarkivar',),
'riksarkivarer': ('riksarkivar',),
'riksdag': ('riksdag',),
'riksdagen': ('riksdag',),
'riksdagene': ('riksdag',),
'riksdager': ('riksdag',),
'riksdaler': ('riksdaler',),
'riksdalere': ('riksdaler',),
'riksdaleren': ('riksdaler',),
'riksdalerer': ('riksdaler',),
'riksdalerne': ('riksdaler',),
'riksa': ('rikse',),
'rikse': ('rikse',),
'riksen': ('rikse',),
'riksene': ('rikse',),
'rikser': ('rikse',),
'riksforsamling': ('riksforsamling',),
'riksforsamlinga': ('riksforsamling',),
'riksforsamlingen': ('riksforsamling',),
'riksforsamlingene': ('riksforsamling',),
'riksforsamlinger': ('riksforsamling',),
'riksgrensa': ('riksgrense',),
'riksgrense': ('riksgrense',),
'riksgrensen': ('riksgrense',),
'riksgrensene': ('riksgrense',),
'riksgrenser': ('riksgrense',),
'rikskringkasting': ('rikskringkasting',),
'rikskringkastinga': ('rikskringkasting',),
'rikskringkastingen': ('rikskringkasting',),
'rikskringkastingene': ('rikskringkasting',),
'rikskringkastinger': ('rikskringkasting',),
'riksmeglingsmann': ('riksmeglingsmann',),
'riksmeglingsmannen': ('riksmeglingsmann',),
'riksmeglingsmenn': ('riksmeglingsmann',),
'riksmeglingsmennene': ('riksmeglingsmann',),
'riksmeklingsmann': ('riksmeklingsmann',),
'riksmeklingsmannen': ('riksmeklingsmann',),
'riksmeklingsmenn': ('riksmeklingsmann',),
'riksmeklingsmennene': ('riksmeklingsmann',),
'riksmål': ('riksmål',),
'riksmåla': ('riksmål',),
'riksmålene': ('riksmål',),
'riksmålet': ('riksmål',),
'riksmøta': ('riksmøte',),
'riksmøte': ('riksmøte',),
'riksmøtene': ('riksmøte',),
'riksmøter': ('riksmøte',),
'riksmøtet': ('riksmøte',),
'riksnett': ('riksnett',),
'riksnetta': ('riksnett',),
'riksnettene': ('riksnett',),
'riksnettet': ('riksnett',),
'riksrett': ('riksrett',),
'riksretten': ('riksrett',),
'riksrettene': ('riksrett',),
'riksretter': ('riksrett',),
'riksrevisjon': ('riksrevisjon',),
'riksrevisjonen': ('riksrevisjon',),
'riksrevisjonene': ('riksrevisjon',),
'riksrevisjoner': ('riksrevisjon',),
'riksråd': ('riksråd',),
'riksråden': ('riksråd',),
'riksrådene': ('riksråd',),
'riksråder': ('riksråd',),
'riksråd': ('riksråd',),
'riksråda': ('riksråd',),
'riksrådene': ('riksråd',),
'riksrådet': ('riksråd',),
'riksspråk': ('riksspråk',),
'riksspråka': ('riksspråk',),
'riksspråkene': ('riksspråk',),
'riksspråket': ('riksspråk',),
'riksstyra': ('riksstyre',),
'riksstyre': ('riksstyre',),
'riksstyrene': ('riksstyre',),
'riksstyrer': ('riksstyre',),
'riksstyret': ('riksstyre',),
'rikstelefon': ('rikstelefon',),
'rikstelefonen': ('rikstelefon',),
'rikstelefonene': ('rikstelefon',),
'rikstelefoner': ('rikstelefon',),
'rikstrener': ('rikstrener',),
'rikstrenere': ('rikstrener',),
'rikstreneren': ('rikstrener',),
'rikstrenerer': ('rikstrener',),
'rikstrenerne': ('rikstrener',),
'riksveg': ('riksveg',),
'riksvegen': ('riksveg',),
'riksvegene': ('riksveg',),
'riksveger': ('riksveg',),
'riksvei': ('riksvei',),
'riksveien': ('riksvei',),
'riksveiene': ('riksvei',),
'riksveier': ('riksvei',),
'riksvåpen': ('riksvåpen',),
'riksvåpenet': ('riksvåpen',),
'riksvåpna': ('riksvåpen',),
'riksvåpnene': ('riksvåpen',),
'rikt': ('rikt',),
'rikta': ('rikt',),
'riktene': ('rikt',),
'riktet': ('rikt',),
'riktighet': ('riktighet',),
'riktigheta': ('riktighet',),
'riktigheten': ('riktighet',),
'riktighetene': ('riktighet',),
'riktigheter': ('riktighet',),
'ril': ('ril',),
'rilen': ('ril',),
'rilene': ('ril',),
'riler': ('ril',),
'rille': ('rille',),
'rillen': ('rille',),
'rillene': ('rille',),
'riller': ('rille',),
'rim': ('rim',),
'rima': ('rim',),
'rimene': ('rim',),
'rimet': ('rim',),
'rim': ('rim',),
'rima': ('rim',),
'rimen': ('rim',),
'rimene': ('rim',),
'rimer': ('rim',),
'rimet': ('rim',),
'rimbrev': ('rimbrev',),
'rimbreva': ('rimbrev',),
'rimbrevene': ('rimbrev',),
'rimbrever': ('rimbrev',),
'rimbrevet': ('rimbrev',),
'rimeri': ('rimeri',),
'rimeria': ('rimeri',),
'rimeriene': ('rimeri',),
'rimerier': ('rimeri',),
'rimeriet': ('rimeri',),
'rimfrost': ('rimfrost',),
'rimfrosten': ('rimfrost',),
'rimfrostene': ('rimfrost',),
'rimfroster': ('rimfrost',),
'rimord': ('rimord',),
'rimorda': ('rimord',),
'rimordene': ('rimord',),
'rimordet': ('rimord',),
'rimsmed': ('rimsmed',),
'rimsmeden': ('rimsmed',),
'rimsmedene': ('rimsmed',),
'rimsmeder': ('rimsmed',),
'rimtuss': ('rimtuss',),
'rimtussen': ('rimtuss',),
'rimtussene': ('rimtuss',),
'rimtusser': ('rimtuss',),
'rimtusse': ('rimtusse',),
'rimtussen': ('rimtusse',),
'rimtussene': ('rimtusse',),
'rimtusser': ('rimtusse',),
'rin': ('rin',),
'rina': ('rin',),
'rinene': ('rin',),
'rinet': ('rin',),
'ring': ('ring',),
'ringen': ('ring',),
'ringene': ('ring',),
'ringer': ('ring',),
'ringblomst': ('ringblomst',),
'ringblomsten': ('ringblomst',),
'ringblomstene': ('ringblomst',),
'ringblomster': ('ringblomst',),
'ringbrynja': ('ringbrynje',),
'ringbrynje': ('ringbrynje',),
'ringbrynjen': ('ringbrynje',),
'ringbrynjene': ('ringbrynje',),
'ringbrynjer': ('ringbrynje',),
'ringbuss': ('ringbuss',),
'ringbussen': ('ringbuss',),
'ringbussene': ('ringbuss',),
'ringbusser': ('ringbuss',),
'ringdans': ('ringdans',),
'ringdansen': ('ringdans',),
'ringdansene': ('ringdans',),
'ringdanser': ('ringdans',),
'ringdommer': ('ringdommer',),
'ringdommere': ('ringdommer',),
'ringdommeren': ('ringdommer',),
'ringdommerer': ('ringdommer',),
'ringdommerne': ('ringdommer',),
'ringdua': ('ringdue',),
'ringdue': ('ringdue',),
'ringduen': ('ringdue',),
'ringduene': ('ringdue',),
'ringduer': ('ringdue',),
'ringa': ('ringe',),
'ringe': ('ringe',),
'ringen': ('ringe',),
'ringene': ('ringe',),
'ringer': ('ringe',),
'ringeakt': ('ringeakt',),
'ringeakten': ('ringeakt',),
'ringeaktene': ('ringeakt',),
'ringeakter': ('ringeakt',),
'ringeapparat': ('ringeapparat',),
'ringeapparata': ('ringeapparat',),
'ringeapparatene': ('ringeapparat',),
'ringeapparater': ('ringeapparat',),
'ringeapparatet': ('ringeapparat',),
'ringeklokka': ('ringeklokke',),
'ringeklokke': ('ringeklokke',),
'ringeklokken': ('ringeklokke',),
'ringeklokkene': ('ringeklokke',),
'ringeklokker': ('ringeklokke',),
'ringel': ('ringel',),
'ringelet': ('ringel',),
'ringla': ('ringel',),
'ringlene': ('ringel',),
'ringler': ('ringel',),
'ringlet': ('ringel',),
'ringer': ('ringer',),
'ringere': ('ringer',),
'ringeren': ('ringer',),
'ringerer': ('ringer',),
'ringerne': ('ringer',),
'ringeriking': ('ringeriking',),
'ringerikingen': ('ringeriking',),
'ringerikingene': ('ringeriking',),
'ringerikinger': ('ringeriking',),
'ringfinger': ('ringfinger',),
'ringfingeren': ('ringfinger',),
'ringfingre': ('ringfinger',),
'ringfingrene': ('ringfinger',),
'ringfingrer': ('ringfinger',),
'ringfjell': ('ringfjell',),
'ringfjella': ('ringfjell',),
'ringfjellene': ('ringfjell',),
'ringfjellet': ('ringfjell',),
'ringgjess': ('ringgås',),
'ringgjessene': ('ringgås',),
'ringgjæsene': ('ringgås',),
'ringgjæser': ('ringgås',),
'ringgås': ('ringgås',),
'ringgåsa': ('ringgås',),
'ringgåsen': ('ringgås',),
'ringhet': ('ringhet',),
'ringheta': ('ringhet',),
'ringheten': ('ringhet',),
'ringhetene': ('ringhet',),
'ringheter': ('ringhet',),
'ringla': ('ringle',),
'ringle': ('ringle',),
'ringlen': ('ringle',),
'ringlene': ('ringle',),
'ringler': ('ringle',),
'ringorm': ('ringorm',),
'ringormen': ('ringorm',),
'ringormene': ('ringorm',),
'ringormer': ('ringorm',),
'ringperm': ('ringperm',),
'ringpermen': ('ringperm',),
'ringpermene': ('ringperm',),
'ringpermer': ('ringperm',),
'ringrev': ('ringrev',),
'ringreven': ('ringrev',),
'ringrevene': ('ringrev',),
'ringrever': ('ringrev',),
'ringveg': ('ringveg',),
'ringvegen': ('ringveg',),
'ringvegene': ('ringveg',),
'ringveger': ('ringveg',),
'ringvei': ('ringvei',),
'ringveien': ('ringvei',),
'ringveiene': ('ringvei',),
'ringveier': ('ringvei',),
'ringvirkning': ('ringvirkning',),
'ringvirkninga': ('ringvirkning',),
'ringvirkningen': ('ringvirkning',),
'ringvirkningene': ('ringvirkning',),
'ringvirkninger': ('ringvirkning',),
'rinskvin': ('rinskvin',),
'rinskvinen': ('rinskvin',),
'rinskvinene': ('rinskvin',),
'rinskviner': ('rinskvin',),
'rip': ('rip',),
'ripa': ('rip',),
'ripene': ('rip',),
'ripet': ('rip',),
'rip': ('rip',),
'ripa': ('rip',),
'ripen': ('rip',),
'ripene': ('rip',),
'riper': ('rip',),
'ripa': ('ripe',),
'ripe': ('ripe',),
'ripen': ('ripe',),
'ripene': ('ripe',),
'riper': ('ripe',),
'ripa': ('ripe',),
'ripe': ('ripe',),
'ripen': ('ripe',),
'ripene': ('ripe',),
'riper': ('ripe',),
'ripost': ('ripost',),
'riposten': ('ripost',),
'ripostene': ('ripost',),
'riposter': ('ripost',),
'ripsbusk': ('ripsbusk',),
'ripsbusken': ('ripsbusk',),
'ripsbuskene': ('ripsbusk',),
'ripsbusker': ('ripsbusk',),
'ripsbær': ('ripsbær',),
'ripsbæra': ('ripsbær',),
'ripsbærene': ('ripsbær',),
'ripsbæret': ('ripsbær',),
'ris': ('ris',),
'risen': ('ris',),
'risene': ('ris',),
'riser': ('ris',),
'ris': ('ris',),
'risa': ('ris',),
'risene': ('ris',),
'riset': ('ris',),
'ris': ('ris',),
'risa': ('ris',),
'risene': ('ris',),
'riset': ('ris',),
'risbit': ('risbit',),
'risbiten': ('risbit',),
'risbitene': ('risbit',),
'risbiter': ('risbit',),
'rise': ('rise',),
'risen': ('rise',),
'risene': ('rise',),
'riser': ('rise',),
'risengraut': ('risengraut',),
'risengrauten': ('risengraut',),
'risengrautene': ('risengraut',),
'risengrauter': ('risengraut',),
'risengryn': ('risengryn',),
'risengryna': ('risengryn',),
'risengrynene': ('risengryn',),
'risengrynet': ('risengryn',),
'risengrynsgraut': ('risengrynsgraut',),
'risengrynsgrauten': ('risengrynsgraut',),
'risengrynsgrautene': ('risengrynsgraut',),
'risengrynsgrauter': ('risengrynsgraut',),
'risengrynsgrøt': ('risengrynsgrøt',),
'risengrynsgrøten': ('risengrynsgrøt',),
'risengrynsgrøtene': ('risengrynsgrøt',),
'risengrynsgrøter': ('risengrynsgrøt',),
'risengrøt': ('risengrøt',),
'risengrøten': ('risengrøt',),
'risengrøtene': ('risengrøt',),
'risengrøter': ('risengrøt',),
'risgjerda': ('risgjerde',),
'risgjerde': ('risgjerde',),
'risgjerdene': ('risgjerde',),
'risgjerder': ('risgjerde',),
'risgjerdet': ('risgjerde',),
'risgraut': ('risgraut',),
'risgrauten': ('risgraut',),
'risgrautene': ('risgraut',),
'risgrauter': ('risgraut',),
'risgryn': ('risgryn',),
'risgryna': ('risgryn',),
'risgrynene': ('risgryn',),
'risgrynet': ('risgryn',),
'risgrøt': ('risgrøt',),
'risgrøten': ('risgrøt',),
'risgrøtene': ('risgrøt',),
'risgrøter': ('risgrøt',),
'risiko': ('risiko',),
'risikoen': ('risiko',),
'risikoene': ('risiko',),
'risikoer': ('risiko',),
'risikokapital': ('risikokapital',),
'risikokapitalen': ('risikokapital',),
'risikokapitalene': ('risikokapital',),
'risikokapitaler': ('risikokapital',),
'risk': ('risk',),
'risken': ('risk',),
'riskene': ('risk',),
'risker': ('risk',),
'riska': ('riske',),
'riske': ('riske',),
'risken': ('riske',),
'riskene': ('riske',),
'risker': ('riske',),
'risla': ('risle',),
'risle': ('risle',),
'rislen': ('risle',),
'rislene': ('risle',),
'risler': ('risle',),
'risla': ('risle',),
'risle': ('risle',),
'rislen': ('risle',),
'rislene': ('risle',),
'risler': ('risle',),
'risling': ('risling',),
'rislinga': ('risling',),
'rislingen': ('risling',),
'rislingene': ('risling',),
'rislinger': ('risling',),
'risotto': ('risotto',),
'risottoen': ('risotto',),
'risottoene': ('risotto',),
'risottoer': ('risotto',),
'risp': ('risp',),
'rispa': ('risp',),
'rispene': ('risp',),
'rispet': ('risp',),
'rispa': ('rispe',),
'rispe': ('rispe',),
'rispen': ('rispe',),
'rispene': ('rispe',),
'risper': ('rispe',),
'rispa': ('rispe',),
'rispe': ('rispe',),
'rispen': ('rispe',),
'rispene': ('rispe',),
'risper': ('rispe',),
'riss': ('riss',),
'rissa': ('riss',),
'rissene': ('riss',),
'risset': ('riss',),
'rissefjær': ('rissefjær',),
'rissefjæra': ('rissefjær',),
'rissefjæren': ('rissefjær',),
'rissefjærene': ('rissefjær',),
'rissefjærer': ('rissefjær',),
'rissefjør': ('rissefjør',),
'rissefjøra': ('rissefjør',),
'rissefjøren': ('rissefjør',),
'rissefjørene': ('rissefjør',),
'rissefjører': ('rissefjør',),
'rist': ('rist',),
'rista': ('rist',),
'ristene': ('rist',),
'ristet': ('rist',),
'rist': ('rist',),
'rista': ('rist',),
'ristene': ('rist',),
'ristet': ('rist',),
'rist': ('rist',),
'rista': ('rist',),
'risten': ('rist',),
'ristene': ('rist',),
'rister': ('rist',),
'rist': ('rist',),
'rista': ('rist',),
'risten': ('rist',),
'ristene': ('rist',),
'rister': ('rist',),
'rist': ('rist',),
'rista': ('rist',),
'risten': ('rist',),
'ristene': ('rist',),
'rister': ('rist',),
'rist': ('rist',),
'ristel': ('ristel',),
'ristelen': ('ristel',),
'ristlene': ('ristel',),
'ristler': ('ristel',),
'ristorno': ('ristorno',),
'ristornoen': ('ristorno',),
'ristornoene': ('ristorno',),
'ristornoer': ('ristorno',),
'risunge': ('risunge',),
'risungen': ('risunge',),
'risungene': ('risunge',),
'risunger': ('risunge',),
'ritardando': ('ritardando',),
'ritardandoa': ('ritardando',),
'ritardandoene': ('ritardando',),
'ritardandoer': ('ritardando',),
'ritardandoet': ('ritardando',),
'rite': ('rite',),
'riten': ('rite',),
'ritene': ('rite',),
'riter': ('rite',),
'ritornell': ('ritornell',),
'ritornella': ('ritornell',),
'ritornellen': ('ritornell',),
'ritornellene': ('ritornell',),
'ritorneller': ('ritornell',),
'ritornellet': ('ritornell',),
'ritt': ('ritt',),
'ritta': ('ritt',),
'rittene': ('ritt',),
'rittet': ('ritt',),
'rittmester': ('rittmester',),
'rittmestere': ('rittmester',),
'rittmesteren': ('rittmester',),
'rittmesterer': ('rittmester',),
'rittmesterne': ('rittmester',),
'rittmestre': ('rittmester',),
'rittmestrene': ('rittmester',),
'rittmestrer': ('rittmester',),
'ritual': ('ritual',),
'rituala': ('ritual',),
'ritualene': ('ritual',),
'ritualer': ('ritual',),
'ritualet': ('ritual',),
'ritualmord': ('ritualmord',),
'ritualmorda': ('ritualmord',),
'ritualmordene': ('ritualmord',),
'ritualmordet': ('ritualmord',),
'ritene': ('ritus',),
'riter': ('ritus',),
'ritus': ('ritus',),
'ritusen': ('ritus',),
'ritusene': ('ritus',),
'rituser': ('ritus',),
'riv': ('riv',),
'riva': ('riv',),
'rivene': ('riv',),
'rivet': ('riv',),
'rival': ('rival',),
'rivalen': ('rival',),
'rivalene': ('rival',),
'rivaler': ('rival',),
'rivalinna': ('rivalinne',),
'rivalinne': ('rivalinne',),
'rivalinnen': ('rivalinne',),
'rivalinnene': ('rivalinne',),
'rivalinner': ('rivalinne',),
'rivalitet': ('rivalitet',),
'rivaliteten': ('rivalitet',),
'rivalitetene': ('rivalitet',),
'rivaliteter': ('rivalitet',),
'riva': ('rive',),
'rive': ('rive',),
'riven': ('rive',),
'rivene': ('rive',),
'river': ('rive',),
'rivehoda': ('rivehode',),
'rivehode': ('rivehode',),
'rivehodene': ('rivehode',),
'rivehoder': ('rivehode',),
'rivehodet': ('rivehode',),
'rivetind': ('rivetind',),
'rivetinden': ('rivetind',),
'rivetindene': ('rivetind',),
'rivetinder': ('rivetind',),
'riviera': ('riviera',),
'rivieraen': ('riviera',),
'rivieraene': ('riviera',),
'rivieraer': ('riviera',),
'rivjern': ('rivjern',),
'rivjerna': ('rivjern',),
'rivjernene': ('rivjern',),
'rivjernet': ('rivjern',),
'rivna': ('rivne',),
'rivne': ('rivne',),
'rivnen': ('rivne',),
'rivnene': ('rivne',),
'rivner': ('rivne',),
'rivna': ('rivne',),
'rivne': ('rivne',),
'rivnen': ('rivne',),
'rivnene': ('rivne',),
'rivner': ('rivne',),
'rivning': ('rivning',),
'rivninga': ('rivning',),
'rivningen': ('rivning',),
'rivningene': ('rivning',),
'rivninger': ('rivning',),
'roastbiff': ('roastbiff',),
'roastbiffen': ('roastbiff',),
'roastbiffene': ('roastbiff',),
'roastbiffer': ('roastbiff',),
'robber': ('robber',),
'robbere': ('robber',),
'robberen': ('robber',),
'robberer': ('robber',),
'robberne': ('robber',),
'robe': ('robe',),
'roben': ('robe',),
'robene': ('robe',),
'rober': ('robe',),
'robinsonade': ('robinsonade',),
'robinsonaden': ('robinsonade',),
'robinsonadene': ('robinsonade',),
'robinsonader': ('robinsonade',),
'robot': ('robot',),
'roboten': ('robot',),
'robotene': ('robot',),
'roboter': ('robot',),
'robotbilda': ('robotbilde',),
'robotbilde': ('robotbilde',),
'robotbildene': ('robotbilde',),
'robotbilder': ('robotbilde',),
'robotbildet': ('robotbilde',),
'robotikk': ('robotikk',),
'robotikken': ('robotikk',),
'robotikkene': ('robotikk',),
'robotikker': ('robotikk',),
'robåt': ('robåt',),
'robåten': ('robåt',),
'robåtene': ('robåt',),
'robåter': ('robåt',),
'rock': ('rock',),
'rocken': ('rock',),
'rockene': ('rock',),
'rocker': ('rock',),
'rock and roll': ('rock and roll',),
'rock and rollen': ('rock and roll',),
'rock and rollene': ('rock and roll',),
'rock and roller': ('rock and roll',),
'rockeplata': ('rockeplate',),
'rockeplate': ('rockeplate',),
'rockeplaten': ('rockeplate',),
'rockeplatene': ('rockeplate',),
'rockeplater': ('rockeplate',),
'rockering': ('rockering',),
'rockeringen': ('rockering',),
'rockeringene': ('rockering',),
'rockeringer': ('rockering',),
'rockesanger': ('rockesanger',),
'rockesangere': ('rockesanger',),
'rockesangeren': ('rockesanger',),
'rockesangerer': ('rockesanger',),
'rockesangerne': ('rockesanger',),
'rode': ('rode',),
'roden': ('rode',),
'rodene': ('rode',),
'roder': ('rode',),
'rode': ('rode',),
'roden': ('rode',),
'rodene': ('rode',),
'roder': ('rode',),
'rodeforstander': ('rodeforstander',),
'rodeforstandere': ('rodeforstander',),
'rodeforstanderen': ('rodeforstander',),
'rodeforstanderer': ('rodeforstander',),
'rodeforstanderne': ('rodeforstander',),
'rodeforstander': ('rodeforstander',),
'rodeforstandere': ('rodeforstander',),
'rodeforstanderen': ('rodeforstander',),
'rodeforstanderer': ('rodeforstander',),
'rodeforstanderne': ('rodeforstander',),
'rodemester': ('rodemester',),
'rodemestere': ('rodemester',),
'rodemesteren': ('rodemester',),
'rodemesterer': ('rodemester',),
'rodemesterne': ('rodemester',),
'rodemestre': ('rodemester',),
'rodemestrene': ('rodemester',),
'rodemestrer': ('rodemester',),
'rodemester': ('rodemester',),
'rodemestere': ('rodemester',),
'rodemesteren': ('rodemester',),
'rodemesterer': ('rodemester',),
'rodemesterne': ('rodemester',),
'rodemestre': ('rodemester',),
'rodemestrene': ('rodemester',),
'rodemestrer': ('rodemester',),
'rodeo': ('rodeo',),
'rodeoen': ('rodeo',),
'rodeoene': ('rodeo',),
'rodeoer': ('rodeo',),
'rododendron': ('rododendron',),
'rododendronen': ('rododendron',),
'rododendronene': ('rododendron',),
'rododendroner': ('rododendron',),
'roe': ('roe',),
'roen': ('roe',),
'roene': ('roe',),
'roer': ('roe',),
'roer': ('roer',),
'roere': ('roer',),
'roeren': ('roer',),
'roerer': ('roer',),
'roerne': ('roer',),
'roesukker': ('roesukker',),
'roesukkera': ('roesukker',),
'roesukkere': ('roesukker',),
'roesukkerene': ('roesukker',),
'roesukkeret': ('roesukker',),
'roesukkerne': ('roesukker',),
'rogalending': ('rogalending',),
'rogalendingen': ('rogalending',),
'rogalendingene': ('rogalending',),
'rogalendinger': ('rogalending',),
'rognasal': ('rognasal',),
'rognasalen': ('rognasal',),
'rognasalene': ('rognasal',),
'rognasaler': ('rognasal',),
'rognebær': ('rognebær',),
'rognebæra': ('rognebær',),
'rognebærene': ('rognebær',),
'rognebæret': ('rognebær',),
'rognebær': ('rognebær',),
'rognebæra': ('rognebær',),
'rognebærene': ('rognebær',),
'rognebæret': ('rognebær',),
'rognebærmøll': ('rognebærmøll',),
'rognebærmølla': ('rognebærmøll',),
'rognebærmøllen': ('rognebærmøll',),
'rognebærmøllene': ('rognebærmøll',),
'rognebærmøllet': ('rognebærmøll',),
'rognfisk': ('rognfisk',),
'rognfisken': ('rognfisk',),
'rognfiskene': ('rognfisk',),
'rognfisker': ('rognfisk',),
'rognkall': ('rognkall',),
'rognkallen': ('rognkall',),
'rognkallene': ('rognkall',),
'rognkaller': ('rognkall',),
'rognkjeks': ('rognkjeks',),
'rognkjeksa': ('rognkjeks',),
'rognkjeksen': ('rognkjeks',),
'rognkjeksene': ('rognkjeks',),
'rognkjekser': ('rognkjeks',),
'rognkjeksa': ('rognkjekse',),
'rognkjekse': ('rognkjekse',),
'rognkjeksen': ('rognkjekse',),
'rognkjeksene': ('rognkjekse',),
'rognkjekser': ('rognkjekse',),
'rojalisme': ('rojalisme',),
'rojalismen': ('rojalisme',),
'rojalismene': ('rojalisme',),
'rojalismer': ('rojalisme',),
'rojalist': ('rojalist',),
'rojalisten': ('rojalist',),
'rojalistene': ('rojalist',),
'rojalister': ('rojalist',),
'rok': ('rok',),
'roka': ('rok',),
'rokene': ('rok',),
'roket': ('rok',),
'rok': ('rok',),
'roka': ('rok',),
'rokene': ('rok',),
'roket': ('rok',),
'rokade': ('rokade',),
'rokaden': ('rokade',),
'rokadene': ('rokade',),
'rokader': ('rokade',),
'rokering': ('rokering',),
'rokeringa': ('rokering',),
'rokeringen': ('rokering',),
'rokeringene': ('rokering',),
'rokeringer': ('rokering',),
'rokk': ('rokk',),
'rokken': ('rokk',),
'rokkene': ('rokk',),
'rokker': ('rokk',),
'rokk': ('rokk',),
'rokka': ('rokk',),
'rokkene': ('rokk',),
'rokket': ('rokk',),
'rokk': ('rokk',),
'rokka': ('rokk',),
'rokkene': ('rokk',),
'rokket': ('rokk',),
'rokka': ('rokke',),
'rokke': ('rokke',),
'rokken': ('rokke',),
'rokkene': ('rokke',),
'rokker': ('rokke',),
'rokkehjul': ('rokkehjul',),
'rokkehjula': ('rokkehjul',),
'rokkehjulene': ('rokkehjul',),
'rokkehjulet': ('rokkehjul',),
'rokokko': ('rokokko',),
'rokokkoen': ('rokokko',),
'rokokkoene': ('rokokko',),
'rokokkoer': ('rokokko',),
'rokokkomøbel': ('rokokkomøbel',),
'rokokkomøbelet': ('rokokkomøbel',),
'rokokkomøbla': ('rokokkomøbel',),
'rokokkomøblene': ('rokokkomøbel',),
'rokokkomøbler': ('rokokkomøbel',),
'rokokkomøblet': ('rokokkomøbel',),
'rokokkostil': ('rokokkostil',),
'rokokkostilen': ('rokokkostil',),
'rokokkostilene': ('rokokkostil',),
'rokokkostiler': ('rokokkostil',),
'roll': ('roll',),
'rollen': ('roll',),
'rollene': ('roll',),
'roller': ('roll',),
'roll-on-roll-off': ('roll-on-roll-off',),
'rolla': ('rolle',),
'rolle': ('rolle',),
'rollen': ('rolle',),
'rollene': ('rolle',),
'roller': ('rolle',),
'rollebesetning': ('rollebesetning',),
'rollebesetninga': ('rollebesetning',),
'rollebesetningen': ('rollebesetning',),
'rollebesetningene': ('rollebesetning',),
'rollebesetninger': ('rollebesetning',),
'rollehefta': ('rollehefte',),
'rollehefte': ('rollehefte',),
'rolleheftene': ('rollehefte',),
'rollehefter': ('rollehefte',),
'rolleheftet': ('rollehefte',),
'rollemønster': ('rollemønster',),
'rollemønsteret': ('rollemønster',),
'rollemønstra': ('rollemønster',),
'rollemønstre': ('rollemønster',),
'rollemønstrene': ('rollemønster',),
'rollemønstret': ('rollemønster',),
'rolling': ('rolling',),
'rollingen': ('rolling',),
'rollingene': ('rolling',),
'rollinger': ('rolling',),
'rollmops': ('rollmops',),
'rollmopsen': ('rollmops',),
'rollmopsene': ('rollmops',),
'rollmopser': ('rollmops',),
'rom': ('rom',),
'rommen': ('rom',),
'rommene': ('rom',),
'rommer': ('rom',),
'rom': ('rom',),
'romma': ('rom',),
'rommene': ('rom',),
'rommet': ('rom',),
'roman': ('roman',),
'romanen': ('roman',),
'romanene': ('roman',),
'romaner': ('roman',),
'romanes': ('romanes',),
'romanfigur': ('romanfigur',),
'romanfiguren': ('romanfigur',),
'romanfigurene': ('romanfigur',),
'romanfigurer': ('romanfigur',),
'romanforfatter': ('romanforfatter',),
'romanforfattere': ('romanforfatter',),
'romanforfatteren': ('romanforfatter',),
'romanforfatterer': ('romanforfatter',),
'romanforfatterne': ('romanforfatter',),
'romanhelt': ('romanhelt',),
'romanhelten': ('romanhelt',),
'romanheltene': ('romanhelt',),
'romanhelter': ('romanhelt',),
'romani': ('romani',),
'romanien': ('romani',),
'romaniene': ('romani',),
'romanier': ('romani',),
'romanisme': ('romanisme',),
'romanismen': ('romanisme',),
'romanismene': ('romanisme',),
'romanismer': ('romanisme',),
'romanist': ('romanist',),
'romanisten': ('romanist',),
'romanistene': ('romanist',),
'romanister': ('romanist',),
'romanse': ('romanse',),
'romansen': ('romanse',),
'romansene': ('romanse',),
'romanser': ('romanse',),
'romanseaften': ('romanseaften',),
'romanseaftenen': ('romanseaften',),
'romanseaftenene': ('romanseaften',),
'romanseaftener': ('romanseaften',),
'romantiker': ('romantiker',),
'romantikere': ('romantiker',),
'romantikeren': ('romantiker',),
'romantikerer': ('romantiker',),
'romantikerne': ('romantiker',),
'romantikk': ('romantikk',),
'romantikken': ('romantikk',),
'romantikkene': ('romantikk',),
'romantikker': ('romantikk',),
'romapengene': ('romapenger',),
'romapenger': ('romapenger',),
'romaskatt': ('romaskatt',),
'romaskatten': ('romaskatt',),
'romaskattene': ('romaskatt',),
'romaskatter': ('romaskatt',),
'rombe': ('rombe',),
'romben': ('rombe',),
'rombene': ('rombe',),
'romber': ('rombe',),
'romdrakt': ('romdrakt',),
'romdrakta': ('romdrakt',),
'romdrakten': ('romdrakt',),
'romdraktene': ('romdrakt',),
'romdrakter': ('romdrakt',),
'romer': ('romer',),
'romere': ('romer',),
'romeren': ('romer',),
'romerer': ('romer',),
'romerne': ('romer',),
'romerbad': ('romerbad',),
'romerbada': ('romerbad',),
'romerbadene': ('romerbad',),
'romerbadet': ('romerbad',),
'romerbrev': ('romerbrev',),
'romerbreva': ('romerbrev',),
'romerbrevene': ('romerbrev',),
'romerbrever': ('romerbrev',),
'romerbrevet': ('romerbrev',),
'romeriking': ('romeriking',),
'romerikingen': ('romeriking',),
'romerikingene': ('romeriking',),
'romerikinger': ('romeriking',),
'romerkirka': ('romerkirke',),
'romerkirke': ('romerkirke',),
'romerkirken': ('romerkirke',),
'romerkirkene': ('romerkirke',),
'romerkirker': ('romerkirke',),
'romerkjerka': ('romerkjerke',),
'romerkjerke': ('romerkjerke',),
'romerkjerken': ('romerkjerke',),
'romerkjerkene': ('romerkjerke',),
'romerkjerker': ('romerkjerke',),
'romernesa': ('romernese',),
'romernese': ('romernese',),
'romernesen': ('romernese',),
'romernesene': ('romernese',),
'romerneser': ('romernese',),
'romerrett': ('romerrett',),
'romerretten': ('romerrett',),
'romerrettene': ('romerrett',),
'romerretter': ('romerrett',),
'romertal': ('romertal',),
'romertala': ('romertal',),
'romertalene': ('romertal',),
'romertalet': ('romertal',),
'romertall': ('romertall',),
'romertalla': ('romertall',),
'romertallene': ('romertall',),
'romertallet': ('romertall',),
'romessens': ('romessens',),
'romessensen': ('romessens',),
'romessensene': ('romessens',),
'romessenser': ('romessens',),
'romfang': ('romfang',),
'romfanga': ('romfang',),
'romfangene': ('romfang',),
'romfanget': ('romfang',),
'romfarer': ('romfarer',),
'romfarere': ('romfarer',),
'romfareren': ('romfarer',),
'romfarerer': ('romfarer',),
'romfarerne': ('romfarer',),
'romfart': ('romfart',),
'romfarten': ('romfart',),
'romfartene': ('romfart',),
'romfarter': ('romfart',),
'romfartøy': ('romfartøy',),
'romfartøya': ('romfartøy',),
'romfartøyene': ('romfartøy',),
'romfartøyer': ('romfartøy',),
'romfartøyet': ('romfartøy',),
'romferd': ('romferd',),
'romferda': ('romferd',),
'romferden': ('romferd',),
'romferdene': ('romferd',),
'romferder': ('romferd',),
'romferga': ('romferge',),
'romferge': ('romferge',),
'romfergen': ('romferge',),
'romfergene': ('romferge',),
'romferger': ('romferge',),
'romferja': ('romferje',),
'romferje': ('romferje',),
'romferjen': ('romferje',),
'romferjene': ('romferje',),
'romferjer': ('romferje',),
'romfigur': ('romfigur',),
'romfiguren': ('romfigur',),
'romfigurene': ('romfigur',),
'romfigurer': ('romfigur',),
'romgeometri': ('romgeometri',),
'romgeometrien': ('romgeometri',),
'romgeometriene': ('romgeometri',),
'romgeometrier': ('romgeometri',),
'romhelg': ('romhelg',),
'romhelga': ('romhelg',),
'romhelgen': ('romhelg',),
'romhelgene': ('romhelg',),
'romhelger': ('romhelg',),
'rominnhold': ('rominnhold',),
'rominnholda': ('rominnhold',),
'rominnholdene': ('rominnhold',),
'rominnholdet': ('rominnhold',),
'romjul': ('romjul',),
'romjula': ('romjul',),
'romjulen': ('romjul',),
'romjulene': ('romjul',),
'romjuler': ('romjul',),
'romkapsel': ('romkapsel',),
'romkapselen': ('romkapsel',),
'romkapslene': ('romkapsel',),
'romkapsler': ('romkapsel',),
'rommål': ('rommål',),
'rommåla': ('rommål',),
'rommålene': ('rommål',),
'rommålet': ('rommål',),
'romrakett': ('romrakett',),
'romraketten': ('romrakett',),
'romrakettene': ('romrakett',),
'romraketter': ('romrakett',),
'romreisa': ('romreise',),
'romreise': ('romreise',),
'romreisen': ('romreise',),
'romreisene': ('romreise',),
'romreiser': ('romreise',),
'romsans': ('romsans',),
'romsansen': ('romsans',),
'romsansene': ('romsans',),
'romsanser': ('romsans',),
'romsdaling': ('romsdaling',),
'romsdalingen': ('romsdaling',),
'romsdalingene': ('romsdaling',),
'romsdalinger': ('romsdaling',),
'romskip': ('romskip',),
'romskipa': ('romskip',),
'romskipene': ('romskip',),
'romskipet': ('romskip',),
'romsonde': ('romsonde',),
'romsonden': ('romsonde',),
'romsondene': ('romsonde',),
'romsonder': ('romsonde',),
'romstasjon': ('romstasjon',),
'romstasjonen': ('romstasjon',),
'romstasjonene': ('romstasjon',),
'romstasjoner': ('romstasjon',),
'romstørrelse': ('romstørrelse',),
'romstørrelsen': ('romstørrelse',),
'romstørrelsene': ('romstørrelse',),
'romstørrelser': ('romstørrelse',),
'romvirkning': ('romvirkning',),
'romvirkninga': ('romvirkning',),
'romvirkningen': ('romvirkning',),
'romvirkningene': ('romvirkning',),
'romvirkninger': ('romvirkning',),
'rondell': ('rondell',),
'rondellen': ('rondell',),
'rondellene': ('rondell',),
'rondeller': ('rondell',),
'rondo': ('rondo',),
'rondoen': ('rondo',),
'rondoene': ('rondo',),
'rondoer': ('rondo',),
'rengene': ('rong',),
'renger': ('rong',),
'rong': ('rong',),
'ronga': ('rong',),
'rongen': ('rong',),
'rop': ('rop',),
'ropa': ('rop',),
'ropene': ('rop',),
'ropet': ('rop',),
'ropert': ('ropert',),
'roperten': ('ropert',),
'ropertene': ('ropert',),
'roperter': ('ropert',),
'roquefort': ('roquefort',),
'roqueforten': ('roquefort',),
'roquefortene': ('roquefort',),
'roqueforter': ('roquefort',),
'ror': ('ror',),
'roren': ('ror',),
'rorene': ('ror',),
'rorer': ('ror',),
'ror': ('ror',),
'rora': ('ror',),
'rorene': ('ror',),
'roret': ('ror',),
'rorbu': ('rorbu',),
'rorbua': ('rorbu',),
'rorbuen': ('rorbu',),
'rorbuene': ('rorbu',),
'rorbuer': ('rorbu',),
'rorbuferie': ('rorbuferie',),
'rorbuferien': ('rorbuferie',),
'rorbuferiene': ('rorbuferie',),
'rorbuferier': ('rorbuferie',),
'rorkar': ('rorkar',),
'rorkaren': ('rorkar',),
'rorkarene': ('rorkar',),
'rorkarer': ('rorkar',),
'rorkult': ('rorkult',),
'rorkulten': ('rorkult',),
'rorkultene': ('rorkult',),
'rorkulter': ('rorkult',),
'rormann': ('rormann',),
'rormannen': ('rormann',),
'rormenn': ('rormann',),
'rormennene': ('rormann',),
'roro': ('roro',),
'roroskip': ('roroskip',),
'roroskipa': ('roroskip',),
'roroskipene': ('roroskip',),
'roroskipet': ('roroskip',),
'rorpinne': ('rorpinne',),
'rorpinnen': ('rorpinne',),
'rorpinnene': ('rorpinne',),
'rorpinner': ('rorpinne',),
'rorskar': ('rorskar',),
'rorskaren': ('rorskar',),
'rorskarene': ('rorskar',),
'rorskarer': ('rorskar',),
'rortørn': ('rortørn',),
'rortørnen': ('rortørn',),
'rortørnene': ('rortørn',),
'rortørner': ('rortørn',),
'ros': ('ros',),
'rosen': ('ros',),
'rosene': ('ros',),
'roser': ('ros',),
'rosévin': ('rosévin',),
'rosévinen': ('rosévin',),
'rosévinene': ('rosévin',),
'roséviner': ('rosévin',),
'rosa': ('rosa',),
'rosa': ('rose',),
'rose': ('rose',),
'rosen': ('rose',),
'rosene': ('rose',),
'roser': ('rose',),
'rosebusk': ('rosebusk',),
'rosebusken': ('rosebusk',),
'rosebuskene': ('rosebusk',),
'rosebusker': ('rosebusk',),
'roseepla': ('roseeple',),
'roseeple': ('roseeple',),
'roseeplene': ('roseeple',),
'roseepler': ('roseeple',),
'roseeplet': ('roseeple',),
'rosefamilie': ('rosefamilie',),
'rosefamilien': ('rosefamilie',),
'rosefamiliene': ('rosefamilie',),
'rosefamilier': ('rosefamilie',),
'roseknopp': ('roseknopp',),
'roseknoppen': ('roseknopp',),
'roseknoppene': ('roseknopp',),
'roseknopper': ('roseknopp',),
'roseknupp': ('roseknupp',),
'roseknuppen': ('roseknupp',),
'roseknuppene': ('roseknupp',),
'roseknupper': ('roseknupp',),
'rosemaler': ('rosemaler',),
'rosemalere': ('rosemaler',),
'rosemaleren': ('rosemaler',),
'rosemalerer': ('rosemaler',),
'rosemalerne': ('rosemaler',),
'rosemaling': ('rosemaling',),
'rosemalinga': ('rosemaling',),
'rosemalingen': ('rosemaling',),
'rosemalingene': ('rosemaling',),
'rosemalinger': ('rosemaling',),
'rosen': ('rosen',),
'rosenen': ('rosen',),
'rosenene': ('rosen',),
'rosener': ('rosen',),
'rosenbusk': ('rosenbusk',),
'rosenbusken': ('rosenbusk',),
'rosenbuskene': ('rosenbusk',),
'rosenbusker': ('rosenbusk',),
'rosenepla': ('roseneple',),
'roseneple': ('roseneple',),
'roseneplene': ('roseneple',),
'rosenepler': ('roseneple',),
'roseneplet': ('roseneple',),
'rosenknopp': ('rosenknopp',),
'rosenknoppen': ('rosenknopp',),
'rosenknoppene': ('rosenknopp',),
'rosenknopper': ('rosenknopp',),
'rosenknupp': ('rosenknupp',),
'rosenknuppen': ('rosenknupp',),
'rosenknuppene': ('rosenknupp',),
'rosenknupper': ('rosenknupp',),
'rosenkrans': ('rosenkrans',),
'rosenkransen': ('rosenkrans',),
'rosenkransene': ('rosenkrans',),
'rosenkranser': ('rosenkrans',),
'rosenkål': ('rosenkål',),
'rosenkålen': ('rosenkål',),
'rosenkålene': ('rosenkål',),
'rosenkåler': ('rosenkål',),
'rosenolja': ('rosenolje',),
'rosenolje': ('rosenolje',),
'rosenoljen': ('rosenolje',),
'rosenoljene': ('rosenolje',),
'rosenoljer': ('rosenolje',),
'rosenrot': ('rosenrot',),
'rosenrota': ('rosenrot',),
'rosenroten': ('rosenrot',),
'rosenrotene': ('rosenrot',),
'rosenstokk': ('rosenstokk',),
'rosenstokken': ('rosenstokk',),
'rosenstokkene': ('rosenstokk',),
'rosenstokker': ('rosenstokk',),
'rosenvann': ('rosenvann',),
'rosenvanna': ('rosenvann',),
'rosenvannene': ('rosenvann',),
'rosenvannet': ('rosenvann',),
'rosenvatn': ('rosenvatn',),
'rosenvatna': ('rosenvatn',),
'rosenvatnene': ('rosenvatn',),
'rosenvatnet': ('rosenvatn',),
'roseolja': ('roseolje',),
'roseolje': ('roseolje',),
'roseoljen': ('roseolje',),
'roseoljene': ('roseolje',),
'roseoljer': ('roseolje',),
'rosestokk': ('rosestokk',),
'rosestokken': ('rosestokk',),
'rosestokkene': ('rosestokk',),
'rosestokker': ('rosestokk',),
'rosett': ('rosett',),
'rosetten': ('rosett',),
'rosettene': ('rosett',),
'rosetter': ('rosett',),
'rosevann': ('rosevann',),
'rosevanna': ('rosevann',),
'rosevannene': ('rosevann',),
'rosevannet': ('rosevann',),
'rosevatn': ('rosevatn',),
'rosevatna': ('rosevatn',),
'rosevatnene': ('rosevatn',),
'rosevatnet': ('rosevatn',),
'rosignal': ('rosignal',),
'rosignala': ('rosignal',),
'rosignalene': ('rosignal',),
'rosignaler': ('rosignal',),
'rosignalet': ('rosignal',),
'rosin': ('rosin',),
'rosina': ('rosin',),
'rosinen': ('rosin',),
'rosinene': ('rosin',),
'rosiner': ('rosin',),
'roskap': ('roskap',),
'roskapa': ('roskap',),
'roskapene': ('roskap',),
'roskapet': ('roskap',),
'rosmarin': ('rosmarin',),
'rosmarinen': ('rosmarin',),
'rosmarinene': ('rosmarin',),
'rosmariner': ('rosmarin',),
'rossa': ('rosse',),
'rosse': ('rosse',),
'rossen': ('rosse',),
'rossene': ('rosse',),
'rosser': ('rosse',),
'rossmål': ('rossmål',),
'rossmålen': ('rossmål',),
'rossmålene': ('rossmål',),
'rossmåler': ('rossmål',),
'roste': ('roste',),
'rosten': ('roste',),
'rostene': ('roste',),
'roster': ('roste',),
'rostekar': ('rostekar',),
'rostekara': ('rostekar',),
'rostekarene': ('rostekar',),
'rostekaret': ('rostekar',),
'rot': ('rot',),
'rota': ('rot',),
'rotene': ('rot',),
'rotet': ('rot',),
'rot': ('rot',),
'rota': ('rot',),
'roten': ('rot',),
'røttene': ('rot',),
'røtter': ('rot',),
'rotang': ('rotang',),
'rotangen': ('rotang',),
'rotangene': ('rotang',),
'rotanger': ('rotang',),
'rotangpalme': ('rotangpalme',),
'rotangpalmen': ('rotangpalme',),
'rotangpalmene': ('rotangpalme',),
'rotangpalmer': ('rotangpalme',),
'rotarianer': ('rotarianer',),
'rotarianere': ('rotarianer',),
'rotarianeren': ('rotarianer',),
'rotarianerer': ('rotarianer',),
'rotarianerne': ('rotarianer',),
'rotaryklubb': ('rotaryklubb',),
'rotaryklubben': ('rotaryklubb',),
'rotaryklubbene': ('rotaryklubb',),
'rotaryklubber': ('rotaryklubb',),
'rotasjon': ('rotasjon',),
'rotasjonen': ('rotasjon',),
'rotasjonene': ('rotasjon',),
'rotasjoner': ('rotasjon',),
'rotasjonspressa': ('rotasjonspresse',),
'rotasjonspresse': ('rotasjonspresse',),
'rotasjonspressen': ('rotasjonspresse',),
'rotasjonspressene': ('rotasjonspresse',),
'rotasjonspresser': ('rotasjonspresse',),
'rotavledning': ('rotavledning',),
'rotavledninga': ('rotavledning',),
'rotavledningen': ('rotavledning',),
'rotavledningene': ('rotavledning',),
'rotavledninger': ('rotavledning',),
'rotavleiing': ('rotavleiing',),
'rotavleiinga': ('rotavleiing',),
'rotavleiingen': ('rotavleiing',),
'rotavleiingene': ('rotavleiing',),
'rotavleiinger': ('rotavleiing',),
'rotbløyta': ('rotbløyte',),
'rotbløyte': ('rotbløyte',),
'rotbløyten': ('rotbløyte',),
'rotbløytene': ('rotbløyte',),
'rotbløyter': ('rotbløyte',),
'rote': ('rote',),
'roten': ('rote',),
'rotene': ('rote',),
'roter': ('rote',),
'rote': ('rote',),
'roten': ('rote',),
'rotene': ('rote',),
'roter': ('rote',),
'roteforstander': ('roteforstander',),
'roteforstandere': ('roteforstander',),
'roteforstanderen': ('roteforstander',),
'roteforstanderer': ('roteforstander',),
'roteforstanderne': ('roteforstander',),
'roteforstander': ('roteforstander',),
'roteforstandere': ('roteforstander',),
'roteforstanderen': ('roteforstander',),
'roteforstanderer': ('roteforstander',),
'roteforstanderne': ('roteforstander',),
'rotehoda': ('rotehode',),
'rotehode': ('rotehode',),
'rotehodene': ('rotehode',),
'rotehoder': ('rotehode',),
'rotehodet': ('rotehode',),
'rotehus': ('rotehus',),
'rotehusa': ('rotehus',),
'rotehusene': ('rotehus',),
'rotehuset': ('rotehus',),
'rotekopp': ('rotekopp',),
'rotekoppen': ('rotekopp',),
'rotekoppene': ('rotekopp',),
'rotekopper': ('rotekopp',),
'rotemester': ('rotemester',),
'rotemestere': ('rotemester',),
'rotemesteren': ('rotemester',),
'rotemesterer': ('rotemester',),
'rotemesterne': ('rotemester',),
'rotemestre': ('rotemester',),
'rotemestrene': ('rotemester',),
'rotemestrer': ('rotemester',),
'rotemester': ('rotemester',),
'rotemestere': ('rotemester',),
'rotemesteren': ('rotemester',),
'rotemesterer': ('rotemester',),
'rotemesterne': ('rotemester',),
'rotemestre': ('rotemester',),
'rotemestrene': ('rotemester',),
'rotemestrer': ('rotemester',),
'rotende': ('rotende',),
'rotenden': ('rotende',),
'rotendene': ('rotende',),
'rotender': ('rotende',),
'rotenon': ('rotenon',),
'rotenona': ('rotenon',),
'rotenonene': ('rotenon',),
'rotenonet': ('rotenon',),
'rotfrukt': ('rotfrukt',),
'rotfrukta': ('rotfrukt',),
'rotfrukten': ('rotfrukt',),
'rotfruktene': ('rotfrukt',),
'rotfrukter': ('rotfrukt',),
'rotfylling': ('rotfylling',),
'rotfyllinga': ('rotfylling',),
'rotfyllingen': ('rotfylling',),
'rotfyllingene': ('rotfylling',),
'rotfyllinger': ('rotfylling',),
'rothogger': ('rothogger',),
'rothoggere': ('rothogger',),
'rothoggeren': ('rothogger',),
'rothoggerer': ('rothogger',),
'rothoggerne': ('rothogger',),
'rothugger': ('rothugger',),
'rothuggere': ('rothugger',),
'rothuggeren': ('rothugger',),
'rothuggerer': ('rothugger',),
'rothuggerne': ('rothugger',),
'rotisseri': ('rotisseri',),
'rotisseria': ('rotisseri',),
'rotisseriene': ('rotisseri',),
'rotisserier': ('rotisseri',),
'rotisseriet': ('rotisseri',),
'rotknoll': ('rotknoll',),
'rotknollen': ('rotknoll',),
'rotknollene': ('rotknoll',),
'rotknoller': ('rotknoll',),
'rotløshet': ('rotløshet',),
'rotløsheta': ('rotløshet',),
'rotløsheten': ('rotløshet',),
'rotløshetene': ('rotløshet',),
'rotløsheter': ('rotløshet',),
'rotløysa': ('rotløyse',),
'rotløyse': ('rotløyse',),
'rotløysen': ('rotløyse',),
'rotløysene': ('rotløyse',),
'rotløyser': ('rotløyse',),
'rotor': ('rotor',),
'rotoren': ('rotor',),
'rotorene': ('rotor',),
'rotorer': ('rotor',),
'rotord': ('rotord',),
'rotorda': ('rotord',),
'rotordene': ('rotord',),
'rotordet': ('rotord',),
'rotskott': ('rotskott',),
'rotskotta': ('rotskott',),
'rotskottene': ('rotskott',),
'rotskottet': ('rotskott',),
'rotskudd': ('rotskudd',),
'rotskudda': ('rotskudd',),
'rotskuddene': ('rotskudd',),
'rotskuddet': ('rotskudd',),
'rotstavelse': ('rotstavelse',),
'rotstavelsen': ('rotstavelse',),
'rotstavelsene': ('rotstavelse',),
'rotstavelser': ('rotstavelse',),
'rotstaving': ('rotstaving',),
'rotstavinga': ('rotstaving',),
'rotstavingen': ('rotstaving',),
'rotstavingene': ('rotstaving',),
'rotstavinger': ('rotstaving',),
'rotstokk': ('rotstokk',),
'rotstokken': ('rotstokk',),
'rotstokkene': ('rotstokk',),
'rotstokker': ('rotstokk',),
'rotta': ('rotte',),
'rotte': ('rotte',),
'rotten': ('rotte',),
'rottene': ('rotte',),
'rotter': ('rotte',),
'rottefella': ('rottefelle',),
'rottefelle': ('rottefelle',),
'rottefellen': ('rottefelle',),
'rottefellene': ('rottefelle',),
'rottefeller': ('rottefelle',),
'rottegift': ('rottegift',),
'rottegifta': ('rottegift',),
'rottegiften': ('rottegift',),
'rottegiftene': ('rottegift',),
'rottegifter': ('rottegift',),
'rottegn': ('rottegn',),
'rottegna': ('rottegn',),
'rottegnene': ('rottegn',),
'rottegnet': ('rottegn',),
'rottehol': ('rottehol',),
'rottehola': ('rottehol',),
'rotteholene': ('rottehol',),
'rotteholet': ('rottehol',),
'rottehull': ('rottehull',),
'rottehulla': ('rottehull',),
'rottehullene': ('rottehull',),
'rottehuller': ('rottehull',),
'rottehullet': ('rottehull',),
'rottekonge': ('rottekonge',),
'rottekongen': ('rottekonge',),
'rottekongene': ('rottekonge',),
'rottekonger': ('rottekonge',),
'rotterumpa': ('rotterumpe',),
'rotterumpe': ('rotterumpe',),
'rotterumpen': ('rotterumpe',),
'rotterumpene': ('rotterumpe',),
'rotterumper': ('rotterumpe',),
'rotting': ('rotting',),
'rottingen': ('rotting',),
'rottingene': ('rotting',),
'rottinger': ('rotting',),
'rottrevl': ('rottrevl',),
'rottrevlen': ('rottrevl',),
'rottrevlene': ('rottrevl',),
'rottrevler': ('rottrevl',),
'rottweiler': ('rottweiler',),
'rottweilere': ('rottweiler',),
'rottweileren': ('rottweiler',),
'rottweilerer': ('rottweiler',),
'rottweilerne': ('rottweiler',),
'rotugras': ('rotugras',),
'rotugrasa': ('rotugras',),
'rotugrasene': ('rotugras',),
'rotugraset': ('rotugras',),
'rotugress': ('rotugress',),
'rotugressa': ('rotugress',),
'rotugressene': ('rotugress',),
'rotugresset': ('rotugress',),
'rotunde': ('rotunde',),
'rotunden': ('rotunde',),
'rotundene': ('rotunde',),
'rotunder': ('rotunde',),
'rotvekst': ('rotvekst',),
'rotveksten': ('rotvekst',),
'rotvekstene': ('rotvekst',),
'rotvekster': ('rotvekst',),
'rotvelsk': ('rotvelsk',),
'rotvelsken': ('rotvelsk',),
'rotvelskene': ('rotvelsk',),
'rotvelsker': ('rotvelsk',),
'rotvelta': ('rotvelte',),
'rotvelte': ('rotvelte',),
'rotvelten': ('rotvelte',),
'rotveltene': ('rotvelte',),
'rotvelter': ('rotvelte',),
'rouge': ('rouge',),
'rougen': ('rouge',),
'rougene': ('rouge',),
'rouger': ('rouge',),
'rov': ('rov',),
'rova': ('rov',),
'rovene': ('rov',),
'rovet': ('rov',),
'rovdrift': ('rovdrift',),
'rovdrifta': ('rovdrift',),
'rovdriften': ('rovdrift',),
'rovdriftene': ('rovdrift',),
'rovdrifter': ('rovdrift',),
'rovdyr': ('rovdyr',),
'rovdyra': ('rovdyr',),
'rovdyrene': ('rovdyr',),
'rovdyret': ('rovdyr',),
'rovdyrinstinkt': ('rovdyrinstinkt',),
'rovdyrinstinkta': ('rovdyrinstinkt',),
'rovdyrinstinktene': ('rovdyrinstinkt',),
'rovdyrinstinkter': ('rovdyrinstinkt',),
'rovdyrinstinktet': ('rovdyrinstinkt',),
'rova': ('rove',),
'rove': ('rove',),
'roven': ('rove',),
'rovene': ('rove',),
'rover': ('rove',),
'rover': ('rover',),
'rovere': ('rover',),
'roveren': ('rover',),
'roverer': ('rover',),
'roverne': ('rover',),
'rover': ('rover',),
'rovera': ('rover',),
'roverene': ('rover',),
'roverer': ('rover',),
'roveret': ('rover',),
'rovfisk': ('rovfisk',),
'rovfisken': ('rovfisk',),
'rovfiskene': ('rovfisk',),
'rovfisker': ('rovfisk',),
'rovfiska': ('rovfiske',),
'rovfiske': ('rovfiske',),
'rovfiskene': ('rovfiske',),
'rovfisker': ('rovfiske',),
'rovfisket': ('rovfiske',),
'rovfugl': ('rovfugl',),
'rovfuglen': ('rovfugl',),
'rovfuglene': ('rovfugl',),
'rovfugler': ('rovfugl',),
'rovjakt': ('rovjakt',),
'rovjakta': ('rovjakt',),
'rovjakten': ('rovjakt',),
'rovjaktene': ('rovjakt',),
'rovjakter': ('rovjakt',),
'rovlyst': ('rovlyst',),
'rovlysta': ('rovlyst',),
'rovlysten': ('rovlyst',),
'rovlystene': ('rovlyst',),
'rovlyster': ('rovlyst',),
'rovmord': ('rovmord',),
'rovmorda': ('rovmord',),
'rovmordene': ('rovmord',),
'rovmordet': ('rovmord',),
'rovmorder': ('rovmorder',),
'rovmordere': ('rovmorder',),
'rovmorderen': ('rovmorder',),
'rovmorderer': ('rovmorder',),
'rovmorderne': ('rovmorder',),
'rovtann': ('rovtann',),
'rovtanna': ('rovtann',),
'rovtannen': ('rovtann',),
'rovtennene': ('rovtann',),
'rovtenner': ('rovtann',),
'royalties': ('royalty',),
'royalty': ('royalty',),
'royaltyen': ('royalty',),
'royaltyene': ('royalty',),
'royaltyer': ('royalty',),
'rubank': ('rubank',),
'rubanken': ('rubank',),
'rubankene': ('rubank',),
'rubanker': ('rubank',),
'rubato': ('rubato',),
'rubatoa': ('rubato',),
'rubatoene': ('rubato',),
'rubatoer': ('rubato',),
'rubatoet': ('rubato',),
'rubb': ('rubb',),
'rubbel': ('rubbel',),
'rubel': ('rubel',),
'rubelen': ('rubel',),
'rublene': ('rubel',),
'rubler': ('rubel',),
'rubidium': ('rubidium',),
'rubidiuma': ('rubidium',),
'rubidiumene': ('rubidium',),
'rubidiumet': ('rubidium',),
'rubin': ('rubin',),
'rubinen': ('rubin',),
'rubinene': ('rubin',),
'rubiner': ('rubin',),
'rubladfamilie': ('rubladfamilie',),
'rubladfamilien': ('rubladfamilie',),
'rubladfamiliene': ('rubladfamilie',),
'rubladfamilier': ('rubladfamilie',),
'rubrikk': ('rubrikk',),
'rubrikken': ('rubrikk',),
'rubrikkene': ('rubrikk',),
'rubrikker': ('rubrikk',),
'rubrikkannonsa': ('rubrikkannonse',),
'rubrikkannonse': ('rubrikkannonse',),
'rubrikkannonsen': ('rubrikkannonse',),
'rubrikkannonsene': ('rubrikkannonse',),
'rubrikkannonser': ('rubrikkannonse',),
'ruderatplanta': ('ruderatplante',),
'ruderatplante': ('ruderatplante',),
'ruderatplanten': ('ruderatplante',),
'ruderatplantene': ('ruderatplante',),
'ruderatplanter': ('ruderatplante',),
'rudiment': ('rudiment',),
'rudimenta': ('rudiment',),
'rudimentene': ('rudiment',),
'rudimenter': ('rudiment',),
'rudimentet': ('rudiment',),
'rudkall': ('rudkall',),
'rudkallen': ('rudkall',),
'rudkallene': ('rudkall',),
'rudkaller': ('rudkall',),
'ruelse': ('ruelse',),
'ruelsen': ('ruelse',),
'ruelsene': ('ruelse',),
'ruelser': ('ruelse',),
'ruffer': ('ruffer',),
'ruffere': ('ruffer',),
'rufferen': ('ruffer',),
'rufferer': ('ruffer',),
'rufferne': ('ruffer',),
'rufferi': ('rufferi',),
'rufferia': ('rufferi',),
'rufferiene': ('rufferi',),
'rufferier': ('rufferi',),
'rufferiet': ('rufferi',),
'rufferska': ('rufferske',),
'rufferske': ('rufferske',),
'ruffersken': ('rufferske',),
'rufferskene': ('rufferske',),
'ruffersker': ('rufferske',),
'rufs': ('rufs',),
'rufsen': ('rufs',),
'rufsene': ('rufs',),
'rufser': ('rufs',),
'rug': ('rug',),
'rugen': ('rug',),
'rugene': ('rug',),
'ruger': ('rug',),
'rugbrød': ('rugbrød',),
'rugbrøda': ('rugbrød',),
'rugbrødene': ('rugbrød',),
'rugbrødet': ('rugbrød',),
'rugby': ('rugby',),
'rugbyen': ('rugby',),
'rugbyene': ('rugby',),
'rugbyer': ('rugby',),
'rugda': ('rugde',),
'rugde': ('rugde',),
'rugden': ('rugde',),
'rugdene': ('rugde',),
'rugder': ('rugde',),
'rugdetrekk': ('rugdetrekk',),
'rugdetrekka': ('rugdetrekk',),
'rugdetrekkene': ('rugdetrekk',),
'rugdetrekket': ('rugdetrekk',),
'rugehøna': ('rugehøne',),
'rugehøne': ('rugehøne',),
'rugehønen': ('rugehøne',),
'rugehønene': ('rugehøne',),
'rugehøner': ('rugehøne',),
'rugekassa': ('rugekasse',),
'rugekasse': ('rugekasse',),
'rugekassen': ('rugekasse',),
'rugekassene': ('rugekasse',),
'rugekasser': ('rugekasse',),
'rugemaskin': ('rugemaskin',),
'rugemaskina': ('rugemaskin',),
'rugemaskinen': ('rugemaskin',),
'rugemaskinene': ('rugemaskin',),
'rugemaskiner': ('rugemaskin',),
'rugeplass': ('rugeplass',),
'rugeplassen': ('rugeplass',),
'rugeplassene': ('rugeplass',),
'rugeplasser': ('rugeplass',),
'rugg': ('rugg',),
'ruggen': ('rugg',),
'ruggene': ('rugg',),
'rugger': ('rugg',),
'rugga': ('rugge',),
'rugge': ('rugge',),
'ruggen': ('rugge',),
'ruggene': ('rugge',),
'rugger': ('rugge',),
'ruggestol': ('ruggestol',),
'ruggestolen': ('ruggestol',),
'ruggestolene': ('ruggestol',),
'ruggestoler': ('ruggestol',),
'rugla': ('rugle',),
'rugle': ('rugle',),
'ruglen': ('rugle',),
'ruglene': ('rugle',),
'rugler': ('rugle',),
'ruin': ('ruin',),
'ruinen': ('ruin',),
'ruinene': ('ruin',),
'ruiner': ('ruin',),
'ruinhaug': ('ruinhaug',),
'ruinhaugen': ('ruinhaug',),
'ruinhaugene': ('ruinhaug',),
'ruinhauger': ('ruinhaug',),
'rujern': ('rujern',),
'rujerna': ('rujern',),
'rujernene': ('rujern',),
'rujernet': ('rujern',),
'ruka': ('ruke',),
'ruke': ('ruke',),
'ruken': ('ruke',),
'rukene': ('ruke',),
'ruker': ('ruke',),
'rukka': ('rukke',),
'rukke': ('rukke',),
'rukken': ('rukke',),
'rukkene': ('rukke',),
'rukker': ('rukke',),
'rukkel': ('rukkel',),
'rukkelet': ('rukkel',),
'rukla': ('rukkel',),
'ruklene': ('rukkel',),
'ruklet': ('rukkel',),
'rukl': ('rukl',),
'rukla': ('rukl',),
'ruklene': ('rukl',),
'ruklet': ('rukl',),
'rulade': ('rulade',),
'ruladen': ('rulade',),
'ruladene': ('rulade',),
'rulader': ('rulade',),
'rulett': ('rulett',),
'ruletten': ('rulett',),
'rulettene': ('rulett',),
'ruletter': ('rulett',),
'rull': ('rull',),
'rullen': ('rull',),
'rullene': ('rull',),
'ruller': ('rull',),
'rull': ('rull',),
'rullen': ('rull',),
'rullene': ('rull',),
'ruller': ('rull',),
'rulle': ('rulle',),
'rullen': ('rulle',),
'rullene': ('rulle',),
'ruller': ('rulle',),
'rulla': ('rulle',),
'rulle': ('rulle',),
'rullen': ('rulle',),
'rullene': ('rulle',),
'ruller': ('rulle',),
'rullebane': ('rullebane',),
'rullebanen': ('rullebane',),
'rullebanene': ('rullebane',),
'rullebaner': ('rullebane',),
'rulleblad': ('rulleblad',),
'rulleblada': ('rulleblad',),
'rullebladene': ('rulleblad',),
'rulleblader': ('rulleblad',),
'rullebladet': ('rulleblad',),
'rullebrett': ('rullebrett',),
'rullebretta': ('rullebrett',),
'rullebrettene': ('rullebrett',),
'rullebretter': ('rullebrett',),
'rullebrettet': ('rullebrett',),
'rullefører': ('rullefører',),
'rulleførere': ('rullefører',),
'rulleføreren': ('rullefører',),
'rulleførerer': ('rullefører',),
'rulleførerne': ('rullefører',),
'rullegardin': ('rullegardin',),
'rullegardina': ('rullegardin',),
'rullegardinen': ('rullegardin',),
'rullegardinene': ('rullegardin',),
'rullegardiner': ('rullegardin',),
'rullegardinet': ('rullegardin',),
'rullekaka': ('rullekake',),
'rullekake': ('rullekake',),
'rullekaken': ('rullekake',),
'rullekakene': ('rullekake',),
'rullekaker': ('rullekake',),
'rulleski': ('rulleski',),
'rulleskia': ('rulleski',),
'rulleskien': ('rulleski',),
'rulleskiene': ('rulleski',),
'rulleskier': ('rulleski',),
'rulleskøyta': ('rulleskøyte',),
'rulleskøyte': ('rulleskøyte',),
'rulleskøyten': ('rulleskøyte',),
'rulleskøytene': ('rulleskøyte',),
'rulleskøyter': ('rulleskøyte',),
'rullestein': ('rullestein',),
'rullesteinen': ('rullestein',),
'rullesteinene': ('rullestein',),
'rullesteiner': ('rullestein',),
'rullestol': ('rullestol',),
'rullestolen': ('rullestol',),
'rullestolene': ('rullestol',),
'rullestoler': ('rullestol',),
'rulletrapp': ('rulletrapp',),
'rulletrappa': ('rulletrapp',),
'rulletrappen': ('rulletrapp',),
'rulletrappene': ('rulletrapp',),
'rulletrapper': ('rulletrapp',),
'rullings': ('rullings',),
'rullingsen': ('rullings',),
'rullingsene': ('rullings',),
'rullingser': ('rullings',),
'rult': ('rult',),
'rulten': ('rult',),
'rultene': ('rult',),
'rulter': ('rult',),
'rulta': ('rulte',),
'rulte': ('rulte',),
'rulten': ('rulte',),
'rultene': ('rulte',),
'rulter': ('rulte',),
'rumba': ('rumba',),
'rumbaen': ('rumba',),
'rumbaene': ('rumba',),
'rumbaer': ('rumba',),
'rumener': ('rumener',),
'rumenere': ('rumener',),
'rumeneren': ('rumener',),
'rumenerer': ('rumener',),
'rumenerne': ('rumener',),
'rumla': ('rummel',),
'rumlene': ('rummel',),
'rumler': ('rummel',),
'rumlet': ('rummel',),
'rummel': ('rummel',),
'rummelen': ('rummel',),
'rummelet': ('rummel',),
'rumpa': ('rumpe',),
'rumpe': ('rumpe',),
'rumpen': ('rumpe',),
'rumpene': ('rumpe',),
'rumper': ('rumpe',),
'rumpetaska': ('rumpetaske',),
'rumpetaske': ('rumpetaske',),
'rumpetasken': ('rumpetaske',),
'rumpetaskene': ('rumpetaske',),
'rumpetasker': ('rumpetaske',),
'rumpetroll': ('rumpetroll',),
'rumpetrolla': ('rumpetroll',),
'rumpetrollene': ('rumpetroll',),
'rumpetrollet': ('rumpetroll',),
'run': ('run',),
'runa': ('run',),
'runene': ('run',),
'runet': ('run',),
'rundboge': ('rundboge',),
'rundbogen': ('rundboge',),
'rundbogene': ('rundboge',),
'rundboger': ('rundboge',),
'rundbogestil': ('rundbogestil',),
'rundbogestilen': ('rundbogestil',),
'rundbogestilene': ('rundbogestil',),
'rundbogestiler': ('rundbogestil',),
'rundbrenner': ('rundbrenner',),
'rundbrennere': ('rundbrenner',),
'rundbrenneren': ('rundbrenner',),
'rundbrennerer': ('rundbrenner',),
'rundbrennerne': ('rundbrenner',),
'rundbue': ('rundbue',),
'rundbuen': ('rundbue',),
'rundbuene': ('rundbue',),
'rundbuer': ('rundbue',),
'rundbuestil': ('rundbuestil',),
'rundbuestilen': ('rundbuestil',),
'rundbuestilene': ('rundbuestil',),
'rundbuestiler': ('rundbuestil',),
'runddans': ('runddans',),
'runddansen': ('runddans',),
'runddansene': ('runddans',),
'runddanser': ('runddans',),
'runde': ('runde',),
'runden': ('runde',),
'rundene': ('runde',),
'runder': ('runde',),
'rundebordskonferanse': ('rundebordskonferanse',),
'rundebordskonferansen': ('rundebordskonferanse',),
'rundebordskonferansene': ('rundebordskonferanse',),
'rundebordskonferanser': ('rundebordskonferanse',),
'rundeskjema': ('rundeskjema',),
'rundeskjemaene': ('rundeskjema',),
'rundeskjemaer': ('rundeskjema',),
'rundeskjemaet': ('rundeskjema',),
'rundetid': ('rundetid',),
'rundetida': ('rundetid',),
'rundetiden': ('rundetid',),
'rundetidene': ('rundetid',),
'rundetider': ('rundetid',),
'rundfisk': ('rundfisk',),
'rundfisken': ('rundfisk',),
'rundfiskene': ('rundfisk',),
'rundfisker': ('rundfisk',),
'rundgang': ('rundgang',),
'rundgangen': ('rundgang',),
'rundgangene': ('rundgang',),
'rundganger': ('rundgang',),
'rundholt': ('rundholt',),
'rundholta': ('rundholt',),
'rundholten': ('rundholt',),
'rundholtene': ('rundholt',),
'rundholter': ('rundholt',),
'rundholtet': ('rundholt',),
'runding': ('runding',),
'rundingen': ('runding',),
'rundingene': ('runding',),
'rundinger': ('runding',),
'rundjern': ('rundjern',),
'rundjerna': ('rundjern',),
'rundjernene': ('rundjern',),
'rundjernet': ('rundjern',),
'rundjuling': ('rundjuling',),
'rundjulinga': ('rundjuling',),
'rundjulingen': ('rundjuling',),
'rundjulingene': ('rundjuling',),
'rundjulinger': ('rundjuling',),
'rundkast': ('rundkast',),
'rundkasta': ('rundkast',),
'rundkastene': ('rundkast',),
'rundkastet': ('rundkast',),
'rundkirka': ('rundkirke',),
'rundkirke': ('rundkirke',),
'rundkirken': ('rundkirke',),
'rundkirkene': ('rundkirke',),
'rundkirker': ('rundkirke',),
'rundkjerka': ('rundkjerke',),
'rundkjerke': ('rundkjerke',),
'rundkjerken': ('rundkjerke',),
'rundkjerkene': ('rundkjerke',),
'rundkjerker': ('rundkjerke',),
'rundkjøring': ('rundkjøring',),
'rundkjøringa': ('rundkjøring',),
'rundkjøringen': ('rundkjøring',),
'rundkjøringene': ('rundkjøring',),
'rundkjøringer': ('rundkjøring',),
'rundlast': ('rundlast',),
'rundlasta': ('rundlast',),
'rundlasten': ('rundlast',),
'rundlastene': ('rundlast',),
'rundlaster': ('rundlast',),
'rundmunn': ('rundmunn',),
'rundmunnen': ('rundmunn',),
'rundmunnene': ('rundmunn',),
'rundmunner': ('rundmunn',),
'rundorm': ('rundorm',),
'rundormen': ('rundorm',),
'rundormene': ('rundorm',),
'rundormer': ('rundorm',),
'rundpinne': ('rundpinne',),
'rundpinnen': ('rundpinne',),
'rundpinnene': ('rundpinne',),
'rundpinner': ('rundpinne',),
'rundreisa': ('rundreise',),
'rundreise': ('rundreise',),
'rundreisen': ('rundreise',),
'rundreisene': ('rundreise',),
'rundreiser': ('rundreise',),
'rundskriv': ('rundskriv',),
'rundskriva': ('rundskriv',),
'rundskrivene': ('rundskriv',),
'rundskrivet': ('rundskriv',),
'rundskua': ('rundskue',),
'rundskue': ('rundskue',),
'rundskuene': ('rundskue',),
'rundskuer': ('rundskue',),
'rundskuet': ('rundskue',),
'rundspørring': ('rundspørring',),
'rundspørringa': ('rundspørring',),
'rundspørringen': ('rundspørring',),
'rundspørringene': ('rundspørring',),
'rundspørringer': ('rundspørring',),
'rundstokk': ('rundstokk',),
'rundstokken': ('rundstokk',),
'rundstokkene': ('rundstokk',),
'rundstokker': ('rundstokk',),
'rundstykka': ('rundstykke',),
'rundstykke': ('rundstykke',),
'rundstykkene': ('rundstykke',),
'rundstykker': ('rundstykke',),
'rundstykket': ('rundstykke',),
'rundtur': ('rundtur',),
'rundturen': ('rundtur',),
'rundturene': ('rundtur',),
'rundturer': ('rundtur',),
'rundtørn': ('rundtørn',),
'rundtørna': ('rundtørn',),
'rundtørnene': ('rundtørn',),
'rundtørnet': ('rundtørn',),
'rundvask': ('rundvask',),
'rundvasken': ('rundvask',),
'rundvaskene': ('rundvask',),
'rundvasker': ('rundvask',),
'rune': ('rune',),
'runen': ('rune',),
'runene': ('rune',),
'runer': ('rune',),
'runa': ('rune',),
'rune': ('rune',),
'runen': ('rune',),
'runene': ('rune',),
'runer': ('rune',),
'runebomma': ('runebomme',),
'runebomme': ('runebomme',),
'runebommen': ('runebomme',),
'runebommene': ('runebomme',),
'runebommer': ('runebomme',),
'runeinnskrift': ('runeinnskrift',),
'runeinnskrifta': ('runeinnskrift',),
'runeinnskriften': ('runeinnskrift',),
'runeinnskriftene': ('runeinnskrift',),
'runeinnskrifter': ('runeinnskrift',),
'runekall': ('runekall',),
'runekallen': ('runekall',),
'runekallene': ('runekall',),
'runekaller': ('runekall',),
'runerekka': ('runerekke',),
'runerekke': ('runerekke',),
'runerekken': ('runerekke',),
'runerekkene': ('runerekke',),
'runerekker': ('runerekke',),
'runestav': ('runestav',),
'runestaven': ('runestav',),
'runestavene': ('runestav',),
'runestaver': ('runestav',),
'runestein': ('runestein',),
'runesteinen': ('runestein',),
'runesteinene': ('runestein',),
'runesteiner': ('runestein',),
'runetegn': ('runetegn',),
'runetegna': ('runetegn',),
'runetegnene': ('runetegn',),
'runetegnet': ('runetegn',),
'runn': ('runn',),
'runnen': ('runn',),
'runnene': ('runn',),
'runner': ('runn',),
'runne': ('runne',),
'runnen': ('runne',),
'runnene': ('runne',),
'runner': ('runne',),
'runner': ('runner',),
'runnere': ('runner',),
'runneren': ('runner',),
'runnerer': ('runner',),
'runnerne': ('runner',),
'runner up': ('runner up',),
'runolog': ('runolog',),
'runologen': ('runolog',),
'runologene': ('runolog',),
'runologer': ('runolog',),
'runologi': ('runologi',),
'runologien': ('runologi',),
'runologiene': ('runologi',),
'runologier': ('runologi',),
'runway': ('runway',),
'runwayen': ('runway',),
'runwayene': ('runway',),
'runwayer': ('runway',),
'runways': ('runway',),
'rupanel': ('rupanel',),
'rupanela': ('rupanel',),
'rupanelene': ('rupanel',),
'rupaneler': ('rupanel',),
'rupanelet': ('rupanel',),
'rupi': ('rupi',),
'rupien': ('rupi',),
'rupiene': ('rupi',),
'rupier': ('rupi',),
'ruptur': ('ruptur',),
'rupturen': ('ruptur',),
'rupturene': ('ruptur',),
'rupturer': ('ruptur',),
'rur': ('rur',),
'ruren': ('rur',),
'rurene': ('rur',),
'rurer': ('rur',),
'rus': ('rus',),
'rusa': ('rus',),
'rusen': ('rus',),
'rusene': ('rus',),
'ruser': ('rus',),
'ruset': ('rus',),
'rusdrikk': ('rusdrikk',),
'rusdrikken': ('rusdrikk',),
'rusdrikkene': ('rusdrikk',),
'rusdrikker': ('rusdrikk',),
'rusa': ('ruse',),
'ruse': ('ruse',),
'rusen': ('ruse',),
'rusene': ('ruse',),
'ruser': ('ruse',),
'rusgift': ('rusgift',),
'rusgifta': ('rusgift',),
'rusgiften': ('rusgift',),
'rusgiftene': ('rusgift',),
'rusgifter': ('rusgift',),
'rush': ('rush',),
'rusha': ('rush',),
'rushene': ('rush',),
'rushet': ('rush',),
'rushtid': ('rushtid',),
'rushtida': ('rushtid',),
'rushtiden': ('rushtid',),
'rushtidene': ('rushtid',),
'rushtider': ('rushtid',),
'rusk': ('rusk',),
'rusken': ('rusk',),
'ruskene': ('rusk',),
'rusker': ('rusk',),
'rusk': ('rusk',),
'ruska': ('rusk',),
'ruskene': ('rusk',),
'rusket': ('rusk',),
'rusk': ('rusk',),
'ruska': ('rusk',),
'ruskene': ('rusk',),
'rusket': ('rusk',),
'ruskevær': ('ruskevær',),
'ruskeværa': ('ruskevær',),
'ruskeværene': ('ruskevær',),
'ruskeværet': ('ruskevær',),
'ruskevær': ('ruskevær',),
'ruskeværa': ('ruskevær',),
'ruskeværene': ('ruskevær',),
'ruskeværet': ('ruskevær',),
'ruskomsnusk': ('ruskomsnusk',),
'ruskomsnuska': ('ruskomsnusk',),
'ruskomsnuskene': ('ruskomsnusk',),
'ruskomsnusket': ('ruskomsnusk',),
'rusmiddel': ('rusmiddel',),
'rusmiddelet': ('rusmiddel',),
'rusmidla': ('rusmiddel',),
'rusmidlene': ('rusmiddel',),
'rusmidler': ('rusmiddel',),
'rusmidlet': ('rusmiddel',),
'russ': ('russ',),
'russen': ('russ',),
'russene': ('russ',),
'russer': ('russ',),
'russ': ('russ',),
'russen': ('russ',),
'russene': ('russ',),
'russehandel': ('russehandel',),
'russehandelen': ('russehandel',),
'russehandlene': ('russehandel',),
'russehandler': ('russehandel',),
'russelua': ('russelue',),
'russelue': ('russelue',),
'russeluen': ('russelue',),
'russeluene': ('russelue',),
'russeluer': ('russelue',),
'russenorsk': ('russenorsk',),
'russenorsken': ('russenorsk',),
'russenorskene': ('russenorsk',),
'russenorsker': ('russenorsk',),
'russer': ('russer',),
'russere': ('russer',),
'russeren': ('russer',),
'russerer': ('russer',),
'russerne': ('russer',),
'russestyra': ('russestyre',),
'russestyre': ('russestyre',),
'russestyrene': ('russestyre',),
'russestyrer': ('russestyre',),
'russestyret': ('russestyre',),
'russetale': ('russetale',),
'russetalen': ('russetale',),
'russetalene': ('russetale',),
'russetaler': ('russetale',),
'russetid': ('russetid',),
'russetida': ('russetid',),
'russetiden': ('russetid',),
'russetidene': ('russetid',),
'russetider': ('russetid',),
'russetog': ('russetog',),
'russetoga': ('russetog',),
'russetogene': ('russetog',),
'russetoget': ('russetog',),
'russisk': ('russisk',),
'russisken': ('russisk',),
'russiskene': ('russisk',),
'russisker': ('russisk',),
'russlær': ('russlær',),
'russlæra': ('russlær',),
'russlærene': ('russlær',),
'russlæret': ('russlær',),
'rustand': ('rustand',),
'rustanda': ('rustand',),
'rustanden': ('rustand',),
'rustendene': ('rustand',),
'rustender': ('rustand',),
'rusting': ('rusting',),
'rustinga': ('rusting',),
'rustingen': ('rusting',),
'rustingene': ('rusting',),
'rustinger': ('rusting',),
'rustingsindustri': ('rustingsindustri',),
'rustingsindustrien': ('rustingsindustri',),
'rustingsindustriene': ('rustingsindustri',),
'rustingsindustrier': ('rustingsindustri',),
'rustingskappløp': ('rustingskappløp',),
'rustingskappløpa': ('rustingskappløp',),
'rustingskappløpene': ('rustingskappløp',),
'rustingskappløpet': ('rustingskappløp',),
'rustkammer': ('rustkammer',),
'rustkammeret': ('rustkammer',),
'rustkamra': ('rustkammer',),
'rustkamre': ('rustkammer',),
'rustkamrene': ('rustkammer',),
'rustningsindustri': ('rustningsindustri',),
'rustningsindustrien': ('rustningsindustri',),
'rustningsindustriene': ('rustningsindustri',),
'rustningsindustrier': ('rustningsindustri',),
'rustningskappløp': ('rustningskappløp',),
'rustningskappløpa': ('rustningskappløp',),
'rustningskappløpene': ('rustningskappløp',),
'rustningskappløpet': ('rustningskappløp',),
'rustsopp': ('rustsopp',),
'rustsoppen': ('rustsopp',),
'rustsoppene': ('rustsopp',),
'rustsopper': ('rustsopp',),
'ruta': ('rute',),
'rute': ('rute',),
'ruten': ('rute',),
'rutene': ('rute',),
'ruter': ('rute',),
'ruta': ('rute',),
'rute': ('rute',),
'ruten': ('rute',),
'rutene': ('rute',),
'ruter': ('rute',),
'rutebil': ('rutebil',),
'rutebilen': ('rutebil',),
'rutebilene': ('rutebil',),
'rutebiler': ('rutebil',),
'rutebuss': ('rutebuss',),
'rutebussen': ('rutebuss',),
'rutebussene': ('rutebuss',),
'rutebusser': ('rutebuss',),
'rutebåt': ('rutebåt',),
'rutebåten': ('rutebåt',),
'rutebåtene': ('rutebåt',),
'rutebåter': ('rutebåt',),
'rutefly': ('rutefly',),
'ruteflya': ('rutefly',),
'ruteflyene': ('rutefly',),
'ruteflyet': ('rutefly',),
'ruteknuser': ('ruteknuser',),
'ruteknusere': ('ruteknuser',),
'ruteknuseren': ('ruteknuser',),
'ruteknuserer': ('ruteknuser',),
'ruteknuserne': ('ruteknuser',),
'rutelilja': ('rutelilje',),
'rutelilje': ('rutelilje',),
'ruteliljen': ('rutelilje',),
'ruteliljene': ('rutelilje',),
'ruteliljer': ('rutelilje',),
'rutenett': ('rutenett',),
'rutenetta': ('rutenett',),
'rutenettene': ('rutenett',),
'rutenettet': ('rutenett',),
'rutepapir': ('rutepapir',),
'rutepapira': ('rutepapir',),
'rutepapirene': ('rutepapir',),
'rutepapirer': ('rutepapir',),
'rutepapiret': ('rutepapir',),
'ruter': ('ruter',),
'rutere': ('ruter',),
'ruteren': ('ruter',),
'ruterer': ('ruter',),
'ruterne': ('ruter',),
'ruthenium': ('ruthenium',),
'rutheniuma': ('ruthenium',),
'rutheniumene': ('ruthenium',),
'rutheniumet': ('ruthenium',),
'rutine': ('rutine',),
'rutinen': ('rutine',),
'rutinene': ('rutine',),
'rutiner': ('rutine',),
'rutinearbeid': ('rutinearbeid',),
'rutinearbeida': ('rutinearbeid',),
'rutinearbeidene': ('rutinearbeid',),
'rutinearbeider': ('rutinearbeid',),
'rutinearbeidet': ('rutinearbeid',),
'rutsjebane': ('rutsjebane',),
'rutsjebanen': ('rutsjebane',),
'rutsjebanene': ('rutsjebane',),
'rutsjebaner': ('rutsjebane',),
'ruva': ('ruve',),
'ruve': ('ruve',),
'ruven': ('ruve',),
'ruvene': ('ruve',),
'ruver': ('ruve',),
'rwander': ('rwander',),
'rwandere': ('rwander',),
'rwanderen': ('rwander',),
'rwanderer': ('rwander',),
'rwanderne': ('rwander',),
'ry': ('ry',),
'rya': ('ry',),
'ryene': ('ry',),
'ryet': ('ry',),
'rybs': ('rybs',),
'rybsen': ('rybs',),
'rybsene': ('rybs',),
'rybser': ('rybs',),
'rydning': ('rydning',),
'rydninga': ('rydning',),
'rydningen': ('rydning',),
'rydningene': ('rydning',),
'rydninger': ('rydning',),
'rydningsmann': ('rydningsmann',),
'rydningsmannen': ('rydningsmann',),
'rydningsmenn': ('rydningsmann',),
'rydningsmennene': ('rydningsmann',),
'rya': ('rye',),
'rye': ('rye',),
'ryen': ('rye',),
'ryene': ('rye',),
'ryer': ('rye',),
'rygene': ('ryger',),
'ryger': ('ryger',),
'rygg': ('rygg',),
'ryggen': ('rygg',),
'ryggene': ('rygg',),
'rygger': ('rygg',),
'ryggdekning': ('ryggdekning',),
'ryggdekninga': ('ryggdekning',),
'ryggdekningen': ('ryggdekning',),
'ryggdekningene': ('ryggdekning',),
'ryggdekninger': ('ryggdekning',),
'rygglena': ('rygglene',),
'rygglene': ('rygglene',),
'rygglenene': ('rygglene',),
'rygglener': ('rygglene',),
'rygglenet': ('rygglene',),
'ryggmarg': ('ryggmarg',),
'ryggmargen': ('ryggmarg',),
'ryggmargene': ('ryggmarg',),
'ryggmarger': ('ryggmarg',),
'ryggrad': ('ryggrad',),
'ryggrada': ('ryggrad',),
'ryggraden': ('ryggrad',),
'ryggradene': ('ryggrad',),
'ryggrader': ('ryggrad',),
'ryggsekk': ('ryggsekk',),
'ryggsekken': ('ryggsekk',),
'ryggsekkene': ('ryggsekk',),
'ryggsekker': ('ryggsekk',),
'ryggstø': ('ryggstø',),
'ryggstøa': ('ryggstø',),
'ryggstøene': ('ryggstø',),
'ryggstøet': ('ryggstø',),
'ryggsøyla': ('ryggsøyle',),
'ryggsøyle': ('ryggsøyle',),
'ryggsøylen': ('ryggsøyle',),
'ryggsøylene': ('ryggsøyle',),
'ryggsøyler': ('ryggsøyle',),
'ryggtak': ('ryggtak',),
'ryggtaka': ('ryggtak',),
'ryggtakene': ('ryggtak',),
'ryggtaket': ('ryggtak',),
'ryggtavla': ('ryggtavle',),
'ryggtavle': ('ryggtavle',),
'ryggtavlen': ('ryggtavle',),
'ryggtavlene': ('ryggtavle',),
'ryggtavler': ('ryggtavle',),
'rykk': ('rykk',),
'rykka': ('rykk',),
'rykken': ('rykk',),
'rykkene': ('rykk',),
'rykket': ('rykk',),
'rykker': ('rykker',),
'rykkere': ('rykker',),
'rykkeren': ('rykker',),
'rykkerer': ('rykker',),
'rykkerne': ('rykker',),
'rykkerbrev': ('rykkerbrev',),
'rykkerbreva': ('rykkerbrev',),
'rykkerbrevene': ('rykkerbrev',),
'rykkerbrever': ('rykkerbrev',),
'rykkerbrevet': ('rykkerbrev',),
'rykning': ('rykning',),
'rykninga': ('rykning',),
'rykningen': ('rykning',),
'rykningene': ('rykning',),
'rykninger': ('rykning',),
'rykta': ('rykte',),
'rykte': ('rykte',),
'ryktene': ('rykte',),
'rykter': ('rykte',),
'ryktet': ('rykte',),
'ryktemaker': ('ryktemaker',),
'ryktemakere': ('ryktemaker',),
'ryktemakeren': ('ryktemaker',),
'ryktemakerer': ('ryktemaker',),
'ryktemakerne': ('ryktemaker',),
'ryktesmed': ('ryktesmed',),
'ryktesmeden': ('ryktesmed',),
'ryktesmedene': ('ryktesmed',),
'ryktesmeder': ('ryktesmed',),
'ryllik': ('ryllik',),
'rylliken': ('ryllik',),
'ryllikene': ('ryllik',),
'rylliker': ('ryllik',),
'ryllik': ('ryllik',),
'rylliken': ('ryllik',),
'ryllikene': ('ryllik',),
'rylliker': ('ryllik',),
'rynka': ('rynke',),
'rynke': ('rynke',),
'rynken': ('rynke',),
'rynkene': ('rynke',),
'rynker': ('rynke',),
'rypa': ('rype',),
'rype': ('rype',),
'rypen': ('rype',),
'rypene': ('rype',),
'ryper': ('rype',),
'rypebær': ('rypebær',),
'rypebæra': ('rypebær',),
'rypebærene': ('rypebær',),
'rypebæret': ('rypebær',),
'rypefangst': ('rypefangst',),
'rypefangsten': ('rypefangst',),
'rypefangstene': ('rypefangst',),
'rypefangster': ('rypefangst',),
'rypekull': ('rypekull',),
'rypekulla': ('rypekull',),
'rypekullene': ('rypekull',),
'rypekullet': ('rypekull',),
'rypesekk': ('rypesekk',),
'rypesekken': ('rypesekk',),
'rypesekkene': ('rypesekk',),
'rypesekker': ('rypesekk',),
'rypestegg': ('rypestegg',),
'rypesteggen': ('rypestegg',),
'rypesteggene': ('rypestegg',),
'rypestegger': ('rypestegg',),
'rysj': ('rysj',),
'rysjen': ('rysj',),
'rysjene': ('rysj',),
'rysjer': ('rysj',),
'rystelse': ('rystelse',),
'rystelsen': ('rystelse',),
'rystelsene': ('rystelse',),
'rystelser': ('rystelse',),
'rytme': ('rytme',),
'rytmen': ('rytme',),
'rytmene': ('rytme',),
'rytmer': ('rytme',),
'rytmesans': ('rytmesans',),
'rytmesansen': ('rytmesans',),
'rytmesansene': ('rytmesans',),
'rytmesanser': ('rytmesans',),
'rytmikk': ('rytmikk',),
'rytmikken': ('rytmikk',),
'rytmikkene': ('rytmikk',),
'rytmikker': ('rytmikk',),
'rytter': ('rytter',),
'ryttere': ('rytter',),
'rytteren': ('rytter',),
'rytterer': ('rytter',),
'rytterne': ('rytter',),
'rytteri': ('rytteri',),
'rytteria': ('rytteri',),
'rytteriene': ('rytteri',),
'rytterier': ('rytteri',),
'rytteriet': ('rytteri',),
'rytterska': ('rytterske',),
'rytterske': ('rytterske',),
'ryttersken': ('rytterske',),
'rytterskene': ('rytterske',),
'ryttersker': ('rytterske',),
'rytterstatue': ('rytterstatue',),
'rytterstatuen': ('rytterstatue',),
'rytterstatuene': ('rytterstatue',),
'rytterstatuer': ('rytterstatue',),
'rå': ('rå',),
'råen': ('rå',),
'råene': ('rå',),
'råer': ('rå',),
'råband': ('råband',),
'råbanda': ('råband',),
'råbandene': ('råband',),
'råbandet': ('råband',),
'råbandsknute': ('råbandsknute',),
'råbandsknuten': ('råbandsknute',),
'råbandsknutene': ('råbandsknute',),
'råbandsknuter': ('råbandsknute',),
'råbukk': ('råbukk',),
'råbukken': ('råbukk',),
'råbukkene': ('råbukk',),
'råbukker': ('råbukk',),
'råbygg': ('råbygg',),
'råbygga': ('råbygg',),
'råbyggene': ('råbygg',),
'råbygget': ('råbygg',),
'råd': ('råd',),
'råden': ('råd',),
'rådene': ('råd',),
'råder': ('råd',),
'råd': ('råd',),
'råda': ('råd',),
'rådene': ('råd',),
'rådet': ('råd',),
'rådata': ('rådata',),
'rådataen': ('rådata',),
'rådataene': ('rådata',),
'rådataet': ('rådata',),
'rådbot': ('rådbot',),
'rådbota': ('rådbot',),
'rådboten': ('rådbot',),
'rådbøtene': ('rådbot',),
'rådbøter': ('rådbot',),
'råde': ('råde',),
'råden': ('råde',),
'rådene': ('råde',),
'råder': ('råde',),
'rådebank': ('rådebank',),
'rådebanken': ('rådebank',),
'rådebankene': ('rådebank',),
'rådebanker': ('rådebank',),
'rådelager': ('rådelager',),
'rådelageret': ('rådelager',),
'rådelagra': ('rådelager',),
'rådelagre': ('rådelager',),
'rådelagrene': ('rådelager',),
'råderett': ('råderett',),
'råderetten': ('råderett',),
'råderettene': ('råderett',),
'råderetter': ('råderett',),
'rådgiing': ('rådgiing',),
'rådgiinga': ('rådgiing',),
'rådgiingen': ('rådgiing',),
'rådgiingene': ('rådgiing',),
'rådgiinger': ('rådgiing',),
'rådgiver': ('rådgiver',),
'rådgivere': ('rådgiver',),
'rådgiveren': ('rådgiver',),
'rådgiverer': ('rådgiver',),
'rådgiverne': ('rådgiver',),
'rådgiving': ('rådgiving',),
'rådgivinga': ('rådgiving',),
'rådgivingen': ('rådgiving',),
'rådgivingene': ('rådgiving',),
'rådgivinger': ('rådgiving',),
'rådgivning': ('rådgivning',),
'rådgivninga': ('rådgivning',),
'rådgivningen': ('rådgivning',),
'rådgivningene': ('rådgivning',),
'rådgivninger': ('rådgivning',),
'rådgjerd': ('rådgjerd',),
'rådgjerda': ('rådgjerd',),
'rådgjerden': ('rådgjerd',),
'rådgjerdene': ('rådgjerd',),
'rådgjerder': ('rådgjerd',),
'rådhus': ('rådhus',),
'rådhusa': ('rådhus',),
'rådhusene': ('rådhus',),
'rådhuset': ('rådhus',),
'rådighet': ('rådighet',),
'rådigheta': ('rådighet',),
'rådigheten': ('rådighet',),
'rådighetene': ('rådighet',),
'rådigheter': ('rådighet',),
'rådløshet': ('rådløshet',),
'rådløsheta': ('rådløshet',),
'rådløsheten': ('rådløshet',),
'rådløshetene': ('rådløshet',),
'rådløsheter': ('rådløshet',),
'rådløysa': ('rådløyse',),
'rådløyse': ('rådløyse',),
'rådløysen': ('rådløyse',),
'rådløysene': ('rådløyse',),
'rådløyser': ('rådløyse',),
'rådmann': ('rådmann',),
'rådmannen': ('rådmann',),
'rådmenn': ('rådmann',),
'rådmennene': ('rådmann',),
'rådsdreng': ('rådsdreng',),
'rådsdrengen': ('rådsdreng',),
'rådsdrengene': ('rådsdreng',),
'rådsdrenger': ('rådsdreng',),
'rådsforsamling': ('rådsforsamling',),
'rådsforsamlinga': ('rådsforsamling',),
'rådsforsamlingen': ('rådsforsamling',),
'rådsforsamlingene': ('rådsforsamling',),
'rådsforsamlinger': ('rådsforsamling',),
'rådsherre': ('rådsherre',),
'rådsherren': ('rådsherre',),
'rådsherrene': ('rådsherre',),
'rådsherrer': ('rådsherre',),
'rådskar': ('rådskar',),
'rådskaren': ('rådskar',),
'rådskarene': ('rådskar',),
'rådskarer': ('rådskar',),
'rådslag': ('rådslag',),
'rådslaga': ('rådslag',),
'rådslagene': ('rådslag',),
'rådslaget': ('rådslag',),
'rådslagning': ('rådslagning',),
'rådslagninga': ('rådslagning',),
'rådslagningen': ('rådslagning',),
'rådslagningene': ('rådslagning',),
'rådslagninger': ('rådslagning',),
'rådslåing': ('rådslåing',),
'rådslåinga': ('rådslåing',),
'rådslåingen': ('rådslåing',),
'rådslåingene': ('rådslåing',),
'rådslåinger': ('rådslåing',),
'rådsrepublikk': ('rådsrepublikk',),
'rådsrepublikken': ('rådsrepublikk',),
'rådsrepublikkene': ('rådsrepublikk',),
'rådsrepublikker': ('rådsrepublikk',),
'rådssystem': ('rådssystem',),
'rådssystema': ('rådssystem',),
'rådssystemene': ('rådssystem',),
'rådssystemer': ('rådssystem',),
'rådssystemet': ('rådssystem',),
'rådstua': ('rådstue',),
'rådstue': ('rådstue',),
'rådstuen': ('rådstue',),
'rådstuene': ('rådstue',),
'rådstuer': ('rådstue',),
'rådvelda': ('rådvelde',),
'rådvelde': ('rådvelde',),
'rådveldene': ('rådvelde',),
'rådvelder': ('rådvelde',),
'rådveldet': ('rådvelde',),
'rådyr': ('rådyr',),
'rådyra': ('rådyr',),
'rådyrene': ('rådyr',),
'rådyret': ('rådyr',),
'rådyr': ('rådyr',),
'rådyra': ('rådyr',),
'rådyrene': ('rådyr',),
'rådyret': ('rådyr',),
'råemna': ('råemne',),
'råemne': ('råemne',),
'råemnene': ('råemne',),
'råemner': ('råemne',),
'råemnet': ('råemne',),
'råfabrikat': ('råfabrikat',),
'råfabrikata': ('råfabrikat',),
'råfabrikatene': ('råfabrikat',),
'råfabrikater': ('råfabrikat',),
'råfabrikatet': ('råfabrikat',),
'råfisk': ('råfisk',),
'råfisken': ('råfisk',),
'råfiskene': ('råfisk',),
'råfisker': ('råfisk',),
'råflaks': ('råflaks',),
'råflaksen': ('råflaks',),
'råflaksene': ('råflaks',),
'råflakser': ('råflaks',),
'rågjenger': ('rågjenger',),
'rågjengere': ('rågjenger',),
'rågjengeren': ('rågjenger',),
'rågjengerer': ('rågjenger',),
'rågjengerne': ('rågjenger',),
'rågummi': ('rågummi',),
'rågummien': ('rågummi',),
'rågummiene': ('rågummi',),
'rågummier': ('rågummi',),
'råhet': ('råhet',),
'råheta': ('råhet',),
'råheten': ('råhet',),
'råhetene': ('råhet',),
'råheter': ('råhet',),
'råjern': ('råjern',),
'råjerna': ('råjern',),
'råjernene': ('råjern',),
'råjernet': ('råjern',),
'råk': ('råk',),
'råka': ('råk',),
'råken': ('råk',),
'råkene': ('råk',),
'råker': ('råk',),
'råk': ('råk',),
'råka': ('råk',),
'råken': ('råk',),
'råkene': ('råk',),
'råker': ('råk',),
'råkjører': ('råkjører',),
'råkjørere': ('råkjører',),
'råkjøreren': ('råkjører',),
'råkjørerer': ('råkjører',),
'råkjørerne': ('råkjører',),
'råkjøring': ('råkjøring',),
'råkjøringa': ('råkjøring',),
'råkjøringen': ('råkjøring',),
'råkjøringene': ('råkjøring',),
'råkjøringer': ('råkjøring',),
'råkmål': ('råkmål',),
'råkmåla': ('råkmål',),
'råkmålene': ('råkmål',),
'råkmålet': ('råkmål',),
'råkost': ('råkost',),
'råkosten': ('råkost',),
'råkostene': ('råkost',),
'råkoster': ('råkost',),
'rål': ('rål',),
'råla': ('rål',),
'rålene': ('rål',),
'rålet': ('rål',),
'rålenda': ('rålende',),
'rålende': ('rålende',),
'rålendene': ('rålende',),
'rålender': ('rålende',),
'rålendet': ('rålende',),
'råmanus': ('råmanus',),
'råmanusa': ('råmanus',),
'råmanusene': ('råmanus',),
'råmanuser': ('råmanus',),
'råmanuset': ('råmanus',),
'råmanuskript': ('råmanuskript',),
'råmanuskripta': ('råmanuskript',),
'råmanuskriptene': ('råmanuskript',),
'råmanuskripter': ('råmanuskript',),
'råmanuskriptet': ('råmanuskript',),
'råmaterial': ('råmaterial',),
'råmateriala': ('råmaterial',),
'råmaterialene': ('råmaterial',),
'råmaterialer': ('råmaterial',),
'råmaterialet': ('råmaterial',),
'råmateriala': ('råmateriale',),
'råmateriale': ('råmateriale',),
'råmaterialene': ('råmateriale',),
'råmaterialer': ('råmateriale',),
'råmaterialet': ('råmateriale',),
'råme': ('råme',),
'råmen': ('råme',),
'råmene': ('råme',),
'råmer': ('råme',),
'råmelk': ('råmelk',),
'råmelka': ('råmelk',),
'råmelken': ('råmelk',),
'råmelkene': ('råmelk',),
'råmelker': ('råmelk',),
'råmjølk': ('råmjølk',),
'råmjølka': ('råmjølk',),
'råmjølken': ('råmjølk',),
'råmjølkene': ('råmjølk',),
'råmjølker': ('råmjølk',),
'råne': ('råne',),
'rånen': ('råne',),
'rånene': ('råne',),
'råner': ('råne',),
'råolja': ('råolje',),
'råolje': ('råolje',),
'råoljen': ('råolje',),
'råoljene': ('råolje',),
'råoljer': ('råolje',),
'råprat': ('råprat',),
'råprata': ('råprat',),
'råpraten': ('råprat',),
'råpratene': ('råprat',),
'råprater': ('råprat',),
'råpratet': ('råprat',),
'rårand': ('rårand',),
'råranda': ('rårand',),
'råranden': ('rårand',),
'rårendene': ('rårand',),
'rårender': ('rårand',),
'rås': ('rås',),
'råsa': ('rås',),
'råsen': ('rås',),
'råsene': ('rås',),
'råser': ('rås',),
'råsegl': ('råsegl',),
'råsegla': ('råsegl',),
'råseglene': ('råsegl',),
'råseglet': ('råsegl',),
'råseil': ('råseil',),
'råseila': ('råseil',),
'råseilene': ('råseil',),
'råseilet': ('råseil',),
'råsilke': ('råsilke',),
'råsilken': ('råsilke',),
'råsilkene': ('råsilke',),
'råsilker': ('råsilke',),
'råskap': ('råskap',),
'råskapen': ('råskap',),
'råskapene': ('råskap',),
'råskaper': ('råskap',),
'råske': ('råske',),
'råsken': ('råske',),
'råskene': ('råske',),
'råsker': ('råske',),
'råskinn': ('råskinn',),
'råskinna': ('råskinn',),
'råskinnene': ('råskinn',),
'råskinnet': ('råskinn',),
'råskjær': ('råskjær',),
'råskjæren': ('råskjær',),
'råskjærene': ('råskjær',),
'råskjærer': ('råskjær',),
'råstoff': ('råstoff',),
'råstoffa': ('råstoff',),
'råstoffene': ('råstoff',),
'råstoffer': ('råstoff',),
'råstoffet': ('råstoff',),
'råtamp': ('råtamp',),
'råtampen': ('råtamp',),
'råtampene': ('råtamp',),
'råtamper': ('råtamp',),
'råtass': ('råtass',),
'råtassen': ('råtass',),
'råtassene': ('råtass',),
'råtasser': ('råtass',),
'råte': ('råte',),
'råten': ('råte',),
'råtene': ('råte',),
'råter': ('råte',),
'råtev': ('råtev',),
'råteven': ('råtev',),
'råtevene': ('råtev',),
'råtever': ('råtev',),
'råttenskap': ('råttenskap',),
'råttenskapen': ('råttenskap',),
'råttenskapene': ('råttenskap',),
'råttenskaper': ('råttenskap',),
'råvara': ('råvare',),
'råvare': ('råvare',),
'råvaren': ('råvare',),
'råvarene': ('råvare',),
'råvarer': ('råvare',),
'råvær': ('råvær',),
'råværa': ('råvær',),
'råværene': ('råvær',),
'råværet': ('råvær',),
'råvær': ('råvær',),
'råværa': ('råvær',),
'råværene': ('råvær',),
'råværet': ('råvær',),
'ræv': ('ræv',),
'ræva': ('ræv',),
'ræven': ('ræv',),
'rævene': ('ræv',),
'ræver': ('ræv',),
'rødalge': ('rødalge',),
'rødalgen': ('rødalge',),
'rødalgene': ('rødalge',),
'rødalger': ('rødalge',),
'rødbeta': ('rødbete',),
'rødbete': ('rødbete',),
'rødbeten': ('rødbete',),
'rødbetene': ('rødbete',),
'rødbeter': ('rødbete',),
'rødbetsaft': ('rødbetsaft',),
'rødbetsafta': ('rødbetsaft',),
'rødbetsaften': ('rødbetsaft',),
'rødbetsaftene': ('rødbetsaft',),
'rødbetsafter': ('rødbetsaft',),
'røde': ('røde',),
'røden': ('røde',),
'rødene': ('røde',),
'røder': ('røde',),
'røda': ('røde',),
'røde': ('røde',),
'røden': ('røde',),
'rødene': ('røde',),
'røder': ('røde',),
'rødegardist': ('rødegardist',),
'rødegardisten': ('rødegardist',),
'rødegardistene': ('rødegardist',),
'rødegardister': ('rødegardist',),
'rødeik': ('rødeik',),
'rødeika': ('rødeik',),
'rødeiken': ('rødeik',),
'rødeikene': ('rødeik',),
'rødeiker': ('rødeik',),
'rødekorssøster': ('rødekorssøster',),
'rødekorssøstera': ('rødekorssøster',),
'rødekorssøsteren': ('rødekorssøster',),
'rødekorssøstre': ('rødekorssøster',),
'rødekorssøstrene': ('rødekorssøster',),
'rødekorssøstrer': ('rødekorssøster',),
'rødfisk': ('rødfisk',),
'rødfisken': ('rødfisk',),
'rødfiskene': ('rødfisk',),
'rødfisker': ('rødfisk',),
'rødfuru': ('rødfuru',),
'rødfurua': ('rødfuru',),
'rødfuruen': ('rødfuru',),
'rødfuruene': ('rødfuru',),
'rødfuruer': ('rødfuru',),
'rødgraut': ('rødgraut',),
'rødgrauten': ('rødgraut',),
'rødgrautene': ('rødgraut',),
'rødgrauter': ('rødgraut',),
'rødgrøt': ('rødgrøt',),
'rødgrøten': ('rødgrøt',),
'rødgrøtene': ('rødgrøt',),
'rødgrøter': ('rødgrøt',),
'rødhud': ('rødhud',),
'rødhuden': ('rødhud',),
'rødhudene': ('rødhud',),
'rødhuder': ('rødhud',),
'rødkjelk': ('rødkjelk',),
'rødkjelken': ('rødkjelk',),
'rødkjelkene': ('rødkjelk',),
'rødkjelker': ('rødkjelk',),
'rødkløver': ('rødkløver',),
'rødkløvere': ('rødkløver',),
'rødkløveren': ('rødkløver',),
'rødkløverer': ('rødkløver',),
'rødkløverne': ('rødkløver',),
'rødkolla': ('rødkolle',),
'rødkolle': ('rødkolle',),
'rødkollen': ('rødkolle',),
'rødkollene': ('rødkolle',),
'rødkoller': ('rødkolle',),
'rødkål': ('rødkål',),
'rødkålen': ('rødkål',),
'rødkålene': ('rødkål',),
'rødkåler': ('rødkål',),
'rødme': ('rødme',),
'rødmen': ('rødme',),
'rødmene': ('rødme',),
'rødmer': ('rødme',),
'rødmose': ('rødmose',),
'rødmosen': ('rødmose',),
'rødmosene': ('rødmose',),
'rødmoser': ('rødmose',),
'rødrev': ('rødrev',),
'rødreven': ('rødrev',),
'rødrevene': ('rødrev',),
'rødrever': ('rødrev',),
'rødruss': ('rødruss',),
'rødrussen': ('rødruss',),
'rødrussene': ('rødruss',),
'rødsjuka': ('rødsjuke',),
'rødsjuke': ('rødsjuke',),
'rødsjuken': ('rødsjuke',),
'rødsjukene': ('rødsjuke',),
'rødsjuker': ('rødsjuke',),
'rødsott': ('rødsott',),
'rødsotta': ('rødsott',),
'rødsotten': ('rødsott',),
'rødsottene': ('rødsott',),
'rødsotter': ('rødsott',),
'rødspetta': ('rødspette',),
'rødspette': ('rødspette',),
'rødspetten': ('rødspette',),
'rødspettene': ('rødspette',),
'rødspetter': ('rødspette',),
'rødsprit': ('rødsprit',),
'rødspriten': ('rødsprit',),
'rødspritene': ('rødsprit',),
'rødspriter': ('rødsprit',),
'rødstein': ('rødstein',),
'rødsteinen': ('rødstein',),
'rødsteinene': ('rødstein',),
'rødsteiner': ('rødstein',),
'rødstilk': ('rødstilk',),
'rødstilken': ('rødstilk',),
'rødstilkene': ('rødstilk',),
'rødstilker': ('rødstilk',),
'rødstjert': ('rødstjert',),
'rødstjerten': ('rødstjert',),
'rødstjertene': ('rødstjert',),
'rødstjerter': ('rødstjert',),
'rødstrupe': ('rødstrupe',),
'rødstrupen': ('rødstrupe',),
'rødstrupene': ('rødstrupe',),
'rødstruper': ('rødstrupe',),
'rødstrømpa': ('rødstrømpe',),
'rødstrømpe': ('rødstrømpe',),
'rødstrømpen': ('rødstrømpe',),
'rødstrømpene': ('rødstrømpe',),
'rødstrømper': ('rødstrømpe',),
'rødsyka': ('rødsyke',),
'rødsyke': ('rødsyke',),
'rødsyken': ('rødsyke',),
'rødsykene': ('rødsyke',),
'rødsyker': ('rødsyke',),
'rødt': ('rødt',),
'rødtopp': ('rødtopp',),
'rødtoppen': ('rødtopp',),
'rødtoppene': ('rødtopp',),
'rødtopper': ('rødtopp',),
'rødveng': ('rødveng',),
'rødvengen': ('rødveng',),
'rødvengene': ('rødveng',),
'rødvenger': ('rødveng',),
'rødvin': ('rødvin',),
'rødvinen': ('rødvin',),
'rødvinene': ('rødvin',),
'rødviner': ('rødvin',),
'rødving': ('rødving',),
'rødvingen': ('rødving',),
'rødvingene': ('rødving',),
'rødvinger': ('rødving',),
'rødvinge': ('rødvinge',),
'rødvingen': ('rødvinge',),
'rødvingene': ('rødvinge',),
'rødvinger': ('rødvinge',),
'rødvinstoddi': ('rødvinstoddi',),
'rødvinstoddien': ('rødvinstoddi',),
'rødvinstoddiene': ('rødvinstoddi',),
'rødvinstoddier': ('rødvinstoddi',),
'rødåta': ('rødåte',),
'rødåte': ('rødåte',),
'rødåten': ('rødåte',),
'rødåtene': ('rødåte',),
'rødåter': ('rødåte',),
'rødåtet': ('rødåte',),
'røffel': ('røffel',),
'røffelen': ('røffel',),
'røflene': ('røffel',),
'røfler': ('røffel',),
'røft': ('røft',),
'røfta': ('røft',),
'røften': ('røft',),
'røftene': ('røft',),
'røfter': ('røft',),
'røfta': ('røfte',),
'røfte': ('røfte',),
'røftene': ('røfte',),
'røfter': ('røfte',),
'røftet': ('røfte',),
'røkelseskar': ('røkelseskar',),
'røkelseskara': ('røkelseskar',),
'røkelseskarene': ('røkelseskar',),
'røkelseskaret': ('røkelseskar',),
'røkkel': ('røkkel',),
'røkkelet': ('røkkel',),
'røkla': ('røkkel',),
'røklene': ('røkkel',),
'røkler': ('røkkel',),
'røklet': ('røkkel',),
'røkt': ('røkt',),
'røkta': ('røkt',),
'røkten': ('røkt',),
'røktene': ('røkt',),
'røkter': ('røkt',),
'røkter': ('røkter',),
'røktere': ('røkter',),
'røkteren': ('røkter',),
'røkterer': ('røkter',),
'røkterne': ('røkter',),
'røl': ('røl',),
'røla': ('røl',),
'rølene': ('røl',),
'rølet': ('røl',),
'røllik': ('røllik',),
'rølliken': ('røllik',),
'røllikene': ('røllik',),
'rølliker': ('røllik',),
'røllik': ('røllik',),
'rølliken': ('røllik',),
'røllikene': ('røllik',),
'rølliker': ('røllik',),
'rølpelag': ('rølpelag',),
'rølpelaga': ('rølpelag',),
'rølpelagene': ('rølpelag',),
'rølpelaget': ('rølpelag',),
'rømling': ('rømling',),
'rømlingen': ('rømling',),
'rømlingene': ('rømling',),
'rømlinger': ('rømling',),
'rømme': ('rømme',),
'rømmen': ('rømme',),
'rømmene': ('rømme',),
'rømmer': ('rømme',),
'rømmegraut': ('rømmegraut',),
'rømmegrauten': ('rømmegraut',),
'rømmegrautene': ('rømmegraut',),
'rømmegrauter': ('rømmegraut',),
'rømmegrøt': ('rømmegrøt',),
'rømmegrøten': ('rømmegrøt',),
'rømmegrøtene': ('rømmegrøt',),
'rømmegrøter': ('rømmegrøt',),
'rømmekolla': ('rømmekolle',),
'rømmekolle': ('rømmekolle',),
'rømmekollen': ('rømmekolle',),
'rømmekollene': ('rømmekolle',),
'rømmekoller': ('rømmekolle',),
'rømmer': ('rømmer',),
'rømmere': ('rømmer',),
'rømmeren': ('rømmer',),
'rømmerer': ('rømmer',),
'rømmerne': ('rømmer',),
'rømning': ('rømning',),
'rømninga': ('rømning',),
'rømningen': ('rømning',),
'rømningene': ('rømning',),
'rømninger': ('rømning',),
'rømningsforsøk': ('rømningsforsøk',),
'rømningsforsøka': ('rømningsforsøk',),
'rømningsforsøkene': ('rømningsforsøk',),
'rømningsforsøket': ('rømningsforsøk',),
'rønna': ('rønne',),
'rønne': ('rønne',),
'rønnen': ('rønne',),
'rønnene': ('rønne',),
'rønner': ('rønne',),
'rønner': ('rønner',),
'rønnere': ('rønner',),
'rønneren': ('rønner',),
'rønnerer': ('rønner',),
'rønnerne': ('rønner',),
'røntgen': ('røntgen',),
'røntgenen': ('røntgen',),
'røntgenene': ('røntgen',),
'røntgenbehandling': ('røntgenbehandling',),
'røntgenbehandlinga': ('røntgenbehandling',),
'røntgenbehandlingen': ('røntgenbehandling',),
'røntgenbehandlingene': ('røntgenbehandling',),
'røntgenbehandlinger': ('røntgenbehandling',),
'røntgenbilda': ('røntgenbilde',),
'røntgenbilde': ('røntgenbilde',),
'røntgenbildene': ('røntgenbilde',),
'røntgenbilder': ('røntgenbilde',),
'røntgenbildet': ('røntgenbilde',),
'røntgenograf': ('røntgenograf',),
'røntgenografen': ('røntgenograf',),
'røntgenografene': ('røntgenograf',),
'røntgenografer': ('røntgenograf',),
'røntgenologi': ('røntgenologi',),
'røntgenologien': ('røntgenologi',),
'røntgenologiene': ('røntgenologi',),
'røntgenologier': ('røntgenologi',),
'rørelse': ('rørelse',),
'rørelsen': ('rørelse',),
'rørelsene': ('rørelse',),
'rørelser': ('rørelse',),
'rørfletning': ('rørfletning',),
'rørfletninga': ('rørfletning',),
'rørfletningen': ('rørfletning',),
'rørfletningene': ('rørfletning',),
'rørfletninger': ('rørfletning',),
'rørgata': ('rørgate',),
'rørgate': ('rørgate',),
'rørgaten': ('rørgate',),
'rørgatene': ('rørgate',),
'rørgater': ('rørgate',),
'rørledning': ('rørledning',),
'rørledninga': ('rørledning',),
'rørledningen': ('rørledning',),
'rørledningene': ('rørledning',),
'rørledninger': ('rørledning',),
'rørlegger': ('rørlegger',),
'rørleggere': ('rørlegger',),
'rørleggeren': ('rørlegger',),
'rørleggerer': ('rørlegger',),
'rørleggerne': ('rørlegger',),
'rørmøbel': ('rørmøbel',),
'rørmøbelet': ('rørmøbel',),
'rørmøbla': ('rørmøbel',),
'rørmøblene': ('rørmøbel',),
'rørmøbler': ('rørmøbel',),
'rørmøblet': ('rørmøbel',),
'rørpalme': ('rørpalme',),
'rørpalmen': ('rørpalme',),
'rørpalmene': ('rørpalme',),
'rørpalmer': ('rørpalme',),
'rørpost': ('rørpost',),
'rørposten': ('rørpost',),
'rørpostene': ('rørpost',),
'rørposter': ('rørpost',),
'rørsanger': ('rørsanger',),
'rørsangere': ('rørsanger',),
'rørsangeren': ('rørsanger',),
'rørsangerer': ('rørsanger',),
'rørsangerne': ('rørsanger',),
'rørsla': ('rørsle',),
'rørsle': ('rørsle',),
'rørslen': ('rørsle',),
'rørslene': ('rørsle',),
'rørsler': ('rørsle',),
'rørstol': ('rørstol',),
'rørstolen': ('rørstol',),
'rørstolene': ('rørstol',),
'rørstoler': ('rørstol',),
'rørsukker': ('rørsukker',),
'rørsukkera': ('rørsukker',),
'rørsukkere': ('rørsukker',),
'rørsukkerene': ('rørsukker',),
'rørsukkeret': ('rørsukker',),
'rørsukkerne': ('rørsukker',),
'røsk': ('røsk',),
'røska': ('røsk',),
'røskene': ('røsk',),
'røsket': ('røsk',),
'røsslyng': ('røsslyng',),
'røsslynga': ('røsslyng',),
'røsslyngen': ('røsslyng',),
'røsslyngene': ('røsslyng',),
'røsslynger': ('røsslyng',),
'røsslynget': ('røsslyng',),
'røst': ('røst',),
'røsta': ('røst',),
'røstene': ('røst',),
'røstet': ('røst',),
'røst': ('røst',),
'røsta': ('røst',),
'røstene': ('røst',),
'røstet': ('røst',),
'røst': ('røst',),
'røsta': ('røst',),
'røsten': ('røst',),
'røstene': ('røst',),
'røster': ('røst',),
'røver': ('røver',),
'røvere': ('røver',),
'røveren': ('røver',),
'røverer': ('røver',),
'røverne': ('røver',),
'røverhistoria': ('røverhistorie',),
'røverhistorie': ('røverhistorie',),
'røverhistorien': ('røverhistorie',),
'røverhistoriene': ('røverhistorie',),
'røverhistorier': ('røverhistorie',),
'røveri': ('røveri',),
'røveria': ('røveri',),
'røveriene': ('røveri',),
'røverier': ('røveri',),
'røveriet': ('røveri',),
'røverkjøp': ('røverkjøp',),
'røverkjøpa': ('røverkjøp',),
'røverkjøpene': ('røverkjøp',),
'røverkjøpet': ('røverkjøp',),
'røverpris': ('røverpris',),
'røverprisen': ('røverpris',),
'røverprisene': ('røverpris',),
'røverpriser': ('røverpris',),
'røverstat': ('røverstat',),
'røverstaten': ('røverstat',),
'røverstatene': ('røverstat',),
'røverstater': ('røverstat',),
'røverunge': ('røverunge',),
'røverungen': ('røverunge',),
'røverungene': ('røverunge',),
'røverunger': ('røverunge',),
'røy': ('røy',),
'røya': ('røy',),
'røyen': ('røy',),
'røyene': ('røy',),
'røyer': ('røy',),
'røya': ('røye',),
'røye': ('røye',),
'røyen': ('røye',),
'røyene': ('røye',),
'røyer': ('røye',),
'røykdykker': ('røykdykker',),
'røykdykkere': ('røykdykker',),
'røykdykkeren': ('røykdykker',),
'røykdykkerer': ('røykdykker',),
'røykdykkerne': ('røykdykker',),
'røykejakka': ('røykejakke',),
'røykejakke': ('røykejakke',),
'røykejakken': ('røykejakke',),
'røykejakkene': ('røykejakke',),
'røykejakker': ('røykejakke',),
'røykelaks': ('røykelaks',),
'røykelaksen': ('røykelaks',),
'røykelaksene': ('røykelaks',),
'røykelakser': ('røykelaks',),
'røykelseskar': ('røykelseskar',),
'røykelseskara': ('røykelseskar',),
'røykelseskarene': ('røykelseskar',),
'røykelseskaret': ('røykelseskar',),
'røyker': ('røyker',),
'røykere': ('røyker',),
'røykeren': ('røyker',),
'røykerer': ('røyker',),
'røykerne': ('røyker',),
'røykeri': ('røykeri',),
'røykeria': ('røykeri',),
'røykeriene': ('røykeri',),
'røykerier': ('røykeri',),
'røykeriet': ('røykeri',),
'røykeværelsa': ('røykeværelse',),
'røykeværelse': ('røykeværelse',),
'røykeværelsene': ('røykeværelse',),
'røykeværelser': ('røykeværelse',),
'røykeværelset': ('røykeværelse',),
'røykhatt': ('røykhatt',),
'røykhatten': ('røykhatt',),
'røykhattene': ('røykhatt',),
'røykhatter': ('røykhatt',),
'røyking': ('røyking',),
'røykinga': ('røyking',),
'røykingen': ('røyking',),
'røykingene': ('røyking',),
'røykinger': ('røyking',),
'røykoffer': ('røykoffer',),
'røykofferet': ('røykoffer',),
'røykofra': ('røykoffer',),
'røykofre': ('røykoffer',),
'røykofrene': ('røykoffer',),
'røykomn': ('røykomn',),
'røykomnen': ('røykomn',),
'røykomnene': ('røykomn',),
'røykomner': ('røykomn',),
'røykovn': ('røykovn',),
'røykovnen': ('røykovn',),
'røykovnene': ('røykovn',),
'røykovner': ('røykovn',),
'røykplaga': ('røykplage',),
'røykplage': ('røykplage',),
'røykplagen': ('røykplage',),
'røykplagene': ('røykplage',),
'røykplager': ('røykplage',),
'røyksopp': ('røyksopp',),
'røyksoppen': ('røyksopp',),
'røyksoppene': ('røyksopp',),
'røyksopper': ('røyksopp',),
'røykstova': ('røykstove',),
'røykstove': ('røykstove',),
'røykstoven': ('røykstove',),
'røykstovene': ('røykstove',),
'røykstover': ('røykstove',),
'røykstua': ('røykstue',),
'røykstue': ('røykstue',),
'røykstuen': ('røykstue',),
'røykstuene': ('røykstue',),
'røykstuer': ('røykstue',),
'røykteppa': ('røykteppe',),
'røykteppe': ('røykteppe',),
'røykteppene': ('røykteppe',),
'røyktepper': ('røykteppe',),
'røykteppet': ('røykteppe',),
'røyl': ('røyl',),
'røylen': ('røyl',),
'røylene': ('røyl',),
'røyler': ('røyl',),
'røynd': ('røynd',),
'røynda': ('røynd',),
'røynden': ('røynd',),
'røyndene': ('røynd',),
'røynder': ('røynd',),
'røynsla': ('røynsle',),
'røynsle': ('røynsle',),
'røynslen': ('røynsle',),
'røynslene': ('røynsle',),
'røynsler': ('røynsle',),
'røyr': ('røyr',),
'røyra': ('røyr',),
'røyren': ('røyr',),
'røyrene': ('røyr',),
'røyrer': ('røyr',),
'røys': ('røys',),
'røysa': ('røys',),
'røysen': ('røys',),
'røysene': ('røys',),
'røyser': ('røys',),
'røysert': ('røysert',),
'røyserten': ('røysert',),
'røysertene': ('røysert',),
'røyserter': ('røysert',),
'røyskatt': ('røyskatt',),
'røyskatten': ('røyskatt',),
'røyskattene': ('røyskatt',),
'røyskatter': ('røyskatt',),
's': ('s',),
's\'en': ('s',),
's-en': ('s',),
's-ene': ('s',),
's-er': ('s',),
'sabadillefrø': ('sabadillefrø',),
'sabadillefrøa': ('sabadillefrø',),
'sabadillefrøene': ('sabadillefrø',),
'sabadillefrøet': ('sabadillefrø',),
'sabb': ('sabb',),
'sabben': ('sabb',),
'sabbene': ('sabb',),
'sabber': ('sabb',),
'sabbat': ('sabbat',),
'sabbaten': ('sabbat',),
'sabbatene': ('sabbat',),
'sabbater': ('sabbat',),
'sabbatsår': ('sabbatsår',),
'sabbatsåra': ('sabbatsår',),
'sabbatsårene': ('sabbatsår',),
'sabbatsåret': ('sabbatsår',),
'sabba': ('sabbe',),
'sabbe': ('sabbe',),
'sabben': ('sabbe',),
'sabbene': ('sabbe',),
'sabber': ('sabbe',),
'sabbeføra': ('sabbeføre',),
'sabbeføre': ('sabbeføre',),
'sabbeførene': ('sabbeføre',),
'sabbefører': ('sabbeføre',),
'sabbeføret': ('sabbeføre',),
'sabel': ('sabel',),
'sabelen': ('sabel',),
'sablene': ('sabel',),
'sabler': ('sabel',),
'sabelrasling': ('sabelrasling',),
'sabelraslinga': ('sabelrasling',),
'sabelraslingen': ('sabelrasling',),
'sabelraslingene': ('sabelrasling',),
'sabelraslinger': ('sabelrasling',),
'sabotasje': ('sabotasje',),
'sabotasjen': ('sabotasje',),
'sabotasjene': ('sabotasje',),
'sabotasjer': ('sabotasje',),
'sabotør': ('sabotør',),
'sabotøren': ('sabotør',),
'sabotørene': ('sabotør',),
'sabotører': ('sabotør',),
'saddukeer': ('saddukeer',),
'saddukeere': ('saddukeer',),
'saddukeeren': ('saddukeer',),
'saddukeerer': ('saddukeer',),
'saddukeerne': ('saddukeer',),
'sadel': ('sadel',),
'sadelen': ('sadel',),
'sadlene': ('sadel',),
'sadler': ('sadel',),
'sadelgjord': ('sadelgjord',),
'sadelgjorda': ('sadelgjord',),
'sadelgjorden': ('sadelgjord',),
'sadelgjordene': ('sadelgjord',),
'sadelgjorder': ('sadelgjord',),
'sadelknapp': ('sadelknapp',),
'sadelknappen': ('sadelknapp',),
'sadelknappene': ('sadelknapp',),
'sadelknapper': ('sadelknapp',),
'sadelplass': ('sadelplass',),
'sadelplassen': ('sadelplass',),
'sadelplassene': ('sadelplass',),
'sadelplasser': ('sadelplass',),
'sadelputa': ('sadelpute',),
'sadelpute': ('sadelpute',),
'sadelputen': ('sadelpute',),
'sadelputene': ('sadelpute',),
'sadelputer': ('sadelpute',),
'sadeltak': ('sadeltak',),
'sadeltaka': ('sadeltak',),
'sadeltakene': ('sadeltak',),
'sadeltaket': ('sadeltak',),
'sadeltaska': ('sadeltaske',),
'sadeltaske': ('sadeltaske',),
'sadeltasken': ('sadeltaske',),
'sadeltaskene': ('sadeltaske',),
'sadeltasker': ('sadeltaske',),
'sadelveska': ('sadelveske',),
'sadelveske': ('sadelveske',),
'sadelvesken': ('sadelveske',),
'sadelveskene': ('sadelveske',),
'sadelvesker': ('sadelveske',),
'sadisme': ('sadisme',),
'sadismen': ('sadisme',),
'sadismene': ('sadisme',),
'sadismer': ('sadisme',),
'sadist': ('sadist',),
'sadisten': ('sadist',),
'sadistene': ('sadist',),
'sadister': ('sadist',),
'sadomasochisme': ('sadomasochisme',),
'sadomasochismen': ('sadomasochisme',),
'sadomasochismene': ('sadomasochisme',),
'sadomasochismer': ('sadomasochisme',),
'safari': ('safari',),
'safarien': ('safari',),
'safariene': ('safari',),
'safarier': ('safari',),
'safarijakka': ('safarijakke',),
'safarijakke': ('safarijakke',),
'safarijakken': ('safarijakke',),
'safarijakkene': ('safarijakke',),
'safarijakker': ('safarijakke',),
'safe': ('safe',),
'safen': ('safe',),
'safene': ('safe',),
'safer': ('safe',),
'saffian': ('saffian',),
'saffiana': ('saffian',),
'saffianene': ('saffian',),
'saffianet': ('saffian',),
'saffiansko': ('saffiansko',),
'saffianskoa': ('saffiansko',),
'saffianskoen': ('saffiansko',),
'saffianskoene': ('saffiansko',),
'saffianskor': ('saffiansko',),
'saffianskorne': ('saffiansko',),
'safir': ('safir',),
'safiren': ('safir',),
'safirene': ('safir',),
'safirer': ('safir',),
'safran': ('safran',),
'safranen': ('safran',),
'safranene': ('safran',),
'safraner': ('safran',),
'saft': ('saft',),
'safta': ('saft',),
'saften': ('saft',),
'saftene': ('saft',),
'safter': ('saft',),
'saftogvann': ('saftogvann',),
'saftogvanna': ('saftogvann',),
'saftogvannene': ('saftogvann',),
'saftogvannet': ('saftogvann',),
'saftogvatn': ('saftogvatn',),
'saftogvatna': ('saftogvatn',),
'saftogvatnene': ('saftogvatn',),
'saftogvatnet': ('saftogvatn',),
'saftpressa': ('saftpresse',),
'saftpresse': ('saftpresse',),
'saftpressen': ('saftpresse',),
'saftpressene': ('saftpresse',),
'saftpresser': ('saftpresse',),
'sag': ('sag',),
'saga': ('sag',),
'sagen': ('sag',),
'sagene': ('sag',),
'sager': ('sag',),
'saga': ('saga',),
'sagaen': ('saga',),
'sagaene': ('saga',),
'sagaer': ('saga',),
'sagakonge': ('sagakonge',),
'sagakongen': ('sagakonge',),
'sagakongene': ('sagakonge',),
'sagakonger': ('sagakonge',),
'sagakvinna': ('sagakvinne',),
'sagakvinne': ('sagakvinne',),
'sagakvinnen': ('sagakvinne',),
'sagakvinnene': ('sagakvinne',),
'sagakvinner': ('sagakvinne',),
'sagaskikkelse': ('sagaskikkelse',),
'sagaskikkelsen': ('sagaskikkelse',),
'sagaskikkelsene': ('sagaskikkelse',),
'sagaskikkelser': ('sagaskikkelse',),
'sagaskriver': ('sagaskriver',),
'sagaskrivere': ('sagaskriver',),
'sagaskriveren': ('sagaskriver',),
'sagaskriverer': ('sagaskriver',),
'sagaskriverne': ('sagaskriver',),
'sagastil': ('sagastil',),
'sagastilen': ('sagastil',),
'sagastilene': ('sagastil',),
'sagastiler': ('sagastil',),
'sagatid': ('sagatid',),
'sagatida': ('sagatid',),
'sagatiden': ('sagatid',),
'sagatidene': ('sagatid',),
'sagatider': ('sagatid',),
'sagatått': ('sagatått',),
'sagatåtten': ('sagatått',),
'sagatåttene': ('sagatått',),
'sagatåtter': ('sagatått',),
'sagatættene': ('sagatått',),
'sagatætter': ('sagatått',),
'sagblad': ('sagblad',),
'sagblada': ('sagblad',),
'sagbladene': ('sagblad',),
'sagblader': ('sagblad',),
'sagbladet': ('sagblad',),
'sagbruk': ('sagbruk',),
'sagbruka': ('sagbruk',),
'sagbrukene': ('sagbruk',),
'sagbruket': ('sagbruk',),
'sagdam': ('sagdam',),
'sagdammen': ('sagdam',),
'sagdammene': ('sagdam',),
'sagdammer': ('sagdam',),
'sagflis': ('sagflis',),
'sagflisa': ('sagflis',),
'sagflisen': ('sagflis',),
'sagflisene': ('sagflis',),
'sagfliser': ('sagflis',),
'sagkrakk': ('sagkrakk',),
'sagkrakken': ('sagkrakk',),
'sagkrakkene': ('sagkrakk',),
'sagkrakker': ('sagkrakk',),
'sagmel': ('sagmel',),
'sagmela': ('sagmel',),
'sagmelene': ('sagmel',),
'sagmelet': ('sagmel',),
'sagmester': ('sagmester',),
'sagmestere': ('sagmester',),
'sagmesteren': ('sagmester',),
'sagmesterer': ('sagmester',),
'sagmesterne': ('sagmester',),
'sagmestre': ('sagmester',),
'sagmestrene': ('sagmester',),
'sagmestrer': ('sagmester',),
'sagmo': ('sagmo',),
'sagmoa': ('sagmo',),
'sagmoene': ('sagmo',),
'sagmoet': ('sagmo',),
'sagmugg': ('sagmugg',),
'sagmugga': ('sagmugg',),
'sagmuggen': ('sagmugg',),
'sagmuggene': ('sagmugg',),
'sagmugger': ('sagmugg',),
'sagmugget': ('sagmugg',),
'sagn': ('sagn',),
'sagna': ('sagn',),
'sagnene': ('sagn',),
'sagnet': ('sagn',),
'sagnfigur': ('sagnfigur',),
'sagnfiguren': ('sagnfigur',),
'sagnfigurene': ('sagnfigur',),
'sagnfigurer': ('sagnfigur',),
'sagnhelt': ('sagnhelt',),
'sagnhelten': ('sagnhelt',),
'sagnheltene': ('sagnhelt',),
'sagnhelter': ('sagnhelt',),
'sagnkrets': ('sagnkrets',),
'sagnkretsen': ('sagnkrets',),
'sagnkretsene': ('sagnkrets',),
'sagnkretser': ('sagnkrets',),
'sagnmotiv': ('sagnmotiv',),
'sagnmotiva': ('sagnmotiv',),
'sagnmotivene': ('sagnmotiv',),
'sagnmotiver': ('sagnmotiv',),
'sagnmotivet': ('sagnmotiv',),
'sago': ('sago',),
'sagoen': ('sago',),
'sagoene': ('sago',),
'sagoer': ('sago',),
'sagogryn': ('sagogryn',),
'sagogryna': ('sagogryn',),
'sagogrynene': ('sagogryn',),
'sagogrynet': ('sagogryn',),
'sagomel': ('sagomel',),
'sagomela': ('sagomel',),
'sagomelene': ('sagomel',),
'sagomelet': ('sagomel',),
'sagomjøl': ('sagomjøl',),
'sagomjøla': ('sagomjøl',),
'sagomjølene': ('sagomjøl',),
'sagomjølet': ('sagomjøl',),
'sagopalme': ('sagopalme',),
'sagopalmen': ('sagopalme',),
'sagopalmene': ('sagopalme',),
'sagopalmer': ('sagopalme',),
'sagosuppa': ('sagosuppe',),
'sagosuppe': ('sagosuppe',),
'sagosuppen': ('sagosuppe',),
'sagosuppene': ('sagosuppe',),
'sagosupper': ('sagosuppe',),
'sagradabark': ('sagradabark',),
'sagradabarken': ('sagradabark',),
'sagradabarkene': ('sagradabark',),
'sagradabarker': ('sagradabark',),
'sagradapilla': ('sagradapille',),
'sagradapille': ('sagradapille',),
'sagradapillen': ('sagradapille',),
'sagradapillene': ('sagradapille',),
'sagradapiller': ('sagradapille',),
'sagskur': ('sagskur',),
'sagskuren': ('sagskur',),
'sagskurene': ('sagskur',),
'sagskurer': ('sagskur',),
'sagskurd': ('sagskurd',),
'sagskurden': ('sagskurd',),
'sagskurdene': ('sagskurd',),
'sagskurder': ('sagskurd',),
'sagstol': ('sagstol',),
'sagstolen': ('sagstol',),
'sagstolene': ('sagstol',),
'sagstoler': ('sagstol',),
'sagtann': ('sagtann',),
'sagtanna': ('sagtann',),
'sagtannen': ('sagtann',),
'sagtennene': ('sagtann',),
'sagtenner': ('sagtann',),
'sagtind': ('sagtind',),
'sagtinden': ('sagtind',),
'sagtindene': ('sagtind',),
'sagtinder': ('sagtind',),
'sahib': ('sahib',),
'sahiben': ('sahib',),
'sahibene': ('sahib',),
'sahiber': ('sahib',),
'saiga': ('saiga',),
'saigaen': ('saiga',),
'saigaene': ('saiga',),
'saigaer': ('saiga',),
'saivok': ('saivok',),
'saivoken': ('saivok',),
'saivokene': ('saivok',),
'saivoker': ('saivok',),
'sak': ('sak',),
'saka': ('sak',),
'saken': ('sak',),
'sakene': ('sak',),
'saker': ('sak',),
'sake': ('sake',),
'saken': ('sake',),
'sakene': ('sake',),
'saker': ('sake',),
'sakefall': ('sakefall',),
'sakefalla': ('sakefall',),
'sakefallene': ('sakefall',),
'sakefallet': ('sakefall',),
'sakfører': ('sakfører',),
'sakførere': ('sakfører',),
'sakføreren': ('sakfører',),
'sakførerer': ('sakfører',),
'sakførerne': ('sakfører',),
'sakførsel': ('sakførsel',),
'sakførselen': ('sakførsel',),
'sakførslene': ('sakførsel',),
'sakførsler': ('sakførsel',),
'sakkarin': ('sakkarin',),
'sakkarina': ('sakkarin',),
'sakkarinen': ('sakkarin',),
'sakkarinene': ('sakkarin',),
'sakkariner': ('sakkarin',),
'sakkarinet': ('sakkarin',),
'sakkunnskap': ('sakkunnskap',),
'sakkunnskapen': ('sakkunnskap',),
'sakkunnskapene': ('sakkunnskap',),
'sakkunnskaper': ('sakkunnskap',),
'saklista': ('sakliste',),
'sakliste': ('sakliste',),
'saklisten': ('sakliste',),
'saklistene': ('sakliste',),
'saklister': ('sakliste',),
'sakn': ('sakn',),
'sakna': ('sakn',),
'saknene': ('sakn',),
'saknet': ('sakn',),
'saknad': ('saknad',),
'saknaden': ('saknad',),
'saknadene': ('saknad',),
'saknader': ('saknad',),
'sakprosa': ('sakprosa',),
'sakprosaen': ('sakprosa',),
'sakprosaene': ('sakprosa',),
'sakprosaer': ('sakprosa',),
'sakrament': ('sakrament',),
'sakramenta': ('sakrament',),
'sakramentene': ('sakrament',),
'sakramenter': ('sakrament',),
'sakramentet': ('sakrament',),
'sakregister': ('sakregister',),
'sakregisteret': ('sakregister',),
'sakregistra': ('sakregister',),
'sakregistre': ('sakregister',),
'sakregistrene': ('sakregister',),
'sakregistret': ('sakregister',),
'sakristi': ('sakristi',),
'sakristia': ('sakristi',),
'sakristiene': ('sakristi',),
'sakristier': ('sakristi',),
'sakristiet': ('sakristi',),
'saks': ('saks',),
'saksa': ('saks',),
'saksen': ('saks',),
'saksene': ('saks',),
'sakser': ('saks',),
'saksbehandler': ('saksbehandler',),
'saksbehandlere': ('saksbehandler',),
'saksbehandleren': ('saksbehandler',),
'saksbehandlerer': ('saksbehandler',),
'saksbehandlerne': ('saksbehandler',),
'saksbehandling': ('saksbehandling',),
'saksbehandlinga': ('saksbehandling',),
'saksbehandlingen': ('saksbehandling',),
'saksbehandlingene': ('saksbehandling',),
'saksbehandlinger': ('saksbehandling',),
'saksedyr': ('saksedyr',),
'saksedyra': ('saksedyr',),
'saksedyrene': ('saksedyr',),
'saksedyret': ('saksedyr',),
'sakser': ('sakser',),
'saksere': ('sakser',),
'sakseren': ('sakser',),
'sakserer': ('sakser',),
'sakserne': ('sakser',),
'saksespark': ('saksespark',),
'saksesparka': ('saksespark',),
'saksesparkene': ('saksespark',),
'saksesparket': ('saksespark',),
'saksestil': ('saksestil',),
'saksestilen': ('saksestil',),
'saksestilene': ('saksestil',),
'saksestiler': ('saksestil',),
'saksforhold': ('saksforhold',),
'saksforholda': ('saksforhold',),
'saksforholdene': ('saksforhold',),
'saksforholdet': ('saksforhold',),
'saksframstilling': ('saksframstilling',),
'saksframstillinga': ('saksframstilling',),
'saksframstillingen': ('saksframstilling',),
'saksframstillingene': ('saksframstilling',),
'saksframstillinger': ('saksframstilling',),
'saksfremstilling': ('saksfremstilling',),
'saksfremstillinga': ('saksfremstilling',),
'saksfremstillingen': ('saksfremstilling',),
'saksfremstillingene': ('saksfremstilling',),
'saksfremstillinger': ('saksfremstilling',),
'saksgang': ('saksgang',),
'saksgangen': ('saksgang',),
'saksgangene': ('saksgang',),
'saksganger': ('saksgang',),
'saksifraga': ('saksifraga',),
'saksifragaen': ('saksifraga',),
'saksifragaene': ('saksifraga',),
'saksifragaer': ('saksifraga',),
'sakslista': ('saksliste',),
'saksliste': ('saksliste',),
'sakslisten': ('saksliste',),
'sakslistene': ('saksliste',),
'sakslister': ('saksliste',),
'saksofon': ('saksofon',),
'saksofonen': ('saksofon',),
'saksofonene': ('saksofon',),
'saksofoner': ('saksofon',),
'saksofonist': ('saksofonist',),
'saksofonisten': ('saksofonist',),
'saksofonistene': ('saksofonist',),
'saksofonister': ('saksofonist',),
'saksomkostning': ('saksomkostning',),
'saksomkostninga': ('saksomkostning',),
'saksomkostningen': ('saksomkostning',),
'saksomkostningene': ('saksomkostning',),
'saksomkostninger': ('saksomkostning',),
'saksøker': ('saksøker',),
'saksøkere': ('saksøker',),
'saksøkeren': ('saksøker',),
'saksøkerer': ('saksøker',),
'saksøkerne': ('saksøker',),
'saktmodighet': ('saktmodighet',),
'saktmodigheta': ('saktmodighet',),
'saktmodigheten': ('saktmodighet',),
'saktmodighetene': ('saktmodighet',),
'saktmodigheter': ('saktmodighet',),
'sal': ('sal',),
'salen': ('sal',),
'salene': ('sal',),
'saler': ('sal',),
'sal': ('sal',),
'salen': ('sal',),
'salene': ('sal',),
'saler': ('sal',),
'salamander': ('salamander',),
'salamandere': ('salamander',),
'salamanderen': ('salamander',),
'salamanderer': ('salamander',),
'salamanderne': ('salamander',),
'salamandre': ('salamander',),
'salamandrene': ('salamander',),
'salamandrer': ('salamander',),
'salami': ('salami',),
'salamien': ('salami',),
'salamiene': ('salami',),
'salamier': ('salami',),
'salamipølsa': ('salamipølse',),
'salamipølse': ('salamipølse',),
'salamipølsen': ('salamipølse',),
'salamipølsene': ('salamipølse',),
'salamipølser': ('salamipølse',),
'salamitaktikk': ('salamitaktikk',),
'salamitaktikken': ('salamitaktikk',),
'salamitaktikkene': ('salamitaktikk',),
'salamitaktikker': ('salamitaktikk',),
'salangan': ('salangan',),
'salanganen': ('salangan',),
'salanganene': ('salangan',),
'salanganer': ('salangan',),
'salangansvala': ('salangansvale',),
'salangansvale': ('salangansvale',),
'salangansvalen': ('salangansvale',),
'salangansvalene': ('salangansvale',),
'salangansvaler': ('salangansvale',),
'salat': ('salat',),
'salaten': ('salat',),
'salatene': ('salat',),
'salater': ('salat',),
'salatbestikk': ('salatbestikk',),
'salatbestikka': ('salatbestikk',),
'salatbestikkene': ('salatbestikk',),
'salatbestikket': ('salatbestikk',),
'salathoda': ('salathode',),
'salathode': ('salathode',),
'salathodene': ('salathode',),
'salathoder': ('salathode',),
'salathodet': ('salathode',),
'saldering': ('saldering',),
'salderinga': ('saldering',),
'salderingen': ('saldering',),
'salderingene': ('saldering',),
'salderinger': ('saldering',),
'salderingsdebatt': ('salderingsdebatt',),
'salderingsdebatten': ('salderingsdebatt',),
'salderingsdebattene': ('salderingsdebatt',),
'salderingsdebatter': ('salderingsdebatt',),
'salderingspost': ('salderingspost',),
'salderingsposten': ('salderingspost',),
'salderingspostene': ('salderingspost',),
'salderingsposter': ('salderingspost',),
'saldo': ('saldo',),
'saldoen': ('saldo',),
'saldoene': ('saldo',),
'saldoer': ('saldo',),
'salg': ('salg',),
'salga': ('salg',),
'salgene': ('salg',),
'salget': ('salg',),
'salgjord': ('salgjord',),
'salgjorda': ('salgjord',),
'salgjorden': ('salgjord',),
'salgjordene': ('salgjord',),
'salgjorder': ('salgjord',),
'salgsapparat': ('salgsapparat',),
'salgsapparata': ('salgsapparat',),
'salgsapparatene': ('salgsapparat',),
'salgsapparater': ('salgsapparat',),
'salgsapparatet': ('salgsapparat',),
'salgslag': ('salgslag',),
'salgslaga': ('salgslag',),
'salgslagene': ('salgslag',),
'salgslaget': ('salgslag',),
'salgsorganisasjon': ('salgsorganisasjon',),
'salgsorganisasjonen': ('salgsorganisasjon',),
'salgsorganisasjonene': ('salgsorganisasjon',),
'salgsorganisasjoner': ('salgsorganisasjon',),
'salgsrepresentant': ('salgsrepresentant',),
'salgsrepresentanten': ('salgsrepresentant',),
'salgsrepresentantene': ('salgsrepresentant',),
'salgsrepresentanter': ('salgsrepresentant',),
'salgssentral': ('salgssentral',),
'salgssentralen': ('salgssentral',),
'salgssentralene': ('salgssentral',),
'salgssentraler': ('salgssentral',),
'salgssjåfør': ('salgssjåfør',),
'salgssjåføren': ('salgssjåfør',),
'salgssjåførene': ('salgssjåfør',),
'salgssjåfører': ('salgssjåfør',),
'salgsvara': ('salgsvare',),
'salgsvare': ('salgsvare',),
'salgsvaren': ('salgsvare',),
'salgsvarene': ('salgsvare',),
'salgsvarer': ('salgsvare',),
'salgsverdi': ('salgsverdi',),
'salgsverdien': ('salgsverdi',),
'salgsverdiene': ('salgsverdi',),
'salgsverdier': ('salgsverdi',),
'salighet': ('salighet',),
'saligheta': ('salighet',),
'saligheten': ('salighet',),
'salighetene': ('salighet',),
'saligheter': ('salighet',),
'saling': ('saling',),
'salinga': ('saling',),
'salingen': ('saling',),
'salingene': ('saling',),
'salinger': ('saling',),
'salisyl': ('salisyl',),
'salisyla': ('salisyl',),
'salisylene': ('salisyl',),
'salisylet': ('salisyl',),
'salisylsyra': ('salisylsyre',),
'salisylsyre': ('salisylsyre',),
'salisylsyren': ('salisylsyre',),
'salisylsyrene': ('salisylsyre',),
'salisylsyrer': ('salisylsyre',),
'salknapp': ('salknapp',),
'salknappen': ('salknapp',),
'salknappene': ('salknapp',),
'salknapper': ('salknapp',),
'salmaker': ('salmaker',),
'salmakere': ('salmaker',),
'salmakeren': ('salmaker',),
'salmakerer': ('salmaker',),
'salmakerne': ('salmaker',),
'salme': ('salme',),
'salmen': ('salme',),
'salmene': ('salme',),
'salmer': ('salme',),
'salmetone': ('salmetone',),
'salmetonen': ('salmetone',),
'salmetonene': ('salmetone',),
'salmetoner': ('salmetone',),
'salmevers': ('salmevers',),
'salmeversa': ('salmevers',),
'salmeversene': ('salmevers',),
'salmeverset': ('salmevers',),
'salmiakk': ('salmiakk',),
'salmiakken': ('salmiakk',),
'salmiakkene': ('salmiakk',),
'salmiakker': ('salmiakk',),
'salmiakkløsning': ('salmiakkløsning',),
'salmiakkløsninga': ('salmiakkløsning',),
'salmiakkløsningen': ('salmiakkløsning',),
'salmiakkløsningene': ('salmiakkløsning',),
'salmiakkløsninger': ('salmiakkløsning',),
'salmiakkoppløsning': ('salmiakkoppløsning',),
'salmiakkoppløsninga': ('salmiakkoppløsning',),
'salmiakkoppløsningen': ('salmiakkoppløsning',),
'salmiakkoppløsningene': ('salmiakkoppløsning',),
'salmiakkoppløsninger': ('salmiakkoppløsning',),
'salmiakkspiritus': ('salmiakkspiritus',),
'salmiakkspiritusen': ('salmiakkspiritus',),
'salmiakkspiritusene': ('salmiakkspiritus',),
'salmiakkspirituser': ('salmiakkspiritus',),
'salmist': ('salmist',),
'salmisten': ('salmist',),
'salmistene': ('salmist',),
'salmister': ('salmist',),
'salmodikon': ('salmodikon',),
'salmodikona': ('salmodikon',),
'salmodikonene': ('salmodikon',),
'salmodikoner': ('salmodikon',),
'salmodikonet': ('salmodikon',),
'salomoner': ('salomoner',),
'salomonere': ('salomoner',),
'salomoneren': ('salomoner',),
'salomonerer': ('salomoner',),
'salomonerne': ('salomoner',),
'salong': ('salong',),
'salongen': ('salong',),
'salongene': ('salong',),
'salonger': ('salong',),
'salongdekk': ('salongdekk',),
'salongdekka': ('salongdekk',),
'salongdekkene': ('salongdekk',),
'salongdekket': ('salongdekk',),
'salonggevær': ('salonggevær',),
'salonggeværa': ('salonggevær',),
'salonggeværene': ('salonggevær',),
'salonggeværer': ('salonggevær',),
'salonggeværet': ('salonggevær',),
'salongmusikk': ('salongmusikk',),
'salongmusikken': ('salongmusikk',),
'salongmusikkene': ('salongmusikk',),
'salongmusikker': ('salongmusikk',),
'salongorkester': ('salongorkester',),
'salongorkesteret': ('salongorkester',),
'salongorkestra': ('salongorkester',),
'salongorkestre': ('salongorkester',),
'salongorkestrene': ('salongorkester',),
'salongorkestret': ('salongorkester',),
'salongradikaler': ('salongradikaler',),
'salongradikalere': ('salongradikaler',),
'salongradikaleren': ('salongradikaler',),
'salongradikalerer': ('salongradikaler',),
'salongradikalerne': ('salongradikaler',),
'salongrifla': ('salongrifle',),
'salongrifle': ('salongrifle',),
'salongriflen': ('salongrifle',),
'salongriflene': ('salongrifle',),
'salongrifler': ('salongrifle',),
'salongstykka': ('salongstykke',),
'salongstykke': ('salongstykke',),
'salongstykkene': ('salongstykke',),
'salongstykker': ('salongstykke',),
'salongstykket': ('salongstykke',),
'saloon': ('saloon',),
'saloonen': ('saloon',),
'saloonene': ('saloon',),
'salooner': ('saloon',),
'saloondør': ('saloondør',),
'saloondøra': ('saloondør',),
'saloondøren': ('saloondør',),
'saloondørene': ('saloondør',),
'saloondører': ('saloondør',),
'salpeter': ('salpeter',),
'salpetere': ('salpeter',),
'salpeteren': ('salpeter',),
'salpeterer': ('salpeter',),
'salpeterne': ('salpeter',),
'salpetre': ('salpeter',),
'salpetrene': ('salpeter',),
'salpetrer': ('salpeter',),
'salpetersyra': ('salpetersyre',),
'salpetersyre': ('salpetersyre',),
'salpetersyren': ('salpetersyre',),
'salpetersyrene': ('salpetersyre',),
'salpetersyrer': ('salpetersyre',),
'salplass': ('salplass',),
'salplassen': ('salplass',),
'salplassene': ('salplass',),
'salplasser': ('salplass',),
'salputa': ('salpute',),
'salpute': ('salpute',),
'salputen': ('salpute',),
'salputene': ('salpute',),
'salputer': ('salpute',),
'salt': ('salt',),
'salta': ('salt',),
'saltene': ('salt',),
'salter': ('salt',),
'saltet': ('salt',),
'saltak': ('saltak',),
'saltaka': ('saltak',),
'saltakene': ('saltak',),
'saltaket': ('saltak',),
'saltaska': ('saltaske',),
'saltaske': ('saltaske',),
'saltasken': ('saltaske',),
'saltaskene': ('saltaske',),
'saltasker': ('saltaske',),
'saltbrenning': ('saltbrenning',),
'saltbrenninga': ('saltbrenning',),
'saltbrenningen': ('saltbrenning',),
'saltbrenningene': ('saltbrenning',),
'saltbrenninger': ('saltbrenning',),
'saltbrott': ('saltbrott',),
'saltbrotta': ('saltbrott',),
'saltbrottene': ('saltbrott',),
'saltbrottet': ('saltbrott',),
'saltbrudd': ('saltbrudd',),
'saltbrudda': ('saltbrudd',),
'saltbruddene': ('saltbrudd',),
'saltbruddet': ('saltbrudd',),
'saltbøssa': ('saltbøsse',),
'saltbøsse': ('saltbøsse',),
'saltbøssen': ('saltbøsse',),
'saltbøssene': ('saltbøsse',),
'saltbøsser': ('saltbøsse',),
'saltekar': ('saltekar',),
'saltekara': ('saltekar',),
'saltekarene': ('saltekar',),
'saltekaret': ('saltekar',),
'salter': ('salter',),
'saltere': ('salter',),
'salteren': ('salter',),
'salterer': ('salter',),
'salterne': ('salter',),
'salteri': ('salteri',),
'salteria': ('salteri',),
'salteriene': ('salteri',),
'salterier': ('salteri',),
'salteriet': ('salteri',),
'saltfisk': ('saltfisk',),
'saltfisken': ('saltfisk',),
'saltfiskene': ('saltfisk',),
'saltfisker': ('saltfisk',),
'saltkar': ('saltkar',),
'saltkara': ('saltkar',),
'saltkarene': ('saltkar',),
'saltkaret': ('saltkar',),
'saltkjøtt': ('saltkjøtt',),
'saltkjøtta': ('saltkjøtt',),
'saltkjøttene': ('saltkjøtt',),
'saltkjøttet': ('saltkjøtt',),
'saltkoker': ('saltkoker',),
'saltkokere': ('saltkoker',),
'saltkokeren': ('saltkoker',),
'saltkokerer': ('saltkoker',),
'saltkokerne': ('saltkoker',),
'saltlake': ('saltlake',),
'saltlaken': ('saltlake',),
'saltlakene': ('saltlake',),
'saltlaker': ('saltlake',),
'saltløsning': ('saltløsning',),
'saltløsninga': ('saltløsning',),
'saltløsningen': ('saltløsning',),
'saltløsningene': ('saltløsning',),
'saltløsninger': ('saltløsning',),
'saltmat': ('saltmat',),
'saltmaten': ('saltmat',),
'saltmatene': ('saltmat',),
'saltmater': ('saltmat',),
'salto': ('salto',),
'saltoen': ('salto',),
'saltoene': ('salto',),
'saltoer': ('salto',),
'saltomortale': ('saltomortale',),
'saltomortalen': ('saltomortale',),
'saltomortalene': ('saltomortale',),
'saltomortaler': ('saltomortale',),
'saltoppløsning': ('saltoppløsning',),
'saltoppløsninga': ('saltoppløsning',),
'saltoppløsningen': ('saltoppløsning',),
'saltoppløsningene': ('saltoppløsning',),
'saltoppløsninger': ('saltoppløsning',),
'saltsild': ('saltsild',),
'saltsilda': ('saltsild',),
'saltsilden': ('saltsild',),
'saltsildene': ('saltsild',),
'saltsilder': ('saltsild',),
'saltstein': ('saltstein',),
'saltsteinen': ('saltstein',),
'saltsteinene': ('saltstein',),
'saltsteiner': ('saltstein',),
'saltstøtta': ('saltstøtte',),
'saltstøtte': ('saltstøtte',),
'saltstøtten': ('saltstøtte',),
'saltstøttene': ('saltstøtte',),
'saltstøtter': ('saltstøtte',),
'saltsyra': ('saltsyre',),
'saltsyre': ('saltsyre',),
'saltsyren': ('saltsyre',),
'saltsyrene': ('saltsyre',),
'saltsyrer': ('saltsyre',),
'saltvann': ('saltvann',),
'saltvanna': ('saltvann',),
'saltvannene': ('saltvann',),
'saltvannet': ('saltvann',),
'saltvatn': ('saltvatn',),
'saltvatna': ('saltvatn',),
'saltvatnene': ('saltvatn',),
'saltvatnet': ('saltvatn',),
'salutt': ('salutt',),
'salutten': ('salutt',),
'saluttene': ('salutt',),
'salutter': ('salutt',),
'salvadoraner': ('salvadoraner',),
'salvadoranere': ('salvadoraner',),
'salvadoraneren': ('salvadoraner',),
'salvadoranerer': ('salvadoraner',),
'salvadoranerne': ('salvadoraner',),
'salvarsan': ('salvarsan',),
'salvarsana': ('salvarsan',),
'salvarsanene': ('salvarsan',),
'salvarsanet': ('salvarsan',),
'salvasjonist': ('salvasjonist',),
'salvasjonisten': ('salvasjonist',),
'salvasjonistene': ('salvasjonist',),
'salvasjonister': ('salvasjonist',),
'salva': ('salve',),
'salve': ('salve',),
'salven': ('salve',),
'salvene': ('salve',),
'salver': ('salve',),
'salva': ('salve',),
'salve': ('salve',),
'salven': ('salve',),
'salvene': ('salve',),
'salver': ('salve',),
'salvelse': ('salvelse',),
'salvelsen': ('salvelse',),
'salvelsene': ('salvelse',),
'salvelser': ('salvelse',),
'salveska': ('salveske',),
'salveske': ('salveske',),
'salvesken': ('salveske',),
'salveskene': ('salveske',),
'salvesker': ('salveske',),
'salvie': ('salvie',),
'salvien': ('salvie',),
'salviene': ('salvie',),
'salvier': ('salvie',),
'salviete': ('salviete',),
'salvieteen': ('salviete',),
'salvieteene': ('salviete',),
'salvieteer': ('salviete',),
'salving': ('salving',),
'salvinga': ('salving',),
'salvingen': ('salving',),
'salvingene': ('salving',),
'salvinger': ('salving',),
'salvingsakt': ('salvingsakt',),
'salvingsakta': ('salvingsakt',),
'salvingsakten': ('salvingsakt',),
'salvingsaktene': ('salvingsakt',),
'salvingsakter': ('salvingsakt',),
'salær': ('salær',),
'salæra': ('salær',),
'salærene': ('salær',),
'salærer': ('salær',),
'salæret': ('salær',),
'samarbeid': ('samarbeid',),
'samarbeida': ('samarbeid',),
'samarbeidene': ('samarbeid',),
'samarbeider': ('samarbeid',),
'samarbeidet': ('samarbeid',),
'samarbeidsutvalg': ('samarbeidsutvalg',),
'samarbeidsutvalga': ('samarbeidsutvalg',),
'samarbeidsutvalgene': ('samarbeidsutvalg',),
'samarbeidsutvalget': ('samarbeidsutvalg',),
'samarie': ('samarie',),
'samarien': ('samarie',),
'samariene': ('samarie',),
'samarier': ('samarie',),
'samaritan': ('samaritan',),
'samaritanen': ('samaritan',),
'samaritanene': ('samaritan',),
'samaritaner': ('samaritan',),
'samaritt': ('samaritt',),
'samaritten': ('samaritt',),
'samarittene': ('samaritt',),
'samaritter': ('samaritt',),
'samarium': ('samarium',),
'samariuma': ('samarium',),
'samariumene': ('samarium',),
'samariumet': ('samarium',),
'samarskitt': ('samarskitt',),
'samarskitten': ('samarskitt',),
'samarskittene': ('samarskitt',),
'samarskitter': ('samarskitt',),
'samba': ('samba',),
'sambaen': ('samba',),
'sambaene': ('samba',),
'sambaer': ('samba',),
'samband': ('samband',),
'sambanda': ('samband',),
'sambandene': ('samband',),
'sambandet': ('samband',),
'sambandsoffiser': ('sambandsoffiser',),
'sambandsoffiseren': ('sambandsoffiser',),
'sambandsoffiserene': ('sambandsoffiser',),
'sambandsoffiserer': ('sambandsoffiser',),
'sambandssatellitt': ('sambandssatellitt',),
'sambandssatellitten': ('sambandssatellitt',),
'sambandssatellittene': ('sambandssatellitt',),
'sambandssatellitter': ('sambandssatellitt',),
'sambandstjeneste': ('sambandstjeneste',),
'sambandstjenesten': ('sambandstjeneste',),
'sambandstjenestene': ('sambandstjeneste',),
'sambandstjenester': ('sambandstjeneste',),
'sambandstropp': ('sambandstropp',),
'sambandstroppen': ('sambandstropp',),
'sambandstroppene': ('sambandstropp',),
'sambandstropper': ('sambandstropp',),
'sambinding': ('sambinding',),
'sambindinga': ('sambinding',),
'sambindingen': ('sambinding',),
'sambindingene': ('sambinding',),
'sambindinger': ('sambinding',),
'sambo': ('sambo',),
'samboen': ('sambo',),
'samboene': ('sambo',),
'samboer': ('sambo',),
'samboer': ('samboer',),
'samboere': ('samboer',),
'samboeren': ('samboer',),
'samboerer': ('samboer',),
'samboerne': ('samboer',),
'samboerskap': ('samboerskap',),
'samboerskapa': ('samboerskap',),
'samboerskapene': ('samboerskap',),
'samboerskapet': ('samboerskap',),
'sambruk': ('sambruk',),
'sambruka': ('sambruk',),
'sambruket': ('sambruk',),
'sambuer': ('sambuer',),
'sambuere': ('sambuer',),
'sambueren': ('sambuer',),
'sambuerer': ('sambuer',),
'sambuerne': ('sambuer',),
'sambuerskap': ('sambuerskap',),
'sambuerskapa': ('sambuerskap',),
'sambuerskapene': ('sambuerskap',),
'sambuerskapet': ('sambuerskap',),
'sambygding': ('sambygding',),
'sambygdingen': ('sambygding',),
'sambygdingene': ('sambygding',),
'sambygdinger': ('sambygding',),
'samdrektighet': ('samdrektighet',),
'samdrektigheta': ('samdrektighet',),
'samdrektigheten': ('samdrektighet',),
'samdrektighetene': ('samdrektighet',),
'samdrektigheter': ('samdrektighet',),
'samdrift': ('samdrift',),
'samdrifta': ('samdrift',),
'samdriften': ('samdrift',),
'samdriftene': ('samdrift',),
'samdrifter': ('samdrift',),
'same': ('same',),
'samen': ('same',),
'samene': ('same',),
'samer': ('same',),
'samedrakt': ('samedrakt',),
'samedrakta': ('samedrakt',),
'samedrakten': ('samedrakt',),
'samedraktene': ('samedrakt',),
'samedrakter': ('samedrakt',),
'sameia': ('sameie',),
'sameie': ('sameie',),
'sameiene': ('sameie',),
'sameier': ('sameie',),
'sameiet': ('sameie',),
'sameksistens': ('sameksistens',),
'sameksistensen': ('sameksistens',),
'sameksistensene': ('sameksistens',),
'sameksistenser': ('sameksistens',),
'sameleir': ('sameleir',),
'sameleiren': ('sameleir',),
'sameleirene': ('sameleir',),
'sameleirer': ('sameleir',),
'sametelt': ('sametelt',),
'sametelta': ('sametelt',),
'sameteltene': ('sametelt',),
'sametelter': ('sametelt',),
'sameteltet': ('sametelt',),
'sameting': ('sameting',),
'sametinga': ('sameting',),
'sametingene': ('sameting',),
'sametinget': ('sameting',),
'samferdsel': ('samferdsel',),
'samferdselen': ('samferdsel',),
'samferdsla': ('samferdsel',),
'samferdslene': ('samferdsel',),
'samferdsler': ('samferdsel',),
'samferdselsdepartement': ('samferdselsdepartement',),
'samferdselsdepartementa': ('samferdselsdepartement',),
'samferdselsdepartementene': ('samferdselsdepartement',),
'samferdselsdepartementer': ('samferdselsdepartement',),
'samferdselsdepartementet': ('samferdselsdepartement',),
'samferdselsmiddel': ('samferdselsmiddel',),
'samferdselsmiddelet': ('samferdselsmiddel',),
'samferdselsmidla': ('samferdselsmiddel',),
'samferdselsmidlene': ('samferdselsmiddel',),
'samferdselsmidler': ('samferdselsmiddel',),
'samferdselsmidlet': ('samferdselsmiddel',),
'samfunn': ('samfunn',),
'samfunna': ('samfunn',),
'samfunnene': ('samfunn',),
'samfunnet': ('samfunn',),
'samfunnsborger': ('samfunnsborger',),
'samfunnsborgere': ('samfunnsborger',),
'samfunnsborgeren': ('samfunnsborger',),
'samfunnsborgerer': ('samfunnsborger',),
'samfunnsborgerne': ('samfunnsborger',),
'samfunnsfag': ('samfunnsfag',),
'samfunnsfaga': ('samfunnsfag',),
'samfunnsfagene': ('samfunnsfag',),
'samfunnsfaget': ('samfunnsfag',),
'samfunnsfiende': ('samfunnsfiende',),
'samfunnsfienden': ('samfunnsfiende',),
'samfunnsfiendene': ('samfunnsfiende',),
'samfunnsfiender': ('samfunnsfiende',),
'samfunnsforskning': ('samfunnsforskning',),
'samfunnsforskninga': ('samfunnsforskning',),
'samfunnsforskningen': ('samfunnsforskning',),
'samfunnsforskningene': ('samfunnsforskning',),
'samfunnsforskninger': ('samfunnsforskning',),
'samfunnsgoda': ('samfunnsgode',),
'samfunnsgode': ('samfunnsgode',),
'samfunnsgodene': ('samfunnsgode',),
'samfunnsgoder': ('samfunnsgode',),
'samfunnsgodet': ('samfunnsgode',),
'samfunnshus': ('samfunnshus',),
'samfunnshusa': ('samfunnshus',),
'samfunnshusene': ('samfunnshus',),
'samfunnshuset': ('samfunnshus',),
'samfunnsklassa': ('samfunnsklasse',),
'samfunnsklasse': ('samfunnsklasse',),
'samfunnsklassen': ('samfunnsklasse',),
'samfunnsklassene': ('samfunnsklasse',),
'samfunnsklasser': ('samfunnsklasse',),
'samfunnskunnskap': ('samfunnskunnskap',),
'samfunnskunnskapen': ('samfunnskunnskap',),
'samfunnskunnskapene': ('samfunnskunnskap',),
'samfunnskunnskaper': ('samfunnskunnskap',),
'samfunnslag': ('samfunnslag',),
'samfunnslaga': ('samfunnslag',),
'samfunnslagene': ('samfunnslag',),
'samfunnslaget': ('samfunnslag',),
'samfunnslinja': ('samfunnslinje',),
'samfunnslinje': ('samfunnslinje',),
'samfunnslinjen': ('samfunnslinje',),
'samfunnslinjene': ('samfunnslinje',),
'samfunnslinjer': ('samfunnslinje',),
'samfunnslæra': ('samfunnslære',),
'samfunnslære': ('samfunnslære',),
'samfunnslæren': ('samfunnslære',),
'samfunnslærene': ('samfunnslære',),
'samfunnslærer': ('samfunnslære',),
'samfunnsmoral': ('samfunnsmoral',),
'samfunnsmoralen': ('samfunnsmoral',),
'samfunnsmoralene': ('samfunnsmoral',),
'samfunnsmoraler': ('samfunnsmoral',),
'samfunnsorden': ('samfunnsorden',),
'samfunnsordenen': ('samfunnsorden',),
'samfunnsordenene': ('samfunnsorden',),
'samfunnsordener': ('samfunnsorden',),
'samfunnsordning': ('samfunnsordning',),
'samfunnsordninga': ('samfunnsordning',),
'samfunnsordningen': ('samfunnsordning',),
'samfunnsordningene': ('samfunnsordning',),
'samfunnsordninger': ('samfunnsordning',),
'samfunnsplikt': ('samfunnsplikt',),
'samfunnsplikta': ('samfunnsplikt',),
'samfunnsplikten': ('samfunnsplikt',),
'samfunnspliktene': ('samfunnsplikt',),
'samfunnsplikter': ('samfunnsplikt',),
'samfunnsregning': ('samfunnsregning',),
'samfunnsregninga': ('samfunnsregning',),
'samfunnsregningen': ('samfunnsregning',),
'samfunnsregningene': ('samfunnsregning',),
'samfunnsregninger': ('samfunnsregning',),
'samfunnsrekning': ('samfunnsrekning',),
'samfunnsrekninga': ('samfunnsrekning',),
'samfunnsrekningen': ('samfunnsrekning',),
'samfunnsrekningene': ('samfunnsrekning',),
'samfunnsrekninger': ('samfunnsrekning',),
'samfunnsspørsmål': ('samfunnsspørsmål',),
'samfunnsspørsmåla': ('samfunnsspørsmål',),
'samfunnsspørsmålene': ('samfunnsspørsmål',),
'samfunnsspørsmålet': ('samfunnsspørsmål',),
'samfunnsstormer': ('samfunnsstormer',),
'samfunnsstormere': ('samfunnsstormer',),
'samfunnsstormeren': ('samfunnsstormer',),
'samfunnsstormerer': ('samfunnsstormer',),
'samfunnsstormerne': ('samfunnsstormer',),
'samfunnsstøtta': ('samfunnsstøtte',),
'samfunnsstøtte': ('samfunnsstøtte',),
'samfunnsstøtten': ('samfunnsstøtte',),
'samfunnsstøttene': ('samfunnsstøtte',),
'samfunnsstøtter': ('samfunnsstøtte',),
'samfunnstjeneste': ('samfunnstjeneste',),
'samfunnstjenesten': ('samfunnstjeneste',),
'samfunnstjenestene': ('samfunnstjeneste',),
'samfunnstjenester': ('samfunnstjeneste',),
'samfunnsvitenskap': ('samfunnsvitenskap',),
'samfunnsvitenskapen': ('samfunnsvitenskap',),
'samfunnsvitenskapene': ('samfunnsvitenskap',),
'samfunnsvitenskaper': ('samfunnsvitenskap',),
'samfunnsviter': ('samfunnsviter',),
'samfunnsvitere': ('samfunnsviter',),
'samfunnsviteren': ('samfunnsviter',),
'samfunnsviterer': ('samfunnsviter',),
'samfunnsviterne': ('samfunnsviter',),
'samfunnsvitskap': ('samfunnsvitskap',),
'samfunnsvitskapen': ('samfunnsvitskap',),
'samfunnsvitskapene': ('samfunnsvitskap',),
'samfunnsvitskaper': ('samfunnsvitskap',),
'samfunnsånd': ('samfunnsånd',),
'samfunnsånden': ('samfunnsånd',),
'samfunnsåndene': ('samfunnsånd',),
'samfunnsånder': ('samfunnsånd',),
'samfølelse': ('samfølelse',),
'samfølelsen': ('samfølelse',),
'samfølelsene': ('samfølelse',),
'samfølelser': ('samfølelse',),
'samhandel': ('samhandel',),
'samhandelen': ('samhandel',),
'samhandlene': ('samhandel',),
'samhandler': ('samhandel',),
'samhandling': ('samhandling',),
'samhandlinga': ('samhandling',),
'samhandlingen': ('samhandling',),
'samhandlingene': ('samhandling',),
'samhandlinger': ('samhandling',),
'samhold': ('samhold',),
'samholda': ('samhold',),
'samholdene': ('samhold',),
'samholdet': ('samhold',),
'samhug': ('samhug',),
'samhugen': ('samhug',),
'samhugene': ('samhug',),
'samhuger': ('samhug',),
'samhørighet': ('samhørighet',),
'samhørigheta': ('samhørighet',),
'samhørigheten': ('samhørighet',),
'samhørighetene': ('samhørighet',),
'samhørigheter': ('samhørighet',),
'samisk': ('samisk',),
'samisken': ('samisk',),
'samiskene': ('samisk',),
'samisker': ('samisk',),
'samkjensla': ('samkjensle',),
'samkjensle': ('samkjensle',),
'samkjenslen': ('samkjensle',),
'samkjenslene': ('samkjensle',),
'samkjensler': ('samkjensle',),
'samkjøring': ('samkjøring',),
'samkjøringa': ('samkjøring',),
'samkjøringen': ('samkjøring',),
'samkjøringene': ('samkjøring',),
'samkjøringer': ('samkjøring',),
'samklang': ('samklang',),
'samklangen': ('samklang',),
'samklangene': ('samklang',),
'samklanger': ('samklang',),
'samkoma': ('samkome',),
'samkome': ('samkome',),
'samkomen': ('samkome',),
'samkomene': ('samkome',),
'samkomer': ('samkome',),
'samkomma': ('samkomme',),
'samkomme': ('samkomme',),
'samkommen': ('samkomme',),
'samkommene': ('samkomme',),
'samkommer': ('samkomme',),
'samkvem': ('samkvem',),
'samkvemma': ('samkvem',),
'samkvemmene': ('samkvem',),
'samkvemmet': ('samkvem',),
'samlag': ('samlag',),
'samlaga': ('samlag',),
'samlagene': ('samlag',),
'samlaget': ('samlag',),
'samlast': ('samlast',),
'samlasta': ('samlast',),
'samlasten': ('samlast',),
'samlastene': ('samlast',),
'samlaster': ('samlast',),
'samlasting': ('samlasting',),
'samlastingen': ('samlasting',),
'samlastingene': ('samlasting',),
'samlastinger': ('samlasting',),
'samleband': ('samleband',),
'samlebanda': ('samleband',),
'samlebandene': ('samleband',),
'samlebandet': ('samleband',),
'samlebegrep': ('samlebegrep',),
'samlebegrepa': ('samlebegrep',),
'samlebegrepene': ('samlebegrep',),
'samlebegreper': ('samlebegrep',),
'samlebegrepet': ('samlebegrep',),
'samlebetegnelse': ('samlebetegnelse',),
'samlebetegnelsen': ('samlebetegnelse',),
'samlebetegnelsene': ('samlebetegnelse',),
'samlebetegnelser': ('samlebetegnelse',),
'samlebånd': ('samlebånd',),
'samlebånda': ('samlebånd',),
'samlebåndene': ('samlebånd',),
'samlebåndet': ('samlebånd',),
'samlegymnas': ('samlegymnas',),
'samlegymnasa': ('samlegymnas',),
'samlegymnasene': ('samlegymnas',),
'samlegymnaser': ('samlegymnas',),
'samlegymnaset': ('samlegymnas',),
'samleia': ('samleie',),
'samleie': ('samleie',),
'samleiene': ('samleie',),
'samleier': ('samleie',),
'samleiet': ('samleie',),
'samlelinsa': ('samlelinse',),
'samlelinse': ('samlelinse',),
'samlelinsen': ('samlelinse',),
'samlelinsene': ('samlelinse',),
'samlelinser': ('samlelinse',),
'samler': ('samler',),
'samlere': ('samler',),
'samleren': ('samler',),
'samlerer': ('samler',),
'samlerne': ('samler',),
'samleveg': ('samleveg',),
'samlevegen': ('samleveg',),
'samlevegene': ('samleveg',),
'samleveger': ('samleveg',),
'samlevei': ('samlevei',),
'samleveien': ('samlevei',),
'samleveiene': ('samlevei',),
'samleveier': ('samlevei',),
'samling': ('samling',),
'samlinga': ('samling',),
'samlingen': ('samling',),
'samlingene': ('samling',),
'samlinger': ('samling',),
'samlingsmerka': ('samlingsmerke',),
'samlingsmerke': ('samlingsmerke',),
'samlingsmerkene': ('samlingsmerke',),
'samlingsmerker': ('samlingsmerke',),
'samlingsmerket': ('samlingsmerke',),
'samlingsregjering': ('samlingsregjering',),
'samlingsregjeringa': ('samlingsregjering',),
'samlingsregjeringen': ('samlingsregjering',),
'samlingsregjeringene': ('samlingsregjering',),
'samlingsregjeringer': ('samlingsregjering',),
'samlingssted': ('samlingssted',),
'samlingsstedene': ('samlingssted',),
'samlingssteder': ('samlingssted',),
'samlingsstedet': ('samlingssted',),
'samliv': ('samliv',),
'samliva': ('samliv',),
'samlivene': ('samliv',),
'samlivet': ('samliv',),
'samlivsform': ('samlivsform',),
'samlivsforma': ('samlivsform',),
'samlivsformen': ('samlivsform',),
'samlivsformene': ('samlivsform',),
'samlivsformer': ('samlivsform',),
'samlivsundervisning': ('samlivsundervisning',),
'samlivsundervisninga': ('samlivsundervisning',),
'samlivsundervisningen': ('samlivsundervisning',),
'samlivsundervisningene': ('samlivsundervisning',),
'samlivsundervisninger': ('samlivsundervisning',),
'samløp': ('samløp',),
'samløpa': ('samløp',),
'samløpene': ('samløp',),
'samløpet': ('samløp',),
'sammenblanding': ('sammenblanding',),
'sammenblandinga': ('sammenblanding',),
'sammenblandingen': ('sammenblanding',),
'sammenblandingene': ('sammenblanding',),
'sammenblandinger': ('sammenblanding',),
'sammenbrott': ('sammenbrott',),
'sammenbrotta': ('sammenbrott',),
'sammenbrottene': ('sammenbrott',),
'sammenbrottet': ('sammenbrott',),
'sammenbrudd': ('sammenbrudd',),
'sammenbrudda': ('sammenbrudd',),
'sammenbruddene': ('sammenbrudd',),
'sammenbruddet': ('sammenbrudd',),
'sammendrag': ('sammendrag',),
'sammendraga': ('sammendrag',),
'sammendragene': ('sammendrag',),
'sammendraget': ('sammendrag',),
'sammenfall': ('sammenfall',),
'sammenfalla': ('sammenfall',),
'sammenfallene': ('sammenfall',),
'sammenfallet': ('sammenfall',),
'sammenføyning': ('sammenføyning',),
'sammenføyninga': ('sammenføyning',),
'sammenføyningen': ('sammenføyning',),
'sammenføyningene': ('sammenføyning',),
'sammenføyninger': ('sammenføyning',),
'sammenheng': ('sammenheng',),
'sammenhengen': ('sammenheng',),
'sammenhengene': ('sammenheng',),
'sammenhenger': ('sammenheng',),
'sammenkok': ('sammenkok',),
'sammenkoka': ('sammenkok',),
'sammenkokene': ('sammenkok',),
'sammenkoket': ('sammenkok',),
'sammenkomst': ('sammenkomst',),
'sammenkomsten': ('sammenkomst',),
'sammenkomstene': ('sammenkomst',),
'sammenkomster': ('sammenkomst',),
'sammenligning': ('sammenligning',),
'sammenligninga': ('sammenligning',),
'sammenligningen': ('sammenligning',),
'sammenligningene': ('sammenligning',),
'sammenligninger': ('sammenligning',),
'sammenligningskonjunksjon': ('sammenligningskonjunksjon',),
'sammenligningskonjunksjonen': ('sammenligningskonjunksjon',),
'sammenligningskonjunksjonene': ('sammenligningskonjunksjon',),
'sammenligningskonjunksjoner': ('sammenligningskonjunksjon',),
'sammenligningsledd': ('sammenligningsledd',),
'sammenligningsledda': ('sammenligningsledd',),
'sammenligningsleddene': ('sammenligningsledd',),
'sammenligningsleddet': ('sammenligningsledd',),
'sammenligningssetning': ('sammenligningssetning',),
'sammenligningssetninga': ('sammenligningssetning',),
'sammenligningssetningen': ('sammenligningssetning',),
'sammenligningssetningene': ('sammenligningssetning',),
'sammenligningssetninger': ('sammenligningssetning',),
'sammenlikning': ('sammenlikning',),
'sammenlikninga': ('sammenlikning',),
'sammenlikningen': ('sammenlikning',),
'sammenlikningene': ('sammenlikning',),
'sammenlikninger': ('sammenlikning',),
'sammenlikningskonjunksjon': ('sammenlikningskonjunksjon',),
'sammenlikningskonjunksjonen': ('sammenlikningskonjunksjon',),
'sammenlikningskonjunksjonene': ('sammenlikningskonjunksjon',),
'sammenlikningskonjunksjoner': ('sammenlikningskonjunksjon',),
'sammenlikningsledd': ('sammenlikningsledd',),
'sammenlikningsledda': ('sammenlikningsledd',),
'sammenlikningsleddene': ('sammenlikningsledd',),
'sammenlikningsleddet': ('sammenlikningsledd',),
'sammenlikningssetning': ('sammenlikningssetning',),
'sammenlikningssetninga': ('sammenlikningssetning',),
'sammenlikningssetningen': ('sammenlikningssetning',),
'sammenlikningssetningene': ('sammenlikningssetning',),
'sammenlikningssetninger': ('sammenlikningssetning',),
'sammenløp': ('sammenløp',),
'sammenløpa': ('sammenløp',),
'sammenløpene': ('sammenløp',),
'sammenløpet': ('sammenløp',),
'sammensetning': ('sammensetning',),
'sammensetninga': ('sammensetning',),
'sammensetningen': ('sammensetning',),
'sammensetningene': ('sammensetning',),
'sammensetninger': ('sammensetning',),
'sammensetningsledd': ('sammensetningsledd',),
'sammensetningsledda': ('sammensetningsledd',),
'sammensetningsleddene': ('sammensetningsledd',),
'sammensetningsleddet': ('sammensetningsledd',),
'sammenskott': ('sammenskott',),
'sammenskotta': ('sammenskott',),
'sammenskottene': ('sammenskott',),
'sammenskottet': ('sammenskott',),
'sammenskottsfest': ('sammenskottsfest',),
'sammenskottsfesten': ('sammenskottsfest',),
'sammenskottsfestene': ('sammenskottsfest',),
'sammenskottsfester': ('sammenskottsfest',),
'sammenskriving': ('sammenskriving',),
'sammenskrivinga': ('sammenskriving',),
'sammenskrivingen': ('sammenskriving',),
'sammenskrivingene': ('sammenskriving',),
'sammenskrivinger': ('sammenskriving',),
'sammenskrivning': ('sammenskrivning',),
'sammenskrivninga': ('sammenskrivning',),
'sammenskrivningen': ('sammenskrivning',),
'sammenskrivningene': ('sammenskrivning',),
'sammenskrivninger': ('sammenskrivning',),
'sammenskudd': ('sammenskudd',),
'sammenskudda': ('sammenskudd',),
'sammenskuddene': ('sammenskudd',),
'sammenskuddet': ('sammenskudd',),
'sammenskuddsfest': ('sammenskuddsfest',),
'sammenskuddsfesten': ('sammenskuddsfest',),
'sammenskuddsfestene': ('sammenskuddsfest',),
'sammenskuddsfester': ('sammenskuddsfest',),
'sammenslutning': ('sammenslutning',),
'sammenslutninga': ('sammenslutning',),
'sammenslutningen': ('sammenslutning',),
'sammenslutningene': ('sammenslutning',),
'sammenslutninger': ('sammenslutning',),
'sammenslåing': ('sammenslåing',),
'sammenslåinga': ('sammenslåing',),
'sammenslåingen': ('sammenslåing',),
'sammenslåingene': ('sammenslåing',),
'sammenslåinger': ('sammenslåing',),
'sammenstimling': ('sammenstimling',),
'sammenstimlinga': ('sammenstimling',),
'sammenstimlingen': ('sammenstimling',),
'sammenstimlingene': ('sammenstimling',),
'sammenstimlinger': ('sammenstimling',),
'sammenstøt': ('sammenstøt',),
'sammenstøta': ('sammenstøt',),
'sammenstøtene': ('sammenstøt',),
'sammenstøtet': ('sammenstøt',),
'sammenstøyt': ('sammenstøyt',),
'sammenstøyten': ('sammenstøyt',),
'sammenstøytene': ('sammenstøyt',),
'sammenstøyter': ('sammenstøyt',),
'sammensuria': ('sammensurium',),
'sammensuriene': ('sammensurium',),
'sammensurier': ('sammensurium',),
'sammensuriet': ('sammensurium',),
'sammensurium': ('sammensurium',),
'sammensvergelse': ('sammensvergelse',),
'sammensvergelsen': ('sammensvergelse',),
'sammensvergelsene': ('sammensvergelse',),
'sammensvergelser': ('sammensvergelse',),
'sammensverjing': ('sammensverjing',),
'sammensverjinga': ('sammensverjing',),
'sammensverjingen': ('sammensverjing',),
'sammensverjingene': ('sammensverjing',),
'sammensverjinger': ('sammensverjing',),
'sammentreff': ('sammentreff',),
'sammentreffa': ('sammentreff',),
'sammentreffene': ('sammentreff',),
'sammentreffet': ('sammentreff',),
'sammentrekning': ('sammentrekning',),
'sammentrekninga': ('sammentrekning',),
'sammentrekningen': ('sammentrekning',),
'sammentrekningene': ('sammentrekning',),
'sammentrekninger': ('sammentrekning',),
'samnavn': ('samnavn',),
'samnavna': ('samnavn',),
'samnavnene': ('samnavn',),
'samnavnet': ('samnavn',),
'samnorsk': ('samnorsk',),
'samnorsken': ('samnorsk',),
'samnorskene': ('samnorsk',),
'samnorsker': ('samnorsk',),
'samoaner': ('samoaner',),
'samoanere': ('samoaner',),
'samoaneren': ('samoaner',),
'samoanerer': ('samoaner',),
'samoanerne': ('samoaner',),
'samojed': ('samojed',),
'samojeden': ('samojed',),
'samojedene': ('samojed',),
'samojeder': ('samojed',),
'samojedhund': ('samojedhund',),
'samojedhunden': ('samojedhund',),
'samojedhundene': ('samojedhund',),
'samojedhunder': ('samojedhund',),
'samordning': ('samordning',),
'samordninga': ('samordning',),
'samordningen': ('samordning',),
'samordningene': ('samordning',),
'samordninger': ('samordning',),
'samorganisasjon': ('samorganisasjon',),
'samorganisasjonen': ('samorganisasjon',),
'samorganisasjonene': ('samorganisasjon',),
'samorganisasjoner': ('samorganisasjon',),
'samovar': ('samovar',),
'samovaren': ('samovar',),
'samovarene': ('samovar',),
'samovarer': ('samovar',),
'sampan': ('sampan',),
'sampanen': ('sampan',),
'sampanene': ('sampan',),
'sampaner': ('sampan',),
'sampel': ('sampel',),
'sampelet': ('sampel',),
'sampla': ('sampel',),
'samplene': ('sampel',),
'sampler': ('sampel',),
'samplet': ('sampel',),
'sampla': ('sample',),
'sample': ('sample',),
'samplene': ('sample',),
'sampler': ('sample',),
'samplet': ('sample',),
'sampler': ('sampler',),
'samplere': ('sampler',),
'sampleren': ('sampler',),
'samplerer': ('sampler',),
'samplerne': ('sampler',),
'sampling': ('sampling',),
'samplinga': ('sampling',),
'samplingen': ('sampling',),
'samplingene': ('sampling',),
'samplinger': ('sampling',),
'samproduksjon': ('samproduksjon',),
'samproduksjonen': ('samproduksjon',),
'samproduksjonene': ('samproduksjon',),
'samproduksjoner': ('samproduksjon',),
'samråd': ('samråd',),
'samråda': ('samråd',),
'samrådene': ('samråd',),
'samrådet': ('samråd',),
'samrøra': ('samrøre',),
'samrøre': ('samrøre',),
'samrørene': ('samrøre',),
'samrører': ('samrøre',),
'samrøret': ('samrøre',),
'samrøring': ('samrøring',),
'samrøringa': ('samrøring',),
'samrøringen': ('samrøring',),
'samrøringene': ('samrøring',),
'samrøringer': ('samrøring',),
'samsending': ('samsending',),
'samsendinga': ('samsending',),
'samsendingen': ('samsending',),
'samsendingene': ('samsending',),
'samsendinger': ('samsending',),
'samskatt': ('samskatt',),
'samskatten': ('samskatt',),
'samskattene': ('samskatt',),
'samskatter': ('samskatt',),
'samskipnad': ('samskipnad',),
'samskipnaden': ('samskipnad',),
'samskipnadene': ('samskipnad',),
'samskipnader': ('samskipnad',),
'samspell': ('samspell',),
'samspella': ('samspell',),
'samspellene': ('samspell',),
'samspellet': ('samspell',),
'samspill': ('samspill',),
'samspilla': ('samspill',),
'samspillene': ('samspill',),
'samspillet': ('samspill',),
'samstemmighet': ('samstemmighet',),
'samstemmigheta': ('samstemmighet',),
'samstemmigheten': ('samstemmighet',),
'samstemmighetene': ('samstemmighet',),
'samstemmigheter': ('samstemmighet',),
'samsvar': ('samsvar',),
'samsvara': ('samsvar',),
'samsvarene': ('samsvar',),
'samsvaret': ('samsvar',),
'samsvarbøying': ('samsvarbøying',),
'samsvarbøyinga': ('samsvarbøying',),
'samsvarbøyingen': ('samsvarbøying',),
'samsvarbøyingene': ('samsvarbøying',),
'samsvarbøyinger': ('samsvarbøying',),
'samsvarbøyning': ('samsvarbøyning',),
'samsvarbøyninga': ('samsvarbøyning',),
'samsvarbøyningen': ('samsvarbøyning',),
'samsvarbøyningene': ('samsvarbøyning',),
'samsvarbøyninger': ('samsvarbøyning',),
'samsvarsbøying': ('samsvarsbøying',),
'samsvarsbøyinga': ('samsvarsbøying',),
'samsvarsbøyingen': ('samsvarsbøying',),
'samsvarsbøyingene': ('samsvarsbøying',),
'samsvarsbøyinger': ('samsvarsbøying',),
'samsvarsbøyning': ('samsvarsbøyning',),
'samsvarsbøyninga': ('samsvarsbøyning',),
'samsvarsbøyningen': ('samsvarsbøyning',),
'samsvarsbøyningene': ('samsvarsbøyning',),
'samsvarsbøyninger': ('samsvarsbøyning',),
'samsyn': ('samsyn',),
'samsyna': ('samsyn',),
'samsynene': ('samsyn',),
'samsyner': ('samsyn',),
'samsynet': ('samsyn',),
'samtale': ('samtale',),
'samtalen': ('samtale',),
'samtalene': ('samtale',),
'samtaler': ('samtale',),
'samtaleemna': ('samtaleemne',),
'samtaleemne': ('samtaleemne',),
'samtaleemnene': ('samtaleemne',),
'samtaleemner': ('samtaleemne',),
'samtaleemnet': ('samtaleemne',),
'samtid': ('samtid',),
'samtida': ('samtid',),
'samtiden': ('samtid',),
'samtidene': ('samtid',),
'samtider': ('samtid',),
'samtidshistoria': ('samtidshistorie',),
'samtidshistorie': ('samtidshistorie',),
'samtidshistorien': ('samtidshistorie',),
'samtidshistoriene': ('samtidshistorie',),
'samtidshistorier': ('samtidshistorie',),
'samtidskunnskap': ('samtidskunnskap',),
'samtidskunnskapen': ('samtidskunnskap',),
'samtidskunnskapene': ('samtidskunnskap',),
'samtidskunnskaper': ('samtidskunnskap',),
'samtykka': ('samtykke',),
'samtykke': ('samtykke',),
'samtykkene': ('samtykke',),
'samtykker': ('samtykke',),
'samtykket': ('samtykke',),
'samurai': ('samurai',),
'samuraien': ('samurai',),
'samuraiene': ('samurai',),
'samuraier': ('samurai',),
'samvelda': ('samvelde',),
'samvelde': ('samvelde',),
'samveldene': ('samvelde',),
'samvelder': ('samvelde',),
'samveldet': ('samvelde',),
'samvett': ('samvett',),
'samvetta': ('samvett',),
'samvettene': ('samvett',),
'samvettet': ('samvett',),
'samvirka': ('samvirke',),
'samvirke': ('samvirke',),
'samvirkene': ('samvirke',),
'samvirker': ('samvirke',),
'samvirket': ('samvirke',),
'samvirkelag': ('samvirkelag',),
'samvirkelaga': ('samvirkelag',),
'samvirkelagene': ('samvirkelag',),
'samvirkelaget': ('samvirkelag',),
'samvittighet': ('samvittighet',),
'samvittigheta': ('samvittighet',),
'samvittigheten': ('samvittighet',),
'samvittighetene': ('samvittighet',),
'samvittigheter': ('samvittighet',),
'samvittighetsekteskap': ('samvittighetsekteskap',),
'samvittighetsekteskapa': ('samvittighetsekteskap',),
'samvittighetsekteskapene': ('samvittighetsekteskap',),
'samvittighetsekteskaper': ('samvittighetsekteskap',),
'samvittighetsekteskapet': ('samvittighetsekteskap',),
'samvittighetsfange': ('samvittighetsfange',),
'samvittighetsfangen': ('samvittighetsfange',),
'samvittighetsfangene': ('samvittighetsfange',),
'samvittighetsfanger': ('samvittighetsfange',),
'samvittighetsnag': ('samvittighetsnag',),
'samvittighetsnaga': ('samvittighetsnag',),
'samvittighetsnagene': ('samvittighetsnag',),
'samvittighetsnaget': ('samvittighetsnag',),
'samvittighetsspørsmål': ('samvittighetsspørsmål',),
'samvittighetsspørsmåla': ('samvittighetsspørsmål',),
'samvittighetsspørsmålene': ('samvittighetsspørsmål',),
'samvittighetsspørsmålet': ('samvittighetsspørsmål',),
'samvær': ('samvær',),
'samværa': ('samvær',),
'samværene': ('samvær',),
'samværet': ('samvær',),
'samværsrett': ('samværsrett',),
'samværsretten': ('samværsrett',),
'samværsrettene': ('samværsrett',),
'samværsretter': ('samværsrett',),
'sanatorieopphold': ('sanatorieopphold',),
'sanatorieoppholda': ('sanatorieopphold',),
'sanatorieoppholdene': ('sanatorieopphold',),
'sanatorieoppholdet': ('sanatorieopphold',),
'sanatoria': ('sanatorium',),
'sanatoriene': ('sanatorium',),
'sanatorier': ('sanatorium',),
'sanatoriet': ('sanatorium',),
'sanatorium': ('sanatorium',),
'sand': ('sand',),
'sanden': ('sand',),
'sandene': ('sand',),
'sander': ('sand',),
'sandal': ('sandal',),
'sandalen': ('sandal',),
'sandalene': ('sandal',),
'sandaler': ('sandal',),
'sandbanke': ('sandbanke',),
'sandbanken': ('sandbanke',),
'sandbankene': ('sandbanke',),
'sandbanker': ('sandbanke',),
'sanddyne': ('sanddyne',),
'sanddynen': ('sanddyne',),
'sanddynene': ('sanddyne',),
'sanddyner': ('sanddyne',),
'sandel': ('sandel',),
'sandelen': ('sandel',),
'sandlene': ('sandel',),
'sandler': ('sandel',),
'sandinist': ('sandinist',),
'sandinisten': ('sandinist',),
'sandinistene': ('sandinist',),
'sandinister': ('sandinist',),
'sandjord': ('sandjord',),
'sandjorda': ('sandjord',),
'sandjorden': ('sandjord',),
'sandjordene': ('sandjord',),
'sandjorder': ('sandjord',),
'sandkaka': ('sandkake',),
'sandkake': ('sandkake',),
'sandkaken': ('sandkake',),
'sandkakene': ('sandkake',),
'sandkaker': ('sandkake',),
'sandkassa': ('sandkasse',),
'sandkasse': ('sandkasse',),
'sandkassen': ('sandkasse',),
'sandkassene': ('sandkasse',),
'sandkasser': ('sandkasse',),
'sandmel': ('sandmel',),
'sandmelen': ('sandmel',),
'sandmelene': ('sandmel',),
'sandmeler': ('sandmel',),
'sandmele': ('sandmele',),
'sandmelen': ('sandmele',),
'sandmelene': ('sandmele',),
'sandmeler': ('sandmele',),
'sandpapir': ('sandpapir',),
'sandpapira': ('sandpapir',),
'sandpapirene': ('sandpapir',),
'sandpapirer': ('sandpapir',),
'sandpapiret': ('sandpapir',),
'sandpåstrøer': ('sandpåstrøer',),
'sandpåstrøere': ('sandpåstrøer',),
'sandpåstrøeren': ('sandpåstrøer',),
'sandpåstrøerer': ('sandpåstrøer',),
'sandpåstrøerne': ('sandpåstrøer',),
'sandpåstrøing': ('sandpåstrøing',),
'sandpåstrøinga': ('sandpåstrøing',),
'sandpåstrøingen': ('sandpåstrøing',),
'sandpåstrøingene': ('sandpåstrøing',),
'sandpåstrøinger': ('sandpåstrøing',),
'sandstein': ('sandstein',),
'sandsteinen': ('sandstein',),
'sandsteinene': ('sandstein',),
'sandsteiner': ('sandstein',),
'sandstorm': ('sandstorm',),
'sandstormen': ('sandstorm',),
'sandstormene': ('sandstorm',),
'sandstormer': ('sandstorm',),
'sandtak': ('sandtak',),
'sandtaka': ('sandtak',),
'sandtakene': ('sandtak',),
'sandtaket': ('sandtak',),
'sandwich': ('sandwich',),
'sandwichen': ('sandwich',),
'sandwichene': ('sandwich',),
'sandwicher': ('sandwich',),
'sandwichelement': ('sandwichelement',),
'sandwichelementa': ('sandwichelement',),
'sandwichelementene': ('sandwichelement',),
'sandwichelementer': ('sandwichelement',),
'sandwichelementet': ('sandwichelement',),
'sandwichkonstruksjon': ('sandwichkonstruksjon',),
'sandwichkonstruksjonen': ('sandwichkonstruksjon',),
'sandwichkonstruksjonene': ('sandwichkonstruksjon',),
'sandwichkonstruksjoner': ('sandwichkonstruksjon',),
'sanering': ('sanering',),
'saneringa': ('sanering',),
'saneringen': ('sanering',),
'saneringene': ('sanering',),
'saneringer': ('sanering',),
'sang': ('sang',),
'sangen': ('sang',),
'sangene': ('sang',),
'sanger': ('sang',),
'sangdans': ('sangdans',),
'sangdansen': ('sangdans',),
'sangdansene': ('sangdans',),
'sangdanser': ('sangdans',),
'sanger': ('sanger',),
'sangere': ('sanger',),
'sangeren': ('sanger',),
'sangerer': ('sanger',),
'sangerne': ('sanger',),
'sangerinna': ('sangerinne',),
'sangerinne': ('sangerinne',),
'sangerinnen': ('sangerinne',),
'sangerinnene': ('sangerinne',),
'sangerinner': ('sangerinne',),
'sangerstemna': ('sangerstemne',),
'sangerstemne': ('sangerstemne',),
'sangerstemnen': ('sangerstemne',),
'sangerstemnene': ('sangerstemne',),
'sangerstemner': ('sangerstemne',),
'sangerstemnet': ('sangerstemne',),
'sangerstevna': ('sangerstevne',),
'sangerstevne': ('sangerstevne',),
'sangerstevnene': ('sangerstevne',),
'sangerstevner': ('sangerstevne',),
'sangerstevnet': ('sangerstevne',),
'sangforening': ('sangforening',),
'sangforeninga': ('sangforening',),
'sangforeningen': ('sangforening',),
'sangforeningene': ('sangforening',),
'sangforeninger': ('sangforening',),
'sangfugl': ('sangfugl',),
'sangfuglen': ('sangfugl',),
'sangfuglene': ('sangfugl',),
'sangfugler': ('sangfugl',),
'sangkor': ('sangkor',),
'sangkora': ('sangkor',),
'sangkorene': ('sangkor',),
'sangkoret': ('sangkor',),
'sangleik': ('sangleik',),
'sangleiken': ('sangleik',),
'sangleikene': ('sangleik',),
'sangleiker': ('sangleik',),
'sanglek': ('sanglek',),
'sangleken': ('sanglek',),
'sanglekene': ('sanglek',),
'sangleker': ('sanglek',),
'sanglerka': ('sanglerke',),
'sanglerke': ('sanglerke',),
'sanglerken': ('sanglerke',),
'sanglerkene': ('sanglerke',),
'sanglerker': ('sanglerke',),
'sanglærer': ('sanglærer',),
'sanglærere': ('sanglærer',),
'sanglæreren': ('sanglærer',),
'sanglærerer': ('sanglærer',),
'sanglærerne': ('sanglærer',),
'sangpedagog': ('sangpedagog',),
'sangpedagogen': ('sangpedagog',),
'sangpedagogene': ('sangpedagog',),
'sangpedagoger': ('sangpedagog',),
'sangria': ('sangria',),
'sangriaen': ('sangria',),
'sangriaene': ('sangria',),
'sangriaer': ('sangria',),
'sangstemme': ('sangstemme',),
'sangstemmen': ('sangstemme',),
'sangstemmene': ('sangstemme',),
'sangstemmer': ('sangstemme',),
'sangsvana': ('sangsvane',),
'sangsvane': ('sangsvane',),
'sangsvanen': ('sangsvane',),
'sangsvanene': ('sangsvane',),
'sangsvaner': ('sangsvane',),
'sangviniker': ('sangviniker',),
'sangvinikere': ('sangviniker',),
'sangvinikeren': ('sangviniker',),
'sangvinikerer': ('sangviniker',),
'sangvinikerne': ('sangviniker',),
'sanikkel': ('sanikkel',),
'sanikkelen': ('sanikkel',),
'saniklene': ('sanikkel',),
'sanikler': ('sanikkel',),
'sanitet': ('sanitet',),
'saniteten': ('sanitet',),
'sanitetene': ('sanitet',),
'saniteter': ('sanitet',),
'sanitetsbind': ('sanitetsbind',),
'sanitetsbinda': ('sanitetsbind',),
'sanitetsbindene': ('sanitetsbind',),
'sanitetsbindet': ('sanitetsbind',),
'sanitetsforening': ('sanitetsforening',),
'sanitetsforeninga': ('sanitetsforening',),
'sanitetsforeningen': ('sanitetsforening',),
'sanitetsforeningene': ('sanitetsforening',),
'sanitetsforeninger': ('sanitetsforening',),
'sanitetskvinna': ('sanitetskvinne',),
'sanitetskvinne': ('sanitetskvinne',),
'sanitetskvinnen': ('sanitetskvinne',),
'sanitetskvinnene': ('sanitetskvinne',),
'sanitetskvinner': ('sanitetskvinne',),
'sanitetssøster': ('sanitetssøster',),
'sanitetssøstera': ('sanitetssøster',),
'sanitetssøsteren': ('sanitetssøster',),
'sanitetssøstre': ('sanitetssøster',),
'sanitetssøstrene': ('sanitetssøster',),
'sanitetssøstrer': ('sanitetssøster',),
'sanitetstropp': ('sanitetstropp',),
'sanitetstroppen': ('sanitetstropp',),
'sanitetstroppene': ('sanitetstropp',),
'sanitetstropper': ('sanitetstropp',),
'sanitæranlegg': ('sanitæranlegg',),
'sanitæranlegga': ('sanitæranlegg',),
'sanitæranleggene': ('sanitæranlegg',),
'sanitæranlegget': ('sanitæranlegg',),
'sanker': ('sanker',),
'sankere': ('sanker',),
'sankeren': ('sanker',),
'sankerer': ('sanker',),
'sankerne': ('sanker',),
'sanksjon': ('sanksjon',),
'sanksjonen': ('sanksjon',),
'sanksjonene': ('sanksjon',),
'sanksjoner': ('sanksjon',),
'sanktbernhardshund': ('sanktbernhardshund',),
'sanktbernhardshunden': ('sanktbernhardshund',),
'sanktbernhardshundene': ('sanktbernhardshund',),
'sanktbernhardshunder': ('sanktbernhardshund',),
'sankthans': ('sankthans',),
'sankthansen': ('sankthans',),
'sankthansene': ('sankthans',),
'sankthanser': ('sankthans',),
'sankthansaften': ('sankthansaften',),
'sankthansaftenen': ('sankthansaften',),
'sankthansaftenene': ('sankthansaften',),
'sankthansaftener': ('sankthansaften',),
'sankthansbål': ('sankthansbål',),
'sankthansbåla': ('sankthansbål',),
'sankthansbålene': ('sankthansbål',),
'sankthansbålet': ('sankthansbål',),
'sankthansdag': ('sankthansdag',),
'sankthansdagen': ('sankthansdag',),
'sankthansdagene': ('sankthansdag',),
'sankthansdager': ('sankthansdag',),
'sankthanskveld': ('sankthanskveld',),
'sankthanskvelden': ('sankthanskveld',),
'sankthanskveldene': ('sankthanskveld',),
'sankthanskvelder': ('sankthanskveld',),
'sankthansorm': ('sankthansorm',),
'sankthansormen': ('sankthansorm',),
'sankthansormene': ('sankthansorm',),
'sankthansormer': ('sankthansorm',),
'sanktpeterfisk': ('sanktpeterfisk',),
'sanktpeterfisken': ('sanktpeterfisk',),
'sanktpeterfiskene': ('sanktpeterfisk',),
'sanktpeterfisker': ('sanktpeterfisk',),
'sanktveitsdans': ('sanktveitsdans',),
'sanktveitsdansen': ('sanktveitsdans',),
'sanktveitsdansene': ('sanktveitsdans',),
'sanktveitsdanser': ('sanktveitsdans',),
'sanmariner': ('sanmariner',),
'sanmarinere': ('sanmariner',),
'sanmarineren': ('sanmariner',),
'sanmarinerer': ('sanmariner',),
'sanmarinerne': ('sanmariner',),
'sannhet': ('sannhet',),
'sannheta': ('sannhet',),
'sannheten': ('sannhet',),
'sannhetene': ('sannhet',),
'sannheter': ('sannhet',),
'sannhetsbevis': ('sannhetsbevis',),
'sannhetsbevisa': ('sannhetsbevis',),
'sannhetsbevisene': ('sannhetsbevis',),
'sannhetsbeviser': ('sannhetsbevis',),
'sannhetsbeviset': ('sannhetsbevis',),
'sannhetsord': ('sannhetsord',),
'sannhetsorda': ('sannhetsord',),
'sannhetsordene': ('sannhetsord',),
'sannhetsordet': ('sannhetsord',),
'sannhetssera': ('sannhetsserum',),
'sannhetsseraene': ('sannhetsserum',),
'sannhetsserum': ('sannhetsserum',),
'sannhetsseruma': ('sannhetsserum',),
'sannhetsserumene': ('sannhetsserum',),
'sannhetsserumer': ('sannhetsserum',),
'sannhetsserumet': ('sannhetsserum',),
'sannhetsvitna': ('sannhetsvitne',),
'sannhetsvitne': ('sannhetsvitne',),
'sannhetsvitnene': ('sannhetsvitne',),
'sannhetsvitner': ('sannhetsvitne',),
'sannhetsvitnet': ('sannhetsvitne',),
'sanning': ('sanning',),
'sanninga': ('sanning',),
'sanningen': ('sanning',),
'sanningene': ('sanning',),
'sanninger': ('sanning',),
'sannsagn': ('sannsagn',),
'sannsagna': ('sannsagn',),
'sannsagnene': ('sannsagn',),
'sannsagnet': ('sannsagn',),
'sannsiger': ('sannsiger',),
'sannsigere': ('sannsiger',),
'sannsigeren': ('sannsiger',),
'sannsigerer': ('sannsiger',),
'sannsigerne': ('sannsiger',),
'sannsigerska': ('sannsigerske',),
'sannsigerske': ('sannsigerske',),
'sannsigersken': ('sannsigerske',),
'sannsigerskene': ('sannsigerske',),
'sannsigersker': ('sannsigerske',),
'sannsynlighet': ('sannsynlighet',),
'sannsynligheta': ('sannsynlighet',),
'sannsynligheten': ('sannsynlighet',),
'sannsynlighetene': ('sannsynlighet',),
'sannsynligheter': ('sannsynlighet',),
'sannsynlighetsbevis': ('sannsynlighetsbevis',),
'sannsynlighetsbevisa': ('sannsynlighetsbevis',),
'sannsynlighetsbevisene': ('sannsynlighetsbevis',),
'sannsynlighetsbeviser': ('sannsynlighetsbevis',),
'sannsynlighetsbeviset': ('sannsynlighetsbevis',),
'sannsynlighetsregning': ('sannsynlighetsregning',),
'sannsynlighetsregninga': ('sannsynlighetsregning',),
'sannsynlighetsregningen': ('sannsynlighetsregning',),
'sannsynlighetsregningene': ('sannsynlighetsregning',),
'sannsynlighetsregninger': ('sannsynlighetsregning',),
'sannsynlighetsrekning': ('sannsynlighetsrekning',),
'sannsynlighetsrekninga': ('sannsynlighetsrekning',),
'sannsynlighetsrekningen': ('sannsynlighetsrekning',),
'sannsynlighetsrekningene': ('sannsynlighetsrekning',),
'sannsynlighetsrekninger': ('sannsynlighetsrekning',),
'sans': ('sans',),
'sansen': ('sans',),
'sansene': ('sans',),
'sanser': ('sans',),
'sansebedrag': ('sansebedrag',),
'sansebedraga': ('sansebedrag',),
'sansebedragene': ('sansebedrag',),
'sansebedraget': ('sansebedrag',),
'sanseinntrykk': ('sanseinntrykk',),
'sanseinntrykka': ('sanseinntrykk',),
'sanseinntrykkene': ('sanseinntrykk',),
'sanseinntrykket': ('sanseinntrykk',),
'sansekaka': ('sansekake',),
'sansekake': ('sansekake',),
'sansekaken': ('sansekake',),
'sansekakene': ('sansekake',),
'sansekaker': ('sansekake',),
'sanseløshet': ('sanseløshet',),
'sanseløsheta': ('sanseløshet',),
'sanseløsheten': ('sanseløshet',),
'sanseløshetene': ('sanseløshet',),
'sanseløsheter': ('sanseløshet',),
'sanseløysa': ('sanseløyse',),
'sanseløyse': ('sanseløyse',),
'sanseløysen': ('sanseløyse',),
'sanseløysene': ('sanseløyse',),
'sanseløyser': ('sanseløyse',),
'sansenytelse': ('sansenytelse',),
'sansenytelsen': ('sansenytelse',),
'sansenytelsene': ('sansenytelse',),
'sansenytelser': ('sansenytelse',),
'sansenyting': ('sansenyting',),
'sansenytinga': ('sansenyting',),
'sansenytingen': ('sansenyting',),
'sansenytingene': ('sansenyting',),
'sansenytinger': ('sansenyting',),
'sanseorgan': ('sanseorgan',),
'sanseorgana': ('sanseorgan',),
'sanseorganene': ('sanseorgan',),
'sanseorganer': ('sanseorgan',),
'sanseorganet': ('sanseorgan',),
'sansepåvirkning': ('sansepåvirkning',),
'sansepåvirkninga': ('sansepåvirkning',),
'sansepåvirkningen': ('sansepåvirkning',),
'sansepåvirkningene': ('sansepåvirkning',),
'sansepåvirkninger': ('sansepåvirkning',),
'sanseverden': ('sanseverden',),
'sanseverdenen': ('sanseverden',),
'sanseverdenene': ('sanseverden',),
'sanseverdener': ('sanseverden',),
'sansing': ('sansing',),
'sansinga': ('sansing',),
'sansingen': ('sansing',),
'sansingene': ('sansing',),
'sansinger': ('sansing',),
'sanskrit': ('sanskrit',),
'sanskriten': ('sanskrit',),
'sanskritene': ('sanskrit',),
'sanskriter': ('sanskrit',),
'sanskritist': ('sanskritist',),
'sanskritisten': ('sanskritist',),
'sanskritistene': ('sanskritist',),
'sanskritister': ('sanskritist',),
'sanskulott': ('sanskulott',),
'sanskulotten': ('sanskulott',),
'sanskulottene': ('sanskulott',),
'sanskulotter': ('sanskulott',),
'sansning': ('sansning',),
'sansninga': ('sansning',),
'sansningen': ('sansning',),
'sansningene': ('sansning',),
'sansninger': ('sansning',),
'santal': ('santal',),
'santalen': ('santal',),
'santalene': ('santal',),
'santaler': ('santal',),
'santali': ('santali',),
'santalien': ('santali',),
'santaliene': ('santali',),
'santalier': ('santali',),
'santalmisjon': ('santalmisjon',),
'santalmisjonen': ('santalmisjon',),
'santalmisjonene': ('santalmisjon',),
'santalmisjoner': ('santalmisjon',),
'santen': ('santen',),
'sappe': ('sappe',),
'sappen': ('sappe',),
'sappene': ('sappe',),
'sapper': ('sappe',),
'sappør': ('sappør',),
'sappøren': ('sappør',),
'sappørene': ('sappør',),
'sappører': ('sappør',),
'sappør': ('sappør',),
'sappøren': ('sappør',),
'sappørene': ('sappør',),
'sappører': ('sappør',),
'saprofytt': ('saprofytt',),
'saprofytten': ('saprofytt',),
'saprofyttene': ('saprofytt',),
'saprofytter': ('saprofytt',),
'sapør': ('sapør',),
'sapøren': ('sapør',),
'sapørene': ('sapør',),
'sapører': ('sapør',),
'sapør': ('sapør',),
'sapøren': ('sapør',),
'sapørene': ('sapør',),
'sapører': ('sapør',),
'sarabande': ('sarabande',),
'sarabanden': ('sarabande',),
'sarabandene': ('sarabande',),
'sarabander': ('sarabande',),
'sarasener': ('sarasener',),
'sarasenere': ('sarasener',),
'saraseneren': ('sarasener',),
'sarasenerer': ('sarasener',),
'sarasenerne': ('sarasener',),
'sardell': ('sardell',),
'sardellen': ('sardell',),
'sardellene': ('sardell',),
'sardeller': ('sardell',),
'sarder': ('sarder',),
'sardere': ('sarder',),
'sarderen': ('sarder',),
'sarderer': ('sarder',),
'sarderne': ('sarder',),
'sardin': ('sardin',),
'sardinen': ('sardin',),
'sardinene': ('sardin',),
'sardiner': ('sardin',),
'sardinier': ('sardinier',),
'sardiniere': ('sardinier',),
'sardinieren': ('sardinier',),
'sardinierer': ('sardinier',),
'sardinierne': ('sardinier',),
'sareptakrukka': ('sareptakrukke',),
'sareptakrukke': ('sareptakrukke',),
'sareptakrukken': ('sareptakrukke',),
'sareptakrukkene': ('sareptakrukke',),
'sareptakrukker': ('sareptakrukke',),
'sarg': ('sarg',),
'sargen': ('sarg',),
'sargene': ('sarg',),
'sarger': ('sarg',),
'sargassotang': ('sargassotang',),
'sargassotanga': ('sargassotang',),
'sargassotangen': ('sargassotang',),
'sargassotangene': ('sargassotang',),
'sargassotanger': ('sargassotang',),
'sargassotanget': ('sargassotang',),
'sari': ('sari',),
'sarien': ('sari',),
'sariene': ('sari',),
'sarier': ('sari',),
'sarkasme': ('sarkasme',),
'sarkasmen': ('sarkasme',),
'sarkasmene': ('sarkasme',),
'sarkasmer': ('sarkasme',),
'sarkofag': ('sarkofag',),
'sarkofagen': ('sarkofag',),
'sarkofagene': ('sarkofag',),
'sarkofager': ('sarkofag',),
'sarkom': ('sarkom',),
'sarkoma': ('sarkom',),
'sarkomene': ('sarkom',),
'sarkomer': ('sarkom',),
'sarkomet': ('sarkom',),
'sarong': ('sarong',),
'sarongen': ('sarong',),
'sarongene': ('sarong',),
'saronger': ('sarong',),
'sarping': ('sarping',),
'sarpingen': ('sarping',),
'sarpingene': ('sarping',),
'sarpinger': ('sarping',),
'sarv': ('sarv',),
'sarva': ('sarv',),
'sarvene': ('sarv',),
'sarvet': ('sarv',),
'satan': ('satan',),
'satanen': ('satan',),
'satanene': ('satan',),
'sataner': ('satan',),
'satanisme': ('satanisme',),
'satanismen': ('satanisme',),
'satanismene': ('satanisme',),
'satanismer': ('satanisme',),
'satanist': ('satanist',),
'satanisten': ('satanist',),
'satanistene': ('satanist',),
'satanister': ('satanist',),
'satellitt': ('satellitt',),
'satellitten': ('satellitt',),
'satellittene': ('satellitt',),
'satellitter': ('satellitt',),
'satellittsamband': ('satellittsamband',),
'satellittsambanda': ('satellittsamband',),
'satellittsambandene': ('satellittsamband',),
'satellittsambandet': ('satellittsamband',),
'satellittstat': ('satellittstat',),
'satellittstaten': ('satellittstat',),
'satellittstatene': ('satellittstat',),
'satellittstater': ('satellittstat',),
'satemspråk': ('satemspråk',),
'satemspråka': ('satemspråk',),
'satemspråkene': ('satemspråk',),
'satemspråket': ('satemspråk',),
'sateng': ('sateng',),
'satengen': ('sateng',),
'satengene': ('sateng',),
'satenger': ('sateng',),
'satengkjole': ('satengkjole',),
'satengkjolen': ('satengkjole',),
'satengkjolene': ('satengkjole',),
'satengkjoler': ('satengkjole',),
'satire': ('satire',),
'satiren': ('satire',),
'satirene': ('satire',),
'satirer': ('satire',),
'satirikal': ('satirikal',),
'satirikalen': ('satirikal',),
'satirikalene': ('satirikal',),
'satirikaler': ('satirikal',),
'satiriker': ('satiriker',),
'satirikere': ('satiriker',),
'satirikeren': ('satiriker',),
'satirikerer': ('satiriker',),
'satirikerne': ('satiriker',),
'satisfaksjon': ('satisfaksjon',),
'satisfaksjonen': ('satisfaksjon',),
'satisfaksjonene': ('satisfaksjon',),
'satisfaksjoner': ('satisfaksjon',),
'satrap': ('satrap',),
'satrapen': ('satrap',),
'satrapene': ('satrap',),
'satraper': ('satrap',),
'sats': ('sats',),
'satsen': ('sats',),
'satsene': ('sats',),
'satser': ('sats',),
'satsing': ('satsing',),
'satsinga': ('satsing',),
'satsingen': ('satsing',),
'satsingene': ('satsing',),
'satsinger': ('satsing',),
'saturnaliene': ('saturnalier',),
'saturnalier': ('saturnalier',),
'satyr': ('satyr',),
'satyren': ('satyr',),
'satyrene': ('satyr',),
'satyrer': ('satyr',),
'satyrspell': ('satyrspell',),
'satyrspella': ('satyrspell',),
'satyrspellene': ('satyrspell',),
'satyrspellet': ('satyrspell',),
'satyrspill': ('satyrspill',),
'satyrspilla': ('satyrspill',),
'satyrspillene': ('satyrspill',),
'satyrspillet': ('satyrspill',),
'sau': ('sau',),
'sauen': ('sau',),
'sauene': ('sau',),
'sauer': ('sau',),
'saual': ('saual',),
'sauala': ('saual',),
'saualene': ('saual',),
'saualet': ('saual',),
'sauavl': ('sauavl',),
'sauavlen': ('sauavl',),
'sauavlene': ('sauavl',),
'sauavler': ('sauavl',),
'saubukk': ('saubukk',),
'saubukken': ('saubukk',),
'saubukkene': ('saubukk',),
'saubukker': ('saubukk',),
'saucisse': ('saucisse',),
'saucissen': ('saucisse',),
'saucissene': ('saucisse',),
'saucisser': ('saucisse',),
'saucisse': ('saucisse',),
'saucissen': ('saucisse',),
'saucissene': ('saucisse',),
'saucisser': ('saucisse',),
'saudiaraber': ('saudiaraber',),
'saudiarabere': ('saudiaraber',),
'saudiaraberen': ('saudiaraber',),
'saudiaraberer': ('saudiaraber',),
'saudiaraberne': ('saudiaraber',),
'saudier': ('saudier',),
'saudiere': ('saudier',),
'saudieren': ('saudier',),
'saudierer': ('saudier',),
'saudierne': ('saudier',),
'saueal': ('saueal',),
'saueala': ('saueal',),
'sauealene': ('saueal',),
'sauealet': ('saueal',),
'saueavl': ('saueavl',),
'saueavlen': ('saueavl',),
'saueavlene': ('saueavl',),
'saueavler': ('saueavl',),
'sauekjøtt': ('sauekjøtt',),
'sauekjøtta': ('sauekjøtt',),
'sauekjøttene': ('sauekjøtt',),
'sauekjøttet': ('sauekjøtt',),
'sauekve': ('sauekve',),
'sauekvea': ('sauekve',),
'sauekveen': ('sauekve',),
'sauekveene': ('sauekve',),
'sauekveer': ('sauekve',),
'saueull': ('saueull',),
'saueulla': ('saueull',),
'saueullen': ('saueull',),
'saueullene': ('saueull',),
'saueuller': ('saueull',),
'sauna': ('sauna',),
'saunaen': ('sauna',),
'saunaene': ('sauna',),
'saunaer': ('sauna',),
'saup': ('saup',),
'saupa': ('saup',),
'saupene': ('saup',),
'saupet': ('saup',),
'saus': ('saus',),
'sausen': ('saus',),
'sausene': ('saus',),
'sauser': ('saus',),
'sausekopp': ('sausekopp',),
'sausekoppen': ('sausekopp',),
'sausekoppene': ('sausekopp',),
'sausekopper': ('sausekopp',),
'sausekopp': ('sausekopp',),
'sausekoppen': ('sausekopp',),
'sausekoppene': ('sausekopp',),
'sausekopper': ('sausekopp',),
'sausenebba': ('sausenebbe',),
'sausenebbe': ('sausenebbe',),
'sausenebben': ('sausenebbe',),
'sausenebbene': ('sausenebbe',),
'sausenebber': ('sausenebbe',),
'sausenebba': ('sausenebbe',),
'sausenebbe': ('sausenebbe',),
'sausenebben': ('sausenebbe',),
'sausenebbene': ('sausenebbe',),
'sausenebber': ('sausenebbe',),
'sauskopp': ('sauskopp',),
'sauskoppen': ('sauskopp',),
'sauskoppene': ('sauskopp',),
'sauskopper': ('sauskopp',),
'sauskopp': ('sauskopp',),
'sauskoppen': ('sauskopp',),
'sauskoppene': ('sauskopp',),
'sauskopper': ('sauskopp',),
'sausnebba': ('sausnebbe',),
'sausnebbe': ('sausnebbe',),
'sausnebben': ('sausnebbe',),
'sausnebbene': ('sausnebbe',),
'sausnebber': ('sausnebbe',),
'sauteen': ('sauté',),
'sauteene': ('sauté',),
'sauteer': ('sauté',),
'sauté': ('sauté',),
'sautéen': ('sauté',),
'sautéene': ('sauté',),
'sautéer': ('sauté',),
'sauull': ('sauull',),
'sauulla': ('sauull',),
'sauullen': ('sauull',),
'sauullene': ('sauull',),
'sauuller': ('sauull',),
'sav': ('sav',),
'sava': ('sav',),
'savene': ('sav',),
'savet': ('sav',),
'savanne': ('savanne',),
'savannen': ('savanne',),
'savannene': ('savanne',),
'savanner': ('savanne',),
'save': ('save',),
'saven': ('save',),
'savene': ('save',),
'saver': ('save',),
'savl': ('savl',),
'savla': ('savl',),
'savlene': ('savl',),
'savlet': ('savl',),
'savn': ('savn',),
'savna': ('savn',),
'savnene': ('savn',),
'savnet': ('savn',),
'scandium': ('scandium',),
'scandiuma': ('scandium',),
'scandiumene': ('scandium',),
'scandiumet': ('scandium',),
'scenario': ('scenario',),
'scenarioa': ('scenario',),
'scenarioene': ('scenario',),
'scenarioer': ('scenario',),
'scenarioet': ('scenario',),
'scenaria': ('scenarium',),
'scenariene': ('scenarium',),
'scenarier': ('scenarium',),
'scenariet': ('scenarium',),
'scenarium': ('scenarium',),
'scene': ('scene',),
'scenen': ('scene',),
'scenene': ('scene',),
'scener': ('scene',),
'sceneri': ('sceneri',),
'sceneria': ('sceneri',),
'sceneriene': ('sceneri',),
'scenerier': ('sceneri',),
'sceneriet': ('sceneri',),
'scenograf': ('scenograf',),
'scenografen': ('scenograf',),
'scenografene': ('scenograf',),
'scenografer': ('scenograf',),
'scenografi': ('scenografi',),
'scenografien': ('scenografi',),
'scenografiene': ('scenografi',),
'scenografier': ('scenografi',),
'scherzo': ('scherzo',),
'scherzoen': ('scherzo',),
'scherzoene': ('scherzo',),
'scherzoer': ('scherzo',),
'schilling': ('schilling',),
'schillingen': ('schilling',),
'schillingene': ('schilling',),
'schizofreni': ('schizofreni',),
'schizofrenien': ('schizofreni',),
'schizofreniene': ('schizofreni',),
'schizofrenier': ('schizofreni',),
'schnauzer': ('schnauzer',),
'schnauzere': ('schnauzer',),
'schnauzeren': ('schnauzer',),
'schnauzerer': ('schnauzer',),
'schnauzerne': ('schnauzer',),
'schwung': ('schwung',),
'schwungen': ('schwung',),
'schwungene': ('schwung',),
'schwunger': ('schwung',),
'schæfer': ('schæfer',),
'schæfere': ('schæfer',),
'schæferen': ('schæfer',),
'schæferer': ('schæfer',),
'schæferne': ('schæfer',),
'schæferhund': ('schæferhund',),
'schæferhunden': ('schæferhund',),
'schæferhundene': ('schæferhund',),
'schæferhunder': ('schæferhund',),
'science fiction': ('science fiction',),
'scientolog': ('scientolog',),
'scientologen': ('scientolog',),
'scientologene': ('scientolog',),
'scientologer': ('scientolog',),
'scientologi': ('scientologi',),
'scientologien': ('scientologi',),
'scientologiene': ('scientologi',),
'scientologier': ('scientologi',),
'scone': ('scone',),
'sconen': ('scone',),
'sconene': ('scone',),
'scones': ('scone',),
'scones': ('scones',),
'sconesen': ('scones',),
'sconesene': ('scones',),
'scoop': ('scoop',),
'scoopa': ('scoop',),
'scoopene': ('scoop',),
'scoopet': ('scoop',),
'scooter': ('scooter',),
'scootere': ('scooter',),
'scooteren': ('scooter',),
'scooterer': ('scooter',),
'scooterne': ('scooter',),
'score': ('score',),
'scoren': ('score',),
'scorene': ('score',),
'scorer': ('score',),
'scorer': ('scorer',),
'scorere': ('scorer',),
'scoreren': ('scorer',),
'scorerer': ('scorer',),
'scorerne': ('scorer',),
'scoring': ('scoring',),
'scoringa': ('scoring',),
'scoringen': ('scoring',),
'scoringene': ('scoring',),
'scoringer': ('scoring',),
'scoringssjanse': ('scoringssjanse',),
'scoringssjansen': ('scoringssjanse',),
'scoringssjansene': ('scoringssjanse',),
'scoringssjanser': ('scoringssjanse',),
'script': ('script',),
'scripten': ('script',),
'scriptene': ('script',),
'scripter': ('script',),
'sculler': ('sculler',),
'scullere': ('sculler',),
'sculleren': ('sculler',),
'scullerer': ('sculler',),
'scullerne': ('sculler',),
'scullery': ('scullery',),
'scullerya': ('scullery',),
'sculleryene': ('scullery',),
'sculleryer': ('scullery',),
'sculleryet': ('scullery',),
'señor': ('señor',),
'señoren': ('señor',),
'señorene': ('señor',),
'señorer': ('señor',),
'señora': ('señora',),
'señoraen': ('señora',),
'señoraene': ('señora',),
'señoraer': ('señora',),
'señorita': ('señorita',),
'señoritaen': ('señorita',),
'señoritaene': ('señorita',),
'señoritaer': ('señorita',),
'señorito': ('señorito',),
'señoritoen': ('señorito',),
'señoritoene': ('señorito',),
'señoritoer': ('señorito',),
'seanse': ('seanse',),
'seansen': ('seanse',),
'seansene': ('seanse',),
'seanser': ('seanse',),
'sebra': ('sebra',),
'sebraen': ('sebra',),
'sebraene': ('sebra',),
'sebraer': ('sebra',),
'sebrafelt': ('sebrafelt',),
'sebrafelta': ('sebrafelt',),
'sebrafeltene': ('sebrafelt',),
'sebrafelter': ('sebrafelt',),
'sebrafeltet': ('sebrafelt',),
'sebu': ('sebu',),
'sebuen': ('sebu',),
'sebuene': ('sebu',),
'sebuer': ('sebu',),
'sebu': ('sebu',),
'sebuen': ('sebu',),
'sebuene': ('sebu',),
'sebuer': ('sebu',),
'secondo': ('secondo',),
'sed': ('sed',),
'seden': ('sed',),
'sedene': ('sed',),
'seder': ('sed',),
'sedan': ('sedan',),
'sedanen': ('sedan',),
'sedanene': ('sedan',),
'sedaner': ('sedan',),
'sedativ': ('sedativ',),
'sedativa': ('sedativ',),
'sedativene': ('sedativ',),
'sedativer': ('sedativ',),
'sedativet': ('sedativ',),
'seddel': ('seddel',),
'seddelen': ('seddel',),
'sedlene': ('seddel',),
'sedler': ('seddel',),
'seddelbok': ('seddelbok',),
'seddelboka': ('seddelbok',),
'seddelboken': ('seddelbok',),
'seddelbøkene': ('seddelbok',),
'seddelbøker': ('seddelbok',),
'seddelpressa': ('seddelpresse',),
'seddelpresse': ('seddelpresse',),
'seddelpressen': ('seddelpresse',),
'seddelpressene': ('seddelpresse',),
'seddelpresser': ('seddelpresse',),
'sedelighet': ('sedelighet',),
'sedeligheta': ('sedelighet',),
'sedeligheten': ('sedelighet',),
'sedelighetene': ('sedelighet',),
'sedeligheter': ('sedelighet',),
'sedelighetsforbrytelse': ('sedelighetsforbrytelse',),
'sedelighetsforbrytelsen': ('sedelighetsforbrytelse',),
'sedelighetsforbrytelsene': ('sedelighetsforbrytelse',),
'sedelighetsforbrytelser': ('sedelighetsforbrytelse',),
'sedelighetsforbryter': ('sedelighetsforbryter',),
'sedelighetsforbrytere': ('sedelighetsforbryter',),
'sedelighetsforbryteren': ('sedelighetsforbryter',),
'sedelighetsforbryterer': ('sedelighetsforbryter',),
'sedelighetsforbryterne': ('sedelighetsforbryter',),
'seder': ('seder',),
'sedere': ('seder',),
'sederen': ('seder',),
'sederne': ('seder',),
'sedre': ('seder',),
'sedrene': ('seder',),
'sedrer': ('seder',),
'sediment': ('sediment',),
'sedimenta': ('sediment',),
'sedimentene': ('sediment',),
'sedimenter': ('sediment',),
'sedimentet': ('sediment',),
'sedløshet': ('sedløshet',),
'sedløsheta': ('sedløshet',),
'sedløsheten': ('sedløshet',),
'sedløshetene': ('sedløshet',),
'sedløsheter': ('sedløshet',),
'sedløysa': ('sedløyse',),
'sedløyse': ('sedløyse',),
'sedløysen': ('sedløyse',),
'sedløysene': ('sedløyse',),
'sedløyser': ('sedløyse',),
'sedvane': ('sedvane',),
'sedvanen': ('sedvane',),
'sedvanene': ('sedvane',),
'sedvaner': ('sedvane',),
'sedvanerett': ('sedvanerett',),
'sedvaneretten': ('sedvanerett',),
'sedvanerettene': ('sedvanerett',),
'sedvaneretter': ('sedvanerett',),
'seer': ('seer',),
'seere': ('seer',),
'seeren': ('seer',),
'seerer': ('seer',),
'seerne': ('seer',),
'seerblikk': ('seerblikk',),
'seerblikka': ('seerblikk',),
'seerblikkene': ('seerblikk',),
'seerblikket': ('seerblikk',),
'seerevna': ('seerevne',),
'seerevne': ('seerevne',),
'seerevnen': ('seerevne',),
'seerevnene': ('seerevne',),
'seerevner': ('seerevne',),
'sefard': ('sefard',),
'sefarden': ('sefard',),
'sefardene': ('sefard',),
'sefarder': ('sefard',),
'sefardi': ('sefardi',),
'sefardien': ('sefardi',),
'sefardim': ('sefardi',),
'sefardimene': ('sefardi',),
'sefyr': ('sefyr',),
'sefyren': ('sefyr',),
'sefyrene': ('sefyr',),
'sefyrer': ('sefyr',),
'sefyrgarn': ('sefyrgarn',),
'sefyrgarna': ('sefyrgarn',),
'sefyrgarnene': ('sefyrgarn',),
'sefyrgarnet': ('sefyrgarn',),
'seglbrett': ('seglbrett',),
'seglbretta': ('seglbrett',),
'seglbrettene': ('seglbrett',),
'seglbretter': ('seglbrett',),
'seglbrettet': ('seglbrett',),
'seglbåt': ('seglbåt',),
'seglbåten': ('seglbåt',),
'seglbåtene': ('seglbåt',),
'seglbåter': ('seglbåt',),
'seglduk': ('seglduk',),
'seglduken': ('seglduk',),
'segldukene': ('seglduk',),
'seglduker': ('seglduk',),
'segler': ('segler',),
'seglere': ('segler',),
'segleren': ('segler',),
'seglerer': ('segler',),
'seglerne': ('segler',),
'seglfly': ('seglfly',),
'seglflya': ('seglfly',),
'seglflyene': ('seglfly',),
'seglflyet': ('seglfly',),
'seglflyger': ('seglflyger',),
'seglflygere': ('seglflyger',),
'seglflygeren': ('seglflyger',),
'seglflygerer': ('seglflyger',),
'seglflygerne': ('seglflyger',),
'seglføring': ('seglføring',),
'seglføringa': ('seglføring',),
'seglføringen': ('seglføring',),
'seglføringene': ('seglføring',),
'seglføringer': ('seglføring',),
'segling': ('segling',),
'seglinga': ('segling',),
'seglingen': ('segling',),
'seglingene': ('segling',),
'seglinger': ('segling',),
'segllakk': ('segllakk',),
'segllakken': ('segllakk',),
'segllakkene': ('segllakk',),
'segllakker': ('segllakk',),
'seglmaker': ('seglmaker',),
'seglmakere': ('seglmaker',),
'seglmakeren': ('seglmaker',),
'seglmakerer': ('seglmaker',),
'seglmakerne': ('seglmaker',),
'seglskip': ('seglskip',),
'seglskipa': ('seglskip',),
'seglskipene': ('seglskip',),
'seglskipet': ('seglskip',),
'seglskuta': ('seglskute',),
'seglskute': ('seglskute',),
'seglskuten': ('seglskute',),
'seglskutene': ('seglskute',),
'seglskuter': ('seglskute',),
'seglskutetid': ('seglskutetid',),
'seglskutetida': ('seglskutetid',),
'seglskutetiden': ('seglskutetid',),
'seglskutetidene': ('seglskutetid',),
'seglskutetider': ('seglskutetid',),
'seglsport': ('seglsport',),
'seglsporten': ('seglsport',),
'seglsportene': ('seglsport',),
'seglsporter': ('seglsport',),
'segment': ('segment',),
'segmenta': ('segment',),
'segmentene': ('segment',),
'segmenter': ('segment',),
'segmentet': ('segment',),
'segmentasjon': ('segmentasjon',),
'segmentasjonen': ('segmentasjon',),
'segmentasjonene': ('segmentasjon',),
'segmentasjoner': ('segmentasjon',),
'segmentering': ('segmentering',),
'segmenteringa': ('segmentering',),
'segmenteringen': ('segmentering',),
'segmenteringene': ('segmentering',),
'segmenteringer': ('segmentering',),
'segn': ('segn',),
'segna': ('segn',),
'segnen': ('segn',),
'segnene': ('segn',),
'segner': ('segn',),
'segregasjon': ('segregasjon',),
'segregasjonen': ('segregasjon',),
'segregasjonene': ('segregasjon',),
'segregasjoner': ('segregasjon',),
'segregasjonist': ('segregasjonist',),
'segregasjonisten': ('segregasjonist',),
'segregasjonistene': ('segregasjonist',),
'segregasjonister': ('segregasjonist',),
'sei': ('sei',),
'seien': ('sei',),
'seiene': ('sei',),
'seier': ('sei',),
'seibiff': ('seibiff',),
'seibiffen': ('seibiff',),
'seibiffene': ('seibiff',),
'seibiffer': ('seibiff',),
'seid': ('seid',),
'seiden': ('seid',),
'seidene': ('seid',),
'seider': ('seid',),
'seide': ('seide',),
'seiden': ('seide',),
'seidene': ('seide',),
'seider': ('seide',),
'seidel': ('seidel',),
'seidelen': ('seidel',),
'seidlene': ('seidel',),
'seidler': ('seidel',),
'seidkona': ('seidkone',),
'seidkone': ('seidkone',),
'seidkonen': ('seidkone',),
'seidkonene': ('seidkone',),
'seidkoner': ('seidkone',),
'seidmann': ('seidmann',),
'seidmannen': ('seidmann',),
'seidmenn': ('seidmann',),
'seidmennene': ('seidmann',),
'seier': ('seier',),
'seiere': ('seier',),
'seieren': ('seier',),
'seierer': ('seier',),
'seierne': ('seier',),
'seire': ('seier',),
'seirene': ('seier',),
'seirer': ('seier',),
'seierherre': ('seierherre',),
'seierherren': ('seierherre',),
'seierherrene': ('seierherre',),
'seierherrer': ('seierherre',),
'seiersgang': ('seiersgang',),
'seiersgangen': ('seiersgang',),
'seiersgangene': ('seiersgang',),
'seiersganger': ('seiersgang',),
'seiershua': ('seiershue',),
'seiershue': ('seiershue',),
'seiershuen': ('seiershue',),
'seiershuene': ('seiershue',),
'seiershuer': ('seiershue',),
'seiershuva': ('seiershuve',),
'seiershuve': ('seiershuve',),
'seiershuven': ('seiershuve',),
'seiershuvene': ('seiershuve',),
'seiershuver': ('seiershuve',),
'seierslua': ('seierslue',),
'seierslue': ('seierslue',),
'seiersluen': ('seierslue',),
'seiersluene': ('seierslue',),
'seiersluer': ('seierslue',),
'seiersluva': ('seiersluve',),
'seiersluve': ('seiersluve',),
'seiersluven': ('seiersluve',),
'seiersluvene': ('seiersluve',),
'seiersluver': ('seiersluve',),
'seierspall': ('seierspall',),
'seierspallen': ('seierspall',),
'seierspallene': ('seierspall',),
'seierspaller': ('seierspall',),
'seiersrus': ('seiersrus',),
'seiersrusa': ('seiersrus',),
'seiersrusen': ('seiersrus',),
'seiersrusene': ('seiersrus',),
'seiersruser': ('seiersrus',),
'seiersruset': ('seiersrus',),
'seiflak': ('seiflak',),
'seiflaka': ('seiflak',),
'seiflakene': ('seiflak',),
'seiflaket': ('seiflak',),
'seigmann': ('seigmann',),
'seigmannen': ('seigmann',),
'seigmenn': ('seigmann',),
'seigmennene': ('seigmann',),
'seigneur': ('seigneur',),
'seigneuren': ('seigneur',),
'seigneurene': ('seigneur',),
'seigneurer': ('seigneur',),
'seihval': ('seihval',),
'seihvalen': ('seihval',),
'seihvalene': ('seihval',),
'seihvaler': ('seihval',),
'seikaka': ('seikake',),
'seikake': ('seikake',),
'seikaken': ('seikake',),
'seikakene': ('seikake',),
'seikaker': ('seikake',),
'seikval': ('seikval',),
'seikvalen': ('seikval',),
'seikvalene': ('seikval',),
'seikvaler': ('seikval',),
'seil': ('seil',),
'seilen': ('seil',),
'seilene': ('seil',),
'seiler': ('seil',),
'seil': ('seil',),
'seila': ('seil',),
'seilene': ('seil',),
'seilet': ('seil',),
'seilas': ('seilas',),
'seilasen': ('seilas',),
'seilasene': ('seilas',),
'seilaser': ('seilas',),
'seilbrett': ('seilbrett',),
'seilbretta': ('seilbrett',),
'seilbrettene': ('seilbrett',),
'seilbretter': ('seilbrett',),
'seilbrettet': ('seilbrett',),
'seilbåt': ('seilbåt',),
'seilbåten': ('seilbåt',),
'seilbåtene': ('seilbåt',),
'seilbåter': ('seilbåt',),
'seilduk': ('seilduk',),
'seilduken': ('seilduk',),
'seildukene': ('seilduk',),
'seilduker': ('seilduk',),
'seiler': ('seiler',),
'seilere': ('seiler',),
'seileren': ('seiler',),
'seilerer': ('seiler',),
'seilerne': ('seiler',),
'seilfly': ('seilfly',),
'seilflya': ('seilfly',),
'seilflyene': ('seilfly',),
'seilflyet': ('seilfly',),
'seilflyger': ('seilflyger',),
'seilflygere': ('seilflyger',),
'seilflygeren': ('seilflyger',),
'seilflygerer': ('seilflyger',),
'seilflygerne': ('seilflyger',),
'seilføring': ('seilføring',),
'seilføringa': ('seilføring',),
'seilføringen': ('seilføring',),
'seilføringene': ('seilføring',),
'seilføringer': ('seilføring',),
'seiling': ('seiling',),
'seilinga': ('seiling',),
'seilingen': ('seiling',),
'seilingene': ('seiling',),
'seilinger': ('seiling',),
'seilmaker': ('seilmaker',),
'seilmakere': ('seilmaker',),
'seilmakeren': ('seilmaker',),
'seilmakerer': ('seilmaker',),
'seilmakerne': ('seilmaker',),
'seilskip': ('seilskip',),
'seilskipa': ('seilskip',),
'seilskipene': ('seilskip',),
'seilskipet': ('seilskip',),
'seilskuta': ('seilskute',),
'seilskute': ('seilskute',),
'seilskuten': ('seilskute',),
'seilskutene': ('seilskute',),
'seilskuter': ('seilskute',),
'seilskutetid': ('seilskutetid',),
'seilskutetida': ('seilskutetid',),
'seilskutetiden': ('seilskutetid',),
'seilskutetidene': ('seilskutetid',),
'seilskutetider': ('seilskutetid',),
'seilsport': ('seilsport',),
'seilsporten': ('seilsport',),
'seilsportene': ('seilsport',),
'seilsporter': ('seilsport',),
'seindrektighet': ('seindrektighet',),
'seindrektigheta': ('seindrektighet',),
'seindrektigheten': ('seindrektighet',),
'seindrektighetene': ('seindrektighet',),
'seindrektigheter': ('seindrektighet',),
'seinkapitalisme': ('seinkapitalisme',),
'seinkapitalismen': ('seinkapitalisme',),
'seinkapitalismene': ('seinkapitalisme',),
'seinkapitalismer': ('seinkapitalisme',),
'seinsommer': ('seinsommer',),
'seinsommere': ('seinsommer',),
'seinsommeren': ('seinsommer',),
'seinsommerne': ('seinsommer',),
'seinsomre': ('seinsommer',),
'seinsomrene': ('seinsommer',),
'seinsomrer': ('seinsommer',),
'seising': ('seising',),
'seisingen': ('seising',),
'seisingene': ('seising',),
'seisinger': ('seising',),
'seismikk': ('seismikk',),
'seismikken': ('seismikk',),
'seismikkene': ('seismikk',),
'seismikker': ('seismikk',),
'seismisitet': ('seismisitet',),
'seismisiteten': ('seismisitet',),
'seismisitetene': ('seismisitet',),
'seismisiteter': ('seismisitet',),
'seismograf': ('seismograf',),
'seismografen': ('seismograf',),
'seismografene': ('seismograf',),
'seismografer': ('seismograf',),
'seismogram': ('seismogram',),
'seismogramma': ('seismogram',),
'seismogrammene': ('seismogram',),
'seismogrammer': ('seismogram',),
'seismogrammet': ('seismogram',),
'seismologi': ('seismologi',),
'seismologien': ('seismologi',),
'seismologiene': ('seismologi',),
'seismologier': ('seismologi',),
'seismometer': ('seismometer',),
'seismometeret': ('seismometer',),
'seismometra': ('seismometer',),
'seismometre': ('seismometer',),
'seismometrene': ('seismometer',),
'seismometret': ('seismometer',),
'sekant': ('sekant',),
'sekanten': ('sekant',),
'sekantene': ('sekant',),
'sekanter': ('sekant',),
'sekel': ('sekel',),
'sekelet': ('sekel',),
'sekla': ('sekel',),
'seklene': ('sekel',),
'sekler': ('sekel',),
'seklet': ('sekel',),
'sekelskifta': ('sekelskifte',),
'sekelskifte': ('sekelskifte',),
'sekelskiftene': ('sekelskifte',),
'sekelskifter': ('sekelskifte',),
'sekelskiftet': ('sekelskifte',),
'sekk': ('sekk',),
'sekken': ('sekk',),
'sekkene': ('sekk',),
'sekker': ('sekk',),
'sekkdyr': ('sekkdyr',),
'sekkdyra': ('sekkdyr',),
'sekkdyrene': ('sekkdyr',),
'sekkdyret': ('sekkdyr',),
'sekkeband': ('sekkeband',),
'sekkebanda': ('sekkeband',),
'sekkebandene': ('sekkeband',),
'sekkebandet': ('sekkeband',),
'sekkebetegnelse': ('sekkebetegnelse',),
'sekkebetegnelsen': ('sekkebetegnelse',),
'sekkebetegnelsene': ('sekkebetegnelse',),
'sekkebetegnelser': ('sekkebetegnelse',),
'sekkebevilgning': ('sekkebevilgning',),
'sekkebevilgninga': ('sekkebevilgning',),
'sekkebevilgningen': ('sekkebevilgning',),
'sekkebevilgningene': ('sekkebevilgning',),
'sekkebevilgninger': ('sekkebevilgning',),
'sekkebånd': ('sekkebånd',),
'sekkebånda': ('sekkebånd',),
'sekkebåndene': ('sekkebånd',),
'sekkebåndet': ('sekkebånd',),
'sekkeløp': ('sekkeløp',),
'sekkeløpa': ('sekkeløp',),
'sekkeløpene': ('sekkeløp',),
'sekkeløpet': ('sekkeløp',),
'sekkeord': ('sekkeord',),
'sekkeorda': ('sekkeord',),
'sekkeordene': ('sekkeord',),
'sekkeordet': ('sekkeord',),
'sekkepipa': ('sekkepipe',),
'sekkepipe': ('sekkepipe',),
'sekkepipen': ('sekkepipe',),
'sekkepipene': ('sekkepipe',),
'sekkepiper': ('sekkepipe',),
'sekkepost': ('sekkepost',),
'sekkeposten': ('sekkepost',),
'sekkepostene': ('sekkepost',),
'sekkeposter': ('sekkepost',),
'sekkestrie': ('sekkestrie',),
'sekkestrien': ('sekkestrie',),
'sekkestriene': ('sekkestrie',),
'sekkestrier': ('sekkestrie',),
'sekondløytnant': ('sekondløytnant',),
'sekondløytnanten': ('sekondløytnant',),
'sekondløytnantene': ('sekondløytnant',),
'sekondløytnanter': ('sekondløytnant',),
'sekresjon': ('sekresjon',),
'sekresjonen': ('sekresjon',),
'sekresjonene': ('sekresjon',),
'sekresjoner': ('sekresjon',),
'sekret': ('sekret',),
'sekreta': ('sekret',),
'sekretene': ('sekret',),
'sekreter': ('sekret',),
'sekretet': ('sekret',),
'sekret': ('sekret',),
'sekreta': ('sekret',),
'sekretene': ('sekret',),
'sekreter': ('sekret',),
'sekretet': ('sekret',),
'sekretariat': ('sekretariat',),
'sekretariata': ('sekretariat',),
'sekretariatene': ('sekretariat',),
'sekretariater': ('sekretariat',),
'sekretariatet': ('sekretariat',),
'sekretariatsleder': ('sekretariatsleder',),
'sekretariatsledere': ('sekretariatsleder',),
'sekretariatslederen': ('sekretariatsleder',),
'sekretariatslederer': ('sekretariatsleder',),
'sekretariatslederne': ('sekretariatsleder',),
'sekretær': ('sekretær',),
'sekretæren': ('sekretær',),
'sekretærene': ('sekretær',),
'sekretærer': ('sekretær',),
'sekretærlinja': ('sekretærlinje',),
'sekretærlinje': ('sekretærlinje',),
'sekretærlinjen': ('sekretærlinje',),
'sekretærlinjene': ('sekretærlinje',),
'sekretærlinjer': ('sekretærlinje',),
'sekretærskole': ('sekretærskole',),
'sekretærskolen': ('sekretærskole',),
'sekretærskolene': ('sekretærskole',),
'sekretærskoler': ('sekretærskole',),
'seksa': ('seksa',),
'seksaen': ('seksa',),
'seksaene': ('seksa',),
'seksaer': ('seksa',),
'seksagesima': ('seksagesima',),
'seksagesimalsystem': ('seksagesimalsystem',),
'seksagesimalsystema': ('seksagesimalsystem',),
'seksagesimalsystemene': ('seksagesimalsystem',),
'seksagesimalsystemer': ('seksagesimalsystem',),
'seksagesimalsystemet': ('seksagesimalsystem',),
'seksdel': ('seksdel',),
'seksdelen': ('seksdel',),
'seksdelene': ('seksdel',),
'seksdeler': ('seksdel',),
'sekser': ('sekser',),
'seksere': ('sekser',),
'sekseren': ('sekser',),
'sekserer': ('sekser',),
'sekserne': ('sekser',),
'seksjon': ('seksjon',),
'seksjonen': ('seksjon',),
'seksjonene': ('seksjon',),
'seksjoner': ('seksjon',),
'seksjonshus': ('seksjonshus',),
'seksjonshusa': ('seksjonshus',),
'seksjonshusene': ('seksjonshus',),
'seksjonshuset': ('seksjonshus',),
'seksjonsleder': ('seksjonsleder',),
'seksjonsledere': ('seksjonsleder',),
'seksjonslederen': ('seksjonsleder',),
'seksjonslederer': ('seksjonsleder',),
'seksjonslederne': ('seksjonsleder',),
'sekskant': ('sekskant',),
'sekskanten': ('sekskant',),
'sekskantene': ('sekskant',),
'sekskanter': ('sekskant',),
'seksling': ('seksling',),
'sekslingen': ('seksling',),
'sekslingene': ('seksling',),
'sekslinger': ('seksling',),
'seksløper': ('seksløper',),
'seksløpere': ('seksløper',),
'seksløperen': ('seksløper',),
'seksløperer': ('seksløper',),
'seksløperne': ('seksløper',),
'seksmeter': ('seksmeter',),
'seksmetere': ('seksmeter',),
'seksmeteren': ('seksmeter',),
'seksmeterer': ('seksmeter',),
'seksmeterne': ('seksmeter',),
'sekst': ('sekst',),
'seksten': ('sekst',),
'sekstene': ('sekst',),
'sekster': ('sekst',),
'sekstal': ('sekstal',),
'sekstala': ('sekstal',),
'sekstalene': ('sekstal',),
'sekstalet': ('sekstal',),
'sekstall': ('sekstall',),
'sekstalla': ('sekstall',),
'sekstallene': ('sekstall',),
'sekstallet': ('sekstall',),
'sekstant': ('sekstant',),
'sekstanten': ('sekstant',),
'sekstantene': ('sekstant',),
'sekstanter': ('sekstant',),
'sekstendel': ('sekstendel',),
'sekstendelen': ('sekstendel',),
'sekstendelene': ('sekstendel',),
'sekstendeler': ('sekstendel',),
'sekstenmeter': ('sekstenmeter',),
'sekstenmetere': ('sekstenmeter',),
'sekstenmeteren': ('sekstenmeter',),
'sekstenmeterer': ('sekstenmeter',),
'sekstenmeterne': ('sekstenmeter',),
'sekstenmeterstrek': ('sekstenmeterstrek',),
'sekstenmeterstreken': ('sekstenmeterstrek',),
'sekstenmeterstrekene': ('sekstenmeterstrek',),
'sekstenmeterstreker': ('sekstenmeterstrek',),
'sekstenåring': ('sekstenåring',),
'sekstenåringen': ('sekstenåring',),
'sekstenåringene': ('sekstenåring',),
'sekstenåringer': ('sekstenåring',),
'sekstenårsalder': ('sekstenårsalder',),
'sekstenårsaldere': ('sekstenårsalder',),
'sekstenårsalderen': ('sekstenårsalder',),
'sekstenårsalderer': ('sekstenårsalder',),
'sekstenårsalderne': ('sekstenårsalder',),
'sekstenårsaldre': ('sekstenårsalder',),
'sekstenårsaldrene': ('sekstenårsalder',),
'sekstenårsaldrer': ('sekstenårsalder',),
'sekstett': ('sekstett',),
'sekstetten': ('sekstett',),
'sekstettene': ('sekstett',),
'sekstetter': ('sekstett',),
'sekstid': ('sekstid',),
'sekstida': ('sekstid',),
'sekstiden': ('sekstid',),
'sekstidene': ('sekstid',),
'sekstider': ('sekstid',),
'sekstidel': ('sekstidel',),
'sekstidelen': ('sekstidel',),
'sekstidelene': ('sekstidel',),
'sekstideler': ('sekstidel',),
'sekstimeter': ('sekstimeter',),
'sekstimetere': ('sekstimeter',),
'sekstimeteren': ('sekstimeter',),
'sekstimeterer': ('sekstimeter',),
'sekstimeterne': ('sekstimeter',),
'sekstiår': ('sekstiår',),
'sekstiåra': ('sekstiår',),
'sekstiårene': ('sekstiår',),
'sekstiåret': ('sekstiår',),
'sekstiåring': ('sekstiåring',),
'sekstiåringen': ('sekstiåring',),
'sekstiåringene': ('sekstiåring',),
'sekstiåringer': ('sekstiåring',),
'sekstiårsdag': ('sekstiårsdag',),
'sekstiårsdagen': ('sekstiårsdag',),
'sekstiårsdagene': ('sekstiårsdag',),
'sekstiårsdager': ('sekstiårsdag',),
'sekstol': ('sekstol',),
'sekstolen': ('sekstol',),
'sekstolene': ('sekstol',),
'sekstoler': ('sekstol',),
'sekstur': ('sekstur',),
'seksturen': ('sekstur',),
'seksturene': ('sekstur',),
'seksturer': ('sekstur',),
'seksualdebut': ('seksualdebut',),
'seksualdebuten': ('seksualdebut',),
'seksualdebutene': ('seksualdebut',),
'seksualdebuter': ('seksualdebut',),
'seksualdrift': ('seksualdrift',),
'seksualdrifta': ('seksualdrift',),
'seksualdriften': ('seksualdrift',),
'seksualdriftene': ('seksualdrift',),
'seksualdrifter': ('seksualdrift',),
'seksualforbrytelse': ('seksualforbrytelse',),
'seksualforbrytelsen': ('seksualforbrytelse',),
'seksualforbrytelsene': ('seksualforbrytelse',),
'seksualforbrytelser': ('seksualforbrytelse',),
'seksualisering': ('seksualisering',),
'seksualiseringa': ('seksualisering',),
'seksualiseringen': ('seksualisering',),
'seksualiseringene': ('seksualisering',),
'seksualiseringer': ('seksualisering',),
'seksualisme': ('seksualisme',),
'seksualismen': ('seksualisme',),
'seksualismene': ('seksualisme',),
'seksualismer': ('seksualisme',),
'seksualliv': ('seksualliv',),
'seksualliva': ('seksualliv',),
'seksuallivene': ('seksualliv',),
'seksuallivet': ('seksualliv',),
'seksualopplysning': ('seksualopplysning',),
'seksualopplysninga': ('seksualopplysning',),
'seksualopplysningen': ('seksualopplysning',),
'seksualopplysningene': ('seksualopplysning',),
'seksualopplysninger': ('seksualopplysning',),
'seksualorgan': ('seksualorgan',),
'seksualorgana': ('seksualorgan',),
'seksualorganene': ('seksualorgan',),
'seksualorganer': ('seksualorgan',),
'seksualorganet': ('seksualorgan',),
'seksualundervisning': ('seksualundervisning',),
'seksualundervisninga': ('seksualundervisning',),
'seksualundervisningen': ('seksualundervisning',),
'seksualundervisningene': ('seksualundervisning',),
'seksualundervisninger': ('seksualundervisning',),
'seksåring': ('seksåring',),
'seksåringen': ('seksåring',),
'seksåringene': ('seksåring',),
'seksåringer': ('seksåring',),
'seksårsalder': ('seksårsalder',),
'seksårsaldere': ('seksårsalder',),
'seksårsalderen': ('seksårsalder',),
'seksårsalderer': ('seksårsalder',),
'seksårsalderne': ('seksårsalder',),
'seksårsaldre': ('seksårsalder',),
'seksårsaldrene': ('seksårsalder',),
'seksårsaldrer': ('seksårsalder',),
'seksæring': ('seksæring',),
'seksæringen': ('seksæring',),
'seksæringene': ('seksæring',),
'seksæringer': ('seksæring',),
'sekt': ('sekt',),
'sekten': ('sekt',),
'sektene': ('sekt',),
'sekter': ('sekt',),
'sekt': ('sekt',),
'sekta': ('sekt',),
'sekten': ('sekt',),
'sektene': ('sekt',),
'sekter': ('sekt',),
'sektdannelse': ('sektdannelse',),
'sektdannelsen': ('sektdannelse',),
'sektdannelsene': ('sektdannelse',),
'sektdannelser': ('sektdannelse',),
'sektdanning': ('sektdanning',),
'sektdanninga': ('sektdanning',),
'sektdanningen': ('sektdanning',),
'sektdanningene': ('sektdanning',),
'sektdanninger': ('sektdanning',),
'sekterer': ('sekterer',),
'sekterere': ('sekterer',),
'sektereren': ('sekterer',),
'sektererer': ('sekterer',),
'sektererne': ('sekterer',),
'sekterisme': ('sekterisme',),
'sekterismen': ('sekterisme',),
'sekterismene': ('sekterisme',),
'sekterismer': ('sekterisme',),
'sekterist': ('sekterist',),
'sekteristen': ('sekterist',),
'sekteristene': ('sekterist',),
'sekterister': ('sekterist',),
'sektor': ('sektor',),
'sektoren': ('sektor',),
'sektorene': ('sektor',),
'sektorer': ('sektor',),
'sektortenkning': ('sektortenkning',),
'sektortenkninga': ('sektortenkning',),
'sektortenkningen': ('sektortenkning',),
'sektortenkningene': ('sektortenkning',),
'sektortenkninger': ('sektortenkning',),
'sektvesen': ('sektvesen',),
'sektvesena': ('sektvesen',),
'sektvesenene': ('sektvesen',),
'sektvesener': ('sektvesen',),
'sektvesenet': ('sektvesen',),
'sekularfest': ('sekularfest',),
'sekularfesten': ('sekularfest',),
'sekularfestene': ('sekularfest',),
'sekularfester': ('sekularfest',),
'seklene': ('sekulum',),
'sekler': ('sekulum',),
'sekulum': ('sekulum',),
'sekulumet': ('sekulum',),
'sekund': ('sekund',),
'sekunden': ('sekund',),
'sekundene': ('sekund',),
'sekunder': ('sekund',),
'sekund': ('sekund',),
'sekunda': ('sekund',),
'sekundene': ('sekund',),
'sekunder': ('sekund',),
'sekundet': ('sekund',),
'sekundant': ('sekundant',),
'sekundanten': ('sekundant',),
'sekundantene': ('sekundant',),
'sekundanter': ('sekundant',),
'sekundavara': ('sekundavare',),
'sekundavare': ('sekundavare',),
'sekundavaren': ('sekundavare',),
'sekundavarene': ('sekundavare',),
'sekundavarer': ('sekundavare',),
'sekundaveksel': ('sekundaveksel',),
'sekundavekselen': ('sekundaveksel',),
'sekundavekslene': ('sekundaveksel',),
'sekundaveksler': ('sekundaveksel',),
'sekundmeter': ('sekundmeter',),
'sekundmetere': ('sekundmeter',),
'sekundmeteren': ('sekundmeter',),
'sekundmeterer': ('sekundmeter',),
'sekundmeterne': ('sekundmeter',),
'sekundviser': ('sekundviser',),
'sekundvisere': ('sekundviser',),
'sekundviseren': ('sekundviser',),
'sekundviserer': ('sekundviser',),
'sekundviserne': ('sekundviser',),
'sekundærkommune': ('sekundærkommune',),
'sekundærkommunen': ('sekundærkommune',),
'sekundærkommunene': ('sekundærkommune',),
'sekundærkommuner': ('sekundærkommune',),
'sekundærmetall': ('sekundærmetall',),
'sekundærmetalla': ('sekundærmetall',),
'sekundærmetallene': ('sekundærmetall',),
'sekundærmetaller': ('sekundærmetall',),
'sekundærmetallet': ('sekundærmetall',),
'sekundærnæring': ('sekundærnæring',),
'sekundærnæringa': ('sekundærnæring',),
'sekundærnæringen': ('sekundærnæring',),
'sekundærnæringene': ('sekundærnæring',),
'sekundærnæringer': ('sekundærnæring',),
'sekuritet': ('sekuritet',),
'sekuriteten': ('sekuritet',),
'sekuritetene': ('sekuritet',),
'sekuriteter': ('sekuritet',),
'sekvens': ('sekvens',),
'sekvensen': ('sekvens',),
'sekvensene': ('sekvens',),
'sekvenser': ('sekvens',),
'sel': ('sel',),
'selen': ('sel',),
'selene': ('sel',),
'seler': ('sel',),
'sel': ('sel',),
'sela': ('sel',),
'selene': ('sel',),
'selet': ('sel',),
'selbugenser': ('selbugenser',),
'selbugensere': ('selbugenser',),
'selbugenseren': ('selbugenser',),
'selbugenserer': ('selbugenser',),
'selbugenserne': ('selbugenser',),
'selbuvott': ('selbuvott',),
'selbuvotten': ('selbuvott',),
'selbuvottene': ('selbuvott',),
'selbuvotter': ('selbuvott',),
'seldsjukk': ('seldsjukk',),
'seldsjukken': ('seldsjukk',),
'seldsjukkene': ('seldsjukk',),
'seldsjukker': ('seldsjukk',),
'sele': ('sele',),
'selen': ('sele',),
'selene': ('sele',),
'seler': ('sele',),
'seleksjon': ('seleksjon',),
'seleksjonen': ('seleksjon',),
'seleksjonene': ('seleksjon',),
'seleksjoner': ('seleksjon',),
'selektivitet': ('selektivitet',),
'selektiviteten': ('selektivitet',),
'selektivitetene': ('selektivitet',),
'selektiviteter': ('selektivitet',),
'selen': ('selen',),
'selena': ('selen',),
'selenene': ('selen',),
'selenet': ('selen',),
'selenografi': ('selenografi',),
'selenografien': ('selenografi',),
'selenografiene': ('selenografi',),
'selenografier': ('selenografi',),
'selenologi': ('selenologi',),
'selenologien': ('selenologi',),
'selenologiene': ('selenologi',),
'selenologier': ('selenologi',),
'selepinne': ('selepinne',),
'selepinnen': ('selepinne',),
'selepinnene': ('selepinne',),
'selepinner': ('selepinne',),
'seletøy': ('seletøy',),
'seletøya': ('seletøy',),
'seletøyene': ('seletøy',),
'seletøyer': ('seletøy',),
'seletøyet': ('seletøy',),
'selfanger': ('selfanger',),
'selfangere': ('selfanger',),
'selfangeren': ('selfanger',),
'selfangerer': ('selfanger',),
'selfangerne': ('selfanger',),
'selfangst': ('selfangst',),
'selfangsten': ('selfangst',),
'selfangstene': ('selfangst',),
'selfangster': ('selfangst',),
'selger': ('selger',),
'selgere': ('selger',),
'selgeren': ('selger',),
'selgerer': ('selger',),
'selgerne': ('selger',),
'selhund': ('selhund',),
'selhunden': ('selhund',),
'selhundene': ('selhund',),
'selhunder': ('selhund',),
'selhval': ('selhval',),
'selhvalen': ('selhval',),
'selhvalene': ('selhval',),
'selhvaler': ('selhval',),
'selja': ('selje',),
'selje': ('selje',),
'seljen': ('selje',),
'seljene': ('selje',),
'seljer': ('selje',),
'seljefløyta': ('seljefløyte',),
'seljefløyte': ('seljefløyte',),
'seljefløyten': ('seljefløyte',),
'seljefløytene': ('seljefløyte',),
'seljefløyter': ('seljefløyte',),
'seljemannamess': ('seljemannamess',),
'seljemannamess': ('seljemannamess',),
'seljemannamesse': ('seljemannamesse',),
'selle': ('selle',),
'sellen': ('selle',),
'sellene': ('selle',),
'seller': ('selle',),
'selleri': ('selleri',),
'sellerien': ('selleri',),
'selleriene': ('selleri',),
'sellerier': ('selleri',),
'selot': ('selot',),
'seloten': ('selot',),
'selotene': ('selot',),
'seloter': ('selot',),
'selskap': ('selskap',),
'selskapa': ('selskap',),
'selskapene': ('selskap',),
'selskaper': ('selskap',),
'selskapet': ('selskap',),
'selskapelighet': ('selskapelighet',),
'selskapeligheten': ('selskapelighet',),
'selskapelighetene': ('selskapelighet',),
'selskapeligheter': ('selskapelighet',),
'selskapsdama': ('selskapsdame',),
'selskapsdame': ('selskapsdame',),
'selskapsdamen': ('selskapsdame',),
'selskapsdamene': ('selskapsdame',),
'selskapsdamer': ('selskapsdame',),
'selskapsdans': ('selskapsdans',),
'selskapsdansen': ('selskapsdans',),
'selskapsdansene': ('selskapsdans',),
'selskapsdanser': ('selskapsdans',),
'selskapsdress': ('selskapsdress',),
'selskapsdressen': ('selskapsdress',),
'selskapsdressene': ('selskapsdress',),
'selskapsdresser': ('selskapsdress',),
'selskapskjole': ('selskapskjole',),
'selskapskjolen': ('selskapskjole',),
'selskapskjolene': ('selskapskjole',),
'selskapskjoler': ('selskapskjole',),
'selskapsleik': ('selskapsleik',),
'selskapsleiken': ('selskapsleik',),
'selskapsleikene': ('selskapsleik',),
'selskapsleiker': ('selskapsleik',),
'selskapslek': ('selskapslek',),
'selskapsleken': ('selskapslek',),
'selskapslekene': ('selskapslek',),
'selskapsleker': ('selskapslek',),
'selskapsliv': ('selskapsliv',),
'selskapsliva': ('selskapsliv',),
'selskapslivene': ('selskapsliv',),
'selskapslivet': ('selskapsliv',),
'selskapslokala': ('selskapslokale',),
'selskapslokale': ('selskapslokale',),
'selskapslokalene': ('selskapslokale',),
'selskapslokaler': ('selskapslokale',),
'selskapslokalet': ('selskapslokale',),
'selskapsløva': ('selskapsløve',),
'selskapsløve': ('selskapsløve',),
'selskapsløven': ('selskapsløve',),
'selskapsløvene': ('selskapsløve',),
'selskapsløver': ('selskapsløve',),
'selskapsmenneska': ('selskapsmenneske',),
'selskapsmenneske': ('selskapsmenneske',),
'selskapsmenneskene': ('selskapsmenneske',),
'selskapsmennesker': ('selskapsmenneske',),
'selskapsmennesket': ('selskapsmenneske',),
'selskapsreisa': ('selskapsreise',),
'selskapsreise': ('selskapsreise',),
'selskapsreisen': ('selskapsreise',),
'selskapsreisene': ('selskapsreise',),
'selskapsreiser': ('selskapsreise',),
'selskapssang': ('selskapssang',),
'selskapssangen': ('selskapssang',),
'selskapssangene': ('selskapssang',),
'selskapssanger': ('selskapssang',),
'selskapsskatt': ('selskapsskatt',),
'selskapsskatten': ('selskapsskatt',),
'selskapsskattene': ('selskapsskatt',),
'selskapsskatter': ('selskapsskatt',),
'selskinn': ('selskinn',),
'selskinna': ('selskinn',),
'selskinnene': ('selskinn',),
'selskinnet': ('selskinn',),
'selskinnslua': ('selskinnslue',),
'selskinnslue': ('selskinnslue',),
'selskinnsluen': ('selskinnslue',),
'selskinnsluene': ('selskinnslue',),
'selskinnsluer': ('selskinnslue',),
'selsnepa': ('selsnepe',),
'selsnepe': ('selsnepe',),
'selsnepen': ('selsnepe',),
'selsnepene': ('selsnepe',),
'selsneper': ('selsnepe',),
'selspekk': ('selspekk',),
'selspekka': ('selspekk',),
'selspekkene': ('selspekk',),
'selspekket': ('selspekk',),
'selters': ('selters',),
'seltersen': ('selters',),
'seltersene': ('selters',),
'selv': ('selv',),
'selva': ('selv',),
'selvene': ('selv',),
'selvet': ('selv',),
'selvaktelse': ('selvaktelse',),
'selvaktelsen': ('selvaktelse',),
'selvaktelsene': ('selvaktelse',),
'selvaktelser': ('selvaktelse',),
'selvangivelse': ('selvangivelse',),
'selvangivelsen': ('selvangivelse',),
'selvangivelsene': ('selvangivelse',),
'selvangivelser': ('selvangivelse',),
'selvantenning': ('selvantenning',),
'selvantenninga': ('selvantenning',),
'selvantenningen': ('selvantenning',),
'selvantenningene': ('selvantenning',),
'selvantenninger': ('selvantenning',),
'selvassuranse': ('selvassuranse',),
'selvassuransen': ('selvassuranse',),
'selvassuransene': ('selvassuranse',),
'selvassuranser': ('selvassuranse',),
'selvbebreidelse': ('selvbebreidelse',),
'selvbebreidelsen': ('selvbebreidelse',),
'selvbebreidelsene': ('selvbebreidelse',),
'selvbebreidelser': ('selvbebreidelse',),
'selvbebreiding': ('selvbebreiding',),
'selvbebreidinga': ('selvbebreiding',),
'selvbebreidingen': ('selvbebreiding',),
'selvbebreidingene': ('selvbebreiding',),
'selvbebreidinger': ('selvbebreiding',),
'selvbedrag': ('selvbedrag',),
'selvbedraga': ('selvbedrag',),
'selvbedragene': ('selvbedrag',),
'selvbedraget': ('selvbedrag',),
'selvbehag': ('selvbehag',),
'selvbehaga': ('selvbehag',),
'selvbehagene': ('selvbehag',),
'selvbehaget': ('selvbehag',),
'selvbeherskelse': ('selvbeherskelse',),
'selvbeherskelsen': ('selvbeherskelse',),
'selvbeherskelsene': ('selvbeherskelse',),
'selvbeherskelser': ('selvbeherskelse',),
'selvbehersking': ('selvbehersking',),
'selvbeherskinga': ('selvbehersking',),
'selvbeherskingen': ('selvbehersking',),
'selvbeherskingene': ('selvbehersking',),
'selvbeherskinger': ('selvbehersking',),
'selvbekjennelse': ('selvbekjennelse',),
'selvbekjennelsen': ('selvbekjennelse',),
'selvbekjennelsene': ('selvbekjennelse',),
'selvbekjennelser': ('selvbekjennelse',),
'selvbekjenning': ('selvbekjenning',),
'selvbekjenninga': ('selvbekjenning',),
'selvbekjenningen': ('selvbekjenning',),
'selvbekjenningene': ('selvbekjenning',),
'selvbekjenninger': ('selvbekjenning',),
'selvberging': ('selvberging',),
'selvberginga': ('selvberging',),
'selvbergingen': ('selvberging',),
'selvbergingene': ('selvberging',),
'selvberginger': ('selvberging',),
'selvbergingspolitikk': ('selvbergingspolitikk',),
'selvbergingspolitikken': ('selvbergingspolitikk',),
'selvbergingspolitikkene': ('selvbergingspolitikk',),
'selvbergingspolitikker': ('selvbergingspolitikk',),
'selvbergingsøkonomi': ('selvbergingsøkonomi',),
'selvbergingsøkonomien': ('selvbergingsøkonomi',),
'selvbergingsøkonomiene': ('selvbergingsøkonomi',),
'selvbergingsøkonomier': ('selvbergingsøkonomi',),
'selvbestemmelse': ('selvbestemmelse',),
'selvbestemmelsen': ('selvbestemmelse',),
'selvbestemmelsene': ('selvbestemmelse',),
'selvbestemmelser': ('selvbestemmelse',),
'selvbestemmelsesrett': ('selvbestemmelsesrett',),
'selvbestemmelsesretten': ('selvbestemmelsesrett',),
'selvbestemmelsesrettene': ('selvbestemmelsesrett',),
'selvbestemmelsesretter': ('selvbestemmelsesrett',),
'selvbetjening': ('selvbetjening',),
'selvbetjeninga': ('selvbetjening',),
'selvbetjeningen': ('selvbetjening',),
'selvbetjeningene': ('selvbetjening',),
'selvbetjeninger': ('selvbetjening',),
'selvbetjeningsbutikk': ('selvbetjeningsbutikk',),
'selvbetjeningsbutikken': ('selvbetjeningsbutikk',),
'selvbetjeningsbutikkene': ('selvbetjeningsbutikk',),
'selvbetjeningsbutikker': ('selvbetjeningsbutikk',),
'selvbetjeningshytta': ('selvbetjeningshytte',),
'selvbetjeningshytte': ('selvbetjeningshytte',),
'selvbetjeningshytten': ('selvbetjeningshytte',),
'selvbetjeningshyttene': ('selvbetjeningshytte',),
'selvbetjeningshytter': ('selvbetjeningshytte',),
'selvbevissthet': ('selvbevissthet',),
'selvbevisstheta': ('selvbevissthet',),
'selvbevisstheten': ('selvbevissthet',),
'selvbevissthetene': ('selvbevissthet',),
'selvbevisstheter': ('selvbevissthet',),
'selvbinder': ('selvbinder',),
'selvbindere': ('selvbinder',),
'selvbinderen': ('selvbinder',),
'selvbinderer': ('selvbinder',),
'selvbinderne': ('selvbinder',),
'selvbiografi': ('selvbiografi',),
'selvbiografien': ('selvbiografi',),
'selvbiografiene': ('selvbiografi',),
'selvbiografier': ('selvbiografi',),
'selvbygger': ('selvbygger',),
'selvbyggere': ('selvbygger',),
'selvbyggeren': ('selvbygger',),
'selvbyggerer': ('selvbygger',),
'selvbyggerne': ('selvbygger',),
'selvbyggerlag': ('selvbyggerlag',),
'selvbyggerlaga': ('selvbyggerlag',),
'selvbyggerlagene': ('selvbyggerlag',),
'selvbyggerlaget': ('selvbyggerlag',),
'selvdekning': ('selvdekning',),
'selvdekninga': ('selvdekning',),
'selvdekningen': ('selvdekning',),
'selvdekningene': ('selvdekning',),
'selvdekninger': ('selvdekning',),
'selvdisiplin': ('selvdisiplin',),
'selvdisiplinen': ('selvdisiplin',),
'selvdisiplinene': ('selvdisiplin',),
'selvdisipliner': ('selvdisiplin',),
'selveia': ('selveie',),
'selveie': ('selveie',),
'selveiene': ('selveie',),
'selveier': ('selveie',),
'selveiet': ('selveie',),
'selveier': ('selveier',),
'selveiere': ('selveier',),
'selveieren': ('selveier',),
'selveierer': ('selveier',),
'selveierne': ('selveier',),
'selveierleilighet': ('selveierleilighet',),
'selveierleiligheta': ('selveierleilighet',),
'selveierleiligheten': ('selveierleilighet',),
'selveierleilighetene': ('selveierleilighet',),
'selveierleiligheter': ('selveierleilighet',),
'selverkjennelse': ('selverkjennelse',),
'selverkjennelsen': ('selverkjennelse',),
'selverkjennelsene': ('selverkjennelse',),
'selverkjennelser': ('selverkjennelse',),
'selvfinansiering': ('selvfinansiering',),
'selvfinansieringa': ('selvfinansiering',),
'selvfinansieringen': ('selvfinansiering',),
'selvfinansieringene': ('selvfinansiering',),
'selvfinansieringer': ('selvfinansiering',),
'selvfordypelse': ('selvfordypelse',),
'selvfordypelsen': ('selvfordypelse',),
'selvfordypelsene': ('selvfordypelse',),
'selvfordypelser': ('selvfordypelse',),
'selvfordyping': ('selvfordyping',),
'selvfordypinga': ('selvfordyping',),
'selvfordypingen': ('selvfordyping',),
'selvfordypingene': ('selvfordyping',),
'selvfordypinger': ('selvfordyping',),
'selvforherligelse': ('selvforherligelse',),
'selvforherligelsen': ('selvforherligelse',),
'selvforherligelsene': ('selvforherligelse',),
'selvforherligelser': ('selvforherligelse',),
'selvfornedrelse': ('selvfornedrelse',),
'selvfornedrelsen': ('selvfornedrelse',),
'selvfornedrelsene': ('selvfornedrelse',),
'selvfornedrelser': ('selvfornedrelse',),
'selvfornedring': ('selvfornedring',),
'selvfornedringa': ('selvfornedring',),
'selvfornedringen': ('selvfornedring',),
'selvfornedringene': ('selvfornedring',),
'selvfornedringer': ('selvfornedring',),
'selvfornekter': ('selvfornekter',),
'selvfornektere': ('selvfornekter',),
'selvfornekteren': ('selvfornekter',),
'selvfornekterer': ('selvfornekter',),
'selvfornekterne': ('selvfornekter',),
'selvfornekting': ('selvfornekting',),
'selvfornektinga': ('selvfornekting',),
'selvfornektingen': ('selvfornekting',),
'selvfornektingene': ('selvfornekting',),
'selvfornektinger': ('selvfornekting',),
'selvfornyelse': ('selvfornyelse',),
'selvfornyelsen': ('selvfornyelse',),
'selvfornyelsene': ('selvfornyelse',),
'selvfornyelser': ('selvfornyelse',),
'selvfornying': ('selvfornying',),
'selvfornyinga': ('selvfornying',),
'selvfornyingen': ('selvfornying',),
'selvfornyingene': ('selvfornying',),
'selvfornyinger': ('selvfornying',),
'selvforsagelse': ('selvforsagelse',),
'selvforsagelsen': ('selvforsagelse',),
'selvforsagelsene': ('selvforsagelse',),
'selvforsagelser': ('selvforsagelse',),
'selvforsakelse': ('selvforsakelse',),
'selvforsakelsen': ('selvforsakelse',),
'selvforsakelsene': ('selvforsakelse',),
'selvforsakelser': ('selvforsakelse',),
'selvforsaking': ('selvforsaking',),
'selvforsakinga': ('selvforsaking',),
'selvforsakingen': ('selvforsaking',),
'selvforsakingene': ('selvforsaking',),
'selvforsakinger': ('selvforsaking',),
'selvforsvar': ('selvforsvar',),
'selvforsvara': ('selvforsvar',),
'selvforsvarene': ('selvforsvar',),
'selvforsvaret': ('selvforsvar',),
'selvforsyning': ('selvforsyning',),
'selvforsyninga': ('selvforsyning',),
'selvforsyningen': ('selvforsyning',),
'selvforsyningene': ('selvforsyning',),
'selvforsyninger': ('selvforsyning',),
'selvforsyningsgrad': ('selvforsyningsgrad',),
'selvforsyningsgraden': ('selvforsyningsgrad',),
'selvforsyningsgradene': ('selvforsyningsgrad',),
'selvforsyningsgrader': ('selvforsyningsgrad',),
'selvfølelse': ('selvfølelse',),
'selvfølelsen': ('selvfølelse',),
'selvfølelsene': ('selvfølelse',),
'selvfølelser': ('selvfølelse',),
'selvfølga': ('selvfølge',),
'selvfølge': ('selvfølge',),
'selvfølgen': ('selvfølge',),
'selvfølgene': ('selvfølge',),
'selvfølger': ('selvfølge',),
'selvfølgelighet': ('selvfølgelighet',),
'selvfølgeligheta': ('selvfølgelighet',),
'selvfølgeligheten': ('selvfølgelighet',),
'selvfølgelighetene': ('selvfølgelighet',),
'selvfølgeligheter': ('selvfølgelighet',),
'selvgodhet': ('selvgodhet',),
'selvgodheta': ('selvgodhet',),
'selvgodheten': ('selvgodhet',),
'selvgodhetene': ('selvgodhet',),
'selvgodheter': ('selvgodhet',),
'selvhevdelse': ('selvhevdelse',),
'selvhevdelsen': ('selvhevdelse',),
'selvhevdelsene': ('selvhevdelse',),
'selvhevdelser': ('selvhevdelse',),
'selvhevding': ('selvhevding',),
'selvhevdinga': ('selvhevding',),
'selvhevdingen': ('selvhevding',),
'selvhevdingene': ('selvhevding',),
'selvhevdinger': ('selvhevding',),
'selvhjelp': ('selvhjelp',),
'selvhjelpa': ('selvhjelp',),
'selvhjelpen': ('selvhjelp',),
'selvhjelpene': ('selvhjelp',),
'selvhjelper': ('selvhjelp',),
'selvironi': ('selvironi',),
'selvironien': ('selvironi',),
'selvironiene': ('selvironi',),
'selvironier': ('selvironi',),
'selviskhet': ('selviskhet',),
'selviskheta': ('selviskhet',),
'selviskheten': ('selviskhet',),
'selviskhetene': ('selviskhet',),
'selviskheter': ('selviskhet',),
'selvjustis': ('selvjustis',),
'selvjustisen': ('selvjustis',),
'selvjustisene': ('selvjustis',),
'selvjustiser': ('selvjustis',),
'selvkjensla': ('selvkjensle',),
'selvkjensle': ('selvkjensle',),
'selvkjenslen': ('selvkjensle',),
'selvkjenslene': ('selvkjensle',),
'selvkjensler': ('selvkjensle',),
'selvkontroll': ('selvkontroll',),
'selvkontrollen': ('selvkontroll',),
'selvkontrollene': ('selvkontroll',),
'selvkontroller': ('selvkontroll',),
'selvkost': ('selvkost',),
'selvkosta': ('selvkost',),
'selvkostene': ('selvkost',),
'selvkostet': ('selvkost',),
'selvkostnad': ('selvkostnad',),
'selvkostnaden': ('selvkostnad',),
'selvkostnadene': ('selvkostnad',),
'selvkostnader': ('selvkostnad',),
'selvkritikk': ('selvkritikk',),
'selvkritikken': ('selvkritikk',),
'selvkritikkene': ('selvkritikk',),
'selvkritikker': ('selvkritikk',),
'selvladegevær': ('selvladegevær',),
'selvladegeværa': ('selvladegevær',),
'selvladegeværene': ('selvladegevær',),
'selvladegeværer': ('selvladegevær',),
'selvladegeværet': ('selvladegevær',),
'selvmedlidenhet': ('selvmedlidenhet',),
'selvmedlidenheta': ('selvmedlidenhet',),
'selvmedlidenheten': ('selvmedlidenhet',),
'selvmedlidenhetene': ('selvmedlidenhet',),
'selvmedlidenheter': ('selvmedlidenhet',),
'selvmord': ('selvmord',),
'selvmorda': ('selvmord',),
'selvmordene': ('selvmord',),
'selvmordet': ('selvmord',),
'selvmorder': ('selvmorder',),
'selvmordere': ('selvmorder',),
'selvmorderen': ('selvmorder',),
'selvmorderer': ('selvmorder',),
'selvmorderne': ('selvmorder',),
'selvmotsigelse': ('selvmotsigelse',),
'selvmotsigelsen': ('selvmotsigelse',),
'selvmotsigelsene': ('selvmotsigelse',),
'selvmotsigelser': ('selvmotsigelse',),
'selvmål': ('selvmål',),
'selvmåla': ('selvmål',),
'selvmålene': ('selvmål',),
'selvmålet': ('selvmål',),
'selvoppgiing': ('selvoppgiing',),
'selvoppgiinga': ('selvoppgiing',),
'selvoppgiingen': ('selvoppgiing',),
'selvoppgiingene': ('selvoppgiing',),
'selvoppgiinger': ('selvoppgiing',),
'selvoppgivelse': ('selvoppgivelse',),
'selvoppgivelsen': ('selvoppgivelse',),
'selvoppgivelsene': ('selvoppgivelse',),
'selvoppgivelser': ('selvoppgivelse',),
'selvoppgiving': ('selvoppgiving',),
'selvoppgivinga': ('selvoppgiving',),
'selvoppgivingen': ('selvoppgiving',),
'selvoppgivingene': ('selvoppgiving',),
'selvoppgivinger': ('selvoppgiving',),
'selvoppholdelse': ('selvoppholdelse',),
'selvoppholdelsen': ('selvoppholdelse',),
'selvoppholdelsene': ('selvoppholdelse',),
'selvoppholdelser': ('selvoppholdelse',),
'selvoppholdelsesdrift': ('selvoppholdelsesdrift',),
'selvoppholdelsesdrifta': ('selvoppholdelsesdrift',),
'selvoppholdelsesdriften': ('selvoppholdelsesdrift',),
'selvoppholdelsesdriftene': ('selvoppholdelsesdrift',),
'selvoppholdelsesdrifter': ('selvoppholdelsesdrift',),
'selvopphøyelse': ('selvopphøyelse',),
'selvopphøyelsen': ('selvopphøyelse',),
'selvopphøyelsene': ('selvopphøyelse',),
'selvopphøyelser': ('selvopphøyelse',),
'selvoppofrelse': ('selvoppofrelse',),
'selvoppofrelsen': ('selvoppofrelse',),
'selvoppofrelsene': ('selvoppofrelse',),
'selvoppofrelser': ('selvoppofrelse',),
'selvoppofring': ('selvoppofring',),
'selvoppofringa': ('selvoppofring',),
'selvoppofringen': ('selvoppofring',),
'selvoppofringene': ('selvoppofring',),
'selvoppofringer': ('selvoppofring',),
'selvopptatthet': ('selvopptatthet',),
'selvopptattheta': ('selvopptatthet',),
'selvopptattheten': ('selvopptatthet',),
'selvopptatthetene': ('selvopptatthet',),
'selvopptattheter': ('selvopptatthet',),
'selvovervinnelse': ('selvovervinnelse',),
'selvovervinnelsen': ('selvovervinnelse',),
'selvovervinnelsene': ('selvovervinnelse',),
'selvovervinnelser': ('selvovervinnelse',),
'selvovervurdering': ('selvovervurdering',),
'selvovervurderinga': ('selvovervurdering',),
'selvovervurderingen': ('selvovervurdering',),
'selvovervurderingene': ('selvovervurdering',),
'selvovervurderinger': ('selvovervurdering',),
'selvpiner': ('selvpiner',),
'selvpinere': ('selvpiner',),
'selvpineren': ('selvpiner',),
'selvpinerer': ('selvpiner',),
'selvpinerne': ('selvpiner',),
'selvpinsel': ('selvpinsel',),
'selvpinselen': ('selvpinsel',),
'selvpinslene': ('selvpinsel',),
'selvpinsler': ('selvpinsel',),
'selvplager': ('selvplager',),
'selvplagere': ('selvplager',),
'selvplageren': ('selvplager',),
'selvplagerer': ('selvplager',),
'selvplagerne': ('selvplager',),
'selvplageri': ('selvplageri',),
'selvplageria': ('selvplageri',),
'selvplageriene': ('selvplageri',),
'selvplagerier': ('selvplageri',),
'selvplageriet': ('selvplageri',),
'selvplaging': ('selvplaging',),
'selvplaginga': ('selvplaging',),
'selvplagingen': ('selvplaging',),
'selvplagingene': ('selvplaging',),
'selvplaginger': ('selvplaging',),
'selvplukk': ('selvplukk',),
'selvplukken': ('selvplukk',),
'selvplukkene': ('selvplukk',),
'selvplukker': ('selvplukk',),
'selvplukker': ('selvplukker',),
'selvplukkere': ('selvplukker',),
'selvplukkeren': ('selvplukker',),
'selvplukkerer': ('selvplukker',),
'selvplukkerne': ('selvplukker',),
'selvplukking': ('selvplukking',),
'selvplukkinga': ('selvplukking',),
'selvplukkingen': ('selvplukking',),
'selvplukkingene': ('selvplukking',),
'selvplukkinger': ('selvplukking',),
'selvportrett': ('selvportrett',),
'selvportretta': ('selvportrett',),
'selvportrettene': ('selvportrett',),
'selvportretter': ('selvportrett',),
'selvportrettet': ('selvportrett',),
'selvproletarisering': ('selvproletarisering',),
'selvproletariseringa': ('selvproletarisering',),
'selvproletariseringen': ('selvproletarisering',),
'selvproletariseringene': ('selvproletarisering',),
'selvproletariseringer': ('selvproletarisering',),
'selvprøvelse': ('selvprøvelse',),
'selvprøvelsen': ('selvprøvelse',),
'selvprøvelsene': ('selvprøvelse',),
'selvprøvelser': ('selvprøvelse',),
'selvprøving': ('selvprøving',),
'selvprøvinga': ('selvprøving',),
'selvprøvingen': ('selvprøving',),
'selvprøvingene': ('selvprøving',),
'selvprøvinger': ('selvprøving',),
'selvransakelse': ('selvransakelse',),
'selvransakelsen': ('selvransakelse',),
'selvransakelsene': ('selvransakelse',),
'selvransakelser': ('selvransakelse',),
'selvransaking': ('selvransaking',),
'selvransakinga': ('selvransaking',),
'selvransakingen': ('selvransaking',),
'selvransakingene': ('selvransaking',),
'selvransakinger': ('selvransaking',),
'selvrealisering': ('selvrealisering',),
'selvrealiseringa': ('selvrealisering',),
'selvrealiseringen': ('selvrealisering',),
'selvrealiseringene': ('selvrealisering',),
'selvrealiseringer': ('selvrealisering',),
'selvrespekt': ('selvrespekt',),
'selvrespekten': ('selvrespekt',),
'selvrespektene': ('selvrespekt',),
'selvrespekter': ('selvrespekt',),
'selvrisiko': ('selvrisiko',),
'selvrisikoen': ('selvrisiko',),
'selvrisikoene': ('selvrisiko',),
'selvrisikoer': ('selvrisiko',),
'selvros': ('selvros',),
'selvrosen': ('selvros',),
'selvrosene': ('selvros',),
'selvroser': ('selvros',),
'selvråderett': ('selvråderett',),
'selvråderetten': ('selvråderett',),
'selvråderettene': ('selvråderett',),
'selvråderetter': ('selvråderett',),
'selvsikkerhet': ('selvsikkerhet',),
'selvsikkerheta': ('selvsikkerhet',),
'selvsikkerheten': ('selvsikkerhet',),
'selvsikkerhetene': ('selvsikkerhet',),
'selvsikkerheter': ('selvsikkerhet',),
'selvskott': ('selvskott',),
'selvskotta': ('selvskott',),
'selvskottene': ('selvskott',),
'selvskottet': ('selvskott',),
'selvskryt': ('selvskryt',),
'selvskryta': ('selvskryt',),
'selvskrytene': ('selvskryt',),
'selvskrytet': ('selvskryt',),
'selvskudd': ('selvskudd',),
'selvskudda': ('selvskudd',),
'selvskuddene': ('selvskudd',),
'selvskuddet': ('selvskudd',),
'selvskyldner': ('selvskyldner',),
'selvskyldnere': ('selvskyldner',),
'selvskyldneren': ('selvskyldner',),
'selvskyldnerer': ('selvskyldner',),
'selvskyldnerne': ('selvskyldner',),
'selvskyldnerkausjon': ('selvskyldnerkausjon',),
'selvskyldnerkausjonen': ('selvskyldnerkausjon',),
'selvskyldnerkausjonene': ('selvskyldnerkausjon',),
'selvskyldnerkausjoner': ('selvskyldnerkausjon',),
'selvskyldnerkausjonist': ('selvskyldnerkausjonist',),
'selvskyldnerkausjonisten': ('selvskyldnerkausjonist',),
'selvskyldnerkausjonistene': ('selvskyldnerkausjonist',),
'selvskyldnerkausjonister': ('selvskyldnerkausjonist',),
'selvstarter': ('selvstarter',),
'selvstartere': ('selvstarter',),
'selvstarteren': ('selvstarter',),
'selvstarterer': ('selvstarter',),
'selvstarterne': ('selvstarter',),
'selvstendighet': ('selvstendighet',),
'selvstendigheta': ('selvstendighet',),
'selvstendigheten': ('selvstendighet',),
'selvstendighetene': ('selvstendighet',),
'selvstendigheter': ('selvstendighet',),
'selvstendighetsfølelse': ('selvstendighetsfølelse',),
'selvstendighetsfølelsen': ('selvstendighetsfølelse',),
'selvstendighetsfølelsene': ('selvstendighetsfølelse',),
'selvstendighetsfølelser': ('selvstendighetsfølelse',),
'selvstendighetsparti': ('selvstendighetsparti',),
'selvstendighetspartia': ('selvstendighetsparti',),
'selvstendighetspartiene': ('selvstendighetsparti',),
'selvstendighetspartier': ('selvstendighetsparti',),
'selvstendighetspartiet': ('selvstendighetsparti',),
'selvstendighetstrang': ('selvstendighetstrang',),
'selvstendighetstrangen': ('selvstendighetstrang',),
'selvstendighetstrangene': ('selvstendighetstrang',),
'selvstendighetstranger': ('selvstendighetstrang',),
'selvstudia': ('selvstudium',),
'selvstudiene': ('selvstudium',),
'selvstudier': ('selvstudium',),
'selvstudiet': ('selvstudium',),
'selvstudium': ('selvstudium',),
'selvstyra': ('selvstyre',),
'selvstyre': ('selvstyre',),
'selvstyrene': ('selvstyre',),
'selvstyrer': ('selvstyre',),
'selvstyret': ('selvstyre',),
'selvstyring': ('selvstyring',),
'selvstyringa': ('selvstyring',),
'selvstyringen': ('selvstyring',),
'selvstyringene': ('selvstyring',),
'selvstyringer': ('selvstyring',),
'selvtekt': ('selvtekt',),
'selvtekta': ('selvtekt',),
'selvtekten': ('selvtekt',),
'selvtektene': ('selvtekt',),
'selvtekter': ('selvtekt',),
'selvtillit': ('selvtillit',),
'selvtillita': ('selvtillit',),
'selvtilliten': ('selvtillit',),
'selvtillitene': ('selvtillit',),
'selvtilliter': ('selvtillit',),
'selvtrimmer': ('selvtrimmer',),
'selvtrimmere': ('selvtrimmer',),
'selvtrimmeren': ('selvtrimmer',),
'selvtrimmerer': ('selvtrimmer',),
'selvtrimmerne': ('selvtrimmer',),
'selvtrøst': ('selvtrøst',),
'selvtrøsta': ('selvtrøst',),
'selvtrøsten': ('selvtrøst',),
'selvtrøstene': ('selvtrøst',),
'selvtrøster': ('selvtrøst',),
'selvtukt': ('selvtukt',),
'selvtukta': ('selvtukt',),
'selvtukten': ('selvtukt',),
'selvtuktene': ('selvtukt',),
'selvtukter': ('selvtukt',),
'selvutløser': ('selvutløser',),
'selvutløsere': ('selvutløser',),
'selvutløseren': ('selvutløser',),
'selvutløserer': ('selvutløser',),
'selvutløserne': ('selvutløser',),
'selvutløyser': ('selvutløyser',),
'selvutløysere': ('selvutløyser',),
'selvutløyseren': ('selvutløyser',),
'selvutløyserer': ('selvutløyser',),
'selvutløyserne': ('selvutløyser',),
'selvvalg': ('selvvalg',),
'selvvalga': ('selvvalg',),
'selvvalgene': ('selvvalg',),
'selvvalget': ('selvvalg',),
'selvvalgsbutikk': ('selvvalgsbutikk',),
'selvvalgsbutikken': ('selvvalgsbutikk',),
'selvvalgsbutikkene': ('selvvalgsbutikk',),
'selvvalgsbutikker': ('selvvalgsbutikk',),
'semafor': ('semafor',),
'semaforen': ('semafor',),
'semaforene': ('semafor',),
'semaforer': ('semafor',),
'semaforist': ('semaforist',),
'semaforisten': ('semaforist',),
'semaforistene': ('semaforist',),
'semaforister': ('semaforist',),
'semantiker': ('semantiker',),
'semantikere': ('semantiker',),
'semantikeren': ('semantiker',),
'semantikerer': ('semantiker',),
'semantikerne': ('semantiker',),
'semantikk': ('semantikk',),
'semantikken': ('semantikk',),
'semantikkene': ('semantikk',),
'semantikker': ('semantikk',),
'semasiologi': ('semasiologi',),
'semasiologien': ('semasiologi',),
'semasiologiene': ('semasiologi',),
'semasiologier': ('semasiologi',),
'sement': ('sement',),
'sementen': ('sement',),
'sementene': ('sement',),
'sementer': ('sement',),
'semester': ('semester',),
'semesteret': ('semester',),
'semestra': ('semester',),
'semestre': ('semester',),
'semestrene': ('semester',),
'semestret': ('semester',),
'semesteravgift': ('semesteravgift',),
'semesteravgifta': ('semesteravgift',),
'semesteravgiften': ('semesteravgift',),
'semesteravgiftene': ('semesteravgift',),
'semesteravgifter': ('semesteravgift',),
'semifinale': ('semifinale',),
'semifinalen': ('semifinale',),
'semifinalene': ('semifinale',),
'semifinaler': ('semifinale',),
'semifinalist': ('semifinalist',),
'semifinalisten': ('semifinalist',),
'semifinalistene': ('semifinalist',),
'semifinalister': ('semifinalist',),
'semikolon': ('semikolon',),
'semikolona': ('semikolon',),
'semikolonene': ('semikolon',),
'semikoloner': ('semikolon',),
'semikolonet': ('semikolon',),
'semin': ('semin',),
'seminen': ('semin',),
'seminene': ('semin',),
'seminer': ('semin',),
'seminar': ('seminar',),
'seminara': ('seminar',),
'seminarene': ('seminar',),
'seminarer': ('seminar',),
'seminaret': ('seminar',),
'seminarisme': ('seminarisme',),
'seminarismen': ('seminarisme',),
'seminarismene': ('seminarisme',),
'seminarismer': ('seminarisme',),
'seminarist': ('seminarist',),
'seminaristen': ('seminarist',),
'seminaristene': ('seminarist',),
'seminarister': ('seminarist',),
'seminavl': ('seminavl',),
'seminavlen': ('seminavl',),
'seminavlene': ('seminavl',),
'seminavler': ('seminavl',),
'seminokse': ('seminokse',),
'seminoksen': ('seminokse',),
'seminoksene': ('seminokse',),
'seminokser': ('seminokse',),
'seminstasjon': ('seminstasjon',),
'seminstasjonen': ('seminstasjon',),
'seminstasjonene': ('seminstasjon',),
'seminstasjoner': ('seminstasjon',),
'semiologi': ('semiologi',),
'semiologien': ('semiologi',),
'semiologiene': ('semiologi',),
'semiologier': ('semiologi',),
'semiotikk': ('semiotikk',),
'semiotikken': ('semiotikk',),
'semiotikkene': ('semiotikk',),
'semiotikker': ('semiotikk',),
'semitrailer': ('semitrailer',),
'semitrailere': ('semitrailer',),
'semitraileren': ('semitrailer',),
'semitrailerer': ('semitrailer',),
'semitrailerne': ('semitrailer',),
'semitt': ('semitt',),
'semitten': ('semitt',),
'semittene': ('semitt',),
'semitter': ('semitt',),
'semittisk': ('semittisk',),
'semittisken': ('semittisk',),
'semittiskene': ('semittisk',),
'semittisker': ('semittisk',),
'semittisme': ('semittisme',),
'semittismen': ('semittisme',),
'semittismene': ('semittisme',),
'semittismer': ('semittisme',),
'semja': ('semje',),
'semje': ('semje',),
'semjen': ('semje',),
'semjene': ('semje',),
'semjer': ('semje',),
'semlene': ('semmel',),
'semler': ('semmel',),
'semmel': ('semmel',),
'semmelen': ('semmel',),
'semule': ('semule',),
'semulen': ('semule',),
'semulene': ('semule',),
'semuler': ('semule',),
'semulegraut': ('semulegraut',),
'semulegrauten': ('semulegraut',),
'semulegrautene': ('semulegraut',),
'semulegrauter': ('semulegraut',),
'semulegryn': ('semulegryn',),
'semulegryna': ('semulegryn',),
'semulegrynene': ('semulegryn',),
'semulegrynet': ('semulegryn',),
'semulegrøt': ('semulegrøt',),
'semulegrøten': ('semulegrøt',),
'semulegrøtene': ('semulegrøt',),
'semulegrøter': ('semulegrøt',),
'semulepudding': ('semulepudding',),
'semulepuddingen': ('semulepudding',),
'semulepuddingene': ('semulepudding',),
'semulepuddinger': ('semulepudding',),
'sen': ('sen',),
'senen': ('sen',),
'senene': ('sen',),
'senat': ('senat',),
'senata': ('senat',),
'senatene': ('senat',),
'senater': ('senat',),
'senatet': ('senat',),
'senator': ('senator',),
'senatoren': ('senator',),
'senatorene': ('senator',),
'senatorer': ('senator',),
'sendebud': ('sendebud',),
'sendebuda': ('sendebud',),
'sendebudene': ('sendebud',),
'sendebudet': ('sendebud',),
'sendeferd': ('sendeferd',),
'sendeferda': ('sendeferd',),
'sendeferden': ('sendeferd',),
'sendeferdene': ('sendeferd',),
'sendeferder': ('sendeferd',),
'sendelag': ('sendelag',),
'sendelaga': ('sendelag',),
'sendelagene': ('sendelag',),
'sendelaget': ('sendelag',),
'sendelektor': ('sendelektor',),
'sendelektoren': ('sendelektor',),
'sendelektorene': ('sendelektor',),
'sendelektorer': ('sendelektor',),
'sendemann': ('sendemann',),
'sendemannen': ('sendemann',),
'sendemenn': ('sendemann',),
'sendemennene': ('sendemann',),
'sendeplata': ('sendeplate',),
'sendeplate': ('sendeplate',),
'sendeplaten': ('sendeplate',),
'sendeplatene': ('sendeplate',),
'sendeplater': ('sendeplate',),
'sender': ('sender',),
'sendere': ('sender',),
'senderen': ('sender',),
'senderer': ('sender',),
'senderne': ('sender',),
'senderstasjon': ('senderstasjon',),
'senderstasjonen': ('senderstasjon',),
'senderstasjonene': ('senderstasjon',),
'senderstasjoner': ('senderstasjon',),
'sendetid': ('sendetid',),
'sendetida': ('sendetid',),
'sendetiden': ('sendetid',),
'sendetidene': ('sendetid',),
'sendetider': ('sendetid',),
'sending': ('sending',),
'sendinga': ('sending',),
'sendingen': ('sending',),
'sendingene': ('sending',),
'sendinger': ('sending',),
'sendingskorg': ('sendingskorg',),
'sendingskorga': ('sendingskorg',),
'sendingskorgen': ('sendingskorg',),
'sendingskorgene': ('sendingskorg',),
'sendingskorger': ('sendingskorg',),
'sendingskurv': ('sendingskurv',),
'sendingskurva': ('sendingskurv',),
'sendingskurven': ('sendingskurv',),
'sendingskurvene': ('sendingskurv',),
'sendingskurver': ('sendingskurv',),
'sendrektighet': ('sendrektighet',),
'sendrektigheta': ('sendrektighet',),
'sendrektigheten': ('sendrektighet',),
'sendrektighetene': ('sendrektighet',),
'sendrektigheter': ('sendrektighet',),
'sena': ('sene',),
'sene': ('sene',),
'senen': ('sene',),
'senene': ('sene',),
'sener': ('sene',),
'senebetennelse': ('senebetennelse',),
'senebetennelsen': ('senebetennelse',),
'senebetennelsene': ('senebetennelse',),
'senebetennelser': ('senebetennelse',),
'senegaleser': ('senegaleser',),
'senegalesere': ('senegaleser',),
'senegaleseren': ('senegaleser',),
'senegaleserer': ('senegaleser',),
'senegaleserne': ('senegaleser',),
'senehinna': ('senehinne',),
'senehinne': ('senehinne',),
'senehinnen': ('senehinne',),
'senehinnene': ('senehinne',),
'senehinner': ('senehinne',),
'seneskjede': ('seneskjede',),
'seneskjeden': ('seneskjede',),
'seneskjedene': ('seneskjede',),
'seneskjeder': ('seneskjede',),
'seneskjedebetennelse': ('seneskjedebetennelse',),
'seneskjedebetennelsen': ('seneskjedebetennelse',),
'seneskjedebetennelsene': ('seneskjedebetennelse',),
'seneskjedebetennelser': ('seneskjedebetennelse',),
'senestrekk': ('senestrekk',),
'senestrekka': ('senestrekk',),
'senestrekken': ('senestrekk',),
'senestrekkene': ('senestrekk',),
'senestrekker': ('senestrekk',),
'senestrekket': ('senestrekk',),
'senetrekning': ('senetrekning',),
'senetrekninga': ('senetrekning',),
'senetrekningen': ('senetrekning',),
'senetrekningene': ('senetrekning',),
'senetrekninger': ('senetrekning',),
'senevev': ('senevev',),
'seneveva': ('senevev',),
'senevevene': ('senevev',),
'senevevet': ('senevev',),
'seng': ('seng',),
'senga': ('seng',),
'sengen': ('seng',),
'sengene': ('seng',),
'senger': ('seng',),
'sengebenk': ('sengebenk',),
'sengebenken': ('sengebenk',),
'sengebenkene': ('sengebenk',),
'sengebenker': ('sengebenk',),
'sengebotn': ('sengebotn',),
'sengebotnen': ('sengebotn',),
'sengebotnene': ('sengebotn',),
'sengebotner': ('sengebotn',),
'sengebunn': ('sengebunn',),
'sengebunnen': ('sengebunn',),
'sengebunnene': ('sengebunn',),
'sengebunner': ('sengebunn',),
'sengeforlegger': ('sengeforlegger',),
'sengeforleggere': ('sengeforlegger',),
'sengeforleggeren': ('sengeforlegger',),
'sengeforleggerer': ('sengeforlegger',),
'sengeforleggerne': ('sengeforlegger',),
'sengehalm': ('sengehalm',),
'sengehalmen': ('sengehalm',),
'sengehalmene': ('sengehalm',),
'sengehalmer': ('sengehalm',),
'sengehest': ('sengehest',),
'sengehesten': ('sengehest',),
'sengehestene': ('sengehest',),
'sengehester': ('sengehest',),
'sengehygga': ('sengehygge',),
'sengehygge': ('sengehygge',),
'sengehyggen': ('sengehygge',),
'sengehyggene': ('sengehygge',),
'sengehygger': ('sengehygge',),
'sengekamerat': ('sengekamerat',),
'sengekameraten': ('sengekamerat',),
'sengekameratene': ('sengekamerat',),
'sengekamerater': ('sengekamerat',),
'sengekammer': ('sengekammer',),
'sengekammeret': ('sengekammer',),
'sengekamra': ('sengekammer',),
'sengekamre': ('sengekammer',),
'sengekamrene': ('sengekammer',),
'sengekant': ('sengekant',),
'sengekanten': ('sengekant',),
'sengekantene': ('sengekant',),
'sengekanter': ('sengekant',),
'sengeklær': ('sengeklær',),
'sengeklærne': ('sengeklær',),
'sengeplass': ('sengeplass',),
'sengeplassen': ('sengeplass',),
'sengeplassene': ('sengeplass',),
'sengeplasser': ('sengeplass',),
'sengerøyker': ('sengerøyker',),
'sengerøykere': ('sengerøyker',),
'sengerøykeren': ('sengerøyker',),
'sengerøykerer': ('sengerøyker',),
'sengerøykerne': ('sengerøyker',),
'sengerøyking': ('sengerøyking',),
'sengerøykinga': ('sengerøyking',),
'sengerøykingen': ('sengerøyking',),
'sengerøykingene': ('sengerøyking',),
'sengerøykinger': ('sengerøyking',),
'sengestokk': ('sengestokk',),
'sengestokken': ('sengestokk',),
'sengestokkene': ('sengestokk',),
'sengestokker': ('sengestokk',),
'sengestolpe': ('sengestolpe',),
'sengestolpen': ('sengestolpe',),
'sengestolpene': ('sengestolpe',),
'sengestolper': ('sengestolpe',),
'sengeteppa': ('sengeteppe',),
'sengeteppe': ('sengeteppe',),
'sengeteppene': ('sengeteppe',),
'sengetepper': ('sengeteppe',),
'sengeteppet': ('sengeteppe',),
'sengetid': ('sengetid',),
'sengetida': ('sengetid',),
'sengetiden': ('sengetid',),
'sengetidene': ('sengetid',),
'sengetider': ('sengetid',),
'sengevæter': ('sengevæter',),
'sengevætere': ('sengevæter',),
'sengevæteren': ('sengevæter',),
'sengevæterer': ('sengevæter',),
'sengevæterne': ('sengevæter',),
'sengevæting': ('sengevæting',),
'sengevætinga': ('sengevæting',),
'sengevætingen': ('sengevæting',),
'sengevætingene': ('sengevæting',),
'sengevætinger': ('sengevæting',),
'sengkamerat': ('sengkamerat',),
'sengkameraten': ('sengkamerat',),
'sengkameratene': ('sengkamerat',),
'sengkamerater': ('sengkamerat',),
'sengkammer': ('sengkammer',),
'sengkammeret': ('sengkammer',),
'sengkamra': ('sengkammer',),
'sengkamre': ('sengkammer',),
'sengkamrene': ('sengkammer',),
'sengklær': ('sengklær',),
'sengklærne': ('sengklær',),
'senilitet': ('senilitet',),
'seniliteten': ('senilitet',),
'senilitetene': ('senilitet',),
'seniliteter': ('senilitet',),
'senior': ('senior',),
'senioren': ('senior',),
'seniorene': ('senior',),
'seniorer': ('senior',),
'seniorat': ('seniorat',),
'seniorata': ('seniorat',),
'senioratene': ('seniorat',),
'seniorater': ('seniorat',),
'senioratet': ('seniorat',),
'seniorklassa': ('seniorklasse',),
'seniorklasse': ('seniorklasse',),
'seniorklassen': ('seniorklasse',),
'seniorklassene': ('seniorklasse',),
'seniorklasser': ('seniorklasse',),
'seniorløper': ('seniorløper',),
'seniorløpere': ('seniorløper',),
'seniorløperen': ('seniorløper',),
'seniorløperer': ('seniorløper',),
'seniorløperne': ('seniorløper',),
'seniorsjef': ('seniorsjef',),
'seniorsjefen': ('seniorsjef',),
'seniorsjefene': ('seniorsjef',),
'seniorsjefer': ('seniorsjef',),
'senit': ('senit',),
'senita': ('senit',),
'senitene': ('senit',),
'senitet': ('senit',),
'senk': ('senk',),
'senkapitalisme': ('senkapitalisme',),
'senkapitalismen': ('senkapitalisme',),
'senkapitalismene': ('senkapitalisme',),
'senkapitalismer': ('senkapitalisme',),
'senkekassa': ('senkekasse',),
'senkekasse': ('senkekasse',),
'senkekassen': ('senkekasse',),
'senkekassene': ('senkekasse',),
'senkekasser': ('senkekasse',),
'senkekjøl': ('senkekjøl',),
'senkekjølen': ('senkekjøl',),
'senkekjølene': ('senkekjøl',),
'senkekjøler': ('senkekjøl',),
'senkekjølsbåt': ('senkekjølsbåt',),
'senkekjølsbåten': ('senkekjølsbåt',),
'senkekjølsbåtene': ('senkekjølsbåt',),
'senkekjølsbåter': ('senkekjølsbåt',),
'senkkassa': ('senkkasse',),
'senkkasse': ('senkkasse',),
'senkkassen': ('senkkasse',),
'senkkassene': ('senkkasse',),
'senkkasser': ('senkkasse',),
'senkning': ('senkning',),
'senkninga': ('senkning',),
'senkningen': ('senkning',),
'senkningene': ('senkning',),
'senkninger': ('senkning',),
'senkningsreaksjon': ('senkningsreaksjon',),
'senkningsreaksjonen': ('senkningsreaksjon',),
'senkningsreaksjonene': ('senkningsreaksjon',),
'senkningsreaksjoner': ('senkningsreaksjon',),
'senn': ('senn',),
'senna': ('senna',),
'sennaen': ('senna',),
'sennaene': ('senna',),
'sennaer': ('senna',),
'sennegras': ('sennegras',),
'sennegrasa': ('sennegras',),
'sennegrasene': ('sennegras',),
'sennegraset': ('sennegras',),
'sennegress': ('sennegress',),
'sennegressa': ('sennegress',),
'sennegressene': ('sennegress',),
'sennegresset': ('sennegress',),
'sennep': ('sennep',),
'sennepen': ('sennep',),
'sennepene': ('sennep',),
'senneper': ('sennep',),
'sennepsfrø': ('sennepsfrø',),
'sennepsfrøa': ('sennepsfrø',),
'sennepsfrøene': ('sennepsfrø',),
'sennepsfrøet': ('sennepsfrø',),
'sennepsgass': ('sennepsgass',),
'sennepsgassen': ('sennepsgass',),
'sennepsgassene': ('sennepsgass',),
'sennepsgasser': ('sennepsgass',),
'sennepskorn': ('sennepskorn',),
'sennepskorna': ('sennepskorn',),
'sennepskornene': ('sennepskorn',),
'sennepskornet': ('sennepskorn',),
'sennepskrukka': ('sennepskrukke',),
'sennepskrukke': ('sennepskrukke',),
'sennepskrukken': ('sennepskrukke',),
'sennepskrukkene': ('sennepskrukke',),
'sennepskrukker': ('sennepskrukke',),
'sennesblad': ('sennesblad',),
'sennesblada': ('sennesblad',),
'sennesbladene': ('sennesblad',),
'sennesblader': ('sennesblad',),
'sennesbladet': ('sennesblad',),
'sennesgraut': ('sennesgraut',),
'sennesgrauten': ('sennesgraut',),
'sennesgrautene': ('sennesgraut',),
'sennesgrauter': ('sennesgraut',),
'sennesgrøt': ('sennesgrøt',),
'sennesgrøten': ('sennesgrøt',),
'sennesgrøtene': ('sennesgrøt',),
'sennesgrøter': ('sennesgrøt',),
'senneste': ('senneste',),
'sennesteen': ('senneste',),
'sennesteene': ('senneste',),
'sennesteer': ('senneste',),
'sensasjon': ('sensasjon',),
'sensasjonen': ('sensasjon',),
'sensasjonene': ('sensasjon',),
'sensasjoner': ('sensasjon',),
'sensasjonsavis': ('sensasjonsavis',),
'sensasjonsavisa': ('sensasjonsavis',),
'sensasjonsavisen': ('sensasjonsavis',),
'sensasjonsavisene': ('sensasjonsavis',),
'sensasjonsaviser': ('sensasjonsavis',),
'sensasjonslyst': ('sensasjonslyst',),
'sensasjonslysta': ('sensasjonslyst',),
'sensasjonslysten': ('sensasjonslyst',),
'sensasjonslystene': ('sensasjonslyst',),
'sensasjonslyster': ('sensasjonslyst',),
'sensasjonspressa': ('sensasjonspresse',),
'sensasjonspresse': ('sensasjonspresse',),
'sensasjonspressen': ('sensasjonspresse',),
'sensasjonspressene': ('sensasjonspresse',),
'sensasjonspresser': ('sensasjonspresse',),
'sensasjonsstoff': ('sensasjonsstoff',),
'sensasjonsstoffa': ('sensasjonsstoff',),
'sensasjonsstoffene': ('sensasjonsstoff',),
'sensasjonsstoffer': ('sensasjonsstoff',),
'sensasjonsstoffet': ('sensasjonsstoff',),
'sensibilitet': ('sensibilitet',),
'sensibiliteten': ('sensibilitet',),
'sensibilitetene': ('sensibilitet',),
'sensibiliteter': ('sensibilitet',),
'sensitivitet': ('sensitivitet',),
'sensitiviteten': ('sensitivitet',),
'sensitivitetene': ('sensitivitet',),
'sensitiviteter': ('sensitivitet',),
'sensitivitetstrening': ('sensitivitetstrening',),
'sensitivitetstreninga': ('sensitivitetstrening',),
'sensitivitetstreningen': ('sensitivitetstrening',),
'sensitivitetstreningene': ('sensitivitetstrening',),
'sensitivitetstreninger': ('sensitivitetstrening',),
'sensommer': ('sensommer',),
'sensommere': ('sensommer',),
'sensommeren': ('sensommer',),
'sensommerne': ('sensommer',),
'sensomre': ('sensommer',),
'sensomrene': ('sensommer',),
'sensomrer': ('sensommer',),
'sensor': ('sensor',),
'sensoren': ('sensor',),
'sensorene': ('sensor',),
'sensorer': ('sensor',),
'sensualisme': ('sensualisme',),
'sensualismen': ('sensualisme',),
'sensualismene': ('sensualisme',),
'sensualismer': ('sensualisme',),
'sensualist': ('sensualist',),
'sensualisten': ('sensualist',),
'sensualistene': ('sensualist',),
'sensualister': ('sensualist',),
'sensualitet': ('sensualitet',),
'sensualiteten': ('sensualitet',),
'sensualitetene': ('sensualitet',),
'sensualiteter': ('sensualitet',),
'sensur': ('sensur',),
'sensuren': ('sensur',),
'sensurene': ('sensur',),
'sensurer': ('sensur',),
'sentens': ('sentens',),
'sentensen': ('sentens',),
'sentensene': ('sentens',),
'sentenser': ('sentens',),
'senter': ('senter',),
'sentere': ('senter',),
'senteren': ('senter',),
'senterer': ('senter',),
'senterne': ('senter',),
'senter': ('senter',),
'senteret': ('senter',),
'sentra': ('senter',),
'sentre': ('senter',),
'sentrene': ('senter',),
'sentret': ('senter',),
'senterbord': ('senterbord',),
'senterborda': ('senterbord',),
'senterbordene': ('senterbord',),
'senterborder': ('senterbord',),
'senterbordet': ('senterbord',),
'senterhalf': ('senterhalf',),
'senterhalfen': ('senterhalf',),
'senterhalfene': ('senterhalf',),
'senterhalfer': ('senterhalf',),
'senterløper': ('senterløper',),
'senterløpere': ('senterløper',),
'senterløperen': ('senterløper',),
'senterløperer': ('senterløper',),
'senterløperne': ('senterløper',),
'sentimentalist': ('sentimentalist',),
'sentimentalisten': ('sentimentalist',),
'sentimentalistene': ('sentimentalist',),
'sentimentalister': ('sentimentalist',),
'sentimentalitet': ('sentimentalitet',),
'sentimentaliteten': ('sentimentalitet',),
'sentimentalitetene': ('sentimentalitet',),
'sentimentaliteter': ('sentimentalitet',),
'sentral': ('sentral',),
'sentralen': ('sentral',),
'sentralene': ('sentral',),
'sentraler': ('sentral',),
'sentraladministrasjon': ('sentraladministrasjon',),
'sentraladministrasjonen': ('sentraladministrasjon',),
'sentraladministrasjonene': ('sentraladministrasjon',),
'sentraladministrasjoner': ('sentraladministrasjon',),
'sentralafrikaner': ('sentralafrikaner',),
'sentralafrikanere': ('sentralafrikaner',),
'sentralafrikaneren': ('sentralafrikaner',),
'sentralafrikanerer': ('sentralafrikaner',),
'sentralafrikanerne': ('sentralafrikaner',),
'sentralbanestasjon': ('sentralbanestasjon',),
'sentralbanestasjonen': ('sentralbanestasjon',),
'sentralbanestasjonene': ('sentralbanestasjon',),
'sentralbanestasjoner': ('sentralbanestasjon',),
'sentralbank': ('sentralbank',),
'sentralbanken': ('sentralbank',),
'sentralbankene': ('sentralbank',),
'sentralbanker': ('sentralbank',),
'sentralbord': ('sentralbord',),
'sentralborda': ('sentralbord',),
'sentralbordene': ('sentralbord',),
'sentralborder': ('sentralbord',),
'sentralbordet': ('sentralbord',),
'sentralbordbetjent': ('sentralbordbetjent',),
'sentralbordbetjenten': ('sentralbordbetjent',),
'sentralbordbetjentene': ('sentralbordbetjent',),
'sentralbordbetjenter': ('sentralbordbetjent',),
'sentralborddama': ('sentralborddame',),
'sentralborddame': ('sentralborddame',),
'sentralborddamen': ('sentralborddame',),
'sentralborddamene': ('sentralborddame',),
'sentralborddamer': ('sentralborddame',),
'sentralenhet': ('sentralenhet',),
'sentralenheta': ('sentralenhet',),
'sentralenheten': ('sentralenhet',),
'sentralenhetene': ('sentralenhet',),
'sentralenheter': ('sentralenhet',),
'sentralforvaltning': ('sentralforvaltning',),
'sentralforvaltninga': ('sentralforvaltning',),
'sentralforvaltningen': ('sentralforvaltning',),
'sentralforvaltningene': ('sentralforvaltning',),
'sentralforvaltninger': ('sentralforvaltning',),
'sentralfyr': ('sentralfyr',),
'sentralfyren': ('sentralfyr',),
'sentralfyrene': ('sentralfyr',),
'sentralfyrer': ('sentralfyr',),
'sentralfyring': ('sentralfyring',),
'sentralfyringa': ('sentralfyring',),
'sentralfyringen': ('sentralfyring',),
'sentralfyringene': ('sentralfyring',),
'sentralfyringer': ('sentralfyring',),
'sentralisasjon': ('sentralisasjon',),
'sentralisasjonen': ('sentralisasjon',),
'sentralisasjonene': ('sentralisasjon',),
'sentralisasjoner': ('sentralisasjon',),
'sentralisering': ('sentralisering',),
'sentraliseringa': ('sentralisering',),
'sentraliseringen': ('sentralisering',),
'sentraliseringene': ('sentralisering',),
'sentraliseringer': ('sentralisering',),
'sentraliseringspolitikk': ('sentraliseringspolitikk',),
'sentraliseringspolitikken': ('sentraliseringspolitikk',),
'sentraliseringspolitikkene': ('sentraliseringspolitikk',),
'sentraliseringspolitikker': ('sentraliseringspolitikk',),
'sentralisme': ('sentralisme',),
'sentralismen': ('sentralisme',),
'sentralismene': ('sentralisme',),
'sentralismer': ('sentralisme',),
'sentralist': ('sentralist',),
'sentralisten': ('sentralist',),
'sentralistene': ('sentralist',),
'sentralister': ('sentralist',),
'sentralkirka': ('sentralkirke',),
'sentralkirke': ('sentralkirke',),
'sentralkirken': ('sentralkirke',),
'sentralkirkene': ('sentralkirke',),
'sentralkirker': ('sentralkirke',),
'sentralkjerka': ('sentralkjerke',),
'sentralkjerke': ('sentralkjerke',),
'sentralkjerken': ('sentralkjerke',),
'sentralkjerkene': ('sentralkjerke',),
'sentralkjerker': ('sentralkjerke',),
'sentrallyrikk': ('sentrallyrikk',),
'sentrallyrikken': ('sentrallyrikk',),
'sentrallyrikkene': ('sentrallyrikk',),
'sentrallyrikker': ('sentrallyrikk',),
'sentralnervesystem': ('sentralnervesystem',),
'sentralnervesystema': ('sentralnervesystem',),
'sentralnervesystemene': ('sentralnervesystem',),
'sentralnervesystemer': ('sentralnervesystem',),
'sentralnervesystemet': ('sentralnervesystem',),
'sentralredaksjon': ('sentralredaksjon',),
'sentralredaksjonen': ('sentralredaksjon',),
'sentralredaksjonene': ('sentralredaksjon',),
'sentralredaksjoner': ('sentralredaksjon',),
'sentralsjukehus': ('sentralsjukehus',),
'sentralsjukehusa': ('sentralsjukehus',),
'sentralsjukehusene': ('sentralsjukehus',),
'sentralsjukehuset': ('sentralsjukehus',),
'sentralskole': ('sentralskole',),
'sentralskolen': ('sentralskole',),
'sentralskolene': ('sentralskole',),
'sentralskoler': ('sentralskole',),
'sentralstasjon': ('sentralstasjon',),
'sentralstasjonen': ('sentralstasjon',),
'sentralstasjonene': ('sentralstasjon',),
'sentralstasjoner': ('sentralstasjon',),
'sentralstyra': ('sentralstyre',),
'sentralstyre': ('sentralstyre',),
'sentralstyrene': ('sentralstyre',),
'sentralstyrer': ('sentralstyre',),
'sentralstyret': ('sentralstyre',),
'sentralsykehus': ('sentralsykehus',),
'sentralsykehusa': ('sentralsykehus',),
'sentralsykehusene': ('sentralsykehus',),
'sentralsykehuset': ('sentralsykehus',),
'sentralvarme': ('sentralvarme',),
'sentralvarmen': ('sentralvarme',),
'sentralvarmene': ('sentralvarme',),
'sentralvarmer': ('sentralvarme',),
'sentralvinkel': ('sentralvinkel',),
'sentralvinkelen': ('sentralvinkel',),
'sentralvinklene': ('sentralvinkel',),
'sentralvinkler': ('sentralvinkel',),
'sentrifugalkraft': ('sentrifugalkraft',),
'sentrifugalkrafta': ('sentrifugalkraft',),
'sentrifugalkraften': ('sentrifugalkraft',),
'sentrifugalkreftene': ('sentrifugalkraft',),
'sentrifugalkrefter': ('sentrifugalkraft',),
'sentrifuge': ('sentrifuge',),
'sentrifugen': ('sentrifuge',),
'sentrifugene': ('sentrifuge',),
'sentrifuger': ('sentrifuge',),
'sentring': ('sentring',),
'sentringa': ('sentring',),
'sentringen': ('sentring',),
'sentringene': ('sentring',),
'sentringer': ('sentring',),
'sentripetalkraft': ('sentripetalkraft',),
'sentripetalkrafta': ('sentripetalkraft',),
'sentripetalkraften': ('sentripetalkraft',),
'sentripetalkreftene': ('sentripetalkraft',),
'sentripetalkrefter': ('sentripetalkraft',),
'sentrisme': ('sentrisme',),
'sentrismen': ('sentrisme',),
'sentrismene': ('sentrisme',),
'sentrismer': ('sentrisme',),
'sentra': ('sentrum',),
'sentraene': ('sentrum',),
'sentre': ('sentrum',),
'sentrene': ('sentrum',),
'sentret': ('sentrum',),
'sentrum': ('sentrum',),
'sentrumet': ('sentrum',),
'sentrumsdannelse': ('sentrumsdannelse',),
'sentrumsdannelsen': ('sentrumsdannelse',),
'sentrumsdannelsene': ('sentrumsdannelse',),
'sentrumsdannelser': ('sentrumsdannelse',),
'sentrumsdanning': ('sentrumsdanning',),
'sentrumsdanninga': ('sentrumsdanning',),
'sentrumsdanningen': ('sentrumsdanning',),
'sentrumsdanningene': ('sentrumsdanning',),
'sentrumsdanninger': ('sentrumsdanning',),
'sentrumsparti': ('sentrumsparti',),
'sentrumspartia': ('sentrumsparti',),
'sentrumspartiene': ('sentrumsparti',),
'sentrumspartier': ('sentrumsparti',),
'sentrumspartiet': ('sentrumsparti',),
'sentrumsregjering': ('sentrumsregjering',),
'sentrumsregjeringa': ('sentrumsregjering',),
'sentrumsregjeringen': ('sentrumsregjering',),
'sentrumsregjeringene': ('sentrumsregjering',),
'sentrumsregjeringer': ('sentrumsregjering',),
'separasjon': ('separasjon',),
'separasjonen': ('separasjon',),
'separasjonene': ('separasjon',),
'separasjoner': ('separasjon',),
'separatfred': ('separatfred',),
'separatfreden': ('separatfred',),
'separatfredene': ('separatfred',),
'separatfreder': ('separatfred',),
'separatisme': ('separatisme',),
'separatismen': ('separatisme',),
'separatismene': ('separatisme',),
'separatismer': ('separatisme',),
'separatist': ('separatist',),
'separatisten': ('separatist',),
'separatistene': ('separatist',),
'separatister': ('separatist',),
'separatistbevegelse': ('separatistbevegelse',),
'separatistbevegelsen': ('separatistbevegelse',),
'separatistbevegelsene': ('separatistbevegelse',),
'separatistbevegelser': ('separatistbevegelse',),
'separator': ('separator',),
'separatoren': ('separator',),
'separatorene': ('separator',),
'separatorer': ('separator',),
'separatormelk': ('separatormelk',),
'separatormelka': ('separatormelk',),
'separatormelken': ('separatormelk',),
'separatormelkene': ('separatormelk',),
'separatormelker': ('separatormelk',),
'separatormjølk': ('separatormjølk',),
'separatormjølka': ('separatormjølk',),
'separatormjølken': ('separatormjølk',),
'separatormjølkene': ('separatormjølk',),
'separatormjølker': ('separatormjølk',),
'separatutstilling': ('separatutstilling',),
'separatutstillinga': ('separatutstilling',),
'separatutstillingen': ('separatutstilling',),
'separatutstillingene': ('separatutstilling',),
'separatutstillinger': ('separatutstilling',),
'sepia': ('sepia',),
'sepiaen': ('sepia',),
'sepiaene': ('sepia',),
'sepiaer': ('sepia',),
'sepoy': ('sepoy',),
'sepoyen': ('sepoy',),
'sepoyene': ('sepoy',),
'sepoyer': ('sepoy',),
'sepsis': ('sepsis',),
'sepsisen': ('sepsis',),
'sepsisene': ('sepsis',),
'sepsiser': ('sepsis',),
'september': ('september',),
'septer': ('septer',),
'septeret': ('septer',),
'septra': ('septer',),
'septre': ('septer',),
'septrene': ('septer',),
'septret': ('septer',),
'septett': ('septett',),
'septetten': ('septett',),
'septettene': ('septett',),
'septetter': ('septett',),
'septiktank': ('septiktank',),
'septiktanken': ('septiktank',),
'septiktankene': ('septiktank',),
'septiktanker': ('septiktank',),
'septim': ('septim',),
'septimen': ('septim',),
'septimene': ('septim',),
'septimer': ('septim',),
'septimakkord': ('septimakkord',),
'septimakkorden': ('septimakkord',),
'septimakkordene': ('septimakkord',),
'septimakkorder': ('septimakkord',),
'septuagesima': ('septuagesima',),
'sequoia': ('sequoia',),
'sequoiaen': ('sequoia',),
'sequoiaene': ('sequoia',),
'sequoiaer': ('sequoia',),
'seraf': ('seraf',),
'serafen': ('seraf',),
'serafene': ('seraf',),
'serafer': ('seraf',),
'serafimerorden': ('serafimerorden',),
'serafimerordenen': ('serafimerorden',),
'serafimerordenene': ('serafimerorden',),
'serafimerordener': ('serafimerorden',),
'serai': ('serai',),
'seraia': ('serai',),
'seraiene': ('serai',),
'seraier': ('serai',),
'seraiet': ('serai',),
'serber': ('serber',),
'serbere': ('serber',),
'serberen': ('serber',),
'serberer': ('serber',),
'serberne': ('serber',),
'serbokroatisk': ('serbokroatisk',),
'serbokroatisken': ('serbokroatisk',),
'serbokroatiskene': ('serbokroatisk',),
'serbokroatisker': ('serbokroatisk',),
'seremoni': ('seremoni',),
'seremonien': ('seremoni',),
'seremoniene': ('seremoni',),
'seremonier': ('seremoni',),
'seremoniell': ('seremoniell',),
'seremoniella': ('seremoniell',),
'seremoniellene': ('seremoniell',),
'seremonieller': ('seremoniell',),
'seremoniellet': ('seremoniell',),
'seremonimester': ('seremonimester',),
'seremonimestere': ('seremonimester',),
'seremonimesteren': ('seremonimester',),
'seremonimesterer': ('seremonimester',),
'seremonimesterne': ('seremonimester',),
'seremonimestre': ('seremonimester',),
'seremonimestrene': ('seremonimester',),
'seremonimestrer': ('seremonimester',),
'serenade': ('serenade',),
'serenaden': ('serenade',),
'serenadene': ('serenade',),
'serenader': ('serenade',),
'serialisme': ('serialisme',),
'serialismen': ('serialisme',),
'serialismene': ('serialisme',),
'serialismer': ('serialisme',),
'serie': ('serie',),
'serien': ('serie',),
'seriene': ('serie',),
'serier': ('serie',),
'seriedynamo': ('seriedynamo',),
'seriedynamoen': ('seriedynamo',),
'seriedynamoene': ('seriedynamo',),
'seriedynamoer': ('seriedynamo',),
'seriefabrikasjon': ('seriefabrikasjon',),
'seriefabrikasjonen': ('seriefabrikasjon',),
'seriefabrikasjonene': ('seriefabrikasjon',),
'seriefabrikasjoner': ('seriefabrikasjon',),
'seriekamp': ('seriekamp',),
'seriekampen': ('seriekamp',),
'seriekampene': ('seriekamp',),
'seriekamper': ('seriekamp',),
'seriekobling': ('seriekobling',),
'seriekoblinga': ('seriekobling',),
'seriekoblingen': ('seriekobling',),
'seriekoblingene': ('seriekobling',),
'seriekoblinger': ('seriekobling',),
'seriekopling': ('seriekopling',),
'seriekoplinga': ('seriekopling',),
'seriekoplingen': ('seriekopling',),
'seriekoplingene': ('seriekopling',),
'seriekoplinger': ('seriekopling',),
'serielån': ('serielån',),
'serielåna': ('serielån',),
'serielånene': ('serielån',),
'serielånet': ('serielån',),
'seriemagasin': ('seriemagasin',),
'seriemagasina': ('seriemagasin',),
'seriemagasinene': ('seriemagasin',),
'seriemagasiner': ('seriemagasin',),
'seriemagasinet': ('seriemagasin',),
'seriemester': ('seriemester',),
'seriemestere': ('seriemester',),
'seriemesteren': ('seriemester',),
'seriemesterer': ('seriemester',),
'seriemesterne': ('seriemester',),
'seriemestre': ('seriemester',),
'seriemestrene': ('seriemester',),
'seriemestrer': ('seriemester',),
'seriemorder': ('seriemorder',),
'seriemordere': ('seriemorder',),
'seriemorderen': ('seriemorder',),
'seriemorderer': ('seriemorder',),
'seriemorderne': ('seriemorder',),
'serieproduksjon': ('serieproduksjon',),
'serieproduksjonen': ('serieproduksjon',),
'serieproduksjonene': ('serieproduksjon',),
'serieproduksjoner': ('serieproduksjon',),
'serierunde': ('serierunde',),
'serierunden': ('serierunde',),
'serierundene': ('serierunde',),
'serierunder': ('serierunde',),
'seriff': ('seriff',),
'seriffen': ('seriff',),
'seriffene': ('seriff',),
'seriffer': ('seriff',),
'serigrafi': ('serigrafi',),
'serigrafien': ('serigrafi',),
'serigrafiene': ('serigrafi',),
'serigrafier': ('serigrafi',),
'serigrafi': ('serigrafi',),
'serigrafia': ('serigrafi',),
'serigrafiene': ('serigrafi',),
'serigrafier': ('serigrafi',),
'serigrafiet': ('serigrafi',),
'serinakaka': ('serinakake',),
'serinakake': ('serinakake',),
'serinakaken': ('serinakake',),
'serinakakene': ('serinakake',),
'serinakaker': ('serinakake',),
'seriøsitet': ('seriøsitet',),
'seriøsiteten': ('seriøsitet',),
'seriøsitetene': ('seriøsitet',),
'seriøsiteter': ('seriøsitet',),
'serk': ('serk',),
'serken': ('serk',),
'serkene': ('serk',),
'serker': ('serk',),
'serologi': ('serologi',),
'serologien': ('serologi',),
'serologiene': ('serologi',),
'serologier': ('serologi',),
'serpentin': ('serpentin',),
'serpentinen': ('serpentin',),
'serpentinene': ('serpentin',),
'serpentiner': ('serpentin',),
'sersjant': ('sersjant',),
'sersjanten': ('sersjant',),
'sersjantene': ('sersjant',),
'sersjanter': ('sersjant',),
'sertifikat': ('sertifikat',),
'sertifikata': ('sertifikat',),
'sertifikatene': ('sertifikat',),
'sertifikater': ('sertifikat',),
'sertifikatet': ('sertifikat',),
'sera': ('serum',),
'seraene': ('serum',),
'serum': ('serum',),
'seruma': ('serum',),
'serumene': ('serum',),
'serumer': ('serum',),
'serumet': ('serum',),
'serval': ('serval',),
'servalen': ('serval',),
'servalene': ('serval',),
'servaler': ('serval',),
'servant': ('servant',),
'servanten': ('servant',),
'servantene': ('servant',),
'servanter': ('servant',),
'serve': ('serve',),
'serven': ('serve',),
'servene': ('serve',),
'server': ('serve',),
'servelat': ('servelat',),
'servelaten': ('servelat',),
'servelatene': ('servelat',),
'servelater': ('servelat',),
'servelatpølsa': ('servelatpølse',),
'servelatpølse': ('servelatpølse',),
'servelatpølsen': ('servelatpølse',),
'servelatpølsene': ('servelatpølse',),
'servelatpølser': ('servelatpølse',),
'servering': ('servering',),
'serveringa': ('servering',),
'serveringen': ('servering',),
'serveringene': ('servering',),
'serveringer': ('servering',),
'serveringsdama': ('serveringsdame',),
'serveringsdame': ('serveringsdame',),
'serveringsdamen': ('serveringsdame',),
'serveringsdamene': ('serveringsdame',),
'serveringsdamer': ('serveringsdame',),
'service': ('service',),
'servicen': ('service',),
'servicene': ('service',),
'servicer': ('service',),
'servicebil': ('servicebil',),
'servicebilen': ('servicebil',),
'servicebilene': ('servicebil',),
'servicebiler': ('servicebil',),
'serviceinstitusjon': ('serviceinstitusjon',),
'serviceinstitusjonen': ('serviceinstitusjon',),
'serviceinstitusjonene': ('serviceinstitusjon',),
'serviceinstitusjoner': ('serviceinstitusjon',),
'servicekontrakt': ('servicekontrakt',),
'servicekontrakten': ('servicekontrakt',),
'servicekontraktene': ('servicekontrakt',),
'servicekontrakter': ('servicekontrakt',),
'servicenæring': ('servicenæring',),
'servicenæringa': ('servicenæring',),
'servicenæringen': ('servicenæring',),
'servicenæringene': ('servicenæring',),
'servicenæringer': ('servicenæring',),
'serviceyrka': ('serviceyrke',),
'serviceyrke': ('serviceyrke',),
'serviceyrkene': ('serviceyrke',),
'serviceyrker': ('serviceyrke',),
'serviceyrket': ('serviceyrke',),
'serviett': ('serviett',),
'servietten': ('serviett',),
'serviettene': ('serviett',),
'servietter': ('serviett',),
'serviettholder': ('serviettholder',),
'serviettholdere': ('serviettholder',),
'serviettholderen': ('serviettholder',),
'serviettholderer': ('serviettholder',),
'serviettholderne': ('serviettholder',),
'serviettring': ('serviettring',),
'serviettringen': ('serviettring',),
'serviettringene': ('serviettring',),
'serviettringer': ('serviettring',),
'servilitet': ('servilitet',),
'serviliteten': ('servilitet',),
'servilitetene': ('servilitet',),
'serviliteter': ('servilitet',),
'servisa': ('servise',),
'servise': ('servise',),
'servisene': ('servise',),
'serviser': ('servise',),
'serviset': ('servise',),
'servitrisa': ('servitrise',),
'servitrise': ('servitrise',),
'servitrisen': ('servitrise',),
'servitrisene': ('servitrise',),
'servitriser': ('servitrise',),
'servitutt': ('servitutt',),
'servitutta': ('servitutt',),
'servitutten': ('servitutt',),
'servituttene': ('servitutt',),
'servitutter': ('servitutt',),
'servituttet': ('servitutt',),
'servitør': ('servitør',),
'servitøren': ('servitør',),
'servitørene': ('servitør',),
'servitører': ('servitør',),
'servobrems': ('servobrems',),
'servobremsen': ('servobrems',),
'servobremsene': ('servobrems',),
'servobremser': ('servobrems',),
'servobremsa': ('servobremse',),
'servobremse': ('servobremse',),
'servobremsen': ('servobremse',),
'servobremsene': ('servobremse',),
'servobremser': ('servobremse',),
'servomekanisme': ('servomekanisme',),
'servomekanismen': ('servomekanisme',),
'servomekanismene': ('servomekanisme',),
'servomekanismer': ('servomekanisme',),
'servostyring': ('servostyring',),
'servostyringa': ('servostyring',),
'servostyringen': ('servostyring',),
'servostyringene': ('servostyring',),
'servostyringer': ('servostyring',),
'servoteknikk': ('servoteknikk',),
'servoteknikken': ('servoteknikk',),
'servoteknikkene': ('servoteknikk',),
'servoteknikker': ('servoteknikk',),
'servus': ('servus',),
'servusen': ('servus',),
'servusene': ('servus',),
'servuser': ('servus',),
'sesam': ('sesam',),
'sesamen': ('sesam',),
'sesamene': ('sesam',),
'sesamer': ('sesam',),
'sesam': ('sesam',),
'sesama': ('sesam',),
'sesamene': ('sesam',),
'sesamet': ('sesam',),
'sesamfrø': ('sesamfrø',),
'sesamfrøa': ('sesamfrø',),
'sesamfrøene': ('sesamfrø',),
'sesamfrøet': ('sesamfrø',),
'sesjon': ('sesjon',),
'sesjonen': ('sesjon',),
'sesjonene': ('sesjon',),
'sesjoner': ('sesjon',),
'sesong': ('sesong',),
'sesongen': ('sesong',),
'sesongene': ('sesong',),
'sesonger': ('sesong',),
'sesongarbeid': ('sesongarbeid',),
'sesongarbeida': ('sesongarbeid',),
'sesongarbeidene': ('sesongarbeid',),
'sesongarbeider': ('sesongarbeid',),
'sesongarbeidet': ('sesongarbeid',),
'sesongarbeider': ('sesongarbeider',),
'sesongarbeidere': ('sesongarbeider',),
'sesongarbeideren': ('sesongarbeider',),
'sesongarbeiderer': ('sesongarbeider',),
'sesongarbeiderne': ('sesongarbeider',),
'sesongbillett': ('sesongbillett',),
'sesongbilletten': ('sesongbillett',),
'sesongbillettene': ('sesongbillett',),
'sesongbilletter': ('sesongbillett',),
'sesongkort': ('sesongkort',),
'sesongkorta': ('sesongkort',),
'sesongkortene': ('sesongkort',),
'sesongkortet': ('sesongkort',),
'sesongsalg': ('sesongsalg',),
'sesongsalga': ('sesongsalg',),
'sesongsalgene': ('sesongsalg',),
'sesongsalget': ('sesongsalg',),
'sess': ('sess',),
'sessen': ('sess',),
'sessene': ('sess',),
'sesser': ('sess',),
'seta': ('sete',),
'sete': ('sete',),
'setene': ('sete',),
'seter': ('sete',),
'setet': ('sete',),
'setefødsel': ('setefødsel',),
'setefødselen': ('setefødsel',),
'setefødslene': ('setefødsel',),
'setefødsler': ('setefødsel',),
'setegard': ('setegard',),
'setegarden': ('setegard',),
'setegardene': ('setegard',),
'setegarder': ('setegard',),
'setegård': ('setegård',),
'setegården': ('setegård',),
'setegårdene': ('setegård',),
'setegårder': ('setegård',),
'setekapasitet': ('setekapasitet',),
'setekapasiteten': ('setekapasitet',),
'setekapasitetene': ('setekapasitet',),
'setekapasiteter': ('setekapasitet',),
'seter': ('seter',),
'seteren': ('seter',),
'setra': ('seter',),
'setre': ('seter',),
'setrene': ('seter',),
'setrer': ('seter',),
'seterbruk': ('seterbruk',),
'seterbruka': ('seterbruk',),
'seterbrukene': ('seterbruk',),
'seterbruket': ('seterbruk',),
'seterbu': ('seterbu',),
'seterbua': ('seterbu',),
'seterbuen': ('seterbu',),
'seterbuene': ('seterbu',),
'seterbuer': ('seterbu',),
'seterdrift': ('seterdrift',),
'seterdrifta': ('seterdrift',),
'seterdriften': ('seterdrift',),
'seterdriftene': ('seterdrift',),
'seterdrifter': ('seterdrift',),
'setergrend': ('setergrend',),
'setergrenda': ('setergrend',),
'setergrenden': ('setergrend',),
'setergrendene': ('setergrend',),
'setergrender': ('setergrend',),
'seterhus': ('seterhus',),
'seterhusa': ('seterhus',),
'seterhusene': ('seterhus',),
'seterhuset': ('seterhus',),
'seterjenta': ('seterjente',),
'seterjente': ('seterjente',),
'seterjenten': ('seterjente',),
'seterjentene': ('seterjente',),
'seterjenter': ('seterjente',),
'seterkost': ('seterkost',),
'seterkosten': ('seterkost',),
'seterkostene': ('seterkost',),
'seterkoster': ('seterkost',),
'setervang': ('setervang',),
'setervangen': ('setervang',),
'setervangene': ('setervang',),
'setervanger': ('setervang',),
'seterveg': ('seterveg',),
'setervegen': ('seterveg',),
'setervegene': ('seterveg',),
'seterveger': ('seterveg',),
'setervei': ('setervei',),
'seterveien': ('setervei',),
'seterveiene': ('setervei',),
'seterveier': ('setervei',),
'setervoll': ('setervoll',),
'setervollen': ('setervoll',),
'setervollene': ('setervoll',),
'setervoller': ('setervoll',),
'setesdøl': ('setesdøl',),
'setesdølen': ('setesdøl',),
'setesdølene': ('setesdøl',),
'setesdøler': ('setesdøl',),
'setning': ('setning',),
'setninga': ('setning',),
'setningen': ('setning',),
'setningene': ('setning',),
'setninger': ('setning',),
'setning': ('setning',),
'setninga': ('setning',),
'setningen': ('setning',),
'setningene': ('setning',),
'setninger': ('setning',),
'setningsaksent': ('setningsaksent',),
'setningsaksenten': ('setningsaksent',),
'setningsaksentene': ('setningsaksent',),
'setningsaksenter': ('setningsaksent',),
'setningsbygning': ('setningsbygning',),
'setningsbygninga': ('setningsbygning',),
'setningsbygningen': ('setningsbygning',),
'setningsbygningene': ('setningsbygning',),
'setningsbygninger': ('setningsbygning',),
'setningsdel': ('setningsdel',),
'setningsdelen': ('setningsdel',),
'setningsdelene': ('setningsdel',),
'setningsdeler': ('setningsdel',),
'setningsemna': ('setningsemne',),
'setningsemne': ('setningsemne',),
'setningsemnene': ('setningsemne',),
'setningsemner': ('setningsemne',),
'setningsemnet': ('setningsemne',),
'setningsknute': ('setningsknute',),
'setningsknuten': ('setningsknute',),
'setningsknutene': ('setningsknute',),
'setningsknuter': ('setningsknute',),
'setningsledd': ('setningsledd',),
'setningsledda': ('setningsledd',),
'setningsleddene': ('setningsledd',),
'setningsleddet': ('setningsledd',),
'setningslæra': ('setningslære',),
'setningslære': ('setningslære',),
'setningslæren': ('setningslære',),
'setningslærene': ('setningslære',),
'setningslærer': ('setningslære',),
'setningsmelodi': ('setningsmelodi',),
'setningsmelodien': ('setningsmelodi',),
'setningsmelodiene': ('setningsmelodi',),
'setningsmelodier': ('setningsmelodi',),
'setningsrest': ('setningsrest',),
'setningsresten': ('setningsrest',),
'setningsrestene': ('setningsrest',),
'setningsrester': ('setningsrest',),
'setningstype': ('setningstype',),
'setningstypen': ('setningstype',),
'setningstypene': ('setningstype',),
'setningstyper': ('setningstype',),
'sett': ('sett',),
'setta': ('sett',),
'settene': ('sett',),
'settet': ('sett',),
'sett': ('sett',),
'setta': ('sett',),
'settene': ('sett',),
'settet': ('sett',),
'settball': ('settball',),
'settballen': ('settball',),
'settballene': ('settball',),
'settballer': ('settball',),
'settbord': ('settbord',),
'settborda': ('settbord',),
'settbordene': ('settbord',),
'settborder': ('settbord',),
'settbordet': ('settbord',),
'settedommer': ('settedommer',),
'settedommere': ('settedommer',),
'settedommeren': ('settedommer',),
'settedommerer': ('settedommer',),
'settedommerne': ('settedommer',),
'settefisk': ('settefisk',),
'settefisken': ('settefisk',),
'settefiskene': ('settefisk',),
'settefisker': ('settefisk',),
'settemaskin': ('settemaskin',),
'settemaskina': ('settemaskin',),
'settemaskinen': ('settemaskin',),
'settemaskinene': ('settemaskin',),
'settemaskiner': ('settemaskin',),
'setteordfører': ('setteordfører',),
'setteordførere': ('setteordfører',),
'setteordføreren': ('setteordfører',),
'setteordførerer': ('setteordfører',),
'setteordførerne': ('setteordfører',),
'settepotet': ('settepotet',),
'settepoteten': ('settepotet',),
'settepotetene': ('settepotet',),
'settepoteter': ('settepotet',),
'setter': ('setter',),
'settere': ('setter',),
'setteren': ('setter',),
'setterer': ('setter',),
'setterne': ('setter',),
'setter': ('setter',),
'settere': ('setter',),
'setteren': ('setter',),
'setterer': ('setter',),
'setterne': ('setter',),
'setteri': ('setteri',),
'setteria': ('setteri',),
'setteriene': ('setteri',),
'setterier': ('setteri',),
'setteriet': ('setteri',),
'setterlærling': ('setterlærling',),
'setterlærlingen': ('setterlærling',),
'setterlærlingene': ('setterlærling',),
'setterlærlinger': ('setterlærling',),
'setthammar': ('setthammar',),
'setthammaren': ('setthammar',),
'setthamrene': ('setthammar',),
'setthamrer': ('setthammar',),
'setthammer': ('setthammer',),
'setthammere': ('setthammer',),
'setthammeren': ('setthammer',),
'setthammerer': ('setthammer',),
'setthammerne': ('setthammer',),
'setthamrene': ('setthammer',),
'setthamrer': ('setthammer',),
'settjern': ('settjern',),
'settjerna': ('settjern',),
'settjernene': ('settjern',),
'settjernet': ('settjern',),
'settlement': ('settlement',),
'settlementa': ('settlement',),
'settlementene': ('settlement',),
'settlementer': ('settlement',),
'settlementet': ('settlement',),
'settler': ('settler',),
'settlere': ('settler',),
'settleren': ('settler',),
'settlerer': ('settler',),
'settlerne': ('settler',),
'settseier': ('settseier',),
'settseiere': ('settseier',),
'settseieren': ('settseier',),
'settseierne': ('settseier',),
'settseire': ('settseier',),
'settseirene': ('settseier',),
'settseirer': ('settseier',),
'settsiffer': ('settsiffer',),
'settsifferet': ('settsiffer',),
'settsifra': ('settsiffer',),
'settsifre': ('settsiffer',),
'settsifrene': ('settsiffer',),
'settskrue': ('settskrue',),
'settskruen': ('settskrue',),
'settskruene': ('settskrue',),
'settskruer': ('settskrue',),
'settskruve': ('settskruve',),
'settskruven': ('settskruve',),
'settskruvene': ('settskruve',),
'settskruver': ('settskruve',),
'settung': ('settung',),
'settungen': ('settung',),
'settungene': ('settung',),
'settunger': ('settung',),
'sev': ('sev',),
'seva': ('sev',),
'sevene': ('sev',),
'sevet': ('sev',),
'sev': ('sev',),
'seva': ('sev',),
'sevene': ('sev',),
'sevet': ('sev',),
'severdighet': ('severdighet',),
'severdigheta': ('severdighet',),
'severdigheten': ('severdighet',),
'severdighetene': ('severdighet',),
'severdigheter': ('severdighet',),
'sevfamilie': ('sevfamilie',),
'sevfamilien': ('sevfamilie',),
'sevfamiliene': ('sevfamilie',),
'sevfamilier': ('sevfamilie',),
'sevfamilie': ('sevfamilie',),
'sevfamilien': ('sevfamilie',),
'sevfamiliene': ('sevfamilie',),
'sevfamilier': ('sevfamilie',),
'sevhøna': ('sevhøne',),
'sevhøne': ('sevhøne',),
'sevhønen': ('sevhøne',),
'sevhønene': ('sevhøne',),
'sevhøner': ('sevhøne',),
'sevhøna': ('sevhøne',),
'sevhøne': ('sevhøne',),
'sevhønen': ('sevhøne',),
'sevhønene': ('sevhøne',),
'sevhøner': ('sevhøne',),
'sevja': ('sevje',),
'sevje': ('sevje',),
'sevjen': ('sevje',),
'sevjene': ('sevje',),
'sevjer': ('sevje',),
'sevmatta': ('sevmatte',),
'sevmatte': ('sevmatte',),
'sevmatten': ('sevmatte',),
'sevmattene': ('sevmatte',),
'sevmatter': ('sevmatte',),
'sevmatta': ('sevmatte',),
'sevmatte': ('sevmatte',),
'sevmatten': ('sevmatte',),
'sevmattene': ('sevmatte',),
'sevmatter': ('sevmatte',),
'sevresporselen': ('sevresporselen',),
'sevresporselena': ('sevresporselen',),
'sevresporselenene': ('sevresporselen',),
'sevresporselener': ('sevresporselen',),
'sevresporselenet': ('sevresporselen',),
'sevsanger': ('sevsanger',),
'sevsangere': ('sevsanger',),
'sevsangeren': ('sevsanger',),
'sevsangerer': ('sevsanger',),
'sevsangerne': ('sevsanger',),
'sevsanger': ('sevsanger',),
'sevsangere': ('sevsanger',),
'sevsangeren': ('sevsanger',),
'sevsangerer': ('sevsanger',),
'sevsangerne': ('sevsanger',),
'sevstarr': ('sevstarr',),
'sevstarren': ('sevstarr',),
'sevstarrene': ('sevstarr',),
'sevstarrer': ('sevstarr',),
'sevstarr': ('sevstarr',),
'sevstarren': ('sevstarr',),
'sevstarrene': ('sevstarr',),
'sevstarrer': ('sevstarr',),
'sevstorr': ('sevstorr',),
'sevstorren': ('sevstorr',),
'sevstorrene': ('sevstorr',),
'sevstorrer': ('sevstorr',),
'sevstorr': ('sevstorr',),
'sevstorren': ('sevstorr',),
'sevstorrene': ('sevstorr',),
'sevstorrer': ('sevstorr',),
'sex': ('sex',),
'sexen': ('sex',),
'sexene': ('sex',),
'sexer': ('sex',),
'sex appeal': ('sex appeal',),
'sex appealen': ('sex appeal',),
'sex appealene': ('sex appeal',),
'sex appealer': ('sex appeal',),
'sexbomba': ('sexbombe',),
'sexbombe': ('sexbombe',),
'sexbomben': ('sexbombe',),
'sexbombene': ('sexbombe',),
'sexbomber': ('sexbombe',),
'sexfilm': ('sexfilm',),
'sexfilmen': ('sexfilm',),
'sexfilmene': ('sexfilm',),
'sexfilmer': ('sexfilm',),
'sexklubb': ('sexklubb',),
'sexklubben': ('sexklubb',),
'sexklubbene': ('sexklubb',),
'sexklubber': ('sexklubb',),
'sexolog': ('sexolog',),
'sexologen': ('sexolog',),
'sexologene': ('sexolog',),
'sexologer': ('sexolog',),
'sexologi': ('sexologi',),
'sexologien': ('sexologi',),
'sexologiene': ('sexologi',),
'sexologier': ('sexologi',),
'sexus': ('sexus',),
'seycheller': ('seycheller',),
'seychellere': ('seycheller',),
'seychelleren': ('seycheller',),
'seychellerer': ('seycheller',),
'seychellerne': ('seycheller',),
'sfinks': ('sfinks',),
'sfinksen': ('sfinks',),
'sfinksene': ('sfinks',),
'sfinkser': ('sfinks',),
'sfragistikk': ('sfragistikk',),
'sfragistikken': ('sfragistikk',),
'sfragistikkene': ('sfragistikk',),
'sfragistikker': ('sfragistikk',),
'sfære': ('sfære',),
'sfæren': ('sfære',),
'sfærene': ('sfære',),
'sfærer': ('sfære',),
'shake': ('shake',),
'shaken': ('shake',),
'shakene': ('shake',),
'shaker': ('shake',),
'shaker': ('shaker',),
'shakere': ('shaker',),
'shakeren': ('shaker',),
'shakerer': ('shaker',),
'shakerne': ('shaker',),
'shantung': ('shantung',),
'shantungen': ('shantung',),
'shantungene': ('shantung',),
'shantunger': ('shantung',),
'sharper': ('sharper',),
'sharpere': ('sharper',),
'sharperen': ('sharper',),
'sharperer': ('sharper',),
'sharperne': ('sharper',),
'shelf': ('shelf',),
'shelfen': ('shelf',),
'shelfene': ('shelf',),
'shelfer': ('shelf',),
'shelf-is': ('shelf-is',),
'shelf-isen': ('shelf-is',),
'shelf-isene': ('shelf-is',),
'shelf-iser': ('shelf-is',),
'shelterdekk': ('shelterdekk',),
'shelterdekka': ('shelterdekk',),
'shelterdekkene': ('shelterdekk',),
'shelterdekket': ('shelterdekk',),
'shelterdekker': ('shelterdekker',),
'shelterdekkere': ('shelterdekker',),
'shelterdekkeren': ('shelterdekker',),
'shelterdekkerer': ('shelterdekker',),
'shelterdekkerne': ('shelterdekker',),
'sheriff': ('sheriff',),
'sheriffen': ('sheriff',),
'sheriffene': ('sheriff',),
'sheriffer': ('sheriff',),
'sherpa': ('sherpa',),
'sherpaen': ('sherpa',),
'sherpaene': ('sherpa',),
'sherpaer': ('sherpa',),
'sherry': ('sherry',),
'sherryen': ('sherry',),
'sherryene': ('sherry',),
'sherryer': ('sherry',),
'shetlender': ('shetlender',),
'shetlendere': ('shetlender',),
'shetlenderen': ('shetlender',),
'shetlenderer': ('shetlender',),
'shetlenderne': ('shetlender',),
'shetlending': ('shetlending',),
'shetlendingen': ('shetlending',),
'shetlendingene': ('shetlending',),
'shetlendinger': ('shetlending',),
'shilling': ('shilling',),
'shillingen': ('shilling',),
'shillingene': ('shilling',),
'shingel': ('shingel',),
'shingelen': ('shingel',),
'shinglene': ('shingel',),
'shingler': ('shingel',),
'shintoisme': ('shintoisme',),
'shintoismen': ('shintoisme',),
'shintoismene': ('shintoisme',),
'shintoismer': ('shintoisme',),
'shintoist': ('shintoist',),
'shintoisten': ('shintoist',),
'shintoistene': ('shintoist',),
'shintoister': ('shintoist',),
'shipping': ('shipping',),
'shippingen': ('shipping',),
'shippingene': ('shipping',),
'shippinger': ('shipping',),
'shippingfolk': ('shippingfolk',),
'shippingfolka': ('shippingfolk',),
'shippingfolkene': ('shippingfolk',),
'shippingfolket': ('shippingfolk',),
'shit': ('shit',),
'shiten': ('shit',),
'shitene': ('shit',),
'shiter': ('shit',),
'shop': ('shop',),
'shopen': ('shop',),
'shopene': ('shop',),
'shoper': ('shop',),
'shopping': ('shopping',),
'shoppingen': ('shopping',),
'shoppingene': ('shopping',),
'shoppinger': ('shopping',),
'shoppingsenter': ('shoppingsenter',),
'shoppingsenteret': ('shoppingsenter',),
'shoppingsentra': ('shoppingsenter',),
'shoppingsentre': ('shoppingsenter',),
'shoppingsentrene': ('shoppingsenter',),
'shoppingsentret': ('shoppingsenter',),
'short story': ('short story',),
'short storyen': ('short story',),
'short storyene': ('short story',),
'short storyer': ('short story',),
'shortpassing': ('shortpassing',),
'shortpassingen': ('shortpassing',),
'shortpassingene': ('shortpassing',),
'shortpassinger': ('shortpassing',),
'shorts': ('shorts',),
'shortsen': ('shorts',),
'shortsene': ('shorts',),
'shortser': ('shorts',),
'shovel': ('shovel',),
'shovelen': ('shovel',),
'shovlene': ('shovel',),
'shovler': ('shovel',),
'shoveldoser': ('shoveldoser',),
'shoveldosere': ('shoveldoser',),
'shoveldoseren': ('shoveldoser',),
'shoveldoserer': ('shoveldoser',),
'shoveldoserne': ('shoveldoser',),
'show': ('show',),
'showa': ('show',),
'showene': ('show',),
'showet': ('show',),
'showbusiness': ('showbusiness',),
'showbusinessen': ('showbusiness',),
'showbusinessene': ('showbusiness',),
'showbusinesser': ('showbusiness',),
'shrapnel': ('shrapnel',),
'shrapnelen': ('shrapnel',),
'shrapnelene': ('shrapnel',),
'shrapnels': ('shrapnel',),
'shunt': ('shunt',),
'shunten': ('shunt',),
'shuntene': ('shunt',),
'shunter': ('shunt',),
'shuntdynamo': ('shuntdynamo',),
'shuntdynamoen': ('shuntdynamo',),
'shuntdynamoene': ('shuntdynamo',),
'shuntdynamoer': ('shuntdynamo',),
'si': ('si',),
'sien': ('si',),
'siene': ('si',),
'sier': ('si',),
'si': ('si',),
'sial': ('sial',),
'siala': ('sial',),
'sialene': ('sial',),
'sialet': ('sial',),
'siameser': ('siameser',),
'siamesere': ('siameser',),
'siameseren': ('siameser',),
'siameserer': ('siameser',),
'siameserne': ('siameser',),
'sibirer': ('sibirer',),
'sibirere': ('sibirer',),
'sibireren': ('sibirer',),
'sibirerer': ('sibirer',),
'sibirerne': ('sibirer',),
'sibylla': ('sibylle',),
'sibylle': ('sibylle',),
'sibyllen': ('sibylle',),
'sibyllene': ('sibylle',),
'sibyller': ('sibylle',),
'sicilianer': ('sicilianer',),
'sicilianere': ('sicilianer',),
'sicilianeren': ('sicilianer',),
'sicilianerer': ('sicilianer',),
'sicilianerne': ('sicilianer',),
'sida': ('sida',),
'sidaen': ('sida',),
'sidaene': ('sida',),
'sidaer': ('sida',),
'sidd': ('sidd',),
'sidda': ('sidd',),
'sidden': ('sidd',),
'siddene': ('sidd',),
'sidder': ('sidd',),
'sidda': ('sidde',),
'sidde': ('sidde',),
'sidden': ('sidde',),
'siddene': ('sidde',),
'sidder': ('sidde',),
'sida': ('side',),
'side': ('side',),
'siden': ('side',),
'sidene': ('side',),
'sider': ('side',),
'sidebane': ('sidebane',),
'sidebanen': ('sidebane',),
'sidebanene': ('sidebane',),
'sidebaner': ('sidebane',),
'sidebein': ('sidebein',),
'sidebeina': ('sidebein',),
'sidebeinene': ('sidebein',),
'sidebeinet': ('sidebein',),
'sidebemerkning': ('sidebemerkning',),
'sidebemerkninga': ('sidebemerkning',),
'sidebemerkningen': ('sidebemerkning',),
'sidebemerkningene': ('sidebemerkning',),
'sidebemerkninger': ('sidebemerkning',),
'sideben': ('sideben',),
'sidebena': ('sideben',),
'sidebenene': ('sideben',),
'sidebenet': ('sideben',),
'sideblikk': ('sideblikk',),
'sideblikka': ('sideblikk',),
'sideblikkene': ('sideblikk',),
'sideblikket': ('sideblikk',),
'sidebygning': ('sidebygning',),
'sidebygninga': ('sidebygning',),
'sidebygningen': ('sidebygning',),
'sidebygningene': ('sidebygning',),
'sidebygninger': ('sidebygning',),
'sidebytta': ('sidebytte',),
'sidebytte': ('sidebytte',),
'sidebyttene': ('sidebytte',),
'sidebytter': ('sidebytte',),
'sidebyttet': ('sidebytte',),
'sidedal': ('sidedal',),
'sidedalen': ('sidedal',),
'sidedalene': ('sidedal',),
'sidedaler': ('sidedal',),
'sideelv': ('sideelv',),
'sideelva': ('sideelv',),
'sideelven': ('sideelv',),
'sideelvene': ('sideelv',),
'sideelver': ('sideelv',),
'sideflata': ('sideflate',),
'sideflate': ('sideflate',),
'sideflaten': ('sideflate',),
'sideflatene': ('sideflate',),
'sideflater': ('sideflate',),
'sideflesk': ('sideflesk',),
'sidefleska': ('sideflesk',),
'sidefleskene': ('sideflesk',),
'sideflesket': ('sideflesk',),
'sideform': ('sideform',),
'sideforma': ('sideform',),
'sideformen': ('sideform',),
'sideformene': ('sideform',),
'sideformer': ('sideform',),
'sidegang': ('sidegang',),
'sidegangen': ('sidegang',),
'sidegangene': ('sidegang',),
'sideganger': ('sidegang',),
'sidegata': ('sidegate',),
'sidegate': ('sidegate',),
'sidegaten': ('sidegate',),
'sidegatene': ('sidegate',),
'sidegater': ('sidegate',),
'sidegrein': ('sidegrein',),
'sidegreina': ('sidegrein',),
'sidegreinen': ('sidegrein',),
'sidegreinene': ('sidegrein',),
'sidegreiner': ('sidegrein',),
'sidegren': ('sidegren',),
'sidegrena': ('sidegren',),
'sidegrenen': ('sidegren',),
'sidegrenene': ('sidegren',),
'sidegrener': ('sidegren',),
'sidelinja': ('sidelinje',),
'sidelinje': ('sidelinje',),
'sidelinjen': ('sidelinje',),
'sidelinjene': ('sidelinje',),
'sidelinjer': ('sidelinje',),
'sidelomma': ('sidelomme',),
'sidelomme': ('sidelomme',),
'sidelommen': ('sidelomme',),
'sidelommene': ('sidelomme',),
'sidelommer': ('sidelomme',),
'sidemann': ('sidemann',),
'sidemannen': ('sidemann',),
'sidemenn': ('sidemann',),
'sidemennene': ('sidemann',),
'sidemål': ('sidemål',),
'sidemåla': ('sidemål',),
'sidemålene': ('sidemål',),
'sidemålet': ('sidemål',),
'sidensvans': ('sidensvans',),
'sidensvansen': ('sidensvans',),
'sidensvansene': ('sidensvans',),
'sidensvanser': ('sidensvans',),
'sideordning': ('sideordning',),
'sideordninga': ('sideordning',),
'sideordningen': ('sideordning',),
'sideordningene': ('sideordning',),
'sideordninger': ('sideordning',),
'sider': ('sider',),
'sidere': ('sider',),
'sideren': ('sider',),
'siderne': ('sider',),
'sidre': ('sider',),
'sidrene': ('sider',),
'sidrer': ('sider',),
'siderom': ('siderom',),
'sideromma': ('siderom',),
'siderommene': ('siderom',),
'siderommet': ('siderom',),
'sideror': ('sideror',),
'siderora': ('sideror',),
'siderorene': ('sideror',),
'sideroret': ('sideror',),
'sideskip': ('sideskip',),
'sideskipa': ('sideskip',),
'sideskipene': ('sideskip',),
'sideskipet': ('sideskip',),
'sidespark': ('sidespark',),
'sidesparka': ('sidespark',),
'sidesparkene': ('sidespark',),
'sidesparket': ('sidespark',),
'sidespor': ('sidespor',),
'sidespora': ('sidespor',),
'sidesporene': ('sidespor',),
'sidesporet': ('sidespor',),
'sidesprang': ('sidesprang',),
'sidespranga': ('sidesprang',),
'sidesprangene': ('sidesprang',),
'sidespranget': ('sidesprang',),
'sidestilling': ('sidestilling',),
'sidestillinga': ('sidestilling',),
'sidestillingen': ('sidestilling',),
'sidestillingene': ('sidestilling',),
'sidestillinger': ('sidestilling',),
'sidestykka': ('sidestykke',),
'sidestykke': ('sidestykke',),
'sidestykkene': ('sidestykke',),
'sidestykker': ('sidestykke',),
'sidestykket': ('sidestykke',),
'sidestyring': ('sidestyring',),
'sidestyringa': ('sidestyring',),
'sidestyringen': ('sidestyring',),
'sidestyringene': ('sidestyring',),
'sidestyringer': ('sidestyring',),
'sidetråler': ('sidetråler',),
'sidetrålere': ('sidetråler',),
'sidetråleren': ('sidetråler',),
'sidetrålerer': ('sidetråler',),
'sidetrålerne': ('sidetråler',),
'sideveg': ('sideveg',),
'sidevegen': ('sideveg',),
'sidevegene': ('sideveg',),
'sideveger': ('sideveg',),
'sidevei': ('sidevei',),
'sideveien': ('sidevei',),
'sideveiene': ('sidevei',),
'sideveier': ('sidevei',),
'sidevind': ('sidevind',),
'sidevinden': ('sidevind',),
'sidevindene': ('sidevind',),
'sidevinder': ('sidevind',),
'sidevogn': ('sidevogn',),
'sidevogna': ('sidevogn',),
'sidevognen': ('sidevogn',),
'sidevognene': ('sidevogn',),
'sidevogner': ('sidevogn',),
'sidlenda': ('sidlende',),
'sidlende': ('sidlende',),
'sidlendene': ('sidlende',),
'sidlender': ('sidlende',),
'sidlendet': ('sidlende',),
'siemens': ('siemens',),
'siemensen': ('siemens',),
'siemensene': ('siemens',),
'sierraleoner': ('sierraleoner',),
'sierraleonere': ('sierraleoner',),
'sierraleoneren': ('sierraleoner',),
'sierraleonerer': ('sierraleoner',),
'sierraleonerne': ('sierraleoner',),
'siesta': ('siesta',),
'siestaen': ('siesta',),
'siestaene': ('siesta',),
'siestaer': ('siesta',),
'sievert': ('sievert',),
'sieverten': ('sievert',),
'sievertene': ('sievert',),
'siffer': ('siffer',),
'sifferet': ('siffer',),
'sifra': ('siffer',),
'sifre': ('siffer',),
'sifrene': ('siffer',),
'sifferkode': ('sifferkode',),
'sifferkoden': ('sifferkode',),
'sifferkodene': ('sifferkode',),
'sifferkoder': ('sifferkode',),
'sifferlås': ('sifferlås',),
'sifferlåsa': ('sifferlås',),
'sifferlåsen': ('sifferlås',),
'sifferlåsene': ('sifferlås',),
'sifferlåser': ('sifferlås',),
'sifferlåset': ('sifferlås',),
'sifferskrift': ('sifferskrift',),
'sifferskrifta': ('sifferskrift',),
'sifferskriften': ('sifferskrift',),
'sifferskriftene': ('sifferskrift',),
'sifferskrifter': ('sifferskrift',),
'siffertekst': ('siffertekst',),
'sifferteksta': ('siffertekst',),
'sifferteksten': ('siffertekst',),
'siffertekstene': ('siffertekst',),
'siffertekster': ('siffertekst',),
'siffertelegram': ('siffertelegram',),
'siffertelegramma': ('siffertelegram',),
'siffertelegrammene': ('siffertelegram',),
'siffertelegrammer': ('siffertelegram',),
'siffertelegrammet': ('siffertelegram',),
'sifferur': ('sifferur',),
'sifferura': ('sifferur',),
'sifferurene': ('sifferur',),
'sifferuret': ('sifferur',),
'sifong': ('sifong',),
'sifongen': ('sifong',),
'sifongene': ('sifong',),
'sifonger': ('sifong',),
'sig': ('sig',),
'siga': ('sig',),
'sigene': ('sig',),
'siget': ('sig',),
'sigar': ('sigar',),
'sigaren': ('sigar',),
'sigarene': ('sigar',),
'sigarer': ('sigar',),
'sigarett': ('sigarett',),
'sigaretten': ('sigarett',),
'sigarettene': ('sigarett',),
'sigaretter': ('sigarett',),
'sigarettmunnstykka': ('sigarettmunnstykke',),
'sigarettmunnstykke': ('sigarettmunnstykke',),
'sigarettmunnstykkene': ('sigarettmunnstykke',),
'sigarettmunnstykker': ('sigarettmunnstykke',),
'sigarettmunnstykket': ('sigarettmunnstykke',),
'sigarettpakka': ('sigarettpakke',),
'sigarettpakke': ('sigarettpakke',),
'sigarettpakken': ('sigarettpakke',),
'sigarettpakkene': ('sigarettpakke',),
'sigarettpakker': ('sigarettpakke',),
'sigarettpapir': ('sigarettpapir',),
'sigarettpapira': ('sigarettpapir',),
'sigarettpapirene': ('sigarettpapir',),
'sigarettpapirer': ('sigarettpapir',),
'sigarettpapiret': ('sigarettpapir',),
'sigarettstump': ('sigarettstump',),
'sigarettstumpen': ('sigarettstump',),
'sigarettstumpene': ('sigarettstump',),
'sigarettstumper': ('sigarettstump',),
'sigarillo': ('sigarillo',),
'sigarilloen': ('sigarillo',),
'sigarilloene': ('sigarillo',),
'sigarilloer': ('sigarillo',),
'sigarkassa': ('sigarkasse',),
'sigarkasse': ('sigarkasse',),
'sigarkassen': ('sigarkasse',),
'sigarkassene': ('sigarkasse',),
'sigarkasser': ('sigarkasse',),
'sigd': ('sigd',),
'sigden': ('sigd',),
'sigdene': ('sigd',),
'sigder': ('sigd',),
'sigdalsfrokost': ('sigdalsfrokost',),
'sigdalsfrokosten': ('sigdalsfrokost',),
'sigdalsfrokostene': ('sigdalsfrokost',),
'sigdalsfrokoster': ('sigdalsfrokost',),
'sigdøl': ('sigdøl',),
'sigdølen': ('sigdøl',),
'sigdølene': ('sigdøl',),
'sigdøler': ('sigdøl',),
'sigenda': ('sigende',),
'sigende': ('sigende',),
'sigendene': ('sigende',),
'sigender': ('sigende',),
'sigendet': ('sigende',),
'sightseeing': ('sightseeing',),
'sightseeingen': ('sightseeing',),
'sightseeingene': ('sightseeing',),
'sightseeinger': ('sightseeing',),
'sigill': ('sigill',),
'sigilla': ('sigill',),
'sigillene': ('sigill',),
'sigiller': ('sigill',),
'sigillet': ('sigill',),
'sigillografi': ('sigillografi',),
'sigillografien': ('sigillografi',),
'sigillografiene': ('sigillografi',),
'sigillografier': ('sigillografi',),
'sigma': ('sigma',),
'sigmaen': ('sigma',),
'sigmaene': ('sigma',),
'sigmaer': ('sigma',),
'signal': ('signal',),
'signala': ('signal',),
'signalene': ('signal',),
'signaler': ('signal',),
'signalet': ('signal',),
'signalement': ('signalement',),
'signalementa': ('signalement',),
'signalementene': ('signalement',),
'signalementer': ('signalement',),
'signalementet': ('signalement',),
'signalflagg': ('signalflagg',),
'signalflagga': ('signalflagg',),
'signalflaggene': ('signalflagg',),
'signalflagget': ('signalflagg',),
'signalhorn': ('signalhorn',),
'signalhorna': ('signalhorn',),
'signalhornene': ('signalhorn',),
'signalhornet': ('signalhorn',),
'signalist': ('signalist',),
'signalisten': ('signalist',),
'signalistene': ('signalist',),
'signalister': ('signalist',),
'signalklokka': ('signalklokke',),
'signalklokke': ('signalklokke',),
'signalklokken': ('signalklokke',),
'signalklokkene': ('signalklokke',),
'signalklokker': ('signalklokke',),
'signallampa': ('signallampe',),
'signallampe': ('signallampe',),
'signallampen': ('signallampe',),
'signallampene': ('signallampe',),
'signallamper': ('signallampe',),
'signallys': ('signallys',),
'signallysa': ('signallys',),
'signallysene': ('signallys',),
'signallyset': ('signallys',),
'signalpistol': ('signalpistol',),
'signalpistolen': ('signalpistol',),
'signalpistolene': ('signalpistol',),
'signalpistoler': ('signalpistol',),
'signalsystem': ('signalsystem',),
'signalsystema': ('signalsystem',),
'signalsystemene': ('signalsystem',),
'signalsystemer': ('signalsystem',),
'signalsystemet': ('signalsystem',),
'signalør': ('signalør',),
'signaløren': ('signalør',),
'signalørene': ('signalør',),
'signalører': ('signalør',),
'signatar': ('signatar',),
'signataren': ('signatar',),
'signatarene': ('signatar',),
'signatarer': ('signatar',),
'signatarmakt': ('signatarmakt',),
'signatarmakta': ('signatarmakt',),
'signatarmakten': ('signatarmakt',),
'signatarmaktene': ('signatarmakt',),
'signatarmakter': ('signatarmakt',),
'signatur': ('signatur',),
'signaturen': ('signatur',),
'signaturene': ('signatur',),
'signaturer': ('signatur',),
'signeformular': ('signeformular',),
'signeformulara': ('signeformular',),
'signeformularen': ('signeformular',),
'signeformularene': ('signeformular',),
'signeformularer': ('signeformular',),
'signeformularet': ('signeformular',),
'signekall': ('signekall',),
'signekallen': ('signekall',),
'signekallene': ('signekall',),
'signekaller': ('signekall',),
'signekjerring': ('signekjerring',),
'signekjerringa': ('signekjerring',),
'signekjerringen': ('signekjerring',),
'signekjerringene': ('signekjerring',),
'signekjerringer': ('signekjerring',),
'signet': ('signet',),
'signeta': ('signet',),
'signetene': ('signet',),
'signeter': ('signet',),
'signetet': ('signet',),
'signetring': ('signetring',),
'signetringen': ('signetring',),
'signetringene': ('signetring',),
'signetringer': ('signetring',),
'signifikans': ('signifikans',),
'signifikansen': ('signifikans',),
'signifikansene': ('signifikans',),
'signifikanser': ('signifikans',),
'signing': ('signing',),
'signinga': ('signing',),
'signingen': ('signing',),
'signingene': ('signing',),
'signinger': ('signing',),
'signora': ('signora',),
'signoraen': ('signora',),
'signoraene': ('signora',),
'signoraer': ('signora',),
'signore': ('signore',),
'signoren': ('signore',),
'signorene': ('signore',),
'signorer': ('signore',),
'signorina': ('signorina',),
'signorinaen': ('signorina',),
'signorinaene': ('signorina',),
'signorinaer': ('signorina',),
'signorino': ('signorino',),
'signorinoen': ('signorino',),
'signorinoene': ('signorino',),
'signorinoer': ('signorino',),
'signa': ('signum',),
'signaene': ('signum',),
'signum': ('signum',),
'signumet': ('signum',),
'sigøyner': ('sigøyner',),
'sigøynere': ('sigøyner',),
'sigøyneren': ('sigøyner',),
'sigøynerer': ('sigøyner',),
'sigøynerne': ('sigøyner',),
'sigøynermusikk': ('sigøynermusikk',),
'sigøynermusikken': ('sigøynermusikk',),
'sigøynermusikkene': ('sigøynermusikk',),
'sigøynermusikker': ('sigøynermusikk',),
'sigøynerorkester': ('sigøynerorkester',),
'sigøynerorkesteret': ('sigøynerorkester',),
'sigøynerorkestra': ('sigøynerorkester',),
'sigøynerorkestre': ('sigøynerorkester',),
'sigøynerorkestrene': ('sigøynerorkester',),
'sigøynerorkestret': ('sigøynerorkester',),
'sigøynerspråk': ('sigøynerspråk',),
'sigøynerspråka': ('sigøynerspråk',),
'sigøynerspråkene': ('sigøynerspråk',),
'sigøynerspråket': ('sigøynerspråk',),
'sik': ('sik',),
'siken': ('sik',),
'sikene': ('sik',),
'siker': ('sik',),
'sik': ('sik',),
'sika': ('sik',),
'sikene': ('sik',),
'siket': ('sik',),
'sik': ('sik',),
'sika': ('sik',),
'siken': ('sik',),
'sikene': ('sik',),
'siker': ('sik',),
'sikade': ('sikade',),
'sikaden': ('sikade',),
'sikadene': ('sikade',),
'sikader': ('sikade',),
'sikahjort': ('sikahjort',),
'sikahjorten': ('sikahjort',),
'sikahjortene': ('sikahjort',),
'sikahjorter': ('sikahjort',),
'sikh': ('sikh',),
'sikhen': ('sikh',),
'sikhene': ('sikh',),
'sikher': ('sikh',),
'sikkativ': ('sikkativ',),
'sikkativa': ('sikkativ',),
'sikkativene': ('sikkativ',),
'sikkativer': ('sikkativ',),
'sikkativet': ('sikkativ',),
'sikkel': ('sikkel',),
'sikkelet': ('sikkel',),
'sikla': ('sikkel',),
'siklene': ('sikkel',),
'siklet': ('sikkel',),
'sikkel': ('sikkel',),
'sikkelet': ('sikkel',),
'sikla': ('sikkel',),
'siklene': ('sikkel',),
'siklet': ('sikkel',),
'sikkerhet': ('sikkerhet',),
'sikkerheta': ('sikkerhet',),
'sikkerheten': ('sikkerhet',),
'sikkerhetene': ('sikkerhet',),
'sikkerheter': ('sikkerhet',),
'sikkerhetsavtale': ('sikkerhetsavtale',),
'sikkerhetsavtalen': ('sikkerhetsavtale',),
'sikkerhetsavtalene': ('sikkerhetsavtale',),
'sikkerhetsavtaler': ('sikkerhetsavtale',),
'sikkerhetsbelta': ('sikkerhetsbelte',),
'sikkerhetsbelte': ('sikkerhetsbelte',),
'sikkerhetsbeltene': ('sikkerhetsbelte',),
'sikkerhetsbelter': ('sikkerhetsbelte',),
'sikkerhetsbeltet': ('sikkerhetsbelte',),
'sikkerhetscella': ('sikkerhetscelle',),
'sikkerhetscelle': ('sikkerhetscelle',),
'sikkerhetscellen': ('sikkerhetscelle',),
'sikkerhetscellene': ('sikkerhetscelle',),
'sikkerhetsceller': ('sikkerhetscelle',),
'sikkerhetsforanstaltning': ('sikkerhetsforanstaltning',),
'sikkerhetsforanstaltninga': ('sikkerhetsforanstaltning',),
'sikkerhetsforanstaltningen': ('sikkerhetsforanstaltning',),
'sikkerhetsforanstaltningene': ('sikkerhetsforanstaltning',),
'sikkerhetsforanstaltninger': ('sikkerhetsforanstaltning',),
'sikkerhetsforskrift': ('sikkerhetsforskrift',),
'sikkerhetsforskrifta': ('sikkerhetsforskrift',),
'sikkerhetsforskriften': ('sikkerhetsforskrift',),
'sikkerhetsforskriftene': ('sikkerhetsforskrift',),
'sikkerhetsforskrifter': ('sikkerhetsforskrift',),
'sikkerhetshvelv': ('sikkerhetshvelv',),
'sikkerhetshvelva': ('sikkerhetshvelv',),
'sikkerhetshvelvene': ('sikkerhetshvelv',),
'sikkerhetshvelvet': ('sikkerhetshvelv',),
'sikkerhetskonferanse': ('sikkerhetskonferanse',),
'sikkerhetskonferansen': ('sikkerhetskonferanse',),
'sikkerhetskonferansene': ('sikkerhetskonferanse',),
'sikkerhetskonferanser': ('sikkerhetskonferanse',),
'sikkerhetslenka': ('sikkerhetslenke',),
'sikkerhetslenke': ('sikkerhetslenke',),
'sikkerhetslenken': ('sikkerhetslenke',),
'sikkerhetslenkene': ('sikkerhetslenke',),
'sikkerhetslenker': ('sikkerhetslenke',),
'sikkerhetslås': ('sikkerhetslås',),
'sikkerhetslåsa': ('sikkerhetslås',),
'sikkerhetslåsen': ('sikkerhetslås',),
'sikkerhetslåsene': ('sikkerhetslås',),
'sikkerhetslåser': ('sikkerhetslås',),
'sikkerhetslåset': ('sikkerhetslås',),
'sikkerhetsnål': ('sikkerhetsnål',),
'sikkerhetsnåla': ('sikkerhetsnål',),
'sikkerhetsnålen': ('sikkerhetsnål',),
'sikkerhetsnålene': ('sikkerhetsnål',),
'sikkerhetsnåler': ('sikkerhetsnål',),
'sikkerhetspoliti': ('sikkerhetspoliti',),
'sikkerhetspolitia': ('sikkerhetspoliti',),
'sikkerhetspolitiene': ('sikkerhetspoliti',),
'sikkerhetspolitier': ('sikkerhetspoliti',),
'sikkerhetspolitiet': ('sikkerhetspoliti',),
'sikkerhetspolitikk': ('sikkerhetspolitikk',),
'sikkerhetspolitikken': ('sikkerhetspolitikk',),
'sikkerhetspolitikkene': ('sikkerhetspolitikk',),
'sikkerhetspolitikker': ('sikkerhetspolitikk',),
'sikkerhetsråd': ('sikkerhetsråd',),
'sikkerhetsråda': ('sikkerhetsråd',),
'sikkerhetsrådene': ('sikkerhetsråd',),
'sikkerhetsrådet': ('sikkerhetsråd',),
'sikkerhetssele': ('sikkerhetssele',),
'sikkerhetsselen': ('sikkerhetssele',),
'sikkerhetsselene': ('sikkerhetssele',),
'sikkerhetsseler': ('sikkerhetssele',),
'sikkerhetstiltak': ('sikkerhetstiltak',),
'sikkerhetstiltaka': ('sikkerhetstiltak',),
'sikkerhetstiltakene': ('sikkerhetstiltak',),
'sikkerhetstiltaket': ('sikkerhetstiltak',),
'sikkerhetstjeneste': ('sikkerhetstjeneste',),
'sikkerhetstjenesten': ('sikkerhetstjeneste',),
'sikkerhetstjenestene': ('sikkerhetstjeneste',),
'sikkerhetstjenester': ('sikkerhetstjeneste',),
'sikkerhetsventil': ('sikkerhetsventil',),
'sikkerhetsventilen': ('sikkerhetsventil',),
'sikkerhetsventilene': ('sikkerhetsventil',),
'sikkerhetsventiler': ('sikkerhetsventil',),
'sikkimeser': ('sikkimeser',),
'sikkimesere': ('sikkimeser',),
'sikkimeseren': ('sikkimeser',),
'sikkimeserer': ('sikkimeser',),
'sikkimeserne': ('sikkimeser',),
'sikksakk': ('sikksakk',),
'sikksakkband': ('sikksakkband',),
'sikksakkbanda': ('sikksakkband',),
'sikksakkbandene': ('sikksakkband',),
'sikksakkbandet': ('sikksakkband',),
'sikksakkbånd': ('sikksakkbånd',),
'sikksakkbånda': ('sikksakkbånd',),
'sikksakkbåndene': ('sikksakkbånd',),
'sikksakkbåndet': ('sikksakkbånd',),
'sikksakklyn': ('sikksakklyn',),
'sikksakklyna': ('sikksakklyn',),
'sikksakklynene': ('sikksakklyn',),
'sikksakklynet': ('sikksakklyn',),
'sikl': ('sikl',),
'sikla': ('sikl',),
'siklene': ('sikl',),
'siklet': ('sikl',),
'sikl': ('sikl',),
'sikla': ('sikl',),
'siklene': ('sikl',),
'siklet': ('sikl',),
'sikling': ('sikling',),
'siklingen': ('sikling',),
'siklingene': ('sikling',),
'siklinger': ('sikling',),
'sikori': ('sikori',),
'sikorien': ('sikori',),
'sikoriene': ('sikori',),
'sikorier': ('sikori',),
'sikring': ('sikring',),
'sikringa': ('sikring',),
'sikringen': ('sikring',),
'sikringene': ('sikring',),
'sikringer': ('sikring',),
'sikringsanstalt': ('sikringsanstalt',),
'sikringsanstalten': ('sikringsanstalt',),
'sikringsanstaltene': ('sikringsanstalt',),
'sikringsanstalter': ('sikringsanstalt',),
'sikringsboks': ('sikringsboks',),
'sikringsboksen': ('sikringsboks',),
'sikringsboksene': ('sikringsboks',),
'sikringsbokser': ('sikringsboks',),
'sikringsfange': ('sikringsfange',),
'sikringsfangen': ('sikringsfange',),
'sikringsfangene': ('sikringsfange',),
'sikringsfanger': ('sikringsfange',),
'sikringskost': ('sikringskost',),
'sikringskosten': ('sikringskost',),
'sikringskostene': ('sikringskost',),
'sikringskoster': ('sikringskost',),
'sikringsskap': ('sikringsskap',),
'sikringsskapa': ('sikringsskap',),
'sikringsskapene': ('sikringsskap',),
'sikringsskapet': ('sikringsskap',),
'sikringstavla': ('sikringstavle',),
'sikringstavle': ('sikringstavle',),
'sikringstavlen': ('sikringstavle',),
'sikringstavlene': ('sikringstavle',),
'sikringstavler': ('sikringstavle',),
'sikringsventil': ('sikringsventil',),
'sikringsventilen': ('sikringsventil',),
'sikringsventilene': ('sikringsventil',),
'sikringsventiler': ('sikringsventil',),
'sikspens': ('sikspens',),
'sikspensen': ('sikspens',),
'sikspensene': ('sikspens',),
'sikspenser': ('sikspens',),
'sikspenslua': ('sikspenslue',),
'sikspenslue': ('sikspenslue',),
'sikspensluen': ('sikspenslue',),
'sikspensluene': ('sikspenslue',),
'sikspensluer': ('sikspenslue',),
'sikspensluva': ('sikspensluve',),
'sikspensluve': ('sikspensluve',),
'sikspensluven': ('sikspensluve',),
'sikspensluvene': ('sikspensluve',),
'sikspensluver': ('sikspensluve',),
'sikt': ('sikt',),
'sikta': ('sikt',),
'sikten': ('sikt',),
'siktene': ('sikt',),
'sikter': ('sikt',),
'sikt': ('sikt',),
'sikta': ('sikt',),
'sikten': ('sikt',),
'siktene': ('sikt',),
'sikter': ('sikt',),
'siktbarhet': ('siktbarhet',),
'siktbarheta': ('siktbarhet',),
'siktbarheten': ('siktbarhet',),
'siktbarhetene': ('siktbarhet',),
'siktbarheter': ('siktbarhet',),
'sikta': ('sikte',),
'sikte': ('sikte',),
'siktene': ('sikte',),
'sikter': ('sikte',),
'siktet': ('sikte',),
'siktelinja': ('siktelinje',),
'siktelinje': ('siktelinje',),
'siktelinjen': ('siktelinje',),
'siktelinjene': ('siktelinje',),
'siktelinjer': ('siktelinje',),
'siktelse': ('siktelse',),
'siktelsen': ('siktelse',),
'siktelsene': ('siktelse',),
'siktelser': ('siktelse',),
'siktemel': ('siktemel',),
'siktemela': ('siktemel',),
'siktemelene': ('siktemel',),
'siktemelet': ('siktemel',),
'siktemiddel': ('siktemiddel',),
'siktemiddelet': ('siktemiddel',),
'siktemidla': ('siktemiddel',),
'siktemidlene': ('siktemiddel',),
'siktemidler': ('siktemiddel',),
'siktemidlet': ('siktemiddel',),
'siktemjøl': ('siktemjøl',),
'siktemjøla': ('siktemjøl',),
'siktemjølene': ('siktemjøl',),
'siktemjølet': ('siktemjøl',),
'siktemål': ('siktemål',),
'siktemåla': ('siktemål',),
'siktemålene': ('siktemål',),
'siktemålet': ('siktemål',),
'siktepunkt': ('siktepunkt',),
'siktepunkta': ('siktepunkt',),
'siktepunktene': ('siktepunkt',),
'siktepunkter': ('siktepunkt',),
'siktepunktet': ('siktepunkt',),
'sikteskår': ('sikteskår',),
'sikteskåra': ('sikteskår',),
'sikteskårene': ('sikteskår',),
'sikteskåret': ('sikteskår',),
'siktveksel': ('siktveksel',),
'siktvekselen': ('siktveksel',),
'siktvekslene': ('siktveksel',),
'siktveksler': ('siktveksel',),
'sil': ('sil',),
'silen': ('sil',),
'silene': ('sil',),
'siler': ('sil',),
'sil': ('sil',),
'silen': ('sil',),
'silene': ('sil',),
'siler': ('sil',),
'siland': ('siland',),
'silanda': ('siland',),
'silanden': ('siland',),
'silendene': ('siland',),
'silender': ('siland',),
'sild': ('sild',),
'silda': ('sild',),
'silden': ('sild',),
'sildene': ('sild',),
'silder': ('sild',),
'sildebruk': ('sildebruk',),
'sildebruka': ('sildebruk',),
'sildebrukene': ('sildebruk',),
'sildebruket': ('sildebruk',),
'sildefisk': ('sildefisk',),
'sildefisken': ('sildefisk',),
'sildefiskene': ('sildefisk',),
'sildefisker': ('sildefisk',),
'sildefiska': ('sildefiske',),
'sildefiske': ('sildefiske',),
'sildefiskene': ('sildefiske',),
'sildefisker': ('sildefiske',),
'sildefisket': ('sildefiske',),
'sildeganing': ('sildeganing',),
'sildeganinga': ('sildeganing',),
'sildeganingen': ('sildeganing',),
'sildeganingene': ('sildeganing',),
'sildeganinger': ('sildeganing',),
'sildegarn': ('sildegarn',),
'sildegarna': ('sildegarn',),
'sildegarnene': ('sildegarn',),
'sildegarnet': ('sildegarn',),
'sildehai': ('sildehai',),
'sildehaien': ('sildehai',),
'sildehaiene': ('sildehai',),
'sildehaier': ('sildehai',),
'sildekaka': ('sildekake',),
'sildekake': ('sildekake',),
'sildekaken': ('sildekake',),
'sildekakene': ('sildekake',),
'sildekaker': ('sildekake',),
'sildekong': ('sildekong',),
'sildekongen': ('sildekong',),
'sildekongene': ('sildekong',),
'sildekonger': ('sildekong',),
'sildekonge': ('sildekonge',),
'sildekongen': ('sildekonge',),
'sildekongene': ('sildekonge',),
'sildekonger': ('sildekonge',),
'sildemel': ('sildemel',),
'sildemela': ('sildemel',),
'sildemelene': ('sildemel',),
'sildemelet': ('sildemel',),
'sildemelfabrikk': ('sildemelfabrikk',),
'sildemelfabrikken': ('sildemelfabrikk',),
'sildemelfabrikkene': ('sildemelfabrikk',),
'sildemelfabrikker': ('sildemelfabrikk',),
'sildemjølfabrikk': ('sildemjølfabrikk',),
'sildemjølfabrikken': ('sildemjølfabrikk',),
'sildemjølfabrikkene': ('sildemjølfabrikk',),
'sildemjølfabrikker': ('sildemjølfabrikk',),
'sildemåka': ('sildemåke',),
'sildemåke': ('sildemåke',),
'sildemåken': ('sildemåke',),
'sildemåkene': ('sildemåke',),
'sildemåker': ('sildemåke',),
'sildemåse': ('sildemåse',),
'sildemåsen': ('sildemåse',),
'sildemåsene': ('sildemåse',),
'sildemåser': ('sildemåse',),
'sildeolja': ('sildeolje',),
'sildeolje': ('sildeolje',),
'sildeoljen': ('sildeolje',),
'sildeoljene': ('sildeolje',),
'sildeoljer': ('sildeolje',),
'sildepumpa': ('sildepumpe',),
'sildepumpe': ('sildepumpe',),
'sildepumpen': ('sildepumpe',),
'sildepumpene': ('sildepumpe',),
'sildepumper': ('sildepumpe',),
'silder': ('silder',),
'silderet': ('silder',),
'sildra': ('silder',),
'sildre': ('silder',),
'sildrene': ('silder',),
'sildrer': ('silder',),
'sildret': ('silder',),
'silderasp': ('silderasp',),
'silderaspa': ('silderasp',),
'silderaspene': ('silderasp',),
'silderaspet': ('silderasp',),
'sildesalat': ('sildesalat',),
'sildesalaten': ('sildesalat',),
'sildesalatene': ('sildesalat',),
'sildesalater': ('sildesalat',),
'sildesteng': ('sildesteng',),
'sildestenga': ('sildesteng',),
'sildestengene': ('sildesteng',),
'sildestenget': ('sildesteng',),
'sildestim': ('sildestim',),
'sildestima': ('sildestim',),
'sildestimen': ('sildestim',),
'sildestimene': ('sildestim',),
'sildestimer': ('sildestim',),
'sildestimet': ('sildestim',),
'sildestørja': ('sildestørje',),
'sildestørje': ('sildestørje',),
'sildestørjen': ('sildestørje',),
'sildestørjene': ('sildestørje',),
'sildestørjer': ('sildestørje',),
'sildevraker': ('sildevraker',),
'sildevrakere': ('sildevraker',),
'sildevrakeren': ('sildevraker',),
'sildevrakerer': ('sildevraker',),
'sildevrakerne': ('sildevraker',),
'sildolja': ('sildolje',),
'sildolje': ('sildolje',),
'sildoljen': ('sildolje',),
'sildoljene': ('sildolje',),
'sildoljer': ('sildolje',),
'sildra': ('sildre',),
'sildre': ('sildre',),
'sildren': ('sildre',),
'sildrene': ('sildre',),
'sildrer': ('sildre',),
'sildra': ('sildre',),
'sildre': ('sildre',),
'sildren': ('sildre',),
'sildrene': ('sildre',),
'sildrer': ('sildre',),
'sildrebekk': ('sildrebekk',),
'sildrebekken': ('sildrebekk',),
'sildrebekkene': ('sildrebekk',),
'sildrebekker': ('sildrebekk',),
'sildrefamilie': ('sildrefamilie',),
'sildrefamilien': ('sildrefamilie',),
'sildrefamiliene': ('sildrefamilie',),
'sildrefamilier': ('sildrefamilie',),
'sildråpe': ('sildråpe',),
'sildråpen': ('sildråpe',),
'sildråpene': ('sildråpe',),
'sildråper': ('sildråpe',),
'silentium': ('silentium',),
'silhuett': ('silhuett',),
'silhuetten': ('silhuett',),
'silhuettene': ('silhuett',),
'silhuetter': ('silhuett',),
'silhår': ('silhår',),
'silhåra': ('silhår',),
'silhårene': ('silhår',),
'silhåret': ('silhår',),
'silikat': ('silikat',),
'silikata': ('silikat',),
'silikatene': ('silikat',),
'silikater': ('silikat',),
'silikatet': ('silikat',),
'silikon': ('silikon',),
'silikona': ('silikon',),
'silikonene': ('silikon',),
'silikoner': ('silikon',),
'silikonet': ('silikon',),
'silikose': ('silikose',),
'silikosen': ('silikose',),
'silikosene': ('silikose',),
'silikoser': ('silikose',),
'silisium': ('silisium',),
'silisiuma': ('silisium',),
'silisiumene': ('silisium',),
'silisiumet': ('silisium',),
'silisiumkarbid': ('silisiumkarbid',),
'silisiumkarbida': ('silisiumkarbid',),
'silisiumkarbiden': ('silisiumkarbid',),
'silisiumkarbidene': ('silisiumkarbid',),
'silisiumkarbider': ('silisiumkarbid',),
'silisiumkarbidet': ('silisiumkarbid',),
'silke': ('silke',),
'silken': ('silke',),
'silkene': ('silke',),
'silker': ('silke',),
'silkeatlask': ('silkeatlask',),
'silkeatlasken': ('silkeatlask',),
'silkeatlaskene': ('silkeatlask',),
'silkeatlasker': ('silkeatlask',),
'silkebroderi': ('silkebroderi',),
'silkebroderia': ('silkebroderi',),
'silkebroderiene': ('silkebroderi',),
'silkebroderier': ('silkebroderi',),
'silkebroderiet': ('silkebroderi',),
'silkeføra': ('silkeføre',),
'silkeføre': ('silkeføre',),
'silkeførene': ('silkeføre',),
'silkefører': ('silkeføre',),
'silkeføret': ('silkeføre',),
'silkehanske': ('silkehanske',),
'silkehansken': ('silkehanske',),
'silkehanskene': ('silkehanske',),
'silkehansker': ('silkehanske',),
'silkehår': ('silkehår',),
'silkehåra': ('silkehår',),
'silkehårene': ('silkehår',),
'silkehåret': ('silkehår',),
'silkekjole': ('silkekjole',),
'silkekjolen': ('silkekjole',),
'silkekjolene': ('silkekjole',),
'silkekjoler': ('silkekjole',),
'silkekokong': ('silkekokong',),
'silkekokongen': ('silkekokong',),
'silkekokongene': ('silkekokong',),
'silkekokonger': ('silkekokong',),
'silkemusling': ('silkemusling',),
'silkemuslingen': ('silkemusling',),
'silkemuslingene': ('silkemusling',),
'silkemuslinger': ('silkemusling',),
'silkeorm': ('silkeorm',),
'silkeormen': ('silkeorm',),
'silkeormene': ('silkeorm',),
'silkeormer': ('silkeorm',),
'silkepapir': ('silkepapir',),
'silkepapira': ('silkepapir',),
'silkepapirene': ('silkepapir',),
'silkepapirer': ('silkepapir',),
'silkepapiret': ('silkepapir',),
'silkeramp': ('silkeramp',),
'silkerampen': ('silkeramp',),
'silkerampene': ('silkeramp',),
'silkeramper': ('silkeramp',),
'silkeseng': ('silkeseng',),
'silkesenga': ('silkeseng',),
'silkesengen': ('silkeseng',),
'silkesengene': ('silkeseng',),
'silkesenger': ('silkeseng',),
'silkesnor': ('silkesnor',),
'silkesnora': ('silkesnor',),
'silkesnoren': ('silkesnor',),
'silkesnorene': ('silkesnor',),
'silkesnorer': ('silkesnor',),
'silkespinner': ('silkespinner',),
'silkespinnere': ('silkespinner',),
'silkespinneren': ('silkespinner',),
'silkespinnerer': ('silkespinner',),
'silkespinnerne': ('silkespinner',),
'silkestjert': ('silkestjert',),
'silkestjerten': ('silkestjert',),
'silkestjertene': ('silkestjert',),
'silkestjerter': ('silkestjert',),
'silkestrømpa': ('silkestrømpe',),
'silkestrømpe': ('silkestrømpe',),
'silkestrømpen': ('silkestrømpe',),
'silkestrømpene': ('silkestrømpe',),
'silkestrømper': ('silkestrømpe',),
'silketrykk': ('silketrykk',),
'silketrykka': ('silketrykk',),
'silketrykkene': ('silketrykk',),
'silketrykket': ('silketrykk',),
'silketrykker': ('silketrykker',),
'silketrykkere': ('silketrykker',),
'silketrykkeren': ('silketrykker',),
'silketrykkerer': ('silketrykker',),
'silketrykkerne': ('silketrykker',),
'silketråd': ('silketråd',),
'silketråden': ('silketråd',),
'silketrådene': ('silketråd',),
'silketråder': ('silketråd',),
'silkleda': ('silklede',),
'silklede': ('silklede',),
'silkledene': ('silklede',),
'silkleder': ('silklede',),
'silkledet': ('silklede',),
'silo': ('silo',),
'siloen': ('silo',),
'siloene': ('silo',),
'siloer': ('silo',),
'silosaft': ('silosaft',),
'silosafta': ('silosaft',),
'silosaften': ('silosaft',),
'silosaftene': ('silosaft',),
'silosafter': ('silosaft',),
'silosvans': ('silosvans',),
'silosvansen': ('silosvans',),
'silosvansene': ('silosvans',),
'silosvanser': ('silosvans',),
'silregn': ('silregn',),
'silregna': ('silregn',),
'silregnene': ('silregn',),
'silregnet': ('silregn',),
'silt': ('silt',),
'silten': ('silt',),
'siltene': ('silt',),
'silter': ('silt',),
'silur': ('silur',),
'siluren': ('silur',),
'silurene': ('silur',),
'silurer': ('silur',),
'silurformasjon': ('silurformasjon',),
'silurformasjonen': ('silurformasjon',),
'silurformasjonene': ('silurformasjon',),
'silurformasjoner': ('silurformasjon',),
'silurperiode': ('silurperiode',),
'silurperioden': ('silurperiode',),
'silurperiodene': ('silurperiode',),
'silurperioder': ('silurperiode',),
'silursystem': ('silursystem',),
'silursystema': ('silursystem',),
'silursystemene': ('silursystem',),
'silursystemer': ('silursystem',),
'silursystemet': ('silursystem',),
'sima': ('sima',),
'simaa': ('sima',),
'simaene': ('sima',),
'simaet': ('sima',),
'simalag': ('simalag',),
'simalaga': ('simalag',),
'simalagene': ('simalag',),
'simalaget': ('simalag',),
'simili': ('simili',),
'similia': ('simili',),
'similiene': ('simili',),
'similier': ('simili',),
'similiet': ('simili',),
'similidiamant': ('similidiamant',),
'similidiamanten': ('similidiamant',),
'similidiamantene': ('similidiamant',),
'similidiamanter': ('similidiamant',),
'similismykka': ('similismykke',),
'similismykke': ('similismykke',),
'similismykkene': ('similismykke',),
'similismykker': ('similismykke',),
'similismykket': ('similismykke',),
'similor': ('similor',),
'similora': ('similor',),
'similorene': ('similor',),
'similoret': ('similor',),
'simla': ('simle',),
'simle': ('simle',),
'simlen': ('simle',),
'simlene': ('simle',),
'simler': ('simle',),
'simoni': ('simoni',),
'simonien': ('simoni',),
'simoniene': ('simoni',),
'simonier': ('simoni',),
'simonsdag': ('simonsdag',),
'simonsdagen': ('simonsdag',),
'simonsdagene': ('simonsdag',),
'simonsdager': ('simonsdag',),
'simonsmess': ('simonsmess',),
'simonsmesse': ('simonsmesse',),
'simpa': ('simpe',),
'simpe': ('simpe',),
'simpen': ('simpe',),
'simpene': ('simpe',),
'simper': ('simpe',),
'simpelhet': ('simpelhet',),
'simpelheta': ('simpelhet',),
'simpelheten': ('simpelhet',),
'simpelhetene': ('simpelhet',),
'simpelheter': ('simpelhet',),
'simpleksord': ('simpleksord',),
'simpleksorda': ('simpleksord',),
'simpleksordene': ('simpleksord',),
'simpleksordet': ('simpleksord',),
'simplifikasjon': ('simplifikasjon',),
'simplifikasjonen': ('simplifikasjon',),
'simplifikasjonene': ('simplifikasjon',),
'simplifikasjoner': ('simplifikasjon',),
'simulant': ('simulant',),
'simulanten': ('simulant',),
'simulantene': ('simulant',),
'simulanter': ('simulant',),
'simulasjon': ('simulasjon',),
'simulasjonen': ('simulasjon',),
'simulasjonene': ('simulasjon',),
'simulasjoner': ('simulasjon',),
'simulator': ('simulator',),
'simulatoren': ('simulator',),
'simulatorene': ('simulator',),
'simulatorer': ('simulator',),
'simuleringsmodell': ('simuleringsmodell',),
'simuleringsmodellen': ('simuleringsmodell',),
'simuleringsmodellene': ('simuleringsmodell',),
'simuleringsmodeller': ('simuleringsmodell',),
'simultanoversettelse': ('simultanoversettelse',),
'simultanoversettelsen': ('simultanoversettelse',),
'simultanoversettelsene': ('simultanoversettelse',),
'simultanoversettelser': ('simultanoversettelse',),
'simultanparti': ('simultanparti',),
'simultanpartia': ('simultanparti',),
'simultanpartiene': ('simultanparti',),
'simultanpartier': ('simultanparti',),
'simultanpartiet': ('simultanparti',),
'simultantolk': ('simultantolk',),
'simultantolken': ('simultantolk',),
'simultantolkene': ('simultantolk',),
'simultantolker': ('simultantolk',),
'sinder': ('sinder',),
'sinderet': ('sinder',),
'sindra': ('sinder',),
'sindre': ('sinder',),
'sindrene': ('sinder',),
'sindrer': ('sinder',),
'sindret': ('sinder',),
'sinders': ('sinders',),
'sindersen': ('sinders',),
'sindersene': ('sinders',),
'sinderser': ('sinders',),
'sindighet': ('sindighet',),
'sindigheta': ('sindighet',),
'sindigheten': ('sindighet',),
'sindighetene': ('sindighet',),
'sindigheter': ('sindighet',),
'sine qua non': ('sine qua non',),
'sinekyre': ('sinekyre',),
'sinekyren': ('sinekyre',),
'sinekyrene': ('sinekyre',),
'sinekyrer': ('sinekyre',),
'sinekyrist': ('sinekyrist',),
'sinekyristen': ('sinekyrist',),
'sinekyristene': ('sinekyrist',),
'sinekyrister': ('sinekyrist',),
'sinemelk': ('sinemelk',),
'sinemelka': ('sinemelk',),
'sinemelken': ('sinemelk',),
'sinemelkene': ('sinemelk',),
'sinemelker': ('sinemelk',),
'sinemjølk': ('sinemjølk',),
'sinemjølka': ('sinemjølk',),
'sinemjølken': ('sinemjølk',),
'sinemjølkene': ('sinemjølk',),
'sinemjølker': ('sinemjølk',),
'sinfonia': ('sinfonia',),
'sinfoniaen': ('sinfonia',),
'sinfoniaene': ('sinfonia',),
'sinfoniaer': ('sinfonia',),
'singaleser': ('singaleser',),
'singalesere': ('singaleser',),
'singaleseren': ('singaleser',),
'singaleserer': ('singaleser',),
'singaleserne': ('singaleser',),
'singaporer': ('singaporer',),
'singaporere': ('singaporer',),
'singaporeren': ('singaporer',),
'singaporerer': ('singaporer',),
'singaporerne': ('singaporer',),
'singel': ('singel',),
'singelen': ('singel',),
'singlene': ('singel',),
'singler': ('singel',),
'singel': ('singel',),
'singelen': ('singel',),
'singelet': ('singel',),
'singla': ('singel',),
'singlene': ('singel',),
'singler': ('singel',),
'singlet': ('singel',),
'singelplata': ('singelplate',),
'singelplate': ('singelplate',),
'singelplaten': ('singelplate',),
'singelplatene': ('singelplate',),
'singelplater': ('singelplate',),
'single': ('single',),
'singlen': ('single',),
'singlene': ('single',),
'singler': ('single',),
'singlesculler': ('singlesculler',),
'singlescullere': ('singlesculler',),
'singlesculleren': ('singlesculler',),
'singlescullerer': ('singlesculler',),
'singlescullerne': ('singlesculler',),
'singlet': ('singlet',),
'singleten': ('singlet',),
'singletene': ('singlet',),
'singleter': ('singlet',),
'singleton': ('singleton',),
'singletonen': ('singleton',),
'singletonene': ('singleton',),
'singular': ('singular',),
'singularen': ('singular',),
'singularene': ('singular',),
'singularer': ('singular',),
'singularform': ('singularform',),
'singularforma': ('singularform',),
'singularformen': ('singularform',),
'singularformene': ('singularform',),
'singularformer': ('singularform',),
'singularis': ('singularis',),
'singularisen': ('singularis',),
'singularisene': ('singularis',),
'singulariser': ('singularis',),
'singularisme': ('singularisme',),
'singularismen': ('singularisme',),
'singularismene': ('singularisme',),
'singularismer': ('singularisme',),
'sink': ('sink',),
'sinken': ('sink',),
'sinkene': ('sink',),
'sinker': ('sink',),
'sink': ('sink',),
'sinka': ('sink',),
'sinken': ('sink',),
'sinkene': ('sink',),
'sinker': ('sink',),
'sinket': ('sink',),
'sinkblende': ('sinkblende',),
'sinkblenden': ('sinkblende',),
'sinkblendene': ('sinkblende',),
'sinkblender': ('sinkblende',),
'sinke': ('sinke',),
'sinken': ('sinke',),
'sinkene': ('sinke',),
'sinker': ('sinke',),
'sinke': ('sinke',),
'sinken': ('sinke',),
'sinkene': ('sinke',),
'sinker': ('sinke',),
'sinkeleksa': ('sinkelekse',),
'sinkelekse': ('sinkelekse',),
'sinkeleksen': ('sinkelekse',),
'sinkeleksene': ('sinkelekse',),
'sinkelekser': ('sinkelekse',),
'sinkemaskin': ('sinkemaskin',),
'sinkemaskina': ('sinkemaskin',),
'sinkemaskinen': ('sinkemaskin',),
'sinkemaskinene': ('sinkemaskin',),
'sinkemaskiner': ('sinkemaskin',),
'sinkfarge': ('sinkfarge',),
'sinkfargen': ('sinkfarge',),
'sinkfargene': ('sinkfarge',),
'sinkfarger': ('sinkfarge',),
'sinkhvitt': ('sinkhvitt',),
'sinkkvitt': ('sinkkvitt',),
'sinklegering': ('sinklegering',),
'sinklegeringa': ('sinklegering',),
'sinklegeringen': ('sinklegering',),
'sinklegeringene': ('sinklegering',),
'sinklegeringer': ('sinklegering',),
'sinkoksid': ('sinkoksid',),
'sinkoksida': ('sinkoksid',),
'sinkoksidene': ('sinkoksid',),
'sinkoksider': ('sinkoksid',),
'sinkoksidet': ('sinkoksid',),
'sinksalva': ('sinksalve',),
'sinksalve': ('sinksalve',),
'sinksalven': ('sinksalve',),
'sinksalvene': ('sinksalve',),
'sinksalver': ('sinksalve',),
'sinn': ('sinn',),
'sinna': ('sinn',),
'sinnene': ('sinn',),
'sinnet': ('sinn',),
'sinnatagg': ('sinnatagg',),
'sinnataggen': ('sinnatagg',),
'sinnataggene': ('sinnatagg',),
'sinnatagger': ('sinnatagg',),
'sinnbilda': ('sinnbilde',),
'sinnbilde': ('sinnbilde',),
'sinnbildene': ('sinnbilde',),
'sinnbilder': ('sinnbilde',),
'sinnbildet': ('sinnbilde',),
'sinna': ('sinne',),
'sinne': ('sinne',),
'sinnene': ('sinne',),
'sinner': ('sinne',),
'sinnet': ('sinne',),
'sinnelag': ('sinnelag',),
'sinnelaga': ('sinnelag',),
'sinnelagene': ('sinnelag',),
'sinnelaget': ('sinnelag',),
'sinnetokt': ('sinnetokt',),
'sinnetokta': ('sinnetokt',),
'sinnetokten': ('sinnetokt',),
'sinnetoktene': ('sinnetokt',),
'sinnetokter': ('sinnetokt',),
'sinnsbevegelse': ('sinnsbevegelse',),
'sinnsbevegelsen': ('sinnsbevegelse',),
'sinnsbevegelsene': ('sinnsbevegelse',),
'sinnsbevegelser': ('sinnsbevegelse',),
'sinnsforvirring': ('sinnsforvirring',),
'sinnsforvirringa': ('sinnsforvirring',),
'sinnsforvirringen': ('sinnsforvirring',),
'sinnsforvirringene': ('sinnsforvirring',),
'sinnsforvirringer': ('sinnsforvirring',),
'sinnslidelse': ('sinnslidelse',),
'sinnslidelsen': ('sinnslidelse',),
'sinnslidelsene': ('sinnslidelse',),
'sinnslidelser': ('sinnslidelse',),
'sinnsopprør': ('sinnsopprør',),
'sinnsopprøra': ('sinnsopprør',),
'sinnsopprørene': ('sinnsopprør',),
'sinnsopprøret': ('sinnsopprør',),
'sinnsro': ('sinnsro',),
'sinnsroa': ('sinnsro',),
'sinnsroen': ('sinnsro',),
'sinnsroene': ('sinnsro',),
'sinnsroer': ('sinnsro',),
'sinnssjukdom': ('sinnssjukdom',),
'sinnssjukdommen': ('sinnssjukdom',),
'sinnssjukdommene': ('sinnssjukdom',),
'sinnssjukdommer': ('sinnssjukdom',),
'sinnssjukeasyl': ('sinnssjukeasyl',),
'sinnssjukeasyla': ('sinnssjukeasyl',),
'sinnssjukeasylene': ('sinnssjukeasyl',),
'sinnssjukeasyler': ('sinnssjukeasyl',),
'sinnssjukeasylet': ('sinnssjukeasyl',),
'sinnssjukehus': ('sinnssjukehus',),
'sinnssjukehusa': ('sinnssjukehus',),
'sinnssjukehusene': ('sinnssjukehus',),
'sinnssjukehuset': ('sinnssjukehus',),
'sinnsstemning': ('sinnsstemning',),
'sinnsstemninga': ('sinnsstemning',),
'sinnsstemningen': ('sinnsstemning',),
'sinnsstemningene': ('sinnsstemning',),
'sinnsstemninger': ('sinnsstemning',),
'sinnsstyrke': ('sinnsstyrke',),
'sinnsstyrken': ('sinnsstyrke',),
'sinnsstyrkene': ('sinnsstyrke',),
'sinnsstyrker': ('sinnsstyrke',),
'sinnssykdom': ('sinnssykdom',),
'sinnssykdommen': ('sinnssykdom',),
'sinnssykdommene': ('sinnssykdom',),
'sinnssykdommer': ('sinnssykdom',),
'sinnssykeasyl': ('sinnssykeasyl',),
'sinnssykeasyla': ('sinnssykeasyl',),
'sinnssykeasylene': ('sinnssykeasyl',),
'sinnssykeasyler': ('sinnssykeasyl',),
'sinnssykeasylet': ('sinnssykeasyl',),
'sinnssykehus': ('sinnssykehus',),
'sinnssykehusa': ('sinnssykehus',),
'sinnssykehusene': ('sinnssykehus',),
'sinnssykehuset': ('sinnssykehus',),
'sinnstilstand': ('sinnstilstand',),
'sinnstilstanden': ('sinnstilstand',),
'sinnstilstandene': ('sinnstilstand',),
'sinnstilstander': ('sinnstilstand',),
'sinober': ('sinober',),
'sinobere': ('sinober',),
'sinoberen': ('sinober',),
'sinoberer': ('sinober',),
'sinoberne': ('sinober',),
'sinobre': ('sinober',),
'sinobrene': ('sinober',),
'sinobrer': ('sinober',),
'sinolog': ('sinolog',),
'sinologen': ('sinolog',),
'sinologene': ('sinolog',),
'sinologer': ('sinolog',),
'sinologi': ('sinologi',),
'sinologien': ('sinologi',),
'sinologiene': ('sinologi',),
'sinologier': ('sinologi',),
'sinter': ('sinter',),
'sintere': ('sinter',),
'sinteren': ('sinter',),
'sinterer': ('sinter',),
'sinterne': ('sinter',),
'sintre': ('sinter',),
'sintrene': ('sinter',),
'sintrer': ('sinter',),
'sinus': ('sinus',),
'sinusen': ('sinus',),
'sinusene': ('sinus',),
'sinuser': ('sinus',),
'sinusitt': ('sinusitt',),
'sinusitten': ('sinusitt',),
'sinusittene': ('sinusitt',),
'sinusitter': ('sinusitt',),
'sinusknute': ('sinusknute',),
'sinusknuten': ('sinusknute',),
'sinusknutene': ('sinusknute',),
'sinusknuter': ('sinusknute',),
'sinustabell': ('sinustabell',),
'sinustabellen': ('sinustabell',),
'sinustabellene': ('sinustabell',),
'sinustabeller': ('sinustabell',),
'sionisme': ('sionisme',),
'sionismen': ('sionisme',),
'sionismene': ('sionisme',),
'sionismer': ('sionisme',),
'sionist': ('sionist',),
'sionisten': ('sionist',),
'sionistene': ('sionist',),
'sionister': ('sionist',),
'sioux': ('sioux',),
'siouxen': ('sioux',),
'siouxene': ('sioux',),
'siouxer': ('sioux',),
'sioux': ('sioux',),
'siouxindianer': ('siouxindianer',),
'siouxindianere': ('siouxindianer',),
'siouxindianeren': ('siouxindianer',),
'siouxindianerer': ('siouxindianer',),
'siouxindianerne': ('siouxindianer',),
'sip': ('sip',),
'sipa': ('sip',),
'sipene': ('sip',),
'sipet': ('sip',),
'sipp': ('sipp',),
'sippa': ('sipp',),
'sippene': ('sipp',),
'sippet': ('sipp',),
'sir': ('sir',),
'siren': ('sir',),
'sirene': ('sir',),
'sirer': ('sir',),
'sir': ('sir',),
'siren': ('sir',),
'sirene': ('sir',),
'sirer': ('sir',),
'sira': ('sira',),
'siraen': ('sira',),
'siraene': ('sira',),
'siraer': ('sira',),
'sirat': ('sirat',),
'sirata': ('sirat',),
'siratene': ('sirat',),
'sirater': ('sirat',),
'siratet': ('sirat',),
'siregn': ('siregn',),
'siregna': ('siregn',),
'siregnene': ('siregn',),
'siregnet': ('siregn',),
'sirena': ('sirene',),
'sirene': ('sirene',),
'sirenen': ('sirene',),
'sirenene': ('sirene',),
'sirener': ('sirene',),
'sireneprøva': ('sireneprøve',),
'sireneprøve': ('sireneprøve',),
'sireneprøven': ('sireneprøve',),
'sireneprøvene': ('sireneprøve',),
'sireneprøver': ('sireneprøve',),
'sirenesang': ('sirenesang',),
'sirenesangen': ('sirenesang',),
'sirenesangene': ('sirenesang',),
'sirenesanger': ('sirenesang',),
'siriss': ('siriss',),
'sirissen': ('siriss',),
'sirissene': ('siriss',),
'sirisser': ('siriss',),
'sirkel': ('sirkel',),
'sirkelen': ('sirkel',),
'sirklene': ('sirkel',),
'sirkler': ('sirkel',),
'sirkelbevis': ('sirkelbevis',),
'sirkelbevisa': ('sirkelbevis',),
'sirkelbevisene': ('sirkelbevis',),
'sirkelbeviser': ('sirkelbevis',),
'sirkelbeviset': ('sirkelbevis',),
'sirkeldefinisjon': ('sirkeldefinisjon',),
'sirkeldefinisjonen': ('sirkeldefinisjon',),
'sirkeldefinisjonene': ('sirkeldefinisjon',),
'sirkeldefinisjoner': ('sirkeldefinisjon',),
'sirkelsag': ('sirkelsag',),
'sirkelsaga': ('sirkelsag',),
'sirkelsagen': ('sirkelsag',),
'sirkelsagene': ('sirkelsag',),
'sirkelsager': ('sirkelsag',),
'sirkeltrening': ('sirkeltrening',),
'sirkeltreninga': ('sirkeltrening',),
'sirkeltreningen': ('sirkeltrening',),
'sirkeltreningene': ('sirkeltrening',),
'sirkeltreninger': ('sirkeltrening',),
'sirkulasjon': ('sirkulasjon',),
'sirkulasjonen': ('sirkulasjon',),
'sirkulasjonene': ('sirkulasjon',),
'sirkulasjoner': ('sirkulasjon',),
'sirkulæra': ('sirkulære',),
'sirkulære': ('sirkulære',),
'sirkulærene': ('sirkulære',),
'sirkulærer': ('sirkulære',),
'sirkulæret': ('sirkulære',),
'sirkus': ('sirkus',),
'sirkusa': ('sirkus',),
'sirkusene': ('sirkus',),
'sirkuser': ('sirkus',),
'sirkuset': ('sirkus',),
'sirkusartist': ('sirkusartist',),
'sirkusartisten': ('sirkusartist',),
'sirkusartistene': ('sirkusartist',),
'sirkusartister': ('sirkusartist',),
'sirkushest': ('sirkushest',),
'sirkushesten': ('sirkushest',),
'sirkushestene': ('sirkushest',),
'sirkushester': ('sirkushest',),
'sirs': ('sirs',),
'sirsen': ('sirs',),
'sirsene': ('sirs',),
'sirser': ('sirs',),
'sirup': ('sirup',),
'sirupen': ('sirup',),
'sirupene': ('sirup',),
'siruper': ('sirup',),
'sirupskaka': ('sirupskake',),
'sirupskake': ('sirupskake',),
'sirupskaken': ('sirupskake',),
'sirupskakene': ('sirupskake',),
'sirupskaker': ('sirupskake',),
'sirupssnipp': ('sirupssnipp',),
'sirupssnippen': ('sirupssnipp',),
'sirupssnippene': ('sirupssnipp',),
'sirupssnipper': ('sirupssnipp',),
'sisal': ('sisal',),
'sisalen': ('sisal',),
'sisalene': ('sisal',),
'sisaler': ('sisal',),
'sisalhamp': ('sisalhamp',),
'sisalhampen': ('sisalhamp',),
'sisalhampene': ('sisalhamp',),
'sisalhamper': ('sisalhamp',),
'sisel': ('sisel',),
'siselen': ('sisel',),
'siselene': ('sisel',),
'siseler': ('sisel',),
'siselør': ('siselør',),
'siseløren': ('siselør',),
'siselørene': ('siselør',),
'siselører': ('siselør',),
'sisik': ('sisik',),
'sisiken': ('sisik',),
'sisikene': ('sisik',),
'sisiker': ('sisik',),
'sisselrot': ('sisselrot',),
'sisselrota': ('sisselrot',),
'sisselroten': ('sisselrot',),
'sisselrotene': ('sisselrot',),
'sisselrotfamilie': ('sisselrotfamilie',),
'sisselrotfamilien': ('sisselrotfamilie',),
'sisselrotfamiliene': ('sisselrotfamilie',),
'sisselrotfamilier': ('sisselrotfamilie',),
'sistemann': ('sistemann',),
'sistemannen': ('sistemann',),
'sistemannene': ('sistemann',),
'sistemanner': ('sistemann',),
'sisten': ('sisten',),
'sisu': ('sisu',),
'sisuen': ('sisu',),
'sisuene': ('sisu',),
'sisuer': ('sisu',),
'sisyfosarbeid': ('sisyfosarbeid',),
'sisyfosarbeida': ('sisyfosarbeid',),
'sisyfosarbeidene': ('sisyfosarbeid',),
'sisyfosarbeider': ('sisyfosarbeid',),
'sisyfosarbeidet': ('sisyfosarbeid',),
'sitant': ('sitant',),
'sitanten': ('sitant',),
'sitantene': ('sitant',),
'sitanter': ('sitant',),
'sitar': ('sitar',),
'sitaren': ('sitar',),
'sitarene': ('sitar',),
'sitarer': ('sitar',),
'sitat': ('sitat',),
'sitata': ('sitat',),
'sitatene': ('sitat',),
'sitater': ('sitat',),
'sitatet': ('sitat',),
'sitatfusk': ('sitatfusk',),
'sitatfuska': ('sitatfusk',),
'sitatfuskene': ('sitatfusk',),
'sitatfusket': ('sitatfusk',),
'sitattegn': ('sitattegn',),
'sitattegna': ('sitattegn',),
'sitattegnene': ('sitattegn',),
'sitattegnet': ('sitattegn',),
'sitdownstreik': ('sitdownstreik',),
'sitdownstreiken': ('sitdownstreik',),
'sitdownstreikene': ('sitdownstreik',),
'sitdownstreiker': ('sitdownstreik',),
'siter': ('siter',),
'sitere': ('siter',),
'siteren': ('siter',),
'siterer': ('siter',),
'siterne': ('siter',),
'sitkagran': ('sitkagran',),
'sitkagrana': ('sitkagran',),
'sitkagranen': ('sitkagran',),
'sitkagranene': ('sitkagran',),
'sitkagraner': ('sitkagran',),
'sitron': ('sitron',),
'sitronen': ('sitron',),
'sitronene': ('sitron',),
'sitroner': ('sitron',),
'sitronbrus': ('sitronbrus',),
'sitronbrusen': ('sitronbrus',),
'sitronbrusene': ('sitronbrus',),
'sitronpressa': ('sitronpresse',),
'sitronpresse': ('sitronpresse',),
'sitronpressen': ('sitronpresse',),
'sitronpressene': ('sitronpresse',),
'sitronpresser': ('sitronpresse',),
'sitronsommerfugl': ('sitronsommerfugl',),
'sitronsommerfuglen': ('sitronsommerfugl',),
'sitronsommerfuglene': ('sitronsommerfugl',),
'sitronsommerfugler': ('sitronsommerfugl',),
'sitronsyra': ('sitronsyre',),
'sitronsyre': ('sitronsyre',),
'sitronsyren': ('sitronsyre',),
'sitronsyrene': ('sitronsyre',),
'sitronsyrer': ('sitronsyre',),
'sitrontre': ('sitrontre',),
'sitrontrea': ('sitrontre',),
'sitrontreet': ('sitrontre',),
'sitrontrær': ('sitrontre',),
'sitrontrærne': ('sitrontre',),
'sitrusfrukt': ('sitrusfrukt',),
'sitrusfrukta': ('sitrusfrukt',),
'sitrusfrukten': ('sitrusfrukt',),
'sitrusfruktene': ('sitrusfrukt',),
'sitrusfrukter': ('sitrusfrukt',),
'sittefot': ('sittefot',),
'sittefoten': ('sittefot',),
'sitteføttene': ('sittefot',),
'sitteføtter': ('sittefot',),
'sitteplass': ('sitteplass',),
'sitteplassen': ('sitteplass',),
'sitteplassene': ('sitteplass',),
'sitteplasser': ('sitteplass',),
'sitterrokka': ('sitterrokke',),
'sitterrokke': ('sitterrokke',),
'sitterrokken': ('sitterrokke',),
'sitterrokkene': ('sitterrokke',),
'sitterrokker': ('sitterrokke',),
'sitterål': ('sitterål',),
'sitterålen': ('sitterål',),
'sitterålene': ('sitterål',),
'sitteråler': ('sitterål',),
'sittestreik': ('sittestreik',),
'sittestreiken': ('sittestreik',),
'sittestreikene': ('sittestreik',),
'sittestreiker': ('sittestreik',),
'sittnedstreik': ('sittnedstreik',),
'sittnedstreiken': ('sittnedstreik',),
'sittnedstreikene': ('sittnedstreik',),
'sittnedstreiker': ('sittnedstreik',),
'situasjon': ('situasjon',),
'situasjonen': ('situasjon',),
'situasjonene': ('situasjon',),
'situasjoner': ('situasjon',),
'situasjonsbilda': ('situasjonsbilde',),
'situasjonsbilde': ('situasjonsbilde',),
'situasjonsbildene': ('situasjonsbilde',),
'situasjonsbilder': ('situasjonsbilde',),
'situasjonsbildet': ('situasjonsbilde',),
'situasjonskomikk': ('situasjonskomikk',),
'situasjonskomikken': ('situasjonskomikk',),
'situasjonskomikkene': ('situasjonskomikk',),
'situasjonskomikker': ('situasjonskomikk',),
'situasjonsrapport': ('situasjonsrapport',),
'situasjonsrapporten': ('situasjonsrapport',),
'situasjonsrapportene': ('situasjonsrapport',),
'situasjonsrapporter': ('situasjonsrapport',),
'siv': ('siv',),
'siva': ('siv',),
'sivene': ('siv',),
'sivet': ('siv',),
'siv': ('siv',),
'siva': ('siv',),
'sivene': ('siv',),
'sivet': ('siv',),
'sivfamilie': ('sivfamilie',),
'sivfamilien': ('sivfamilie',),
'sivfamiliene': ('sivfamilie',),
'sivfamilier': ('sivfamilie',),
'sivfamilie': ('sivfamilie',),
'sivfamilien': ('sivfamilie',),
'sivfamiliene': ('sivfamilie',),
'sivfamilier': ('sivfamilie',),
'sivhøna': ('sivhøne',),
'sivhøne': ('sivhøne',),
'sivhønen': ('sivhøne',),
'sivhønene': ('sivhøne',),
'sivhøner': ('sivhøne',),
'sivhøna': ('sivhøne',),
'sivhøne': ('sivhøne',),
'sivhønen': ('sivhøne',),
'sivhønene': ('sivhøne',),
'sivhøner': ('sivhøne',),
'sivil': ('sivil',),
'sivilagronom': ('sivilagronom',),
'sivilagronomen': ('sivilagronom',),
'sivilagronomene': ('sivilagronom',),
'sivilagronomer': ('sivilagronom',),
'sivilarbeid': ('sivilarbeid',),
'sivilarbeida': ('sivilarbeid',),
'sivilarbeidene': ('sivilarbeid',),
'sivilarbeidet': ('sivilarbeid',),
'sivilarbeid': ('sivilarbeid',),
'sivilarbeider': ('sivilarbeider',),
'sivilarbeidere': ('sivilarbeider',),
'sivilarbeideren': ('sivilarbeider',),
'sivilarbeiderer': ('sivilarbeider',),
'sivilarbeiderne': ('sivilarbeider',),
'sivilbefolkning': ('sivilbefolkning',),
'sivilbefolkninga': ('sivilbefolkning',),
'sivilbefolkningen': ('sivilbefolkning',),
'sivilbefolkningene': ('sivilbefolkning',),
'sivilbefolkninger': ('sivilbefolkning',),
'sivildomstol': ('sivildomstol',),
'sivildomstolen': ('sivildomstol',),
'sivildomstolene': ('sivildomstol',),
'sivildomstoler': ('sivildomstol',),
'sivilforsvar': ('sivilforsvar',),
'sivilforsvara': ('sivilforsvar',),
'sivilforsvarene': ('sivilforsvar',),
'sivilforsvaret': ('sivilforsvar',),
'sivilingeniør': ('sivilingeniør',),
'sivilingeniøren': ('sivilingeniør',),
'sivilingeniørene': ('sivilingeniør',),
'sivilingeniører': ('sivilingeniør',),
'sivilisasjon': ('sivilisasjon',),
'sivilisasjonen': ('sivilisasjon',),
'sivilisasjonene': ('sivilisasjon',),
'sivilisasjoner': ('sivilisasjon',),
'sivilisator': ('sivilisator',),
'sivilisatoren': ('sivilisator',),
'sivilisatorene': ('sivilisator',),
'sivilisatorer': ('sivilisator',),
'sivilist': ('sivilist',),
'sivilisten': ('sivilist',),
'sivilistene': ('sivilist',),
'sivilister': ('sivilist',),
'sivilombudsmann': ('sivilombudsmann',),
'sivilombudsmannen': ('sivilombudsmann',),
'sivilombudsmenn': ('sivilombudsmann',),
'sivilombudsmennene': ('sivilombudsmann',),
'sivilperson': ('sivilperson',),
'sivilpersonen': ('sivilperson',),
'sivilpersonene': ('sivilperson',),
'sivilpersoner': ('sivilperson',),
'sivilprosess': ('sivilprosess',),
'sivilprosessen': ('sivilprosess',),
'sivilprosessene': ('sivilprosess',),
'sivilprosesser': ('sivilprosess',),
'sivilrett': ('sivilrett',),
'sivilretten': ('sivilrett',),
'sivilrettene': ('sivilrett',),
'sivilretter': ('sivilrett',),
'sivilsak': ('sivilsak',),
'sivilsaka': ('sivilsak',),
'sivilsaken': ('sivilsak',),
'sivilsakene': ('sivilsak',),
'sivilsaker': ('sivilsak',),
'sivilstand': ('sivilstand',),
'sivilstanden': ('sivilstand',),
'sivilstandene': ('sivilstand',),
'sivilstander': ('sivilstand',),
'siviløkonom': ('siviløkonom',),
'siviløkonomen': ('siviløkonom',),
'siviløkonomene': ('siviløkonom',),
'siviløkonomer': ('siviløkonom',),
'sivmatta': ('sivmatte',),
'sivmatte': ('sivmatte',),
'sivmatten': ('sivmatte',),
'sivmattene': ('sivmatte',),
'sivmatter': ('sivmatte',),
'sivmatta': ('sivmatte',),
'sivmatte': ('sivmatte',),
'sivmatten': ('sivmatte',),
'sivmattene': ('sivmatte',),
'sivmatter': ('sivmatte',),
'sivsanger': ('sivsanger',),
'sivsangere': ('sivsanger',),
'sivsangeren': ('sivsanger',),
'sivsangerer': ('sivsanger',),
'sivsangerne': ('sivsanger',),
'sivsanger': ('sivsanger',),
'sivsangere': ('sivsanger',),
'sivsangeren': ('sivsanger',),
'sivsangerer': ('sivsanger',),
'sivsangerne': ('sivsanger',),
'sivstarr': ('sivstarr',),
'sivstarren': ('sivstarr',),
'sivstarrene': ('sivstarr',),
'sivstarrer': ('sivstarr',),
'sivstarr': ('sivstarr',),
'sivstarren': ('sivstarr',),
'sivstarrene': ('sivstarr',),
'sivstarrer': ('sivstarr',),
'sivstorr': ('sivstorr',),
'sivstorren': ('sivstorr',),
'sivstorrene': ('sivstorr',),
'sivstorrer': ('sivstorr',),
'sivstorr': ('sivstorr',),
'sivstorren': ('sivstorr',),
'sivstorrene': ('sivstorr',),
'sivstorrer': ('sivstorr',),
'sjablon': ('sjablon',),
'sjablonen': ('sjablon',),
'sjablonene': ('sjablon',),
'sjabloner': ('sjablon',),
'sjablong': ('sjablong',),
'sjablongen': ('sjablong',),
'sjablongene': ('sjablong',),
'sjablonger': ('sjablong',),
'sjagreng': ('sjagreng',),
'sjagrengen': ('sjagreng',),
'sjagrengene': ('sjagreng',),
'sjagrenger': ('sjagreng',),
'sjah': ('sjah',),
'sjahen': ('sjah',),
'sjahene': ('sjah',),
'sjaher': ('sjah',),
'sjakal': ('sjakal',),
'sjakalen': ('sjakal',),
'sjakalene': ('sjakal',),
'sjakaler': ('sjakal',),
'sjakett': ('sjakett',),
'sjaketten': ('sjakett',),
'sjakettene': ('sjakett',),
'sjaketter': ('sjakett',),
'sjakk': ('sjakk',),
'sjakken': ('sjakk',),
'sjakkene': ('sjakk',),
'sjakker': ('sjakk',),
'sjakkbrett': ('sjakkbrett',),
'sjakkbretta': ('sjakkbrett',),
'sjakkbrettene': ('sjakkbrett',),
'sjakkbretter': ('sjakkbrett',),
'sjakkbrettet': ('sjakkbrett',),
'sjakkbrikka': ('sjakkbrikke',),
'sjakkbrikke': ('sjakkbrikke',),
'sjakkbrikken': ('sjakkbrikke',),
'sjakkbrikkene': ('sjakkbrikke',),
'sjakkbrikker': ('sjakkbrikke',),
'sjakkel': ('sjakkel',),
'sjakkelen': ('sjakkel',),
'sjaklene': ('sjakkel',),
'sjakler': ('sjakkel',),
'sjakkmatt': ('sjakkmatt',),
'sjako': ('sjako',),
'sjakoen': ('sjako',),
'sjakoene': ('sjako',),
'sjakoer': ('sjako',),
'sjakrer': ('sjakrer',),
'sjakrere': ('sjakrer',),
'sjakreren': ('sjakrer',),
'sjakrerer': ('sjakrer',),
'sjakrerne': ('sjakrer',),
'sjakt': ('sjakt',),
'sjakta': ('sjakt',),
'sjakten': ('sjakt',),
'sjaktene': ('sjakt',),
'sjakter': ('sjakt',),
'sjaktel': ('sjaktel',),
'sjaktelen': ('sjaktel',),
'sjaktlene': ('sjaktel',),
'sjaktler': ('sjaktel',),
'sjal': ('sjal',),
'sjala': ('sjal',),
'sjalene': ('sjal',),
'sjalet': ('sjal',),
'sjallstykka': ('sjallstykke',),
'sjallstykke': ('sjallstykke',),
'sjallstykkene': ('sjallstykke',),
'sjallstykker': ('sjallstykke',),
'sjallstykket': ('sjallstykke',),
'sjalottløk': ('sjalottløk',),
'sjalottløken': ('sjalottløk',),
'sjalottløkene': ('sjalottløk',),
'sjalottløker': ('sjalottløk',),
'sjalskrage': ('sjalskrage',),
'sjalskragen': ('sjalskrage',),
'sjalskragene': ('sjalskrage',),
'sjalskrager': ('sjalskrage',),
'sjalskrave': ('sjalskrave',),
'sjalskraven': ('sjalskrave',),
'sjalskravene': ('sjalskrave',),
'sjalskraver': ('sjalskrave',),
'sjalter': ('sjalter',),
'sjaltere': ('sjalter',),
'sjalteren': ('sjalter',),
'sjalterer': ('sjalter',),
'sjalterne': ('sjalter',),
'sjalupp': ('sjalupp',),
'sjaluppen': ('sjalupp',),
'sjaluppene': ('sjalupp',),
'sjalupper': ('sjalupp',),
'sjalusidrama': ('sjalusidrama',),
'sjalusidramaene': ('sjalusidrama',),
'sjalusidramaer': ('sjalusidrama',),
'sjalusidramaet': ('sjalusidrama',),
'sjalusidør': ('sjalusidør',),
'sjalusidøra': ('sjalusidør',),
'sjalusidøren': ('sjalusidør',),
'sjalusidørene': ('sjalusidør',),
'sjalusidører': ('sjalusidør',),
'sjalusiskap': ('sjalusiskap',),
'sjalusiskapa': ('sjalusiskap',),
'sjalusiskapene': ('sjalusiskap',),
'sjalusiskapet': ('sjalusiskap',),
'sjaman': ('sjaman',),
'sjamanen': ('sjaman',),
'sjamanene': ('sjaman',),
'sjamaner': ('sjaman',),
'sjamanisme': ('sjamanisme',),
'sjamanismen': ('sjamanisme',),
'sjamanismene': ('sjamanisme',),
'sjamanismer': ('sjamanisme',),
'sjampinjong': ('sjampinjong',),
'sjampinjongen': ('sjampinjong',),
'sjampinjongene': ('sjampinjong',),
'sjampinjonger': ('sjampinjong',),
'sjampinjongsuppa': ('sjampinjongsuppe',),
'sjampinjongsuppe': ('sjampinjongsuppe',),
'sjampinjongsuppen': ('sjampinjongsuppe',),
'sjampinjongsuppene': ('sjampinjongsuppe',),
'sjampinjongsupper': ('sjampinjongsuppe',),
'sjampo': ('sjampo',),
'sjampoen': ('sjampo',),
'sjampoene': ('sjampo',),
'sjampoer': ('sjampo',),
'sjanger': ('sjanger',),
'sjangere': ('sjanger',),
'sjangeren': ('sjanger',),
'sjangerer': ('sjanger',),
'sjangerne': ('sjanger',),
'sjangre': ('sjanger',),
'sjangrene': ('sjanger',),
'sjangrer': ('sjanger',),
'sjangerbilda': ('sjangerbilde',),
'sjangerbilde': ('sjangerbilde',),
'sjangerbildene': ('sjangerbilde',),
'sjangerbilder': ('sjangerbilde',),
'sjangerbildet': ('sjangerbilde',),
'sjanker': ('sjanker',),
'sjankere': ('sjanker',),
'sjankeren': ('sjanker',),
'sjankerer': ('sjanker',),
'sjankerne': ('sjanker',),
'sjankre': ('sjanker',),
'sjankrene': ('sjanker',),
'sjankrer': ('sjanker',),
'sjanse': ('sjanse',),
'sjansen': ('sjanse',),
'sjansene': ('sjanse',),
'sjanser': ('sjanse',),
'sjanseseilas': ('sjanseseilas',),
'sjanseseilasen': ('sjanseseilas',),
'sjanseseilasene': ('sjanseseilas',),
'sjanseseilaser': ('sjanseseilas',),
'sjansespell': ('sjansespell',),
'sjansespella': ('sjansespell',),
'sjansespellene': ('sjansespell',),
'sjansespellet': ('sjansespell',),
'sjansespill': ('sjansespill',),
'sjansespilla': ('sjansespill',),
'sjansespillene': ('sjansespill',),
'sjansespillet': ('sjansespill',),
'sjanti': ('sjanti',),
'sjantien': ('sjanti',),
'sjantiene': ('sjanti',),
'sjantier': ('sjanti',),
'sjapp': ('sjapp',),
'sjappa': ('sjapp',),
'sjappen': ('sjapp',),
'sjappene': ('sjapp',),
'sjapper': ('sjapp',),
'sjappa': ('sjappe',),
'sjappe': ('sjappe',),
'sjappen': ('sjappe',),
'sjappene': ('sjappe',),
'sjapper': ('sjappe',),
'sjargong': ('sjargong',),
'sjargongen': ('sjargong',),
'sjargongene': ('sjargong',),
'sjargonger': ('sjargong',),
'sjark': ('sjark',),
'sjarken': ('sjark',),
'sjarkene': ('sjark',),
'sjarker': ('sjark',),
'sjarlatan': ('sjarlatan',),
'sjarlatanen': ('sjarlatan',),
'sjarlatanene': ('sjarlatan',),
'sjarlataner': ('sjarlatan',),
'sjarlataneri': ('sjarlataneri',),
'sjarlataneria': ('sjarlataneri',),
'sjarlataneriene': ('sjarlataneri',),
'sjarlatanerier': ('sjarlataneri',),
'sjarlataneriet': ('sjarlataneri',),
'sjarmoffensiv': ('sjarmoffensiv',),
'sjarmoffensiven': ('sjarmoffensiv',),
'sjarmoffensivene': ('sjarmoffensiv',),
'sjarmoffensiver': ('sjarmoffensiv',),
'sjarmtroll': ('sjarmtroll',),
'sjarmtrolla': ('sjarmtroll',),
'sjarmtrollene': ('sjarmtroll',),
'sjarmtrollet': ('sjarmtroll',),
'sjarmør': ('sjarmør',),
'sjarmøren': ('sjarmør',),
'sjarmørene': ('sjarmør',),
'sjarmører': ('sjarmør',),
'sjask': ('sjask',),
'sjaska': ('sjask',),
'sjaskene': ('sjask',),
'sjasket': ('sjask',),
'sjaslik': ('sjaslik',),
'sjasliken': ('sjaslik',),
'sjaslikene': ('sjaslik',),
'sjasliker': ('sjaslik',),
'sjasmin': ('sjasmin',),
'sjasminen': ('sjasmin',),
'sjasminene': ('sjasmin',),
'sjasminer': ('sjasmin',),
'sjattering': ('sjattering',),
'sjatteringa': ('sjattering',),
'sjatteringen': ('sjattering',),
'sjatteringene': ('sjattering',),
'sjatteringer': ('sjattering',),
'sjau': ('sjau',),
'sjauen': ('sjau',),
'sjauene': ('sjau',),
'sjauer': ('sjau',),
'sjauer': ('sjauer',),
'sjauere': ('sjauer',),
'sjaueren': ('sjauer',),
'sjauerer': ('sjauer',),
'sjauerne': ('sjauer',),
'sjauergjeng': ('sjauergjeng',),
'sjauergjengen': ('sjauergjeng',),
'sjauergjengene': ('sjauergjeng',),
'sjauergjenger': ('sjauergjeng',),
'sjef': ('sjef',),
'sjefen': ('sjef',),
'sjefene': ('sjef',),
'sjefer': ('sjef',),
'sjefredaktør': ('sjefredaktør',),
'sjefredaktøren': ('sjefredaktør',),
'sjefredaktørene': ('sjefredaktør',),
'sjefredaktører': ('sjefredaktør',),
'sjefsekretær': ('sjefsekretær',),
'sjefsekretæren': ('sjefsekretær',),
'sjefsekretærene': ('sjefsekretær',),
'sjefsekretærer': ('sjefsekretær',),
'sjefsregulativ': ('sjefsregulativ',),
'sjefsregulativa': ('sjefsregulativ',),
'sjefsregulativene': ('sjefsregulativ',),
'sjefsregulativer': ('sjefsregulativ',),
'sjefsregulativet': ('sjefsregulativ',),
'sjefssekretær': ('sjefssekretær',),
'sjefssekretæren': ('sjefssekretær',),
'sjefssekretærene': ('sjefssekretær',),
'sjefssekretærer': ('sjefssekretær',),
'sjefsstilling': ('sjefsstilling',),
'sjefsstillinga': ('sjefsstilling',),
'sjefsstillingen': ('sjefsstilling',),
'sjefsstillingene': ('sjefsstilling',),
'sjefsstillinger': ('sjefsstilling',),
'sjeider': ('sjeider',),
'sjeidere': ('sjeider',),
'sjeideren': ('sjeider',),
'sjeiderer': ('sjeider',),
'sjeiderne': ('sjeider',),
'sjeik': ('sjeik',),
'sjeiken': ('sjeik',),
'sjeikene': ('sjeik',),
'sjeiker': ('sjeik',),
'sjekk': ('sjekk',),
'sjekken': ('sjekk',),
'sjekkene': ('sjekk',),
'sjekker': ('sjekk',),
'sjekk': ('sjekk',),
'sjekken': ('sjekk',),
'sjekkene': ('sjekk',),
'sjekker': ('sjekk',),
'sjekkfalsk': ('sjekkfalsk',),
'sjekkfalsken': ('sjekkfalsk',),
'sjekkfalskene': ('sjekkfalsk',),
'sjekkfalsker': ('sjekkfalsk',),
'sjekkhefta': ('sjekkhefte',),
'sjekkhefte': ('sjekkhefte',),
'sjekkheftene': ('sjekkhefte',),
'sjekkhefter': ('sjekkhefte',),
'sjekkheftet': ('sjekkhefte',),
'sjekkkonti': ('sjekkkonto',),
'sjekkkontiene': ('sjekkkonto',),
'sjekkkonto': ('sjekkkonto',),
'sjekkkontoen': ('sjekkkonto',),
'sjekkkontoene': ('sjekkkonto',),
'sjekkkontoer': ('sjekkkonto',),
'sjekksvindler': ('sjekksvindler',),
'sjekksvindlere': ('sjekksvindler',),
'sjekksvindleren': ('sjekksvindler',),
'sjekksvindlerer': ('sjekksvindler',),
'sjekksvindlerne': ('sjekksvindler',),
'sjekta': ('sjekte',),
'sjekte': ('sjekte',),
'sjekten': ('sjekte',),
'sjektene': ('sjekte',),
'sjekter': ('sjekte',),
'sjel': ('sjel',),
'sjela': ('sjel',),
'sjelen': ('sjel',),
'sjelene': ('sjel',),
'sjeler': ('sjel',),
'sjeldenhet': ('sjeldenhet',),
'sjeldenheta': ('sjeldenhet',),
'sjeldenheten': ('sjeldenhet',),
'sjeldenhetene': ('sjeldenhet',),
'sjeldenheter': ('sjeldenhet',),
'sjeleangst': ('sjeleangst',),
'sjeleangsten': ('sjeleangst',),
'sjeleangstene': ('sjeleangst',),
'sjeleangster': ('sjeleangst',),
'sjelefred': ('sjelefred',),
'sjelefreden': ('sjelefred',),
'sjelefredene': ('sjelefred',),
'sjelefreder': ('sjelefred',),
'sjelegava': ('sjelegave',),
'sjelegave': ('sjelegave',),
'sjelegaven': ('sjelegave',),
'sjelegavene': ('sjelegave',),
'sjelegaver': ('sjelegave',),
'sjelegransker': ('sjelegransker',),
'sjelegranskere': ('sjelegransker',),
'sjelegranskeren': ('sjelegransker',),
'sjelegranskerer': ('sjelegransker',),
'sjelegranskerne': ('sjelegransker',),
'sjelekamp': ('sjelekamp',),
'sjelekampen': ('sjelekamp',),
'sjelekampene': ('sjelekamp',),
'sjelekamper': ('sjelekamp',),
'sjelekjenner': ('sjelekjenner',),
'sjelekjennere': ('sjelekjenner',),
'sjelekjenneren': ('sjelekjenner',),
'sjelekjennerer': ('sjelekjenner',),
'sjelekjennerne': ('sjelekjenner',),
'sjelekval': ('sjelekval',),
'sjelekvalen': ('sjelekval',),
'sjelekvalene': ('sjelekval',),
'sjelekvaler': ('sjelekval',),
'sjeleliv': ('sjeleliv',),
'sjeleliva': ('sjeleliv',),
'sjelelivene': ('sjeleliv',),
'sjelelivet': ('sjeleliv',),
'sjelelæra': ('sjelelære',),
'sjelelære': ('sjelelære',),
'sjelelæren': ('sjelelære',),
'sjelelærene': ('sjelelære',),
'sjelelærer': ('sjelelære',),
'sjelemessa': ('sjelemesse',),
'sjelemesse': ('sjelemesse',),
'sjelemessen': ('sjelemesse',),
'sjelemessene': ('sjelemesse',),
'sjelemesser': ('sjelemesse',),
'sjelenød': ('sjelenød',),
'sjelenøda': ('sjelenød',),
'sjelenøden': ('sjelenød',),
'sjelenødene': ('sjelenød',),
'sjelenøder': ('sjelenød',),
'sjelero': ('sjelero',),
'sjeleroa': ('sjelero',),
'sjeleroen': ('sjelero',),
'sjeleroene': ('sjelero',),
'sjeleroer': ('sjelero',),
'sjelesorg': ('sjelesorg',),
'sjelesorga': ('sjelesorg',),
'sjelesorgen': ('sjelesorg',),
'sjelesorgene': ('sjelesorg',),
'sjelesorger': ('sjelesorg',),
'sjelesørger': ('sjelesørger',),
'sjelesørgere': ('sjelesørger',),
'sjelesørgeren': ('sjelesørger',),
'sjelesørgerer': ('sjelesørger',),
'sjelesørgerne': ('sjelesørger',),
'sjelevandring': ('sjelevandring',),
'sjelevandringa': ('sjelevandring',),
'sjelevandringen': ('sjelevandring',),
'sjelevandringene': ('sjelevandring',),
'sjelevandringer': ('sjelevandring',),
'sjelsevna': ('sjelsevne',),
'sjelsevne': ('sjelsevne',),
'sjelsevnen': ('sjelsevne',),
'sjelsevnene': ('sjelsevne',),
'sjelsevner': ('sjelsevne',),
'sjelsro': ('sjelsro',),
'sjelsroa': ('sjelsro',),
'sjelsroen': ('sjelsro',),
'sjelsroene': ('sjelsro',),
'sjelsroer': ('sjelsro',),
'sjelsstyrke': ('sjelsstyrke',),
'sjelsstyrken': ('sjelsstyrke',),
'sjelsstyrkene': ('sjelsstyrke',),
'sjelsstyrker': ('sjelsstyrke',),
'sjelstilstand': ('sjelstilstand',),
'sjelstilstanden': ('sjelstilstand',),
'sjelstilstandene': ('sjelstilstand',),
'sjelstilstander': ('sjelstilstand',),
'sjenanse': ('sjenanse',),
'sjenansen': ('sjenanse',),
'sjenansene': ('sjenanse',),
'sjenanser': ('sjenanse',),
'sjenerthet': ('sjenerthet',),
'sjenertheta': ('sjenerthet',),
'sjenertheten': ('sjenerthet',),
'sjenerthetene': ('sjenerthet',),
'sjenertheter': ('sjenerthet',),
'sjenerøsitet': ('sjenerøsitet',),
'sjenerøsiteten': ('sjenerøsitet',),
'sjenerøsitetene': ('sjenerøsitet',),
'sjenerøsiteter': ('sjenerøsitet',),
'sjenever': ('sjenever',),
'sjeneveren': ('sjenever',),
'sjeneverene': ('sjenever',),
'sjeneverer': ('sjenever',),
'sjenkel': ('sjenkel',),
'sjenkelen': ('sjenkel',),
'sjenklene': ('sjenkel',),
'sjenkler': ('sjenkel',),
'sjeselong': ('sjeselong',),
'sjeselongen': ('sjeselong',),
'sjeselongene': ('sjeselong',),
'sjeselonger': ('sjeselong',),
'sjeteen': ('sjeté',),
'sjeteene': ('sjeté',),
'sjeteer': ('sjeté',),
'sjeté': ('sjeté',),
'sjetéen': ('sjeté',),
'sjetéene': ('sjeté',),
'sjetéer': ('sjeté',),
'sjetong': ('sjetong',),
'sjetongen': ('sjetong',),
'sjetongene': ('sjetong',),
'sjetonger': ('sjetong',),
'sjettedel': ('sjettedel',),
'sjettedelen': ('sjettedel',),
'sjettedelene': ('sjettedel',),
'sjettedeler': ('sjettedel',),
'sjeviot': ('sjeviot',),
'sjevioten': ('sjeviot',),
'sjeviotene': ('sjeviot',),
'sjevioter': ('sjeviot',),
'sjeviotdress': ('sjeviotdress',),
'sjeviotdressen': ('sjeviotdress',),
'sjeviotdressene': ('sjeviotdress',),
'sjeviotdresser': ('sjeviotdress',),
'sjeviotsau': ('sjeviotsau',),
'sjeviotsauen': ('sjeviotsau',),
'sjeviotsauene': ('sjeviotsau',),
'sjeviotsauer': ('sjeviotsau',),
'sjevrå': ('sjevrå',),
'sjevråen': ('sjevrå',),
'sjevråene': ('sjevrå',),
'sjevråer': ('sjevrå',),
'sjevråstøvel': ('sjevråstøvel',),
'sjevråstøvelen': ('sjevråstøvel',),
'sjevråstøvlene': ('sjevråstøvel',),
'sjevråstøvler': ('sjevråstøvel',),
'sjia': ('sjia',),
'sjiaen': ('sjia',),
'sjiaene': ('sjia',),
'sjiaer': ('sjia',),
'sjiamuslim': ('sjiamuslim',),
'sjiamuslimen': ('sjiamuslim',),
'sjiamuslimene': ('sjiamuslim',),
'sjiamuslimer': ('sjiamuslim',),
'sjibbolett': ('sjibbolett',),
'sjibboletta': ('sjibbolett',),
'sjibbolettene': ('sjibbolett',),
'sjibboletter': ('sjibbolett',),
'sjibbolettet': ('sjibbolett',),
'sjiisme': ('sjiisme',),
'sjiismen': ('sjiisme',),
'sjiismene': ('sjiisme',),
'sjiismer': ('sjiisme',),
'sjiitt': ('sjiitt',),
'sjiitten': ('sjiitt',),
'sjiittene': ('sjiitt',),
'sjiitter': ('sjiitt',),
'sjikane': ('sjikane',),
'sjikanen': ('sjikane',),
'sjikanene': ('sjikane',),
'sjikaner': ('sjikane',),
'sjikt': ('sjikt',),
'sjikta': ('sjikt',),
'sjiktene': ('sjikt',),
'sjiktet': ('sjikt',),
'sjimpanse': ('sjimpanse',),
'sjimpansen': ('sjimpanse',),
'sjimpansene': ('sjimpanse',),
'sjimpanser': ('sjimpanse',),
'sjingel': ('sjingel',),
'sjingelen': ('sjingel',),
'sjinglene': ('sjingel',),
'sjingler': ('sjingel',),
'sjiraff': ('sjiraff',),
'sjiraffen': ('sjiraff',),
'sjiraffene': ('sjiraff',),
'sjiraffer': ('sjiraff',),
'sjirokko': ('sjirokko',),
'sjirokkoen': ('sjirokko',),
'sjirokkoene': ('sjirokko',),
'sjirokkoer': ('sjirokko',),
'sjirting': ('sjirting',),
'sjirtingen': ('sjirting',),
'sjirtingene': ('sjirting',),
'sjirtinger': ('sjirting',),
'sjirtingbind': ('sjirtingbind',),
'sjirtingbinda': ('sjirtingbind',),
'sjirtingbindene': ('sjirtingbind',),
'sjirtingbindet': ('sjirtingbind',),
'sjoddi': ('sjoddi',),
'sjoddien': ('sjoddi',),
'sjoddiene': ('sjoddi',),
'sjoddier': ('sjoddi',),
'sjofelhet': ('sjofelhet',),
'sjofelheta': ('sjofelhet',),
'sjofelheten': ('sjofelhet',),
'sjofelhetene': ('sjofelhet',),
'sjofelheter': ('sjofelhet',),
'sjog': ('sjog',),
'sjoga': ('sjog',),
'sjogene': ('sjog',),
'sjoget': ('sjog',),
'sjogs': ('sjogs',),
'sjogsa': ('sjogs',),
'sjogsene': ('sjogs',),
'sjogset': ('sjogs',),
'sjokk': ('sjokk',),
'sjokka': ('sjokk',),
'sjokkene': ('sjokk',),
'sjokket': ('sjokk',),
'sjokkbehandling': ('sjokkbehandling',),
'sjokkbehandlinga': ('sjokkbehandling',),
'sjokkbehandlingen': ('sjokkbehandling',),
'sjokkbehandlingene': ('sjokkbehandling',),
'sjokkbehandlinger': ('sjokkbehandling',),
'sjokkbølga': ('sjokkbølge',),
'sjokkbølge': ('sjokkbølge',),
'sjokkbølgen': ('sjokkbølge',),
'sjokkbølgene': ('sjokkbølge',),
'sjokkbølger': ('sjokkbølge',),
'sjokkbølgja': ('sjokkbølgje',),
'sjokkbølgje': ('sjokkbølgje',),
'sjokkbølgjen': ('sjokkbølgje',),
'sjokkbølgjene': ('sjokkbølgje',),
'sjokkbølgjer': ('sjokkbølgje',),
'sjokkinnfrysing': ('sjokkinnfrysing',),
'sjokkinnfrysinga': ('sjokkinnfrysing',),
'sjokkinnfrysingen': ('sjokkinnfrysing',),
'sjokkinnfrysingene': ('sjokkinnfrysing',),
'sjokkinnfrysinger': ('sjokkinnfrysing',),
'sjokkpris': ('sjokkpris',),
'sjokkprisen': ('sjokkpris',),
'sjokkprisene': ('sjokkpris',),
'sjokkpriser': ('sjokkpris',),
'sjokkskade': ('sjokkskade',),
'sjokkskaden': ('sjokkskade',),
'sjokkskadene': ('sjokkskade',),
'sjokkskader': ('sjokkskade',),
'sjokkåpning': ('sjokkåpning',),
'sjokkåpninga': ('sjokkåpning',),
'sjokkåpningen': ('sjokkåpning',),
'sjokkåpningene': ('sjokkåpning',),
'sjokkåpninger': ('sjokkåpning',),
'sjokolade': ('sjokolade',),
'sjokoladen': ('sjokolade',),
'sjokoladene': ('sjokolade',),
'sjokolader': ('sjokolade',),
'sjokoladekaka': ('sjokoladekake',),
'sjokoladekake': ('sjokoladekake',),
'sjokoladekaken': ('sjokoladekake',),
'sjokoladekakene': ('sjokoladekake',),
'sjokoladekaker': ('sjokoladekake',),
'sjokoladeplata': ('sjokoladeplate',),
'sjokoladeplate': ('sjokoladeplate',),
'sjokoladeplaten': ('sjokoladeplate',),
'sjokoladeplatene': ('sjokoladeplate',),
'sjokoladeplater': ('sjokoladeplate',),
'sjokoladepudding': ('sjokoladepudding',),
'sjokoladepuddingen': ('sjokoladepudding',),
'sjokoladepuddingene': ('sjokoladepudding',),
'sjokoladepuddinger': ('sjokoladepudding',),
'sjonglør': ('sjonglør',),
'sjongløren': ('sjonglør',),
'sjonglørene': ('sjonglør',),
'sjonglører': ('sjonglør',),
'sjudel': ('sjudel',),
'sjudelen': ('sjudel',),
'sjudelene': ('sjudel',),
'sjudeler': ('sjudel',),
'sjuendedel': ('sjuendedel',),
'sjuendedelen': ('sjuendedel',),
'sjuendedelene': ('sjuendedel',),
'sjuendedeler': ('sjuendedel',),
'sjuer': ('sjuer',),
'sjuere': ('sjuer',),
'sjueren': ('sjuer',),
'sjuerer': ('sjuer',),
'sjuerne': ('sjuer',),
'sjukdom': ('sjukdom',),
'sjukdommen': ('sjukdom',),
'sjukdommene': ('sjukdom',),
'sjukdommer': ('sjukdom',),
'sjukdomsforfall': ('sjukdomsforfall',),
'sjukdomsforfalla': ('sjukdomsforfall',),
'sjukdomsforfallene': ('sjukdomsforfall',),
'sjukdomsforfallet': ('sjukdomsforfall',),
'sjukdomstilfella': ('sjukdomstilfelle',),
'sjukdomstilfelle': ('sjukdomstilfelle',),
'sjukdomstilfellene': ('sjukdomstilfelle',),
'sjukdomstilfeller': ('sjukdomstilfelle',),
'sjukdomstilfellet': ('sjukdomstilfelle',),
'sjuka': ('sjuke',),
'sjuke': ('sjuke',),
'sjuken': ('sjuke',),
'sjukene': ('sjuke',),
'sjuker': ('sjuke',),
'sjukebesøk': ('sjukebesøk',),
'sjukebesøka': ('sjukebesøk',),
'sjukebesøkene': ('sjukebesøk',),
'sjukebesøket': ('sjukebesøk',),
'sjukebil': ('sjukebil',),
'sjukebilen': ('sjukebil',),
'sjukebilene': ('sjukebil',),
'sjukebiler': ('sjukebil',),
'sjukebåra': ('sjukebåre',),
'sjukebåre': ('sjukebåre',),
'sjukebåren': ('sjukebåre',),
'sjukebårene': ('sjukebåre',),
'sjukebårer': ('sjukebåre',),
'sjukegymnast': ('sjukegymnast',),
'sjukegymnasten': ('sjukegymnast',),
'sjukegymnastene': ('sjukegymnast',),
'sjukegymnaster': ('sjukegymnast',),
'sjukegymnastikk': ('sjukegymnastikk',),
'sjukegymnastikken': ('sjukegymnastikk',),
'sjukegymnastikkene': ('sjukegymnastikk',),
'sjukegymnastikker': ('sjukegymnastikk',),
'sjukeheim': ('sjukeheim',),
'sjukeheimen': ('sjukeheim',),
'sjukeheimene': ('sjukeheim',),
'sjukeheimer': ('sjukeheim',),
'sjukehjem': ('sjukehjem',),
'sjukehjemma': ('sjukehjem',),
'sjukehjemmene': ('sjukehjem',),
'sjukehjemmet': ('sjukehjem',),
'sjukehotell': ('sjukehotell',),
'sjukehotella': ('sjukehotell',),
'sjukehotellene': ('sjukehotell',),
'sjukehoteller': ('sjukehotell',),
'sjukehotellet': ('sjukehotell',),
'sjukehus': ('sjukehus',),
'sjukehusa': ('sjukehus',),
'sjukehusene': ('sjukehus',),
'sjukehuset': ('sjukehus',),
'sjukejournal': ('sjukejournal',),
'sjukejournalen': ('sjukejournal',),
'sjukejournalene': ('sjukejournal',),
'sjukejournaler': ('sjukejournal',),
'sjukekassa': ('sjukekasse',),
'sjukekasse': ('sjukekasse',),
'sjukekassen': ('sjukekasse',),
'sjukekassene': ('sjukekasse',),
'sjukekasser': ('sjukekasse',),
'sjukeleia': ('sjukeleie',),
'sjukeleie': ('sjukeleie',),
'sjukeleiene': ('sjukeleie',),
'sjukeleier': ('sjukeleie',),
'sjukeleiet': ('sjukeleie',),
'sjukelista': ('sjukeliste',),
'sjukeliste': ('sjukeliste',),
'sjukelisten': ('sjukeliste',),
'sjukelistene': ('sjukeliste',),
'sjukelister': ('sjukeliste',),
'sjukelønn': ('sjukelønn',),
'sjukelønna': ('sjukelønn',),
'sjukelønnen': ('sjukelønn',),
'sjukelønnene': ('sjukelønn',),
'sjukelønner': ('sjukelønn',),
'sjukemelding': ('sjukemelding',),
'sjukemeldinga': ('sjukemelding',),
'sjukemeldingen': ('sjukemelding',),
'sjukemeldingene': ('sjukemelding',),
'sjukemeldinger': ('sjukemelding',),
'sjukepasser': ('sjukepasser',),
'sjukepassere': ('sjukepasser',),
'sjukepasseren': ('sjukepasser',),
'sjukepasserer': ('sjukepasser',),
'sjukepasserne': ('sjukepasser',),
'sjukepengene': ('sjukepenger',),
'sjukepenger': ('sjukepenger',),
'sjukepleia': ('sjukepleie',),
'sjukepleie': ('sjukepleie',),
'sjukepleien': ('sjukepleie',),
'sjukepleiene': ('sjukepleie',),
'sjukepleier': ('sjukepleie',),
'sjukepleier': ('sjukepleier',),
'sjukepleiere': ('sjukepleier',),
'sjukepleieren': ('sjukepleier',),
'sjukepleierer': ('sjukepleier',),
'sjukepleierne': ('sjukepleier',),
'sjukepleierelev': ('sjukepleierelev',),
'sjukepleiereleven': ('sjukepleierelev',),
'sjukepleierelevene': ('sjukepleierelev',),
'sjukepleierelever': ('sjukepleierelev',),
'sjukepleierskole': ('sjukepleierskole',),
'sjukepleierskolen': ('sjukepleierskole',),
'sjukepleierskolene': ('sjukepleierskole',),
'sjukepleierskoler': ('sjukepleierskole',),
'sjukesal': ('sjukesal',),
'sjukesalen': ('sjukesal',),
'sjukesalene': ('sjukesal',),
'sjukesaler': ('sjukesal',),
'sjukeseng': ('sjukeseng',),
'sjukesenga': ('sjukeseng',),
'sjukesengen': ('sjukeseng',),
'sjukesengene': ('sjukeseng',),
'sjukesenger': ('sjukeseng',),
'sjukestova': ('sjukestove',),
'sjukestove': ('sjukestove',),
'sjukestoven': ('sjukestove',),
'sjukestovene': ('sjukestove',),
'sjukestover': ('sjukestove',),
'sjukestova': ('sjukestove',),
'sjukestove': ('sjukestove',),
'sjukestoven': ('sjukestove',),
'sjukestovene': ('sjukestove',),
'sjukestover': ('sjukestove',),
'sjukestua': ('sjukestue',),
'sjukestue': ('sjukestue',),
'sjukestuen': ('sjukestue',),
'sjukestuene': ('sjukestue',),
'sjukestuer': ('sjukestue',),
'sjukesøster': ('sjukesøster',),
'sjukesøstera': ('sjukesøster',),
'sjukesøsteren': ('sjukesøster',),
'sjukesøstre': ('sjukesøster',),
'sjukesøstrene': ('sjukesøster',),
'sjukesøstrer': ('sjukesøster',),
'sjuketransport': ('sjuketransport',),
'sjuketransporten': ('sjuketransport',),
'sjuketransportene': ('sjuketransport',),
'sjuketransporter': ('sjuketransport',),
'sjukhjem': ('sjukhjem',),
'sjukhjemma': ('sjukhjem',),
'sjukhjemmene': ('sjukhjem',),
'sjukhjemmet': ('sjukhjem',),
'sjukling': ('sjukling',),
'sjuklingen': ('sjukling',),
'sjuklingene': ('sjukling',),
'sjuklinger': ('sjukling',),
'sjukmelding': ('sjukmelding',),
'sjukmeldinga': ('sjukmelding',),
'sjukmeldingen': ('sjukmelding',),
'sjukmeldingene': ('sjukmelding',),
'sjukmeldinger': ('sjukmelding',),
'sjumilsfart': ('sjumilsfart',),
'sjumilsfarta': ('sjumilsfart',),
'sjumilsfarten': ('sjumilsfart',),
'sjumilsfartene': ('sjumilsfart',),
'sjumilsfarter': ('sjumilsfart',),
'sjumilsstøvlene': ('sjumilsstøvler',),
'sjumilsstøvler': ('sjumilsstøvler',),
'sjursmess': ('sjursmess',),
'sjursmess': ('sjursmess',),
'sjursmesse': ('sjursmesse',),
'sjusk': ('sjusk',),
'sjusken': ('sjusk',),
'sjuskene': ('sjusk',),
'sjusker': ('sjusk',),
'sjusk': ('sjusk',),
'sjuska': ('sjusk',),
'sjuskene': ('sjusk',),
'sjusket': ('sjusk',),
'sjuskarbeid': ('sjuskarbeid',),
'sjuskarbeida': ('sjuskarbeid',),
'sjuskarbeidene': ('sjuskarbeid',),
'sjuskarbeider': ('sjuskarbeid',),
'sjuskarbeidet': ('sjuskarbeid',),
'sjuska': ('sjuske',),
'sjuske': ('sjuske',),
'sjusken': ('sjuske',),
'sjuskene': ('sjuske',),
'sjusker': ('sjuske',),
'sjuskearbeid': ('sjuskearbeid',),
'sjuskearbeida': ('sjuskearbeid',),
'sjuskearbeidene': ('sjuskearbeid',),
'sjuskearbeider': ('sjuskearbeid',),
'sjuskearbeidet': ('sjuskearbeid',),
'sjuskeri': ('sjuskeri',),
'sjuskeria': ('sjuskeri',),
'sjuskeriene': ('sjuskeri',),
'sjuskerier': ('sjuskeri',),
'sjuskeriet': ('sjuskeri',),
'sjuskjæra': ('sjuskjære',),
'sjuskjære': ('sjuskjære',),
'sjuskjæren': ('sjuskjære',),
'sjuskjærene': ('sjuskjære',),
'sjuskjærer': ('sjuskjære',),
'sjusover': ('sjusover',),
'sjusovere': ('sjusover',),
'sjusoveren': ('sjusover',),
'sjusoverer': ('sjusover',),
'sjusoverne': ('sjusover',),
'sjusoverdag': ('sjusoverdag',),
'sjusoverdagen': ('sjusoverdag',),
'sjusoverdagene': ('sjusoverdag',),
'sjusoverdager': ('sjusoverdag',),
'sjutal': ('sjutal',),
'sjutala': ('sjutal',),
'sjutalene': ('sjutal',),
'sjutalet': ('sjutal',),
'sjutall': ('sjutall',),
'sjutalla': ('sjutall',),
'sjutallene': ('sjutall',),
'sjutallet': ('sjutall',),
'sjutid': ('sjutid',),
'sjutida': ('sjutid',),
'sjutiden': ('sjutid',),
'sjutidene': ('sjutid',),
'sjutider': ('sjutid',),
'sjuåring': ('sjuåring',),
'sjuåringen': ('sjuåring',),
'sjuåringene': ('sjuåring',),
'sjuåringer': ('sjuåring',),
'sjuårsalder': ('sjuårsalder',),
'sjuårsaldere': ('sjuårsalder',),
'sjuårsalderen': ('sjuårsalder',),
'sjuårsalderer': ('sjuårsalder',),
'sjuårsalderne': ('sjuårsalder',),
'sjuårsaldre': ('sjuårsalder',),
'sjuårsaldrene': ('sjuårsalder',),
'sjuårsaldrer': ('sjuårsalder',),
'sjy': ('sjy',),
'sjyen': ('sjy',),
'sjyene': ('sjy',),
'sjyer': ('sjy',),
'sjå': ('sjå',),
'sjåa': ('sjå',),
'sjåene': ('sjå',),
'sjået': ('sjå',),
'sjåfør': ('sjåfør',),
'sjåføren': ('sjåfør',),
'sjåførene': ('sjåfør',),
'sjåfører': ('sjåfør',),
'sjåførlærer': ('sjåførlærer',),
'sjåførlærere': ('sjåførlærer',),
'sjåførlæreren': ('sjåførlærer',),
'sjåførlærerer': ('sjåførlærer',),
'sjåførlærerne': ('sjåførlærer',),
'sjåvinisme': ('sjåvinisme',),
'sjåvinismen': ('sjåvinisme',),
'sjåvinismene': ('sjåvinisme',),
'sjåvinismer': ('sjåvinisme',),
'sjåvinist': ('sjåvinist',),
'sjåvinisten': ('sjåvinist',),
'sjåvinistene': ('sjåvinist',),
'sjåvinister': ('sjåvinist',),
'sjællender': ('sjællender',),
'sjællendere': ('sjællender',),
'sjællenderen': ('sjællender',),
'sjællenderer': ('sjællender',),
'sjællenderne': ('sjællender',),
'sjø': ('sjø',),
'sjøen': ('sjø',),
'sjøene': ('sjø',),
'sjøer': ('sjø',),
'sjøanemone': ('sjøanemone',),
'sjøanemonen': ('sjøanemone',),
'sjøanemonene': ('sjøanemone',),
'sjøanemoner': ('sjøanemone',),
'sjøassuranse': ('sjøassuranse',),
'sjøassuransen': ('sjøassuranse',),
'sjøassuransene': ('sjøassuranse',),
'sjøassuranser': ('sjøassuranse',),
'sjøaure': ('sjøaure',),
'sjøauren': ('sjøaure',),
'sjøaurene': ('sjøaure',),
'sjøaurer': ('sjøaure',),
'sjøbad': ('sjøbad',),
'sjøbada': ('sjøbad',),
'sjøbadene': ('sjøbad',),
'sjøbadet': ('sjøbad',),
'sjøben': ('sjøben',),
'sjøbena': ('sjøben',),
'sjøbenene': ('sjøben',),
'sjøbenet': ('sjøben',),
'sjøblomst': ('sjøblomst',),
'sjøblomsten': ('sjøblomst',),
'sjøblomstene': ('sjøblomst',),
'sjøblomster': ('sjøblomst',),
'sjøbolle': ('sjøbolle',),
'sjøbollen': ('sjøbolle',),
'sjøbollene': ('sjøbolle',),
'sjøboller': ('sjøbolle',),
'sjøbotn': ('sjøbotn',),
'sjøbotnen': ('sjøbotn',),
'sjøbotnene': ('sjøbotn',),
'sjøbotner': ('sjøbotn',),
'sjøbris': ('sjøbris',),
'sjøbrisen': ('sjøbris',),
'sjøbrisene': ('sjøbris',),
'sjøbriser': ('sjøbris',),
'sjøbruk': ('sjøbruk',),
'sjøbruka': ('sjøbruk',),
'sjøbrukene': ('sjøbruk',),
'sjøbruket': ('sjøbruk',),
'sjøbu': ('sjøbu',),
'sjøbua': ('sjøbu',),
'sjøbuen': ('sjøbu',),
'sjøbuene': ('sjøbu',),
'sjøbuer': ('sjøbu',),
'sjøbunn': ('sjøbunn',),
'sjøbunnen': ('sjøbunn',),
'sjøbunnene': ('sjøbunn',),
'sjøbunner': ('sjøbunn',),
'sjøbuss': ('sjøbuss',),
'sjøbussen': ('sjøbuss',),
'sjøbussene': ('sjøbuss',),
'sjøbusser': ('sjøbuss',),
'sjøbåt': ('sjøbåt',),
'sjøbåten': ('sjøbåt',),
'sjøbåtene': ('sjøbåt',),
'sjøbåter': ('sjøbåt',),
'sjødyktighetsattest': ('sjødyktighetsattest',),
'sjødyktighetsattesten': ('sjødyktighetsattest',),
'sjødyktighetsattestene': ('sjødyktighetsattest',),
'sjødyktighetsattester': ('sjødyktighetsattest',),
'sjødyr': ('sjødyr',),
'sjødyra': ('sjødyr',),
'sjødyrene': ('sjødyr',),
'sjødyret': ('sjødyr',),
'sjøfarer': ('sjøfarer',),
'sjøfarere': ('sjøfarer',),
'sjøfareren': ('sjøfarer',),
'sjøfarerer': ('sjøfarer',),
'sjøfarerne': ('sjøfarer',),
'sjøfart': ('sjøfart',),
'sjøfarten': ('sjøfart',),
'sjøfartene': ('sjøfart',),
'sjøfarter': ('sjøfart',),
'sjøfartsby': ('sjøfartsby',),
'sjøfartsbyen': ('sjøfartsby',),
'sjøfartsbyene': ('sjøfartsby',),
'sjøfartsbyer': ('sjøfartsby',),
'sjøfartsdirektorat': ('sjøfartsdirektorat',),
'sjøfartsdirektorata': ('sjøfartsdirektorat',),
'sjøfartsdirektoratene': ('sjøfartsdirektorat',),
'sjøfartsdirektorater': ('sjøfartsdirektorat',),
'sjøfartsdirektoratet': ('sjøfartsdirektorat',),
'sjøfartsnasjon': ('sjøfartsnasjon',),
'sjøfartsnasjonen': ('sjøfartsnasjon',),
'sjøfartsnasjonene': ('sjøfartsnasjon',),
'sjøfartsnasjoner': ('sjøfartsnasjon',),
'sjøfisk': ('sjøfisk',),
'sjøfisken': ('sjøfisk',),
'sjøfiskene': ('sjøfisk',),
'sjøfisker': ('sjøfisk',),
'sjøfiska': ('sjøfiske',),
'sjøfiske': ('sjøfiske',),
'sjøfiskene': ('sjøfiske',),
'sjøfisker': ('sjøfiske',),
'sjøfisket': ('sjøfiske',),
'sjøfly': ('sjøfly',),
'sjøflya': ('sjøfly',),
'sjøflyene': ('sjøfly',),
'sjøflyet': ('sjøfly',),
'sjøflyhamn': ('sjøflyhamn',),
'sjøflyhamna': ('sjøflyhamn',),
'sjøflyhamnen': ('sjøflyhamn',),
'sjøflyhamnene': ('sjøflyhamn',),
'sjøflyhamner': ('sjøflyhamn',),
'sjøflyhavn': ('sjøflyhavn',),
'sjøflyhavna': ('sjøflyhavn',),
'sjøflyhavnen': ('sjøflyhavn',),
'sjøflyhavnene': ('sjøflyhavn',),
'sjøflyhavner': ('sjøflyhavn',),
'sjøfolk': ('sjøfolk',),
'sjøfolka': ('sjøfolk',),
'sjøfolkene': ('sjøfolk',),
'sjøfolket': ('sjøfolk',),
'sjøforklaring': ('sjøforklaring',),
'sjøforklaringa': ('sjøforklaring',),
'sjøforklaringen': ('sjøforklaring',),
'sjøforklaringene': ('sjøforklaring',),
'sjøforklaringer': ('sjøforklaring',),
'sjøforsikring': ('sjøforsikring',),
'sjøforsikringa': ('sjøforsikring',),
'sjøforsikringen': ('sjøforsikring',),
'sjøforsikringene': ('sjøforsikring',),
'sjøforsikringer': ('sjøforsikring',),
'sjøforsvar': ('sjøforsvar',),
'sjøforsvara': ('sjøforsvar',),
'sjøforsvarene': ('sjøforsvar',),
'sjøforsvaret': ('sjøforsvar',),
'sjøfortelling': ('sjøfortelling',),
'sjøfortellinga': ('sjøfortelling',),
'sjøfortellingen': ('sjøfortelling',),
'sjøfortellingene': ('sjøfortelling',),
'sjøfortellinger': ('sjøfortelling',),
'sjøfugl': ('sjøfugl',),
'sjøfuglen': ('sjøfugl',),
'sjøfuglene': ('sjøfugl',),
'sjøfugler': ('sjøfugl',),
'sjøgang': ('sjøgang',),
'sjøgangen': ('sjøgang',),
'sjøgangene': ('sjøgang',),
'sjøganger': ('sjøgang',),
'sjøgras': ('sjøgras',),
'sjøgrasa': ('sjøgras',),
'sjøgrasene': ('sjøgras',),
'sjøgraset': ('sjøgras',),
'sjøgrensa': ('sjøgrense',),
'sjøgrense': ('sjøgrense',),
'sjøgrensen': ('sjøgrense',),
'sjøgrensene': ('sjøgrense',),
'sjøgrenser': ('sjøgrense',),
'sjøgress': ('sjøgress',),
'sjøgressa': ('sjøgress',),
'sjøgressene': ('sjøgress',),
'sjøgresset': ('sjøgress',),
'sjøgutt': ('sjøgutt',),
'sjøgutten': ('sjøgutt',),
'sjøguttene': ('sjøgutt',),
'sjøgutter': ('sjøgutt',),
'sjøhare': ('sjøhare',),
'sjøharen': ('sjøhare',),
'sjøharene': ('sjøhare',),
'sjøharer': ('sjøhare',),
'sjøhelt': ('sjøhelt',),
'sjøhelten': ('sjøhelt',),
'sjøheltene': ('sjøhelt',),
'sjøhelter': ('sjøhelt',),
'sjøkabel': ('sjøkabel',),
'sjøkabelen': ('sjøkabel',),
'sjøkablene': ('sjøkabel',),
'sjøkabler': ('sjøkabel',),
'sjøkadett': ('sjøkadett',),
'sjøkadetten': ('sjøkadett',),
'sjøkadettene': ('sjøkadett',),
'sjøkadetter': ('sjøkadett',),
'sjøkaptein': ('sjøkaptein',),
'sjøkapteinen': ('sjøkaptein',),
'sjøkapteinene': ('sjøkaptein',),
'sjøkapteiner': ('sjøkaptein',),
'sjøkart': ('sjøkart',),
'sjøkarta': ('sjøkart',),
'sjøkartene': ('sjøkart',),
'sjøkarter': ('sjøkart',),
'sjøkartet': ('sjøkart',),
'sjøkonge': ('sjøkonge',),
'sjøkongen': ('sjøkonge',),
'sjøkongene': ('sjøkonge',),
'sjøkonger': ('sjøkonge',),
'sjøkreps': ('sjøkreps',),
'sjøkrepsen': ('sjøkreps',),
'sjøkrepsene': ('sjøkreps',),
'sjøkrepser': ('sjøkreps',),
'sjøkrig': ('sjøkrig',),
'sjøkrigen': ('sjøkrig',),
'sjøkrigene': ('sjøkrig',),
'sjøkriger': ('sjøkrig',),
'sjøkrigsskole': ('sjøkrigsskole',),
'sjøkrigsskolen': ('sjøkrigsskole',),
'sjøkrigsskolene': ('sjøkrigsskole',),
'sjøkrigsskoler': ('sjøkrigsskole',),
'sjøkrok': ('sjøkrok',),
'sjøkroken': ('sjøkrok',),
'sjøkrokene': ('sjøkrok',),
'sjøkroker': ('sjøkrok',),
'sjøku': ('sjøku',),
'sjøkua': ('sjøku',),
'sjøkuen': ('sjøku',),
'sjøkuene': ('sjøku',),
'sjøkuer': ('sjøku',),
'sjøkyr': ('sjøku',),
'sjøkyrne': ('sjøku',),
'sjøkveisa': ('sjøkveise',),
'sjøkveise': ('sjøkveise',),
'sjøkveisen': ('sjøkveise',),
'sjøkveisene': ('sjøkveise',),
'sjøkveiser': ('sjøkveise',),
'sjølaktelse': ('sjølaktelse',),
'sjølaktelsen': ('sjølaktelse',),
'sjølaktelsene': ('sjølaktelse',),
'sjølaktelser': ('sjølaktelse',),
'sjølantennelse': ('sjølantennelse',),
'sjølantennelsen': ('sjølantennelse',),
'sjølantennelsene': ('sjølantennelse',),
'sjølantennelser': ('sjølantennelse',),
'sjølantenning': ('sjølantenning',),
'sjølantenninga': ('sjølantenning',),
'sjølantenningen': ('sjølantenning',),
'sjølantenningene': ('sjølantenning',),
'sjølantenninger': ('sjølantenning',),
'sjølassuranse': ('sjølassuranse',),
'sjølassuransen': ('sjølassuranse',),
'sjølassuransene': ('sjølassuranse',),
'sjølassuranser': ('sjølassuranse',),
'sjølbebreidelse': ('sjølbebreidelse',),
'sjølbebreidelsen': ('sjølbebreidelse',),
'sjølbebreidelsene': ('sjølbebreidelse',),
'sjølbebreidelser': ('sjølbebreidelse',),
'sjølbebreiding': ('sjølbebreiding',),
'sjølbebreidinga': ('sjølbebreiding',),
'sjølbebreidingen': ('sjølbebreiding',),
'sjølbebreidingene': ('sjølbebreiding',),
'sjølbebreidinger': ('sjølbebreiding',),
'sjølbedrag': ('sjølbedrag',),
'sjølbedraga': ('sjølbedrag',),
'sjølbedragene': ('sjølbedrag',),
'sjølbedraget': ('sjølbedrag',),
'sjølbehag': ('sjølbehag',),
'sjølbehaga': ('sjølbehag',),
'sjølbehagene': ('sjølbehag',),
'sjølbehaget': ('sjølbehag',),
'sjølbeherskelse': ('sjølbeherskelse',),
'sjølbeherskelsen': ('sjølbeherskelse',),
'sjølbeherskelsene': ('sjølbeherskelse',),
'sjølbeherskelser': ('sjølbeherskelse',),
'sjølbehersking': ('sjølbehersking',),
'sjølbeherskinga': ('sjølbehersking',),
'sjølbeherskingen': ('sjølbehersking',),
'sjølbeherskingene': ('sjølbehersking',),
'sjølbeherskinger': ('sjølbehersking',),
'sjølbekjennelse': ('sjølbekjennelse',),
'sjølbekjennelsen': ('sjølbekjennelse',),
'sjølbekjennelsene': ('sjølbekjennelse',),
'sjølbekjennelser': ('sjølbekjennelse',),
'sjølbekjenning': ('sjølbekjenning',),
'sjølbekjenninga': ('sjølbekjenning',),
'sjølbekjenningen': ('sjølbekjenning',),
'sjølbekjenningene': ('sjølbekjenning',),
'sjølbekjenninger': ('sjølbekjenning',),
'sjølberging': ('sjølberging',),
'sjølberginga': ('sjølberging',),
'sjølbergingen': ('sjølberging',),
'sjølbergingene': ('sjølberging',),
'sjølberginger': ('sjølberging',),
'sjølbergingspolitikk': ('sjølbergingspolitikk',),
'sjølbergingspolitikken': ('sjølbergingspolitikk',),
'sjølbergingspolitikkene': ('sjølbergingspolitikk',),
'sjølbergingspolitikker': ('sjølbergingspolitikk',),
'sjølbergingsøkonomi': ('sjølbergingsøkonomi',),
'sjølbergingsøkonomien': ('sjølbergingsøkonomi',),
'sjølbergingsøkonomiene': ('sjølbergingsøkonomi',),
'sjølbergingsøkonomier': ('sjølbergingsøkonomi',),
'sjølbestemmelse': ('sjølbestemmelse',),
'sjølbestemmelsen': ('sjølbestemmelse',),
'sjølbestemmelsene': ('sjølbestemmelse',),
'sjølbestemmelser': ('sjølbestemmelse',),
'sjølbestemmelsesrett': ('sjølbestemmelsesrett',),
'sjølbestemmelsesretten': ('sjølbestemmelsesrett',),
'sjølbestemmelsesrettene': ('sjølbestemmelsesrett',),
'sjølbestemmelsesretter': ('sjølbestemmelsesrett',),
'sjølbetjening': ('sjølbetjening',),
'sjølbetjeninga': ('sjølbetjening',),
'sjølbetjeningen': ('sjølbetjening',),
'sjølbetjeningene': ('sjølbetjening',),
'sjølbetjeninger': ('sjølbetjening',),
'sjølbetjeningsbutikk': ('sjølbetjeningsbutikk',),
'sjølbetjeningsbutikken': ('sjølbetjeningsbutikk',),
'sjølbetjeningsbutikkene': ('sjølbetjeningsbutikk',),
'sjølbetjeningsbutikker': ('sjølbetjeningsbutikk',),
'sjølbetjeningshytta': ('sjølbetjeningshytte',),
'sjølbetjeningshytte': ('sjølbetjeningshytte',),
'sjølbetjeningshytten': ('sjølbetjeningshytte',),
'sjølbetjeningshyttene': ('sjølbetjeningshytte',),
'sjølbetjeningshytter': ('sjølbetjeningshytte',),
'sjølbevissthet': ('sjølbevissthet',),
'sjølbevisstheta': ('sjølbevissthet',),
'sjølbevisstheten': ('sjølbevissthet',),
'sjølbevissthetene': ('sjølbevissthet',),
'sjølbevisstheter': ('sjølbevissthet',),
'sjølbinder': ('sjølbinder',),
'sjølbindere': ('sjølbinder',),
'sjølbinderen': ('sjølbinder',),
'sjølbinderer': ('sjølbinder',),
'sjølbinderne': ('sjølbinder',),
'sjølbiografi': ('sjølbiografi',),
'sjølbiografien': ('sjølbiografi',),
'sjølbiografiene': ('sjølbiografi',),
'sjølbiografier': ('sjølbiografi',),
'sjølbygger': ('sjølbygger',),
'sjølbyggere': ('sjølbygger',),
'sjølbyggeren': ('sjølbygger',),
'sjølbyggerer': ('sjølbygger',),
'sjølbyggerne': ('sjølbygger',),
'sjølbyggerlag': ('sjølbyggerlag',),
'sjølbyggerlaga': ('sjølbyggerlag',),
'sjølbyggerlagene': ('sjølbyggerlag',),
'sjølbyggerlaget': ('sjølbyggerlag',),
'sjøldekning': ('sjøldekning',),
'sjøldekninga': ('sjøldekning',),
'sjøldekningen': ('sjøldekning',),
'sjøldekningene': ('sjøldekning',),
'sjøldekninger': ('sjøldekning',),
'sjøldisiplin': ('sjøldisiplin',),
'sjøldisiplinen': ('sjøldisiplin',),
'sjøldisiplinene': ('sjøldisiplin',),
'sjøldisipliner': ('sjøldisiplin',),
'sjølei': ('sjølei',),
'sjøleia': ('sjølei',),
'sjøleien': ('sjølei',),
'sjøleiene': ('sjølei',),
'sjøleier': ('sjølei',),
'sjøleia': ('sjøleie',),
'sjøleie': ('sjøleie',),
'sjøleiene': ('sjøleie',),
'sjøleier': ('sjøleie',),
'sjøleiet': ('sjøleie',),
'sjøleier': ('sjøleier',),
'sjøleiere': ('sjøleier',),
'sjøleieren': ('sjøleier',),
'sjøleierer': ('sjøleier',),
'sjøleierne': ('sjøleier',),
'sjøleierleilighet': ('sjøleierleilighet',),
'sjøleierleiligheta': ('sjøleierleilighet',),
'sjøleierleiligheten': ('sjøleierleilighet',),
'sjøleierleilighetene': ('sjøleierleilighet',),
'sjøleierleiligheter': ('sjøleierleilighet',),
'sjølerkjennelse': ('sjølerkjennelse',),
'sjølerkjennelsen': ('sjølerkjennelse',),
'sjølerkjennelsene': ('sjølerkjennelse',),
'sjølerkjennelser': ('sjølerkjennelse',),
'sjølfinansiering': ('sjølfinansiering',),
'sjølfinansieringa': ('sjølfinansiering',),
'sjølfinansieringen': ('sjølfinansiering',),
'sjølfinansieringene': ('sjølfinansiering',),
'sjølfinansieringer': ('sjølfinansiering',),
'sjølfolk': ('sjølfolk',),
'sjølfolka': ('sjølfolk',),
'sjølfolkene': ('sjølfolk',),
'sjølfolket': ('sjølfolk',),
'sjølfordypelse': ('sjølfordypelse',),
'sjølfordypelsen': ('sjølfordypelse',),
'sjølfordypelsene': ('sjølfordypelse',),
'sjølfordypelser': ('sjølfordypelse',),
'sjølfordyping': ('sjølfordyping',),
'sjølfordypinga': ('sjølfordyping',),
'sjølfordypingen': ('sjølfordyping',),
'sjølfordypingene': ('sjølfordyping',),
'sjølfordypinger': ('sjølfordyping',),
'sjølforherligelse': ('sjølforherligelse',),
'sjølforherligelsen': ('sjølforherligelse',),
'sjølforherligelsene': ('sjølforherligelse',),
'sjølforherligelser': ('sjølforherligelse',),
'sjølfornedrelse': ('sjølfornedrelse',),
'sjølfornedrelsen': ('sjølfornedrelse',),
'sjølfornedrelsene': ('sjølfornedrelse',),
'sjølfornedrelser': ('sjølfornedrelse',),
'sjølfornedring': ('sjølfornedring',),
'sjølfornedringa': ('sjølfornedring',),
'sjølfornedringen': ('sjølfornedring',),
'sjølfornedringene': ('sjølfornedring',),
'sjølfornedringer': ('sjølfornedring',),
'sjølfornekter': ('sjølfornekter',),
'sjølfornektere': ('sjølfornekter',),
'sjølfornekteren': ('sjølfornekter',),
'sjølfornekterer': ('sjølfornekter',),
'sjølfornekterne': ('sjølfornekter',),
'sjølfornyelse': ('sjølfornyelse',),
'sjølfornyelsen': ('sjølfornyelse',),
'sjølfornyelsene': ('sjølfornyelse',),
'sjølfornyelser': ('sjølfornyelse',),
'sjølfornying': ('sjølfornying',),
'sjølfornyinga': ('sjølfornying',),
'sjølfornyingen': ('sjølfornying',),
'sjølfornyingene': ('sjølfornying',),
'sjølfornyinger': ('sjølfornying',),
'sjølforsagelse': ('sjølforsagelse',),
'sjølforsagelsen': ('sjølforsagelse',),
'sjølforsagelsene': ('sjølforsagelse',),
'sjølforsagelser': ('sjølforsagelse',),
'sjølforsakelse': ('sjølforsakelse',),
'sjølforsakelsen': ('sjølforsakelse',),
'sjølforsakelsene': ('sjølforsakelse',),
'sjølforsakelser': ('sjølforsakelse',),
'sjølforsaking': ('sjølforsaking',),
'sjølforsakinga': ('sjølforsaking',),
'sjølforsakingen': ('sjølforsaking',),
'sjølforsakingene': ('sjølforsaking',),
'sjølforsakinger': ('sjølforsaking',),
'sjølforsvar': ('sjølforsvar',),
'sjølforsvara': ('sjølforsvar',),
'sjølforsvarene': ('sjølforsvar',),
'sjølforsvaret': ('sjølforsvar',),
'sjølforsyning': ('sjølforsyning',),
'sjølforsyninga': ('sjølforsyning',),
'sjølforsyningen': ('sjølforsyning',),
'sjølforsyningene': ('sjølforsyning',),
'sjølforsyninger': ('sjølforsyning',),
'sjølforsyningsgrad': ('sjølforsyningsgrad',),
'sjølforsyningsgraden': ('sjølforsyningsgrad',),
'sjølforsyningsgradene': ('sjølforsyningsgrad',),
'sjølforsyningsgrader': ('sjølforsyningsgrad',),
'sjølfølelse': ('sjølfølelse',),
'sjølfølelsen': ('sjølfølelse',),
'sjølfølelsene': ('sjølfølelse',),
'sjølfølelser': ('sjølfølelse',),
'sjølgodhet': ('sjølgodhet',),
'sjølgodheta': ('sjølgodhet',),
'sjølgodheten': ('sjølgodhet',),
'sjølgodhetene': ('sjølgodhet',),
'sjølgodheter': ('sjølgodhet',),
'sjølhevdelse': ('sjølhevdelse',),
'sjølhevdelsen': ('sjølhevdelse',),
'sjølhevdelsene': ('sjølhevdelse',),
'sjølhevdelser': ('sjølhevdelse',),
'sjølhevding': ('sjølhevding',),
'sjølhevdinga': ('sjølhevding',),
'sjølhevdingen': ('sjølhevding',),
'sjølhevdingene': ('sjølhevding',),
'sjølhevdinger': ('sjølhevding',),
'sjølhjelp': ('sjølhjelp',),
'sjølhjelpa': ('sjølhjelp',),
'sjølhjelpen': ('sjølhjelp',),
'sjølhjelpene': ('sjølhjelp',),
'sjølhjelper': ('sjølhjelp',),
'sjølilja': ('sjølilje',),
'sjølilje': ('sjølilje',),
'sjøliljen': ('sjølilje',),
'sjøliljene': ('sjølilje',),
'sjøliljer': ('sjølilje',),
'sjølironi': ('sjølironi',),
'sjølironien': ('sjølironi',),
'sjølironiene': ('sjølironi',),
'sjølironier': ('sjølironi',),
'sjøliv': ('sjøliv',),
'sjøliva': ('sjøliv',),
'sjølivene': ('sjøliv',),
'sjølivet': ('sjøliv',),
'sjøljustis': ('sjøljustis',),
'sjøljustisen': ('sjøljustis',),
'sjøljustisene': ('sjøljustis',),
'sjøljustiser': ('sjøljustis',),
'sjølkjensla': ('sjølkjensle',),
'sjølkjensle': ('sjølkjensle',),
'sjølkjenslen': ('sjølkjensle',),
'sjølkjenslene': ('sjølkjensle',),
'sjølkjensler': ('sjølkjensle',),
'sjølkontroll': ('sjølkontroll',),
'sjølkontrollen': ('sjølkontroll',),
'sjølkontrollene': ('sjølkontroll',),
'sjølkontroller': ('sjølkontroll',),
'sjølkost': ('sjølkost',),
'sjølkosta': ('sjølkost',),
'sjølkostene': ('sjølkost',),
'sjølkostet': ('sjølkost',),
'sjølkostnad': ('sjølkostnad',),
'sjølkostnaden': ('sjølkostnad',),
'sjølkostnadene': ('sjølkostnad',),
'sjølkostnader': ('sjølkostnad',),
'sjølkritikk': ('sjølkritikk',),
'sjølkritikken': ('sjølkritikk',),
'sjølkritikkene': ('sjølkritikk',),
'sjølkritikker': ('sjølkritikk',),
'sjølladegevær': ('sjølladegevær',),
'sjølladegeværa': ('sjølladegevær',),
'sjølladegeværene': ('sjølladegevær',),
'sjølladegeværer': ('sjølladegevær',),
'sjølladegeværet': ('sjølladegevær',),
'sjølmedlidenhet': ('sjølmedlidenhet',),
'sjølmedlidenheta': ('sjølmedlidenhet',),
'sjølmedlidenheten': ('sjølmedlidenhet',),
'sjølmedlidenhetene': ('sjølmedlidenhet',),
'sjølmedlidenheter': ('sjølmedlidenhet',),
'sjølmelding': ('sjølmelding',),
'sjølmeldinga': ('sjølmelding',),
'sjølmeldingen': ('sjølmelding',),
'sjølmeldingene': ('sjølmelding',),
'sjølmeldinger': ('sjølmelding',),
'sjølmord': ('sjølmord',),
'sjølmorda': ('sjølmord',),
'sjølmordene': ('sjølmord',),
'sjølmordet': ('sjølmord',),
'sjølmorder': ('sjølmorder',),
'sjølmordere': ('sjølmorder',),
'sjølmorderen': ('sjølmorder',),
'sjølmorderer': ('sjølmorder',),
'sjølmorderne': ('sjølmorder',),
'sjølmotsigelse': ('sjølmotsigelse',),
'sjølmotsigelsen': ('sjølmotsigelse',),
'sjølmotsigelsene': ('sjølmotsigelse',),
'sjølmotsigelser': ('sjølmotsigelse',),
'sjølmotsiing': ('sjølmotsiing',),
'sjølmotsiinga': ('sjølmotsiing',),
'sjølmotsiingen': ('sjølmotsiing',),
'sjølmotsiingene': ('sjølmotsiing',),
'sjølmotsiinger': ('sjølmotsiing',),
'sjølmål': ('sjølmål',),
'sjølmåla': ('sjølmål',),
'sjølmålene': ('sjølmål',),
'sjølmålet': ('sjølmål',),
'sjølnekting': ('sjølnekting',),
'sjølnektinga': ('sjølnekting',),
'sjølnektingen': ('sjølnekting',),
'sjølnektingene': ('sjølnekting',),
'sjølnektinger': ('sjølnekting',),
'sjøloppgiing': ('sjøloppgiing',),
'sjøloppgiinga': ('sjøloppgiing',),
'sjøloppgiingen': ('sjøloppgiing',),
'sjøloppgiingene': ('sjøloppgiing',),
'sjøloppgiinger': ('sjøloppgiing',),
'sjøloppgivelse': ('sjøloppgivelse',),
'sjøloppgivelsen': ('sjøloppgivelse',),
'sjøloppgivelsene': ('sjøloppgivelse',),
'sjøloppgivelser': ('sjøloppgivelse',),
'sjøloppgiving': ('sjøloppgiving',),
'sjøloppgivinga': ('sjøloppgiving',),
'sjøloppgivingen': ('sjøloppgiving',),
'sjøloppgivingene': ('sjøloppgiving',),
'sjøloppgivinger': ('sjøloppgiving',),
'sjøloppholdelse': ('sjøloppholdelse',),
'sjøloppholdelsen': ('sjøloppholdelse',),
'sjøloppholdelsene': ('sjøloppholdelse',),
'sjøloppholdelser': ('sjøloppholdelse',),
'sjøloppholdelsesdrift': ('sjøloppholdelsesdrift',),
'sjøloppholdelsesdrifta': ('sjøloppholdelsesdrift',),
'sjøloppholdelsesdriften': ('sjøloppholdelsesdrift',),
'sjøloppholdelsesdriftene': ('sjøloppholdelsesdrift',),
'sjøloppholdelsesdrifter': ('sjøloppholdelsesdrift',),
'sjølopphøyelse': ('sjølopphøyelse',),
'sjølopphøyelsen': ('sjølopphøyelse',),
'sjølopphøyelsene': ('sjølopphøyelse',),
'sjølopphøyelser': ('sjølopphøyelse',),
'sjøloppofrelse': ('sjøloppofrelse',),
'sjøloppofrelsen': ('sjøloppofrelse',),
'sjøloppofrelsene': ('sjøloppofrelse',),
'sjøloppofrelser': ('sjøloppofrelse',),
'sjøloppofring': ('sjøloppofring',),
'sjøloppofringa': ('sjøloppofring',),
'sjøloppofringen': ('sjøloppofring',),
'sjøloppofringene': ('sjøloppofring',),
'sjøloppofringer': ('sjøloppofring',),
'sjølopptatthet': ('sjølopptatthet',),
'sjølopptattheta': ('sjølopptatthet',),
'sjølopptattheten': ('sjølopptatthet',),
'sjølopptatthetene': ('sjølopptatthet',),
'sjølopptattheter': ('sjølopptatthet',),
'sjølovervinnelse': ('sjølovervinnelse',),
'sjølovervinnelsen': ('sjølovervinnelse',),
'sjølovervinnelsene': ('sjølovervinnelse',),
'sjølovervinnelser': ('sjølovervinnelse',),
'sjølovervurdering': ('sjølovervurdering',),
'sjølovervurderinga': ('sjølovervurdering',),
'sjølovervurderingen': ('sjølovervurdering',),
'sjølovervurderingene': ('sjølovervurdering',),
'sjølovervurderinger': ('sjølovervurdering',),
'sjølpiner': ('sjølpiner',),
'sjølpinere': ('sjølpiner',),
'sjølpineren': ('sjølpiner',),
'sjølpinerer': ('sjølpiner',),
'sjølpinerne': ('sjølpiner',),
'sjølpinsel': ('sjølpinsel',),
'sjølpinselen': ('sjølpinsel',),
'sjølpinslene': ('sjølpinsel',),
'sjølpinsler': ('sjølpinsel',),
'sjølplager': ('sjølplager',),
'sjølplagere': ('sjølplager',),
'sjølplageren': ('sjølplager',),
'sjølplagerer': ('sjølplager',),
'sjølplagerne': ('sjølplager',),
'sjølplageri': ('sjølplageri',),
'sjølplageria': ('sjølplageri',),
'sjølplageriene': ('sjølplageri',),
'sjølplagerier': ('sjølplageri',),
'sjølplageriet': ('sjølplageri',),
'sjølplaging': ('sjølplaging',),
'sjølplaginga': ('sjølplaging',),
'sjølplagingen': ('sjølplaging',),
'sjølplagingene': ('sjølplaging',),
'sjølplaginger': ('sjølplaging',),
'sjølplukk': ('sjølplukk',),
'sjølplukken': ('sjølplukk',),
'sjølplukkene': ('sjølplukk',),
'sjølplukker': ('sjølplukk',),
'sjølplukker': ('sjølplukker',),
'sjølplukkere': ('sjølplukker',),
'sjølplukkeren': ('sjølplukker',),
'sjølplukkerer': ('sjølplukker',),
'sjølplukkerne': ('sjølplukker',),
'sjølplukking': ('sjølplukking',),
'sjølplukkinga': ('sjølplukking',),
'sjølplukkingen': ('sjølplukking',),
'sjølplukkingene': ('sjølplukking',),
'sjølplukkinger': ('sjølplukking',),
'sjølportrett': ('sjølportrett',),
'sjølportretta': ('sjølportrett',),
'sjølportrettene': ('sjølportrett',),
'sjølportretter': ('sjølportrett',),
'sjølportrettet': ('sjølportrett',),
'sjølproletarisering': ('sjølproletarisering',),
'sjølproletariseringa': ('sjølproletarisering',),
'sjølproletariseringen': ('sjølproletarisering',),
'sjølproletariseringene': ('sjølproletarisering',),
'sjølproletariseringer': ('sjølproletarisering',),
'sjølprøvelse': ('sjølprøvelse',),
'sjølprøvelsen': ('sjølprøvelse',),
'sjølprøvelsene': ('sjølprøvelse',),
'sjølprøvelser': ('sjølprøvelse',),
'sjølprøving': ('sjølprøving',),
'sjølprøvinga': ('sjølprøving',),
'sjølprøvingen': ('sjølprøving',),
'sjølprøvingene': ('sjølprøving',),
'sjølprøvinger': ('sjølprøving',),
'sjølransakelse': ('sjølransakelse',),
'sjølransakelsen': ('sjølransakelse',),
'sjølransakelsene': ('sjølransakelse',),
'sjølransakelser': ('sjølransakelse',),
'sjølransaking': ('sjølransaking',),
'sjølransakinga': ('sjølransaking',),
'sjølransakingen': ('sjølransaking',),
'sjølransakingene': ('sjølransaking',),
'sjølransakinger': ('sjølransaking',),
'sjølrealisering': ('sjølrealisering',),
'sjølrealiseringa': ('sjølrealisering',),
'sjølrealiseringen': ('sjølrealisering',),
'sjølrealiseringene': ('sjølrealisering',),
'sjølrealiseringer': ('sjølrealisering',),
'sjølrespekt': ('sjølrespekt',),
'sjølrespekten': ('sjølrespekt',),
'sjølrespektene': ('sjølrespekt',),
'sjølrespekter': ('sjølrespekt',),
'sjølrisiko': ('sjølrisiko',),
'sjølrisikoen': ('sjølrisiko',),
'sjølrisikoene': ('sjølrisiko',),
'sjølrisikoer': ('sjølrisiko',),
'sjølros': ('sjølros',),
'sjølrosen': ('sjølros',),
'sjølrosene': ('sjølros',),
'sjølroser': ('sjølros',),
'sjølråderett': ('sjølråderett',),
'sjølråderetten': ('sjølråderett',),
'sjølråderettene': ('sjølråderett',),
'sjølråderetter': ('sjølråderett',),
'sjølsikkerhet': ('sjølsikkerhet',),
'sjølsikkerheta': ('sjølsikkerhet',),
'sjølsikkerheten': ('sjølsikkerhet',),
'sjølsikkerhetene': ('sjølsikkerhet',),
'sjølsikkerheter': ('sjølsikkerhet',),
'sjølskott': ('sjølskott',),
'sjølskotta': ('sjølskott',),
'sjølskottene': ('sjølskott',),
'sjølskottet': ('sjølskott',),
'sjølskryt': ('sjølskryt',),
'sjølskryta': ('sjølskryt',),
'sjølskrytene': ('sjølskryt',),
'sjølskrytet': ('sjølskryt',),
'sjølskudd': ('sjølskudd',),
'sjølskudda': ('sjølskudd',),
'sjølskuddene': ('sjølskudd',),
'sjølskuddet': ('sjølskudd',),
'sjølskyldner': ('sjølskyldner',),
'sjølskyldnere': ('sjølskyldner',),
'sjølskyldneren': ('sjølskyldner',),
'sjølskyldnerer': ('sjølskyldner',),
'sjølskyldnerne': ('sjølskyldner',),
'sjølskyldnerkausjon': ('sjølskyldnerkausjon',),
'sjølskyldnerkausjonen': ('sjølskyldnerkausjon',),
'sjølskyldnerkausjonene': ('sjølskyldnerkausjon',),
'sjølskyldnerkausjoner': ('sjølskyldnerkausjon',),
'sjølskyldnerkausjonist': ('sjølskyldnerkausjonist',),
'sjølskyldnerkausjonisten': ('sjølskyldnerkausjonist',),
'sjølskyldnerkausjonistene': ('sjølskyldnerkausjonist',),
'sjølskyldnerkausjonister': ('sjølskyldnerkausjonist',),
'sjølstarter': ('sjølstarter',),
'sjølstartere': ('sjølstarter',),
'sjølstarteren': ('sjølstarter',),
'sjølstarterer': ('sjølstarter',),
'sjølstarterne': ('sjølstarter',),
'sjølstenda': ('sjølstende',),
'sjølstende': ('sjølstende',),
'sjølstendene': ('sjølstende',),
'sjølstender': ('sjølstende',),
'sjølstendet': ('sjølstende',),
'sjølstendighet': ('sjølstendighet',),
'sjølstendigheta': ('sjølstendighet',),
'sjølstendigheten': ('sjølstendighet',),
'sjølstendighetene': ('sjølstendighet',),
'sjølstendigheter': ('sjølstendighet',),
'sjølstendighetsfølelse': ('sjølstendighetsfølelse',),
'sjølstendighetsfølelsen': ('sjølstendighetsfølelse',),
'sjølstendighetsfølelsene': ('sjølstendighetsfølelse',),
'sjølstendighetsfølelser': ('sjølstendighetsfølelse',),
'sjølstendighetsparti': ('sjølstendighetsparti',),
'sjølstendighetspartia': ('sjølstendighetsparti',),
'sjølstendighetspartiene': ('sjølstendighetsparti',),
'sjølstendighetspartier': ('sjølstendighetsparti',),
'sjølstendighetspartiet': ('sjølstendighetsparti',),
'sjølstendighetstrang': ('sjølstendighetstrang',),
'sjølstendighetstrangen': ('sjølstendighetstrang',),
'sjølstendighetstrangene': ('sjølstendighetstrang',),
'sjølstendighetstranger': ('sjølstendighetstrang',),
'sjølstudia': ('sjølstudium',),
'sjølstudiene': ('sjølstudium',),
'sjølstudier': ('sjølstudium',),
'sjølstudiet': ('sjølstudium',),
'sjølstudium': ('sjølstudium',),
'sjølstyra': ('sjølstyre',),
'sjølstyre': ('sjølstyre',),
'sjølstyrene': ('sjølstyre',),
'sjølstyrer': ('sjølstyre',),
'sjølstyret': ('sjølstyre',),
'sjølstyring': ('sjølstyring',),
'sjølstyringa': ('sjølstyring',),
'sjølstyringen': ('sjølstyring',),
'sjølstyringene': ('sjølstyring',),
'sjølstyringer': ('sjølstyring',),
'sjølsyn': ('sjølsyn',),
'sjølsyna': ('sjølsyn',),
'sjølsynene': ('sjølsyn',),
'sjølsynet': ('sjølsyn',),
'sjølsyn': ('sjølsyn',),
'sjølsyna': ('sjølsyn',),
'sjølsynene': ('sjølsyn',),
'sjølsyner': ('sjølsyn',),
'sjølsynet': ('sjølsyn',),
'sjøltekt': ('sjøltekt',),
'sjøltekta': ('sjøltekt',),
'sjøltekten': ('sjøltekt',),
'sjøltektene': ('sjøltekt',),
'sjøltekter': ('sjøltekt',),
'sjøltillit': ('sjøltillit',),
'sjøltillita': ('sjøltillit',),
'sjøltilliten': ('sjøltillit',),
'sjøltillitene': ('sjøltillit',),
'sjøltilliter': ('sjøltillit',),
'sjøltrimmer': ('sjøltrimmer',),
'sjøltrimmere': ('sjøltrimmer',),
'sjøltrimmeren': ('sjøltrimmer',),
'sjøltrimmerer': ('sjøltrimmer',),
'sjøltrimmerne': ('sjøltrimmer',),
'sjøltrøst': ('sjøltrøst',),
'sjøltrøsta': ('sjøltrøst',),
'sjøltrøsten': ('sjøltrøst',),
'sjøltrøstene': ('sjøltrøst',),
'sjøltrøster': ('sjøltrøst',),
'sjøltukt': ('sjøltukt',),
'sjøltukta': ('sjøltukt',),
'sjøltukten': ('sjøltukt',),
'sjøltuktene': ('sjøltukt',),
'sjøltukter': ('sjøltukt',),
'sjøluft': ('sjøluft',),
'sjølufta': ('sjøluft',),
'sjøluften': ('sjøluft',),
'sjøluftene': ('sjøluft',),
'sjølufter': ('sjøluft',),
'sjølutløser': ('sjølutløser',),
'sjølutløsere': ('sjølutløser',),
'sjølutløseren': ('sjølutløser',),
'sjølutløserer': ('sjølutløser',),
'sjølutløserne': ('sjølutløser',),
'sjølutløyser': ('sjølutløyser',),
'sjølutløysere': ('sjølutløyser',),
'sjølutløyseren': ('sjølutløyser',),
'sjølutløyserer': ('sjølutløyser',),
'sjølutløyserne': ('sjølutløyser',),
'sjølvalg': ('sjølvalg',),
'sjølvalga': ('sjølvalg',),
'sjølvalgene': ('sjølvalg',),
'sjølvalget': ('sjølvalg',),
'sjølvalgsbutikk': ('sjølvalgsbutikk',),
'sjølvalgsbutikken': ('sjølvalgsbutikk',),
'sjølvalgsbutikkene': ('sjølvalgsbutikk',),
'sjølvalgsbutikker': ('sjølvalgsbutikk',),
'sjølvefolk': ('sjølvefolk',),
'sjølvefolka': ('sjølvefolk',),
'sjølvefolkene': ('sjølvefolk',),
'sjølvefolket': ('sjølvefolk',),
'sjølvørdnad': ('sjølvørdnad',),
'sjølvørdnaden': ('sjølvørdnad',),
'sjølvørdnadene': ('sjølvørdnad',),
'sjølvørdnader': ('sjølvørdnad',),
'sjølvørnad': ('sjølvørnad',),
'sjølvørnaden': ('sjølvørnad',),
'sjølvørnadene': ('sjølvørnad',),
'sjølvørnader': ('sjølvørnad',),
'sjøløva': ('sjøløve',),
'sjøløve': ('sjøløve',),
'sjøløven': ('sjøløve',),
'sjøløvene': ('sjøløve',),
'sjøløver': ('sjøløve',),
'sjømann': ('sjømann',),
'sjømannen': ('sjømann',),
'sjømenn': ('sjømann',),
'sjømennene': ('sjømann',),
'sjømannskap': ('sjømannskap',),
'sjømannskapa': ('sjømannskap',),
'sjømannskapen': ('sjømannskap',),
'sjømannskapene': ('sjømannskap',),
'sjømannskaper': ('sjømannskap',),
'sjømannskapet': ('sjømannskap',),
'sjømannskirka': ('sjømannskirke',),
'sjømannskirke': ('sjømannskirke',),
'sjømannskirken': ('sjømannskirke',),
'sjømannskirkene': ('sjømannskirke',),
'sjømannskirker': ('sjømannskirke',),
'sjømannskjerka': ('sjømannskjerke',),
'sjømannskjerke': ('sjømannskjerke',),
'sjømannskjerken': ('sjømannskjerke',),
'sjømannskjerkene': ('sjømannskjerke',),
'sjømannskjerker': ('sjømannskjerke',),
'sjømannsknute': ('sjømannsknute',),
'sjømannsknuten': ('sjømannsknute',),
'sjømannsknutene': ('sjømannsknute',),
'sjømannsknuter': ('sjømannsknute',),
'sjømannsprest': ('sjømannsprest',),
'sjømannspresten': ('sjømannsprest',),
'sjømannsprestene': ('sjømannsprest',),
'sjømannsprester': ('sjømannsprest',),
'sjømannsskatt': ('sjømannsskatt',),
'sjømannsskatten': ('sjømannsskatt',),
'sjømannsskattene': ('sjømannsskatt',),
'sjømannsskatter': ('sjømannsskatt',),
'sjømannsskole': ('sjømannsskole',),
'sjømannsskolen': ('sjømannsskole',),
'sjømannsskolene': ('sjømannsskole',),
'sjømannsskoler': ('sjømannsskole',),
'sjømannsspråk': ('sjømannsspråk',),
'sjømannsspråka': ('sjømannsspråk',),
'sjømannsspråkene': ('sjømannsspråk',),
'sjømannsspråket': ('sjømannsspråk',),
'sjømannsuttrykk': ('sjømannsuttrykk',),
'sjømannsuttrykka': ('sjømannsuttrykk',),
'sjømannsuttrykkene': ('sjømannsuttrykk',),
'sjømannsuttrykket': ('sjømannsuttrykk',),
'sjømerka': ('sjømerke',),
'sjømerke': ('sjømerke',),
'sjømerkene': ('sjømerke',),
'sjømerker': ('sjømerke',),
'sjømerket': ('sjømerke',),
'sjømina': ('sjømine',),
'sjømine': ('sjømine',),
'sjøminen': ('sjømine',),
'sjøminene': ('sjømine',),
'sjøminer': ('sjømine',),
'sjøoffiser': ('sjøoffiser',),
'sjøoffiseren': ('sjøoffiser',),
'sjøoffiserene': ('sjøoffiser',),
'sjøoffiserer': ('sjøoffiser',),
'sjøorm': ('sjøorm',),
'sjøormen': ('sjøorm',),
'sjøormene': ('sjøorm',),
'sjøormer': ('sjøorm',),
'sjøorre': ('sjøorre',),
'sjøorren': ('sjøorre',),
'sjøorrene': ('sjøorre',),
'sjøorrer': ('sjøorre',),
'sjøpiggsvin': ('sjøpiggsvin',),
'sjøpiggsvina': ('sjøpiggsvin',),
'sjøpiggsvinene': ('sjøpiggsvin',),
'sjøpiggsvinet': ('sjøpiggsvin',),
'sjøpinnsvin': ('sjøpinnsvin',),
'sjøpinnsvina': ('sjøpinnsvin',),
'sjøpinnsvinene': ('sjøpinnsvin',),
'sjøpinnsvinet': ('sjøpinnsvin',),
'sjøpung': ('sjøpung',),
'sjøpungen': ('sjøpung',),
'sjøpungene': ('sjøpung',),
'sjøpunger': ('sjøpung',),
'sjøpølsa': ('sjøpølse',),
'sjøpølse': ('sjøpølse',),
'sjøpølsen': ('sjøpølse',),
'sjøpølsene': ('sjøpølse',),
'sjøpølser': ('sjøpølse',),
'sjøredningstjeneste': ('sjøredningstjeneste',),
'sjøredningstjenesten': ('sjøredningstjeneste',),
'sjøredningstjenestene': ('sjøredningstjeneste',),
'sjøredningstjenester': ('sjøredningstjeneste',),
'sjøreisa': ('sjøreise',),
'sjøreise': ('sjøreise',),
'sjøreisen': ('sjøreise',),
'sjøreisene': ('sjøreise',),
'sjøreiser': ('sjøreise',),
'sjørett': ('sjørett',),
'sjøretten': ('sjørett',),
'sjørettene': ('sjørett',),
'sjøretter': ('sjørett',),
'sjørosa': ('sjørose',),
'sjørose': ('sjørose',),
'sjørosen': ('sjørose',),
'sjørosene': ('sjørose',),
'sjøroser': ('sjørose',),
'sjørøver': ('sjørøver',),
'sjørøvere': ('sjørøver',),
'sjørøveren': ('sjørøver',),
'sjørøverer': ('sjørøver',),
'sjørøverne': ('sjørøver',),
'sjørøveri': ('sjørøveri',),
'sjørøveria': ('sjørøveri',),
'sjørøveriene': ('sjørøveri',),
'sjørøverier': ('sjørøveri',),
'sjørøveriet': ('sjørøveri',),
'sjørøverreda': ('sjørøverrede',),
'sjørøverrede': ('sjørøverrede',),
'sjørøverredene': ('sjørøverrede',),
'sjørøverreder': ('sjørøverrede',),
'sjørøverredet': ('sjørøverrede',),
'sjørøverreir': ('sjørøverreir',),
'sjørøverreira': ('sjørøverreir',),
'sjørøverreirene': ('sjørøverreir',),
'sjørøverreiret': ('sjørøverreir',),
'sjørøverstat': ('sjørøverstat',),
'sjørøverstaten': ('sjørøverstat',),
'sjørøverstatene': ('sjørøverstat',),
'sjørøverstater': ('sjørøverstat',),
'sjørøvertokt': ('sjørøvertokt',),
'sjørøvertokta': ('sjørøvertokt',),
'sjørøvertoktene': ('sjørøvertokt',),
'sjørøvertokter': ('sjørøvertokt',),
'sjørøvertoktet': ('sjørøvertokt',),
'sjørøya': ('sjørøye',),
'sjørøye': ('sjørøye',),
'sjørøyen': ('sjørøye',),
'sjørøyene': ('sjørøye',),
'sjørøyer': ('sjørøye',),
'sjørøyk': ('sjørøyk',),
'sjørøyken': ('sjørøyk',),
'sjørøykene': ('sjørøyk',),
'sjørøyker': ('sjørøyk',),
'sjørøyr': ('sjørøyr',),
'sjørøyra': ('sjørøyr',),
'sjørøyren': ('sjørøyr',),
'sjørøyrene': ('sjørøyr',),
'sjørøyrer': ('sjørøyr',),
'sjøsame': ('sjøsame',),
'sjøsamen': ('sjøsame',),
'sjøsamene': ('sjøsame',),
'sjøsamer': ('sjøsame',),
'sjøsetning': ('sjøsetning',),
'sjøsetninga': ('sjøsetning',),
'sjøsetningen': ('sjøsetning',),
'sjøsetningene': ('sjøsetning',),
'sjøsetninger': ('sjøsetning',),
'sjøsetting': ('sjøsetting',),
'sjøsettinga': ('sjøsetting',),
'sjøsettingen': ('sjøsetting',),
'sjøsettingene': ('sjøsetting',),
'sjøsettinger': ('sjøsetting',),
'sjøsjuka': ('sjøsjuke',),
'sjøsjuke': ('sjøsjuke',),
'sjøsjuken': ('sjøsjuke',),
'sjøsjukene': ('sjøsjuke',),
'sjøsjuker': ('sjøsjuke',),
'sjøslag': ('sjøslag',),
'sjøslaga': ('sjøslag',),
'sjøslagene': ('sjøslag',),
'sjøslaget': ('sjøslag',),
'sjøsprøyt': ('sjøsprøyt',),
'sjøsprøyta': ('sjøsprøyt',),
'sjøsprøyten': ('sjøsprøyt',),
'sjøsprøytene': ('sjøsprøyt',),
'sjøsprøyter': ('sjøsprøyt',),
'sjøsprøytet': ('sjøsprøyt',),
'sjøstjerna': ('sjøstjerne',),
'sjøstjerne': ('sjøstjerne',),
'sjøstjernen': ('sjøstjerne',),
'sjøstjernene': ('sjøstjerne',),
'sjøstjerner': ('sjøstjerne',),
'sjøstøvel': ('sjøstøvel',),
'sjøstøvelen': ('sjøstøvel',),
'sjøstøvlene': ('sjøstøvel',),
'sjøstøvler': ('sjøstøvel',),
'sjøsyka': ('sjøsyke',),
'sjøsyke': ('sjøsyke',),
'sjøsyken': ('sjøsyke',),
'sjøsykene': ('sjøsyke',),
'sjøsyker': ('sjøsyke',),
'sjøterritoria': ('sjøterritorium',),
'sjøterritoriene': ('sjøterritorium',),
'sjøterritorier': ('sjøterritorium',),
'sjøterritoriet': ('sjøterritorium',),
'sjøterritorium': ('sjøterritorium',),
'sjøtjeneste': ('sjøtjeneste',),
'sjøtjenesten': ('sjøtjeneste',),
'sjøtjenestene': ('sjøtjeneste',),
'sjøtjenester': ('sjøtjeneste',),
'sjøtransport': ('sjøtransport',),
'sjøtransporten': ('sjøtransport',),
'sjøtransportene': ('sjøtransport',),
'sjøtransporter': ('sjøtransport',),
'sjøtre': ('sjøtre',),
'sjøtrea': ('sjøtre',),
'sjøtreet': ('sjøtre',),
'sjøtrær': ('sjøtre',),
'sjøtrærne': ('sjøtre',),
'sjøtunga': ('sjøtunge',),
'sjøtunge': ('sjøtunge',),
'sjøtungen': ('sjøtunge',),
'sjøtungene': ('sjøtunge',),
'sjøtunger': ('sjøtunge',),
'sjøulk': ('sjøulk',),
'sjøulken': ('sjøulk',),
'sjøulkene': ('sjøulk',),
'sjøulker': ('sjøulk',),
'sjøuttrykk': ('sjøuttrykk',),
'sjøuttrykka': ('sjøuttrykk',),
'sjøuttrykkene': ('sjøuttrykk',),
'sjøuttrykket': ('sjøuttrykk',),
'sjøvakt': ('sjøvakt',),
'sjøvakta': ('sjøvakt',),
'sjøvakten': ('sjøvakt',),
'sjøvaktene': ('sjøvakt',),
'sjøvakter': ('sjøvakt',),
'sjøvann': ('sjøvann',),
'sjøvanna': ('sjøvann',),
'sjøvannene': ('sjøvann',),
'sjøvannet': ('sjøvann',),
'sjøvatn': ('sjøvatn',),
'sjøvatna': ('sjøvatn',),
'sjøvatnene': ('sjøvatn',),
'sjøvatnet': ('sjøvatn',),
'sjøveg': ('sjøveg',),
'sjøvegen': ('sjøveg',),
'sjøvegene': ('sjøveg',),
'sjøveger': ('sjøveg',),
'sjøvegsregel': ('sjøvegsregel',),
'sjøvegsregelen': ('sjøvegsregel',),
'sjøvegsreglene': ('sjøvegsregel',),
'sjøvegsregler': ('sjøvegsregel',),
'sjøvei': ('sjøvei',),
'sjøveien': ('sjøvei',),
'sjøveiene': ('sjøvei',),
'sjøveier': ('sjøvei',),
'sjøveisregel': ('sjøveisregel',),
'sjøveisregelen': ('sjøveisregel',),
'sjøveisreglene': ('sjøveisregel',),
'sjøveisregler': ('sjøveisregel',),
'sjøverk': ('sjøverk',),
'sjøverken': ('sjøverk',),
'sjøverkene': ('sjøverk',),
'sjøverker': ('sjøverk',),
'sjøvett': ('sjøvett',),
'sjøvetta': ('sjøvett',),
'sjøvettene': ('sjøvett',),
'sjøvettet': ('sjøvett',),
'sjøvott': ('sjøvott',),
'sjøvotten': ('sjøvott',),
'sjøvottene': ('sjøvott',),
'sjøvotter': ('sjøvott',),
'sjøvær': ('sjøvær',),
'sjøværa': ('sjøvær',),
'sjøværene': ('sjøvær',),
'sjøværet': ('sjøvær',),
'sjøørret': ('sjøørret',),
'sjøørreten': ('sjøørret',),
'sjøørretene': ('sjøørret',),
'sjøørreter': ('sjøørret',),
'skabb': ('skabb',),
'skabba': ('skabb',),
'skabbene': ('skabb',),
'skabbet': ('skabb',),
'skabbhals': ('skabbhals',),
'skabbhalsen': ('skabbhals',),
'skabbhalsene': ('skabbhals',),
'skabbhalser': ('skabbhals',),
'skabbmidd': ('skabbmidd',),
'skabbmidden': ('skabbmidd',),
'skabbmiddene': ('skabbmidd',),
'skabbmidder': ('skabbmidd',),
'skabbmit': ('skabbmit',),
'skabbmiten': ('skabbmit',),
'skabbmitene': ('skabbmit',),
'skabbmiter': ('skabbmit',),
'skabelon': ('skabelon',),
'skabelonen': ('skabelon',),
'skabelonene': ('skabelon',),
'skabeloner': ('skabelon',),
'skaberakk': ('skaberakk',),
'skaberakka': ('skaberakk',),
'skaberakkene': ('skaberakk',),
'skaberakker': ('skaberakk',),
'skaberakket': ('skaberakk',),
'skabilken': ('skabilken',),
'skabilkena': ('skabilken',),
'skabilkenene': ('skabilken',),
'skabilkener': ('skabilken',),
'skabilkenet': ('skabilken',),
'skade': ('skade',),
'skaden': ('skade',),
'skadene': ('skade',),
'skader': ('skade',),
'skadebeløp': ('skadebeløp',),
'skadebeløpa': ('skadebeløp',),
'skadebeløpene': ('skadebeløp',),
'skadebeløpet': ('skadebeløp',),
'skadebjørn': ('skadebjørn',),
'skadebjørnen': ('skadebjørn',),
'skadebjørnene': ('skadebjørn',),
'skadebjørner': ('skadebjørn',),
'skadebot': ('skadebot',),
'skadebota': ('skadebot',),
'skadeboten': ('skadebot',),
'skadebøtene': ('skadebot',),
'skadebøter': ('skadebot',),
'skadedyr': ('skadedyr',),
'skadedyra': ('skadedyr',),
'skadedyrene': ('skadedyr',),
'skadedyret': ('skadedyr',),
'skadeeld': ('skadeeld',),
'skadeelden': ('skadeeld',),
'skadeeldene': ('skadeeld',),
'skadeelder': ('skadeeld',),
'skadeeld': ('skadeeld',),
'skadeelden': ('skadeeld',),
'skadeeldene': ('skadeeld',),
'skadeelder': ('skadeeld',),
'skadeflom': ('skadeflom',),
'skadeflommen': ('skadeflom',),
'skadeflommene': ('skadeflom',),
'skadeflommer': ('skadeflom',),
'skadeforsikring': ('skadeforsikring',),
'skadeforsikringa': ('skadeforsikring',),
'skadeforsikringen': ('skadeforsikring',),
'skadeforsikringene': ('skadeforsikring',),
'skadeforsikringer': ('skadeforsikring',),
'skadefryd': ('skadefryd',),
'skadefryden': ('skadefryd',),
'skadefrydene': ('skadefryd',),
'skadefryder': ('skadefryd',),
'skadeild': ('skadeild',),
'skadeilden': ('skadeild',),
'skadeildene': ('skadeild',),
'skadeilder': ('skadeild',),
'skadeild': ('skadeild',),
'skadeilden': ('skadeild',),
'skadeildene': ('skadeild',),
'skadeilder': ('skadeild',),
'skadeinsekt': ('skadeinsekt',),
'skadeinsekta': ('skadeinsekt',),
'skadeinsektene': ('skadeinsekt',),
'skadeinsekter': ('skadeinsekt',),
'skadeinsektet': ('skadeinsekt',),
'skadelista': ('skadeliste',),
'skadeliste': ('skadeliste',),
'skadelisten': ('skadeliste',),
'skadelistene': ('skadeliste',),
'skadelister': ('skadeliste',),
'skademelding': ('skademelding',),
'skademeldinga': ('skademelding',),
'skademeldingen': ('skademelding',),
'skademeldingene': ('skademelding',),
'skademeldinger': ('skademelding',),
'skadeoppgjør': ('skadeoppgjør',),
'skadeoppgjøra': ('skadeoppgjør',),
'skadeoppgjørene': ('skadeoppgjør',),
'skadeoppgjøret': ('skadeoppgjør',),
'skadeserstatning': ('skadeserstatning',),
'skadeserstatninga': ('skadeserstatning',),
'skadeserstatningen': ('skadeserstatning',),
'skadeserstatningene': ('skadeserstatning',),
'skadeserstatninger': ('skadeserstatning',),
'skadetakst': ('skadetakst',),
'skadetaksten': ('skadetakst',),
'skadetakstene': ('skadetakst',),
'skadetakster': ('skadetakst',),
'skadeutbetaling': ('skadeutbetaling',),
'skadeutbetalinga': ('skadeutbetaling',),
'skadeutbetalingen': ('skadeutbetaling',),
'skadeutbetalingene': ('skadeutbetaling',),
'skadeutbetalinger': ('skadeutbetaling',),
'skadevarme': ('skadevarme',),
'skadevarmen': ('skadevarme',),
'skadevarmene': ('skadevarme',),
'skadevarmer': ('skadevarme',),
'skadeverk': ('skadeverk',),
'skadeverka': ('skadeverk',),
'skadeverkene': ('skadeverk',),
'skadeverker': ('skadeverk',),
'skadeverket': ('skadeverk',),
'skadevirkning': ('skadevirkning',),
'skadevirkninga': ('skadevirkning',),
'skadevirkningen': ('skadevirkning',),
'skadevirkningene': ('skadevirkning',),
'skadevirkninger': ('skadevirkning',),
'skadeår': ('skadeår',),
'skadeåra': ('skadeår',),
'skadeårene': ('skadeår',),
'skadeåret': ('skadeår',),
'skaffebord': ('skaffebord',),
'skaffeborda': ('skaffebord',),
'skaffebordene': ('skaffebord',),
'skaffeborder': ('skaffebord',),
'skaffebordet': ('skaffebord',),
'skafferi': ('skafferi',),
'skafferia': ('skafferi',),
'skafferiene': ('skafferi',),
'skafferier': ('skafferi',),
'skafferiet': ('skafferi',),
'skaffetøy': ('skaffetøy',),
'skaffetøya': ('skaffetøy',),
'skaffetøyene': ('skaffetøy',),
'skaffetøyet': ('skaffetøy',),
'skafott': ('skafott',),
'skafotta': ('skafott',),
'skafottene': ('skafott',),
'skafotter': ('skafott',),
'skafottet': ('skafott',),
'skaft': ('skaft',),
'skafta': ('skaft',),
'skaftene': ('skaft',),
'skafter': ('skaft',),
'skaftet': ('skaft',),
'skaftestøvel': ('skaftestøvel',),
'skaftestøvelen': ('skaftestøvel',),
'skaftestøvlene': ('skaftestøvel',),
'skaftestøvler': ('skaftestøvel',),
'skag': ('skag',),
'skaga': ('skag',),
'skagene': ('skag',),
'skaget': ('skag',),
'skage': ('skage',),
'skagen': ('skage',),
'skagene': ('skage',),
'skager': ('skage',),
'skai': ('skai',),
'skaien': ('skai',),
'skaiene': ('skai',),
'skaier': ('skai',),
'skak': ('skak',),
'skaka': ('skak',),
'skakene': ('skak',),
'skaket': ('skak',),
'skakke': ('skakke',),
'skal': ('skal',),
'skala': ('skal',),
'skalene': ('skal',),
'skalet': ('skal',),
'skal': ('skal',),
'skala': ('skal',),
'skalene': ('skal',),
'skalet': ('skal',),
'skala': ('skala',),
'skalaen': ('skala',),
'skalaene': ('skala',),
'skalaer': ('skala',),
'skalaøvelse': ('skalaøvelse',),
'skalaøvelsen': ('skalaøvelse',),
'skalaøvelsene': ('skalaøvelse',),
'skalaøvelser': ('skalaøvelse',),
'skalaøving': ('skalaøving',),
'skalaøvinga': ('skalaøving',),
'skalaøvingen': ('skalaøving',),
'skalaøvingene': ('skalaøving',),
'skalaøvinger': ('skalaøving',),
'skald': ('skald',),
'skalden': ('skald',),
'skaldene': ('skald',),
'skalder': ('skald',),
'skaldedikt': ('skaldedikt',),
'skaldedikta': ('skaldedikt',),
'skaldediktene': ('skaldedikt',),
'skaldediktet': ('skaldedikt',),
'skaldedikting': ('skaldedikting',),
'skaldediktinga': ('skaldedikting',),
'skaldediktingen': ('skaldedikting',),
'skaldediktingene': ('skaldedikting',),
'skaldediktinger': ('skaldedikting',),
'skaldediktning': ('skaldediktning',),
'skaldediktninga': ('skaldediktning',),
'skaldediktningen': ('skaldediktning',),
'skaldediktningene': ('skaldediktning',),
'skaldediktninger': ('skaldediktning',),
'skaldekvad': ('skaldekvad',),
'skaldekvada': ('skaldekvad',),
'skaldekvadene': ('skaldekvad',),
'skaldekvadet': ('skaldekvad',),
'skaldelønn': ('skaldelønn',),
'skaldelønna': ('skaldelønn',),
'skaldelønnen': ('skaldelønn',),
'skaldelønnene': ('skaldelønn',),
'skaldelønner': ('skaldelønn',),
'skaldevers': ('skaldevers',),
'skaldeversa': ('skaldevers',),
'skaldeversene': ('skaldevers',),
'skaldeverset': ('skaldevers',),
'skaldskap': ('skaldskap',),
'skaldskapen': ('skaldskap',),
'skaldskapene': ('skaldskap',),
'skaldskaper': ('skaldskap',),
'skaldyr': ('skaldyr',),
'skaldyra': ('skaldyr',),
'skaldyrene': ('skaldyr',),
'skaldyret': ('skaldyr',),
'skalk': ('skalk',),
'skalken': ('skalk',),
'skalkene': ('skalk',),
'skalker': ('skalk',),
'skalk': ('skalk',),
'skalken': ('skalk',),
'skalkene': ('skalk',),
'skalker': ('skalk',),
'skalkeskjul': ('skalkeskjul',),
'skalkeskjula': ('skalkeskjul',),
'skalkeskjulene': ('skalkeskjul',),
'skalkeskjulet': ('skalkeskjul',),
'skalkestykka': ('skalkestykke',),
'skalkestykke': ('skalkestykke',),
'skalkestykkene': ('skalkestykke',),
'skalkestykker': ('skalkestykke',),
'skalkestykket': ('skalkestykke',),
'skall': ('skall',),
'skalla': ('skall',),
'skallene': ('skall',),
'skallet': ('skall',),
'skall': ('skall',),
'skalla': ('skall',),
'skallene': ('skall',),
'skallet': ('skall',),
'skalldyr': ('skalldyr',),
'skalldyra': ('skalldyr',),
'skalldyrene': ('skalldyr',),
'skalldyret': ('skalldyr',),
'skalle': ('skalle',),
'skallen': ('skalle',),
'skallene': ('skalle',),
'skaller': ('skalle',),
'skalle': ('skalle',),
'skallen': ('skalle',),
'skallene': ('skalle',),
'skaller': ('skalle',),
'skallmur': ('skallmur',),
'skallmuren': ('skallmur',),
'skallmurene': ('skallmur',),
'skallmurer': ('skallmur',),
'skalmeia': ('skalmeie',),
'skalmeie': ('skalmeie',),
'skalmeien': ('skalmeie',),
'skalmeiene': ('skalmeie',),
'skalmeier': ('skalmeie',),
'skalmur': ('skalmur',),
'skalmuren': ('skalmur',),
'skalmurene': ('skalmur',),
'skalmurer': ('skalmur',),
'skalp': ('skalp',),
'skalpen': ('skalp',),
'skalpene': ('skalp',),
'skalper': ('skalp',),
'skalpell': ('skalpell',),
'skalpellen': ('skalpell',),
'skalpellene': ('skalpell',),
'skalpeller': ('skalpell',),
'skam': ('skam',),
'skamma': ('skam',),
'skammen': ('skam',),
'skammene': ('skam',),
'skammer': ('skam',),
'skambein': ('skambein',),
'skambeina': ('skambein',),
'skambeinene': ('skambein',),
'skambeinet': ('skambein',),
'skamben': ('skamben',),
'skambena': ('skamben',),
'skambenene': ('skamben',),
'skambenet': ('skamben',),
'skambud': ('skambud',),
'skambuda': ('skambud',),
'skambudene': ('skambud',),
'skambudet': ('skambud',),
'skamfiling': ('skamfiling',),
'skamfilinga': ('skamfiling',),
'skamfilingen': ('skamfiling',),
'skamfilingene': ('skamfiling',),
'skamfilinger': ('skamfiling',),
'skamflekk': ('skamflekk',),
'skamflekken': ('skamflekk',),
'skamflekkene': ('skamflekk',),
'skamflekker': ('skamflekk',),
'skamfølelse': ('skamfølelse',),
'skamfølelsen': ('skamfølelse',),
'skamfølelsene': ('skamfølelse',),
'skamfølelser': ('skamfølelse',),
'skamkjensla': ('skamkjensle',),
'skamkjensle': ('skamkjensle',),
'skamkjenslen': ('skamkjensle',),
'skamkjenslene': ('skamkjensle',),
'skamkjensler': ('skamkjensle',),
'skamlepe': ('skamlepe',),
'skamlepen': ('skamlepe',),
'skamlepene': ('skamlepe',),
'skamleper': ('skamlepe',),
'skamleppa': ('skamleppe',),
'skamleppe': ('skamleppe',),
'skamleppen': ('skamleppe',),
'skamleppene': ('skamleppe',),
'skamlepper': ('skamleppe',),
'skamløshet': ('skamløshet',),
'skamløsheta': ('skamløshet',),
'skamløsheten': ('skamløshet',),
'skamløshetene': ('skamløshet',),
'skamløsheter': ('skamløshet',),
'skamløysa': ('skamløyse',),
'skamløyse': ('skamløyse',),
'skamløysen': ('skamløyse',),
'skamløysene': ('skamløyse',),
'skamløyser': ('skamløyse',),
'skammekrok': ('skammekrok',),
'skammekroken': ('skammekrok',),
'skammekrokene': ('skammekrok',),
'skammekroker': ('skammekrok',),
'skamlene': ('skammel',),
'skamler': ('skammel',),
'skammel': ('skammel',),
'skammelen': ('skammel',),
'skamplett': ('skamplett',),
'skampletten': ('skamplett',),
'skamplettene': ('skamplett',),
'skampletter': ('skamplett',),
'skampris': ('skampris',),
'skamprisen': ('skampris',),
'skamprisene': ('skampris',),
'skampriser': ('skampris',),
'skamros': ('skamros',),
'skamrosen': ('skamros',),
'skamrosene': ('skamros',),
'skamroser': ('skamros',),
'skamrødme': ('skamrødme',),
'skamrødmen': ('skamrødme',),
'skamrødmene': ('skamrødme',),
'skamrødmer': ('skamrødme',),
'skamvett': ('skamvett',),
'skamvetta': ('skamvett',),
'skamvettene': ('skamvett',),
'skamvettet': ('skamvett',),
'skandale': ('skandale',),
'skandalen': ('skandale',),
'skandalene': ('skandale',),
'skandaler': ('skandale',),
'skandalepressa': ('skandalepresse',),
'skandalepresse': ('skandalepresse',),
'skandalepressen': ('skandalepresse',),
'skandalepressene': ('skandalepresse',),
'skandalepresser': ('skandalepresse',),
'skandekk': ('skandekk',),
'skandekka': ('skandekk',),
'skandekkene': ('skandekk',),
'skandekket': ('skandekk',),
'skandinav': ('skandinav',),
'skandinaven': ('skandinav',),
'skandinavene': ('skandinav',),
'skandinaver': ('skandinav',),
'skandinavisme': ('skandinavisme',),
'skandinavismen': ('skandinavisme',),
'skandinavismene': ('skandinavisme',),
'skandinavismer': ('skandinavisme',),
'skandinavist': ('skandinavist',),
'skandinavisten': ('skandinavist',),
'skandinavistene': ('skandinavist',),
'skandinavister': ('skandinavist',),
'skandinavistikk': ('skandinavistikk',),
'skandinavistikken': ('skandinavistikk',),
'skandinavistikkene': ('skandinavistikk',),
'skandinavistikker': ('skandinavistikk',),
'skank': ('skank',),
'skanken': ('skank',),
'skankene': ('skank',),
'skanker': ('skank',),
'skann': ('skann',),
'skanna': ('skann',),
'skannene': ('skann',),
'skannet': ('skann',),
'skanner': ('skanner',),
'skannere': ('skanner',),
'skanneren': ('skanner',),
'skannerer': ('skanner',),
'skannerne': ('skanner',),
'skanning': ('skanning',),
'skanninga': ('skanning',),
'skanningen': ('skanning',),
'skanningene': ('skanning',),
'skanninger': ('skanning',),
'skanse': ('skanse',),
'skansen': ('skanse',),
'skansene': ('skanse',),
'skanser': ('skanse',),
'skansegrav': ('skansegrav',),
'skansegrava': ('skansegrav',),
'skansegraven': ('skansegrav',),
'skansegravene': ('skansegrav',),
'skansegraver': ('skansegrav',),
'skansekledning': ('skansekledning',),
'skansekledninga': ('skansekledning',),
'skansekledningen': ('skansekledning',),
'skansekledningene': ('skansekledning',),
'skansekledninger': ('skansekledning',),
'skant': ('skant',),
'skanten': ('skant',),
'skantene': ('skant',),
'skanter': ('skant',),
'skantil': ('skantil',),
'skantila': ('skantil',),
'skantilene': ('skantil',),
'skantilet': ('skantil',),
'skantila': ('skantile',),
'skantile': ('skantile',),
'skantilene': ('skantile',),
'skantiler': ('skantile',),
'skantilet': ('skantile',),
'skap': ('skap',),
'skapa': ('skap',),
'skapene': ('skap',),
'skapet': ('skap',),
'skap': ('skap',),
'skapdranker': ('skapdranker',),
'skapdrankere': ('skapdranker',),
'skapdrankeren': ('skapdranker',),
'skapdrankerer': ('skapdranker',),
'skapdrankerne': ('skapdranker',),
'skapdrikker': ('skapdrikker',),
'skapdrikkere': ('skapdrikker',),
'skapdrikkeren': ('skapdrikker',),
'skapdrikkerer': ('skapdrikker',),
'skapdrikkerne': ('skapdrikker',),
'skapdør': ('skapdør',),
'skapdøra': ('skapdør',),
'skapdøren': ('skapdør',),
'skapdørene': ('skapdør',),
'skapdører': ('skapdør',),
'skapelse': ('skapelse',),
'skapelsen': ('skapelse',),
'skapelsene': ('skapelse',),
'skapelser': ('skapelse',),
'skapelsesberetning': ('skapelsesberetning',),
'skapelsesberetninga': ('skapelsesberetning',),
'skapelsesberetningen': ('skapelsesberetning',),
'skapelsesberetningene': ('skapelsesberetning',),
'skapelsesberetninger': ('skapelsesberetning',),
'skaper': ('skaper',),
'skapere': ('skaper',),
'skaperen': ('skaper',),
'skaperer': ('skaper',),
'skaperne': ('skaper',),
'skaperevna': ('skaperevne',),
'skaperevne': ('skaperevne',),
'skaperevnen': ('skaperevne',),
'skaperevnene': ('skaperevne',),
'skaperevner': ('skaperevne',),
'skapergleda': ('skaperglede',),
'skaperglede': ('skaperglede',),
'skapergleden': ('skaperglede',),
'skapergledene': ('skaperglede',),
'skapergleder': ('skaperglede',),
'skaperi': ('skaperi',),
'skaperia': ('skaperi',),
'skaperiene': ('skaperi',),
'skaperier': ('skaperi',),
'skaperiet': ('skaperi',),
'skaperkraft': ('skaperkraft',),
'skaperkrafta': ('skaperkraft',),
'skaperkraften': ('skaperkraft',),
'skaperkreftene': ('skaperkraft',),
'skaperkrefter': ('skaperkraft',),
'skaperverk': ('skaperverk',),
'skaperverka': ('skaperverk',),
'skaperverkene': ('skaperverk',),
'skaperverker': ('skaperverk',),
'skaperverket': ('skaperverk',),
'skapnad': ('skapnad',),
'skapnaden': ('skapnad',),
'skapnadene': ('skapnad',),
'skapnader': ('skapnad',),
'skapning': ('skapning',),
'skapningen': ('skapning',),
'skapningene': ('skapning',),
'skapninger': ('skapning',),
'skapseng': ('skapseng',),
'skapsenga': ('skapseng',),
'skapsengen': ('skapseng',),
'skapsengene': ('skapseng',),
'skapsenger': ('skapseng',),
'skapsprenger': ('skapsprenger',),
'skapsprengere': ('skapsprenger',),
'skapsprengeren': ('skapsprenger',),
'skapsprengerer': ('skapsprenger',),
'skapsprengerne': ('skapsprenger',),
'skaptjuv': ('skaptjuv',),
'skaptjuven': ('skaptjuv',),
'skaptjuvene': ('skaptjuv',),
'skaptjuver': ('skaptjuv',),
'skaptyv': ('skaptyv',),
'skaptyven': ('skaptyv',),
'skaptyvene': ('skaptyv',),
'skaptyver': ('skaptyv',),
'skapåpner': ('skapåpner',),
'skapåpnere': ('skapåpner',),
'skapåpneren': ('skapåpner',),
'skapåpnerer': ('skapåpner',),
'skapåpnerne': ('skapåpner',),
'skapåpning': ('skapåpning',),
'skapåpninga': ('skapåpning',),
'skapåpningen': ('skapåpning',),
'skapåpningene': ('skapåpning',),
'skapåpninger': ('skapåpning',),
'skar': ('skar',),
'skara': ('skar',),
'skarene': ('skar',),
'skaret': ('skar',),
'skar': ('skar',),
'skara': ('skar',),
'skarene': ('skar',),
'skaret': ('skar',),
'skarabeen': ('skarabé',),
'skarabeene': ('skarabé',),
'skarabeer': ('skarabé',),
'skarabé': ('skarabé',),
'skarabéen': ('skarabé',),
'skarabéene': ('skarabé',),
'skarabéer': ('skarabé',),
'skareføra': ('skareføre',),
'skareføre': ('skareføre',),
'skareførene': ('skareføre',),
'skarefører': ('skareføre',),
'skareføret': ('skareføre',),
'skareklister': ('skareklister',),
'skareklisteret': ('skareklister',),
'skareklistra': ('skareklister',),
'skareklistre': ('skareklister',),
'skareklistrene': ('skareklister',),
'skareklistret': ('skareklister',),
'skarerypa': ('skarerype',),
'skarerype': ('skarerype',),
'skarerypen': ('skarerype',),
'skarerypene': ('skarerype',),
'skareryper': ('skarerype',),
'skaresnø': ('skaresnø',),
'skaresnøen': ('skaresnø',),
'skaresnøene': ('skaresnø',),
'skaresnøer': ('skaresnø',),
'skarifikator': ('skarifikator',),
'skarifikatoren': ('skarifikator',),
'skarifikatorene': ('skarifikator',),
'skarifikatorer': ('skarifikator',),
'skark': ('skark',),
'skarken': ('skark',),
'skarkene': ('skark',),
'skarker': ('skark',),
'skarke': ('skarke',),
'skarken': ('skarke',),
'skarkene': ('skarke',),
'skarker': ('skarke',),
'skarlagen': ('skarlagen',),
'skarlagena': ('skarlagen',),
'skarlagenene': ('skarlagen',),
'skarlagenet': ('skarlagen',),
'skarlagensfeber': ('skarlagensfeber',),
'skarlagensfebere': ('skarlagensfeber',),
'skarlagensfeberen': ('skarlagensfeber',),
'skarlagensfeberer': ('skarlagensfeber',),
'skarlagensfeberne': ('skarlagensfeber',),
'skarlagensfebre': ('skarlagensfeber',),
'skarlagensfebrene': ('skarlagensfeber',),
'skarlagensfebrer': ('skarlagensfeber',),
'skarn': ('skarn',),
'skarna': ('skarn',),
'skarnene': ('skarn',),
'skarnet': ('skarn',),
'skarnbasse': ('skarnbasse',),
'skarnbassen': ('skarnbasse',),
'skarnbassene': ('skarnbasse',),
'skarnbasser': ('skarnbasse',),
'skarnsstykka': ('skarnsstykke',),
'skarnsstykke': ('skarnsstykke',),
'skarnsstykkene': ('skarnsstykke',),
'skarnsstykker': ('skarnsstykke',),
'skarnsstykket': ('skarnsstykke',),
'skarnsunge': ('skarnsunge',),
'skarnsungen': ('skarnsunge',),
'skarnsungene': ('skarnsunge',),
'skarnsunger': ('skarnsunge',),
'skarntil': ('skarntil',),
'skarntila': ('skarntil',),
'skarntilene': ('skarntil',),
'skarntilet': ('skarntil',),
'skarntila': ('skarntile',),
'skarntile': ('skarntile',),
'skarntilene': ('skarntile',),
'skarntiler': ('skarntile',),
'skarntilet': ('skarntile',),
'skarntyde': ('skarntyde',),
'skarntyden': ('skarntyde',),
'skarntydene': ('skarntyde',),
'skarntyder': ('skarntyde',),
'skarp': ('skarp',),
'skarpen': ('skarp',),
'skarpene': ('skarp',),
'skarper': ('skarp',),
'skarping': ('skarping',),
'skarpingen': ('skarping',),
'skarpingene': ('skarping',),
'skarpinger': ('skarping',),
'skarpretter': ('skarpretter',),
'skarprettere': ('skarpretter',),
'skarpretteren': ('skarpretter',),
'skarpretterer': ('skarpretter',),
'skarpretterne': ('skarpretter',),
'skarpsegler': ('skarpsegler',),
'skarpseglere': ('skarpsegler',),
'skarpsegleren': ('skarpsegler',),
'skarpseglerer': ('skarpsegler',),
'skarpseglerne': ('skarpsegler',),
'skarpseiler': ('skarpseiler',),
'skarpseilere': ('skarpseiler',),
'skarpseileren': ('skarpseiler',),
'skarpseilerer': ('skarpseiler',),
'skarpseilerne': ('skarpseiler',),
'skarpsindighet': ('skarpsindighet',),
'skarpsindigheta': ('skarpsindighet',),
'skarpsindigheten': ('skarpsindighet',),
'skarpsindighetene': ('skarpsindighet',),
'skarpsindigheter': ('skarpsindighet',),
'skarpsinn': ('skarpsinn',),
'skarpsinna': ('skarpsinn',),
'skarpsinnene': ('skarpsinn',),
'skarpsinnet': ('skarpsinn',),
'skarpskyting': ('skarpskyting',),
'skarpskytinga': ('skarpskyting',),
'skarpskytingen': ('skarpskyting',),
'skarpskytingene': ('skarpskyting',),
'skarpskytinger': ('skarpskyting',),
'skarpskytter': ('skarpskytter',),
'skarpskyttere': ('skarpskytter',),
'skarpskytteren': ('skarpskytter',),
'skarpskytterer': ('skarpskytter',),
'skarpskytterne': ('skarpskytter',),
'skarre-r': ('skarre-r',),
'skarre-r-en': ('skarre-r',),
'skarre-r-ene': ('skarre-r',),
'skarre-r-er': ('skarre-r',),
'skarv': ('skarv',),
'skarven': ('skarv',),
'skarvene': ('skarv',),
'skarver': ('skarv',),
'skarv': ('skarv',),
'skarven': ('skarv',),
'skarvene': ('skarv',),
'skarver': ('skarv',),
'skarvebåt': ('skarvebåt',),
'skarvebåten': ('skarvebåt',),
'skarvebåtene': ('skarvebåt',),
'skarvebåter': ('skarvebåt',),
'skarvemerr': ('skarvemerr',),
'skarvemerra': ('skarvemerr',),
'skarvemerren': ('skarvemerr',),
'skarvemerrene': ('skarvemerr',),
'skarvemerrer': ('skarvemerr',),
'skarvord': ('skarvord',),
'skarvorda': ('skarvord',),
'skarvordene': ('skarvord',),
'skarvordet': ('skarvord',),
'skat': ('skat',),
'skata': ('skat',),
'skatene': ('skat',),
'skatet': ('skat',),
'skate': ('skate',),
'skaten': ('skate',),
'skatene': ('skate',),
'skater': ('skate',),
'skate': ('skate',),
'skaten': ('skate',),
'skatene': ('skate',),
'skater': ('skate',),
'skatoll': ('skatoll',),
'skatolla': ('skatoll',),
'skatollene': ('skatoll',),
'skatoller': ('skatoll',),
'skatollet': ('skatoll',),
'skatt': ('skatt',),
'skatten': ('skatt',),
'skattene': ('skatt',),
'skatter': ('skatt',),
'skattebetaler': ('skattebetaler',),
'skattebetalere': ('skattebetaler',),
'skattebetaleren': ('skattebetaler',),
'skattebetalerer': ('skattebetaler',),
'skattebetalerne': ('skattebetaler',),
'skattebyrde': ('skattebyrde',),
'skattebyrden': ('skattebyrde',),
'skattebyrdene': ('skattebyrde',),
'skattebyrder': ('skattebyrde',),
'skattebør': ('skattebør',),
'skattebøra': ('skattebør',),
'skattebøren': ('skattebør',),
'skattebørene': ('skattebør',),
'skattebører': ('skattebør',),
'skatteflyktning': ('skatteflyktning',),
'skatteflyktningen': ('skatteflyktning',),
'skatteflyktningene': ('skatteflyktning',),
'skatteflyktninger': ('skatteflyktning',),
'skatteflåing': ('skatteflåing',),
'skatteflåinga': ('skatteflåing',),
'skatteflåingen': ('skatteflåing',),
'skatteflåingene': ('skatteflåing',),
'skatteflåinger': ('skatteflåing',),
'skattefogd': ('skattefogd',),
'skattefogden': ('skattefogd',),
'skattefogdene': ('skattefogd',),
'skattefogder': ('skattefogd',),
'skattefunn': ('skattefunn',),
'skattefunna': ('skattefunn',),
'skattefunnene': ('skattefunn',),
'skattefunnet': ('skattefunn',),
'skattefut': ('skattefut',),
'skattefuten': ('skattefut',),
'skattefutene': ('skattefut',),
'skattefuter': ('skattefut',),
'skattegraver': ('skattegraver',),
'skattegravere': ('skattegraver',),
'skattegraveren': ('skattegraver',),
'skattegraverer': ('skattegraver',),
'skattegraverne': ('skattegraver',),
'skattegraving': ('skattegraving',),
'skattegravinga': ('skattegraving',),
'skattegravingen': ('skattegraving',),
'skattegravingene': ('skattegraving',),
'skattegravinger': ('skattegraving',),
'skattegrunnlag': ('skattegrunnlag',),
'skattegrunnlaga': ('skattegrunnlag',),
'skattegrunnlagene': ('skattegrunnlag',),
'skattegrunnlaget': ('skattegrunnlag',),
'skatteinspektør': ('skatteinspektør',),
'skatteinspektøren': ('skatteinspektør',),
'skatteinspektørene': ('skatteinspektør',),
'skatteinspektører': ('skatteinspektør',),
'skattejakt': ('skattejakt',),
'skattejakta': ('skattejakt',),
'skattejakten': ('skattejakt',),
'skattejaktene': ('skattejakt',),
'skattejakter': ('skattejakt',),
'skatteklassa': ('skatteklasse',),
'skatteklasse': ('skatteklasse',),
'skatteklassen': ('skatteklasse',),
'skatteklassene': ('skatteklasse',),
'skatteklasser': ('skatteklasse',),
'skattekort': ('skattekort',),
'skattekorta': ('skattekort',),
'skattekortene': ('skattekort',),
'skattekortet': ('skattekort',),
'skatteletta': ('skattelette',),
'skattelette': ('skattelette',),
'skatteletten': ('skattelette',),
'skattelettene': ('skattelette',),
'skatteletter': ('skattelette',),
'skattelettelse': ('skattelettelse',),
'skattelettelsen': ('skattelettelse',),
'skattelettelsene': ('skattelettelse',),
'skattelettelser': ('skattelettelse',),
'skatteligning': ('skatteligning',),
'skatteligninga': ('skatteligning',),
'skatteligningen': ('skatteligning',),
'skatteligningene': ('skatteligning',),
'skatteligninger': ('skatteligning',),
'skattelikning': ('skattelikning',),
'skattelikninga': ('skattelikning',),
'skattelikningen': ('skattelikning',),
'skattelikningene': ('skattelikning',),
'skattelikninger': ('skattelikning',),
'skattelista': ('skatteliste',),
'skatteliste': ('skatteliste',),
'skattelisten': ('skatteliste',),
'skattelistene': ('skatteliste',),
'skattelister': ('skatteliste',),
'skattelov': ('skattelov',),
'skatteloven': ('skattelov',),
'skattelovene': ('skattelov',),
'skattelover': ('skattelov',),
'skattemanntal': ('skattemanntal',),
'skattemanntala': ('skattemanntal',),
'skattemanntalene': ('skattemanntal',),
'skattemanntalet': ('skattemanntal',),
'skattemanntall': ('skattemanntall',),
'skattemanntalla': ('skattemanntall',),
'skattemanntallene': ('skattemanntall',),
'skattemanntallet': ('skattemanntall',),
'skattenektelse': ('skattenektelse',),
'skattenektelsen': ('skattenektelse',),
'skattenektelsene': ('skattenektelse',),
'skattenektelser': ('skattenektelse',),
'skattenekting': ('skattenekting',),
'skattenektinga': ('skattenekting',),
'skattenektingen': ('skattenekting',),
'skattenektingene': ('skattenekting',),
'skattenektinger': ('skattenekting',),
'skatteobjekt': ('skatteobjekt',),
'skatteobjekta': ('skatteobjekt',),
'skatteobjektene': ('skatteobjekt',),
'skatteobjekter': ('skatteobjekt',),
'skatteobjektet': ('skatteobjekt',),
'skatteoppebørsel': ('skatteoppebørsel',),
'skatteoppebørselen': ('skatteoppebørsel',),
'skatteoppebørslene': ('skatteoppebørsel',),
'skatteoppebørsler': ('skatteoppebørsel',),
'skatteoppkrever': ('skatteoppkrever',),
'skatteoppkrevere': ('skatteoppkrever',),
'skatteoppkreveren': ('skatteoppkrever',),
'skatteoppkreverer': ('skatteoppkrever',),
'skatteoppkreverne': ('skatteoppkrever',),
'skatteordning': ('skatteordning',),
'skatteordninga': ('skatteordning',),
'skatteordningen': ('skatteordning',),
'skatteordningene': ('skatteordning',),
'skatteordninger': ('skatteordning',),
'skattepakka': ('skattepakke',),
'skattepakke': ('skattepakke',),
'skattepakken': ('skattepakke',),
'skattepakkene': ('skattepakke',),
'skattepakker': ('skattepakke',),
'skatteparadis': ('skatteparadis',),
'skatteparadisa': ('skatteparadis',),
'skatteparadisene': ('skatteparadis',),
'skatteparadiser': ('skatteparadis',),
'skatteparadiset': ('skatteparadis',),
'skattepengene': ('skattepenger',),
'skattepenger': ('skattepenger',),
'skatteprogresjon': ('skatteprogresjon',),
'skatteprogresjonen': ('skatteprogresjon',),
'skatteprogresjonene': ('skatteprogresjon',),
'skatteprogresjoner': ('skatteprogresjon',),
'skatteprosent': ('skatteprosent',),
'skatteprosenten': ('skatteprosent',),
'skatteprosentene': ('skatteprosent',),
'skatteprosenter': ('skatteprosent',),
'skattereform': ('skattereform',),
'skattereformen': ('skattereform',),
'skattereformene': ('skattereform',),
'skattereformer': ('skattereform',),
'skatterestanse': ('skatterestanse',),
'skatterestansen': ('skatterestanse',),
'skatterestansene': ('skatterestanse',),
'skatterestanser': ('skatterestanse',),
'skatterett': ('skatterett',),
'skatteretten': ('skatterett',),
'skatterettene': ('skatterett',),
'skatteretter': ('skatterett',),
'skatteseddel': ('skatteseddel',),
'skatteseddelen': ('skatteseddel',),
'skattesedlene': ('skatteseddel',),
'skattesedler': ('skatteseddel',),
'skatteskrue': ('skatteskrue',),
'skatteskruen': ('skatteskrue',),
'skatteskruene': ('skatteskrue',),
'skatteskruer': ('skatteskrue',),
'skatteskruve': ('skatteskruve',),
'skatteskruven': ('skatteskruve',),
'skatteskruvene': ('skatteskruve',),
'skatteskruver': ('skatteskruve',),
'skattesnyt': ('skattesnyt',),
'skattesnyta': ('skattesnyt',),
'skattesnytene': ('skattesnyt',),
'skattesnytet': ('skattesnyt',),
'skattesnyter': ('skattesnyter',),
'skattesnytere': ('skattesnyter',),
'skattesnyteren': ('skattesnyter',),
'skattesnyterer': ('skattesnyter',),
'skattesnyterne': ('skattesnyter',),
'skattesnyteri': ('skattesnyteri',),
'skattesnyteria': ('skattesnyteri',),
'skattesnyteriene': ('skattesnyteri',),
'skattesnyterier': ('skattesnyteri',),
'skattesnyteriet': ('skattesnyteri',),
'skattestreik': ('skattestreik',),
'skattestreiken': ('skattestreik',),
'skattestreikene': ('skattestreik',),
'skattestreiker': ('skattestreik',),
'skattesvik': ('skattesvik',),
'skattesvika': ('skattesvik',),
'skattesvikene': ('skattesvik',),
'skattesviket': ('skattesvik',),
'skattetabell': ('skattetabell',),
'skattetabellen': ('skattetabell',),
'skattetabellene': ('skattetabell',),
'skattetabeller': ('skattetabell',),
'skattetrekk': ('skattetrekk',),
'skattetrekka': ('skattetrekk',),
'skattetrekkene': ('skattetrekk',),
'skattetrekket': ('skattetrekk',),
'skattetrykk': ('skattetrykk',),
'skattetrykka': ('skattetrykk',),
'skattetrykkene': ('skattetrykk',),
'skattetrykket': ('skattetrykk',),
'skatteutjamning': ('skatteutjamning',),
'skatteutjamninga': ('skatteutjamning',),
'skatteutjamningen': ('skatteutjamning',),
'skatteutjamningene': ('skatteutjamning',),
'skatteutjamninger': ('skatteutjamning',),
'skatteutjevning': ('skatteutjevning',),
'skatteutjevninga': ('skatteutjevning',),
'skatteutjevningen': ('skatteutjevning',),
'skatteutjevningene': ('skatteutjevning',),
'skatteutjevninger': ('skatteutjevning',),
'skattevesen': ('skattevesen',),
'skattevesena': ('skattevesen',),
'skattevesenene': ('skattevesen',),
'skattevesener': ('skattevesen',),
'skattevesenet': ('skattevesen',),
'skatteyter': ('skatteyter',),
'skatteytere': ('skatteyter',),
'skatteyteren': ('skatteyter',),
'skatteyterer': ('skatteyter',),
'skatteyterne': ('skatteyter',),
'skattkammer': ('skattkammer',),
'skattkammeret': ('skattkammer',),
'skattkamra': ('skattkammer',),
'skattkamre': ('skattkammer',),
'skattkamrene': ('skattkammer',),
'skattkista': ('skattkiste',),
'skattkiste': ('skattkiste',),
'skattkisten': ('skattkiste',),
'skattkistene': ('skattkiste',),
'skattkister': ('skattkiste',),
'skattligning': ('skattligning',),
'skattligninga': ('skattligning',),
'skattligningen': ('skattligning',),
'skattligningene': ('skattligning',),
'skattligninger': ('skattligning',),
'skattlikning': ('skattlikning',),
'skattlikninga': ('skattlikning',),
'skattlikningen': ('skattlikning',),
'skattlikningene': ('skattlikning',),
'skattlikninger': ('skattlikning',),
'skattseddel': ('skattseddel',),
'skattseddelen': ('skattseddel',),
'skattsedlene': ('skattseddel',),
'skattsedler': ('skattseddel',),
'skattyter': ('skattyter',),
'skattytere': ('skattyter',),
'skattyteren': ('skattyter',),
'skattyterer': ('skattyter',),
'skattyterne': ('skattyter',),
'skattøre': ('skattøre',),
'skattøren': ('skattøre',),
'skattørene': ('skattøre',),
'skattøret': ('skattøre',),
'skaut': ('skaut',),
'skauta': ('skaut',),
'skautene': ('skaut',),
'skautet': ('skaut',),
'skaut': ('skaut',),
'skauta': ('skaut',),
'skautene': ('skaut',),
'skautet': ('skaut',),
'skaut': ('skaut',),
'skauta': ('skaut',),
'skautene': ('skaut',),
'skautet': ('skaut',),
'skav': ('skav',),
'skava': ('skav',),
'skavene': ('skav',),
'skavet': ('skav',),
'skavank': ('skavank',),
'skavanken': ('skavank',),
'skavankene': ('skavank',),
'skavanker': ('skavank',),
'skavejern': ('skavejern',),
'skavejerna': ('skavejern',),
'skavejernene': ('skavejern',),
'skavejernet': ('skavejern',),
'skavgras': ('skavgras',),
'skavgrasa': ('skavgras',),
'skavgrasene': ('skavgras',),
'skavgraset': ('skavgras',),
'skavjern': ('skavjern',),
'skavjerna': ('skavjern',),
'skavjernene': ('skavjern',),
'skavjernet': ('skavjern',),
'skavkniv': ('skavkniv',),
'skavkniven': ('skavkniv',),
'skavknivene': ('skavkniv',),
'skavkniver': ('skavkniv',),
'skavl': ('skavl',),
'skavlen': ('skavl',),
'skavlene': ('skavl',),
'skavler': ('skavl',),
'skavlefonn': ('skavlefonn',),
'skavlefonna': ('skavlefonn',),
'skavlefonnen': ('skavlefonn',),
'skavlefonnene': ('skavlefonn',),
'skavlefonner': ('skavlefonn',),
'skeet': ('skeet',),
'skeetskyting': ('skeetskyting',),
'skeetskytinga': ('skeetskyting',),
'skeetskytingen': ('skeetskyting',),
'skeetskytingene': ('skeetskyting',),
'skeetskytinger': ('skeetskyting',),
'skeiand': ('skeiand',),
'skeianda': ('skeiand',),
'skeianden': ('skeiand',),
'skeiendene': ('skeiand',),
'skeiender': ('skeiand',),
'skeiblad': ('skeiblad',),
'skeiblada': ('skeiblad',),
'skeibladene': ('skeiblad',),
'skeiblader': ('skeiblad',),
'skeibladet': ('skeiblad',),
'skeid': ('skeid',),
'skeida': ('skeid',),
'skeidene': ('skeid',),
'skeidet': ('skeid',),
'skeilag': ('skeilag',),
'skeilaga': ('skeilag',),
'skeilagene': ('skeilag',),
'skeilaget': ('skeilag',),
'skeileit': ('skeileit',),
'skeileita': ('skeileit',),
'skeileitene': ('skeileit',),
'skeileitet': ('skeileit',),
'skeileit': ('skeileit',),
'skeileita': ('skeileit',),
'skeileitene': ('skeileit',),
'skeileitet': ('skeileit',),
'skeimat': ('skeimat',),
'skeimaten': ('skeimat',),
'skeimatene': ('skeimat',),
'skeimater': ('skeimat',),
'skeisa': ('skeise',),
'skeise': ('skeise',),
'skeisen': ('skeise',),
'skeisene': ('skeise',),
'skeiser': ('skeise',),
'skeisluk': ('skeisluk',),
'skeisluken': ('skeisluk',),
'skeislukene': ('skeisluk',),
'skeisluker': ('skeisluk',),
'skeivhet': ('skeivhet',),
'skeivheta': ('skeivhet',),
'skeivheten': ('skeivhet',),
'skeivhetene': ('skeivhet',),
'skeivheter': ('skeivhet',),
'skepsis': ('skepsis',),
'skepsisen': ('skepsis',),
'skepsisene': ('skepsis',),
'skepsiser': ('skepsis',),
'skeptiker': ('skeptiker',),
'skeptikere': ('skeptiker',),
'skeptikeren': ('skeptiker',),
'skeptikerer': ('skeptiker',),
'skeptikerne': ('skeptiker',),
'skeptisisme': ('skeptisisme',),
'skeptisismen': ('skeptisisme',),
'skeptisismene': ('skeptisisme',),
'skeptisismer': ('skeptisisme',),
'sketsj': ('sketsj',),
'sketsjen': ('sketsj',),
'sketsjene': ('sketsj',),
'sketsjer': ('sketsj',),
'ski': ('ski',),
'skia': ('ski',),
'skien': ('ski',),
'skiene': ('ski',),
'skier': ('ski',),
'ski': ('ski',),
'skia': ('ski',),
'skien': ('ski',),
'skiene': ('ski',),
'skier': ('ski',),
'skibakke': ('skibakke',),
'skibakken': ('skibakke',),
'skibakkene': ('skibakke',),
'skibakker': ('skibakke',),
'skibinding': ('skibinding',),
'skibindinga': ('skibinding',),
'skibindingen': ('skibinding',),
'skibindingene': ('skibinding',),
'skibindinger': ('skibinding',),
'skidag': ('skidag',),
'skidagen': ('skidag',),
'skidagene': ('skidag',),
'skidager': ('skidag',),
'skia': ('skie',),
'skie': ('skie',),
'skien': ('skie',),
'skiene': ('skie',),
'skier': ('skie',),
'skifer': ('skifer',),
'skifere': ('skifer',),
'skiferen': ('skifer',),
'skiferer': ('skifer',),
'skiferne': ('skifer',),
'skifre': ('skifer',),
'skifrene': ('skifer',),
'skifrer': ('skifer',),
'skiferbrott': ('skiferbrott',),
'skiferbrotta': ('skiferbrott',),
'skiferbrottene': ('skiferbrott',),
'skiferbrottet': ('skiferbrott',),
'skiferbrudd': ('skiferbrudd',),
'skiferbrudda': ('skiferbrudd',),
'skiferbruddene': ('skiferbrudd',),
'skiferbruddet': ('skiferbrudd',),
'skifermel': ('skifermel',),
'skifermela': ('skifermel',),
'skifermelene': ('skifermel',),
'skifermelet': ('skifermel',),
'skifermjøl': ('skifermjøl',),
'skifermjøla': ('skifermjøl',),
'skifermjølene': ('skifermjøl',),
'skifermjølet': ('skifermjøl',),
'skiferolja': ('skiferolje',),
'skiferolje': ('skiferolje',),
'skiferoljen': ('skiferolje',),
'skiferoljene': ('skiferolje',),
'skiferoljer': ('skiferolje',),
'skiferstift': ('skiferstift',),
'skiferstiften': ('skiferstift',),
'skiferstiftene': ('skiferstift',),
'skiferstifter': ('skiferstift',),
'skifertak': ('skifertak',),
'skifertaka': ('skifertak',),
'skifertakene': ('skifertak',),
'skifertaket': ('skifertak',),
'skiflyger': ('skiflyger',),
'skiflygere': ('skiflyger',),
'skiflygeren': ('skiflyger',),
'skiflygerer': ('skiflyger',),
'skiflygerne': ('skiflyger',),
'skiflyging': ('skiflyging',),
'skiflyginga': ('skiflyging',),
'skiflygingen': ('skiflyging',),
'skiflygingene': ('skiflyging',),
'skiflyginger': ('skiflyging',),
'skiflygingsbakke': ('skiflygingsbakke',),
'skiflygingsbakken': ('skiflygingsbakke',),
'skiflygingsbakkene': ('skiflygingsbakke',),
'skiflygingsbakker': ('skiflygingsbakke',),
'skiflying': ('skiflying',),
'skiflyinga': ('skiflying',),
'skiflyingen': ('skiflying',),
'skiflyingene': ('skiflying',),
'skiflyinger': ('skiflying',),
'skift': ('skift',),
'skifta': ('skift',),
'skiftene': ('skift',),
'skiftet': ('skift',),
'skiftarbeid': ('skiftarbeid',),
'skiftarbeida': ('skiftarbeid',),
'skiftarbeidene': ('skiftarbeid',),
'skiftarbeider': ('skiftarbeid',),
'skiftarbeidet': ('skiftarbeid',),
'skiftarbeider': ('skiftarbeider',),
'skiftarbeidere': ('skiftarbeider',),
'skiftarbeideren': ('skiftarbeider',),
'skiftarbeiderer': ('skiftarbeider',),
'skiftarbeiderne': ('skiftarbeider',),
'skifta': ('skifte',),
'skifte': ('skifte',),
'skiftene': ('skifte',),
'skifter': ('skifte',),
'skiftet': ('skifte',),
'skiftelokomotiv': ('skiftelokomotiv',),
'skiftelokomotiva': ('skiftelokomotiv',),
'skiftelokomotivene': ('skiftelokomotiv',),
'skiftelokomotiver': ('skiftelokomotiv',),
'skiftelokomotivet': ('skiftelokomotiv',),
'skiftenøkkel': ('skiftenøkkel',),
'skiftenøkkelen': ('skiftenøkkel',),
'skiftenøklene': ('skiftenøkkel',),
'skiftenøkler': ('skiftenøkkel',),
'skifterett': ('skifterett',),
'skifteretten': ('skifterett',),
'skifterettene': ('skifterett',),
'skifteretter': ('skifterett',),
'skiftespor': ('skiftespor',),
'skiftespora': ('skiftespor',),
'skiftesporene': ('skiftespor',),
'skiftesporet': ('skiftespor',),
'skiftestasjon': ('skiftestasjon',),
'skiftestasjonen': ('skiftestasjon',),
'skiftestasjonene': ('skiftestasjon',),
'skiftestasjoner': ('skiftestasjon',),
'skiftning': ('skiftning',),
'skiftninga': ('skiftning',),
'skiftningen': ('skiftning',),
'skiftningene': ('skiftning',),
'skiftninger': ('skiftning',),
'skiføra': ('skiføre',),
'skiføre': ('skiføre',),
'skiførene': ('skiføre',),
'skifører': ('skiføre',),
'skiføret': ('skiføre',),
'skiføring': ('skiføring',),
'skiføringa': ('skiføring',),
'skiføringen': ('skiføring',),
'skiføringene': ('skiføring',),
'skiføringer': ('skiføring',),
'skigard': ('skigard',),
'skigarden': ('skigard',),
'skigardene': ('skigard',),
'skigarder': ('skigard',),
'skigymnas': ('skigymnas',),
'skigymnasa': ('skigymnas',),
'skigymnasene': ('skigymnas',),
'skigymnaser': ('skigymnas',),
'skigymnaset': ('skigymnas',),
'skiheis': ('skiheis',),
'skiheisen': ('skiheis',),
'skiheisene': ('skiheis',),
'skiheiser': ('skiheis',),
'skihopp': ('skihopp',),
'skihoppa': ('skihopp',),
'skihoppene': ('skihopp',),
'skihoppet': ('skihopp',),
'skihopper': ('skihopper',),
'skihoppere': ('skihopper',),
'skihopperen': ('skihopper',),
'skihopperer': ('skihopper',),
'skihopperne': ('skihopper',),
'skihopping': ('skihopping',),
'skihoppinga': ('skihopping',),
'skihoppingen': ('skihopping',),
'skihoppingene': ('skihopping',),
'skihoppinger': ('skihopping',),
'skiidrett': ('skiidrett',),
'skiidretten': ('skiidrett',),
'skiidrettene': ('skiidrett',),
'skiidretter': ('skiidrett',),
'skiinstruktør': ('skiinstruktør',),
'skiinstruktøren': ('skiinstruktør',),
'skiinstruktørene': ('skiinstruktør',),
'skiinstruktører': ('skiinstruktør',),
'skikjelke': ('skikjelke',),
'skikjelken': ('skikjelke',),
'skikjelkene': ('skikjelke',),
'skikjelker': ('skikjelke',),
'skikk': ('skikk',),
'skikken': ('skikk',),
'skikkene': ('skikk',),
'skikker': ('skikk',),
'skikkelse': ('skikkelse',),
'skikkelsen': ('skikkelse',),
'skikkelsene': ('skikkelse',),
'skikkelser': ('skikkelse',),
'skiklubb': ('skiklubb',),
'skiklubben': ('skiklubb',),
'skiklubbene': ('skiklubb',),
'skiklubber': ('skiklubb',),
'skikonge': ('skikonge',),
'skikongen': ('skikonge',),
'skikongene': ('skikonge',),
'skikonger': ('skikonge',),
'skikrets': ('skikrets',),
'skikretsen': ('skikrets',),
'skikretsene': ('skikrets',),
'skikretser': ('skikrets',),
'skilderhus': ('skilderhus',),
'skilderhusa': ('skilderhus',),
'skilderhusene': ('skilderhus',),
'skilderhuset': ('skilderhus',),
'skilderi': ('skilderi',),
'skilderia': ('skilderi',),
'skilderiene': ('skilderi',),
'skilderier': ('skilderi',),
'skilderiet': ('skilderi',),
'skildring': ('skildring',),
'skildringa': ('skildring',),
'skildringen': ('skildring',),
'skildringene': ('skildring',),
'skildringer': ('skildring',),
'skill': ('skill',),
'skillen': ('skill',),
'skillene': ('skill',),
'skiller': ('skill',),
'skilla': ('skille',),
'skille': ('skille',),
'skillene': ('skille',),
'skiller': ('skille',),
'skillet': ('skille',),
'skillelinja': ('skillelinje',),
'skillelinje': ('skillelinje',),
'skillelinjen': ('skillelinje',),
'skillelinjene': ('skillelinje',),
'skillelinjer': ('skillelinje',),
'skillemynt': ('skillemynt',),
'skillemynten': ('skillemynt',),
'skillemyntene': ('skillemynt',),
'skillemynter': ('skillemynt',),
'skilletegn': ('skilletegn',),
'skilletegna': ('skilletegn',),
'skilletegnene': ('skilletegn',),
'skilletegnet': ('skilletegn',),
'skilleveg': ('skilleveg',),
'skillevegen': ('skilleveg',),
'skillevegene': ('skilleveg',),
'skilleveger': ('skilleveg',),
'skillevegg': ('skillevegg',),
'skilleveggen': ('skillevegg',),
'skilleveggene': ('skillevegg',),
'skillevegger': ('skillevegg',),
'skillevei': ('skillevei',),
'skilleveien': ('skillevei',),
'skilleveiene': ('skillevei',),
'skilleveier': ('skillevei',),
'skilling': ('skilling',),
'skillingen': ('skilling',),
'skillingene': ('skilling',),
'skillinger': ('skilling',),
'skillingsblad': ('skillingsblad',),
'skillingsblada': ('skillingsblad',),
'skillingsbladene': ('skillingsblad',),
'skillingsblader': ('skillingsblad',),
'skillingsbladet': ('skillingsblad',),
'skillingsbolle': ('skillingsbolle',),
'skillingsbollen': ('skillingsbolle',),
'skillingsbollene': ('skillingsbolle',),
'skillingsboller': ('skillingsbolle',),
'skillingskaka': ('skillingskake',),
'skillingskake': ('skillingskake',),
'skillingskaken': ('skillingskake',),
'skillingskakene': ('skillingskake',),
'skillingskaker': ('skillingskake',),
'skillingsmagasin': ('skillingsmagasin',),
'skillingsmagasina': ('skillingsmagasin',),
'skillingsmagasinene': ('skillingsmagasin',),
'skillingsmagasiner': ('skillingsmagasin',),
'skillingsmagasinet': ('skillingsmagasin',),
'skillingstrykk': ('skillingstrykk',),
'skillingstrykka': ('skillingstrykk',),
'skillingstrykkene': ('skillingstrykk',),
'skillingstrykket': ('skillingstrykk',),
'skillingsvisa': ('skillingsvise',),
'skillingsvise': ('skillingsvise',),
'skillingsvisen': ('skillingsvise',),
'skillingsvisene': ('skillingsvise',),
'skillingsviser': ('skillingsvise',),
'skilnad': ('skilnad',),
'skilnaden': ('skilnad',),
'skilnadene': ('skilnad',),
'skilnader': ('skilnad',),
'skilpadda': ('skilpadde',),
'skilpadde': ('skilpadde',),
'skilpadden': ('skilpadde',),
'skilpaddene': ('skilpadde',),
'skilpadder': ('skilpadde',),
'skilsmisse': ('skilsmisse',),
'skilsmissen': ('skilsmisse',),
'skilsmissene': ('skilsmisse',),
'skilsmisser': ('skilsmisse',),
'skilsmissebegjæring': ('skilsmissebegjæring',),
'skilsmissebegjæringa': ('skilsmissebegjæring',),
'skilsmissebegjæringen': ('skilsmissebegjæring',),
'skilsmissebegjæringene': ('skilsmissebegjæring',),
'skilsmissebegjæringer': ('skilsmissebegjæring',),
'skilsmissedom': ('skilsmissedom',),
'skilsmissedommen': ('skilsmissedom',),
'skilsmissedommene': ('skilsmissedom',),
'skilsmissedommer': ('skilsmissedom',),
'skilsmissegrunn': ('skilsmissegrunn',),
'skilsmissegrunnen': ('skilsmissegrunn',),
'skilsmissegrunnene': ('skilsmissegrunn',),
'skilsmissegrunner': ('skilsmissegrunn',),
'skilsmål': ('skilsmål',),
'skilsmåla': ('skilsmål',),
'skilsmålene': ('skilsmål',),
'skilsmålet': ('skilsmål',),
'skilt': ('skilt',),
'skilta': ('skilt',),
'skiltene': ('skilt',),
'skilter': ('skilt',),
'skiltet': ('skilt',),
'skiltvakt': ('skiltvakt',),
'skiltvakta': ('skiltvakt',),
'skiltvakten': ('skiltvakt',),
'skiltvaktene': ('skiltvakt',),
'skiltvakter': ('skiltvakt',),
'skilåm': ('skilåm',),
'skilåma': ('skilåm',),
'skilåmen': ('skilåm',),
'skilåmene': ('skilåm',),
'skilåmer': ('skilåm',),
'skilærer': ('skilærer',),
'skilærere': ('skilærer',),
'skilæreren': ('skilærer',),
'skilærerer': ('skilærer',),
'skilærerne': ('skilærer',),
'skiløper': ('skiløper',),
'skiløpere': ('skiløper',),
'skiløperen': ('skiløper',),
'skiløperer': ('skiløper',),
'skiløperne': ('skiløper',),
'skiløperkompani': ('skiløperkompani',),
'skiløperkompania': ('skiløperkompani',),
'skiløperkompaniene': ('skiløperkompani',),
'skiløperkompanier': ('skiløperkompani',),
'skiløperkompaniet': ('skiløperkompani',),
'skiløping': ('skiløping',),
'skiløpinga': ('skiløping',),
'skiløpingen': ('skiløping',),
'skiløpingene': ('skiløping',),
'skiløpinger': ('skiløping',),
'skiløypa': ('skiløype',),
'skiløype': ('skiløype',),
'skiløypen': ('skiløype',),
'skiløypene': ('skiløype',),
'skiløyper': ('skiløype',),
'skimerka': ('skimerke',),
'skimerke': ('skimerke',),
'skimerkene': ('skimerke',),
'skimerker': ('skimerke',),
'skimerket': ('skimerke',),
'skimla': ('skimle',),
'skimle': ('skimle',),
'skimlen': ('skimle',),
'skimlene': ('skimle',),
'skimler': ('skimle',),
'skimmer': ('skimmer',),
'skimmera': ('skimmer',),
'skimmerene': ('skimmer',),
'skimmeret': ('skimmer',),
'skimra': ('skimmer',),
'skimre': ('skimmer',),
'skimrene': ('skimmer',),
'skimt': ('skimt',),
'skimta': ('skimt',),
'skimten': ('skimt',),
'skimtene': ('skimt',),
'skimtet': ('skimt',),
'skin-diving': ('skin-diving',),
'skin-divingen': ('skin-diving',),
'skin-divingene': ('skin-diving',),
'skin-divinger': ('skin-diving',),
'skinka': ('skinke',),
'skinke': ('skinke',),
'skinken': ('skinke',),
'skinkene': ('skinke',),
'skinker': ('skinke',),
'skinkeerma': ('skinkeerme',),
'skinkeerme': ('skinkeerme',),
'skinkeermene': ('skinkeerme',),
'skinkeermer': ('skinkeerme',),
'skinkeermet': ('skinkeerme',),
'skinkemusling': ('skinkemusling',),
'skinkemuslingen': ('skinkemusling',),
'skinkemuslingene': ('skinkemusling',),
'skinkemuslinger': ('skinkemusling',),
'skinkeskjell': ('skinkeskjell',),
'skinkeskjella': ('skinkeskjell',),
'skinkeskjellen': ('skinkeskjell',),
'skinkeskjellene': ('skinkeskjell',),
'skinkeskjellet': ('skinkeskjell',),
'skinkesteik': ('skinkesteik',),
'skinkesteika': ('skinkesteik',),
'skinkesteiken': ('skinkesteik',),
'skinkesteikene': ('skinkesteik',),
'skinkesteiker': ('skinkesteik',),
'skinkestek': ('skinkestek',),
'skinkesteka': ('skinkestek',),
'skinkesteken': ('skinkestek',),
'skinkestekene': ('skinkestek',),
'skinkesteker': ('skinkestek',),
'skinnbevis': ('skinnbevis',),
'skinnbevisa': ('skinnbevis',),
'skinnbevisene': ('skinnbevis',),
'skinnbeviser': ('skinnbevis',),
'skinnbeviset': ('skinnbevis',),
'skinnbind': ('skinnbind',),
'skinnbinda': ('skinnbind',),
'skinnbindene': ('skinnbind',),
'skinnbindet': ('skinnbind',),
'skinnbrev': ('skinnbrev',),
'skinnbreva': ('skinnbrev',),
'skinnbrevene': ('skinnbrev',),
'skinnbrever': ('skinnbrev',),
'skinnbrevet': ('skinnbrev',),
'skinndemokrati': ('skinndemokrati',),
'skinndemokratia': ('skinndemokrati',),
'skinndemokratiene': ('skinndemokrati',),
'skinndemokratier': ('skinndemokrati',),
'skinndemokratiet': ('skinndemokrati',),
'skinna': ('skinne',),
'skinne': ('skinne',),
'skinnen': ('skinne',),
'skinnene': ('skinne',),
'skinner': ('skinne',),
'skinnebein': ('skinnebein',),
'skinnebeina': ('skinnebein',),
'skinnebeinene': ('skinnebein',),
'skinnebeinet': ('skinnebein',),
'skinneben': ('skinneben',),
'skinnebena': ('skinneben',),
'skinnebenene': ('skinneben',),
'skinnebenet': ('skinneben',),
'skinnebuss': ('skinnebuss',),
'skinnebussen': ('skinnebuss',),
'skinnebussene': ('skinnebuss',),
'skinnebusser': ('skinnebuss',),
'skinnegang': ('skinnegang',),
'skinnegangen': ('skinnegang',),
'skinnegangene': ('skinnegang',),
'skinneganger': ('skinnegang',),
'skinnegg': ('skinnegg',),
'skinnegga': ('skinnegg',),
'skinneggene': ('skinnegg',),
'skinnegget': ('skinnegg',),
'skinnelegg': ('skinnelegg',),
'skinneleggen': ('skinnelegg',),
'skinneleggene': ('skinnelegg',),
'skinnelegger': ('skinnelegg',),
'skinnfell': ('skinnfell',),
'skinnfellen': ('skinnfell',),
'skinnfellene': ('skinnfell',),
'skinnfeller': ('skinnfell',),
'skinnhellighet': ('skinnhellighet',),
'skinnhelligheta': ('skinnhellighet',),
'skinnhelligheten': ('skinnhellighet',),
'skinnhellighetene': ('skinnhellighet',),
'skinnhelligheter': ('skinnhellighet',),
'skinnkåpa': ('skinnkåpe',),
'skinnkåpe': ('skinnkåpe',),
'skinnkåpen': ('skinnkåpe',),
'skinnkåpene': ('skinnkåpe',),
'skinnkåper': ('skinnkåpe',),
'skinnmanøver': ('skinnmanøver',),
'skinnmanøvere': ('skinnmanøver',),
'skinnmanøveren': ('skinnmanøver',),
'skinnmanøverne': ('skinnmanøver',),
'skinnmanøvre': ('skinnmanøver',),
'skinnmanøvrene': ('skinnmanøver',),
'skinnmanøvrer': ('skinnmanøver',),
'skinnrygg': ('skinnrygg',),
'skinnryggen': ('skinnrygg',),
'skinnryggene': ('skinnrygg',),
'skinnrygger': ('skinnrygg',),
'skinnsyka': ('skinnsyke',),
'skinnsyke': ('skinnsyke',),
'skinnsyken': ('skinnsyke',),
'skinnsykene': ('skinnsyke',),
'skinnsyker': ('skinnsyke',),
'skinntryta': ('skinntryte',),
'skinntryte': ('skinntryte',),
'skinntryten': ('skinntryte',),
'skinntrytene': ('skinntryte',),
'skinntryter': ('skinntryte',),
'skinnveng': ('skinnveng',),
'skinnvengen': ('skinnveng',),
'skinnvengene': ('skinnveng',),
'skinnvenger': ('skinnveng',),
'skiorientering': ('skiorientering',),
'skiorienteringa': ('skiorientering',),
'skiorienteringen': ('skiorientering',),
'skiorienteringene': ('skiorientering',),
'skiorienteringer': ('skiorientering',),
'skip': ('skip',),
'skipa': ('skip',),
'skipene': ('skip',),
'skipet': ('skip',),
'skipbrott': ('skipbrott',),
'skipbrotta': ('skipbrott',),
'skipbrottene': ('skipbrott',),
'skipbrottet': ('skipbrott',),
'skipbrudd': ('skipbrudd',),
'skipbrudda': ('skipbrudd',),
'skipbruddene': ('skipbrudd',),
'skipbruddet': ('skipbrudd',),
'skipnad': ('skipnad',),
'skipnaden': ('skipnad',),
'skipnadene': ('skipnad',),
'skipnader': ('skipnad',),
'skipning': ('skipning',),
'skipninga': ('skipning',),
'skipningen': ('skipning',),
'skipningene': ('skipning',),
'skipninger': ('skipning',),
'skipper': ('skipper',),
'skippere': ('skipper',),
'skipperen': ('skipper',),
'skipperer': ('skipper',),
'skipperne': ('skipper',),
'skippersertifikat': ('skippersertifikat',),
'skippersertifikata': ('skippersertifikat',),
'skippersertifikatene': ('skippersertifikat',),
'skippersertifikater': ('skippersertifikat',),
'skippersertifikatet': ('skippersertifikat',),
'skipperskjønn': ('skipperskjønn',),
'skipperskjønna': ('skipperskjønn',),
'skipperskjønnene': ('skipperskjønn',),
'skipperskjønnet': ('skipperskjønn',),
'skipperskrøna': ('skipperskrøne',),
'skipperskrøne': ('skipperskrøne',),
'skipperskrønen': ('skipperskrøne',),
'skipperskrønene': ('skipperskrøne',),
'skipperskrøner': ('skipperskrøne',),
'skippertak': ('skippertak',),
'skippertaka': ('skippertak',),
'skippertakene': ('skippertak',),
'skippertaket': ('skippertak',),
'skippund': ('skippund',),
'skippunda': ('skippund',),
'skippundene': ('skippund',),
'skippundet': ('skippund',),
'skipreida': ('skipreide',),
'skipreide': ('skipreide',),
'skipreiden': ('skipreide',),
'skipreidene': ('skipreide',),
'skipreider': ('skipreide',),
'skipreidet': ('skipreide',),
'skipsaksje': ('skipsaksje',),
'skipsaksjen': ('skipsaksje',),
'skipsaksjene': ('skipsaksje',),
'skipsaksjer': ('skipsaksje',),
'skipsavgift': ('skipsavgift',),
'skipsavgifta': ('skipsavgift',),
'skipsavgiften': ('skipsavgift',),
'skipsavgiftene': ('skipsavgift',),
'skipsavgifter': ('skipsavgift',),
'skipsbefal': ('skipsbefal',),
'skipsbefala': ('skipsbefal',),
'skipsbefalene': ('skipsbefal',),
'skipsbefalet': ('skipsbefal',),
'skipsbesetning': ('skipsbesetning',),
'skipsbesetninga': ('skipsbesetning',),
'skipsbesetningen': ('skipsbesetning',),
'skipsbesetningene': ('skipsbesetning',),
'skipsbesetninger': ('skipsbesetning',),
'skipsbord': ('skipsbord',),
'skipsborda': ('skipsbord',),
'skipsbordene': ('skipsbord',),
'skipsborder': ('skipsbord',),
'skipsbordet': ('skipsbord',),
'skipsbygger': ('skipsbygger',),
'skipsbyggere': ('skipsbygger',),
'skipsbyggeren': ('skipsbygger',),
'skipsbyggerer': ('skipsbygger',),
'skipsbyggerne': ('skipsbygger',),
'skipsbyggeri': ('skipsbyggeri',),
'skipsbyggeria': ('skipsbyggeri',),
'skipsbyggeriene': ('skipsbyggeri',),
'skipsbyggerier': ('skipsbyggeri',),
'skipsbyggeriet': ('skipsbyggeri',),
'skipsdekk': ('skipsdekk',),
'skipsdekka': ('skipsdekk',),
'skipsdekkene': ('skipsdekk',),
'skipsdekket': ('skipsdekk',),
'skipsfart': ('skipsfart',),
'skipsfarten': ('skipsfart',),
'skipsfartene': ('skipsfart',),
'skipsfarter': ('skipsfart',),
'skipsfartsinspektør': ('skipsfartsinspektør',),
'skipsfartsinspektøren': ('skipsfartsinspektør',),
'skipsfartsinspektørene': ('skipsfartsinspektør',),
'skipsfartsinspektører': ('skipsfartsinspektør',),
'skipsfolk': ('skipsfolk',),
'skipsfolka': ('skipsfolk',),
'skipsfolkene': ('skipsfolk',),
'skipsfolket': ('skipsfolk',),
'skipsfrakt': ('skipsfrakt',),
'skipsfrakta': ('skipsfrakt',),
'skipsfrakten': ('skipsfrakt',),
'skipsfraktene': ('skipsfrakt',),
'skipsfrakter': ('skipsfrakt',),
'skipsfører': ('skipsfører',),
'skipsførere': ('skipsfører',),
'skipsføreren': ('skipsfører',),
'skipsførerer': ('skipsfører',),
'skipsførerne': ('skipsfører',),
'skipsførereksamen': ('skipsførereksamen',),
'skipsførereksamenen': ('skipsførereksamen',),
'skipsførereksamenene': ('skipsførereksamen',),
'skipsførereksamener': ('skipsførereksamen',),
'skipsførersertifikat': ('skipsførersertifikat',),
'skipsførersertifikata': ('skipsførersertifikat',),
'skipsførersertifikatene': ('skipsførersertifikat',),
'skipsførersertifikater': ('skipsførersertifikat',),
'skipsførersertifikatet': ('skipsførersertifikat',),
'skipsgast': ('skipsgast',),
'skipsgasten': ('skipsgast',),
'skipsgastene': ('skipsgast',),
'skipsgaster': ('skipsgast',),
'skipsgrav': ('skipsgrav',),
'skipsgrava': ('skipsgrav',),
'skipsgraven': ('skipsgrav',),
'skipsgravene': ('skipsgrav',),
'skipsgraver': ('skipsgrav',),
'skipsgutt': ('skipsgutt',),
'skipsgutten': ('skipsgutt',),
'skipsguttene': ('skipsgutt',),
'skipsgutter': ('skipsgutt',),
'skipshandel': ('skipshandel',),
'skipshandelen': ('skipshandel',),
'skipshandlene': ('skipshandel',),
'skipshandler': ('skipshandel',),
'skipshavari': ('skipshavari',),
'skipshavaria': ('skipshavari',),
'skipshavariene': ('skipshavari',),
'skipshavarier': ('skipshavari',),
'skipshavariet': ('skipshavari',),
'skipshud': ('skipshud',),
'skipshuda': ('skipshud',),
'skipshuden': ('skipshud',),
'skipshudene': ('skipshud',),
'skipshuder': ('skipshud',),
'skipshund': ('skipshund',),
'skipshunden': ('skipshund',),
'skipshundene': ('skipshund',),
'skipshunder': ('skipshund',),
'skipsingeniør': ('skipsingeniør',),
'skipsingeniøren': ('skipsingeniør',),
'skipsingeniørene': ('skipsingeniør',),
'skipsingeniører': ('skipsingeniør',),
'skipsinspektør': ('skipsinspektør',),
'skipsinspektøren': ('skipsinspektør',),
'skipsinspektørene': ('skipsinspektør',),
'skipsinspektører': ('skipsinspektør',),
'skipsjournal': ('skipsjournal',),
'skipsjournalen': ('skipsjournal',),
'skipsjournalene': ('skipsjournal',),
'skipsjournaler': ('skipsjournal',),
'skipskanal': ('skipskanal',),
'skipskanalen': ('skipskanal',),
'skipskanalene': ('skipskanal',),
'skipskanaler': ('skipskanal',),
'skipskaptein': ('skipskaptein',),
'skipskapteinen': ('skipskaptein',),
'skipskapteinene': ('skipskaptein',),
'skipskapteiner': ('skipskaptein',),
'skipskatt': ('skipskatt',),
'skipskatten': ('skipskatt',),
'skipskattene': ('skipskatt',),
'skipskatter': ('skipskatt',),
'skipskavring': ('skipskavring',),
'skipskavringen': ('skipskavring',),
'skipskavringene': ('skipskavring',),
'skipskavringer': ('skipskavring',),
'skipskista': ('skipskiste',),
'skipskiste': ('skipskiste',),
'skipskisten': ('skipskiste',),
'skipskistene': ('skipskiste',),
'skipskister': ('skipskiste',),
'skipskjeks': ('skipskjeks',),
'skipskjeksen': ('skipskjeks',),
'skipskjeksene': ('skipskjeks',),
'skipskjel': ('skipskjel',),
'skipskjelen': ('skipskjel',),
'skipskjelene': ('skipskjel',),
'skipskjeler': ('skipskjel',),
'skipskjele': ('skipskjele',),
'skipskjelen': ('skipskjele',),
'skipskjelene': ('skipskjele',),
'skipskjeler': ('skipskjele',),
'skipsklokka': ('skipsklokke',),
'skipsklokke': ('skipsklokke',),
'skipsklokken': ('skipsklokke',),
'skipsklokkene': ('skipsklokke',),
'skipsklokker': ('skipsklokke',),
'skipskontroll': ('skipskontroll',),
'skipskontrollen': ('skipskontroll',),
'skipskontrollene': ('skipskontroll',),
'skipskontroller': ('skipskontroll',),
'skipsladning': ('skipsladning',),
'skipsladninga': ('skipsladning',),
'skipsladningen': ('skipsladning',),
'skipsladningene': ('skipsladning',),
'skipsladninger': ('skipsladning',),
'skipslast': ('skipslast',),
'skipslasta': ('skipslast',),
'skipslasten': ('skipslast',),
'skipslastene': ('skipslast',),
'skipslaster': ('skipslast',),
'skipslege': ('skipslege',),
'skipslegen': ('skipslege',),
'skipslegene': ('skipslege',),
'skipsleger': ('skipslege',),
'skipslei': ('skipslei',),
'skipsleia': ('skipslei',),
'skipsleien': ('skipslei',),
'skipsleiene': ('skipslei',),
'skipsleier': ('skipslei',),
'skipsleilighet': ('skipsleilighet',),
'skipsleiligheta': ('skipsleilighet',),
'skipsleiligheten': ('skipsleilighet',),
'skipsleilighetene': ('skipsleilighet',),
'skipsleiligheter': ('skipsleilighet',),
'skipslengda': ('skipslengde',),
'skipslengde': ('skipslengde',),
'skipslengden': ('skipslengde',),
'skipslengdene': ('skipslengde',),
'skipslengder': ('skipslengde',),
'skipsluka': ('skipsluke',),
'skipsluke': ('skipsluke',),
'skipsluken': ('skipsluke',),
'skipslukene': ('skipsluke',),
'skipsluker': ('skipsluke',),
'skipsmaling': ('skipsmaling',),
'skipsmalinga': ('skipsmaling',),
'skipsmalingen': ('skipsmaling',),
'skipsmalingene': ('skipsmaling',),
'skipsmalinger': ('skipsmaling',),
'skipsmannskap': ('skipsmannskap',),
'skipsmannskapa': ('skipsmannskap',),
'skipsmannskapene': ('skipsmannskap',),
'skipsmannskaper': ('skipsmannskap',),
'skipsmannskapet': ('skipsmannskap',),
'skipsmegler': ('skipsmegler',),
'skipsmeglere': ('skipsmegler',),
'skipsmegleren': ('skipsmegler',),
'skipsmeglerer': ('skipsmegler',),
'skipsmeglerne': ('skipsmegler',),
'skipsmekler': ('skipsmekler',),
'skipsmeklere': ('skipsmekler',),
'skipsmekleren': ('skipsmekler',),
'skipsmeklerer': ('skipsmekler',),
'skipsmeklerne': ('skipsmekler',),
'skipsnagle': ('skipsnagle',),
'skipsnaglen': ('skipsnagle',),
'skipsnaglene': ('skipsnagle',),
'skipsnagler': ('skipsnagle',),
'skipsnisse': ('skipsnisse',),
'skipsnissen': ('skipsnisse',),
'skipsnissene': ('skipsnisse',),
'skipsnisser': ('skipsnisse',),
'skipsoffiser': ('skipsoffiser',),
'skipsoffiseren': ('skipsoffiser',),
'skipsoffiserene': ('skipsoffiser',),
'skipsoffiserer': ('skipsoffiser',),
'skipspapir': ('skipspapir',),
'skipspapira': ('skipspapir',),
'skipspapirene': ('skipspapir',),
'skipspapirer': ('skipspapir',),
'skipspapiret': ('skipspapir',),
'skipsplanke': ('skipsplanke',),
'skipsplanken': ('skipsplanke',),
'skipsplankene': ('skipsplanke',),
'skipsplanker': ('skipsplanke',),
'skipsplata': ('skipsplate',),
'skipsplate': ('skipsplate',),
'skipsplaten': ('skipsplate',),
'skipsplatene': ('skipsplate',),
'skipsplater': ('skipsplate',),
'skipsproviant': ('skipsproviant',),
'skipsprovianten': ('skipsproviant',),
'skipsproviantene': ('skipsproviant',),
'skipsprovianter': ('skipsproviant',),
'skipsreder': ('skipsreder',),
'skipsredere': ('skipsreder',),
'skipsrederen': ('skipsreder',),
'skipsrederer': ('skipsreder',),
'skipsrederne': ('skipsreder',),
'skipsrederi': ('skipsrederi',),
'skipsrederia': ('skipsrederi',),
'skipsrederiene': ('skipsrederi',),
'skipsrederier': ('skipsrederi',),
'skipsrederiet': ('skipsrederi',),
'skipsregister': ('skipsregister',),
'skipsregisteret': ('skipsregister',),
'skipsregistra': ('skipsregister',),
'skipsregistre': ('skipsregister',),
'skipsregistrene': ('skipsregister',),
'skipsregistret': ('skipsregister',),
'skipsråd': ('skipsråd',),
'skipsråda': ('skipsråd',),
'skipsrådene': ('skipsråd',),
'skipsrådet': ('skipsråd',),
'skipssekk': ('skipssekk',),
'skipssekken': ('skipssekk',),
'skipssekkene': ('skipssekk',),
'skipssekker': ('skipssekk',),
'skipssetning': ('skipssetning',),
'skipssetninga': ('skipssetning',),
'skipssetningen': ('skipssetning',),
'skipssetningene': ('skipssetning',),
'skipssetninger': ('skipssetning',),
'skipstrafikk': ('skipstrafikk',),
'skipstrafikken': ('skipstrafikk',),
'skipstrafikkene': ('skipstrafikk',),
'skipstrafikker': ('skipstrafikk',),
'skipstømmer': ('skipstømmer',),
'skipstømmera': ('skipstømmer',),
'skipstømmerene': ('skipstømmer',),
'skipstømmeret': ('skipstømmer',),
'skipstømra': ('skipstømmer',),
'skipstømre': ('skipstømmer',),
'skipstømrene': ('skipstømmer',),
'skipsur': ('skipsur',),
'skipsura': ('skipsur',),
'skipsurene': ('skipsur',),
'skipsuret': ('skipsur',),
'skipsverft': ('skipsverft',),
'skipsverfta': ('skipsverft',),
'skipsverftene': ('skipsverft',),
'skipsverftet': ('skipsverft',),
'skipsvrak': ('skipsvrak',),
'skipsvraka': ('skipsvrak',),
'skipsvrakene': ('skipsvrak',),
'skipsvraket': ('skipsvrak',),
'skirenn': ('skirenn',),
'skirenna': ('skirenn',),
'skirennene': ('skirenn',),
'skirennet': ('skirenn',),
'skiskyting': ('skiskyting',),
'skiskytinga': ('skiskyting',),
'skiskytingen': ('skiskyting',),
'skiskytingene': ('skiskyting',),
'skiskytinger': ('skiskyting',),
'skiskytter': ('skiskytter',),
'skiskyttere': ('skiskytter',),
'skiskytteren': ('skiskytter',),
'skiskytterer': ('skiskytter',),
'skiskytterne': ('skiskytter',),
'skisma': ('skisma',),
'skismaene': ('skisma',),
'skismaer': ('skisma',),
'skismaet': ('skisma',),
'skismatiker': ('skismatiker',),
'skismatikere': ('skismatiker',),
'skismatikeren': ('skismatiker',),
'skismatikerer': ('skismatiker',),
'skismatikerne': ('skismatiker',),
'skismurning': ('skismurning',),
'skismurninga': ('skismurning',),
'skismurningen': ('skismurning',),
'skismurningene': ('skismurning',),
'skismurninger': ('skismurning',),
'skismøring': ('skismøring',),
'skismøringa': ('skismøring',),
'skismøringen': ('skismøring',),
'skismøringene': ('skismøring',),
'skismøringer': ('skismøring',),
'skispor': ('skispor',),
'skispora': ('skispor',),
'skisporene': ('skispor',),
'skisporet': ('skispor',),
'skisport': ('skisport',),
'skisporten': ('skisport',),
'skisportene': ('skisport',),
'skisporter': ('skisport',),
'skissa': ('skisse',),
'skisse': ('skisse',),
'skissen': ('skisse',),
'skissene': ('skisse',),
'skisser': ('skisse',),
'skistav': ('skistav',),
'skistaven': ('skistav',),
'skistavene': ('skistav',),
'skistaver': ('skistav',),
'skistøvel': ('skistøvel',),
'skistøvelen': ('skistøvel',),
'skistøvlene': ('skistøvel',),
'skistøvler': ('skistøvel',),
'skitrekk': ('skitrekk',),
'skitrekka': ('skitrekk',),
'skitrekkene': ('skitrekk',),
'skitrekket': ('skitrekk',),
'skitrener': ('skitrener',),
'skitrenere': ('skitrener',),
'skitreneren': ('skitrener',),
'skitrenerer': ('skitrener',),
'skitrenerne': ('skitrener',),
'skitt': ('skitt',),
'skitten': ('skitt',),
'skittene': ('skitt',),
'skitter': ('skitt',),
'skittentøy': ('skittentøy',),
'skittentøya': ('skittentøy',),
'skittentøyene': ('skittentøy',),
'skittentøyer': ('skittentøy',),
'skittentøyet': ('skittentøy',),
'skittentøyvask': ('skittentøyvask',),
'skittentøyvasken': ('skittentøyvask',),
'skittentøyvaskene': ('skittentøyvask',),
'skittentøyvasker': ('skittentøyvask',),
'skittkjeft': ('skittkjeft',),
'skittkjeften': ('skittkjeft',),
'skittkjeftene': ('skittkjeft',),
'skittkjefter': ('skittkjeft',),
'skittord': ('skittord',),
'skittorda': ('skittord',),
'skittordene': ('skittord',),
'skittordet': ('skittord',),
'skittstøvel': ('skittstøvel',),
'skittstøvelen': ('skittstøvel',),
'skittstøvlene': ('skittstøvel',),
'skittstøvler': ('skittstøvel',),
'skittunge': ('skittunge',),
'skittungen': ('skittunge',),
'skittungene': ('skittunge',),
'skittunger': ('skittunge',),
'skitupp': ('skitupp',),
'skituppen': ('skitupp',),
'skituppene': ('skitupp',),
'skitupper': ('skitupp',),
'skitur': ('skitur',),
'skituren': ('skitur',),
'skiturene': ('skitur',),
'skiturer': ('skitur',),
'skiva': ('skive',),
'skive': ('skive',),
'skiven': ('skive',),
'skivene': ('skive',),
'skiver': ('skive',),
'skivebom': ('skivebom',),
'skivebommen': ('skivebom',),
'skivebommene': ('skivebom',),
'skivebommer': ('skivebom',),
'skivebrems': ('skivebrems',),
'skivebremsen': ('skivebrems',),
'skivebremsene': ('skivebrems',),
'skivebremser': ('skivebrems',),
'skivebremsa': ('skivebremse',),
'skivebremse': ('skivebremse',),
'skivebremsen': ('skivebremse',),
'skivebremsene': ('skivebremse',),
'skivebremser': ('skivebremse',),
'skived': ('skived',),
'skiveden': ('skived',),
'skivedene': ('skived',),
'skiveder': ('skived',),
'skiveharv': ('skiveharv',),
'skiveharva': ('skiveharv',),
'skiveharven': ('skiveharv',),
'skiveharvene': ('skiveharv',),
'skiveharver': ('skiveharv',),
'skivehus': ('skivehus',),
'skivehusa': ('skivehus',),
'skivehusene': ('skivehus',),
'skivehuset': ('skivehus',),
'skivesopp': ('skivesopp',),
'skivesoppen': ('skivesopp',),
'skivesoppene': ('skivesopp',),
'skivesopper': ('skivesopp',),
'skivoks': ('skivoks',),
'skivoksa': ('skivoks',),
'skivoksen': ('skivoks',),
'skivoksene': ('skivoks',),
'skivokser': ('skivoks',),
'skivokset': ('skivoks',),
'skje': ('skje',),
'skjea': ('skje',),
'skjeen': ('skje',),
'skjeene': ('skje',),
'skjeer': ('skje',),
'skjeand': ('skjeand',),
'skjeanda': ('skjeand',),
'skjeanden': ('skjeand',),
'skjeendene': ('skjeand',),
'skjeender': ('skjeand',),
'skjebba': ('skjebbe',),
'skjebbe': ('skjebbe',),
'skjebben': ('skjebbe',),
'skjebbene': ('skjebbe',),
'skjebber': ('skjebbe',),
'skjeblad': ('skjeblad',),
'skjeblada': ('skjeblad',),
'skjebladene': ('skjeblad',),
'skjeblader': ('skjeblad',),
'skjebladet': ('skjeblad',),
'skjebne': ('skjebne',),
'skjebnen': ('skjebne',),
'skjebnene': ('skjebne',),
'skjebner': ('skjebne',),
'skjebnedrama': ('skjebnedrama',),
'skjebnedramaene': ('skjebnedrama',),
'skjebnedramaer': ('skjebnedrama',),
'skjebnedramaet': ('skjebnedrama',),
'skjebnegudinna': ('skjebnegudinne',),
'skjebnegudinne': ('skjebnegudinne',),
'skjebnegudinnen': ('skjebnegudinne',),
'skjebnegudinnene': ('skjebnegudinne',),
'skjebnegudinner': ('skjebnegudinne',),
'skjebnetime': ('skjebnetime',),
'skjebnetimen': ('skjebnetime',),
'skjebnetimene': ('skjebnetime',),
'skjebnetimer': ('skjebnetime',),
'skjebnetro': ('skjebnetro',),
'skjebnetroa': ('skjebnetro',),
'skjebnetroen': ('skjebnetro',),
'skjebnetroene': ('skjebnetro',),
'skjebnetroer': ('skjebnetro',),
'skjede': ('skjede',),
'skjeden': ('skjede',),
'skjedene': ('skjede',),
'skjeder': ('skjede',),
'skjedehornfamilie': ('skjedehornfamilie',),
'skjedehornfamilien': ('skjedehornfamilie',),
'skjedehornfamiliene': ('skjedehornfamilie',),
'skjedehornfamilier': ('skjedehornfamilie',),
'skjefta': ('skjefte',),
'skjefte': ('skjefte',),
'skjeftene': ('skjefte',),
'skjefter': ('skjefte',),
'skjeftet': ('skjefte',),
'skjegg': ('skjegg',),
'skjeggen': ('skjegg',),
'skjeggene': ('skjegg',),
'skjegger': ('skjegg',),
'skjegg': ('skjegg',),
'skjegga': ('skjegg',),
'skjeggene': ('skjegg',),
'skjegget': ('skjegg',),
'skjegg-gran': ('skjegg-gran',),
'skjegg-grana': ('skjegg-gran',),
'skjegg-granen': ('skjegg-gran',),
'skjegg-granene': ('skjegg-gran',),
'skjegg-graner': ('skjegg-gran',),
'skjeggapa': ('skjeggape',),
'skjeggape': ('skjeggape',),
'skjeggapen': ('skjeggape',),
'skjeggapene': ('skjeggape',),
'skjeggaper': ('skjeggape',),
'skjeggbuse': ('skjeggbuse',),
'skjeggbusen': ('skjeggbuse',),
'skjeggbusene': ('skjeggbuse',),
'skjeggbuser': ('skjeggbuse',),
'skjegglav': ('skjegglav',),
'skjegglava': ('skjegglav',),
'skjegglavene': ('skjegglav',),
'skjegglavet': ('skjegglav',),
'skjeggran': ('skjeggran',),
'skjeggrana': ('skjeggran',),
'skjeggranen': ('skjeggran',),
'skjeggranene': ('skjeggran',),
'skjeggraner': ('skjeggran',),
'skjeggrot': ('skjeggrot',),
'skjeggrota': ('skjeggrot',),
'skjeggroten': ('skjeggrot',),
'skjeggrøttene': ('skjeggrot',),
'skjeggrøtter': ('skjeggrot',),
'skjeggsopp': ('skjeggsopp',),
'skjeggsoppen': ('skjeggsopp',),
'skjeggsoppene': ('skjeggsopp',),
'skjeggsopper': ('skjeggsopp',),
'skjeggstubb': ('skjeggstubb',),
'skjeggstubben': ('skjeggstubb',),
'skjeggstubbene': ('skjeggstubb',),
'skjeggstubber': ('skjeggstubb',),
'skjeggtorsk': ('skjeggtorsk',),
'skjeggtorsken': ('skjeggtorsk',),
'skjeggtorskene': ('skjeggtorsk',),
'skjeggtorsker': ('skjeggtorsk',),
'skjeggvekst': ('skjeggvekst',),
'skjeggveksten': ('skjeggvekst',),
'skjeggvekstene': ('skjeggvekst',),
'skjeggvekster': ('skjeggvekst',),
'skjelag': ('skjelag',),
'skjelaga': ('skjelag',),
'skjelagene': ('skjelag',),
'skjelaget': ('skjelag',),
'skjelebrilla': ('skjelebrille',),
'skjelebrille': ('skjelebrille',),
'skjelebrillen': ('skjelebrille',),
'skjelebrillene': ('skjelebrille',),
'skjelebriller': ('skjelebrille',),
'skjeleoperasjon': ('skjeleoperasjon',),
'skjeleoperasjonen': ('skjeleoperasjon',),
'skjeleoperasjonene': ('skjeleoperasjon',),
'skjeleoperasjoner': ('skjeleoperasjon',),
'skjelett': ('skjelett',),
'skjeletta': ('skjelett',),
'skjelettene': ('skjelett',),
'skjeletter': ('skjelett',),
'skjelettet': ('skjelett',),
'skjeling': ('skjeling',),
'skjelinga': ('skjeling',),
'skjelingen': ('skjeling',),
'skjelingene': ('skjeling',),
'skjelinger': ('skjeling',),
'skjell': ('skjell',),
'skjella': ('skjell',),
'skjellen': ('skjell',),
'skjellene': ('skjell',),
'skjellet': ('skjell',),
'skjell-lakk': ('skjell-lakk',),
'skjell-lakken': ('skjell-lakk',),
'skjell-lakkene': ('skjell-lakk',),
'skjell-lakker': ('skjell-lakk',),
'skjellakk': ('skjellakk',),
'skjellakken': ('skjellakk',),
'skjellakkene': ('skjellakk',),
'skjellakker': ('skjellakk',),
'skjellbanke': ('skjellbanke',),
'skjellbanken': ('skjellbanke',),
'skjellbankene': ('skjellbanke',),
'skjellbanker': ('skjellbanke',),
'skjellbrosma': ('skjellbrosme',),
'skjellbrosme': ('skjellbrosme',),
'skjellbrosmen': ('skjellbrosme',),
'skjellbrosmene': ('skjellbrosme',),
'skjellbrosmer': ('skjellbrosme',),
'skjelldyr': ('skjelldyr',),
'skjelldyra': ('skjelldyr',),
'skjelldyrene': ('skjelldyr',),
'skjelldyret': ('skjelldyr',),
'skjellfinnefisk': ('skjellfinnefisk',),
'skjellfinnefisken': ('skjellfinnefisk',),
'skjellfinnefiskene': ('skjellfinnefisk',),
'skjellfinnefisker': ('skjellfinnefisk',),
'skjellrot': ('skjellrot',),
'skjellrota': ('skjellrot',),
'skjellroten': ('skjellrot',),
'skjellrotene': ('skjellrot',),
'skjellrygg': ('skjellrygg',),
'skjellryggen': ('skjellrygg',),
'skjellryggene': ('skjellrygg',),
'skjellrygger': ('skjellrygg',),
'skjellsand': ('skjellsand',),
'skjellsanden': ('skjellsand',),
'skjellsandene': ('skjellsand',),
'skjellsander': ('skjellsand',),
'skjellsopp': ('skjellsopp',),
'skjellsoppen': ('skjellsopp',),
'skjellsoppene': ('skjellsopp',),
'skjellsopper': ('skjellsopp',),
'skjellsord': ('skjellsord',),
'skjellsorda': ('skjellsord',),
'skjellsordene': ('skjellsord',),
'skjellsordet': ('skjellsord',),
'skjelm': ('skjelm',),
'skjelmen': ('skjelm',),
'skjelmene': ('skjelm',),
'skjelmer': ('skjelm',),
'skjelm': ('skjelm',),
'skjelmen': ('skjelm',),
'skjelmene': ('skjelm',),
'skjelmer': ('skjelm',),
'skjelmeri': ('skjelmeri',),
'skjelmeria': ('skjelmeri',),
'skjelmeriene': ('skjelmeri',),
'skjelmerier': ('skjelmeri',),
'skjelmeriet': ('skjelmeri',),
'skjelmsstykka': ('skjelmsstykke',),
'skjelmsstykke': ('skjelmsstykke',),
'skjelmsstykkene': ('skjelmsstykke',),
'skjelmsstykker': ('skjelmsstykke',),
'skjelmsstykket': ('skjelmsstykke',),
'skjeltreka': ('skjeltreke',),
'skjeltreke': ('skjeltreke',),
'skjeltreken': ('skjeltreke',),
'skjeltrekene': ('skjeltreke',),
'skjeltreker': ('skjeltreke',),
'skjelv': ('skjelv',),
'skjelven': ('skjelv',),
'skjelvene': ('skjelv',),
'skjelver': ('skjelv',),
'skjelv': ('skjelv',),
'skjelva': ('skjelv',),
'skjelvene': ('skjelv',),
'skjelvet': ('skjelv',),
'skjelvelamhet': ('skjelvelamhet',),
'skjelvelamheta': ('skjelvelamhet',),
'skjelvelamheten': ('skjelvelamhet',),
'skjelvelamhetene': ('skjelvelamhet',),
'skjelvelamheter': ('skjelvelamhet',),
'skjelvetone': ('skjelvetone',),
'skjelvetonen': ('skjelvetone',),
'skjelvetonene': ('skjelvetone',),
'skjelvetoner': ('skjelvetone',),
'skjema': ('skjema',),
'skjemaene': ('skjema',),
'skjemaer': ('skjema',),
'skjemaet': ('skjema',),
'skjemat': ('skjemat',),
'skjematen': ('skjemat',),
'skjematene': ('skjemat',),
'skjemater': ('skjemat',),
'skjematenkning': ('skjematenkning',),
'skjematenkninga': ('skjematenkning',),
'skjematenkningen': ('skjematenkning',),
'skjematenkningene': ('skjematenkning',),
'skjematenkninger': ('skjematenkning',),
'skjematisme': ('skjematisme',),
'skjematismen': ('skjematisme',),
'skjematismene': ('skjematisme',),
'skjematismer': ('skjematisme',),
'skjemavelda': ('skjemavelde',),
'skjemavelde': ('skjemavelde',),
'skjemaveldene': ('skjemavelde',),
'skjemavelder': ('skjemavelde',),
'skjemaveldet': ('skjemavelde',),
'skjemt': ('skjemt',),
'skjemten': ('skjemt',),
'skjemtene': ('skjemt',),
'skjemter': ('skjemt',),
'skjemtedikt': ('skjemtedikt',),
'skjemtedikta': ('skjemtedikt',),
'skjemtediktene': ('skjemtedikt',),
'skjemtediktet': ('skjemtedikt',),
'skjemtegauk': ('skjemtegauk',),
'skjemtegauken': ('skjemtegauk',),
'skjemtegaukene': ('skjemtegauk',),
'skjemtegauker': ('skjemtegauk',),
'skjemtevisa': ('skjemtevise',),
'skjemtevise': ('skjemtevise',),
'skjemtevisen': ('skjemtevise',),
'skjemtevisene': ('skjemtevise',),
'skjemteviser': ('skjemtevise',),
'skjemtord': ('skjemtord',),
'skjemtorda': ('skjemtord',),
'skjemtordene': ('skjemtord',),
'skjemtordet': ('skjemtord',),
'skjen': ('skjen',),
'skjena': ('skjen',),
'skjenene': ('skjen',),
'skjenet': ('skjen',),
'skjender': ('skjender',),
'skjendere': ('skjender',),
'skjenderen': ('skjender',),
'skjenderer': ('skjender',),
'skjenderne': ('skjender',),
'skjendighet': ('skjendighet',),
'skjendigheta': ('skjendighet',),
'skjendigheten': ('skjendighet',),
'skjendighetene': ('skjendighet',),
'skjendigheter': ('skjendighet',),
'skjenebrett': ('skjenebrett',),
'skjenebretta': ('skjenebrett',),
'skjenebrettene': ('skjenebrett',),
'skjenebretter': ('skjenebrett',),
'skjenebrettet': ('skjenebrett',),
'skjenk': ('skjenk',),
'skjenken': ('skjenk',),
'skjenkene': ('skjenk',),
'skjenker': ('skjenk',),
'skjenkebevilling': ('skjenkebevilling',),
'skjenkebevillingen': ('skjenkebevilling',),
'skjenkebevillingene': ('skjenkebevilling',),
'skjenkebevillinger': ('skjenkebevilling',),
'skjenkedisk': ('skjenkedisk',),
'skjenkedisken': ('skjenkedisk',),
'skjenkediskene': ('skjenkedisk',),
'skjenkedisker': ('skjenkedisk',),
'skjenkerett': ('skjenkerett',),
'skjenkeretten': ('skjenkerett',),
'skjenkerettene': ('skjenkerett',),
'skjenkeretter': ('skjenkerett',),
'skjenkested': ('skjenkested',),
'skjenkestedene': ('skjenkested',),
'skjenkesteder': ('skjenkested',),
'skjenkestedet': ('skjenkested',),
'skjenkestova': ('skjenkestove',),
'skjenkestove': ('skjenkestove',),
'skjenkestoven': ('skjenkestove',),
'skjenkestovene': ('skjenkestove',),
'skjenkestover': ('skjenkestove',),
'skjenkestua': ('skjenkestue',),
'skjenkestue': ('skjenkestue',),
'skjenkestuen': ('skjenkestue',),
'skjenkestuene': ('skjenkestue',),
'skjenkestuer': ('skjenkestue',),
'skjenn': ('skjenn',),
'skjenna': ('skjenn',),
'skjennene': ('skjenn',),
'skjennet': ('skjenn',),
'skjennepreken': ('skjennepreken',),
'skjenneprekenen': ('skjennepreken',),
'skjenneprekenene': ('skjennepreken',),
'skjenneprekener': ('skjennepreken',),
'skjensel': ('skjensel',),
'skjenselen': ('skjensel',),
'skjenslene': ('skjensel',),
'skjensler': ('skjensel',),
'skjenselsgjerning': ('skjenselsgjerning',),
'skjenselsgjerninga': ('skjenselsgjerning',),
'skjenselsgjerningen': ('skjenselsgjerning',),
'skjenselsgjerningene': ('skjenselsgjerning',),
'skjenselsgjerninger': ('skjenselsgjerning',),
'skjeppa': ('skjeppe',),
'skjeppe': ('skjeppe',),
'skjeppen': ('skjeppe',),
'skjeppene': ('skjeppe',),
'skjepper': ('skjeppe',),
'skjerding': ('skjerding',),
'skjerdingen': ('skjerding',),
'skjerdingene': ('skjerding',),
'skjerdinger': ('skjerding',),
'skjerf': ('skjerf',),
'skjerfa': ('skjerf',),
'skjerfene': ('skjerf',),
'skjerfet': ('skjerf',),
'skjerm': ('skjerm',),
'skjermen': ('skjerm',),
'skjermene': ('skjerm',),
'skjermer': ('skjerm',),
'skjermbilda': ('skjermbilde',),
'skjermbilde': ('skjermbilde',),
'skjermbildene': ('skjermbilde',),
'skjermbilder': ('skjermbilde',),
'skjermbildet': ('skjermbilde',),
'skjermbildefotografering': ('skjermbildefotografering',),
'skjermbildefotograferinga': ('skjermbildefotografering',),
'skjermbildefotograferingen': ('skjermbildefotografering',),
'skjermbildefotograferingene': ('skjermbildefotografering',),
'skjermbildefotograferinger': ('skjermbildefotografering',),
'skjermbrett': ('skjermbrett',),
'skjermbretta': ('skjermbrett',),
'skjermbrettene': ('skjermbrett',),
'skjermbretter': ('skjermbrett',),
'skjermbrettet': ('skjermbrett',),
'skjermpilot': ('skjermpilot',),
'skjermpiloten': ('skjermpilot',),
'skjermpilotene': ('skjermpilot',),
'skjermpiloter': ('skjermpilot',),
'skjermplanta': ('skjermplante',),
'skjermplante': ('skjermplante',),
'skjermplanten': ('skjermplante',),
'skjermplantene': ('skjermplante',),
'skjermplanter': ('skjermplante',),
'skjermplantefamilie': ('skjermplantefamilie',),
'skjermplantefamilien': ('skjermplantefamilie',),
'skjermplantefamiliene': ('skjermplantefamilie',),
'skjermplantefamilier': ('skjermplantefamilie',),
'skjermvegg': ('skjermvegg',),
'skjermveggen': ('skjermvegg',),
'skjermveggene': ('skjermvegg',),
'skjermvegger': ('skjermvegg',),
'skjerp': ('skjerp',),
'skjerpa': ('skjerp',),
'skjerpene': ('skjerp',),
'skjerpet': ('skjerp',),
'skjerp': ('skjerp',),
'skjerpa': ('skjerp',),
'skjerpene': ('skjerp',),
'skjerpet': ('skjerp',),
'skjerpelse': ('skjerpelse',),
'skjerpelsen': ('skjerpelse',),
'skjerpelsene': ('skjerpelse',),
'skjerpelser': ('skjerpelse',),
'skjerper': ('skjerper',),
'skjerpere': ('skjerper',),
'skjerperen': ('skjerper',),
'skjerperer': ('skjerper',),
'skjerperne': ('skjerper',),
'skjerv': ('skjerv',),
'skjerven': ('skjerv',),
'skjervene': ('skjerv',),
'skjerver': ('skjerv',),
'skjesluk': ('skjesluk',),
'skjesluken': ('skjesluk',),
'skjeslukene': ('skjesluk',),
'skjesluker': ('skjesluk',),
'skjevann': ('skjevann',),
'skjevanna': ('skjevann',),
'skjevannene': ('skjevann',),
'skjevannet': ('skjevann',),
'skjevatn': ('skjevatn',),
'skjevatna': ('skjevatn',),
'skjevatnene': ('skjevatn',),
'skjevatnet': ('skjevatn',),
'skjevhet': ('skjevhet',),
'skjevheta': ('skjevhet',),
'skjevheten': ('skjevhet',),
'skjevhetene': ('skjevhet',),
'skjevheter': ('skjevhet',),
'skjold': ('skjold',),
'skjolden': ('skjold',),
'skjoldene': ('skjold',),
'skjolder': ('skjold',),
'skjold': ('skjold',),
'skjolda': ('skjold',),
'skjoldene': ('skjold',),
'skjoldet': ('skjold',),
'skjoldbille': ('skjoldbille',),
'skjoldbillen': ('skjoldbille',),
'skjoldbillene': ('skjoldbille',),
'skjoldbiller': ('skjoldbille',),
'skjoldborg': ('skjoldborg',),
'skjoldborga': ('skjoldborg',),
'skjoldborgen': ('skjoldborg',),
'skjoldborgene': ('skjoldborg',),
'skjoldborger': ('skjoldborg',),
'skjoldbrusk': ('skjoldbrusk',),
'skjoldbrusken': ('skjoldbrusk',),
'skjoldbruskene': ('skjoldbrusk',),
'skjoldbrusker': ('skjoldbrusk',),
'skjoldbruskkjertel': ('skjoldbruskkjertel',),
'skjoldbruskkjertelen': ('skjoldbruskkjertel',),
'skjoldbruskkjertlene': ('skjoldbruskkjertel',),
'skjoldbruskkjertler': ('skjoldbruskkjertel',),
'skjoldkjertel': ('skjoldkjertel',),
'skjoldkjertelen': ('skjoldkjertel',),
'skjoldkjertlene': ('skjoldkjertel',),
'skjoldkjertler': ('skjoldkjertel',),
'skjoldlus': ('skjoldlus',),
'skjoldlusa': ('skjoldlus',),
'skjoldlusen': ('skjoldlus',),
'skjoldlusene': ('skjoldlus',),
'skjoldmerka': ('skjoldmerke',),
'skjoldmerke': ('skjoldmerke',),
'skjoldmerkene': ('skjoldmerke',),
'skjoldmerker': ('skjoldmerke',),
'skjoldmerket': ('skjoldmerke',),
'skjoldmøy': ('skjoldmøy',),
'skjoldmøya': ('skjoldmøy',),
'skjoldmøyen': ('skjoldmøy',),
'skjoldmøyene': ('skjoldmøy',),
'skjoldmøyer': ('skjoldmøy',),
'skjor': ('skjor',),
'skjora': ('skjor',),
'skjoren': ('skjor',),
'skjorene': ('skjor',),
'skjorer': ('skjor',),
'skjorereda': ('skjorerede',),
'skjorerede': ('skjorerede',),
'skjoreredene': ('skjorerede',),
'skjorereder': ('skjorerede',),
'skjoreredet': ('skjorerede',),
'skjorereir': ('skjorereir',),
'skjorereira': ('skjorereir',),
'skjorereirene': ('skjorereir',),
'skjorereiret': ('skjorereir',),
'skjorta': ('skjorte',),
'skjorte': ('skjorte',),
'skjorten': ('skjorte',),
'skjortene': ('skjorte',),
'skjorter': ('skjorte',),
'skjortebryst': ('skjortebryst',),
'skjortebrysta': ('skjortebryst',),
'skjortebrystene': ('skjortebryst',),
'skjortebrystet': ('skjortebryst',),
'skjorteerma': ('skjorteerme',),
'skjorteerme': ('skjorteerme',),
'skjorteermene': ('skjorteerme',),
'skjorteermer': ('skjorteerme',),
'skjorteermet': ('skjorteerme',),
'skjorteflak': ('skjorteflak',),
'skjorteflaka': ('skjorteflak',),
'skjorteflakene': ('skjorteflak',),
'skjorteflaket': ('skjorteflak',),
'skjorterma': ('skjorterme',),
'skjorterme': ('skjorterme',),
'skjortermene': ('skjorterme',),
'skjortermer': ('skjorterme',),
'skjortermet': ('skjorterme',),
'skjul': ('skjul',),
'skjula': ('skjul',),
'skjulene': ('skjul',),
'skjulet': ('skjul',),
'skjulespråk': ('skjulespråk',),
'skjulespråka': ('skjulespråk',),
'skjulespråkene': ('skjulespråk',),
'skjulespråket': ('skjulespråk',),
'skjulested': ('skjulested',),
'skjulestedene': ('skjulested',),
'skjulesteder': ('skjulested',),
'skjulestedet': ('skjulested',),
'skjå': ('skjå',),
'skjåen': ('skjå',),
'skjåene': ('skjå',),
'skjåer': ('skjå',),
'skjå': ('skjå',),
'skjåen': ('skjå',),
'skjåene': ('skjå',),
'skjåer': ('skjå',),
'skjålykt': ('skjålykt',),
'skjålykta': ('skjålykt',),
'skjålykten': ('skjålykt',),
'skjålyktene': ('skjålykt',),
'skjålykter': ('skjålykt',),
'skjåskinn': ('skjåskinn',),
'skjåskinna': ('skjåskinn',),
'skjåskinnene': ('skjåskinn',),
'skjåskinnet': ('skjåskinn',),
'skjær': ('skjær',),
'skjæra': ('skjær',),
'skjærene': ('skjær',),
'skjæret': ('skjær',),
'skjær': ('skjær',),
'skjæra': ('skjær',),
'skjærene': ('skjær',),
'skjæret': ('skjær',),
'skjær': ('skjær',),
'skjæra': ('skjær',),
'skjærene': ('skjær',),
'skjæret': ('skjær',),
'skjæra': ('skjære',),
'skjære': ('skjære',),
'skjæren': ('skjære',),
'skjærene': ('skjære',),
'skjærer': ('skjære',),
'skjærebrenner': ('skjærebrenner',),
'skjærebrennere': ('skjærebrenner',),
'skjærebrenneren': ('skjærebrenner',),
'skjærebrennerer': ('skjærebrenner',),
'skjærebrennerne': ('skjærebrenner',),
'skjærefjel': ('skjærefjel',),
'skjærefjela': ('skjærefjel',),
'skjærefjelen': ('skjærefjel',),
'skjærefjelene': ('skjærefjel',),
'skjærefjeler': ('skjærefjel',),
'skjærefjøl': ('skjærefjøl',),
'skjærefjøla': ('skjærefjøl',),
'skjærefjølen': ('skjærefjøl',),
'skjærefjølene': ('skjærefjøl',),
'skjærefjøler': ('skjærefjøl',),
'skjærehoda': ('skjærehode',),
'skjærehode': ('skjærehode',),
'skjærehodene': ('skjærehode',),
'skjærehoder': ('skjærehode',),
'skjærehodet': ('skjærehode',),
'skjærer': ('skjærer',),
'skjærere': ('skjærer',),
'skjæreren': ('skjærer',),
'skjærerer': ('skjærer',),
'skjærerne': ('skjærer',),
'skjærereda': ('skjærerede',),
'skjærerede': ('skjærerede',),
'skjæreredene': ('skjærerede',),
'skjærereder': ('skjærerede',),
'skjæreredet': ('skjærerede',),
'skjærereir': ('skjærereir',),
'skjærereira': ('skjærereir',),
'skjærereirene': ('skjærereir',),
'skjærereiret': ('skjærereir',),
'skjærgard': ('skjærgard',),
'skjærgarden': ('skjærgard',),
'skjærgardene': ('skjærgard',),
'skjærgarder': ('skjærgard',),
'skjærgård': ('skjærgård',),
'skjærgården': ('skjærgård',),
'skjærgårdene': ('skjærgård',),
'skjærgårder': ('skjærgård',),
'skjæring': ('skjæring',),
'skjæringa': ('skjæring',),
'skjæringen': ('skjæring',),
'skjæringene': ('skjæring',),
'skjæringer': ('skjæring',),
'skjæringslinja': ('skjæringslinje',),
'skjæringslinje': ('skjæringslinje',),
'skjæringslinjen': ('skjæringslinje',),
'skjæringslinjene': ('skjæringslinje',),
'skjæringslinjer': ('skjæringslinje',),
'skjæringspunkt': ('skjæringspunkt',),
'skjæringspunkta': ('skjæringspunkt',),
'skjæringspunktene': ('skjæringspunkt',),
'skjæringspunkter': ('skjæringspunkt',),
'skjæringspunktet': ('skjæringspunkt',),
'skjærmyslene': ('skjærmyssel',),
'skjærmysler': ('skjærmyssel',),
'skjærmyssel': ('skjærmyssel',),
'skjærmysselen': ('skjærmyssel',),
'skjærseld': ('skjærseld',),
'skjærselden': ('skjærseld',),
'skjærseldene': ('skjærseld',),
'skjærselder': ('skjærseld',),
'skjærsild': ('skjærsild',),
'skjærsilden': ('skjærsild',),
'skjærsildene': ('skjærsild',),
'skjærsilder': ('skjærsild',),
'skjærsliper': ('skjærsliper',),
'skjærslipere': ('skjærsliper',),
'skjærsliperen': ('skjærsliper',),
'skjærsliperer': ('skjærsliper',),
'skjærsliperne': ('skjærsliper',),
'skjærsmin': ('skjærsmin',),
'skjærsminen': ('skjærsmin',),
'skjærsminene': ('skjærsmin',),
'skjærsminer': ('skjærsmin',),
'skjærsommer': ('skjærsommer',),
'skjærsommere': ('skjærsommer',),
'skjærsommeren': ('skjærsommer',),
'skjærsommerne': ('skjærsommer',),
'skjærsomre': ('skjærsommer',),
'skjærsomrene': ('skjærsommer',),
'skjærsomrer': ('skjærsommer',),
'skjærtorsdag': ('skjærtorsdag',),
'skjærtorsdagen': ('skjærtorsdag',),
'skjærtorsdagene': ('skjærtorsdag',),
'skjærtorsdager': ('skjærtorsdag',),
'skjød': ('skjød',),
'skjøda': ('skjød',),
'skjødene': ('skjød',),
'skjødet': ('skjød',),
'skjødehund': ('skjødehund',),
'skjødehunden': ('skjødehund',),
'skjødehundene': ('skjødehund',),
'skjødehunder': ('skjødehund',),
'skjødesløshet': ('skjødesløshet',),
'skjødesløsheta': ('skjødesløshet',),
'skjødesløsheten': ('skjødesløshet',),
'skjødesløshetene': ('skjødesløshet',),
'skjødesløsheter': ('skjødesløshet',),
'skjøga': ('skjøge',),
'skjøge': ('skjøge',),
'skjøgen': ('skjøge',),
'skjøgene': ('skjøge',),
'skjøger': ('skjøge',),
'skjønn': ('skjønn',),
'skjønna': ('skjønn',),
'skjønnene': ('skjønn',),
'skjønnet': ('skjønn',),
'skjønner': ('skjønner',),
'skjønnere': ('skjønner',),
'skjønneren': ('skjønner',),
'skjønnerer': ('skjønner',),
'skjønnerne': ('skjønner',),
'skjønnhet': ('skjønnhet',),
'skjønnheta': ('skjønnhet',),
'skjønnheten': ('skjønnhet',),
'skjønnhetene': ('skjønnhet',),
'skjønnheter': ('skjønnhet',),
'skjønnhetsdronning': ('skjønnhetsdronning',),
'skjønnhetsdronninga': ('skjønnhetsdronning',),
'skjønnhetsdronningen': ('skjønnhetsdronning',),
'skjønnhetsdronningene': ('skjønnhetsdronning',),
'skjønnhetsdronninger': ('skjønnhetsdronning',),
'skjønnhetsfeil': ('skjønnhetsfeil',),
'skjønnhetsfeilen': ('skjønnhetsfeil',),
'skjønnhetsfeilene': ('skjønnhetsfeil',),
'skjønnhetskonkurranse': ('skjønnhetskonkurranse',),
'skjønnhetskonkurransen': ('skjønnhetskonkurranse',),
'skjønnhetskonkurransene': ('skjønnhetskonkurranse',),
'skjønnhetskonkurranser': ('skjønnhetskonkurranse',),
'skjønnhetskur': ('skjønnhetskur',),
'skjønnhetskuren': ('skjønnhetskur',),
'skjønnhetskurene': ('skjønnhetskur',),
'skjønnhetskurer': ('skjønnhetskur',),
'skjønnhetsmiddel': ('skjønnhetsmiddel',),
'skjønnhetsmiddelet': ('skjønnhetsmiddel',),
'skjønnhetsmidla': ('skjønnhetsmiddel',),
'skjønnhetsmidlene': ('skjønnhetsmiddel',),
'skjønnhetsmidler': ('skjønnhetsmiddel',),
'skjønnhetsmidlet': ('skjønnhetsmiddel',),
'skjønnhetspleia': ('skjønnhetspleie',),
'skjønnhetspleie': ('skjønnhetspleie',),
'skjønnhetspleien': ('skjønnhetspleie',),
'skjønnhetspleiene': ('skjønnhetspleie',),
'skjønnhetspleier': ('skjønnhetspleie',),
'skjønnhetsplett': ('skjønnhetsplett',),
'skjønnhetspletten': ('skjønnhetsplett',),
'skjønnhetsplettene': ('skjønnhetsplett',),
'skjønnhetspletter': ('skjønnhetsplett',),
'skjønnhetssans': ('skjønnhetssans',),
'skjønnhetssansen': ('skjønnhetssans',),
'skjønnhetssansene': ('skjønnhetssans',),
'skjønnhetssanser': ('skjønnhetssans',),
'skjønnhetsverdi': ('skjønnhetsverdi',),
'skjønnhetsverdien': ('skjønnhetsverdi',),
'skjønnhetsverdiene': ('skjønnhetsverdi',),
'skjønnhetsverdier': ('skjønnhetsverdi',),
'skjønnhetsåpenbaring': ('skjønnhetsåpenbaring',),
'skjønnhetsåpenbaringa': ('skjønnhetsåpenbaring',),
'skjønnhetsåpenbaringen': ('skjønnhetsåpenbaring',),
'skjønnhetsåpenbaringene': ('skjønnhetsåpenbaring',),
'skjønnhetsåpenbaringer': ('skjønnhetsåpenbaring',),
'skjønnlitteratur': ('skjønnlitteratur',),
'skjønnlitteraturen': ('skjønnlitteratur',),
'skjønnlitteraturene': ('skjønnlitteratur',),
'skjønnlitteraturer': ('skjønnlitteratur',),
'skjønnmaleri': ('skjønnmaleri',),
'skjønnmaleria': ('skjønnmaleri',),
'skjønnmaleriene': ('skjønnmaleri',),
'skjønnmalerier': ('skjønnmaleri',),
'skjønnmaleriet': ('skjønnmaleri',),
'skjønnsavgjørelse': ('skjønnsavgjørelse',),
'skjønnsavgjørelsen': ('skjønnsavgjørelse',),
'skjønnsavgjørelsene': ('skjønnsavgjørelse',),
'skjønnsavgjørelser': ('skjønnsavgjørelse',),
'skjønnskrift': ('skjønnskrift',),
'skjønnskrifta': ('skjønnskrift',),
'skjønnskriften': ('skjønnskrift',),
'skjønnskriftene': ('skjønnskrift',),
'skjønnskrifter': ('skjønnskrift',),
'skjønnsligning': ('skjønnsligning',),
'skjønnsligninga': ('skjønnsligning',),
'skjønnsligningen': ('skjønnsligning',),
'skjønnsligningene': ('skjønnsligning',),
'skjønnsligninger': ('skjønnsligning',),
'skjønnslikning': ('skjønnslikning',),
'skjønnslikninga': ('skjønnslikning',),
'skjønnslikningen': ('skjønnslikning',),
'skjønnslikningene': ('skjønnslikning',),
'skjønnslikninger': ('skjønnslikning',),
'skjønnsmann': ('skjønnsmann',),
'skjønnsmannen': ('skjønnsmann',),
'skjønnsmenn': ('skjønnsmann',),
'skjønnsmennene': ('skjønnsmann',),
'skjønnsnemnd': ('skjønnsnemnd',),
'skjønnsnemnda': ('skjønnsnemnd',),
'skjønnsnemnden': ('skjønnsnemnd',),
'skjønnsnemndene': ('skjønnsnemnd',),
'skjønnsnemnder': ('skjønnsnemnd',),
'skjønnsomhet': ('skjønnsomhet',),
'skjønnsomheta': ('skjønnsomhet',),
'skjønnsomheten': ('skjønnsomhet',),
'skjønnsomhetene': ('skjønnsomhet',),
'skjønnsomheter': ('skjønnsomhet',),
'skjønnssak': ('skjønnssak',),
'skjønnssaka': ('skjønnssak',),
'skjønnssaken': ('skjønnssak',),
'skjønnssakene': ('skjønnssak',),
'skjønnssaker': ('skjønnssak',),
'skjønnsspørsmål': ('skjønnsspørsmål',),
'skjønnsspørsmåla': ('skjønnsspørsmål',),
'skjønnsspørsmålene': ('skjønnsspørsmål',),
'skjønnsspørsmålet': ('skjønnsspørsmål',),
'skjønnånd': ('skjønnånd',),
'skjønnånden': ('skjønnånd',),
'skjønnåndene': ('skjønnånd',),
'skjønnånder': ('skjønnånd',),
'skjør': ('skjør',),
'skjøra': ('skjør',),
'skjørene': ('skjør',),
'skjøret': ('skjør',),
'skjørblanda': ('skjørblande',),
'skjørblande': ('skjørblande',),
'skjørblanden': ('skjørblande',),
'skjørblandene': ('skjørblande',),
'skjørblander': ('skjørblande',),
'skjørbuk': ('skjørbuk',),
'skjørbuken': ('skjørbuk',),
'skjørbukene': ('skjørbuk',),
'skjørbuker': ('skjørbuk',),
'skjørlevnet': ('skjørlevnet',),
'skjørlevneta': ('skjørlevnet',),
'skjørlevnetene': ('skjørlevnet',),
'skjørlevnetet': ('skjørlevnet',),
'skjørost': ('skjørost',),
'skjørosten': ('skjørost',),
'skjørostene': ('skjørost',),
'skjøroster': ('skjørost',),
'skjørt': ('skjørt',),
'skjørta': ('skjørt',),
'skjørtene': ('skjørt',),
'skjørter': ('skjørt',),
'skjørtet': ('skjørt',),
'skjørtejeger': ('skjørtejeger',),
'skjørtejegere': ('skjørtejeger',),
'skjørtejegeren': ('skjørtejeger',),
'skjørtejegerer': ('skjørtejeger',),
'skjørtejegerne': ('skjørtejeger',),
'skjøt': ('skjøt',),
'skjøten': ('skjøt',),
'skjøtene': ('skjøt',),
'skjøter': ('skjøt',),
'skjøta': ('skjøte',),
'skjøte': ('skjøte',),
'skjøtene': ('skjøte',),
'skjøter': ('skjøte',),
'skjøtet': ('skjøte',),
'skjøteledning': ('skjøteledning',),
'skjøteledninga': ('skjøteledning',),
'skjøteledningen': ('skjøteledning',),
'skjøteledningene': ('skjøteledning',),
'skjøteledninger': ('skjøteledning',),
'skjøtsel': ('skjøtsel',),
'skjøtselen': ('skjøtsel',),
'skjøtslene': ('skjøtsel',),
'skjøtsler': ('skjøtsel',),
'skjøtselplan': ('skjøtselplan',),
'skjøtselplanen': ('skjøtselplan',),
'skjøtselplanene': ('skjøtselplan',),
'skjøtselplaner': ('skjøtselplan',),
'skjøtskinn': ('skjøtskinn',),
'skjøtskinna': ('skjøtskinn',),
'skjøtskinnene': ('skjøtskinn',),
'skjøtskinnet': ('skjøtskinn',),
'skjøtstova': ('skjøtstove',),
'skjøtstove': ('skjøtstove',),
'skjøtstoven': ('skjøtstove',),
'skjøtstovene': ('skjøtstove',),
'skjøtstover': ('skjøtstove',),
'skjøtstua': ('skjøtstue',),
'skjøtstue': ('skjøtstue',),
'skjøtstuen': ('skjøtstue',),
'skjøtstuene': ('skjøtstue',),
'skjøtstuer': ('skjøtstue',),
'sklerometer': ('sklerometer',),
'sklerometeret': ('sklerometer',),
'sklerometra': ('sklerometer',),
'sklerometre': ('sklerometer',),
'sklerometrene': ('sklerometer',),
'sklerometret': ('sklerometer',),
'sklerose': ('sklerose',),
'sklerosen': ('sklerose',),
'sklerosene': ('sklerose',),
'skleroser': ('sklerose',),
'skleroskop': ('skleroskop',),
'skleroskopa': ('skleroskop',),
'skleroskopene': ('skleroskop',),
'skleroskoper': ('skleroskop',),
'skleroskopet': ('skleroskop',),
'sklia': ('sklie',),
'sklie': ('sklie',),
'sklien': ('sklie',),
'skliene': ('sklie',),
'sklier': ('sklie',),
'sko': ('sko',),
'skoa': ('sko',),
'skoen': ('sko',),
'skoene': ('sko',),
'skor': ('sko',),
'skorne': ('sko',),
'skobesparer': ('skobesparer',),
'skobesparere': ('skobesparer',),
'skobespareren': ('skobesparer',),
'skobesparerer': ('skobesparer',),
'skobesparerne': ('skobesparer',),
'skobørste': ('skobørste',),
'skobørsten': ('skobørste',),
'skobørstene': ('skobørste',),
'skobørster': ('skobørste',),
'skodde': ('skodde',),
'skodden': ('skodde',),
'skoddene': ('skodde',),
'skodder': ('skodde',),
'skodda': ('skodde',),
'skodde': ('skodde',),
'skodden': ('skodde',),
'skoddene': ('skodde',),
'skodder': ('skodde',),
'skoddebanke': ('skoddebanke',),
'skoddebanken': ('skoddebanke',),
'skoddebankene': ('skoddebanke',),
'skoddebanker': ('skoddebanke',),
'skoft': ('skoft',),
'skofta': ('skoft',),
'skoften': ('skoft',),
'skoftene': ('skoft',),
'skofter': ('skoft',),
'skoftet': ('skoft',),
'skog': ('skog',),
'skogen': ('skog',),
'skogene': ('skog',),
'skoger': ('skog',),
'skogband': ('skogband',),
'skogbanda': ('skogband',),
'skogbandene': ('skogband',),
'skogbandet': ('skogband',),
'skogblomst': ('skogblomst',),
'skogblomsten': ('skogblomst',),
'skogblomstene': ('skogblomst',),
'skogblomster': ('skogblomst',),
'skogbotn': ('skogbotn',),
'skogbotnen': ('skogbotn',),
'skogbotnene': ('skogbotn',),
'skogbotner': ('skogbotn',),
'skogbrann': ('skogbrann',),
'skogbrannen': ('skogbrann',),
'skogbrannene': ('skogbrann',),
'skogbranner': ('skogbrann',),
'skogbruk': ('skogbruk',),
'skogbruka': ('skogbruk',),
'skogbrukene': ('skogbruk',),
'skogbruket': ('skogbruk',),
'skogbryn': ('skogbryn',),
'skogbryna': ('skogbryn',),
'skogbrynene': ('skogbryn',),
'skogbrynet': ('skogbryn',),
'skogbunn': ('skogbunn',),
'skogbunnen': ('skogbunn',),
'skogbunnene': ('skogbunn',),
'skogbunner': ('skogbunn',),
'skogbygd': ('skogbygd',),
'skogbygda': ('skogbygd',),
'skogbygden': ('skogbygd',),
'skogbygdene': ('skogbygd',),
'skogbygder': ('skogbygd',),
'skogdistrikt': ('skogdistrikt',),
'skogdistrikta': ('skogdistrikt',),
'skogdistriktene': ('skogdistrikt',),
'skogdistrikter': ('skogdistrikt',),
'skogdistriktet': ('skogdistrikt',),
'skogdrift': ('skogdrift',),
'skogdrifta': ('skogdrift',),
'skogdriften': ('skogdrift',),
'skogdriftene': ('skogdrift',),
'skogdrifter': ('skogdrift',),
'skogdua': ('skogdue',),
'skogdue': ('skogdue',),
'skogduen': ('skogdue',),
'skogduene': ('skogdue',),
'skogduer': ('skogdue',),
'skogdød': ('skogdød',),
'skogdøden': ('skogdød',),
'skogdødene': ('skogdød',),
'skogdøder': ('skogdød',),
'skogeier': ('skogeier',),
'skogeiere': ('skogeier',),
'skogeieren': ('skogeier',),
'skogeierer': ('skogeier',),
'skogeierne': ('skogeier',),
'skogfinne': ('skogfinne',),
'skogfinnen': ('skogfinne',),
'skogfinnene': ('skogfinne',),
'skogfinner': ('skogfinne',),
'skogfiol': ('skogfiol',),
'skogfiolen': ('skogfiol',),
'skogfiolene': ('skogfiol',),
'skogfioler': ('skogfiol',),
'skogflått': ('skogflått',),
'skogflåtten': ('skogflått',),
'skogflåttene': ('skogflått',),
'skogflåtter': ('skogflått',),
'skogforvalter': ('skogforvalter',),
'skogforvaltere': ('skogforvalter',),
'skogforvalteren': ('skogforvalter',),
'skogforvalterer': ('skogforvalter',),
'skogforvalterne': ('skogforvalter',),
'skogfugl': ('skogfugl',),
'skogfuglen': ('skogfugl',),
'skogfuglene': ('skogfugl',),
'skogfugler': ('skogfugl',),
'skoggang': ('skoggang',),
'skoggangen': ('skoggang',),
'skoggangene': ('skoggang',),
'skogganger': ('skoggang',),
'skoggangsmann': ('skoggangsmann',),
'skoggangsmannen': ('skoggangsmann',),
'skoggangsmenn': ('skoggangsmann',),
'skoggangsmennene': ('skoggangsmann',),
'skoggerlatrene': ('skoggerlatter',),
'skoggerlatrer': ('skoggerlatter',),
'skoggerlatter': ('skoggerlatter',),
'skoggerlattere': ('skoggerlatter',),
'skoggerlatteren': ('skoggerlatter',),
'skoggerlatterer': ('skoggerlatter',),
'skoggerlatterne': ('skoggerlatter',),
'skoggrensa': ('skoggrense',),
'skoggrense': ('skoggrense',),
'skoggrensen': ('skoggrense',),
'skoggrensene': ('skoggrense',),
'skoggrenser': ('skoggrense',),
'skogholt': ('skogholt',),
'skogholta': ('skogholt',),
'skogholtene': ('skogholt',),
'skogholtet': ('skogholt',),
'skogkant': ('skogkant',),
'skogkanten': ('skogkant',),
'skogkantene': ('skogkant',),
'skogkanter': ('skogkant',),
'skogkatt': ('skogkatt',),
'skogkatten': ('skogkatt',),
'skogkattene': ('skogkatt',),
'skogkatter': ('skogkatt',),
'skogkratt': ('skogkratt',),
'skogkratta': ('skogkratt',),
'skogkrattene': ('skogkratt',),
'skogkrattet': ('skogkratt',),
'skogkultur': ('skogkultur',),
'skogkulturen': ('skogkultur',),
'skogkulturene': ('skogkultur',),
'skogkulturer': ('skogkultur',),
'skoglenda': ('skoglende',),
'skoglende': ('skoglende',),
'skoglendene': ('skoglende',),
'skoglender': ('skoglende',),
'skoglendet': ('skoglende',),
'skogmaur': ('skogmaur',),
'skogmauren': ('skogmaur',),
'skogmaurene': ('skogmaur',),
'skogmester': ('skogmester',),
'skogmestere': ('skogmester',),
'skogmesteren': ('skogmester',),
'skogmesterer': ('skogmester',),
'skogmesterne': ('skogmester',),
'skogmestre': ('skogmester',),
'skogmestrene': ('skogmester',),
'skogmestrer': ('skogmester',),
'skogmus': ('skogmus',),
'skogmusa': ('skogmus',),
'skogmusen': ('skogmus',),
'skogmusene': ('skogmus',),
'skognag': ('skognag',),
'skognaga': ('skognag',),
'skognagene': ('skognag',),
'skognaget': ('skognag',),
'skogområda': ('skogområde',),
'skogområde': ('skogområde',),
'skogområdene': ('skogområde',),
'skogområder': ('skogområde',),
'skogområdet': ('skogområde',),
'skogoppsyn': ('skogoppsyn',),
'skogoppsyna': ('skogoppsyn',),
'skogoppsynene': ('skogoppsyn',),
'skogoppsynet': ('skogoppsyn',),
'skogoppsynsmann': ('skogoppsynsmann',),
'skogoppsynsmannen': ('skogoppsynsmann',),
'skogoppsynsmenn': ('skogoppsynsmann',),
'skogoppsynsmennene': ('skogoppsynsmann',),
'skogplanting': ('skogplanting',),
'skogplantinga': ('skogplanting',),
'skogplantingen': ('skogplanting',),
'skogplantingene': ('skogplanting',),
'skogplantinger': ('skogplanting',),
'skogplantning': ('skogplantning',),
'skogplantninga': ('skogplantning',),
'skogplantningen': ('skogplantning',),
'skogplantningene': ('skogplantning',),
'skogplantninger': ('skogplantning',),
'skogredsel': ('skogredsel',),
'skogredselen': ('skogredsel',),
'skogredslene': ('skogredsel',),
'skogredsler': ('skogredsel',),
'skogreising': ('skogreising',),
'skogreisinga': ('skogreising',),
'skogreisingen': ('skogreising',),
'skogreisingene': ('skogreising',),
'skogreisinger': ('skogreising',),
'skogråd': ('skogråd',),
'skogråda': ('skogråd',),
'skogrådene': ('skogråd',),
'skogrådet': ('skogråd',),
'skogsarbeid': ('skogsarbeid',),
'skogsarbeida': ('skogsarbeid',),
'skogsarbeidene': ('skogsarbeid',),
'skogsarbeider': ('skogsarbeid',),
'skogsarbeidet': ('skogsarbeid',),
'skogsarbeider': ('skogsarbeider',),
'skogsarbeidere': ('skogsarbeider',),
'skogsarbeideren': ('skogsarbeider',),
'skogsarbeiderer': ('skogsarbeider',),
'skogsarbeiderne': ('skogsarbeider',),
'skogsbilveg': ('skogsbilveg',),
'skogsbilvegen': ('skogsbilveg',),
'skogsbilvegene': ('skogsbilveg',),
'skogsbilveger': ('skogsbilveg',),
'skogsbilvei': ('skogsbilvei',),
'skogsbilveien': ('skogsbilvei',),
'skogsbilveiene': ('skogsbilvei',),
'skogsbilveier': ('skogsbilvei',),
'skogsbygd': ('skogsbygd',),
'skogsbygda': ('skogsbygd',),
'skogsbygden': ('skogsbygd',),
'skogsbygdene': ('skogsbygd',),
'skogsbygder': ('skogsbygd',),
'skogsdistrikt': ('skogsdistrikt',),
'skogsdistrikta': ('skogsdistrikt',),
'skogsdistriktene': ('skogsdistrikt',),
'skogsdistrikter': ('skogsdistrikt',),
'skogsdistriktet': ('skogsdistrikt',),
'skogsdrift': ('skogsdrift',),
'skogsdrifta': ('skogsdrift',),
'skogsdriften': ('skogsdrift',),
'skogsdriftene': ('skogsdrift',),
'skogsdrifter': ('skogsdrift',),
'skogselefant': ('skogselefant',),
'skogselefanten': ('skogselefant',),
'skogselefantene': ('skogselefant',),
'skogselefanter': ('skogselefant',),
'skogselskap': ('skogselskap',),
'skogselskapa': ('skogselskap',),
'skogselskapene': ('skogselskap',),
'skogselskaper': ('skogselskap',),
'skogselskapet': ('skogselskap',),
'skogsfugl': ('skogsfugl',),
'skogsfuglen': ('skogsfugl',),
'skogsfuglene': ('skogsfugl',),
'skogsfugler': ('skogsfugl',),
'skogskjøtsel': ('skogskjøtsel',),
'skogskjøtselen': ('skogskjøtsel',),
'skogskjøtslene': ('skogskjøtsel',),
'skogskjøtsler': ('skogskjøtsel',),
'skogskole': ('skogskole',),
'skogskolen': ('skogskole',),
'skogskolene': ('skogskole',),
'skogskoler': ('skogskole',),
'skogsløp': ('skogsløp',),
'skogsløpa': ('skogsløp',),
'skogsløpene': ('skogsløp',),
'skogsløpet': ('skogsløp',),
'skogsmaur': ('skogsmaur',),
'skogsmauren': ('skogsmaur',),
'skogsmaurene': ('skogsmaur',),
'skogsnar': ('skogsnar',),
'skogsnara': ('skogsnar',),
'skogsnarene': ('skogsnar',),
'skogsnaret': ('skogsnar',),
'skogsnegl': ('skogsnegl',),
'skogsneglen': ('skogsnegl',),
'skogsneglene': ('skogsnegl',),
'skogsnegler': ('skogsnegl',),
'skogsnile': ('skogsnile',),
'skogsnilen': ('skogsnile',),
'skogsnilene': ('skogsnile',),
'skogsniler': ('skogsnile',),
'skogsområda': ('skogsområde',),
'skogsområde': ('skogsområde',),
'skogsområdene': ('skogsområde',),
'skogsområder': ('skogsområde',),
'skogsområdet': ('skogsområde',),
'skogsrå': ('skogsrå',),
'skogsråa': ('skogsrå',),
'skogsråen': ('skogsrå',),
'skogsråene': ('skogsrå',),
'skogsråer': ('skogsrå',),
'skogsti': ('skogsti',),
'skogstien': ('skogsti',),
'skogstiene': ('skogsti',),
'skogstier': ('skogsti',),
'skogstjerna': ('skogstjerne',),
'skogstjerne': ('skogstjerne',),
'skogstjernen': ('skogstjerne',),
'skogstjernene': ('skogstjerne',),
'skogstjerner': ('skogstjerne',),
'skogstorkenebb': ('skogstorkenebb',),
'skogstorkenebben': ('skogstorkenebb',),
'skogstorkenebbene': ('skogstorkenebb',),
'skogstorkenebber': ('skogstorkenebb',),
'skogstrekning': ('skogstrekning',),
'skogstrekninga': ('skogstrekning',),
'skogstrekningen': ('skogstrekning',),
'skogstrekningene': ('skogstrekning',),
'skogstrekninger': ('skogstrekning',),
'skogstur': ('skogstur',),
'skogsturen': ('skogstur',),
'skogsturene': ('skogstur',),
'skogsturer': ('skogstur',),
'skogsvirka': ('skogsvirke',),
'skogsvirke': ('skogsvirke',),
'skogsvirkene': ('skogsvirke',),
'skogsvirker': ('skogsvirke',),
'skogsvirket': ('skogsvirke',),
'skogteig': ('skogteig',),
'skogteigen': ('skogteig',),
'skogteigene': ('skogteig',),
'skogteiger': ('skogteig',),
'skogtekniker': ('skogtekniker',),
'skogteknikere': ('skogtekniker',),
'skogteknikeren': ('skogtekniker',),
'skogteknikerer': ('skogtekniker',),
'skogteknikerne': ('skogtekniker',),
'skogtraver': ('skogtraver',),
'skogtravere': ('skogtraver',),
'skogtraveren': ('skogtraver',),
'skogtraverer': ('skogtraver',),
'skogtraverne': ('skogtraver',),
'skogtroll': ('skogtroll',),
'skogtrolla': ('skogtroll',),
'skogtrollene': ('skogtroll',),
'skogtrollet': ('skogtroll',),
'skogtur': ('skogtur',),
'skogturen': ('skogtur',),
'skogturene': ('skogtur',),
'skogturer': ('skogtur',),
'skogvern': ('skogvern',),
'skogverna': ('skogvern',),
'skogvernene': ('skogvern',),
'skogvernet': ('skogvern',),
'skogvernlov': ('skogvernlov',),
'skogvernloven': ('skogvernlov',),
'skogvernlovene': ('skogvernlov',),
'skogvernlover': ('skogvernlov',),
'skogvokter': ('skogvokter',),
'skogvoktere': ('skogvokter',),
'skogvokteren': ('skogvokter',),
'skogvokterer': ('skogvokter',),
'skogvokterne': ('skogvokter',),
'skogås': ('skogås',),
'skogåsen': ('skogås',),
'skogåsene': ('skogås',),
'skogåser': ('skogås',),
'skohorn': ('skohorn',),
'skohorna': ('skohorn',),
'skohornene': ('skohorn',),
'skohornet': ('skohorn',),
'skohæl': ('skohæl',),
'skohælen': ('skohæl',),
'skohælene': ('skohæl',),
'skohæler': ('skohæl',),
'skojern': ('skojern',),
'skojerna': ('skojern',),
'skojernene': ('skojern',),
'skojernet': ('skojern',),
'skokk': ('skokk',),
'skokken': ('skokk',),
'skokkene': ('skokk',),
'skokker': ('skokk',),
'skokla': ('skokle',),
'skokle': ('skokle',),
'skoklen': ('skokle',),
'skoklene': ('skokle',),
'skokler': ('skokle',),
'skoklefall': ('skoklefall',),
'skoklefalla': ('skoklefall',),
'skoklefallene': ('skoklefall',),
'skoklefallet': ('skoklefall',),
'skoklefallsdag': ('skoklefallsdag',),
'skoklefallsdagen': ('skoklefallsdag',),
'skoklefallsdagene': ('skoklefallsdag',),
'skoklefallsdager': ('skoklefallsdag',),
'skokrem': ('skokrem',),
'skokremen': ('skokrem',),
'skokremene': ('skokrem',),
'skokremer': ('skokrem',),
'skolastiker': ('skolastiker',),
'skolastikere': ('skolastiker',),
'skolastikeren': ('skolastiker',),
'skolastikerer': ('skolastiker',),
'skolastikerne': ('skolastiker',),
'skolastikk': ('skolastikk',),
'skolastikken': ('skolastikk',),
'skolastikkene': ('skolastikk',),
'skolastikker': ('skolastikk',),
'skole': ('skole',),
'skolen': ('skole',),
'skolene': ('skole',),
'skoler': ('skole',),
'skolearbeid': ('skolearbeid',),
'skolearbeida': ('skolearbeid',),
'skolearbeidene': ('skolearbeid',),
'skolearbeider': ('skolearbeid',),
'skolearbeidet': ('skolearbeid',),
'skoleatlas': ('skoleatlas',),
'skoleatlasa': ('skoleatlas',),
'skoleatlasene': ('skoleatlas',),
'skoleatlaser': ('skoleatlas',),
'skoleatlaset': ('skoleatlas',),
'skolebarn': ('skolebarn',),
'skolebarna': ('skolebarn',),
'skolebarnene': ('skolebarn',),
'skolebarnet': ('skolebarn',),
'skolebenk': ('skolebenk',),
'skolebenken': ('skolebenk',),
'skolebenkene': ('skolebenk',),
'skolebenker': ('skolebenk',),
'skolebibliotek': ('skolebibliotek',),
'skolebiblioteka': ('skolebibliotek',),
'skolebibliotekene': ('skolebibliotek',),
'skolebiblioteker': ('skolebibliotek',),
'skolebiblioteket': ('skolebibliotek',),
'skoleblad': ('skoleblad',),
'skoleblada': ('skoleblad',),
'skolebladene': ('skoleblad',),
'skoleblader': ('skoleblad',),
'skolebladet': ('skoleblad',),
'skoleboksamling': ('skoleboksamling',),
'skoleboksamlinga': ('skoleboksamling',),
'skoleboksamlingen': ('skoleboksamling',),
'skoleboksamlingene': ('skoleboksamling',),
'skoleboksamlinger': ('skoleboksamling',),
'skolebruk': ('skolebruk',),
'skolebruka': ('skolebruk',),
'skolebruken': ('skolebruk',),
'skolebrukene': ('skolebruk',),
'skolebruker': ('skolebruk',),
'skolebruket': ('skolebruk',),
'skolebrød': ('skolebrød',),
'skolebrøda': ('skolebrød',),
'skolebrødene': ('skolebrød',),
'skolebrødet': ('skolebrød',),
'skolebuss': ('skolebuss',),
'skolebussen': ('skolebuss',),
'skolebussene': ('skolebuss',),
'skolebusser': ('skolebuss',),
'skolebygning': ('skolebygning',),
'skolebygninga': ('skolebygning',),
'skolebygningen': ('skolebygning',),
'skolebygningene': ('skolebygning',),
'skolebygninger': ('skolebygning',),
'skoledag': ('skoledag',),
'skoledagen': ('skoledag',),
'skoledagene': ('skoledag',),
'skoledager': ('skoledag',),
'skoledemokrati': ('skoledemokrati',),
'skoledemokratia': ('skoledemokrati',),
'skoledemokratiene': ('skoledemokrati',),
'skoledemokratier': ('skoledemokrati',),
'skoledemokratiet': ('skoledemokrati',),
'skoledirektør': ('skoledirektør',),
'skoledirektøren': ('skoledirektør',),
'skoledirektørene': ('skoledirektør',),
'skoledirektører': ('skoledirektør',),
'skoleeksempel': ('skoleeksempel',),
'skoleeksempelet': ('skoleeksempel',),
'skoleeksempla': ('skoleeksempel',),
'skoleeksemplene': ('skoleeksempel',),
'skoleeksempler': ('skoleeksempel',),
'skoleeksemplet': ('skoleeksempel',),
'skoleelev': ('skoleelev',),
'skoleeleven': ('skoleelev',),
'skoleelevene': ('skoleelev',),
'skoleelever': ('skoleelev',),
'skolefag': ('skolefag',),
'skolefaga': ('skolefag',),
'skolefagene': ('skolefag',),
'skolefaget': ('skolefag',),
'skoleferie': ('skoleferie',),
'skoleferien': ('skoleferie',),
'skoleferiene': ('skoleferie',),
'skoleferier': ('skoleferie',),
'skolefjernsyn': ('skolefjernsyn',),
'skolefjernsyna': ('skolefjernsyn',),
'skolefjernsynene': ('skolefjernsyn',),
'skolefjernsynet': ('skolefjernsyn',),
'skolefly': ('skolefly',),
'skoleflya': ('skolefly',),
'skoleflyene': ('skolefly',),
'skoleflyet': ('skolefly',),
'skoleflyging': ('skoleflyging',),
'skoleflyginga': ('skoleflyging',),
'skoleflygingen': ('skoleflyging',),
'skoleflygingene': ('skoleflyging',),
'skoleflyginger': ('skoleflyging',),
'skoleflying': ('skoleflying',),
'skoleflyinga': ('skoleflying',),
'skoleflyingen': ('skoleflying',),
'skoleflyingene': ('skoleflying',),
'skoleflyinger': ('skoleflying',),
'skolefolk': ('skolefolk',),
'skolefolka': ('skolefolk',),
'skolefolkene': ('skolefolk',),
'skolefolket': ('skolefolk',),
'skolefri': ('skolefri',),
'skolefrokost': ('skolefrokost',),
'skolefrokosten': ('skolefrokost',),
'skolefrokostene': ('skolefrokost',),
'skolefrokoster': ('skolefrokost',),
'skolegang': ('skolegang',),
'skolegangen': ('skolegang',),
'skolegangene': ('skolegang',),
'skoleganger': ('skolegang',),
'skolegard': ('skolegard',),
'skolegarden': ('skolegard',),
'skolegardene': ('skolegard',),
'skolegarder': ('skolegard',),
'skolegrammatikk': ('skolegrammatikk',),
'skolegrammatikken': ('skolegrammatikk',),
'skolegrammatikkene': ('skolegrammatikk',),
'skolegrammatikker': ('skolegrammatikk',),
'skolegård': ('skolegård',),
'skolegården': ('skolegård',),
'skolegårdene': ('skolegård',),
'skolegårder': ('skolegård',),
'skoleholder': ('skoleholder',),
'skoleholdere': ('skoleholder',),
'skoleholderen': ('skoleholder',),
'skoleholderer': ('skoleholder',),
'skoleholderne': ('skoleholder',),
'skolehus': ('skolehus',),
'skolehusa': ('skolehus',),
'skolehusene': ('skolehus',),
'skolehuset': ('skolehus',),
'skoleinspektør': ('skoleinspektør',),
'skoleinspektøren': ('skoleinspektør',),
'skoleinspektørene': ('skoleinspektør',),
'skoleinspektører': ('skoleinspektør',),
'skoleist': ('skoleist',),
'skoleisten': ('skoleist',),
'skoleistene': ('skoleist',),
'skoleister': ('skoleist',),
'skoleist': ('skoleist',),
'skoleisten': ('skoleist',),
'skoleistene': ('skoleist',),
'skoleister': ('skoleist',),
'skolekamerat': ('skolekamerat',),
'skolekameraten': ('skolekamerat',),
'skolekameratene': ('skolekamerat',),
'skolekamerater': ('skolekamerat',),
'skolekjøkken': ('skolekjøkken',),
'skolekjøkkena': ('skolekjøkken',),
'skolekjøkkenene': ('skolekjøkken',),
'skolekjøkkener': ('skolekjøkken',),
'skolekjøkkenet': ('skolekjøkken',),
'skoleklassa': ('skoleklasse',),
'skoleklasse': ('skoleklasse',),
'skoleklassen': ('skoleklasse',),
'skoleklassene': ('skoleklasse',),
'skoleklasser': ('skoleklasse',),
'skoleklokka': ('skoleklokke',),
'skoleklokke': ('skoleklokke',),
'skoleklokken': ('skoleklokke',),
'skoleklokkene': ('skoleklokke',),
'skoleklokker': ('skoleklokke',),
'skolekonsert': ('skolekonsert',),
'skolekonserten': ('skolekonsert',),
'skolekonsertene': ('skolekonsert',),
'skolekonserter': ('skolekonsert',),
'skolekorps': ('skolekorps',),
'skolekorpsa': ('skolekorps',),
'skolekorpsene': ('skolekorps',),
'skolekorpset': ('skolekorps',),
'skolekrets': ('skolekrets',),
'skolekretsen': ('skolekrets',),
'skolekretsene': ('skolekrets',),
'skolekretser': ('skolekrets',),
'skolekringkasting': ('skolekringkasting',),
'skolekringkastinga': ('skolekringkasting',),
'skolekringkastingen': ('skolekringkasting',),
'skolekringkastingene': ('skolekringkasting',),
'skolekringkastinger': ('skolekringkasting',),
'skolelandskap': ('skolelandskap',),
'skolelandskapa': ('skolelandskap',),
'skolelandskapene': ('skolelandskap',),
'skolelandskaper': ('skolelandskap',),
'skolelandskapet': ('skolelandskap',),
'skolelys': ('skolelys',),
'skolelysa': ('skolelys',),
'skolelysene': ('skolelys',),
'skolelyset': ('skolelys',),
'skolelærer': ('skolelærer',),
'skolelærere': ('skolelærer',),
'skolelæreren': ('skolelærer',),
'skolelærerer': ('skolelærer',),
'skolelærerne': ('skolelærer',),
'skolemann': ('skolemann',),
'skolemannen': ('skolemann',),
'skolemenn': ('skolemann',),
'skolemennene': ('skolemann',),
'skolemat': ('skolemat',),
'skolematen': ('skolemat',),
'skolematene': ('skolemat',),
'skolemater': ('skolemat',),
'skolemateriell': ('skolemateriell',),
'skolemateriella': ('skolemateriell',),
'skolemateriellene': ('skolemateriell',),
'skolemateriellet': ('skolemateriell',),
'skolemedisin': ('skolemedisin',),
'skolemedisinen': ('skolemedisin',),
'skolemedisinene': ('skolemedisin',),
'skolemedisiner': ('skolemedisin',),
'skolemester': ('skolemester',),
'skolemestere': ('skolemester',),
'skolemesteren': ('skolemester',),
'skolemesterer': ('skolemester',),
'skolemesterne': ('skolemester',),
'skolemestre': ('skolemester',),
'skolemestrene': ('skolemester',),
'skolemestrer': ('skolemester',),
'skolemestermina': ('skolemestermine',),
'skolemestermine': ('skolemestermine',),
'skolemesterminen': ('skolemestermine',),
'skolemesterminene': ('skolemestermine',),
'skolemesterminer': ('skolemestermine',),
'skolemåltid': ('skolemåltid',),
'skolemåltida': ('skolemåltid',),
'skolemåltidene': ('skolemåltid',),
'skolemåltider': ('skolemåltid',),
'skolemåltidet': ('skolemåltid',),
'skolepatrulje': ('skolepatrulje',),
'skolepatruljen': ('skolepatrulje',),
'skolepatruljene': ('skolepatrulje',),
'skolepatruljer': ('skolepatrulje',),
'skolepengene': ('skolepenger',),
'skolepenger': ('skolepenger',),
'skoleplikt': ('skoleplikt',),
'skoleplikta': ('skoleplikt',),
'skoleplikten': ('skoleplikt',),
'skolepliktene': ('skoleplikt',),
'skoleplikter': ('skoleplikt',),
'skoleport': ('skoleport',),
'skoleporten': ('skoleport',),
'skoleportene': ('skoleport',),
'skoleporter': ('skoleport',),
'skolepsykolog': ('skolepsykolog',),
'skolepsykologen': ('skolepsykolog',),
'skolepsykologene': ('skolepsykolog',),
'skolepsykologer': ('skolepsykolog',),
'skoleradio': ('skoleradio',),
'skoleradioen': ('skoleradio',),
'skoleradioene': ('skoleradio',),
'skoleradioer': ('skoleradio',),
'skoleregning': ('skoleregning',),
'skoleregninga': ('skoleregning',),
'skoleregningen': ('skoleregning',),
'skoleregningene': ('skoleregning',),
'skoleregninger': ('skoleregning',),
'skolerekning': ('skolerekning',),
'skolerekninga': ('skolerekning',),
'skolerekningen': ('skolerekning',),
'skolerekningene': ('skolerekning',),
'skolerekninger': ('skolerekning',),
'skolerett': ('skolerett',),
'skoleretten': ('skolerett',),
'skolerettene': ('skolerett',),
'skoleretter': ('skolerett',),
'skoleruta': ('skolerute',),
'skolerute': ('skolerute',),
'skoleruten': ('skolerute',),
'skolerutene': ('skolerute',),
'skoleruter': ('skolerute',),
'skoleråd': ('skoleråd',),
'skoleråda': ('skoleråd',),
'skolerådene': ('skoleråd',),
'skolerådet': ('skoleråd',),
'skolerådgiver': ('skolerådgiver',),
'skolerådgivere': ('skolerådgiver',),
'skolerådgiveren': ('skolerådgiver',),
'skolerådgiverer': ('skolerådgiver',),
'skolerådgiverne': ('skolerådgiver',),
'skolesjef': ('skolesjef',),
'skolesjefen': ('skolesjef',),
'skolesjefene': ('skolesjef',),
'skolesjefer': ('skolesjef',),
'skoleskip': ('skoleskip',),
'skoleskipa': ('skoleskip',),
'skoleskipene': ('skoleskip',),
'skoleskipet': ('skoleskip',),
'skoleskyting': ('skoleskyting',),
'skoleskytinga': ('skoleskyting',),
'skoleskytingen': ('skoleskyting',),
'skoleskytingene': ('skoleskyting',),
'skoleskytinger': ('skoleskyting',),
'skolest': ('skolest',),
'skolesten': ('skolest',),
'skolestene': ('skolest',),
'skolester': ('skolest',),
'skolest': ('skolest',),
'skolesten': ('skolest',),
'skolestene': ('skolest',),
'skolester': ('skolest',),
'skolestil': ('skolestil',),
'skolestilen': ('skolestil',),
'skolestilene': ('skolestil',),
'skolestiler': ('skolestil',),
'skolestova': ('skolestove',),
'skolestove': ('skolestove',),
'skolestoven': ('skolestove',),
'skolestovene': ('skolestove',),
'skolestover': ('skolestove',),
'skolestua': ('skolestue',),
'skolestue': ('skolestue',),
'skolestuen': ('skolestue',),
'skolestuene': ('skolestue',),
'skolestuer': ('skolestue',),
'skolestyra': ('skolestyre',),
'skolestyre': ('skolestyre',),
'skolestyrene': ('skolestyre',),
'skolestyrer': ('skolestyre',),
'skolestyret': ('skolestyre',),
'skolestyrer': ('skolestyrer',),
'skolestyrere': ('skolestyrer',),
'skolestyreren': ('skolestyrer',),
'skolestyrerer': ('skolestyrer',),
'skolestyrerne': ('skolestyrer',),
'skoletannlege': ('skoletannlege',),
'skoletannlegen': ('skoletannlege',),
'skoletannlegene': ('skoletannlege',),
'skoletannleger': ('skoletannlege',),
'skoletannpleia': ('skoletannpleie',),
'skoletannpleie': ('skoletannpleie',),
'skoletannpleien': ('skoletannpleie',),
'skoletannpleiene': ('skoletannpleie',),
'skoletannpleier': ('skoletannpleie',),
'skoletid': ('skoletid',),
'skoletida': ('skoletid',),
'skoletiden': ('skoletid',),
'skoletidene': ('skoletid',),
'skoletider': ('skoletid',),
'skoletime': ('skoletime',),
'skoletimen': ('skoletime',),
'skoletimene': ('skoletime',),
'skoletimer': ('skoletime',),
'skolett': ('skolett',),
'skoletten': ('skolett',),
'skolettene': ('skolett',),
'skoletter': ('skolett',),
'skoletur': ('skoletur',),
'skoleturen': ('skoletur',),
'skoleturene': ('skoletur',),
'skoleturer': ('skoletur',),
'skoleungdom': ('skoleungdom',),
'skoleungdommen': ('skoleungdom',),
'skoleungdommene': ('skoleungdom',),
'skoleungdommer': ('skoleungdom',),
'skoleutgava': ('skoleutgave',),
'skoleutgave': ('skoleutgave',),
'skoleutgaven': ('skoleutgave',),
'skoleutgavene': ('skoleutgave',),
'skoleutgaver': ('skoleutgave',),
'skoleveg': ('skoleveg',),
'skolevegen': ('skoleveg',),
'skolevegene': ('skoleveg',),
'skoleveger': ('skoleveg',),
'skolevei': ('skolevei',),
'skoleveien': ('skolevei',),
'skoleveiene': ('skolevei',),
'skoleveier': ('skolevei',),
'skolevesen': ('skolevesen',),
'skolevesena': ('skolevesen',),
'skolevesenene': ('skolevesen',),
'skolevesener': ('skolevesen',),
'skolevesenet': ('skolevesen',),
'skoleår': ('skoleår',),
'skoleåra': ('skoleår',),
'skoleårene': ('skoleår',),
'skoleåret': ('skoleår',),
'skolissa': ('skolisse',),
'skolisse': ('skolisse',),
'skolissen': ('skolisse',),
'skolissene': ('skolisse',),
'skolisser': ('skolisse',),
'skolm': ('skolm',),
'skolma': ('skolm',),
'skolmen': ('skolm',),
'skolmene': ('skolm',),
'skolmer': ('skolm',),
'skolopender': ('skolopender',),
'skolopendere': ('skolopender',),
'skolopenderen': ('skolopender',),
'skolopenderer': ('skolopender',),
'skolopenderne': ('skolopender',),
'skolopendre': ('skolopender',),
'skolopendrene': ('skolopender',),
'skolopendrer': ('skolopender',),
'skolp': ('skolp',),
'skolpen': ('skolp',),
'skolpene': ('skolp',),
'skolper': ('skolp',),
'skolp': ('skolp',),
'skolpen': ('skolp',),
'skolpene': ('skolp',),
'skolper': ('skolp',),
'skolpejern': ('skolpejern',),
'skolpejerna': ('skolpejern',),
'skolpejernene': ('skolpejern',),
'skolpejernet': ('skolpejern',),
'skolt': ('skolt',),
'skolten': ('skolt',),
'skoltene': ('skolt',),
'skolter': ('skolt',),
'skoltesame': ('skoltesame',),
'skoltesamen': ('skoltesame',),
'skoltesamene': ('skoltesame',),
'skoltesamer': ('skoltesame',),
'skomaker': ('skomaker',),
'skomakere': ('skomaker',),
'skomakeren': ('skomaker',),
'skomakerer': ('skomaker',),
'skomakerne': ('skomaker',),
'skomakergutt': ('skomakergutt',),
'skomakergutten': ('skomakergutt',),
'skomakerguttene': ('skomakergutt',),
'skomakergutter': ('skomakergutt',),
'skomakerkniv': ('skomakerkniv',),
'skomakerkniven': ('skomakerkniv',),
'skomakerknivene': ('skomakerkniv',),
'skomakerkniver': ('skomakerkniv',),
'skomakerlaug': ('skomakerlaug',),
'skomakerlauga': ('skomakerlaug',),
'skomakerlaugene': ('skomakerlaug',),
'skomakerlauget': ('skomakerlaug',),
'skoning': ('skoning',),
'skoninga': ('skoning',),
'skoningen': ('skoning',),
'skoningene': ('skoning',),
'skoninger': ('skoning',),
'skonnert': ('skonnert',),
'skonnerten': ('skonnert',),
'skonnertene': ('skonnert',),
'skonnerter': ('skonnert',),
'skonrok': ('skonrok',),
'skonroken': ('skonrok',),
'skonrokene': ('skonrok',),
'skonroker': ('skonrok',),
'skop': ('skop',),
'skopa': ('skop',),
'skopene': ('skop',),
'skoper': ('skop',),
'skopet': ('skop',),
'skopuss': ('skopuss',),
'skopussen': ('skopuss',),
'skopussene': ('skopuss',),
'skopusser': ('skopuss',),
'skopusser': ('skopusser',),
'skopussere': ('skopusser',),
'skopusseren': ('skopusser',),
'skopusserer': ('skopusser',),
'skopusserne': ('skopusser',),
'skorbut': ('skorbut',),
'skorbuten': ('skorbut',),
'skorbutene': ('skorbut',),
'skorbuter': ('skorbut',),
'skorde': ('skorde',),
'skorden': ('skorde',),
'skordene': ('skorde',),
'skorder': ('skorde',),
'skore': ('skore',),
'skoren': ('skore',),
'skorene': ('skore',),
'skorer': ('skore',),
'skoreim': ('skoreim',),
'skoreima': ('skoreim',),
'skoreimen': ('skoreim',),
'skoreimene': ('skoreim',),
'skoreimer': ('skoreim',),
'skorem': ('skorem',),
'skoremma': ('skorem',),
'skoremmen': ('skorem',),
'skoremmene': ('skorem',),
'skoremmer': ('skorem',),
'skorpa': ('skorpe',),
'skorpe': ('skorpe',),
'skorpen': ('skorpe',),
'skorpene': ('skorpe',),
'skorper': ('skorpe',),
'skorpelav': ('skorpelav',),
'skorpelava': ('skorpelav',),
'skorpelavene': ('skorpelav',),
'skorpelavet': ('skorpelav',),
'skorpion': ('skorpion',),
'skorpionen': ('skorpion',),
'skorpionene': ('skorpion',),
'skorpioner': ('skorpion',),
'skorsoner': ('skorsoner',),
'skorsoneren': ('skorsoner',),
'skorsonerene': ('skorsoner',),
'skorsonerer': ('skorsoner',),
'skorsonerrot': ('skorsonerrot',),
'skorsonerrota': ('skorsonerrot',),
'skorsonerroten': ('skorsonerrot',),
'skorsonerrøttene': ('skorsonerrot',),
'skorsonerrøtter': ('skorsonerrot',),
'skorstein': ('skorstein',),
'skorsteinen': ('skorstein',),
'skorsteinene': ('skorstein',),
'skorsteiner': ('skorstein',),
'skorsteinsfeier': ('skorsteinsfeier',),
'skorsteinsfeiere': ('skorsteinsfeier',),
'skorsteinsfeieren': ('skorsteinsfeier',),
'skorsteinsfeierer': ('skorsteinsfeier',),
'skorsteinsfeierne': ('skorsteinsfeier',),
'skorsteinspipa': ('skorsteinspipe',),
'skorsteinspipe': ('skorsteinspipe',),
'skorsteinspipen': ('skorsteinspipe',),
'skorsteinspipene': ('skorsteinspipe',),
'skorsteinspiper': ('skorsteinspipe',),
'skort': ('skort',),
'skorten': ('skort',),
'skortene': ('skort',),
'skorter': ('skort',),
'skorta': ('skorte',),
'skorte': ('skorte',),
'skorten': ('skorte',),
'skortene': ('skorte',),
'skorter': ('skorte',),
'skosa': ('skose',),
'skose': ('skose',),
'skosen': ('skose',),
'skosene': ('skose',),
'skoser': ('skose',),
'skospenna': ('skospenne',),
'skospenne': ('skospenne',),
'skospennen': ('skospenne',),
'skospennene': ('skospenne',),
'skospenner': ('skospenne',),
'skospennet': ('skospenne',),
'skosvein': ('skosvein',),
'skosveinen': ('skosvein',),
'skosveinene': ('skosvein',),
'skosveiner': ('skosvein',),
'skosverta': ('skosverte',),
'skosverte': ('skosverte',),
'skosverten': ('skosverte',),
'skosvertene': ('skosverte',),
'skosverter': ('skosverte',),
'skosåle': ('skosåle',),
'skosålen': ('skosåle',),
'skosålene': ('skosåle',),
'skosåler': ('skosåle',),
'skotsk': ('skotsk',),
'skotsken': ('skotsk',),
'skotskene': ('skotsk',),
'skotsker': ('skotsk',),
'skott': ('skott',),
'skotten': ('skott',),
'skottene': ('skott',),
'skotter': ('skott',),
'skott': ('skott',),
'skotta': ('skott',),
'skottene': ('skott',),
'skottet': ('skott',),
'skott': ('skott',),
'skotta': ('skott',),
'skottene': ('skott',),
'skottet': ('skott',),
'skottarm': ('skottarm',),
'skottarmen': ('skottarm',),
'skottarmene': ('skottarm',),
'skottarmer': ('skottarm',),
'skottbein': ('skottbein',),
'skottbeina': ('skottbein',),
'skottbeinene': ('skottbein',),
'skottbeinet': ('skottbein',),
'skottben': ('skottben',),
'skottbena': ('skottben',),
'skottbenene': ('skottben',),
'skottbenet': ('skottben',),
'skottdag': ('skottdag',),
'skottdagen': ('skottdag',),
'skottdagene': ('skottdag',),
'skottdager': ('skottdag',),
'skotte': ('skotte',),
'skotten': ('skotte',),
'skottene': ('skotte',),
'skotter': ('skotte',),
'skottehistoria': ('skottehistorie',),
'skottehistorie': ('skottehistorie',),
'skottehistorien': ('skottehistorie',),
'skottehistoriene': ('skottehistorie',),
'skottehistorier': ('skottehistorie',),
'skottfelt': ('skottfelt',),
'skottfelta': ('skottfelt',),
'skottfeltene': ('skottfelt',),
'skottfelter': ('skottfelt',),
'skottfeltet': ('skottfelt',),
'skottgamp': ('skottgamp',),
'skottgampen': ('skottgamp',),
'skottgampene': ('skottgamp',),
'skottgamper': ('skottgamp',),
'skotthold': ('skotthold',),
'skottholda': ('skotthold',),
'skottholdene': ('skotthold',),
'skottholdet': ('skotthold',),
'skotthylla': ('skotthylle',),
'skotthylle': ('skotthylle',),
'skotthyllen': ('skotthylle',),
'skotthyllene': ('skotthylle',),
'skotthyller': ('skotthylle',),
'skottlinja': ('skottlinje',),
'skottlinje': ('skottlinje',),
'skottlinjen': ('skottlinje',),
'skottlinjene': ('skottlinje',),
'skottlinjer': ('skottlinje',),
'skottmåned': ('skottmåned',),
'skottmåneden': ('skottmåned',),
'skottmånedene': ('skottmåned',),
'skottmåneder': ('skottmåned',),
'skottpremie': ('skottpremie',),
'skottpremien': ('skottpremie',),
'skottpremiene': ('skottpremie',),
'skottpremier': ('skottpremie',),
'skottsår': ('skottsår',),
'skottsåra': ('skottsår',),
'skottsårene': ('skottsår',),
'skottsåret': ('skottsår',),
'skottveksling': ('skottveksling',),
'skottvekslinga': ('skottveksling',),
'skottvekslingen': ('skottveksling',),
'skottvekslingene': ('skottveksling',),
'skottvekslinger': ('skottveksling',),
'skottår': ('skottår',),
'skottåra': ('skottår',),
'skottårene': ('skottår',),
'skottåret': ('skottår',),
'skotøy': ('skotøy',),
'skotøya': ('skotøy',),
'skotøyene': ('skotøy',),
'skotøyet': ('skotøy',),
'skova': ('skove',),
'skove': ('skove',),
'skoven': ('skove',),
'skovene': ('skove',),
'skover': ('skove',),
'skovl': ('skovl',),
'skovla': ('skovl',),
'skovlen': ('skovl',),
'skovlene': ('skovl',),
'skovler': ('skovl',),
'skovlblad': ('skovlblad',),
'skovlblada': ('skovlblad',),
'skovlbladene': ('skovlblad',),
'skovlblader': ('skovlblad',),
'skovlbladet': ('skovlblad',),
'skovlhjul': ('skovlhjul',),
'skovlhjula': ('skovlhjul',),
'skovlhjulene': ('skovlhjul',),
'skovlhjulet': ('skovlhjul',),
'skrabb': ('skrabb',),
'skrabben': ('skrabb',),
'skrabbene': ('skrabb',),
'skrabber': ('skrabb',),
'skrakkel': ('skrakkel',),
'skrakkelet': ('skrakkel',),
'skrakla': ('skrakkel',),
'skraklene': ('skrakkel',),
'skrakler': ('skrakkel',),
'skraklet': ('skrakkel',),
'skrakleføra': ('skrakleføre',),
'skrakleføre': ('skrakleføre',),
'skrakleførene': ('skrakleføre',),
'skraklefører': ('skrakleføre',),
'skrakleføret': ('skrakleføre',),
'skrall': ('skrall',),
'skralla': ('skrall',),
'skrallene': ('skrall',),
'skrallet': ('skrall',),
'skralla': ('skralle',),
'skralle': ('skralle',),
'skrallen': ('skralle',),
'skrallene': ('skralle',),
'skraller': ('skralle',),
'skramlekassa': ('skramlekasse',),
'skramlekasse': ('skramlekasse',),
'skramlekassen': ('skramlekasse',),
'skramlekassene': ('skramlekasse',),
'skramlekasser': ('skramlekasse',),
'skramleorkester': ('skramleorkester',),
'skramleorkesteret': ('skramleorkester',),
'skramleorkestra': ('skramleorkester',),
'skramleorkestre': ('skramleorkester',),
'skramleorkestrene': ('skramleorkester',),
'skramleorkestret': ('skramleorkester',),
'skramma': ('skramme',),
'skramme': ('skramme',),
'skrammen': ('skramme',),
'skrammene': ('skramme',),
'skrammer': ('skramme',),
'skramla': ('skrammel',),
'skramlene': ('skrammel',),
'skramler': ('skrammel',),
'skramlet': ('skrammel',),
'skrammel': ('skrammel',),
'skrammelet': ('skrammel',),
'skrangel': ('skrangel',),
'skrangelet': ('skrangel',),
'skrangla': ('skrangel',),
'skranglene': ('skrangel',),
'skrangler': ('skrangel',),
'skranglet': ('skrangel',),
'skrangla': ('skrangle',),
'skrangle': ('skrangle',),
'skranglen': ('skrangle',),
'skranglene': ('skrangle',),
'skrangler': ('skrangle',),
'skranglekjerra': ('skranglekjerre',),
'skranglekjerre': ('skranglekjerre',),
'skranglekjerren': ('skranglekjerre',),
'skranglekjerrene': ('skranglekjerre',),
'skranglekjerrer': ('skranglekjerre',),
'skranke': ('skranke',),
'skranken': ('skranke',),
'skrankene': ('skranke',),
'skranker': ('skranke',),
'skrankeadvokat': ('skrankeadvokat',),
'skrankeadvokaten': ('skrankeadvokat',),
'skrankeadvokatene': ('skrankeadvokat',),
'skrankeadvokater': ('skrankeadvokat',),
'skrankebetjening': ('skrankebetjening',),
'skrankebetjeninga': ('skrankebetjening',),
'skrankebetjeningen': ('skrankebetjening',),
'skrankebetjeningene': ('skrankebetjening',),
'skrankebetjeninger': ('skrankebetjening',),
'skrap': ('skrap',),
'skrapa': ('skrap',),
'skrapene': ('skrap',),
'skrapet': ('skrap',),
'skrapa': ('skrape',),
'skrape': ('skrape',),
'skrapen': ('skrape',),
'skrapene': ('skrape',),
'skraper': ('skrape',),
'skrapa': ('skrape',),
'skrape': ('skrape',),
'skrapen': ('skrape',),
'skrapene': ('skrape',),
'skraper': ('skrape',),
'skrapelodd': ('skrapelodd',),
'skrapelodda': ('skrapelodd',),
'skrapeloddene': ('skrapelodd',),
'skrapelodder': ('skrapelodd',),
'skrapeloddet': ('skrapelodd',),
'skraper': ('skraper',),
'skrapere': ('skraper',),
'skraperen': ('skraper',),
'skraperer': ('skraper',),
'skraperne': ('skraper',),
'skrapesjuka': ('skrapesjuke',),
'skrapesjuke': ('skrapesjuke',),
'skrapesjuken': ('skrapesjuke',),
'skrapesjukene': ('skrapesjuke',),
'skrapesjuker': ('skrapesjuke',),
'skrapesyka': ('skrapesyke',),
'skrapesyke': ('skrapesyke',),
'skrapesyken': ('skrapesyke',),
'skrapesykene': ('skrapesyke',),
'skrapesyker': ('skrapesyke',),
'skraphandel': ('skraphandel',),
'skraphandelen': ('skraphandel',),
'skraphandlene': ('skraphandel',),
'skraphandler': ('skraphandel',),
'skraphandler': ('skraphandler',),
'skraphandlere': ('skraphandler',),
'skraphandleren': ('skraphandler',),
'skraphandlerer': ('skraphandler',),
'skraphandlerne': ('skraphandler',),
'skraphaug': ('skraphaug',),
'skraphaugen': ('skraphaug',),
'skraphaugene': ('skraphaug',),
'skraphauger': ('skraphaug',),
'skrapjern': ('skrapjern',),
'skrapjerna': ('skrapjern',),
'skrapjernene': ('skrapjern',),
'skrapjernet': ('skrapjern',),
'skrapslått': ('skrapslått',),
'skrapslåtten': ('skrapslått',),
'skrapslåttene': ('skrapslått',),
'skrapslåtter': ('skrapslått',),
'skrasl': ('skrasl',),
'skrasla': ('skrasl',),
'skraslene': ('skrasl',),
'skraslet': ('skrasl',),
'skrasla': ('skrassel',),
'skraslene': ('skrassel',),
'skrasler': ('skrassel',),
'skraslet': ('skrassel',),
'skrassel': ('skrassel',),
'skrasselet': ('skrassel',),
'skratl': ('skratl',),
'skratla': ('skratl',),
'skratlene': ('skratl',),
'skratlet': ('skratl',),
'skratt': ('skratt',),
'skratta': ('skratt',),
'skratten': ('skratt',),
'skrattene': ('skratt',),
'skrattet': ('skratt',),
'skravl': ('skravl',),
'skravla': ('skravl',),
'skravlene': ('skravl',),
'skravlet': ('skravl',),
'skravl': ('skravl',),
'skravla': ('skravl',),
'skravlen': ('skravl',),
'skravlene': ('skravl',),
'skravler': ('skravl',),
'skravla': ('skravle',),
'skravle': ('skravle',),
'skravlen': ('skravle',),
'skravlene': ('skravle',),
'skravler': ('skravle',),
'skravlebøtta': ('skravlebøtte',),
'skravlebøtte': ('skravlebøtte',),
'skravlebøtten': ('skravlebøtte',),
'skravlebøttene': ('skravlebøtte',),
'skravlebøtter': ('skravlebøtte',),
'skred': ('skred',),
'skreda': ('skred',),
'skredene': ('skred',),
'skredet': ('skred',),
'skredder': ('skredder',),
'skreddere': ('skredder',),
'skredderen': ('skredder',),
'skredderer': ('skredder',),
'skredderne': ('skredder',),
'skredderi': ('skredderi',),
'skredderia': ('skredderi',),
'skredderiene': ('skredderi',),
'skredderier': ('skredderi',),
'skredderiet': ('skredderi',),
'skreddersaks': ('skreddersaks',),
'skreddersaksa': ('skreddersaks',),
'skreddersaksen': ('skreddersaks',),
'skreddersaksene': ('skreddersaks',),
'skreddersakser': ('skreddersaks',),
'skredderstilling': ('skredderstilling',),
'skredderstillinga': ('skredderstilling',),
'skredderstillingen': ('skredderstilling',),
'skredderstillingene': ('skredderstilling',),
'skredderstillinger': ('skredderstilling',),
'skreddersvenn': ('skreddersvenn',),
'skreddersvennen': ('skreddersvenn',),
'skreddersvennene': ('skreddersvenn',),
'skreddersvenner': ('skreddersvenn',),
'skreddersøm': ('skreddersøm',),
'skreddersømmen': ('skreddersøm',),
'skreddersømmene': ('skreddersøm',),
'skreddersømmer': ('skreddersøm',),
'skreddertime': ('skreddertime',),
'skreddertimen': ('skreddertime',),
'skreddertimene': ('skreddertime',),
'skreddertimer': ('skreddertime',),
'skredfare': ('skredfare',),
'skredfaren': ('skredfare',),
'skredfarene': ('skredfare',),
'skredfarer': ('skredfare',),
'skredforsker': ('skredforsker',),
'skredforskere': ('skredforsker',),
'skredforskeren': ('skredforsker',),
'skredforskerer': ('skredforsker',),
'skredforskerne': ('skredforsker',),
'skrei': ('skrei',),
'skreien': ('skrei',),
'skreiene': ('skrei',),
'skreier': ('skrei',),
'skrei': ('skrei',),
'skreien': ('skrei',),
'skreiene': ('skrei',),
'skreier': ('skrei',),
'skreifiska': ('skreifiske',),
'skreifiske': ('skreifiske',),
'skreifiskene': ('skreifiske',),
'skreifisker': ('skreifiske',),
'skreifisket': ('skreifiske',),
'skrekk': ('skrekk',),
'skrekken': ('skrekk',),
'skrekkene': ('skrekk',),
'skrekker': ('skrekk',),
'skrekkfilm': ('skrekkfilm',),
'skrekkfilmen': ('skrekkfilm',),
'skrekkfilmene': ('skrekkfilm',),
'skrekkfilmer': ('skrekkfilm',),
'skrekkvelda': ('skrekkvelde',),
'skrekkvelde': ('skrekkvelde',),
'skrekkveldene': ('skrekkvelde',),
'skrekkvelder': ('skrekkvelde',),
'skrekkveldet': ('skrekkvelde',),
'skrekkøgla': ('skrekkøgle',),
'skrekkøgle': ('skrekkøgle',),
'skrekkøglen': ('skrekkøgle',),
'skrekkøglene': ('skrekkøgle',),
'skrekkøgler': ('skrekkøgle',),
'skrell': ('skrell',),
'skrella': ('skrell',),
'skrellene': ('skrell',),
'skrellet': ('skrell',),
'skrell': ('skrell',),
'skrella': ('skrell',),
'skrellen': ('skrell',),
'skrellene': ('skrell',),
'skrellet': ('skrell',),
'skreller': ('skreller',),
'skrellere': ('skreller',),
'skrelleren': ('skreller',),
'skrellerer': ('skreller',),
'skrellerne': ('skreller',),
'skrelling': ('skrelling',),
'skrellingen': ('skrelling',),
'skrellingene': ('skrelling',),
'skrellinger': ('skrelling',),
'skremmebilda': ('skremmebilde',),
'skremmebilde': ('skremmebilde',),
'skremmebildene': ('skremmebilde',),
'skremmebilder': ('skremmebilde',),
'skremmebildet': ('skremmebilde',),
'skremmeskott': ('skremmeskott',),
'skremmeskotta': ('skremmeskott',),
'skremmeskottene': ('skremmeskott',),
'skremmeskottet': ('skremmeskott',),
'skremmeskudd': ('skremmeskudd',),
'skremmeskudda': ('skremmeskudd',),
'skremmeskuddene': ('skremmeskudd',),
'skremmeskuddet': ('skremmeskudd',),
'skremsel': ('skremsel',),
'skremselen': ('skremsel',),
'skremslene': ('skremsel',),
'skremsler': ('skremsel',),
'skremsel': ('skremsel',),
'skremselet': ('skremsel',),
'skremsla': ('skremsel',),
'skremslene': ('skremsel',),
'skremsler': ('skremsel',),
'skremslet': ('skremsel',),
'skremselspropaganda': ('skremselspropaganda',),
'skremselspropagandaen': ('skremselspropaganda',),
'skremselspropagandaene': ('skremselspropaganda',),
'skremselspropagandaer': ('skremselspropaganda',),
'skrens': ('skrens',),
'skrensen': ('skrens',),
'skrensene': ('skrens',),
'skrenser': ('skrens',),
'skrent': ('skrent',),
'skrenten': ('skrent',),
'skrentene': ('skrent',),
'skrenter': ('skrent',),
'skrepp': ('skrepp',),
'skreppa': ('skrepp',),
'skreppene': ('skrepp',),
'skreppet': ('skrepp',),
'skreppa': ('skreppe',),
'skreppe': ('skreppe',),
'skreppen': ('skreppe',),
'skreppene': ('skreppe',),
'skrepper': ('skreppe',),
'skreppehandel': ('skreppehandel',),
'skreppehandelen': ('skreppehandel',),
'skreppehandlene': ('skreppehandel',),
'skreppehandler': ('skreppehandel',),
'skreppekar': ('skreppekar',),
'skreppekaren': ('skreppekar',),
'skreppekarene': ('skreppekar',),
'skreppekarer': ('skreppekar',),
'skrev': ('skrev',),
'skreva': ('skrev',),
'skrevene': ('skrev',),
'skrevet': ('skrev',),
'skribent': ('skribent',),
'skribenten': ('skribent',),
'skribentene': ('skribent',),
'skribenter': ('skribent',),
'skribentvirksomhet': ('skribentvirksomhet',),
'skribentvirksomheta': ('skribentvirksomhet',),
'skribentvirksomheten': ('skribentvirksomhet',),
'skribentvirksomhetene': ('skribentvirksomhet',),
'skribentvirksomheter': ('skribentvirksomhet',),
'skribler': ('skribler',),
'skriblere': ('skribler',),
'skribleren': ('skribler',),
'skriblerer': ('skribler',),
'skriblerne': ('skribler',),
'skribleri': ('skribleri',),
'skribleria': ('skribleri',),
'skribleriene': ('skribleri',),
'skriblerier': ('skribleri',),
'skribleriet': ('skribleri',),
'skria': ('skrie',),
'skrie': ('skrie',),
'skrien': ('skrie',),
'skriene': ('skrie',),
'skrier': ('skrie',),
'skrift': ('skrift',),
'skrifta': ('skrift',),
'skriftene': ('skrift',),
'skrifter': ('skrift',),
'skriftet': ('skrift',),
'skrift': ('skrift',),
'skrifta': ('skrift',),
'skriften': ('skrift',),
'skriftene': ('skrift',),
'skrifter': ('skrift',),
'skriftbilda': ('skriftbilde',),
'skriftbilde': ('skriftbilde',),
'skriftbildene': ('skriftbilde',),
'skriftbilder': ('skriftbilde',),
'skriftbildet': ('skriftbilde',),
'skrifta': ('skrifte',),
'skrifte': ('skrifte',),
'skriftene': ('skrifte',),
'skrifter': ('skrifte',),
'skriftet': ('skrifte',),
'skriftemål': ('skriftemål',),
'skriftemåla': ('skriftemål',),
'skriftemålene': ('skriftemål',),
'skriftemålet': ('skriftemål',),
'skriftestol': ('skriftestol',),
'skriftestolen': ('skriftestol',),
'skriftestolene': ('skriftestol',),
'skriftestoler': ('skriftestol',),
'skriftform': ('skriftform',),
'skriftforma': ('skriftform',),
'skriftformen': ('skriftform',),
'skriftformene': ('skriftform',),
'skriftformer': ('skriftform',),
'skriftlesning': ('skriftlesning',),
'skriftlesninga': ('skriftlesning',),
'skriftlesningen': ('skriftlesning',),
'skriftlesningene': ('skriftlesning',),
'skriftlesninger': ('skriftlesning',),
'skriftmål': ('skriftmål',),
'skriftmåla': ('skriftmål',),
'skriftmålene': ('skriftmål',),
'skriftmålet': ('skriftmål',),
'skriftprinsipp': ('skriftprinsipp',),
'skriftprinsippa': ('skriftprinsipp',),
'skriftprinsippene': ('skriftprinsipp',),
'skriftprinsipper': ('skriftprinsipp',),
'skriftprinsippet': ('skriftprinsipp',),
'skriftprojektor': ('skriftprojektor',),
'skriftprojektoren': ('skriftprojektor',),
'skriftprojektorene': ('skriftprojektor',),
'skriftprojektorer': ('skriftprojektor',),
'skriftprosjektør': ('skriftprosjektør',),
'skriftprosjektøren': ('skriftprosjektør',),
'skriftprosjektørene': ('skriftprosjektør',),
'skriftprosjektører': ('skriftprosjektør',),
'skriftspråk': ('skriftspråk',),
'skriftspråka': ('skriftspråk',),
'skriftspråkene': ('skriftspråk',),
'skriftspråket': ('skriftspråk',),
'skriftsted': ('skriftsted',),
'skriftstedene': ('skriftsted',),
'skriftsteder': ('skriftsted',),
'skriftstedet': ('skriftsted',),
'skriftstyra': ('skriftstyre',),
'skriftstyre': ('skriftstyre',),
'skriftstyrene': ('skriftstyre',),
'skriftstyrer': ('skriftstyre',),
'skriftstyret': ('skriftstyre',),
'skriftstyrer': ('skriftstyrer',),
'skriftstyrere': ('skriftstyrer',),
'skriftstyreren': ('skriftstyrer',),
'skriftstyrerer': ('skriftstyrer',),
'skriftstyrerne': ('skriftstyrer',),
'skriftstøper': ('skriftstøper',),
'skriftstøpere': ('skriftstøper',),
'skriftstøperen': ('skriftstøper',),
'skriftstøperer': ('skriftstøper',),
'skriftstøperne': ('skriftstøper',),
'skriftstøyper': ('skriftstøyper',),
'skriftstøypere': ('skriftstøyper',),
'skriftstøyperen': ('skriftstøyper',),
'skriftstøyperer': ('skriftstøyper',),
'skriftstøyperne': ('skriftstøyper',),
'skrifttegn': ('skrifttegn',),
'skrifttegna': ('skrifttegn',),
'skrifttegnene': ('skrifttegn',),
'skrifttegnet': ('skrifttegn',),
'skrifttype': ('skrifttype',),
'skrifttypen': ('skrifttype',),
'skrifttypene': ('skrifttype',),
'skrifttyper': ('skrifttype',),
'skriftutlegning': ('skriftutlegning',),
'skriftutlegninga': ('skriftutlegning',),
'skriftutlegningen': ('skriftutlegning',),
'skriftutlegningene': ('skriftutlegning',),
'skriftutlegninger': ('skriftutlegning',),
'skrik': ('skrik',),
'skrika': ('skrik',),
'skrikene': ('skrik',),
'skriket': ('skrik',),
'skrika': ('skrike',),
'skrike': ('skrike',),
'skriken': ('skrike',),
'skrikene': ('skrike',),
'skriker': ('skrike',),
'skrikerunge': ('skrikerunge',),
'skrikerungen': ('skrikerunge',),
'skrikerungene': ('skrikerunge',),
'skrikerunger': ('skrikerunge',),
'skrikhals': ('skrikhals',),
'skrikhalsen': ('skrikhals',),
'skrikhalsene': ('skrikhals',),
'skrikhalser': ('skrikhals',),
'skrin': ('skrin',),
'skrina': ('skrin',),
'skrinene': ('skrin',),
'skrinet': ('skrin',),
'skritt': ('skritt',),
'skritta': ('skritt',),
'skrittene': ('skritt',),
'skrittet': ('skritt',),
'skrittgang': ('skrittgang',),
'skrittgangen': ('skrittgang',),
'skrittgangene': ('skrittgang',),
'skrittganger': ('skrittgang',),
'skriv': ('skriv',),
'skriva': ('skriv',),
'skrivene': ('skriv',),
'skrivet': ('skriv',),
'skrivarbrød': ('skrivarbrød',),
'skrivarbrøda': ('skrivarbrød',),
'skrivarbrødene': ('skrivarbrød',),
'skrivarbrødet': ('skrivarbrød',),
'skrivebord': ('skrivebord',),
'skriveborda': ('skrivebord',),
'skrivebordene': ('skrivebord',),
'skriveborder': ('skrivebord',),
'skrivebordet': ('skrivebord',),
'skrivebordsprodukt': ('skrivebordsprodukt',),
'skrivebordsprodukta': ('skrivebordsprodukt',),
'skrivebordsproduktene': ('skrivebordsprodukt',),
'skrivebordsprodukter': ('skrivebordsprodukt',),
'skrivebordsproduktet': ('skrivebordsprodukt',),
'skrivebordssetting': ('skrivebordssetting',),
'skrivebordssettinga': ('skrivebordssetting',),
'skrivebordssettingen': ('skrivebordssetting',),
'skrivebordssettingene': ('skrivebordssetting',),
'skrivebordssettinger': ('skrivebordssetting',),
'skriveenhet': ('skriveenhet',),
'skriveenheten': ('skriveenhet',),
'skriveenhetene': ('skriveenhet',),
'skriveenheter': ('skriveenhet',),
'skrivefeil': ('skrivefeil',),
'skrivefeilen': ('skrivefeil',),
'skrivefeilene': ('skrivefeil',),
'skriveferdighet': ('skriveferdighet',),
'skriveferdigheta': ('skriveferdighet',),
'skriveferdigheten': ('skriveferdighet',),
'skriveferdighetene': ('skriveferdighet',),
'skriveferdigheter': ('skriveferdighet',),
'skriveklaff': ('skriveklaff',),
'skriveklaffen': ('skriveklaff',),
'skriveklaffene': ('skriveklaff',),
'skriveklaffer': ('skriveklaff',),
'skrivekløe': ('skrivekløe',),
'skrivekløen': ('skrivekløe',),
'skrivekløene': ('skrivekløe',),
'skrivekløer': ('skrivekløe',),
'skrivekrampe': ('skrivekrampe',),
'skrivekrampen': ('skrivekrampe',),
'skrivekrampene': ('skrivekrampe',),
'skrivekramper': ('skrivekrampe',),
'skrivekunst': ('skrivekunst',),
'skrivekunsten': ('skrivekunst',),
'skrivekunstene': ('skrivekunst',),
'skrivekunster': ('skrivekunst',),
'skrivelse': ('skrivelse',),
'skrivelsen': ('skrivelse',),
'skrivelsene': ('skrivelse',),
'skrivelser': ('skrivelse',),
'skrivemaskin': ('skrivemaskin',),
'skrivemaskina': ('skrivemaskin',),
'skrivemaskinen': ('skrivemaskin',),
'skrivemaskinene': ('skrivemaskin',),
'skrivemaskiner': ('skrivemaskin',),
'skrivemåte': ('skrivemåte',),
'skrivemåten': ('skrivemåte',),
'skrivemåtene': ('skrivemåte',),
'skrivemåter': ('skrivemåte',),
'skrivepapir': ('skrivepapir',),
'skrivepapira': ('skrivepapir',),
'skrivepapirene': ('skrivepapir',),
'skrivepapirer': ('skrivepapir',),
'skrivepapiret': ('skrivepapir',),
'skrivepult': ('skrivepult',),
'skrivepulten': ('skrivepult',),
'skrivepultene': ('skrivepult',),
'skrivepulter': ('skrivepult',),
'skriver': ('skriver',),
'skrivere': ('skriver',),
'skriveren': ('skriver',),
'skriverer': ('skriver',),
'skriverne': ('skriver',),
'skrivergard': ('skrivergard',),
'skrivergarden': ('skrivergard',),
'skrivergardene': ('skrivergard',),
'skrivergarder': ('skrivergard',),
'skrivergård': ('skrivergård',),
'skrivergården': ('skrivergård',),
'skrivergårdene': ('skrivergård',),
'skrivergårder': ('skrivergård',),
'skriveri': ('skriveri',),
'skriveria': ('skriveri',),
'skriveriene': ('skriveri',),
'skriverier': ('skriveri',),
'skriveriet': ('skriveri',),
'skriverkar': ('skriverkar',),
'skriverkaren': ('skriverkar',),
'skriverkarene': ('skriverkar',),
'skriverkarer': ('skriverkar',),
'skrivesakene': ('skrivesaker',),
'skrivesaker': ('skrivesaker',),
'skrivestova': ('skrivestove',),
'skrivestove': ('skrivestove',),
'skrivestoven': ('skrivestove',),
'skrivestovene': ('skrivestove',),
'skrivestover': ('skrivestove',),
'skrivestua': ('skrivestue',),
'skrivestue': ('skrivestue',),
'skrivestuen': ('skrivestue',),
'skrivestuene': ('skrivestue',),
'skrivestuer': ('skrivestue',),
'skriving': ('skriving',),
'skrivinga': ('skriving',),
'skrivingen': ('skriving',),
'skrivingene': ('skriving',),
'skrivinger': ('skriving',),
'skrivning': ('skrivning',),
'skrivninga': ('skrivning',),
'skrivningen': ('skrivning',),
'skrivningene': ('skrivning',),
'skrivninger': ('skrivning',),
'skrofulose': ('skrofulose',),
'skrofulosen': ('skrofulose',),
'skrofulosene': ('skrofulose',),
'skrofuloser': ('skrofulose',),
'skrog': ('skrog',),
'skroga': ('skrog',),
'skrogene': ('skrog',),
'skroget': ('skrog',),
'skrot': ('skrot',),
'skrota': ('skrot',),
'skrotene': ('skrot',),
'skrotet': ('skrot',),
'skrotdunge': ('skrotdunge',),
'skrotdungen': ('skrotdunge',),
'skrotdungene': ('skrotdunge',),
'skrotdunger': ('skrotdunge',),
'skrott': ('skrott',),
'skrotten': ('skrott',),
'skrottene': ('skrott',),
'skrotter': ('skrott',),
'skrov': ('skrov',),
'skrova': ('skrov',),
'skrovene': ('skrov',),
'skrovet': ('skrov',),
'skrov': ('skrov',),
'skrova': ('skrov',),
'skrovene': ('skrov',),
'skrovet': ('skrov',),
'skrovis': ('skrovis',),
'skrovisen': ('skrovis',),
'skrovisene': ('skrovis',),
'skroviser': ('skrovis',),
'skru': ('skru',),
'skruen': ('skru',),
'skruene': ('skru',),
'skruer': ('skru',),
'skruball': ('skruball',),
'skruballen': ('skruball',),
'skruballene': ('skruball',),
'skruballer': ('skruball',),
'skrubb': ('skrubb',),
'skrubben': ('skrubb',),
'skrubbene': ('skrubb',),
'skrubber': ('skrubb',),
'skrubb': ('skrubb',),
'skrubba': ('skrubb',),
'skrubben': ('skrubb',),
'skrubbene': ('skrubb',),
'skrubber': ('skrubb',),
'skrubbet': ('skrubb',),
'skrubb-bær': ('skrubb-bær',),
'skrubb-bæra': ('skrubb-bær',),
'skrubb-bærene': ('skrubb-bær',),
'skrubb-bæret': ('skrubb-bær',),
'skrubb-bær': ('skrubb-bær',),
'skrubb-bæra': ('skrubb-bær',),
'skrubb-bærene': ('skrubb-bær',),
'skrubb-bæret': ('skrubb-bær',),
'skrubba': ('skrubbe',),
'skrubbe': ('skrubbe',),
'skrubben': ('skrubbe',),
'skrubbene': ('skrubbe',),
'skrubber': ('skrubbe',),
'skrubbekost': ('skrubbekost',),
'skrubbekosten': ('skrubbekost',),
'skrubbekostene': ('skrubbekost',),
'skrubbekoster': ('skrubbekost',),
'skrubber': ('skrubber',),
'skrubbere': ('skrubber',),
'skrubberen': ('skrubber',),
'skrubberer': ('skrubber',),
'skrubberne': ('skrubber',),
'skrubbhøvel': ('skrubbhøvel',),
'skrubbhøvelen': ('skrubbhøvel',),
'skrubbhøvlene': ('skrubbhøvel',),
'skrubbhøvler': ('skrubbhøvel',),
'skrubbsår': ('skrubbsår',),
'skrubbsåra': ('skrubbsår',),
'skrubbsårene': ('skrubbsår',),
'skrubbsåret': ('skrubbsår',),
'skrubbær': ('skrubbær',),
'skrubbæra': ('skrubbær',),
'skrubbærene': ('skrubbær',),
'skrubbæret': ('skrubbær',),
'skrubbær': ('skrubbær',),
'skrubbæra': ('skrubbær',),
'skrubbærene': ('skrubbær',),
'skrubbæret': ('skrubbær',),
'skrublyant': ('skrublyant',),
'skrublyanten': ('skrublyant',),
'skrublyantene': ('skrublyant',),
'skrublyanter': ('skrublyant',),
'skrud': ('skrud',),
'skruda': ('skrud',),
'skrudene': ('skrud',),
'skrudet': ('skrud',),
'skrue': ('skrue',),
'skruen': ('skrue',),
'skruene': ('skrue',),
'skruer': ('skrue',),
'skrue': ('skrue',),
'skruen': ('skrue',),
'skruene': ('skrue',),
'skruer': ('skrue',),
'skruemutrene': ('skruemutter',),
'skruemutrer': ('skruemutter',),
'skruemutter': ('skruemutter',),
'skruemuttere': ('skruemutter',),
'skruemutteren': ('skruemutter',),
'skruemutterer': ('skruemutter',),
'skruemutterne': ('skruemutter',),
'skruemutrene': ('skruemutter',),
'skruemutrer': ('skruemutter',),
'skruemutter': ('skruemutter',),
'skruemuttere': ('skruemutter',),
'skruemutteren': ('skruemutter',),
'skruemutterer': ('skruemutter',),
'skruemutterne': ('skruemutter',),
'skruestikka': ('skruestikke',),
'skruestikke': ('skruestikke',),
'skruestikken': ('skruestikke',),
'skruestikkene': ('skruestikke',),
'skruestikker': ('skruestikke',),
'skruestikka': ('skruestikke',),
'skruestikke': ('skruestikke',),
'skruestikken': ('skruestikke',),
'skruestikkene': ('skruestikke',),
'skruestikker': ('skruestikke',),
'skrugard': ('skrugard',),
'skrugarden': ('skrugard',),
'skrugardene': ('skrugard',),
'skrugarder': ('skrugard',),
'skruis': ('skruis',),
'skruisen': ('skruis',),
'skruisene': ('skruis',),
'skruiser': ('skruis',),
'skrujern': ('skrujern',),
'skrujerna': ('skrujern',),
'skrujernene': ('skrujern',),
'skrujernet': ('skrujern',),
'skrukk': ('skrukk',),
'skrukken': ('skrukk',),
'skrukkene': ('skrukk',),
'skrukker': ('skrukk',),
'skrukka': ('skrukke',),
'skrukke': ('skrukke',),
'skrukken': ('skrukke',),
'skrukkene': ('skrukke',),
'skrukker': ('skrukke',),
'skrukketroll': ('skrukketroll',),
'skrukketrolla': ('skrukketroll',),
'skrukketrollene': ('skrukketroll',),
'skrukketrollet': ('skrukketroll',),
'skrukork': ('skrukork',),
'skrukorken': ('skrukork',),
'skrukorkene': ('skrukork',),
'skrukorker': ('skrukork',),
'skrulla': ('skrulle',),
'skrulle': ('skrulle',),
'skrullen': ('skrulle',),
'skrullene': ('skrulle',),
'skruller': ('skrulle',),
'skrulling': ('skrulling',),
'skrullingen': ('skrulling',),
'skrullingene': ('skrulling',),
'skrullinger': ('skrulling',),
'skrulokk': ('skrulokk',),
'skrulokken': ('skrulokk',),
'skrulokkene': ('skrulokk',),
'skrulokker': ('skrulokk',),
'skrumor': ('skrumor',),
'skrumora': ('skrumor',),
'skrumoren': ('skrumor',),
'skrumorene': ('skrumor',),
'skrumorer': ('skrumor',),
'skrumplever': ('skrumplever',),
'skrumplevere': ('skrumplever',),
'skrumpleveren': ('skrumplever',),
'skrumpleverer': ('skrumplever',),
'skrumpleverne': ('skrumplever',),
'skrumplevra': ('skrumplever',),
'skrumplevre': ('skrumplever',),
'skrumplevrene': ('skrumplever',),
'skrumplevrer': ('skrumplever',),
'skrumpnyra': ('skrumpnyre',),
'skrumpnyre': ('skrumpnyre',),
'skrumpnyren': ('skrumpnyre',),
'skrumpnyrene': ('skrumpnyre',),
'skrumpnyrer': ('skrumpnyre',),
'skrumpnyret': ('skrumpnyre',),
'skrunøkkel': ('skrunøkkel',),
'skrunøkkelen': ('skrunøkkel',),
'skrunøklene': ('skrunøkkel',),
'skrunøkler': ('skrunøkkel',),
'skruplene': ('skruppel',),
'skrupler': ('skruppel',),
'skruppel': ('skruppel',),
'skruppelen': ('skruppel',),
'skrustikka': ('skrustikke',),
'skrustikke': ('skrustikke',),
'skrustikken': ('skrustikke',),
'skrustikkene': ('skrustikke',),
'skrustikker': ('skrustikke',),
'skrustikka': ('skrustikke',),
'skrustikke': ('skrustikke',),
'skrustikken': ('skrustikke',),
'skrustikkene': ('skrustikke',),
'skrustikker': ('skrustikke',),
'skrutrekker': ('skrutrekker',),
'skrutrekkere': ('skrutrekker',),
'skrutrekkeren': ('skrutrekker',),
'skrutrekkerer': ('skrutrekker',),
'skrutrekkerne': ('skrutrekker',),
'skrutvinga': ('skrutvinge',),
'skrutvinge': ('skrutvinge',),
'skrutvingen': ('skrutvinge',),
'skrutvingene': ('skrutvinge',),
'skrutvinger': ('skrutvinge',),
'skruv': ('skruv',),
'skruven': ('skruv',),
'skruvene': ('skruv',),
'skruver': ('skruv',),
'skruve': ('skruve',),
'skruven': ('skruve',),
'skruvene': ('skruve',),
'skruver': ('skruve',),
'skruve': ('skruve',),
'skruven': ('skruve',),
'skruvene': ('skruve',),
'skruver': ('skruve',),
'skruvemutrene': ('skruvemutter',),
'skruvemutrer': ('skruvemutter',),
'skruvemutter': ('skruvemutter',),
'skruvemuttere': ('skruvemutter',),
'skruvemutteren': ('skruvemutter',),
'skruvemutterer': ('skruvemutter',),
'skruvemutterne': ('skruvemutter',),
'skruvemutrene': ('skruvemutter',),
'skruvemutrer': ('skruvemutter',),
'skruvemutter': ('skruvemutter',),
'skruvemuttere': ('skruvemutter',),
'skruvemutteren': ('skruvemutter',),
'skruvemutterer': ('skruvemutter',),
'skruvemutterne': ('skruvemutter',),
'skruvestikka': ('skruvestikke',),
'skruvestikke': ('skruvestikke',),
'skruvestikken': ('skruvestikke',),
'skruvestikkene': ('skruvestikke',),
'skruvestikker': ('skruvestikke',),
'skruvestikka': ('skruvestikke',),
'skruvestikke': ('skruvestikke',),
'skruvestikken': ('skruvestikke',),
'skruvestikkene': ('skruvestikke',),
'skruvestikker': ('skruvestikke',),
'skryt': ('skryt',),
'skryta': ('skryt',),
'skrytene': ('skryt',),
'skrytet': ('skryt',),
'skrytepave': ('skrytepave',),
'skrytepaven': ('skrytepave',),
'skrytepavene': ('skrytepave',),
'skrytepaver': ('skrytepave',),
'skryter': ('skryter',),
'skrytere': ('skryter',),
'skryteren': ('skryter',),
'skryterer': ('skryter',),
'skryterne': ('skryter',),
'skrythals': ('skrythals',),
'skrythalsen': ('skrythals',),
'skrythalsene': ('skrythals',),
'skrythalser': ('skrythals',),
'skråband': ('skråband',),
'skråbanda': ('skråband',),
'skråbandene': ('skråband',),
'skråbandet': ('skråband',),
'skråbånd': ('skråbånd',),
'skråbånda': ('skråbånd',),
'skråbåndene': ('skråbånd',),
'skråbåndet': ('skråbånd',),
'skrål': ('skrål',),
'skråla': ('skrål',),
'skrålene': ('skrål',),
'skrålet': ('skrål',),
'skrålhals': ('skrålhals',),
'skrålhalsen': ('skrålhals',),
'skrålhalsene': ('skrålhals',),
'skrålhalser': ('skrålhals',),
'skråma': ('skråme',),
'skråme': ('skråme',),
'skråmen': ('skråme',),
'skråmene': ('skråme',),
'skråmer': ('skråme',),
'skråning': ('skråning',),
'skråninga': ('skråning',),
'skråningen': ('skråning',),
'skråningene': ('skråning',),
'skråninger': ('skråning',),
'skråplan': ('skråplan',),
'skråplana': ('skråplan',),
'skråplanene': ('skråplan',),
'skråplanet': ('skråplan',),
'skråskrift': ('skråskrift',),
'skråskrifta': ('skråskrift',),
'skråskriften': ('skråskrift',),
'skråskriftene': ('skråskrift',),
'skråskrifter': ('skråskrift',),
'skråstrek': ('skråstrek',),
'skråstreken': ('skråstrek',),
'skråstrekene': ('skråstrek',),
'skråstreker': ('skråstrek',),
'skråtak': ('skråtak',),
'skråtaka': ('skråtak',),
'skråtakene': ('skråtak',),
'skråtaket': ('skråtak',),
'skråtobakk': ('skråtobakk',),
'skråtobakken': ('skråtobakk',),
'skråtobakkene': ('skråtobakk',),
'skråtobakker': ('skråtobakk',),
'skræling': ('skræling',),
'skrælingen': ('skræling',),
'skrælingene': ('skræling',),
'skrælinger': ('skræling',),
'skrø': ('skrø',),
'skrøen': ('skrø',),
'skrøene': ('skrø',),
'skrøer': ('skrø',),
'skrøfterug': ('skrøfterug',),
'skrøfterugen': ('skrøfterug',),
'skrøfterugene': ('skrøfterug',),
'skrøfteruger': ('skrøfterug',),
'skrømt': ('skrømt',),
'skrømta': ('skrømt',),
'skrømtene': ('skrømt',),
'skrømtet': ('skrømt',),
'skrøn': ('skrøn',),
'skrøna': ('skrøn',),
'skrønene': ('skrøn',),
'skrønet': ('skrøn',),
'skrøna': ('skrøne',),
'skrøne': ('skrøne',),
'skrønen': ('skrøne',),
'skrønene': ('skrøne',),
'skrøner': ('skrøne',),
'skrønemaker': ('skrønemaker',),
'skrønemakere': ('skrønemaker',),
'skrønemakeren': ('skrønemaker',),
'skrønemakerer': ('skrønemaker',),
'skrønemakerne': ('skrønemaker',),
'skubb': ('skubb',),
'skubba': ('skubb',),
'skubben': ('skubb',),
'skubbene': ('skubb',),
'skubbet': ('skubb',),
'skudd': ('skudd',),
'skudda': ('skudd',),
'skuddene': ('skudd',),
'skuddet': ('skudd',),
'skudd-dag': ('skudd-dag',),
'skudd-dagen': ('skudd-dag',),
'skudd-dagene': ('skudd-dag',),
'skudd-dager': ('skudd-dag',),
'skuddag': ('skuddag',),
'skuddagen': ('skuddag',),
'skuddagene': ('skuddag',),
'skuddager': ('skuddag',),
'skuddarm': ('skuddarm',),
'skuddarmen': ('skuddarm',),
'skuddarmene': ('skuddarm',),
'skuddarmer': ('skuddarm',),
'skuddbein': ('skuddbein',),
'skuddbeina': ('skuddbein',),
'skuddbeinene': ('skuddbein',),
'skuddbeinet': ('skuddbein',),
'skuddben': ('skuddben',),
'skuddbena': ('skuddben',),
'skuddbenene': ('skuddben',),
'skuddbenet': ('skuddben',),
'skuddermudder': ('skuddermudder',),
'skuddermuddera': ('skuddermudder',),
'skuddermuddere': ('skuddermudder',),
'skuddermudderene': ('skuddermudder',),
'skuddermudderet': ('skuddermudder',),
'skuddermudderne': ('skuddermudder',),
'skuddfelt': ('skuddfelt',),
'skuddfelta': ('skuddfelt',),
'skuddfeltene': ('skuddfelt',),
'skuddfelter': ('skuddfelt',),
'skuddfeltet': ('skuddfelt',),
'skuddhold': ('skuddhold',),
'skuddholda': ('skuddhold',),
'skuddholdene': ('skuddhold',),
'skuddholdet': ('skuddhold',),
'skuddlinja': ('skuddlinje',),
'skuddlinje': ('skuddlinje',),
'skuddlinjen': ('skuddlinje',),
'skuddlinjene': ('skuddlinje',),
'skuddlinjer': ('skuddlinje',),
'skuddmåned': ('skuddmåned',),
'skuddmåneden': ('skuddmåned',),
'skuddmånedene': ('skuddmåned',),
'skuddmåneder': ('skuddmåned',),
'skuddpremie': ('skuddpremie',),
'skuddpremien': ('skuddpremie',),
'skuddpremiene': ('skuddpremie',),
'skuddpremier': ('skuddpremie',),
'skuddsår': ('skuddsår',),
'skuddsåra': ('skuddsår',),
'skuddsårene': ('skuddsår',),
'skuddsåret': ('skuddsår',),
'skuddveksling': ('skuddveksling',),
'skuddvekslinga': ('skuddveksling',),
'skuddvekslingen': ('skuddveksling',),
'skuddvekslingene': ('skuddveksling',),
'skuddvekslinger': ('skuddveksling',),
'skuddår': ('skuddår',),
'skuddåra': ('skuddår',),
'skuddårene': ('skuddår',),
'skuddåret': ('skuddår',),
'skua': ('skue',),
'skue': ('skue',),
'skuene': ('skue',),
'skuer': ('skue',),
'skuet': ('skue',),
'skuebrød': ('skuebrød',),
'skuebrøda': ('skuebrød',),
'skuebrødene': ('skuebrød',),
'skuebrødet': ('skuebrød',),
'skueplass': ('skueplass',),
'skueplassen': ('skueplass',),
'skueplassene': ('skueplass',),
'skueplasser': ('skueplass',),
'skuespill': ('skuespill',),
'skuespilla': ('skuespill',),
'skuespillene': ('skuespill',),
'skuespillet': ('skuespill',),
'skuespiller': ('skuespiller',),
'skuespillere': ('skuespiller',),
'skuespilleren': ('skuespiller',),
'skuespillerer': ('skuespiller',),
'skuespillerne': ('skuespiller',),
'skuff': ('skuff',),
'skuffen': ('skuff',),
'skuffene': ('skuff',),
'skuffer': ('skuff',),
'skuffa': ('skuffe',),
'skuffe': ('skuffe',),
'skuffen': ('skuffe',),
'skuffene': ('skuffe',),
'skuffer': ('skuffe',),
'skuffa': ('skuffe',),
'skuffe': ('skuffe',),
'skuffen': ('skuffe',),
'skuffene': ('skuffe',),
'skuffer': ('skuffe',),
'skuffelse': ('skuffelse',),
'skuffelsen': ('skuffelse',),
'skuffelsene': ('skuffelse',),
'skuffelser': ('skuffelse',),
'skulder': ('skulder',),
'skulderen': ('skulder',),
'skuldra': ('skulder',),
'skuldre': ('skulder',),
'skuldrene': ('skulder',),
'skuldrer': ('skulder',),
'skulderblad': ('skulderblad',),
'skulderblada': ('skulderblad',),
'skulderbladene': ('skulderblad',),
'skulderblader': ('skulderblad',),
'skulderbladet': ('skulderblad',),
'skulderledd': ('skulderledd',),
'skulderledda': ('skulderledd',),
'skulderleddene': ('skulderledd',),
'skulderleddet': ('skulderledd',),
'skulderstykka': ('skulderstykke',),
'skulderstykke': ('skulderstykke',),
'skulderstykkene': ('skulderstykke',),
'skulderstykker': ('skulderstykke',),
'skulderstykket': ('skulderstykke',),
'skuldertrekk': ('skuldertrekk',),
'skuldertrekka': ('skuldertrekk',),
'skuldertrekkene': ('skuldertrekk',),
'skuldertrekket': ('skuldertrekk',),
'skulderveska': ('skulderveske',),
'skulderveske': ('skulderveske',),
'skuldervesken': ('skulderveske',),
'skulderveskene': ('skulderveske',),
'skuldervesker': ('skulderveske',),
'skulderåk': ('skulderåk',),
'skulderåka': ('skulderåk',),
'skulderåkene': ('skulderåk',),
'skulderåket': ('skulderåk',),
'skulene': ('skuler',),
'skuler': ('skuler',),
'skulk': ('skulk',),
'skulken': ('skulk',),
'skulkene': ('skulk',),
'skulker': ('skulk',),
'skulk': ('skulk',),
'skulka': ('skulk',),
'skulkene': ('skulk',),
'skulket': ('skulk',),
'skulker': ('skulker',),
'skulkere': ('skulker',),
'skulkeren': ('skulker',),
'skulkerer': ('skulker',),
'skulkerne': ('skulker',),
'skulkesjuka': ('skulkesjuke',),
'skulkesjuke': ('skulkesjuke',),
'skulkesjuken': ('skulkesjuke',),
'skulkesjukene': ('skulkesjuke',),
'skulkesjuker': ('skulkesjuke',),
'skulkesyka': ('skulkesyke',),
'skulkesyke': ('skulkesyke',),
'skulkesyken': ('skulkesyke',),
'skulkesykene': ('skulkesyke',),
'skulkesyker': ('skulkesyke',),
'skulpe': ('skulpe',),
'skulpen': ('skulpe',),
'skulpene': ('skulpe',),
'skulper': ('skulpe',),
'skulptur': ('skulptur',),
'skulpturen': ('skulptur',),
'skulpturene': ('skulptur',),
'skulpturer': ('skulptur',),
'skulptør': ('skulptør',),
'skulptøren': ('skulptør',),
'skulptørene': ('skulptør',),
'skulptører': ('skulptør',),
'skum': ('skum',),
'skumma': ('skum',),
'skummene': ('skum',),
'skummet': ('skum',),
'skumbad': ('skumbad',),
'skumbada': ('skumbad',),
'skumbadene': ('skumbad',),
'skumbadet': ('skumbad',),
'skumdrev': ('skumdrev',),
'skumdreva': ('skumdrev',),
'skumdrevene': ('skumdrev',),
'skumdrevet': ('skumdrev',),
'skumgummi': ('skumgummi',),
'skumgummien': ('skumgummi',),
'skumgummiene': ('skumgummi',),
'skumgummier': ('skumgummi',),
'skumhatt': ('skumhatt',),
'skumhatten': ('skumhatt',),
'skumhattene': ('skumhatt',),
'skumhatter': ('skumhatt',),
'skumkam': ('skumkam',),
'skumkammen': ('skumkam',),
'skumkammene': ('skumkam',),
'skumkammer': ('skumkam',),
'skumkok': ('skumkok',),
'skumkoka': ('skumkok',),
'skumkoken': ('skumkok',),
'skumkokene': ('skumkok',),
'skumkoker': ('skumkok',),
'skumkoket': ('skumkok',),
'skumleri': ('skumleri',),
'skumleria': ('skumleri',),
'skumleriene': ('skumleri',),
'skumlerier': ('skumleri',),
'skumleriet': ('skumleri',),
'skummamelk': ('skummamelk',),
'skummamelka': ('skummamelk',),
'skummamelken': ('skummamelk',),
'skummamelkene': ('skummamelk',),
'skummamelker': ('skummamelk',),
'skummetmelk': ('skummetmelk',),
'skummetmelka': ('skummetmelk',),
'skummetmelken': ('skummetmelk',),
'skummetmelkene': ('skummetmelk',),
'skummetmelker': ('skummetmelk',),
'skump': ('skump',),
'skumpa': ('skump',),
'skumpen': ('skump',),
'skumpene': ('skump',),
'skumpet': ('skump',),
'skumpelskudd': ('skumpelskudd',),
'skumpelskudda': ('skumpelskudd',),
'skumpelskuddene': ('skumpelskudd',),
'skumpelskuddet': ('skumpelskudd',),
'skumperla': ('skumperle',),
'skumperle': ('skumperle',),
'skumperlen': ('skumperle',),
'skumperlene': ('skumperle',),
'skumperler': ('skumperle',),
'skumplast': ('skumplast',),
'skumplasten': ('skumplast',),
'skumplastene': ('skumplast',),
'skumplaster': ('skumplast',),
'skumplog': ('skumplog',),
'skumplogen': ('skumplog',),
'skumplogene': ('skumplog',),
'skumploger': ('skumplog',),
'skumrens': ('skumrens',),
'skumrensen': ('skumrens',),
'skumrensene': ('skumrens',),
'skumrenser': ('skumrens',),
'skumrensing': ('skumrensing',),
'skumrensinga': ('skumrensing',),
'skumrensingen': ('skumrensing',),
'skumrensingene': ('skumrensing',),
'skumrensinger': ('skumrensing',),
'skumring': ('skumring',),
'skumringa': ('skumring',),
'skumringen': ('skumring',),
'skumringene': ('skumring',),
'skumringer': ('skumring',),
'skumringstime': ('skumringstime',),
'skumringstimen': ('skumringstime',),
'skumringstimene': ('skumringstime',),
'skumringstimer': ('skumringstime',),
'skumrøyk': ('skumrøyk',),
'skumrøyken': ('skumrøyk',),
'skumrøykene': ('skumrøyk',),
'skumrøyker': ('skumrøyk',),
'skumskavl': ('skumskavl',),
'skumskavlen': ('skumskavl',),
'skumskavlene': ('skumskavl',),
'skumskavler': ('skumskavl',),
'skumskjær': ('skumskjær',),
'skumskjæra': ('skumskjær',),
'skumskjærene': ('skumskjær',),
'skumskjæret': ('skumskjær',),
'skumslokker': ('skumslokker',),
'skumslokkere': ('skumslokker',),
'skumslokkeren': ('skumslokker',),
'skumslokkerer': ('skumslokker',),
'skumslokkerne': ('skumslokker',),
'skumslukker': ('skumslukker',),
'skumslukkere': ('skumslukker',),
'skumslukkeren': ('skumslukker',),
'skumslukkerer': ('skumslukker',),
'skumslukkerne': ('skumslukker',),
'skumsprøyt': ('skumsprøyt',),
'skumsprøyta': ('skumsprøyt',),
'skumsprøyten': ('skumsprøyt',),
'skumsprøytene': ('skumsprøyt',),
'skumsprøyter': ('skumsprøyt',),
'skumsprøytet': ('skumsprøyt',),
'skumstripa': ('skumstripe',),
'skumstripe': ('skumstripe',),
'skumstripen': ('skumstripe',),
'skumstripene': ('skumstripe',),
'skumstriper': ('skumstripe',),
'skumtopp': ('skumtopp',),
'skumtoppen': ('skumtopp',),
'skumtoppene': ('skumtopp',),
'skumtopper': ('skumtopp',),
'skunk': ('skunk',),
'skunken': ('skunk',),
'skunkene': ('skunk',),
'skunker': ('skunk',),
'skur': ('skur',),
'skuren': ('skur',),
'skurene': ('skur',),
'skurer': ('skur',),
'skur': ('skur',),
'skura': ('skur',),
'skurene': ('skur',),
'skuret': ('skur',),
'skur': ('skur',),
'skura': ('skur',),
'skuren': ('skur',),
'skurene': ('skur',),
'skurer': ('skur',),
'skurd': ('skurd',),
'skurden': ('skurd',),
'skurdene': ('skurd',),
'skurder': ('skurd',),
'skurd': ('skurd',),
'skurden': ('skurd',),
'skurdene': ('skurd',),
'skurder': ('skurd',),
'skurdfolk': ('skurdfolk',),
'skurdfolka': ('skurdfolk',),
'skurdfolkene': ('skurdfolk',),
'skurdfolket': ('skurdfolk',),
'skurdhare': ('skurdhare',),
'skurdharen': ('skurdhare',),
'skurdharene': ('skurdhare',),
'skurdharer': ('skurdhare',),
'skurdlag': ('skurdlag',),
'skurdlaga': ('skurdlag',),
'skurdlagene': ('skurdlag',),
'skurdlaget': ('skurdlag',),
'skurdlast': ('skurdlast',),
'skurdlasta': ('skurdlast',),
'skurdlasten': ('skurdlast',),
'skurdlastene': ('skurdlast',),
'skurdlaster': ('skurdlast',),
'skurdonn': ('skurdonn',),
'skurdonna': ('skurdonn',),
'skurdonnen': ('skurdonn',),
'skurdonnene': ('skurdonn',),
'skurdonner': ('skurdonn',),
'skurdtresker': ('skurdtresker',),
'skurdtreskere': ('skurdtresker',),
'skurdtreskeren': ('skurdtresker',),
'skurdtreskerer': ('skurdtresker',),
'skurdtreskerne': ('skurdtresker',),
'skurdtømmer': ('skurdtømmer',),
'skurdtømmera': ('skurdtømmer',),
'skurdtømmerene': ('skurdtømmer',),
'skurdtømmeret': ('skurdtømmer',),
'skurdtømra': ('skurdtømmer',),
'skurdtømre': ('skurdtømmer',),
'skurdtømrene': ('skurdtømmer',),
'skurebøtta': ('skurebøtte',),
'skurebøtte': ('skurebøtte',),
'skurebøtten': ('skurebøtte',),
'skurebøttene': ('skurebøtte',),
'skurebøtter': ('skurebøtte',),
'skurefilla': ('skurefille',),
'skurefille': ('skurefille',),
'skurefillen': ('skurefille',),
'skurefillene': ('skurefille',),
'skurefiller': ('skurefille',),
'skurekona': ('skurekone',),
'skurekone': ('skurekone',),
'skurekonen': ('skurekone',),
'skurekonene': ('skurekone',),
'skurekoner': ('skurekone',),
'skurekost': ('skurekost',),
'skurekosten': ('skurekost',),
'skurekostene': ('skurekost',),
'skurekoster': ('skurekost',),
'skurepulver': ('skurepulver',),
'skurepulvera': ('skurepulver',),
'skurepulvere': ('skurepulver',),
'skurepulveret': ('skurepulver',),
'skurepulverne': ('skurepulver',),
'skurfolk': ('skurfolk',),
'skurfolka': ('skurfolk',),
'skurfolkene': ('skurfolk',),
'skurfolket': ('skurfolk',),
'skurhare': ('skurhare',),
'skurharen': ('skurhare',),
'skurharene': ('skurhare',),
'skurharer': ('skurhare',),
'skuring': ('skuring',),
'skuringa': ('skuring',),
'skuringen': ('skuring',),
'skuringene': ('skuring',),
'skuringer': ('skuring',),
'skuringsstripa': ('skuringsstripe',),
'skuringsstripe': ('skuringsstripe',),
'skuringsstripen': ('skuringsstripe',),
'skuringsstripene': ('skuringsstripe',),
'skuringsstriper': ('skuringsstripe',),
'skurk': ('skurk',),
'skurken': ('skurk',),
'skurkene': ('skurk',),
'skurker': ('skurk',),
'skurkerolla': ('skurkerolle',),
'skurkerolle': ('skurkerolle',),
'skurkerollen': ('skurkerolle',),
'skurkerollene': ('skurkerolle',),
'skurkeroller': ('skurkerolle',),
'skurkestrek': ('skurkestrek',),
'skurkestreken': ('skurkestrek',),
'skurkestrekene': ('skurkestrek',),
'skurkestreker': ('skurkestrek',),
'skurlag': ('skurlag',),
'skurlaga': ('skurlag',),
'skurlagene': ('skurlag',),
'skurlaget': ('skurlag',),
'skurlast': ('skurlast',),
'skurlasta': ('skurlast',),
'skurlasten': ('skurlast',),
'skurlastene': ('skurlast',),
'skurlaster': ('skurlast',),
'skuronn': ('skuronn',),
'skuronna': ('skuronn',),
'skuronnen': ('skuronn',),
'skuronnene': ('skuronn',),
'skuronner': ('skuronn',),
'skurtresker': ('skurtresker',),
'skurtreskere': ('skurtresker',),
'skurtreskeren': ('skurtresker',),
'skurtreskerer': ('skurtresker',),
'skurtreskerne': ('skurtresker',),
'skurtømmer': ('skurtømmer',),
'skurtømmera': ('skurtømmer',),
'skurtømmerene': ('skurtømmer',),
'skurtømmeret': ('skurtømmer',),
'skurtømra': ('skurtømmer',),
'skurtømre': ('skurtømmer',),
'skurtømrene': ('skurtømmer',),
'skurv': ('skurv',),
'skurven': ('skurv',),
'skurvene': ('skurv',),
'skurver': ('skurv',),
'skurva': ('skurve',),
'skurve': ('skurve',),
'skurven': ('skurve',),
'skurvene': ('skurve',),
'skurver': ('skurve',),
'skurvesjuka': ('skurvesjuke',),
'skurvesjuke': ('skurvesjuke',),
'skurvesjuken': ('skurvesjuke',),
'skurvesjukene': ('skurvesjuke',),
'skurvesjuker': ('skurvesjuke',),
'skurvesyka': ('skurvesyke',),
'skurvesyke': ('skurvesyke',),
'skurvesyken': ('skurvesyke',),
'skurvesykene': ('skurvesyke',),
'skurvesyker': ('skurvesyke',),
'skussmål': ('skussmål',),
'skussmåla': ('skussmål',),
'skussmålene': ('skussmål',),
'skussmålet': ('skussmål',),
'skut': ('skut',),
'skuten': ('skut',),
'skutene': ('skut',),
'skuter': ('skut',),
'skut': ('skut',),
'skuten': ('skut',),
'skutene': ('skut',),
'skuter': ('skut',),
'skuta': ('skute',),
'skute': ('skute',),
'skuten': ('skute',),
'skutene': ('skute',),
'skuter': ('skute',),
'skutel': ('skutel',),
'skutelen': ('skutel',),
'skutlene': ('skutel',),
'skutler': ('skutel',),
'skutelsvein': ('skutelsvein',),
'skutelsveinen': ('skutelsvein',),
'skutelsveinene': ('skutelsvein',),
'skutelsveiner': ('skutelsvein',),
'skuter': ('skuter',),
'skutere': ('skuter',),
'skuteren': ('skuter',),
'skuterer': ('skuter',),
'skuterne': ('skuter',),
'skutt': ('skutt',),
'skutta': ('skutt',),
'skuttene': ('skutt',),
'skuttet': ('skutt',),
'skvadron': ('skvadron',),
'skvadronen': ('skvadron',),
'skvadronene': ('skvadron',),
'skvadroner': ('skvadron',),
'skvadronør': ('skvadronør',),
'skvadronøren': ('skvadronør',),
'skvadronørene': ('skvadronør',),
'skvadronører': ('skvadronør',),
'skval': ('skval',),
'skvala': ('skval',),
'skvalene': ('skval',),
'skvalet': ('skval',),
'skvalder': ('skvalder',),
'skvalderet': ('skvalder',),
'skvaldra': ('skvalder',),
'skvaldre': ('skvalder',),
'skvaldrene': ('skvalder',),
'skvaldrer': ('skvalder',),
'skvaldret': ('skvalder',),
'skvaldrebøtta': ('skvaldrebøtte',),
'skvaldrebøtte': ('skvaldrebøtte',),
'skvaldrebøtten': ('skvaldrebøtte',),
'skvaldrebøttene': ('skvaldrebøtte',),
'skvaldrebøtter': ('skvaldrebøtte',),
'skvallerkål': ('skvallerkål',),
'skvallerkålen': ('skvallerkål',),
'skvallerkålene': ('skvallerkål',),
'skvallerkåler': ('skvallerkål',),
'skvalp': ('skvalp',),
'skvalpen': ('skvalp',),
'skvalpene': ('skvalp',),
'skvalper': ('skvalp',),
'skvalp': ('skvalp',),
'skvalpa': ('skvalp',),
'skvalpene': ('skvalp',),
'skvalpet': ('skvalp',),
'skvalpesjø': ('skvalpesjø',),
'skvalpesjøen': ('skvalpesjø',),
'skvalpesjøene': ('skvalpesjø',),
'skvalpesjøer': ('skvalpesjø',),
'skvett': ('skvett',),
'skvetten': ('skvett',),
'skvettene': ('skvett',),
'skvetter': ('skvett',),
'skvett': ('skvett',),
'skvetta': ('skvett',),
'skvettene': ('skvett',),
'skvettet': ('skvett',),
'skvettbord': ('skvettbord',),
'skvettborda': ('skvettbord',),
'skvettbordene': ('skvettbord',),
'skvettborder': ('skvettbord',),
'skvettbordet': ('skvettbord',),
'skvettlapp': ('skvettlapp',),
'skvettlappen': ('skvettlapp',),
'skvettlappene': ('skvettlapp',),
'skvettlapper': ('skvettlapp',),
'skvettlær': ('skvettlær',),
'skvettlæra': ('skvettlær',),
'skvettlærene': ('skvettlær',),
'skvettlæret': ('skvettlær',),
'skvettpuss': ('skvettpuss',),
'skvettpussen': ('skvettpuss',),
'skvettpussene': ('skvettpuss',),
'skvettpusser': ('skvettpuss',),
'skvettskjerm': ('skvettskjerm',),
'skvettskjermen': ('skvettskjerm',),
'skvettskjermene': ('skvettskjerm',),
'skvettskjermer': ('skvettskjerm',),
'skvip': ('skvip',),
'skvipa': ('skvip',),
'skvipene': ('skvip',),
'skvipet': ('skvip',),
'skvis': ('skvis',),
'skvisen': ('skvis',),
'skvisene': ('skvis',),
'skviser': ('skvis',),
'skvulp': ('skvulp',),
'skvulpa': ('skvulp',),
'skvulpene': ('skvulp',),
'skvulpet': ('skvulp',),
'skværrigg': ('skværrigg',),
'skværriggen': ('skværrigg',),
'skværriggene': ('skværrigg',),
'skværrigger': ('skværrigg',),
'skværrigger': ('skværrigger',),
'skværriggere': ('skværrigger',),
'skværriggeren': ('skværrigger',),
'skværriggerer': ('skværrigger',),
'skværriggerne': ('skværrigger',),
'skværsegl': ('skværsegl',),
'skværsegla': ('skværsegl',),
'skværseglene': ('skværsegl',),
'skværseglet': ('skværsegl',),
'skværseil': ('skværseil',),
'skværseila': ('skværseil',),
'skværseilene': ('skværseil',),
'skværseilet': ('skværseil',),
'sky': ('sky',),
'skyen': ('sky',),
'skyene': ('sky',),
'skyer': ('sky',),
'sky': ('sky',),
'skya': ('sky',),
'skyen': ('sky',),
'skyene': ('sky',),
'skyer': ('sky',),
'skybanke': ('skybanke',),
'skybanken': ('skybanke',),
'skybankene': ('skybanke',),
'skybanker': ('skybanke',),
'skybrott': ('skybrott',),
'skybrotta': ('skybrott',),
'skybrottene': ('skybrott',),
'skybrottet': ('skybrott',),
'skybrudd': ('skybrudd',),
'skybrudda': ('skybrudd',),
'skybruddene': ('skybrudd',),
'skybruddet': ('skybrudd',),
'skydekka': ('skydekke',),
'skydekke': ('skydekke',),
'skydekkene': ('skydekke',),
'skydekker': ('skydekke',),
'skydekket': ('skydekke',),
'skydott': ('skydott',),
'skydotten': ('skydott',),
'skydottene': ('skydott',),
'skydotter': ('skydott',),
'skydrag': ('skydrag',),
'skydraga': ('skydrag',),
'skydragene': ('skydrag',),
'skydraget': ('skydrag',),
'skyffel': ('skyffel',),
'skyffelen': ('skyffel',),
'skyflene': ('skyffel',),
'skyfler': ('skyffel',),
'skyfloke': ('skyfloke',),
'skyfloken': ('skyfloke',),
'skyflokene': ('skyfloke',),
'skyfloker': ('skyfloke',),
'skygge': ('skygge',),
'skyggen': ('skygge',),
'skyggene': ('skygge',),
'skygger': ('skygge',),
'skyggebilda': ('skyggebilde',),
'skyggebilde': ('skyggebilde',),
'skyggebildene': ('skyggebilde',),
'skyggebilder': ('skyggebilde',),
'skyggebildet': ('skyggebilde',),
'skyggeboksing': ('skyggeboksing',),
'skyggeboksinga': ('skyggeboksing',),
'skyggeboksingen': ('skyggeboksing',),
'skyggeboksingene': ('skyggeboksing',),
'skyggeboksinger': ('skyggeboksing',),
'skyggefekting': ('skyggefekting',),
'skyggefektinga': ('skyggefekting',),
'skyggefektingen': ('skyggefekting',),
'skyggefektingene': ('skyggefekting',),
'skyggefektinger': ('skyggefekting',),
'skyggekabinett': ('skyggekabinett',),
'skyggekabinetta': ('skyggekabinett',),
'skyggekabinettene': ('skyggekabinett',),
'skyggekabinetter': ('skyggekabinett',),
'skyggekabinettet': ('skyggekabinett',),
'skyggekonge': ('skyggekonge',),
'skyggekongen': ('skyggekonge',),
'skyggekongene': ('skyggekonge',),
'skyggekonger': ('skyggekonge',),
'skyggekunstner': ('skyggekunstner',),
'skyggekunstnere': ('skyggekunstner',),
'skyggekunstneren': ('skyggekunstner',),
'skyggekunstnerer': ('skyggekunstner',),
'skyggekunstnerne': ('skyggekunstner',),
'skyggeland': ('skyggeland',),
'skyggelanda': ('skyggeland',),
'skyggelandene': ('skyggeland',),
'skyggelandet': ('skyggeland',),
'skyggelua': ('skyggelue',),
'skyggelue': ('skyggelue',),
'skyggeluen': ('skyggelue',),
'skyggeluene': ('skyggelue',),
'skyggeluer': ('skyggelue',),
'skyggeluva': ('skyggeluve',),
'skyggeluve': ('skyggeluve',),
'skyggeluven': ('skyggeluve',),
'skyggeluvene': ('skyggeluve',),
'skyggeluver': ('skyggeluve',),
'skyggeregjering': ('skyggeregjering',),
'skyggeregjeringa': ('skyggeregjering',),
'skyggeregjeringen': ('skyggeregjering',),
'skyggeregjeringene': ('skyggeregjering',),
'skyggeregjeringer': ('skyggeregjering',),
'skyggerika': ('skyggerike',),
'skyggerike': ('skyggerike',),
'skyggerikene': ('skyggerike',),
'skyggeriker': ('skyggerike',),
'skyggeriket': ('skyggerike',),
'skyggesida': ('skyggeside',),
'skyggeside': ('skyggeside',),
'skyggesiden': ('skyggeside',),
'skyggesidene': ('skyggeside',),
'skyggesider': ('skyggeside',),
'skyggespell': ('skyggespell',),
'skyggespella': ('skyggespell',),
'skyggespellene': ('skyggespell',),
'skyggespellet': ('skyggespell',),
'skyggespill': ('skyggespill',),
'skyggespilla': ('skyggespill',),
'skyggespillene': ('skyggespill',),
'skyggespillet': ('skyggespill',),
'skyggetilværelse': ('skyggetilværelse',),
'skyggetilværelsen': ('skyggetilværelse',),
'skyggetilværelsene': ('skyggetilværelse',),
'skyggetilværelser': ('skyggetilværelse',),
'skyggetone': ('skyggetone',),
'skyggetonen': ('skyggetone',),
'skyggetonene': ('skyggetone',),
'skyggetoner': ('skyggetone',),
'skygning': ('skygning',),
'skygninga': ('skygning',),
'skygningen': ('skygning',),
'skygningene': ('skygning',),
'skygninger': ('skygning',),
'skylag': ('skylag',),
'skylaga': ('skylag',),
'skylagene': ('skylag',),
'skylaget': ('skylag',),
'skylapp': ('skylapp',),
'skylappen': ('skylapp',),
'skylappene': ('skylapp',),
'skylapper': ('skylapp',),
'skyld': ('skyld',),
'skylda': ('skyld',),
'skylden': ('skyld',),
'skyldene': ('skyld',),
'skylder': ('skyld',),
'skyldbrev': ('skyldbrev',),
'skyldbreva': ('skyldbrev',),
'skyldbrevene': ('skyldbrev',),
'skyldbrever': ('skyldbrev',),
'skyldbrevet': ('skyldbrev',),
'skylddaler': ('skylddaler',),
'skylddalere': ('skylddaler',),
'skylddaleren': ('skylddaler',),
'skylddalerer': ('skylddaler',),
'skylddalerne': ('skylddaler',),
'skylddeling': ('skylddeling',),
'skylddelinga': ('skylddeling',),
'skylddelingen': ('skylddeling',),
'skylddelingene': ('skylddeling',),
'skylddelinger': ('skylddeling',),
'skyldfolk': ('skyldfolk',),
'skyldfolka': ('skyldfolk',),
'skyldfolkene': ('skyldfolk',),
'skyldfolket': ('skyldfolk',),
'skyldforhold': ('skyldforhold',),
'skyldforholda': ('skyldforhold',),
'skyldforholdene': ('skyldforhold',),
'skyldforholdet': ('skyldforhold',),
'skyldfølelse': ('skyldfølelse',),
'skyldfølelsen': ('skyldfølelse',),
'skyldfølelsene': ('skyldfølelse',),
'skyldfølelser': ('skyldfølelse',),
'skyldighet': ('skyldighet',),
'skyldigheta': ('skyldighet',),
'skyldigheten': ('skyldighet',),
'skyldighetene': ('skyldighet',),
'skyldigheter': ('skyldighet',),
'skylding': ('skylding',),
'skyldingen': ('skylding',),
'skyldingene': ('skylding',),
'skyldinger': ('skylding',),
'skyldkjensla': ('skyldkjensle',),
'skyldkjensle': ('skyldkjensle',),
'skyldkjenslen': ('skyldkjensle',),
'skyldkjenslene': ('skyldkjensle',),
'skyldkjensler': ('skyldkjensle',),
'skyldmark': ('skyldmark',),
'skyldmarka': ('skyldmark',),
'skyldmarken': ('skyldmark',),
'skyldmarkene': ('skyldmark',),
'skyldnad': ('skyldnad',),
'skyldnaden': ('skyldnad',),
'skyldnadene': ('skyldnad',),
'skyldnader': ('skyldnad',),
'skyldner': ('skyldner',),
'skyldnere': ('skyldner',),
'skyldneren': ('skyldner',),
'skyldnerer': ('skyldner',),
'skyldnerne': ('skyldner',),
'skyldskap': ('skyldskap',),
'skyldskapa': ('skyldskap',),
'skyldskapen': ('skyldskap',),
'skyldskapene': ('skyldskap',),
'skyldskaper': ('skyldskap',),
'skyldskapet': ('skyldskap',),
'skyldspørsmål': ('skyldspørsmål',),
'skyldspørsmåla': ('skyldspørsmål',),
'skyldspørsmålene': ('skyldspørsmål',),
'skyldspørsmålet': ('skyldspørsmål',),
'skyldøre': ('skyldøre',),
'skyldøren': ('skyldøre',),
'skyldørene': ('skyldøre',),
'skyldøret': ('skyldøre',),
'skylight': ('skylight',),
'skylighta': ('skylight',),
'skylighten': ('skylight',),
'skylightene': ('skylight',),
'skylighter': ('skylight',),
'skylightet': ('skylight',),
'skylight': ('skylight',),
'skylighta': ('skylight',),
'skylighten': ('skylight',),
'skylightene': ('skylight',),
'skylighter': ('skylight',),
'skylightet': ('skylight',),
'skyll': ('skyll',),
'skylla': ('skyll',),
'skyllene': ('skyll',),
'skyllet': ('skyll',),
'skylle': ('skylle',),
'skyllen': ('skylle',),
'skyllene': ('skylle',),
'skyller': ('skylle',),
'skyllebolle': ('skyllebolle',),
'skyllebollen': ('skyllebolle',),
'skyllebollene': ('skyllebolle',),
'skylleboller': ('skyllebolle',),
'skyllebøtta': ('skyllebøtte',),
'skyllebøtte': ('skyllebøtte',),
'skyllebøtten': ('skyllebøtte',),
'skyllebøttene': ('skyllebøtte',),
'skyllebøtter': ('skyllebøtte',),
'skylledunk': ('skylledunk',),
'skylledunken': ('skylledunk',),
'skylledunkene': ('skylledunk',),
'skylledunker': ('skylledunk',),
'skyllene': ('skyller',),
'skyller': ('skyller',),
'skyllevann': ('skyllevann',),
'skyllevanna': ('skyllevann',),
'skyllevannene': ('skyllevann',),
'skyllevannet': ('skyllevann',),
'skyllevatn': ('skyllevatn',),
'skyllevatna': ('skyllevatn',),
'skyllevatnene': ('skyllevatn',),
'skyllevatnet': ('skyllevatn',),
'skynding': ('skynding',),
'skyndinga': ('skynding',),
'skyndingen': ('skynding',),
'skyndingene': ('skynding',),
'skyndinger': ('skynding',),
'skypumpa': ('skypumpe',),
'skypumpe': ('skypumpe',),
'skypumpen': ('skypumpe',),
'skypumpene': ('skypumpe',),
'skypumper': ('skypumpe',),
'skyru': ('skyru',),
'skyrua': ('skyru',),
'skyruen': ('skyru',),
'skyruene': ('skyru',),
'skyruer': ('skyru',),
'skyskraper': ('skyskraper',),
'skyskrapere': ('skyskraper',),
'skyskraperen': ('skyskraper',),
'skyskraperer': ('skyskraper',),
'skyskraperne': ('skyskraper',),
'skyss': ('skyss',),
'skyssen': ('skyss',),
'skyssene': ('skyss',),
'skysser': ('skyss',),
'skyss-skifta': ('skyss-skifte',),
'skyss-skifte': ('skyss-skifte',),
'skyss-skiftene': ('skyss-skifte',),
'skyss-skifter': ('skyss-skifte',),
'skyss-skiftet': ('skyss-skifte',),
'skyss-stasjon': ('skyss-stasjon',),
'skyss-stasjonen': ('skyss-stasjon',),
'skyss-stasjonene': ('skyss-stasjon',),
'skyss-stasjoner': ('skyss-stasjon',),
'skyssbonde': ('skyssbonde',),
'skyssbonden': ('skyssbonde',),
'skyssbøndene': ('skyssbonde',),
'skyssbønder': ('skyssbonde',),
'skyssbåt': ('skyssbåt',),
'skyssbåten': ('skyssbåt',),
'skyssbåtene': ('skyssbåt',),
'skyssbåter': ('skyssbåt',),
'skyssdreng': ('skyssdreng',),
'skyssdrengen': ('skyssdreng',),
'skyssdrengene': ('skyssdreng',),
'skyssdrenger': ('skyssdreng',),
'skyssgodtgjørelse': ('skyssgodtgjørelse',),
'skyssgodtgjørelsen': ('skyssgodtgjørelse',),
'skyssgodtgjørelsene': ('skyssgodtgjørelse',),
'skyssgodtgjørelser': ('skyssgodtgjørelse',),
'skyssgodtgjøring': ('skyssgodtgjøring',),
'skyssgodtgjøringa': ('skyssgodtgjøring',),
'skyssgodtgjøringen': ('skyssgodtgjøring',),
'skyssgodtgjøringene': ('skyssgodtgjøring',),
'skyssgodtgjøringer': ('skyssgodtgjøring',),
'skyssgutt': ('skyssgutt',),
'skyssgutten': ('skyssgutt',),
'skyssguttene': ('skyssgutt',),
'skyssgutter': ('skyssgutt',),
'skysshest': ('skysshest',),
'skysshesten': ('skysshest',),
'skysshestene': ('skysshest',),
'skysshester': ('skysshest',),
'skysskar': ('skysskar',),
'skysskaren': ('skysskar',),
'skysskarene': ('skysskar',),
'skysskarer': ('skysskar',),
'skysskifta': ('skysskifte',),
'skysskifte': ('skysskifte',),
'skysskiftene': ('skysskifte',),
'skysskifter': ('skysskifte',),
'skysskiftet': ('skysskifte',),
'skyssplikt': ('skyssplikt',),
'skyssplikta': ('skyssplikt',),
'skyssplikten': ('skyssplikt',),
'skysspliktene': ('skyssplikt',),
'skyssplikter': ('skyssplikt',),
'skysstasjon': ('skysstasjon',),
'skysstasjonen': ('skysstasjon',),
'skysstasjonene': ('skysstasjon',),
'skysstasjoner': ('skysstasjon',),
'skytebane': ('skytebane',),
'skytebanen': ('skytebane',),
'skytebanene': ('skytebane',),
'skytebaner': ('skytebane',),
'skytebas': ('skytebas',),
'skytebasen': ('skytebas',),
'skytebasene': ('skytebas',),
'skytebaser': ('skytebas',),
'skytebomull': ('skytebomull',),
'skytebomulla': ('skytebomull',),
'skytebomullen': ('skytebomull',),
'skytebomullene': ('skytebomull',),
'skytebomuller': ('skytebomull',),
'skytefelt': ('skytefelt',),
'skytefelta': ('skytefelt',),
'skytefeltene': ('skytefelt',),
'skytefelter': ('skytefelt',),
'skytefeltet': ('skytefelt',),
'skytemaska': ('skytemaske',),
'skytemaske': ('skytemaske',),
'skytemasken': ('skytemaske',),
'skytemaskene': ('skytemaske',),
'skytemasker': ('skytemaske',),
'skyter': ('skyter',),
'skytere': ('skyter',),
'skyteren': ('skyter',),
'skyterer': ('skyter',),
'skyterne': ('skyter',),
'skyteskiva': ('skyteskive',),
'skyteskive': ('skyteskive',),
'skyteskiven': ('skyteskive',),
'skyteskivene': ('skyteskive',),
'skyteskiver': ('skyteskive',),
'skyteskår': ('skyteskår',),
'skyteskåra': ('skyteskår',),
'skyteskårene': ('skyteskår',),
'skyteskåret': ('skyteskår',),
'skytestilling': ('skytestilling',),
'skytestillinga': ('skytestilling',),
'skytestillingen': ('skytestilling',),
'skytestillingene': ('skytestilling',),
'skytestillinger': ('skytestilling',),
'skytevåpen': ('skytevåpen',),
'skytevåpenet': ('skytevåpen',),
'skytevåpna': ('skytevåpen',),
'skytevåpnene': ('skytevåpen',),
'skyteøvelse': ('skyteøvelse',),
'skyteøvelsen': ('skyteøvelse',),
'skyteøvelsene': ('skyteøvelse',),
'skyteøvelser': ('skyteøvelse',),
'skyteøving': ('skyteøving',),
'skyteøvinga': ('skyteøving',),
'skyteøvingen': ('skyteøving',),
'skyteøvingene': ('skyteøving',),
'skyteøvinger': ('skyteøving',),
'skytning': ('skytning',),
'skytninga': ('skytning',),
'skytningen': ('skytning',),
'skytningene': ('skytning',),
'skytninger': ('skytning',),
'skytning': ('skytning',),
'skytninga': ('skytning',),
'skytningen': ('skytning',),
'skytningene': ('skytning',),
'skytninger': ('skytning',),
'skytningsstova': ('skytningsstove',),
'skytningsstove': ('skytningsstove',),
'skytningsstoven': ('skytningsstove',),
'skytningsstovene': ('skytningsstove',),
'skytningsstover': ('skytningsstove',),
'skytningsstua': ('skytningsstue',),
'skytningsstue': ('skytningsstue',),
'skytningsstuen': ('skytningsstue',),
'skytningsstuene': ('skytningsstue',),
'skytningsstuer': ('skytningsstue',),
'skyts': ('skyts',),
'skytsa': ('skyts',),
'skytsene': ('skyts',),
'skytset': ('skyts',),
'skytsengel': ('skytsengel',),
'skytsengelen': ('skytsengel',),
'skytsenglene': ('skytsengel',),
'skytsengler': ('skytsengel',),
'skytshelgen': ('skytshelgen',),
'skytshelgenen': ('skytshelgen',),
'skytshelgenene': ('skytshelgen',),
'skytshelgener': ('skytshelgen',),
'skytspatron': ('skytspatron',),
'skytspatronen': ('skytspatron',),
'skytspatronene': ('skytspatron',),
'skytspatroner': ('skytspatron',),
'skytsånd': ('skytsånd',),
'skytsånden': ('skytsånd',),
'skytsåndene': ('skytsånd',),
'skytsånder': ('skytsånd',),
'skytlene': ('skyttel',),
'skytler': ('skyttel',),
'skyttel': ('skyttel',),
'skyttelen': ('skyttel',),
'skytteltrafikk': ('skytteltrafikk',),
'skytteltrafikken': ('skytteltrafikk',),
'skytteltrafikkene': ('skytteltrafikk',),
'skytteltrafikker': ('skytteltrafikk',),
'skytter': ('skytter',),
'skyttere': ('skytter',),
'skytteren': ('skytter',),
'skytterer': ('skytter',),
'skytterne': ('skytter',),
'skyttergrav': ('skyttergrav',),
'skyttergrava': ('skyttergrav',),
'skyttergraven': ('skyttergrav',),
'skyttergravene': ('skyttergrav',),
'skyttergraver': ('skyttergrav',),
'skyttergravskrig': ('skyttergravskrig',),
'skyttergravskrigen': ('skyttergravskrig',),
'skyttergravskrigene': ('skyttergravskrig',),
'skyttergravskriger': ('skyttergravskrig',),
'skytterhus': ('skytterhus',),
'skytterhusa': ('skytterhus',),
'skytterhusene': ('skytterhus',),
'skytterhuset': ('skytterhus',),
'skytteri': ('skytteri',),
'skytteria': ('skytteri',),
'skytteriene': ('skytteri',),
'skytterier': ('skytteri',),
'skytteriet': ('skytteri',),
'skytterkonge': ('skytterkonge',),
'skytterkongen': ('skytterkonge',),
'skytterkongene': ('skytterkonge',),
'skytterkonger': ('skytterkonge',),
'skytterlag': ('skytterlag',),
'skytterlaga': ('skytterlag',),
'skytterlagene': ('skytterlag',),
'skytterlaget': ('skytterlag',),
'skyttermerka': ('skyttermerke',),
'skyttermerke': ('skyttermerke',),
'skyttermerkene': ('skyttermerke',),
'skyttermerker': ('skyttermerke',),
'skyttermerket': ('skyttermerke',),
'skytterprinsessa': ('skytterprinsesse',),
'skytterprinsesse': ('skytterprinsesse',),
'skytterprinsessen': ('skytterprinsesse',),
'skytterprinsessene': ('skytterprinsesse',),
'skytterprinsesser': ('skytterprinsesse',),
'skyttersamlag': ('skyttersamlag',),
'skyttersamlaga': ('skyttersamlag',),
'skyttersamlagene': ('skyttersamlag',),
'skyttersamlaget': ('skyttersamlag',),
'skyttervesen': ('skyttervesen',),
'skyttervesena': ('skyttervesen',),
'skyttervesenene': ('skyttervesen',),
'skyttervesener': ('skyttervesen',),
'skyttervesenet': ('skyttervesen',),
'skyv': ('skyv',),
'skyva': ('skyv',),
'skyvene': ('skyv',),
'skyvet': ('skyv',),
'skyvedør': ('skyvedør',),
'skyvedøra': ('skyvedør',),
'skyvedøren': ('skyvedør',),
'skyvedørene': ('skyvedør',),
'skyvedører': ('skyvedør',),
'skyvelæra': ('skyvelære',),
'skyvelære': ('skyvelære',),
'skyvelæren': ('skyvelære',),
'skyvelærene': ('skyvelære',),
'skyvelærer': ('skyvelære',),
'skyvelæret': ('skyvelære',),
'skyver': ('skyver',),
'skyvere': ('skyver',),
'skyveren': ('skyver',),
'skyverer': ('skyver',),
'skyverne': ('skyver',),
'skjækene': ('skåk',),
'skjæker': ('skåk',),
'skåk': ('skåk',),
'skåka': ('skåk',),
'skåken': ('skåk',),
'skål': ('skål',),
'skåla': ('skål',),
'skålen': ('skål',),
'skålene': ('skål',),
'skåler': ('skål',),
'skålbrott': ('skålbrott',),
'skålbrotta': ('skålbrott',),
'skålbrottene': ('skålbrott',),
'skålbrottet': ('skålbrott',),
'skåle': ('skåle',),
'skålen': ('skåle',),
'skålene': ('skåle',),
'skåler': ('skåle',),
'skålpund': ('skålpund',),
'skålpunda': ('skålpund',),
'skålpundene': ('skålpund',),
'skålpundet': ('skålpund',),
'skåltale': ('skåltale',),
'skåltalen': ('skåltale',),
'skåltalene': ('skåltale',),
'skåltaler': ('skåltale',),
'skåltaler': ('skåltaler',),
'skåltalere': ('skåltaler',),
'skåltaleren': ('skåltaler',),
'skåltalerer': ('skåltaler',),
'skåltalerne': ('skåltaler',),
'skålvekt': ('skålvekt',),
'skålvekta': ('skålvekt',),
'skålvekten': ('skålvekt',),
'skålvektene': ('skålvekt',),
'skålvekter': ('skålvekt',),
'skåning': ('skåning',),
'skåningen': ('skåning',),
'skåningene': ('skåning',),
'skåninger': ('skåning',),
'skånsel': ('skånsel',),
'skånselen': ('skånsel',),
'skånslene': ('skånsel',),
'skånsler': ('skånsel',),
'skår': ('skår',),
'skåren': ('skår',),
'skårene': ('skår',),
'skårer': ('skår',),
'skår': ('skår',),
'skåren': ('skår',),
'skårene': ('skår',),
'skårer': ('skår',),
'skår': ('skår',),
'skåra': ('skår',),
'skårene': ('skår',),
'skåret': ('skår',),
'skåre': ('skåre',),
'skåren': ('skåre',),
'skårene': ('skåre',),
'skårer': ('skåre',),
'skåre': ('skåre',),
'skåren': ('skåre',),
'skårene': ('skåre',),
'skårer': ('skåre',),
'skåre': ('skåre',),
'skåren': ('skåre',),
'skårene': ('skåre',),
'skårer': ('skåre',),
'skåre': ('skåre',),
'skåren': ('skåre',),
'skårene': ('skåre',),
'skårer': ('skåre',),
'skåra': ('skåre',),
'skåre': ('skåre',),
'skåren': ('skåre',),
'skårene': ('skåre',),
'skårer': ('skåre',),
'skåreflis': ('skåreflis',),
'skåreflisa': ('skåreflis',),
'skåreflisen': ('skåreflis',),
'skåreflisene': ('skåreflis',),
'skårefliser': ('skåreflis',),
'skårer': ('skårer',),
'skårere': ('skårer',),
'skåreren': ('skårer',),
'skårerer': ('skårer',),
'skårerne': ('skårer',),
'skårfesta': ('skårfeste',),
'skårfeste': ('skårfeste',),
'skårfestene': ('skårfeste',),
'skårfester': ('skårfeste',),
'skårfestet': ('skårfeste',),
'skåring': ('skåring',),
'skåringa': ('skåring',),
'skåringen': ('skåring',),
'skåringene': ('skåring',),
'skåringer': ('skåring',),
'skåringssjanse': ('skåringssjanse',),
'skåringssjansen': ('skåringssjanse',),
'skåringssjansene': ('skåringssjanse',),
'skåringssjanser': ('skåringssjanse',),
'skårung': ('skårung',),
'skårungen': ('skårung',),
'skårungene': ('skårung',),
'skårunger': ('skårung',),
'skårunge': ('skårunge',),
'skårungen': ('skårunge',),
'skårungene': ('skårunge',),
'skårunger': ('skårunge',),
'skåta': ('skåte',),
'skåte': ('skåte',),
'skåten': ('skåte',),
'skåtene': ('skåte',),
'skåter': ('skåte',),
'skøy': ('skøy',),
'skøya': ('skøy',),
'skøyen': ('skøy',),
'skøyene': ('skøy',),
'skøyer': ('skøy',),
'skøyet': ('skøy',),
'skøyer': ('skøyer',),
'skøyere': ('skøyer',),
'skøyeren': ('skøyer',),
'skøyerer': ('skøyer',),
'skøyerne': ('skøyer',),
'skøyerfant': ('skøyerfant',),
'skøyerfanten': ('skøyerfant',),
'skøyerfantene': ('skøyerfant',),
'skøyerfanter': ('skøyerfant',),
'skøyerstrek': ('skøyerstrek',),
'skøyerstreken': ('skøyerstrek',),
'skøyerstrekene': ('skøyerstrek',),
'skøyerstreker': ('skøyerstrek',),
'skøyta': ('skøyte',),
'skøyte': ('skøyte',),
'skøyten': ('skøyte',),
'skøytene': ('skøyte',),
'skøyter': ('skøyte',),
'skøyta': ('skøyte',),
'skøyte': ('skøyte',),
'skøyten': ('skøyte',),
'skøytene': ('skøyte',),
'skøyter': ('skøyte',),
'skøytebane': ('skøytebane',),
'skøytebanen': ('skøytebane',),
'skøytebanene': ('skøytebane',),
'skøytebaner': ('skøytebane',),
'skøyteis': ('skøyteis',),
'skøyteisen': ('skøyteis',),
'skøyteisene': ('skøyteis',),
'skøyteiser': ('skøyteis',),
'skøytejern': ('skøytejern',),
'skøytejerna': ('skøytejern',),
'skøytejernene': ('skøytejern',),
'skøytejernet': ('skøytejern',),
'skøyteklubb': ('skøyteklubb',),
'skøyteklubben': ('skøyteklubb',),
'skøyteklubbene': ('skøyteklubb',),
'skøyteklubber': ('skøyteklubb',),
'skøytekonge': ('skøytekonge',),
'skøytekongen': ('skøytekonge',),
'skøytekongene': ('skøytekonge',),
'skøytekonger': ('skøytekonge',),
'skøytelandskamp': ('skøytelandskamp',),
'skøytelandskampen': ('skøytelandskamp',),
'skøytelandskampene': ('skøytelandskamp',),
'skøytelandskamper': ('skøytelandskamp',),
'skøyteløp': ('skøyteløp',),
'skøyteløpa': ('skøyteløp',),
'skøyteløpene': ('skøyteløp',),
'skøyteløpet': ('skøyteløp',),
'skøyteløper': ('skøyteløper',),
'skøyteløpere': ('skøyteløper',),
'skøyteløperen': ('skøyteløper',),
'skøyteløperer': ('skøyteløper',),
'skøyteløperne': ('skøyteløper',),
'skøytestål': ('skøytestål',),
'skøyteståla': ('skøytestål',),
'skøytestålene': ('skøytestål',),
'skøytestålet': ('skøytestål',),
'skøytetak': ('skøytetak',),
'skøytetaka': ('skøytetak',),
'skøytetakene': ('skøytetak',),
'skøytetaket': ('skøytetak',),
'skøyting': ('skøyting',),
'skøytinga': ('skøyting',),
'skøytingen': ('skøyting',),
'skøytingene': ('skøyting',),
'skøytinger': ('skøyting',),
'slabb': ('slabb',),
'slabben': ('slabb',),
'slabbene': ('slabb',),
'slabber': ('slabb',),
'slabba': ('slabbe',),
'slabbe': ('slabbe',),
'slabben': ('slabbe',),
'slabbene': ('slabbe',),
'slabber': ('slabbe',),
'slabbedask': ('slabbedask',),
'slabbedasken': ('slabbedask',),
'slabbedaskene': ('slabbedask',),
'slabbedasker': ('slabbedask',),
'slabberas': ('slabberas',),
'slabberasa': ('slabberas',),
'slabberasene': ('slabberas',),
'slabberaset': ('slabberas',),
'slacks': ('slacks',),
'slacksen': ('slacks',),
'slacksene': ('slacks',),
'sladd': ('sladd',),
'sladden': ('sladd',),
'sladdene': ('sladd',),
'sladder': ('sladd',),
'sladd': ('sladd',),
'sladden': ('sladd',),
'sladdene': ('sladd',),
'sladder': ('sladd',),
'sladder': ('sladder',),
'sladdere': ('sladder',),
'sladderen': ('sladder',),
'sladderer': ('sladder',),
'sladderne': ('sladder',),
'sladrene': ('sladder',),
'sladrer': ('sladder',),
'sladderhank': ('sladderhank',),
'sladderhanka': ('sladderhank',),
'sladderhanken': ('sladderhank',),
'sladderhankene': ('sladderhank',),
'sladderhanker': ('sladderhank',),
'sladderhistoria': ('sladderhistorie',),
'sladderhistorie': ('sladderhistorie',),
'sladderhistorien': ('sladderhistorie',),
'sladderhistoriene': ('sladderhistorie',),
'sladderhistorier': ('sladderhistorie',),
'sladrehank': ('sladrehank',),
'sladrehanka': ('sladrehank',),
'sladrehanken': ('sladrehank',),
'sladrehankene': ('sladrehank',),
'sladrehanker': ('sladrehank',),
'sladrekjerring': ('sladrekjerring',),
'sladrekjerringa': ('sladrekjerring',),
'sladrekjerringen': ('sladrekjerring',),
'sladrekjerringene': ('sladrekjerring',),
'sladrekjerringer': ('sladrekjerring',),
'sladrekompass': ('sladrekompass',),
'sladrekompassa': ('sladrekompass',),
'sladrekompassen': ('sladrekompass',),
'sladrekompassene': ('sladrekompass',),
'sladrekompasser': ('sladrekompass',),
'sladrekompasset': ('sladrekompass',),
'sladrespalta': ('sladrespalte',),
'sladrespalte': ('sladrespalte',),
'sladrespalten': ('sladrespalte',),
'sladrespaltene': ('sladrespalte',),
'sladrespalter': ('sladrespalte',),
'sladrespeil': ('sladrespeil',),
'sladrespeila': ('sladrespeil',),
'sladrespeilene': ('sladrespeil',),
'sladrespeilet': ('sladrespeil',),
'slafs': ('slafs',),
'slafsen': ('slafs',),
'slafsene': ('slafs',),
'slafser': ('slafs',),
'slafs': ('slafs',),
'slafsa': ('slafs',),
'slafsene': ('slafs',),
'slafset': ('slafs',),
'slag': ('slag',),
'slaga': ('slag',),
'slagene': ('slag',),
'slaget': ('slag',),
'slag': ('slag',),
'slaga': ('slag',),
'slagene': ('slag',),
'slaget': ('slag',),
'slag': ('slag',),
'slaga': ('slag',),
'slagene': ('slag',),
'slaget': ('slag',),
'slagbenk': ('slagbenk',),
'slagbenken': ('slagbenk',),
'slagbenkene': ('slagbenk',),
'slagbenker': ('slagbenk',),
'slagbjørn': ('slagbjørn',),
'slagbjørnen': ('slagbjørn',),
'slagbjørnene': ('slagbjørn',),
'slagbjørner': ('slagbjørn',),
'slagbor': ('slagbor',),
'slagbora': ('slagbor',),
'slagboren': ('slagbor',),
'slagborene': ('slagbor',),
'slagboret': ('slagbor',),
'slagbord': ('slagbord',),
'slagborda': ('slagbord',),
'slagbordene': ('slagbord',),
'slagborder': ('slagbord',),
'slagbordet': ('slagbord',),
'slager': ('slager',),
'slagere': ('slager',),
'slageren': ('slager',),
'slagerer': ('slager',),
'slagerne': ('slager',),
'slagg': ('slagg',),
'slagga': ('slagg',),
'slaggene': ('slagg',),
'slagget': ('slagg',),
'slagghaug': ('slagghaug',),
'slagghaugen': ('slagghaug',),
'slagghaugene': ('slagghaug',),
'slagghauger': ('slagghaug',),
'slaggrunn': ('slaggrunn',),
'slaggrunnen': ('slaggrunn',),
'slaggrunnene': ('slaggrunn',),
'slaggrunner': ('slaggrunn',),
'slaginstrument': ('slaginstrument',),
'slaginstrumenta': ('slaginstrument',),
'slaginstrumentene': ('slaginstrument',),
'slaginstrumenter': ('slaginstrument',),
'slaginstrumentet': ('slaginstrument',),
'slagkraft': ('slagkraft',),
'slagkrafta': ('slagkraft',),
'slagkraften': ('slagkraft',),
'slagkreftene': ('slagkraft',),
'slagkrefter': ('slagkraft',),
'slaglodd': ('slaglodd',),
'slaglodda': ('slaglodd',),
'slagloddene': ('slaglodd',),
'slaglodder': ('slaglodd',),
'slagloddet': ('slaglodd',),
'slagmark': ('slagmark',),
'slagmarka': ('slagmark',),
'slagmarken': ('slagmark',),
'slagmarkene': ('slagmark',),
'slagmarker': ('slagmark',),
'slagning': ('slagning',),
'slagninga': ('slagning',),
'slagningen': ('slagning',),
'slagningene': ('slagning',),
'slagninger': ('slagning',),
'slagord': ('slagord',),
'slagorda': ('slagord',),
'slagordene': ('slagord',),
'slagordet': ('slagord',),
'slagorden': ('slagorden',),
'slagordenen': ('slagorden',),
'slagordenene': ('slagorden',),
'slagordener': ('slagorden',),
'slagplan': ('slagplan',),
'slagplanen': ('slagplan',),
'slagplanene': ('slagplan',),
'slagplaner': ('slagplan',),
'slagregn': ('slagregn',),
'slagregna': ('slagregn',),
'slagregnene': ('slagregn',),
'slagregnet': ('slagregn',),
'slags': ('slags',),
'slagsbror': ('slagsbror',),
'slagsbroren': ('slagsbror',),
'slagsbrødre': ('slagsbror',),
'slagsbrødrene': ('slagsbror',),
'slagscene': ('slagscene',),
'slagscenen': ('slagscene',),
'slagscenene': ('slagscene',),
'slagscener': ('slagscene',),
'slagsida': ('slagside',),
'slagside': ('slagside',),
'slagsiden': ('slagside',),
'slagsidene': ('slagside',),
'slagsider': ('slagside',),
'slagsida': ('slagside',),
'slagside': ('slagside',),
'slagsiden': ('slagside',),
'slagsidene': ('slagside',),
'slagsider': ('slagside',),
'slagskip': ('slagskip',),
'slagskipa': ('slagskip',),
'slagskipene': ('slagskip',),
'slagskipet': ('slagskip',),
'slagskygge': ('slagskygge',),
'slagskyggen': ('slagskygge',),
'slagskyggene': ('slagskygge',),
'slagskygger': ('slagskygge',),
'slagsmål': ('slagsmål',),
'slagsmåla': ('slagsmål',),
'slagsmålene': ('slagsmål',),
'slagsmålet': ('slagsmål',),
'slagstøvel': ('slagstøvel',),
'slagstøvelen': ('slagstøvel',),
'slagstøvlene': ('slagstøvel',),
'slagstøvler': ('slagstøvel',),
'slagur': ('slagur',),
'slagura': ('slagur',),
'slagurene': ('slagur',),
'slaguret': ('slagur',),
'slagverk': ('slagverk',),
'slagverka': ('slagverk',),
'slagverkene': ('slagverk',),
'slagverker': ('slagverk',),
'slagverket': ('slagverk',),
'slagverker': ('slagverker',),
'slagverkere': ('slagverker',),
'slagverkeren': ('slagverker',),
'slagverkerer': ('slagverker',),
'slagverkerne': ('slagverker',),
'slagvidda': ('slagvidde',),
'slagvidde': ('slagvidde',),
'slagvidden': ('slagvidde',),
'slagviddene': ('slagvidde',),
'slagvidder': ('slagvidde',),
'slagvåpen': ('slagvåpen',),
'slagvåpenet': ('slagvåpen',),
'slagvåpna': ('slagvåpen',),
'slagvåpnene': ('slagvåpen',),
'slakk': ('slakk',),
'slakken': ('slakk',),
'slakkene': ('slakk',),
'slakker': ('slakk',),
'slakt': ('slakt',),
'slakta': ('slakt',),
'slaktene': ('slakt',),
'slaktet': ('slakt',),
'slaktedyr': ('slaktedyr',),
'slaktedyra': ('slaktedyr',),
'slaktedyrene': ('slaktedyr',),
'slaktedyret': ('slaktedyr',),
'slaktefe': ('slaktefe',),
'slaktefea': ('slaktefe',),
'slaktefeene': ('slaktefe',),
'slaktefeet': ('slaktefe',),
'slaktegris': ('slaktegris',),
'slaktegrisen': ('slaktegris',),
'slaktegrisene': ('slaktegris',),
'slaktegriser': ('slaktegris',),
'slaktehus': ('slaktehus',),
'slaktehusa': ('slaktehus',),
'slaktehusene': ('slaktehus',),
'slaktehuset': ('slaktehus',),
'slaktekniv': ('slaktekniv',),
'slaktekniven': ('slaktekniv',),
'slakteknivene': ('slaktekniv',),
'slaktekniver': ('slaktekniv',),
'slaktemaska': ('slaktemaske',),
'slaktemaske': ('slaktemaske',),
'slaktemasken': ('slaktemaske',),
'slaktemaskene': ('slaktemaske',),
'slaktemasker': ('slaktemaske',),
'slaktemat': ('slaktemat',),
'slaktematen': ('slaktemat',),
'slaktematene': ('slaktemat',),
'slaktemater': ('slaktemat',),
'slaktemåned': ('slaktemåned',),
'slaktemåneden': ('slaktemåned',),
'slaktemånedene': ('slaktemåned',),
'slaktemåneder': ('slaktemåned',),
'slakteplass': ('slakteplass',),
'slakteplassen': ('slakteplass',),
'slakteplassene': ('slakteplass',),
'slakteplasser': ('slakteplass',),
'slakter': ('slakter',),
'slaktere': ('slakter',),
'slakteren': ('slakter',),
'slakterer': ('slakter',),
'slakterne': ('slakter',),
'slakterbenk': ('slakterbenk',),
'slakterbenken': ('slakterbenk',),
'slakterbenkene': ('slakterbenk',),
'slakterbenker': ('slakterbenk',),
'slakterbutikk': ('slakterbutikk',),
'slakterbutikken': ('slakterbutikk',),
'slakterbutikkene': ('slakterbutikk',),
'slakterbutikker': ('slakterbutikk',),
'slakteri': ('slakteri',),
'slakteria': ('slakteri',),
'slakteriene': ('slakteri',),
'slakterier': ('slakteri',),
'slakteriet': ('slakteri',),
'slakterkniv': ('slakterkniv',),
'slakterkniven': ('slakterkniv',),
'slakterknivene': ('slakterkniv',),
'slakterkniver': ('slakterkniv',),
'slaktertak': ('slaktertak',),
'slaktertaka': ('slaktertak',),
'slaktertakene': ('slaktertak',),
'slaktertaket': ('slaktertak',),
'slaktetid': ('slaktetid',),
'slaktetida': ('slaktetid',),
'slaktetiden': ('slaktetid',),
'slaktetidene': ('slaktetid',),
'slaktetider': ('slaktetid',),
'slaktevekt': ('slaktevekt',),
'slaktevekta': ('slaktevekt',),
'slaktevekten': ('slaktevekt',),
'slaktevektene': ('slaktevekt',),
'slaktevekter': ('slaktevekt',),
'slaktoffer': ('slaktoffer',),
'slaktofferet': ('slaktoffer',),
'slaktofra': ('slaktoffer',),
'slaktofre': ('slaktoffer',),
'slaktofrene': ('slaktoffer',),
'slalåm': ('slalåm',),
'slalåmen': ('slalåm',),
'slalåmene': ('slalåm',),
'slalåmer': ('slalåm',),
'slalåmbakke': ('slalåmbakke',),
'slalåmbakken': ('slalåmbakke',),
'slalåmbakkene': ('slalåmbakke',),
'slalåmbakker': ('slalåmbakke',),
'slalåmkjører': ('slalåmkjører',),
'slalåmkjørere': ('slalåmkjører',),
'slalåmkjøreren': ('slalåmkjører',),
'slalåmkjørerer': ('slalåmkjører',),
'slalåmkjørerne': ('slalåmkjører',),
'slalåmløypa': ('slalåmløype',),
'slalåmløype': ('slalåmløype',),
'slalåmløypen': ('slalåmløype',),
'slalåmløypene': ('slalåmløype',),
'slalåmløyper': ('slalåmløype',),
'slalåmport': ('slalåmport',),
'slalåmporten': ('slalåmport',),
'slalåmportene': ('slalåmport',),
'slalåmporter': ('slalåmport',),
'slalåmrenn': ('slalåmrenn',),
'slalåmrenna': ('slalåmrenn',),
'slalåmrennene': ('slalåmrenn',),
'slalåmrennet': ('slalåmrenn',),
'slam': ('slam',),
'slamma': ('slam',),
'slammene': ('slam',),
'slammet': ('slam',),
'slamfilter': ('slamfilter',),
'slamfilteret': ('slamfilter',),
'slamfiltra': ('slamfilter',),
'slamfiltre': ('slamfilter',),
'slamfiltrene': ('slamfilter',),
'slamfiltret': ('slamfilter',),
'slamp': ('slamp',),
'slampen': ('slamp',),
'slampene': ('slamp',),
'slamper': ('slamp',),
'slampumpa': ('slampumpe',),
'slampumpe': ('slampumpe',),
'slampumpen': ('slampumpe',),
'slampumpene': ('slampumpe',),
'slampumper': ('slampumpe',),
'slams': ('slams',),
'slamsen': ('slams',),
'slamsene': ('slams',),
'slamser': ('slams',),
'slamsuger': ('slamsuger',),
'slamsugere': ('slamsuger',),
'slamsugeren': ('slamsuger',),
'slamsugerer': ('slamsuger',),
'slamsugerne': ('slamsuger',),
'slang': ('slang',),
'slangen': ('slang',),
'slangene': ('slang',),
'slanger': ('slang',),
'slang': ('slang',),
'slangen': ('slang',),
'slangene': ('slang',),
'slanger': ('slang',),
'slange': ('slange',),
'slangen': ('slange',),
'slangene': ('slange',),
'slanger': ('slange',),
'slangeagurk': ('slangeagurk',),
'slangeagurken': ('slangeagurk',),
'slangeagurkene': ('slangeagurk',),
'slangeagurker': ('slangeagurk',),
'slangemenneska': ('slangemenneske',),
'slangemenneske': ('slangemenneske',),
'slangemenneskene': ('slangemenneske',),
'slangemennesker': ('slangemenneske',),
'slangemennesket': ('slangemenneske',),
'slangetemmer': ('slangetemmer',),
'slangetemmere': ('slangetemmer',),
'slangetemmeren': ('slangetemmer',),
'slangetemmerer': ('slangetemmer',),
'slangetemmerne': ('slangetemmer',),
'slangeyngel': ('slangeyngel',),
'slangeyngelen': ('slangeyngel',),
'slangeynglene': ('slangeyngel',),
'slankediett': ('slankediett',),
'slankedietten': ('slankediett',),
'slankediettene': ('slankediett',),
'slankedietter': ('slankediett',),
'slankekost': ('slankekost',),
'slankekosten': ('slankekost',),
'slankekostene': ('slankekost',),
'slankekoster': ('slankekost',),
'slankekur': ('slankekur',),
'slankekuren': ('slankekur',),
'slankekurene': ('slankekur',),
'slankekurer': ('slankekur',),
'slanker': ('slanker',),
'slankere': ('slanker',),
'slankeren': ('slanker',),
'slankerer': ('slanker',),
'slankerne': ('slanker',),
'slanking': ('slanking',),
'slankinga': ('slanking',),
'slankingen': ('slanking',),
'slankingene': ('slanking',),
'slankinger': ('slanking',),
'slant': ('slant',),
'slanten': ('slant',),
'slantene': ('slant',),
'slanter': ('slant',),
'slappfisk': ('slappfisk',),
'slappfisken': ('slappfisk',),
'slappfiskene': ('slappfisk',),
'slappfisker': ('slappfisk',),
'slapphet': ('slapphet',),
'slappheta': ('slapphet',),
'slappheten': ('slapphet',),
'slapphetene': ('slapphet',),
'slappheter': ('slapphet',),
'slappkista': ('slappkiste',),
'slappkiste': ('slappkiste',),
'slappkisten': ('slappkiste',),
'slappkistene': ('slappkiste',),
'slappkister': ('slappkiste',),
'slaps': ('slaps',),
'slapsa': ('slaps',),
'slapsene': ('slaps',),
'slapset': ('slaps',),
'slapseføra': ('slapseføre',),
'slapseføre': ('slapseføre',),
'slapseførene': ('slapseføre',),
'slapsefører': ('slapseføre',),
'slapseføret': ('slapseføre',),
'slaraffenland': ('slaraffenland',),
'slaraffenlanda': ('slaraffenland',),
'slaraffenlandene': ('slaraffenland',),
'slaraffenlandet': ('slaraffenland',),
'slaraffenliv': ('slaraffenliv',),
'slaraffenliva': ('slaraffenliv',),
'slaraffenlivene': ('slaraffenliv',),
'slaraffenlivet': ('slaraffenliv',),
'slarv': ('slarv',),
'slarven': ('slarv',),
'slarvene': ('slarv',),
'slarver': ('slarv',),
'slarv': ('slarv',),
'slarva': ('slarv',),
'slarvene': ('slarv',),
'slarvet': ('slarv',),
'slarvekjerring': ('slarvekjerring',),
'slarvekjerringa': ('slarvekjerring',),
'slarvekjerringen': ('slarvekjerring',),
'slarvekjerringene': ('slarvekjerring',),
'slarvekjerringer': ('slarvekjerring',),
'slarveprat': ('slarveprat',),
'slarveprata': ('slarveprat',),
'slarvepraten': ('slarveprat',),
'slarvepratene': ('slarveprat',),
'slarveprater': ('slarveprat',),
'slarvepratet': ('slarveprat',),
'slask': ('slask',),
'slasken': ('slask',),
'slaskene': ('slask',),
'slasker': ('slask',),
'slaur': ('slaur',),
'slauren': ('slaur',),
'slaurene': ('slaur',),
'slaurer': ('slaur',),
'slave': ('slave',),
'slaven': ('slave',),
'slavene': ('slave',),
'slaver': ('slave',),
'slavearbeid': ('slavearbeid',),
'slavearbeida': ('slavearbeid',),
'slavearbeidene': ('slavearbeid',),
'slavearbeider': ('slavearbeid',),
'slavearbeidet': ('slavearbeid',),
'slavedriver': ('slavedriver',),
'slavedrivere': ('slavedriver',),
'slavedriveren': ('slavedriver',),
'slavedriverer': ('slavedriver',),
'slavedriverne': ('slavedriver',),
'slavehandel': ('slavehandel',),
'slavehandelen': ('slavehandel',),
'slavehandlene': ('slavehandel',),
'slavehandler': ('slavehandel',),
'slavehandler': ('slavehandler',),
'slavehandlere': ('slavehandler',),
'slavehandleren': ('slavehandler',),
'slavehandlerer': ('slavehandler',),
'slavehandlerne': ('slavehandler',),
'slavekår': ('slavekår',),
'slavekåra': ('slavekår',),
'slavekårene': ('slavekår',),
'slavekåret': ('slavekår',),
'slavelenka': ('slavelenke',),
'slavelenke': ('slavelenke',),
'slavelenken': ('slavelenke',),
'slavelenkene': ('slavelenke',),
'slavelenker': ('slavelenke',),
'slaveliv': ('slaveliv',),
'slaveliva': ('slaveliv',),
'slavelivene': ('slaveliv',),
'slavelivet': ('slaveliv',),
'slavemarked': ('slavemarked',),
'slavemarkeda': ('slavemarked',),
'slavemarkedene': ('slavemarked',),
'slavemarkeder': ('slavemarked',),
'slavemarkedet': ('slavemarked',),
'slavemarknad': ('slavemarknad',),
'slavemarknaden': ('slavemarknad',),
'slavemarknadene': ('slavemarknad',),
'slavemarknader': ('slavemarknad',),
'slavemerka': ('slavemerke',),
'slavemerke': ('slavemerke',),
'slavemerkene': ('slavemerke',),
'slavemerker': ('slavemerke',),
'slavemerket': ('slavemerke',),
'slavepisk': ('slavepisk',),
'slavepisken': ('slavepisk',),
'slavepiskene': ('slavepisk',),
'slavepisker': ('slavepisk',),
'slaver': ('slaver',),
'slavere': ('slaver',),
'slaveren': ('slaver',),
'slaverer': ('slaver',),
'slaverne': ('slaver',),
'slaveri': ('slaveri',),
'slaveria': ('slaveri',),
'slaveriene': ('slaveri',),
'slaverier': ('slaveri',),
'slaveriet': ('slaveri',),
'slavesjel': ('slavesjel',),
'slavesjela': ('slavesjel',),
'slavesjelen': ('slavesjel',),
'slavesjelene': ('slavesjel',),
'slavesjeler': ('slavesjel',),
'slaveskip': ('slaveskip',),
'slaveskipa': ('slaveskip',),
'slaveskipene': ('slaveskip',),
'slaveskipet': ('slaveskip',),
'slaveåk': ('slaveåk',),
'slaveåka': ('slaveåk',),
'slaveåkene': ('slaveåk',),
'slaveåket': ('slaveåk',),
'slavinna': ('slavinne',),
'slavinne': ('slavinne',),
'slavinnen': ('slavinne',),
'slavinnene': ('slavinne',),
'slavinner': ('slavinne',),
'slavist': ('slavist',),
'slavisten': ('slavist',),
'slavistene': ('slavist',),
'slavister': ('slavist',),
'slavistikk': ('slavistikk',),
'slavistikken': ('slavistikk',),
'slavistikkene': ('slavistikk',),
'slavistikker': ('slavistikk',),
'slavofil': ('slavofil',),
'slavofilen': ('slavofil',),
'slavofilene': ('slavofil',),
'slavofiler': ('slavofil',),
'slavofili': ('slavofili',),
'slavofilien': ('slavofili',),
'slavofiliene': ('slavofili',),
'slavofilier': ('slavofili',),
'slavon': ('slavon',),
'slavonen': ('slavon',),
'slavonene': ('slavon',),
'slavoner': ('slavon',),
'slede': ('slede',),
'sleden': ('slede',),
'sledene': ('slede',),
'sleder': ('slede',),
'sledeføra': ('sledeføre',),
'sledeføre': ('sledeføre',),
'sledeførene': ('sledeføre',),
'sledefører': ('sledeføre',),
'sledeføret': ('sledeføre',),
'sledemeia': ('sledemeie',),
'sledemeie': ('sledemeie',),
'sledemeien': ('sledemeie',),
'sledemeiene': ('sledemeie',),
'sledemeier': ('sledemeie',),
'sledevogn': ('sledevogn',),
'sledevogna': ('sledevogn',),
'sledevognen': ('sledevogn',),
'sledevognene': ('sledevogn',),
'sledevogner': ('sledevogn',),
'sleeping partner': ('sleeping partner',),
'sleeping partnere': ('sleeping partner',),
'sleeping partneren': ('sleeping partner',),
'sleeping partnerer': ('sleeping partner',),
'sleeping partnerne': ('sleeping partner',),
'slegga': ('slegge',),
'slegge': ('slegge',),
'sleggen': ('slegge',),
'sleggene': ('slegge',),
'slegger': ('slegge',),
'sleggekast': ('sleggekast',),
'sleggekasta': ('sleggekast',),
'sleggekastene': ('sleggekast',),
'sleggekastet': ('sleggekast',),
'sleggekaster': ('sleggekaster',),
'sleggekastere': ('sleggekaster',),
'sleggekasteren': ('sleggekaster',),
'sleggekasterer': ('sleggekaster',),
'sleggekasterne': ('sleggekaster',),
'sleid': ('sleid',),
'sleiden': ('sleid',),
'sleidene': ('sleid',),
'sleider': ('sleid',),
'sleide': ('sleide',),
'sleiden': ('sleide',),
'sleidene': ('sleide',),
'sleider': ('sleide',),
'sleik': ('sleik',),
'sleiken': ('sleik',),
'sleikene': ('sleik',),
'sleiker': ('sleik',),
'sleiphet': ('sleiphet',),
'sleipheta': ('sleiphet',),
'sleipheten': ('sleiphet',),
'sleiphetene': ('sleiphet',),
'sleipheter': ('sleiphet',),
'sleiping': ('sleiping',),
'sleipingen': ('sleiping',),
'sleipingene': ('sleiping',),
'sleipinger': ('sleiping',),
'sleis': ('sleis',),
'sleisen': ('sleis',),
'sleisene': ('sleis',),
'sleiser': ('sleis',),
'sleiv': ('sleiv',),
'sleiven': ('sleiv',),
'sleivene': ('sleiv',),
'sleiver': ('sleiv',),
'sleiv': ('sleiv',),
'sleiva': ('sleiv',),
'sleivene': ('sleiv',),
'sleivet': ('sleiv',),
'sleiv': ('sleiv',),
'sleiva': ('sleiv',),
'sleiven': ('sleiv',),
'sleivene': ('sleiv',),
'sleiver': ('sleiv',),
'sleivkjeft': ('sleivkjeft',),
'sleivkjeften': ('sleivkjeft',),
'sleivkjeftene': ('sleivkjeft',),
'sleivkjefter': ('sleivkjeft',),
'sleivspark': ('sleivspark',),
'sleivsparka': ('sleivspark',),
'sleivsparkene': ('sleivspark',),
'sleivsparket': ('sleivspark',),
'slekt': ('slekt',),
'slekta': ('slekt',),
'slekten': ('slekt',),
'slektene': ('slekt',),
'slekter': ('slekt',),
'slektning': ('slektning',),
'slektningen': ('slektning',),
'slektningene': ('slektning',),
'slektninger': ('slektning',),
'slektsarv': ('slektsarv',),
'slektsarven': ('slektsarv',),
'slektsarvene': ('slektsarv',),
'slektsarver': ('slektsarv',),
'slektsfeide': ('slektsfeide',),
'slektsfeiden': ('slektsfeide',),
'slektsfeidene': ('slektsfeide',),
'slektsfeider': ('slektsfeide',),
'slektsforsker': ('slektsforsker',),
'slektsforskere': ('slektsforsker',),
'slektsforskeren': ('slektsforsker',),
'slektsforskerer': ('slektsforsker',),
'slektsforskerne': ('slektsforsker',),
'slektsforskning': ('slektsforskning',),
'slektsforskninga': ('slektsforskning',),
'slektsforskningen': ('slektsforskning',),
'slektsforskningene': ('slektsforskning',),
'slektsforskninger': ('slektsforskning',),
'slektsfølelse': ('slektsfølelse',),
'slektsfølelsen': ('slektsfølelse',),
'slektsfølelsene': ('slektsfølelse',),
'slektsfølelser': ('slektsfølelse',),
'slektsgransker': ('slektsgransker',),
'slektsgranskere': ('slektsgransker',),
'slektsgranskeren': ('slektsgransker',),
'slektsgranskerer': ('slektsgransker',),
'slektsgranskerne': ('slektsgransker',),
'slektsgransking': ('slektsgransking',),
'slektsgranskinga': ('slektsgransking',),
'slektsgranskingen': ('slektsgransking',),
'slektsgranskingene': ('slektsgransking',),
'slektsgranskinger': ('slektsgransking',),
'slektshistoria': ('slektshistorie',),
'slektshistorie': ('slektshistorie',),
'slektshistorien': ('slektshistorie',),
'slektshistoriene': ('slektshistorie',),
'slektshistorier': ('slektshistorie',),
'slektskap': ('slektskap',),
'slektskapa': ('slektskap',),
'slektskapen': ('slektskap',),
'slektskapene': ('slektskap',),
'slektskaper': ('slektskap',),
'slektskapet': ('slektskap',),
'slektskapsband': ('slektskapsband',),
'slektskapsbanda': ('slektskapsband',),
'slektskapsbandene': ('slektskapsband',),
'slektskapsbandet': ('slektskapsband',),
'slektskapsbånd': ('slektskapsbånd',),
'slektskapsbånda': ('slektskapsbånd',),
'slektskapsbåndene': ('slektskapsbånd',),
'slektskapsbåndet': ('slektskapsbånd',),
'slektsledd': ('slektsledd',),
'slektsledda': ('slektsledd',),
'slektsleddene': ('slektsledd',),
'slektsleddet': ('slektsledd',),
'slektsnavn': ('slektsnavn',),
'slektsnavna': ('slektsnavn',),
'slektsnavnene': ('slektsnavn',),
'slektsnavnet': ('slektsnavn',),
'slektstavla': ('slektstavle',),
'slektstavle': ('slektstavle',),
'slektstavlen': ('slektstavle',),
'slektstavlene': ('slektstavle',),
'slektstavler': ('slektstavle',),
'slem': ('slem',),
'slemmen': ('slem',),
'slemmene': ('slem',),
'slemmer': ('slem',),
'slemma': ('slemma',),
'slemmen': ('slemmen',),
'slemming': ('slemming',),
'slemmingen': ('slemming',),
'slemmingene': ('slemming',),
'slemminger': ('slemming',),
'slendrian': ('slendrian',),
'slendrianen': ('slendrian',),
'slendrianene': ('slendrian',),
'slendrianer': ('slendrian',),
'sleng': ('sleng',),
'slengen': ('sleng',),
'slengene': ('sleng',),
'slenger': ('sleng',),
'sleng': ('sleng',),
'slenga': ('sleng',),
'slengene': ('sleng',),
'slenget': ('sleng',),
'slengalder': ('slengalder',),
'slengaldere': ('slengalder',),
'slengalderen': ('slengalder',),
'slengalderer': ('slengalder',),
'slengalderne': ('slengalder',),
'slengaldre': ('slengalder',),
'slengaldrene': ('slengalder',),
'slengaldrer': ('slengalder',),
'slengball': ('slengball',),
'slengballen': ('slengball',),
'slengballene': ('slengball',),
'slengballer': ('slengball',),
'slengbemerkning': ('slengbemerkning',),
'slengbemerkninga': ('slengbemerkning',),
'slengbemerkningen': ('slengbemerkning',),
'slengbemerkningene': ('slengbemerkning',),
'slengbemerkninger': ('slengbemerkning',),
'slengbuksa': ('slengbukse',),
'slengbukse': ('slengbukse',),
'slengbuksen': ('slengbukse',),
'slengbuksene': ('slengbukse',),
'slengbukser': ('slengbukse',),
'slenger': ('slenger',),
'slengere': ('slenger',),
'slengeren': ('slenger',),
'slengerer': ('slenger',),
'slengerne': ('slenger',),
'slengeskott': ('slengeskott',),
'slengeskotta': ('slengeskott',),
'slengeskottene': ('slengeskott',),
'slengeskottet': ('slengeskott',),
'slengeskudd': ('slengeskudd',),
'slengeskudda': ('slengeskudd',),
'slengeskuddene': ('slengeskudd',),
'slengeskuddet': ('slengeskudd',),
'slengkyss': ('slengkyss',),
'slengkyssa': ('slengkyss',),
'slengkyssen': ('slengkyss',),
'slengkyssene': ('slengkyss',),
'slengkysset': ('slengkyss',),
'slentretur': ('slentretur',),
'slentreturen': ('slentretur',),
'slentreturene': ('slentretur',),
'slentreturer': ('slentretur',),
'slep': ('slep',),
'slepen': ('slep',),
'slepene': ('slep',),
'sleper': ('slep',),
'slep': ('slep',),
'slepa': ('slep',),
'slepene': ('slep',),
'slepet': ('slep',),
'slepa': ('slepe',),
'slepe': ('slepe',),
'slepen': ('slepe',),
'slepene': ('slepe',),
'sleper': ('slepe',),
'slepebåt': ('slepebåt',),
'slepebåten': ('slepebåt',),
'slepebåtene': ('slepebåt',),
'slepebåter': ('slepebåt',),
'sleper': ('sleper',),
'slepere': ('sleper',),
'sleperen': ('sleper',),
'sleperer': ('sleper',),
'sleperne': ('sleper',),
'sleperiva': ('sleperive',),
'sleperive': ('sleperive',),
'sleperiven': ('sleperive',),
'sleperivene': ('sleperive',),
'sleperiver': ('sleperive',),
'slepetau': ('slepetau',),
'slepetaua': ('slepetau',),
'slepetauene': ('slepetau',),
'slepetauer': ('slepetau',),
'slepetauet': ('slepetau',),
'slepp': ('slepp',),
'sleppa': ('slepp',),
'sleppene': ('slepp',),
'sleppet': ('slepp',),
'sleppe': ('sleppe',),
'sleppen': ('sleppe',),
'sleppene': ('sleppe',),
'slepper': ('sleppe',),
'slesk': ('slesk',),
'slesken': ('slesk',),
'sleskene': ('slesk',),
'slesker': ('slesk',),
'sleskhet': ('sleskhet',),
'sleskheta': ('sleskhet',),
'sleskheten': ('sleskhet',),
'sleskhetene': ('sleskhet',),
'sleskheter': ('sleskhet',),
'slett': ('slett',),
'sletta': ('slett',),
'slettene': ('slett',),
'slettet': ('slett',),
'slettbak': ('slettbak',),
'slettbaken': ('slettbak',),
'slettbakene': ('slettbak',),
'slettbaker': ('slettbak',),
'sletteland': ('sletteland',),
'slettelanda': ('sletteland',),
'slettelandene': ('sletteland',),
'slettelandet': ('sletteland',),
'sletthøvel': ('sletthøvel',),
'sletthøvelen': ('sletthøvel',),
'sletthøvlene': ('sletthøvel',),
'sletthøvler': ('sletthøvel',),
'slettsnok': ('slettsnok',),
'slettsnoken': ('slettsnok',),
'slettsnokene': ('slettsnok',),
'slettsnoker': ('slettsnok',),
'slettvar': ('slettvar',),
'slettvaren': ('slettvar',),
'slettvarene': ('slettvar',),
'slettvarer': ('slettvar',),
'sleve': ('sleve',),
'sleven': ('sleve',),
'slevene': ('sleve',),
'slever': ('sleve',),
'sleva': ('sleve',),
'sleve': ('sleve',),
'sleven': ('sleve',),
'slevene': ('sleve',),
'slever': ('sleve',),
'sli': ('sli',),
'slia': ('sli',),
'sliene': ('sli',),
'sliet': ('sli',),
'slibrighet': ('slibrighet',),
'slibrigheta': ('slibrighet',),
'slibrigheten': ('slibrighet',),
'slibrighetene': ('slibrighet',),
'slibrigheter': ('slibrighet',),
'sliddersladder': ('sliddersladder',),
'sliddersladdera': ('sliddersladder',),
'sliddersladdere': ('sliddersladder',),
'sliddersladderen': ('sliddersladder',),
'sliddersladderene': ('sliddersladder',),
'sliddersladderer': ('sliddersladder',),
'sliddersladderet': ('sliddersladder',),
'sliddersladderne': ('sliddersladder',),
'sliddersladdre': ('sliddersladder',),
'sliddersladdrene': ('sliddersladder',),
'sliddersladrene': ('sliddersladder',),
'sliddersladrer': ('sliddersladder',),
'slide': ('slide',),
'sliden': ('slide',),
'slides': ('slide',),
'slidesene': ('slide',),
'slig': ('slig',),
'sligen': ('slig',),
'sligene': ('slig',),
'sliger': ('slig',),
'slikk': ('slikk',),
'slikken': ('slikk',),
'slikkene': ('slikk',),
'slikker': ('slikk',),
'slikk': ('slikk',),
'slikka': ('slikk',),
'slikkene': ('slikk',),
'slikket': ('slikk',),
'slikkepott': ('slikkepott',),
'slikkepotten': ('slikkepott',),
'slikkepottene': ('slikkepott',),
'slikkepotter': ('slikkepott',),
'slikkeri': ('slikkeri',),
'slikkeria': ('slikkeri',),
'slikkeriene': ('slikkeri',),
'slikkerier': ('slikkeri',),
'slikkeriet': ('slikkeri',),
'slim': ('slim',),
'slima': ('slim',),
'slimene': ('slim',),
'slimet': ('slim',),
'slimdyr': ('slimdyr',),
'slimdyra': ('slimdyr',),
'slimdyrene': ('slimdyr',),
'slimdyret': ('slimdyr',),
'slimfisk': ('slimfisk',),
'slimfisken': ('slimfisk',),
'slimfiskene': ('slimfisk',),
'slimfisker': ('slimfisk',),
'slimhinna': ('slimhinne',),
'slimhinne': ('slimhinne',),
'slimhinnen': ('slimhinne',),
'slimhinnene': ('slimhinne',),
'slimhinner': ('slimhinne',),
'slimhud': ('slimhud',),
'slimhuda': ('slimhud',),
'slimhuden': ('slimhud',),
'slimhudene': ('slimhud',),
'slimhuder': ('slimhud',),
'slimorm': ('slimorm',),
'slimormen': ('slimorm',),
'slimormene': ('slimorm',),
'slimormer': ('slimorm',),
'slimpose': ('slimpose',),
'slimposen': ('slimpose',),
'slimposene': ('slimpose',),
'slimposer': ('slimpose',),
'slimsa': ('slimse',),
'slimse': ('slimse',),
'slimsen': ('slimse',),
'slimsene': ('slimse',),
'slimser': ('slimse',),
'slimskjede': ('slimskjede',),
'slimskjeden': ('slimskjede',),
'slimskjedene': ('slimskjede',),
'slimskjeder': ('slimskjede',),
'slimsopp': ('slimsopp',),
'slimsoppen': ('slimsopp',),
'slimsoppene': ('slimsopp',),
'slimsopper': ('slimsopp',),
'slimål': ('slimål',),
'slimålen': ('slimål',),
'slimålene': ('slimål',),
'slimåler': ('slimål',),
'slind': ('slind',),
'slinda': ('slind',),
'slinden': ('slind',),
'slindene': ('slind',),
'slinder': ('slind',),
'slinger': ('slinger',),
'slingere': ('slinger',),
'slingeren': ('slinger',),
'slingerer': ('slinger',),
'slingerne': ('slinger',),
'slingre': ('slinger',),
'slingrene': ('slinger',),
'slingrer': ('slinger',),
'slingrebrett': ('slingrebrett',),
'slingrebretta': ('slingrebrett',),
'slingrebrettene': ('slingrebrett',),
'slingrebretter': ('slingrebrett',),
'slingrebrettet': ('slingrebrett',),
'slingrekjøl': ('slingrekjøl',),
'slingrekjølen': ('slingrekjøl',),
'slingrekjølene': ('slingrekjøl',),
'slingrekjøler': ('slingrekjøl',),
'slingrekøya': ('slingrekøye',),
'slingrekøye': ('slingrekøye',),
'slingrekøyen': ('slingrekøye',),
'slingrekøyene': ('slingrekøye',),
'slingrekøyer': ('slingrekøye',),
'slingreskott': ('slingreskott',),
'slingreskotta': ('slingreskott',),
'slingreskottene': ('slingreskott',),
'slingreskottet': ('slingreskott',),
'slingring': ('slingring',),
'slingringa': ('slingring',),
'slingringen': ('slingring',),
'slingringene': ('slingring',),
'slingringer': ('slingring',),
'slingringsmonn': ('slingringsmonn',),
'slingringsmonna': ('slingringsmonn',),
'slingringsmonnen': ('slingringsmonn',),
'slingringsmonnene': ('slingringsmonn',),
'slingringsmonner': ('slingringsmonn',),
'slingringsmonnet': ('slingringsmonn',),
'slintra': ('slintre',),
'slintre': ('slintre',),
'slintren': ('slintre',),
'slintrene': ('slintre',),
'slintrer': ('slintre',),
'slip': ('slip',),
'slipen': ('slip',),
'slipene': ('slip',),
'sliper': ('slip',),
'slipelast': ('slipelast',),
'slipelasta': ('slipelast',),
'slipelasten': ('slipelast',),
'slipelastene': ('slipelast',),
'slipelaster': ('slipelast',),
'slipemasse': ('slipemasse',),
'slipemassen': ('slipemasse',),
'slipemassene': ('slipemasse',),
'slipemasser': ('slipemasse',),
'sliper': ('sliper',),
'slipere': ('sliper',),
'sliperen': ('sliper',),
'sliperer': ('sliper',),
'sliperne': ('sliper',),
'slipereim': ('slipereim',),
'slipereima': ('slipereim',),
'slipereimen': ('slipereim',),
'slipereimene': ('slipereim',),
'slipereimer': ('slipereim',),
'sliperi': ('sliperi',),
'sliperia': ('sliperi',),
'sliperiene': ('sliperi',),
'sliperier': ('sliperi',),
'sliperiet': ('sliperi',),
'sliperitømmer': ('sliperitømmer',),
'sliperitømmera': ('sliperitømmer',),
'sliperitømmerene': ('sliperitømmer',),
'sliperitømmeret': ('sliperitømmer',),
'sliperitømra': ('sliperitømmer',),
'sliperitømre': ('sliperitømmer',),
'sliperitømrene': ('sliperitømmer',),
'slipestein': ('slipestein',),
'slipesteinen': ('slipestein',),
'slipesteinene': ('slipestein',),
'slipesteiner': ('slipestein',),
'slipetømmer': ('slipetømmer',),
'slipetømmera': ('slipetømmer',),
'slipetømmerene': ('slipetømmer',),
'slipetømmeret': ('slipetømmer',),
'slipetømra': ('slipetømmer',),
'slipetømre': ('slipetømmer',),
'slipetømrene': ('slipetømmer',),
'slipetømmer': ('slipetømmer',),
'slipetømmera': ('slipetømmer',),
'slipetømmerene': ('slipetømmer',),
'slipetømmeret': ('slipetømmer',),
'slipetømra': ('slipetømmer',),
'slipetømre': ('slipetømmer',),
'slipetømrene': ('slipetømmer',),
'slipmasse': ('slipmasse',),
'slipmassen': ('slipmasse',),
'slipmassene': ('slipmasse',),
'slipmasser': ('slipmasse',),
'slipp': ('slipp',),
'slippen': ('slipp',),
'slippene': ('slipp',),
'slipper': ('slipp',),
'slipp': ('slipp',),
'slippen': ('slipp',),
'slippene': ('slipp',),
'slipper': ('slipp',),
'slipp': ('slipp',),
'slippa': ('slipp',),
'slippene': ('slipp',),
'slippet': ('slipp',),
'slippover': ('slippover',),
'slippovere': ('slippover',),
'slippoveren': ('slippover',),
'slippoverer': ('slippover',),
'slippoverne': ('slippover',),
'slips': ('slips',),
'slipsa': ('slips',),
'slipsene': ('slips',),
'slipset': ('slips',),
'slipsknute': ('slipsknute',),
'slipsknuten': ('slipsknute',),
'slipsknutene': ('slipsknute',),
'slipsknuter': ('slipsknute',),
'slipsnål': ('slipsnål',),
'slipsnåla': ('slipsnål',),
'slipsnålen': ('slipsnål',),
'slipsnålene': ('slipsnål',),
'slipsnåler': ('slipsnål',),
'sliptømmer': ('sliptømmer',),
'sliptømmera': ('sliptømmer',),
'sliptømmerene': ('sliptømmer',),
'sliptømmeret': ('sliptømmer',),
'sliptømra': ('sliptømmer',),
'sliptømre': ('sliptømmer',),
'sliptømrene': ('sliptømmer',),
'sliptømmer': ('sliptømmer',),
'sliptømmera': ('sliptømmer',),
'sliptømmerene': ('sliptømmer',),
'sliptømmeret': ('sliptømmer',),
'sliptømra': ('sliptømmer',),
'sliptømre': ('sliptømmer',),
'sliptømrene': ('sliptømmer',),
'slir': ('slir',),
'slira': ('slir',),
'sliren': ('slir',),
'slirene': ('slir',),
'slirer': ('slir',),
'slira': ('slire',),
'slire': ('slire',),
'sliren': ('slire',),
'slirene': ('slire',),
'slirer': ('slire',),
'slirekna': ('slirekne',),
'slirekne': ('slirekne',),
'slireknen': ('slirekne',),
'slireknene': ('slirekne',),
'slirekner': ('slirekne',),
'slireknet': ('slirekne',),
'slirekniv': ('slirekniv',),
'slirekniven': ('slirekniv',),
'slireknivene': ('slirekniv',),
'slirekniver': ('slirekniv',),
'slisk': ('slisk',),
'slisken': ('slisk',),
'sliskene': ('slisk',),
'slisker': ('slisk',),
'slisk': ('slisk',),
'slisken': ('slisk',),
'sliskene': ('slisk',),
'slisker': ('slisk',),
'sliske': ('sliske',),
'slisken': ('sliske',),
'sliskene': ('sliske',),
'slisker': ('sliske',),
'sliss': ('sliss',),
'slissen': ('sliss',),
'slissene': ('sliss',),
'slisser': ('sliss',),
'slisse': ('slisse',),
'slissen': ('slisse',),
'slissene': ('slisse',),
'slisser': ('slisse',),
'slitasje': ('slitasje',),
'slitasjen': ('slitasje',),
'slitasjene': ('slitasje',),
'slitasjer': ('slitasje',),
'slitebane': ('slitebane',),
'slitebanen': ('slitebane',),
'slitebanene': ('slitebane',),
'slitebaner': ('slitebane',),
'slitekant': ('slitekant',),
'slitekanten': ('slitekant',),
'slitekantene': ('slitekant',),
'slitekanter': ('slitekant',),
'sliter': ('sliter',),
'slitere': ('sliter',),
'sliteren': ('sliter',),
'sliterer': ('sliter',),
'sliterne': ('sliter',),
'slitestyrke': ('slitestyrke',),
'slitestyrken': ('slitestyrke',),
'slitestyrkene': ('slitestyrke',),
'slitestyrker': ('slitestyrke',),
'slitt': ('slitt',),
'slitta': ('slitt',),
'slittene': ('slitt',),
'slittet': ('slitt',),
'slittung': ('slittung',),
'slittungen': ('slittung',),
'slittungene': ('slittung',),
'slittunger': ('slittung',),
'sliul': ('sliul',),
'sliulen': ('sliul',),
'sliulene': ('sliul',),
'sliuler': ('sliul',),
'slivovits': ('slivovits',),
'slivovitsen': ('slivovits',),
'slivovitsene': ('slivovits',),
'slivovitser': ('slivovits',),
'slo': ('slo',),
'sloa': ('slo',),
'sloene': ('slo',),
'sloet': ('slo',),
'slo': ('slo',),
'sloa': ('slo',),
'sloen': ('slo',),
'sloene': ('slo',),
'sloer': ('slo',),
'slo': ('slo',),
'sloa': ('slo',),
'sloen': ('slo',),
'sloene': ('slo',),
'sloer': ('slo',),
'slodd': ('slodd',),
'slodda': ('slodd',),
'slodden': ('slodd',),
'sloddene': ('slodd',),
'slodder': ('slodd',),
'slodda': ('slodde',),
'slodde': ('slodde',),
'slodden': ('slodde',),
'sloddene': ('slodde',),
'slodder': ('slodde',),
'sloe': ('sloe',),
'sloen': ('sloe',),
'sloene': ('sloe',),
'sloer': ('sloe',),
'slogan': ('slogan',),
'slogana': ('slogan',),
'sloganene': ('slogan',),
'sloganet': ('slogan',),
'slok': ('slok',),
'sloka': ('slok',),
'slokene': ('slok',),
'sloket': ('slok',),
'slokker': ('slokker',),
'slokkere': ('slokker',),
'slokkeren': ('slokker',),
'slokkerer': ('slokker',),
'slokkerne': ('slokker',),
'slokkingsarbeid': ('slokkingsarbeid',),
'slokkingsarbeida': ('slokkingsarbeid',),
'slokkingsarbeidene': ('slokkingsarbeid',),
'slokkingsarbeider': ('slokkingsarbeid',),
'slokkingsarbeidet': ('slokkingsarbeid',),
'slokningsarbeid': ('slokningsarbeid',),
'slokningsarbeida': ('slokningsarbeid',),
'slokningsarbeidene': ('slokningsarbeid',),
'slokningsarbeider': ('slokningsarbeid',),
'slokningsarbeidet': ('slokningsarbeid',),
'slom': ('slom',),
'slommen': ('slom',),
'slommene': ('slom',),
'slommer': ('slom',),
'slott': ('slott',),
'slotta': ('slott',),
'slottene': ('slott',),
'slottet': ('slott',),
'slottingmaskin': ('slottingmaskin',),
'slottingmaskina': ('slottingmaskin',),
'slottingmaskinen': ('slottingmaskin',),
'slottingmaskinene': ('slottingmaskin',),
'slottingmaskiner': ('slottingmaskin',),
'slottsball': ('slottsball',),
'slottsballa': ('slottsball',),
'slottsballene': ('slottsball',),
'slottsballer': ('slottsball',),
'slottsballet': ('slottsball',),
'slottsforvalter': ('slottsforvalter',),
'slottsforvaltere': ('slottsforvalter',),
'slottsforvalteren': ('slottsforvalter',),
'slottsforvalterer': ('slottsforvalter',),
'slottsforvalterne': ('slottsforvalter',),
'slottsherre': ('slottsherre',),
'slottsherren': ('slottsherre',),
'slottsherrene': ('slottsherre',),
'slottsherrer': ('slottsherre',),
'slottskirka': ('slottskirke',),
'slottskirke': ('slottskirke',),
'slottskirken': ('slottskirke',),
'slottskirkene': ('slottskirke',),
'slottskirker': ('slottskirke',),
'slottskjerka': ('slottskjerke',),
'slottskjerke': ('slottskjerke',),
'slottskjerken': ('slottskjerke',),
'slottskjerkene': ('slottskjerke',),
'slottskjerker': ('slottskjerke',),
'slottslen': ('slottslen',),
'slottslena': ('slottslen',),
'slottslenene': ('slottslen',),
'slottslenet': ('slottslen',),
'slottsvakt': ('slottsvakt',),
'slottsvakta': ('slottsvakt',),
'slottsvakten': ('slottsvakt',),
'slottsvaktene': ('slottsvakt',),
'slottsvakter': ('slottsvakt',),
'slottsvin': ('slottsvin',),
'slottsvinen': ('slottsvin',),
'slottsvinene': ('slottsvin',),
'slottsviner': ('slottsvin',),
'slovak': ('slovak',),
'slovaken': ('slovak',),
'slovakene': ('slovak',),
'slovaker': ('slovak',),
'slovakisk': ('slovakisk',),
'slovakisken': ('slovakisk',),
'slovakiskene': ('slovakisk',),
'slovakisker': ('slovakisk',),
'slovener': ('slovener',),
'slovenere': ('slovener',),
'sloveneren': ('slovener',),
'slovenerer': ('slovener',),
'slovenerne': ('slovener',),
'slow motion': ('slow motion',),
'slowfox': ('slowfox',),
'slowfoxen': ('slowfox',),
'slowfoxene': ('slowfox',),
'slowfoxer': ('slowfox',),
'slubbert': ('slubbert',),
'slubberten': ('slubbert',),
'slubbertene': ('slubbert',),
'slubberter': ('slubbert',),
'sludd': ('sludd',),
'sludda': ('sludd',),
'sluddene': ('sludd',),
'sluddet': ('sludd',),
'sludd': ('sludd',),
'sludda': ('sludd',),
'sluddene': ('sludd',),
'sluddet': ('sludd',),
'sludder': ('sludder',),
'sluddera': ('sludder',),
'sluddere': ('sludder',),
'sludderene': ('sludder',),
'sludderet': ('sludder',),
'sludderne': ('sludder',),
'sluffa': ('sluffe',),
'sluffe': ('sluffe',),
'sluffen': ('sluffe',),
'sluffene': ('sluffe',),
'sluffer': ('sluffe',),
'slufs': ('slufs',),
'slufsa': ('slufs',),
'slufsene': ('slufs',),
'slufset': ('slufs',),
'slugger': ('slugger',),
'sluggere': ('slugger',),
'sluggeren': ('slugger',),
'sluggerer': ('slugger',),
'sluggerne': ('slugger',),
'sluhet': ('sluhet',),
'sluheta': ('sluhet',),
'sluheten': ('sluhet',),
'sluhetene': ('sluhet',),
'sluheter': ('sluhet',),
'sluing': ('sluing',),
'sluingen': ('sluing',),
'sluingene': ('sluing',),
'sluinger': ('sluing',),
'sluk': ('sluk',),
'sluken': ('sluk',),
'slukene': ('sluk',),
'sluker': ('sluk',),
'sluk': ('sluk',),
'sluka': ('sluk',),
'slukene': ('sluk',),
'sluket': ('sluk',),
'sluker': ('sluker',),
'slukere': ('sluker',),
'slukeren': ('sluker',),
'slukerer': ('sluker',),
'slukerne': ('sluker',),
'slukfiska': ('slukfiske',),
'slukfiske': ('slukfiske',),
'slukfiskene': ('slukfiske',),
'slukfisker': ('slukfiske',),
'slukfisket': ('slukfiske',),
'slukhals': ('slukhals',),
'slukhalsen': ('slukhals',),
'slukhalsene': ('slukhals',),
'slukhalser': ('slukhals',),
'slukker': ('slukker',),
'slukkere': ('slukker',),
'slukkeren': ('slukker',),
'slukkerer': ('slukker',),
'slukkerne': ('slukker',),
'slukkingsarbeid': ('slukkingsarbeid',),
'slukkingsarbeida': ('slukkingsarbeid',),
'slukkingsarbeidene': ('slukkingsarbeid',),
'slukkingsarbeider': ('slukkingsarbeid',),
'slukkingsarbeidet': ('slukkingsarbeid',),
'slukningsarbeid': ('slukningsarbeid',),
'slukningsarbeida': ('slukningsarbeid',),
'slukningsarbeidene': ('slukningsarbeid',),
'slukningsarbeider': ('slukningsarbeid',),
'slukningsarbeidet': ('slukningsarbeid',),
'slukt': ('slukt',),
'slukten': ('slukt',),
'sluktene': ('slukt',),
'slukter': ('slukt',),
'slum': ('slum',),
'slummen': ('slum',),
'slummene': ('slum',),
'slummer': ('slum',),
'slummer': ('slummer',),
'slummere': ('slummer',),
'slummeren': ('slummer',),
'slummerer': ('slummer',),
'slummerne': ('slummer',),
'slumrene': ('slummer',),
'slumrer': ('slummer',),
'slump': ('slump',),
'slumpen': ('slump',),
'slumpene': ('slump',),
'slumper': ('slump',),
'slumpehell': ('slumpehell',),
'slumpehella': ('slumpehell',),
'slumpehellene': ('slumpehell',),
'slumpehellet': ('slumpehell',),
'slumpeskytter': ('slumpeskytter',),
'slumpeskyttere': ('slumpeskytter',),
'slumpeskytteren': ('slumpeskytter',),
'slumpeskytterer': ('slumpeskytter',),
'slumpeskytterne': ('slumpeskytter',),
'slumpetreff': ('slumpetreff',),
'slumpetreffa': ('slumpetreff',),
'slumpetreffene': ('slumpetreff',),
'slumpetreffet': ('slumpetreff',),
'slumreteppa': ('slumreteppe',),
'slumreteppe': ('slumreteppe',),
'slumreteppene': ('slumreteppe',),
'slumretepper': ('slumreteppe',),
'slumreteppet': ('slumreteppe',),
'slums': ('slums',),
'slumsen': ('slums',),
'slumsene': ('slums',),
'slumser': ('slums',),
'slumsa': ('slumse',),
'slumse': ('slumse',),
'slumsen': ('slumse',),
'slumsene': ('slumse',),
'slumser': ('slumse',),
'slumsøster': ('slumsøster',),
'slumsøstera': ('slumsøster',),
'slumsøsteren': ('slumsøster',),
'slumsøstre': ('slumsøster',),
'slumsøstrene': ('slumsøster',),
'slumsøstrer': ('slumsøster',),
'slupp': ('slupp',),
'sluppen': ('slupp',),
'sluppene': ('slupp',),
'slupper': ('slupp',),
'slurk': ('slurk',),
'slurken': ('slurk',),
'slurkene': ('slurk',),
'slurker': ('slurk',),
'slurp': ('slurp',),
'slurpa': ('slurp',),
'slurpene': ('slurp',),
'slurpet': ('slurp',),
'slurv': ('slurv',),
'slurven': ('slurv',),
'slurvene': ('slurv',),
'slurver': ('slurv',),
'slurv': ('slurv',),
'slurva': ('slurv',),
'slurvene': ('slurv',),
'slurvet': ('slurv',),
'slurva': ('slurve',),
'slurve': ('slurve',),
'slurven': ('slurve',),
'slurvene': ('slurve',),
'slurver': ('slurve',),
'slurvefeil': ('slurvefeil',),
'slurvefeilen': ('slurvefeil',),
'slurvefeilene': ('slurvefeil',),
'slusa': ('sluse',),
'sluse': ('sluse',),
'slusen': ('sluse',),
'slusene': ('sluse',),
'sluser': ('sluse',),
'slusekammer': ('slusekammer',),
'slusekammeret': ('slusekammer',),
'slusekamra': ('slusekammer',),
'slusekamre': ('slusekammer',),
'slusekamrene': ('slusekammer',),
'sluseport': ('sluseport',),
'sluseporten': ('sluseport',),
'sluseportene': ('sluseport',),
'sluseporter': ('sluseport',),
'slusk': ('slusk',),
'slusken': ('slusk',),
'sluskene': ('slusk',),
'slusker': ('slusk',),
'sluskeri': ('sluskeri',),
'sluskeria': ('sluskeri',),
'sluskeriene': ('sluskeri',),
'sluskerier': ('sluskeri',),
'sluskeriet': ('sluskeri',),
'slut': ('slut',),
'sluta': ('slut',),
'slutene': ('slut',),
'slutet': ('slut',),
'slut': ('slut',),
'sluta': ('slut',),
'slutene': ('slut',),
'slutet': ('slut',),
'slutning': ('slutning',),
'slutninga': ('slutning',),
'slutningen': ('slutning',),
'slutningene': ('slutning',),
'slutninger': ('slutning',),
'slutningsakkord': ('slutningsakkord',),
'slutningsakkorden': ('slutningsakkord',),
'slutningsakkordene': ('slutningsakkord',),
'slutningsakkorder': ('slutningsakkord',),
'slutningsrekka': ('slutningsrekke',),
'slutningsrekke': ('slutningsrekke',),
'slutningsrekken': ('slutningsrekke',),
'slutningsrekkene': ('slutningsrekke',),
'slutningsrekker': ('slutningsrekke',),
'slutt': ('slutt',),
'slutten': ('slutt',),
'sluttene': ('slutt',),
'slutter': ('slutt',),
'slutt-tid': ('slutt-tid',),
'slutt-tida': ('slutt-tid',),
'slutt-tiden': ('slutt-tid',),
'slutt-tidene': ('slutt-tid',),
'slutt-tider': ('slutt-tid',),
'sluttakkord': ('sluttakkord',),
'sluttakkorden': ('sluttakkord',),
'sluttakkordene': ('sluttakkord',),
'sluttakkorder': ('sluttakkord',),
'slutter': ('slutter',),
'sluttere': ('slutter',),
'slutteren': ('slutter',),
'slutterer': ('slutter',),
'slutterne': ('slutter',),
'sluttid': ('sluttid',),
'sluttida': ('sluttid',),
'sluttiden': ('sluttid',),
'sluttidene': ('sluttid',),
'sluttider': ('sluttid',),
'sluttsats': ('sluttsats',),
'sluttsatsen': ('sluttsats',),
'sluttsatsene': ('sluttsats',),
'sluttsatser': ('sluttsats',),
'sluttseddel': ('sluttseddel',),
'sluttseddelen': ('sluttseddel',),
'sluttsedlene': ('sluttseddel',),
'sluttsedler': ('sluttseddel',),
'sluttspell': ('sluttspell',),
'sluttspella': ('sluttspell',),
'sluttspellene': ('sluttspell',),
'sluttspellet': ('sluttspell',),
'sluttspill': ('sluttspill',),
'sluttspilla': ('sluttspill',),
'sluttspillene': ('sluttspill',),
'sluttspillet': ('sluttspill',),
'sluttspurt': ('sluttspurt',),
'sluttspurten': ('sluttspurt',),
'sluttspurtene': ('sluttspurt',),
'sluttspurter': ('sluttspurt',),
'sluttstein': ('sluttstein',),
'sluttsteinen': ('sluttstein',),
'sluttsteinene': ('sluttstein',),
'sluttsteiner': ('sluttstein',),
'sluttstrek': ('sluttstrek',),
'sluttstreken': ('sluttstrek',),
'sluttstrekene': ('sluttstrek',),
'sluttstreker': ('sluttstrek',),
'sluttstykka': ('sluttstykke',),
'sluttstykke': ('sluttstykke',),
'sluttstykkene': ('sluttstykke',),
'sluttstykker': ('sluttstykke',),
'sluttstykket': ('sluttstykke',),
'sluttsum': ('sluttsum',),
'sluttsummen': ('sluttsum',),
'sluttsummene': ('sluttsum',),
'sluttsummer': ('sluttsum',),
'sly': ('sly',),
'slya': ('sly',),
'slyene': ('sly',),
'slyet': ('sly',),
'slyng': ('slyng',),
'slynga': ('slyng',),
'slyngen': ('slyng',),
'slyngene': ('slyng',),
'slynget': ('slyng',),
'slynga': ('slynge',),
'slynge': ('slynge',),
'slyngen': ('slynge',),
'slyngene': ('slynge',),
'slynger': ('slynge',),
'slyngel': ('slyngel',),
'slyngelen': ('slyngel',),
'slynglene': ('slyngel',),
'slyngler': ('slyngel',),
'slyngelalder': ('slyngelalder',),
'slyngelaldere': ('slyngelalder',),
'slyngelalderen': ('slyngelalder',),
'slyngelalderer': ('slyngelalder',),
'slyngelalderne': ('slyngelalder',),
'slyngelaldre': ('slyngelalder',),
'slyngelaldrene': ('slyngelalder',),
'slyngelaldrer': ('slyngelalder',),
'slyngning': ('slyngning',),
'slyngninga': ('slyngning',),
'slyngningen': ('slyngning',),
'slyngningene': ('slyngning',),
'slyngninger': ('slyngning',),
'slyngplanta': ('slyngplante',),
'slyngplante': ('slyngplante',),
'slyngplanten': ('slyngplante',),
'slyngplantene': ('slyngplante',),
'slyngplanter': ('slyngplante',),
'slyngrosa': ('slyngrose',),
'slyngrose': ('slyngrose',),
'slyngrosen': ('slyngrose',),
'slyngrosene': ('slyngrose',),
'slyngroser': ('slyngrose',),
'slå': ('slå',),
'slåa': ('slå',),
'slåen': ('slå',),
'slåene': ('slå',),
'slåer': ('slå',),
'slåbrok': ('slåbrok',),
'slåbroken': ('slåbrok',),
'slåbrokene': ('slåbrok',),
'slåbroker': ('slåbrok',),
'slåmaskin': ('slåmaskin',),
'slåmaskina': ('slåmaskin',),
'slåmaskinen': ('slåmaskin',),
'slåmaskinene': ('slåmaskin',),
'slåmaskiner': ('slåmaskin',),
'slåp': ('slåp',),
'slåpen': ('slåp',),
'slåpene': ('slåp',),
'slåper': ('slåp',),
'slåpa': ('slåpe',),
'slåpe': ('slåpe',),
'slåpen': ('slåpe',),
'slåpene': ('slåpe',),
'slåper': ('slåpe',),
'slåpetorn': ('slåpetorn',),
'slåpetornen': ('slåpetorn',),
'slåpetornene': ('slåpetorn',),
'slåpetorner': ('slåpetorn',),
'slåsshanske': ('slåsshanske',),
'slåsshansken': ('slåsshanske',),
'slåsshanskene': ('slåsshanske',),
'slåsshansker': ('slåsshanske',),
'slåsskjempa': ('slåsskjempe',),
'slåsskjempe': ('slåsskjempe',),
'slåsskjempen': ('slåsskjempe',),
'slåsskjempene': ('slåsskjempe',),
'slåsskjemper': ('slåsskjempe',),
'slåtta': ('slåtte',),
'slåtte': ('slåtte',),
'slåtten': ('slåtte',),
'slåttene': ('slåtte',),
'slåtter': ('slåtte',),
'slåttegraut': ('slåttegraut',),
'slåttegrauten': ('slåttegraut',),
'slåttegrautene': ('slåttegraut',),
'slåttegrauter': ('slåttegraut',),
'slåttekar': ('slåttekar',),
'slåttekaren': ('slåttekar',),
'slåttekarene': ('slåttekar',),
'slåttekarer': ('slåttekar',),
'slåttonn': ('slåttonn',),
'slåttonna': ('slåttonn',),
'slåttonnen': ('slåttonn',),
'slåttonnene': ('slåttonn',),
'slåttonner': ('slåttonn',),
'sløa': ('sløe',),
'sløe': ('sløe',),
'sløen': ('sløe',),
'sløene': ('sløe',),
'sløer': ('sløe',),
'sløka': ('sløke',),
'sløke': ('sløke',),
'sløken': ('sløke',),
'sløkene': ('sløke',),
'sløker': ('sløke',),
'slør': ('slør',),
'sløren': ('slør',),
'slørene': ('slør',),
'slører': ('slør',),
'slør': ('slør',),
'sløra': ('slør',),
'slørene': ('slør',),
'sløret': ('slør',),
'sløresegl': ('sløresegl',),
'sløresegla': ('sløresegl',),
'sløreseglene': ('sløresegl',),
'sløreseglet': ('sløresegl',),
'sløreseil': ('sløreseil',),
'sløreseila': ('sløreseil',),
'sløreseilene': ('sløreseil',),
'sløreseilet': ('sløreseil',),
'slørevind': ('slørevind',),
'slørevinden': ('slørevind',),
'slørevindene': ('slørevind',),
'slørevinder': ('slørevind',),
'slørsky': ('slørsky',),
'slørskya': ('slørsky',),
'slørskyen': ('slørsky',),
'slørskyene': ('slørsky',),
'slørskyer': ('slørsky',),
'slørsopp': ('slørsopp',),
'slørsoppen': ('slørsopp',),
'slørsoppene': ('slørsopp',),
'slørsopper': ('slørsopp',),
'slørveng': ('slørveng',),
'slørvengen': ('slørveng',),
'slørvengene': ('slørveng',),
'slørvenger': ('slørveng',),
'slørving': ('slørving',),
'slørvingen': ('slørving',),
'slørvingene': ('slørving',),
'slørvinger': ('slørving',),
'slørvinge': ('slørvinge',),
'slørvingen': ('slørvinge',),
'slørvingene': ('slørvinge',),
'slørvinger': ('slørvinge',),
'sløser': ('sløser',),
'sløsere': ('sløser',),
'sløseren': ('sløser',),
'sløserer': ('sløser',),
'sløserne': ('sløser',),
'sløseri': ('sløseri',),
'sløseria': ('sløseri',),
'sløseriene': ('sløseri',),
'sløserier': ('sløseri',),
'sløseriet': ('sløseri',),
'sløvsinn': ('sløvsinn',),
'sløvsinna': ('sløvsinn',),
'sløvsinnene': ('sløvsinn',),
'sløvsinnet': ('sløvsinn',),
'sløyd': ('sløyd',),
'sløyden': ('sløyd',),
'sløydene': ('sløyd',),
'sløyder': ('sløyd',),
'sløyfa': ('sløyfe',),
'sløyfe': ('sløyfe',),
'sløyfen': ('sløyfe',),
'sløyfene': ('sløyfe',),
'sløyfer': ('sløyfe',),
'sløyfeparentes': ('sløyfeparentes',),
'sløyfeparentesen': ('sløyfeparentes',),
'sløyfeparentesene': ('sløyfeparentes',),
'sløyfeparenteser': ('sløyfeparentes',),
'smadder': ('smadder',),
'smaddera': ('smadder',),
'smaddere': ('smadder',),
'smadderene': ('smadder',),
'smadderet': ('smadder',),
'smadderne': ('smadder',),
'smak': ('smak',),
'smaken': ('smak',),
'smakene': ('smak',),
'smaker': ('smak',),
'smakebete': ('smakebete',),
'smakebeten': ('smakebete',),
'smakebetene': ('smakebete',),
'smakebeter': ('smakebete',),
'smakebit': ('smakebit',),
'smakebiten': ('smakebit',),
'smakebitene': ('smakebit',),
'smakebiter': ('smakebit',),
'smaker': ('smaker',),
'smakere': ('smaker',),
'smakeren': ('smaker',),
'smakerer': ('smaker',),
'smakerne': ('smaker',),
'smakløshet': ('smakløshet',),
'smakløsheta': ('smakløshet',),
'smakløsheten': ('smakløshet',),
'smakløshetene': ('smakløshet',),
'smakløsheter': ('smakløshet',),
'smakscella': ('smakscelle',),
'smakscelle': ('smakscelle',),
'smakscellen': ('smakscelle',),
'smakscellene': ('smakscelle',),
'smaksceller': ('smakscelle',),
'smaksdommer': ('smaksdommer',),
'smaksdommere': ('smaksdommer',),
'smaksdommeren': ('smaksdommer',),
'smaksdommerer': ('smaksdommer',),
'smaksdommerne': ('smaksdommer',),
'smaksløk': ('smaksløk',),
'smaksløken': ('smaksløk',),
'smaksløkene': ('smaksløk',),
'smaksløker': ('smaksløk',),
'smaksnerve': ('smaksnerve',),
'smaksnerven': ('smaksnerve',),
'smaksnervene': ('smaksnerve',),
'smaksnerver': ('smaksnerve',),
'smaksprøva': ('smaksprøve',),
'smaksprøve': ('smaksprøve',),
'smaksprøven': ('smaksprøve',),
'smaksprøvene': ('smaksprøve',),
'smaksprøver': ('smaksprøve',),
'smakssak': ('smakssak',),
'smakssaka': ('smakssak',),
'smakssaken': ('smakssak',),
'smakssakene': ('smakssak',),
'smakssaker': ('smakssak',),
'smakssans': ('smakssans',),
'smakssansen': ('smakssans',),
'smakssansene': ('smakssans',),
'smakssanser': ('smakssans',),
'smakssentra': ('smakssentrum',),
'smakssentraene': ('smakssentrum',),
'smakssentre': ('smakssentrum',),
'smakssentrene': ('smakssentrum',),
'smakssentret': ('smakssentrum',),
'smakssentrum': ('smakssentrum',),
'smakssentrumet': ('smakssentrum',),
'smakstilsetning': ('smakstilsetning',),
'smakstilsetninga': ('smakstilsetning',),
'smakstilsetningen': ('smakstilsetning',),
'smakstilsetningene': ('smakstilsetning',),
'smakstilsetninger': ('smakstilsetning',),
'smale': ('smale',),
'smalen': ('smale',),
'smalene': ('smale',),
'smaler': ('smale',),
'smale': ('smale',),
'smalen': ('smale',),
'smalene': ('smale',),
'smaler': ('smale',),
'smalebeist': ('smalebeist',),
'smalebeista': ('smalebeist',),
'smalebeistene': ('smalebeist',),
'smalebeistet': ('smalebeist',),
'smalebeita': ('smalebeite',),
'smalebeite': ('smalebeite',),
'smalebeitene': ('smalebeite',),
'smalebeiter': ('smalebeite',),
'smalebeitet': ('smalebeite',),
'smalebest': ('smalebest',),
'smalebesta': ('smalebest',),
'smalebestene': ('smalebest',),
'smalebestet': ('smalebest',),
'smalehovud': ('smalehovud',),
'smalehovuda': ('smalehovud',),
'smalehovudene': ('smalehovud',),
'smalehovuder': ('smalehovud',),
'smalehovudet': ('smalehovud',),
'smalfilm': ('smalfilm',),
'smalfilmen': ('smalfilm',),
'smalfilmene': ('smalfilm',),
'smalfilmer': ('smalfilm',),
'smalhans': ('smalhans',),
'smalhansen': ('smalhans',),
'smalhansene': ('smalhans',),
'smalhanser': ('smalhans',),
'smallegg': ('smallegg',),
'smalleggen': ('smallegg',),
'smalleggene': ('smallegg',),
'smallegger': ('smallegg',),
'smalrygg': ('smalrygg',),
'smalryggen': ('smalrygg',),
'smalryggene': ('smalrygg',),
'smalrygger': ('smalrygg',),
'smalte': ('smalte',),
'smalten': ('smalte',),
'smaltene': ('smalte',),
'smalter': ('smalte',),
'smaragd': ('smaragd',),
'smaragden': ('smaragd',),
'smaragdene': ('smaragd',),
'smaragder': ('smaragd',),
'smarting': ('smarting',),
'smartingen': ('smarting',),
'smartingene': ('smarting',),
'smartinger': ('smarting',),
'smartness': ('smartness',),
'smartnessen': ('smartness',),
'smartnessene': ('smartness',),
'smartnesser': ('smartness',),
'smash': ('smash',),
'smashen': ('smash',),
'smashene': ('smash',),
'smasher': ('smash',),
'smask': ('smask',),
'smasken': ('smask',),
'smaskene': ('smask',),
'smasker': ('smask',),
'smatt': ('smatt',),
'smatta': ('smatt',),
'smatten': ('smatt',),
'smattene': ('smatt',),
'smattet': ('smatt',),
'smau': ('smau',),
'smaua': ('smau',),
'smauene': ('smau',),
'smauet': ('smau',),
'smau': ('smau',),
'smaua': ('smau',),
'smauene': ('smau',),
'smauet': ('smau',),
'smed': ('smed',),
'smeden': ('smed',),
'smedene': ('smed',),
'smeder': ('smed',),
'smededikt': ('smededikt',),
'smededikta': ('smededikt',),
'smedediktene': ('smededikt',),
'smedediktet': ('smededikt',),
'smedeskrift': ('smedeskrift',),
'smedeskrifta': ('smedeskrift',),
'smedeskriftene': ('smedeskrift',),
'smedeskrifter': ('smedeskrift',),
'smedeskriftet': ('smedeskrift',),
'smeik': ('smeik',),
'smeiken': ('smeik',),
'smeikene': ('smeik',),
'smeiker': ('smeik',),
'smeis': ('smeis',),
'smeisa': ('smeis',),
'smeisen': ('smeis',),
'smeisene': ('smeis',),
'smeiser': ('smeis',),
'smeiset': ('smeis',),
'smekkdør': ('smekkdør',),
'smekkdøra': ('smekkdør',),
'smekkdøren': ('smekkdør',),
'smekkdørene': ('smekkdør',),
'smekkdører': ('smekkdør',),
'smekka': ('smekke',),
'smekke': ('smekke',),
'smekken': ('smekke',),
'smekkene': ('smekke',),
'smekker': ('smekke',),
'smekklås': ('smekklås',),
'smekklåsa': ('smekklås',),
'smekklåsen': ('smekklås',),
'smekklåsene': ('smekklås',),
'smekklåser': ('smekklås',),
'smekklåset': ('smekklås',),
'smella': ('smelle',),
'smelle': ('smelle',),
'smellen': ('smelle',),
'smellene': ('smelle',),
'smeller': ('smelle',),
'smeller': ('smeller',),
'smellere': ('smeller',),
'smelleren': ('smeller',),
'smellerer': ('smeller',),
'smellerne': ('smeller',),
'smellkulda': ('smellkulde',),
'smellkulde': ('smellkulde',),
'smellkulden': ('smellkulde',),
'smellkuldene': ('smellkulde',),
'smellkulder': ('smellkulde',),
'smellkyss': ('smellkyss',),
'smellkyssa': ('smellkyss',),
'smellkyssen': ('smellkyss',),
'smellkyssene': ('smellkyss',),
'smellkysset': ('smellkyss',),
'smellstikka': ('smellstikke',),
'smellstikke': ('smellstikke',),
'smellstikken': ('smellstikke',),
'smellstikkene': ('smellstikke',),
'smellstikker': ('smellstikke',),
'smelta': ('smelte',),
'smelte': ('smelte',),
'smelten': ('smelte',),
'smeltene': ('smelte',),
'smelter': ('smelte',),
'smeltedigel': ('smeltedigel',),
'smeltedigelen': ('smeltedigel',),
'smeltediglene': ('smeltedigel',),
'smeltedigler': ('smeltedigel',),
'smeltehytta': ('smeltehytte',),
'smeltehytte': ('smeltehytte',),
'smeltehytten': ('smeltehytte',),
'smeltehyttene': ('smeltehytte',),
'smeltehytter': ('smeltehytte',),
'smeltemasse': ('smeltemasse',),
'smeltemassen': ('smeltemasse',),
'smeltemassene': ('smeltemasse',),
'smeltemasser': ('smeltemasse',),
'smelteomn': ('smelteomn',),
'smelteomnen': ('smelteomn',),
'smelteomnene': ('smelteomn',),
'smelteomner': ('smelteomn',),
'smelteomn': ('smelteomn',),
'smelteomnen': ('smelteomn',),
'smelteomnene': ('smelteomn',),
'smelteomner': ('smelteomn',),
'smelteomnshall': ('smelteomnshall',),
'smelteomnshallen': ('smelteomnshall',),
'smelteomnshallene': ('smelteomnshall',),
'smelteomnshaller': ('smelteomnshall',),
'smelteomnshall': ('smelteomnshall',),
'smelteomnshallen': ('smelteomnshall',),
'smelteomnshallene': ('smelteomnshall',),
'smelteomnshaller': ('smelteomnshall',),
'smelteost': ('smelteost',),
'smelteosten': ('smelteost',),
'smelteostene': ('smelteost',),
'smelteoster': ('smelteost',),
'smelteovn': ('smelteovn',),
'smelteovnen': ('smelteovn',),
'smelteovnene': ('smelteovn',),
'smelteovner': ('smelteovn',),
'smelteovn': ('smelteovn',),
'smelteovnen': ('smelteovn',),
'smelteovnene': ('smelteovn',),
'smelteovner': ('smelteovn',),
'smelteovnshall': ('smelteovnshall',),
'smelteovnshallen': ('smelteovnshall',),
'smelteovnshallene': ('smelteovnshall',),
'smelteovnshaller': ('smelteovnshall',),
'smelteovnshall': ('smelteovnshall',),
'smelteovnshallen': ('smelteovnshall',),
'smelteovnshallene': ('smelteovnshall',),
'smelteovnshaller': ('smelteovnshall',),
'smeltepunkt': ('smeltepunkt',),
'smeltepunkta': ('smeltepunkt',),
'smeltepunktene': ('smeltepunkt',),
'smeltepunkter': ('smeltepunkt',),
'smeltepunktet': ('smeltepunkt',),
'smeltevann': ('smeltevann',),
'smeltevanna': ('smeltevann',),
'smeltevannene': ('smeltevann',),
'smeltevannet': ('smeltevann',),
'smeltevarme': ('smeltevarme',),
'smeltevarmen': ('smeltevarme',),
'smeltevarmene': ('smeltevarme',),
'smeltevarmer': ('smeltevarme',),
'smeltevatn': ('smeltevatn',),
'smeltevatna': ('smeltevatn',),
'smeltevatnene': ('smeltevatn',),
'smeltevatnet': ('smeltevatn',),
'smelteverk': ('smelteverk',),
'smelteverka': ('smelteverk',),
'smelteverkene': ('smelteverk',),
'smelteverker': ('smelteverk',),
'smelteverket': ('smelteverk',),
'smergel': ('smergel',),
'smergelen': ('smergel',),
'smerglene': ('smergel',),
'smergler': ('smergel',),
'smergelskiva': ('smergelskive',),
'smergelskive': ('smergelskive',),
'smergelskiven': ('smergelskive',),
'smergelskivene': ('smergelskive',),
'smergelskiver': ('smergelskive',),
'smerte': ('smerte',),
'smerten': ('smerte',),
'smertene': ('smerte',),
'smerter': ('smerte',),
'smertegrensa': ('smertegrense',),
'smertegrense': ('smertegrense',),
'smertegrensen': ('smertegrense',),
'smertegrensene': ('smertegrense',),
'smertegrenser': ('smertegrense',),
'smertensbarn': ('smertensbarn',),
'smertensbarna': ('smertensbarn',),
'smertensbarnene': ('smertensbarn',),
'smertensbarnet': ('smertensbarn',),
'smerteskrik': ('smerteskrik',),
'smerteskrika': ('smerteskrik',),
'smerteskrikene': ('smerteskrik',),
'smerteskriket': ('smerteskrik',),
'smetta': ('smette',),
'smette': ('smette',),
'smetten': ('smette',),
'smettene': ('smette',),
'smetter': ('smette',),
'smettet': ('smette',),
'smia': ('smie',),
'smie': ('smie',),
'smien': ('smie',),
'smiene': ('smie',),
'smier': ('smie',),
'smiebelg': ('smiebelg',),
'smiebelgen': ('smiebelg',),
'smiebelgene': ('smiebelg',),
'smiebelger': ('smiebelg',),
'smieste': ('smieste',),
'smiestea': ('smieste',),
'smiesteene': ('smieste',),
'smiesteet': ('smieste',),
'smiger': ('smiger',),
'smigere': ('smiger',),
'smigeren': ('smiger',),
'smigerer': ('smiger',),
'smigerne': ('smiger',),
'smigre': ('smiger',),
'smigrene': ('smiger',),
'smigrer': ('smiger',),
'smihammar': ('smihammar',),
'smihammaren': ('smihammar',),
'smihamrene': ('smihammar',),
'smihamrer': ('smihammar',),
'smihammer': ('smihammer',),
'smihammere': ('smihammer',),
'smihammeren': ('smihammer',),
'smihammerer': ('smihammer',),
'smihammerne': ('smihammer',),
'smihamrene': ('smihammer',),
'smihamrer': ('smihammer',),
'smijern': ('smijern',),
'smijerna': ('smijern',),
'smijernene': ('smijern',),
'smijernet': ('smijern',),
'smijernsport': ('smijernsport',),
'smijernsporten': ('smijernsport',),
'smijernsportene': ('smijernsport',),
'smijernsporter': ('smijernsport',),
'smikk': ('smikk',),
'smikka': ('smikk',),
'smikken': ('smikk',),
'smikkene': ('smikk',),
'smikket': ('smikk',),
'smil': ('smil',),
'smila': ('smil',),
'smilen': ('smil',),
'smilene': ('smil',),
'smilet': ('smil',),
'smileband': ('smileband',),
'smilebanda': ('smileband',),
'smilebandene': ('smileband',),
'smilebandet': ('smileband',),
'smilebånd': ('smilebånd',),
'smilebånda': ('smilebånd',),
'smilebåndene': ('smilebånd',),
'smilebåndet': ('smilebånd',),
'smilehol': ('smilehol',),
'smilehola': ('smilehol',),
'smileholene': ('smilehol',),
'smileholet': ('smilehol',),
'smilehull': ('smilehull',),
'smilehulla': ('smilehull',),
'smilehullene': ('smilehull',),
'smilehuller': ('smilehull',),
'smilehullet': ('smilehull',),
'smilekurs': ('smilekurs',),
'smilekursa': ('smilekurs',),
'smilekursene': ('smilekurs',),
'smilekurser': ('smilekurs',),
'smilekurset': ('smilekurs',),
'smilekursene': ('smilekursus',),
'smilekurser': ('smilekursus',),
'smilekursus': ('smilekursus',),
'smilekursuset': ('smilekursus',),
'smilerynka': ('smilerynke',),
'smilerynke': ('smilerynke',),
'smilerynken': ('smilerynke',),
'smilerynkene': ('smilerynke',),
'smilerynker': ('smilerynke',),
'sminka': ('sminke',),
'sminke': ('sminke',),
'sminken': ('sminke',),
'sminkene': ('sminke',),
'sminker': ('sminke',),
'sminkebord': ('sminkebord',),
'sminkeborda': ('sminkebord',),
'sminkebordene': ('sminkebord',),
'sminkeborder': ('sminkebord',),
'sminkebordet': ('sminkebord',),
'sminkør': ('sminkør',),
'sminkøren': ('sminkør',),
'sminkørene': ('sminkør',),
'sminkører': ('sminkør',),
'sminkøsa': ('sminkøse',),
'sminkøse': ('sminkøse',),
'sminkøsen': ('sminkøse',),
'sminkøsene': ('sminkøse',),
'sminkøser': ('sminkøse',),
'smisk': ('smisk',),
'smisken': ('smisk',),
'smiskene': ('smisk',),
'smisker': ('smisk',),
'smisk': ('smisk',),
'smiska': ('smisk',),
'smiskene': ('smisk',),
'smisket': ('smisk',),
'smitt': ('smitt',),
'smitte': ('smitte',),
'smitten': ('smitte',),
'smittene': ('smitte',),
'smitter': ('smitte',),
'smittebærer': ('smittebærer',),
'smittebærere': ('smittebærer',),
'smittebæreren': ('smittebærer',),
'smittebærerer': ('smittebærer',),
'smittebærerne': ('smittebærer',),
'smittefare': ('smittefare',),
'smittefaren': ('smittefare',),
'smittefarene': ('smittefare',),
'smittefarer': ('smittefare',),
'smittekilde': ('smittekilde',),
'smittekilden': ('smittekilde',),
'smittekildene': ('smittekilde',),
'smittekilder': ('smittekilde',),
'smittekjelda': ('smittekjelde',),
'smittekjelde': ('smittekjelde',),
'smittekjelden': ('smittekjelde',),
'smittekjeldene': ('smittekjelde',),
'smittekjelder': ('smittekjelde',),
'smittespreder': ('smittespreder',),
'smittespredere': ('smittespreder',),
'smittesprederen': ('smittespreder',),
'smittesprederer': ('smittespreder',),
'smittesprederne': ('smittespreder',),
'smittestoff': ('smittestoff',),
'smittestoffa': ('smittestoff',),
'smittestoffene': ('smittestoff',),
'smittestoffer': ('smittestoff',),
'smittestoffet': ('smittestoff',),
'smog': ('smog',),
'smogen': ('smog',),
'smogene': ('smog',),
'smoger': ('smog',),
'smoking': ('smoking',),
'smokingen': ('smoking',),
'smokingene': ('smoking',),
'smokinger': ('smoking',),
'smokk': ('smokk',),
'smokken': ('smokk',),
'smokkene': ('smokk',),
'smokker': ('smokk',),
'smolt': ('smolt',),
'smolten': ('smolt',),
'smoltene': ('smolt',),
'smolter': ('smolt',),
'smug': ('smug',),
'smuga': ('smug',),
'smugene': ('smug',),
'smuget': ('smug',),
'smug': ('smug',),
'smuga': ('smug',),
'smugene': ('smug',),
'smuget': ('smug',),
'smug': ('smug',),
'smughandel': ('smughandel',),
'smughandelen': ('smughandel',),
'smughandlene': ('smughandel',),
'smughandler': ('smughandel',),
'smugler': ('smugler',),
'smuglere': ('smugler',),
'smugleren': ('smugler',),
'smuglerer': ('smugler',),
'smuglerne': ('smugler',),
'smuglerbande': ('smuglerbande',),
'smuglerbanden': ('smuglerbande',),
'smuglerbandene': ('smuglerbande',),
'smuglerbander': ('smuglerbande',),
'smuglersprit': ('smuglersprit',),
'smuglerspriten': ('smuglersprit',),
'smuglerspritene': ('smuglersprit',),
'smuglerspriter': ('smuglersprit',),
'smuglertrafikk': ('smuglertrafikk',),
'smuglertrafikken': ('smuglertrafikk',),
'smuglertrafikkene': ('smuglertrafikk',),
'smuglertrafikker': ('smuglertrafikk',),
'smuglervara': ('smuglervare',),
'smuglervare': ('smuglervare',),
'smuglervaren': ('smuglervare',),
'smuglervarene': ('smuglervare',),
'smuglervarer': ('smuglervare',),
'smukka': ('smukka',),
'smukkas': ('smukkas',),
'smukkasen': ('smukkas',),
'smukkasene': ('smukkas',),
'smukkaser': ('smukkas',),
'smukken': ('smukken',),
'smulder': ('smulder',),
'smulderet': ('smulder',),
'smuldra': ('smulder',),
'smuldre': ('smulder',),
'smuldrene': ('smulder',),
'smuldrer': ('smulder',),
'smuldret': ('smulder',),
'smule': ('smule',),
'smulen': ('smule',),
'smulene': ('smule',),
'smuler': ('smule',),
'smult': ('smult',),
'smulta': ('smult',),
'smultene': ('smult',),
'smultet': ('smult',),
'smultring': ('smultring',),
'smultringen': ('smultring',),
'smultringene': ('smultring',),
'smultringer': ('smultring',),
'smurning': ('smurning',),
'smurninga': ('smurning',),
'smurningen': ('smurning',),
'smurningene': ('smurning',),
'smurninger': ('smurning',),
'smuss': ('smuss',),
'smussa': ('smuss',),
'smussene': ('smuss',),
'smusset': ('smuss',),
'smussblad': ('smussblad',),
'smussblada': ('smussblad',),
'smussbladene': ('smussblad',),
'smussblader': ('smussblad',),
'smussbladet': ('smussblad',),
'smussflekk': ('smussflekk',),
'smussflekken': ('smussflekk',),
'smussflekkene': ('smussflekk',),
'smussflekker': ('smussflekk',),
'smusslitteratur': ('smusslitteratur',),
'smusslitteraturen': ('smusslitteratur',),
'smusslitteraturene': ('smusslitteratur',),
'smusslitteraturer': ('smusslitteratur',),
'smussomslag': ('smussomslag',),
'smussomslaga': ('smussomslag',),
'smussomslagene': ('smussomslag',),
'smussomslaget': ('smussomslag',),
'smusstillegg': ('smusstillegg',),
'smusstillegga': ('smusstillegg',),
'smusstilleggene': ('smusstillegg',),
'smusstillegget': ('smusstillegg',),
'smusstitlene': ('smusstittel',),
'smusstitler': ('smusstittel',),
'smusstittel': ('smusstittel',),
'smusstittelen': ('smusstittel',),
'smutt': ('smutt',),
'smutthol': ('smutthol',),
'smutthola': ('smutthol',),
'smuttholene': ('smutthol',),
'smuttholet': ('smutthol',),
'smutthull': ('smutthull',),
'smutthulla': ('smutthull',),
'smutthullene': ('smutthull',),
'smutthuller': ('smutthull',),
'smutthullet': ('smutthull',),
'smygjakt': ('smygjakt',),
'smygjakta': ('smygjakt',),
'smygjakten': ('smygjakt',),
'smygjaktene': ('smygjakt',),
'smygjakter': ('smygjakt',),
'smygstol': ('smygstol',),
'smygstolen': ('smygstol',),
'smygstolene': ('smygstol',),
'smygstoler': ('smygstol',),
'smykka': ('smykke',),
'smykke': ('smykke',),
'smykkene': ('smykke',),
'smykker': ('smykke',),
'smykket': ('smykke',),
'smykkeskrin': ('smykkeskrin',),
'smykkeskrina': ('smykkeskrin',),
'smykkeskrinene': ('smykkeskrin',),
'smykkeskrinet': ('smykkeskrin',),
'smykkestein': ('smykkestein',),
'smykkesteinen': ('smykkestein',),
'smykkesteinene': ('smykkestein',),
'smykkesteiner': ('smykkestein',),
'smyla': ('smyle',),
'smyle': ('smyle',),
'smylene': ('smyle',),
'smyler': ('smyle',),
'smylet': ('smyle',),
'smylebunke': ('smylebunke',),
'smylebunken': ('smylebunke',),
'smylebunkene': ('smylebunke',),
'smylebunker': ('smylebunke',),
'småarve': ('småarve',),
'småarven': ('småarve',),
'småarvene': ('småarve',),
'småarver': ('småarve',),
'småbarn': ('småbarn',),
'småbarna': ('småbarn',),
'småbarnene': ('småbarn',),
'småbarnet': ('småbarn',),
'småbit': ('småbit',),
'småbiten': ('småbit',),
'småbitene': ('småbit',),
'småbiter': ('småbit',),
'småbonde': ('småbonde',),
'småbonden': ('småbonde',),
'småbøndene': ('småbonde',),
'småbønder': ('småbonde',),
'småbord': ('småbord',),
'småborda': ('småbord',),
'småbordene': ('småbord',),
'småborder': ('småbord',),
'småbordet': ('småbord',),
'småborger': ('småborger',),
'småborgere': ('småborger',),
'småborgeren': ('småborger',),
'småborgerer': ('småborger',),
'småborgerne': ('småborger',),
'småbruk': ('småbruk',),
'småbruka': ('småbruk',),
'småbrukene': ('småbruk',),
'småbruket': ('småbruk',),
'småbruker': ('småbruker',),
'småbrukere': ('småbruker',),
'småbrukeren': ('småbruker',),
'småbrukerer': ('småbruker',),
'småbrukerne': ('småbruker',),
'småby': ('småby',),
'småbyen': ('småby',),
'småbyene': ('småby',),
'småbyer': ('småby',),
'småbåt': ('småbåt',),
'småbåten': ('småbåt',),
'småbåtene': ('småbåt',),
'småbåter': ('småbåt',),
'småbåthamn': ('småbåthamn',),
'småbåthamna': ('småbåthamn',),
'småbåthamnen': ('småbåthamn',),
'småbåthamnene': ('småbåthamn',),
'småbåthamner': ('småbåthamn',),
'småbåthavn': ('småbåthavn',),
'småbåthavna': ('småbåthavn',),
'småbåthavnen': ('småbåthavn',),
'småbåthavnene': ('småbåthavn',),
'småbåthavner': ('småbåthavn',),
'smådjevel': ('smådjevel',),
'smådjevelen': ('smådjevel',),
'smådjevlene': ('smådjevel',),
'smådjevler': ('smådjevel',),
'smådyr': ('smådyr',),
'smådyra': ('smådyr',),
'smådyrene': ('smådyr',),
'smådyret': ('smådyr',),
'småen': ('småen',),
'småfe': ('småfe',),
'småfea': ('småfe',),
'småfeene': ('småfe',),
'småfeet': ('småfe',),
'småfly': ('småfly',),
'småflya': ('småfly',),
'småflyene': ('småfly',),
'småflyet': ('småfly',),
'småflyplass': ('småflyplass',),
'småflyplassen': ('småflyplass',),
'småflyplassene': ('småflyplass',),
'småflyplasser': ('småflyplass',),
'småfolk': ('småfolk',),
'småfolka': ('småfolk',),
'småfolkene': ('småfolk',),
'småfolket': ('småfolk',),
'småfugl': ('småfugl',),
'småfuglen': ('småfugl',),
'småfuglene': ('småfugl',),
'småfugler': ('småfugl',),
'smågnager': ('smågnager',),
'smågnagere': ('smågnager',),
'smågnageren': ('smågnager',),
'smågnagerer': ('smågnager',),
'smågnagerne': ('smågnager',),
'smågris': ('smågris',),
'smågrisen': ('smågris',),
'smågrisene': ('smågris',),
'smågriser': ('smågris',),
'smågutt': ('smågutt',),
'smågutten': ('smågutt',),
'småguttene': ('smågutt',),
'smågutter': ('smågutt',),
'småhus': ('småhus',),
'småhusa': ('småhus',),
'småhusene': ('småhus',),
'småhuset': ('småhus',),
'småjenta': ('småjente',),
'småjente': ('småjente',),
'småjenten': ('småjente',),
'småjentene': ('småjente',),
'småjenter': ('småjente',),
'småkaka': ('småkake',),
'småkake': ('småkake',),
'småkaken': ('småkake',),
'småkakene': ('småkake',),
'småkaker': ('småkake',),
'småkirka': ('småkirke',),
'småkirke': ('småkirke',),
'småkirken': ('småkirke',),
'småkirkene': ('småkirke',),
'småkirker': ('småkirke',),
'småkjerka': ('småkjerke',),
'småkjerke': ('småkjerke',),
'småkjerken': ('småkjerke',),
'småkjerkene': ('småkjerke',),
'småkjerker': ('småkjerke',),
'småkonge': ('småkonge',),
'småkongen': ('småkonge',),
'småkongene': ('småkonge',),
'småkonger': ('småkonge',),
'småkort': ('småkort',),
'småkorta': ('småkort',),
'småkortene': ('småkort',),
'småkortet': ('småkort',),
'småkreps': ('småkreps',),
'småkrepsen': ('småkreps',),
'småkrepsene': ('småkreps',),
'småkrepser': ('småkreps',),
'småkryp': ('småkryp',),
'småkrypa': ('småkryp',),
'småkrypen': ('småkryp',),
'småkrypene': ('småkryp',),
'småkrypet': ('småkryp',),
'småkrøtter': ('småkrøtter',),
'småkrøttera': ('småkrøtter',),
'småkrøtteret': ('småkrøtter',),
'småkrøtterne': ('småkrøtter',),
'småkårsfolk': ('småkårsfolk',),
'småkårsfolka': ('småkårsfolk',),
'småkårsfolkene': ('småkårsfolk',),
'småkårsfolket': ('småkårsfolk',),
'småord': ('småord',),
'småorda': ('småord',),
'småordene': ('småord',),
'småordet': ('småord',),
'småpakka': ('småpakke',),
'småpakke': ('småpakke',),
'småpakken': ('småpakke',),
'småpakkene': ('småpakke',),
'småpakker': ('småpakke',),
'småpengene': ('småpenger',),
'småpenger': ('småpenger',),
'småpika': ('småpike',),
'småpike': ('småpike',),
'småpiken': ('småpike',),
'småpikene': ('småpike',),
'småpiker': ('småpike',),
'småplukk': ('småplukk',),
'småplukka': ('småplukk',),
'småplukkene': ('småplukk',),
'småplukket': ('småplukk',),
'smårika': ('smårike',),
'smårike': ('smårike',),
'smårikene': ('smårike',),
'småriker': ('smårike',),
'småriket': ('smårike',),
'smårolling': ('smårolling',),
'smårollingen': ('smårolling',),
'smårollingene': ('smårolling',),
'smårollinger': ('smårolling',),
'småsild': ('småsild',),
'småsilda': ('småsild',),
'småsilden': ('småsild',),
'småsildene': ('småsild',),
'småsilder': ('småsild',),
'småskog': ('småskog',),
'småskogen': ('småskog',),
'småskogene': ('småskog',),
'småskoger': ('småskog',),
'småskole': ('småskole',),
'småskolen': ('småskole',),
'småskolene': ('småskole',),
'småskoler': ('småskole',),
'småsnipa': ('småsnipe',),
'småsnipe': ('småsnipe',),
'småsnipen': ('småsnipe',),
'småsnipene': ('småsnipe',),
'småsniper': ('småsnipe',),
'småsparer': ('småsparer',),
'småsparere': ('småsparer',),
'småspareren': ('småsparer',),
'småsparerer': ('småsparer',),
'småsparerne': ('småsparer',),
'småspove': ('småspove',),
'småspoven': ('småspove',),
'småspovene': ('småspove',),
'småspover': ('småspove',),
'småspurv': ('småspurv',),
'småspurven': ('småspurv',),
'småspurvene': ('småspurv',),
'småspurver': ('småspurv',),
'småsted': ('småsted',),
'småstedene': ('småsted',),
'småsteder': ('småsted',),
'småstedet': ('småsted',),
'småstein': ('småstein',),
'småsteinen': ('småstein',),
'småsteinene': ('småstein',),
'småsteiner': ('småstein',),
'småstykka': ('småstykke',),
'småstykke': ('småstykke',),
'småstykkene': ('småstykke',),
'småstykker': ('småstykke',),
'småstykket': ('småstykke',),
'småting': ('småting',),
'småtinga': ('småting',),
'småtingen': ('småting',),
'småtingene': ('småting',),
'småtroll': ('småtroll',),
'småtrolla': ('småtroll',),
'småtrollene': ('småtroll',),
'småtrollet': ('småtroll',),
'småtråler': ('småtråler',),
'småtrålere': ('småtråler',),
'småtråleren': ('småtråler',),
'småtrålerer': ('småtråler',),
'småtrålerne': ('småtråler',),
'småtteri': ('småtteri',),
'småtteria': ('småtteri',),
'småtteriene': ('småtteri',),
'småtterier': ('småtteri',),
'småtteriet': ('småtteri',),
'småvann': ('småvann',),
'småvanna': ('småvann',),
'småvannene': ('småvann',),
'småvannet': ('småvann',),
'småvarmt': ('småvarmt',),
'småvask': ('småvask',),
'småvasken': ('småvask',),
'småvaskene': ('småvask',),
'småvasker': ('småvask',),
'småvatn': ('småvatn',),
'småvatna': ('småvatn',),
'småvatnene': ('småvatn',),
'småvatnet': ('småvatn',),
'småvilt': ('småvilt',),
'småvilta': ('småvilt',),
'småviltene': ('småvilt',),
'småviltet': ('småvilt',),
'smør': ('smør',),
'smøra': ('smør',),
'smørene': ('smør',),
'smøret': ('smør',),
'smørblom': ('smørblom',),
'smørblommen': ('smørblom',),
'smørblommene': ('smørblom',),
'smørblommer': ('smørblom',),
'smørblomst': ('smørblomst',),
'smørblomsten': ('smørblomst',),
'smørblomstene': ('smørblomst',),
'smørblomster': ('smørblomst',),
'smørbrød': ('smørbrød',),
'smørbrøda': ('smørbrød',),
'smørbrødene': ('smørbrød',),
'smørbrødet': ('smørbrød',),
'smørbukk': ('smørbukk',),
'smørbukken': ('smørbukk',),
'smørbukkene': ('smørbukk',),
'smørbukker': ('smørbukk',),
'smørbutt': ('smørbutt',),
'smørbutten': ('smørbutt',),
'smørbuttene': ('smørbutt',),
'smørbutter': ('smørbutt',),
'smørdall': ('smørdall',),
'smørdallen': ('smørdall',),
'smørdallene': ('smørdall',),
'smørdaller': ('smørdall',),
'smørdeig': ('smørdeig',),
'smørdeigen': ('smørdeig',),
'smørdeigene': ('smørdeig',),
'smørdeiger': ('smørdeig',),
'smøreevna': ('smøreevne',),
'smøreevne': ('smøreevne',),
'smøreevnen': ('smøreevne',),
'smøreevnene': ('smøreevne',),
'smøreevner': ('smøreevne',),
'smørehall': ('smørehall',),
'smørehallen': ('smørehall',),
'smørehallene': ('smørehall',),
'smørehaller': ('smørehall',),
'smørehol': ('smørehol',),
'smørehola': ('smørehol',),
'smøreholene': ('smørehol',),
'smøreholet': ('smørehol',),
'smørehull': ('smørehull',),
'smørehulla': ('smørehull',),
'smørehullene': ('smørehull',),
'smørehuller': ('smørehull',),
'smørehullet': ('smørehull',),
'smørekopp': ('smørekopp',),
'smørekoppen': ('smørekopp',),
'smørekoppene': ('smørekopp',),
'smørekopper': ('smørekopp',),
'smørelse': ('smørelse',),
'smørelsen': ('smørelse',),
'smørelsene': ('smørelse',),
'smørelser': ('smørelse',),
'smøremiddel': ('smøremiddel',),
'smøremiddelet': ('smøremiddel',),
'smøremidla': ('smøremiddel',),
'smøremidlene': ('smøremiddel',),
'smøremidler': ('smøremiddel',),
'smøremidlet': ('smøremiddel',),
'smøreniplene': ('smørenippel',),
'smørenipler': ('smørenippel',),
'smørenippel': ('smørenippel',),
'smørenippelen': ('smørenippel',),
'smøreolja': ('smøreolje',),
'smøreolje': ('smøreolje',),
'smøreoljen': ('smøreolje',),
'smøreoljene': ('smøreolje',),
'smøreoljer': ('smøreolje',),
'smørepunkt': ('smørepunkt',),
'smørepunkta': ('smørepunkt',),
'smørepunktene': ('smørepunkt',),
'smørepunkter': ('smørepunkt',),
'smørepunktet': ('smørepunkt',),
'smører': ('smører',),
'smørere': ('smører',),
'smøreren': ('smører',),
'smørerer': ('smører',),
'smørerne': ('smører',),
'smøreri': ('smøreri',),
'smøreria': ('smøreri',),
'smøreriene': ('smøreri',),
'smørerier': ('smøreri',),
'smøreriet': ('smøreri',),
'smørflyndra': ('smørflyndre',),
'smørflyndre': ('smørflyndre',),
'smørflyndren': ('smørflyndre',),
'smørflyndrene': ('smørflyndre',),
'smørflyndrer': ('smørflyndre',),
'smørgraut': ('smørgraut',),
'smørgrauten': ('smørgraut',),
'smørgrautene': ('smørgraut',),
'smørgrauter': ('smørgraut',),
'smørgrøt': ('smørgrøt',),
'smørgrøten': ('smørgrøt',),
'smørgrøtene': ('smørgrøt',),
'smørgrøter': ('smørgrøt',),
'smørgås': ('smørgås',),
'smørgåsen': ('smørgås',),
'smørgåsene': ('smørgås',),
'smørgåser': ('smørgås',),
'smørgåsbord': ('smørgåsbord',),
'smørgåsborda': ('smørgåsbord',),
'smørgåsbordene': ('smørgåsbord',),
'smørgåsborder': ('smørgåsbord',),
'smørgåsbordet': ('smørgåsbord',),
'smøring': ('smøring',),
'smøringa': ('smøring',),
'smøringen': ('smøring',),
'smøringene': ('smøring',),
'smøringer': ('smøring',),
'smøringsekspert': ('smøringsekspert',),
'smøringseksperten': ('smøringsekspert',),
'smøringsekspertene': ('smøringsekspert',),
'smøringseksperter': ('smøringsekspert',),
'smøringsproblem': ('smøringsproblem',),
'smøringsproblema': ('smøringsproblem',),
'smøringsproblemene': ('smøringsproblem',),
'smøringsproblemer': ('smøringsproblem',),
'smøringsproblemet': ('smøringsproblem',),
'smørja': ('smørje',),
'smørje': ('smørje',),
'smørjen': ('smørje',),
'smørjene': ('smørje',),
'smørjer': ('smørje',),
'smørkrem': ('smørkrem',),
'smørkremen': ('smørkrem',),
'smørkremene': ('smørkrem',),
'smørkremer': ('smørkrem',),
'smørpapir': ('smørpapir',),
'smørpapira': ('smørpapir',),
'smørpapirene': ('smørpapir',),
'smørpapirer': ('smørpapir',),
'smørpapiret': ('smørpapir',),
'smørsida': ('smørside',),
'smørside': ('smørside',),
'smørsiden': ('smørside',),
'smørsidene': ('smørside',),
'smørsider': ('smørside',),
'smørsopp': ('smørsopp',),
'smørsoppen': ('smørsopp',),
'smørsoppene': ('smørsopp',),
'smørsopper': ('smørsopp',),
'smørspade': ('smørspade',),
'smørspaden': ('smørspade',),
'smørspadene': ('smørspade',),
'smørspader': ('smørspade',),
'smørtenor': ('smørtenor',),
'smørtenoren': ('smørtenor',),
'smørtenorene': ('smørtenor',),
'smørtenorer': ('smørtenor',),
'smørøskja': ('smørøskje',),
'smørøskje': ('smørøskje',),
'smørøskjen': ('smørøskje',),
'smørøskjene': ('smørøskje',),
'smørøskjer': ('smørøskje',),
'smøystol': ('smøystol',),
'smøystolen': ('smøystol',),
'smøystolene': ('smøystol',),
'smøystoler': ('smøystol',),
'snabb': ('snabb',),
'snabben': ('snabb',),
'snabbene': ('snabb',),
'snabber': ('snabb',),
'snabel': ('snabel',),
'snabelen': ('snabel',),
'snablene': ('snabel',),
'snabler': ('snabel',),
'snabeldyr': ('snabeldyr',),
'snabeldyra': ('snabeldyr',),
'snabeldyrene': ('snabeldyr',),
'snabeldyret': ('snabeldyr',),
'snabelskøyta': ('snabelskøyte',),
'snabelskøyte': ('snabelskøyte',),
'snabelskøyten': ('snabelskøyte',),
'snabelskøytene': ('snabelskøyte',),
'snabelskøyter': ('snabelskøyte',),
'snackbar': ('snackbar',),
'snackbaren': ('snackbar',),
'snackbarene': ('snackbar',),
'snackbarer': ('snackbar',),
'snacks': ('snacks',),
'snacksen': ('snacks',),
'snacksene': ('snacks',),
'snackser': ('snacks',),
'snadd': ('snadd',),
'snadden': ('snadd',),
'snaddene': ('snadd',),
'snadder': ('snadd',),
'snadda': ('snadde',),
'snadde': ('snadde',),
'snadden': ('snadde',),
'snaddene': ('snadde',),
'snadder': ('snadde',),
'snadder': ('snadder',),
'snaddera': ('snadder',),
'snaddere': ('snadder',),
'snadderene': ('snadder',),
'snadderet': ('snadder',),
'snadderne': ('snadder',),
'snadder': ('snadder',),
'snaddera': ('snadder',),
'snaddere': ('snadder',),
'snadderene': ('snadder',),
'snadderet': ('snadder',),
'snadderne': ('snadder',),
'snafs': ('snafs',),
'snafsen': ('snafs',),
'snafsene': ('snafs',),
'snafser': ('snafs',),
'snakk': ('snakk',),
'snakka': ('snakk',),
'snakken': ('snakk',),
'snakkene': ('snakk',),
'snakker': ('snakk',),
'snakket': ('snakk',),
'snakketøy': ('snakketøy',),
'snakketøya': ('snakketøy',),
'snakketøyene': ('snakketøy',),
'snakketøyer': ('snakketøy',),
'snakketøyet': ('snakketøy',),
'snapphanske': ('snapphanske',),
'snapphansken': ('snapphanske',),
'snapphanskene': ('snapphanske',),
'snapphansker': ('snapphanske',),
'snaps': ('snaps',),
'snapsen': ('snaps',),
'snapsene': ('snaps',),
'snapser': ('snaps',),
'snapshot': ('snapshot',),
'snapshota': ('snapshot',),
'snapshotene': ('snapshot',),
'snapshotet': ('snapshot',),
'snar': ('snar',),
'snara': ('snar',),
'snarene': ('snar',),
'snaret': ('snar',),
'snara': ('snare',),
'snare': ('snare',),
'snaren': ('snare',),
'snarene': ('snare',),
'snarer': ('snare',),
'snarefangst': ('snarefangst',),
'snarefangsten': ('snarefangst',),
'snarefangstene': ('snarefangst',),
'snarefangster': ('snarefangst',),
'snarkjøp': ('snarkjøp',),
'snarkjøpa': ('snarkjøp',),
'snarkjøpene': ('snarkjøp',),
'snarkjøpet': ('snarkjøp',),
'snarkjøpsbutikk': ('snarkjøpsbutikk',),
'snarkjøpsbutikken': ('snarkjøpsbutikk',),
'snarkjøpsbutikkene': ('snarkjøpsbutikk',),
'snarkjøpsbutikker': ('snarkjøpsbutikk',),
'snartur': ('snartur',),
'snarturen': ('snartur',),
'snarturene': ('snartur',),
'snarturer': ('snartur',),
'snarveg': ('snarveg',),
'snarvegen': ('snarveg',),
'snarvegene': ('snarveg',),
'snarveger': ('snarveg',),
'snarvei': ('snarvei',),
'snarveien': ('snarvei',),
'snarveiene': ('snarvei',),
'snarveier': ('snarvei',),
'snarvending': ('snarvending',),
'snarvendinga': ('snarvending',),
'snarvendingen': ('snarvending',),
'snarvendingene': ('snarvending',),
'snarvendinger': ('snarvending',),
'snask': ('snask',),
'snaska': ('snask',),
'snaskene': ('snask',),
'snasket': ('snask',),
'snau': ('snau',),
'snauen': ('snau',),
'snauene': ('snau',),
'snauer': ('snau',),
'snaufjell': ('snaufjell',),
'snaufjella': ('snaufjell',),
'snaufjellene': ('snaufjell',),
'snaufjellet': ('snaufjell',),
'snauhogst': ('snauhogst',),
'snauhogsten': ('snauhogst',),
'snauhogstene': ('snauhogst',),
'snauhogster': ('snauhogst',),
'snauhugst': ('snauhugst',),
'snauhugsten': ('snauhugst',),
'snauhugstene': ('snauhugst',),
'snauhugster': ('snauhugst',),
'snavl': ('snavl',),
'snavla': ('snavl',),
'snavlen': ('snavl',),
'snavlene': ('snavl',),
'snavler': ('snavl',),
'snegl': ('snegl',),
'sneglen': ('snegl',),
'sneglene': ('snegl',),
'snegler': ('snegl',),
'sneglefart': ('sneglefart',),
'sneglefarten': ('sneglefart',),
'sneglefartene': ('sneglefart',),
'sneglefarter': ('sneglefart',),
'sneglehus': ('sneglehus',),
'sneglehusa': ('sneglehus',),
'sneglehusene': ('sneglehus',),
'sneglehuset': ('sneglehus',),
'snei': ('snei',),
'sneien': ('snei',),
'sneiene': ('snei',),
'sneier': ('snei',),
'sneiord': ('sneiord',),
'sneiorda': ('sneiord',),
'sneiordene': ('sneiord',),
'sneiordet': ('sneiord',),
'sneip': ('sneip',),
'sneipen': ('sneip',),
'sneipene': ('sneip',),
'sneiper': ('sneip',),
'sneisegl': ('sneisegl',),
'sneisegla': ('sneisegl',),
'sneiseglene': ('sneisegl',),
'sneiseglet': ('sneisegl',),
'sneiseil': ('sneiseil',),
'sneiseila': ('sneiseil',),
'sneiseilene': ('sneiseil',),
'sneiseilet': ('sneiseil',),
'snek': ('snek',),
'sneken': ('snek',),
'snekene': ('snek',),
'sneker': ('snek',),
'snekka': ('snekke',),
'snekke': ('snekke',),
'snekken': ('snekke',),
'snekkene': ('snekke',),
'snekker': ('snekke',),
'snekka': ('snekke',),
'snekke': ('snekke',),
'snekken': ('snekke',),
'snekkene': ('snekke',),
'snekker': ('snekke',),
'snekkedrev': ('snekkedrev',),
'snekkedreva': ('snekkedrev',),
'snekkedrevene': ('snekkedrev',),
'snekkedrevet': ('snekkedrev',),
'snekker': ('snekker',),
'snekkere': ('snekker',),
'snekkeren': ('snekker',),
'snekkerer': ('snekker',),
'snekkerne': ('snekker',),
'snekkerbuksa': ('snekkerbukse',),
'snekkerbukse': ('snekkerbukse',),
'snekkerbuksen': ('snekkerbukse',),
'snekkerbuksene': ('snekkerbukse',),
'snekkerbukser': ('snekkerbukse',),
'snekkeri': ('snekkeri',),
'snekkeria': ('snekkeri',),
'snekkeriene': ('snekkeri',),
'snekkerier': ('snekkeri',),
'snekkeriet': ('snekkeri',),
'snekkerlast': ('snekkerlast',),
'snekkerlasta': ('snekkerlast',),
'snekkerlasten': ('snekkerlast',),
'snekkerlastene': ('snekkerlast',),
'snekkerlaster': ('snekkerlast',),
'snekkermester': ('snekkermester',),
'snekkermestere': ('snekkermester',),
'snekkermesteren': ('snekkermester',),
'snekkermesterer': ('snekkermester',),
'snekkermesterne': ('snekkermester',),
'snekkermestre': ('snekkermester',),
'snekkermestrene': ('snekkermester',),
'snekkermestrer': ('snekkermester',),
'snekkerpolitur': ('snekkerpolitur',),
'snekkerpolituren': ('snekkerpolitur',),
'snekkerpoliturene': ('snekkerpolitur',),
'snekkerpoliturer': ('snekkerpolitur',),
'snekkerverksted': ('snekkerverksted',),
'snekkerverkstedene': ('snekkerverksted',),
'snekkerverksteder': ('snekkerverksted',),
'snekkerverkstedet': ('snekkerverksted',),
'snella': ('snelle',),
'snelle': ('snelle',),
'snellen': ('snelle',),
'snellene': ('snelle',),
'sneller': ('snelle',),
'snella': ('snelle',),
'snelle': ('snelle',),
'snellen': ('snelle',),
'snellene': ('snelle',),
'sneller': ('snelle',),
'snelletråd': ('snelletråd',),
'snelletråden': ('snelletråd',),
'snelletrådene': ('snelletråd',),
'snelletråder': ('snelletråd',),
'sneppert': ('sneppert',),
'snepperten': ('sneppert',),
'sneppertene': ('sneppert',),
'snepperter': ('sneppert',),
'snerk': ('snerk',),
'snerken': ('snerk',),
'snerkene': ('snerk',),
'snerker': ('snerk',),
'snerpa': ('snerpe',),
'snerpe': ('snerpe',),
'snerpen': ('snerpe',),
'snerpene': ('snerpe',),
'snerper': ('snerpe',),
'snerpa': ('snerpe',),
'snerpe': ('snerpe',),
'snerpen': ('snerpe',),
'snerpene': ('snerpe',),
'snerper': ('snerpe',),
'snerperi': ('snerperi',),
'snerperia': ('snerperi',),
'snerperiene': ('snerperi',),
'snerperier': ('snerperi',),
'snerperiet': ('snerperi',),
'snerr': ('snerr',),
'snerra': ('snerr',),
'snerrene': ('snerr',),
'snerret': ('snerr',),
'snert': ('snert',),
'snerten': ('snert',),
'snertene': ('snert',),
'snerter': ('snert',),
'snes': ('snes',),
'snesa': ('snes',),
'snesene': ('snes',),
'sneset': ('snes',),
'snev': ('snev',),
'sneva': ('snev',),
'sneven': ('snev',),
'snevene': ('snev',),
'snever': ('snev',),
'snevet': ('snev',),
'sneverhet': ('sneverhet',),
'sneverheta': ('sneverhet',),
'sneverheten': ('sneverhet',),
'sneverhetene': ('sneverhet',),
'sneverheter': ('sneverhet',),
'sneversinn': ('sneversinn',),
'sneversinna': ('sneversinn',),
'sneversinnene': ('sneversinn',),
'sneversinnet': ('sneversinn',),
'sneversyn': ('sneversyn',),
'sneversyna': ('sneversyn',),
'sneversynene': ('sneversyn',),
'sneversynet': ('sneversyn',),
'snibel': ('snibel',),
'snibelen': ('snibel',),
'sniblene': ('snibel',),
'snibler': ('snibel',),
'snidel': ('snidel',),
'snidelen': ('snidel',),
'snidlene': ('snidel',),
'snidler': ('snidel',),
'sniffeklut': ('sniffeklut',),
'sniffekluten': ('sniffeklut',),
'sniffeklutene': ('sniffeklut',),
'sniffekluter': ('sniffeklut',),
'sniffer': ('sniffer',),
'sniffere': ('sniffer',),
'snifferen': ('sniffer',),
'snifferer': ('sniffer',),
'snifferne': ('sniffer',),
'snik': ('snik',),
'sniken': ('snik',),
'snikene': ('snik',),
'sniker': ('snik',),
'snik': ('snik',),
'sniken': ('snik',),
'snikene': ('snik',),
'sniker': ('snik',),
'sniker': ('sniker',),
'snikere': ('sniker',),
'snikeren': ('sniker',),
'snikerer': ('sniker',),
'snikerne': ('sniker',),
'snikkontorisering': ('snikkontorisering',),
'snikkontoriseringa': ('snikkontorisering',),
'snikkontoriseringen': ('snikkontorisering',),
'snikkontoriseringene': ('snikkontorisering',),
'snikkontoriseringer': ('snikkontorisering',),
'snikksnakk': ('snikksnakk',),
'snikksnakka': ('snikksnakk',),
'snikksnakkene': ('snikksnakk',),
'snikksnakket': ('snikksnakk',),
'snikmord': ('snikmord',),
'snikmorda': ('snikmord',),
'snikmordene': ('snikmord',),
'snikmordet': ('snikmord',),
'snikmorder': ('snikmorder',),
'snikmordere': ('snikmorder',),
'snikmorderen': ('snikmorder',),
'snikmorderer': ('snikmorder',),
'snikmorderne': ('snikmorder',),
'snikreklame': ('snikreklame',),
'snikreklamen': ('snikreklame',),
'snikreklamene': ('snikreklame',),
'snikreklamer': ('snikreklame',),
'snikskytter': ('snikskytter',),
'snikskyttere': ('snikskytter',),
'snikskytteren': ('snikskytter',),
'snikskytterer': ('snikskytter',),
'snikskytterne': ('snikskytter',),
'snile': ('snile',),
'snilen': ('snile',),
'snilene': ('snile',),
'sniler': ('snile',),
'snilefart': ('snilefart',),
'snilefarten': ('snilefart',),
'snilefartene': ('snilefart',),
'snilefarter': ('snilefart',),
'snilehus': ('snilehus',),
'snilehusa': ('snilehus',),
'snilehusene': ('snilehus',),
'snilehuset': ('snilehus',),
'snilla': ('snille',),
'snille': ('snille',),
'snillene': ('snille',),
'sniller': ('snille',),
'snillet': ('snille',),
'snillhet': ('snillhet',),
'snillheta': ('snillhet',),
'snillheten': ('snillhet',),
'snillhetene': ('snillhet',),
'snillheter': ('snillhet',),
'snillisme': ('snillisme',),
'snillismen': ('snillisme',),
'snillismene': ('snillisme',),
'snillismer': ('snillisme',),
'snillist': ('snillist',),
'snillisten': ('snillist',),
'snillistene': ('snillist',),
'snillister': ('snillist',),
'snipa': ('snipe',),
'snipe': ('snipe',),
'snipen': ('snipe',),
'snipene': ('snipe',),
'sniper': ('snipe',),
'snipp': ('snipp',),
'snippen': ('snipp',),
'snippene': ('snipp',),
'snipper': ('snipp',),
'snippeproletariat': ('snippeproletariat',),
'snippeproletariata': ('snippeproletariat',),
'snippeproletariatene': ('snippeproletariat',),
'snippeproletariater': ('snippeproletariat',),
'snippeproletariatet': ('snippeproletariat',),
'snippeska': ('snippeske',),
'snippeske': ('snippeske',),
'snippesken': ('snippeske',),
'snippeskene': ('snippeske',),
'snippesker': ('snippeske',),
'snippkjole': ('snippkjole',),
'snippkjolen': ('snippkjole',),
'snippkjolene': ('snippkjole',),
'snippkjoler': ('snippkjole',),
'snirkel': ('snirkel',),
'snirkelen': ('snirkel',),
'snirklene': ('snirkel',),
'snirkler': ('snirkel',),
'snitsel': ('snitsel',),
'snitselen': ('snitsel',),
'snitslene': ('snitsel',),
'snitsler': ('snitsel',),
'snitt': ('snitt',),
'snitta': ('snitt',),
'snittene': ('snitt',),
'snittet': ('snitt',),
'snittblomst': ('snittblomst',),
'snittblomsten': ('snittblomst',),
'snittblomstene': ('snittblomst',),
'snittblomster': ('snittblomst',),
'snitte': ('snitte',),
'snitten': ('snitte',),
'snittene': ('snitte',),
'snitter': ('snitte',),
'snitte': ('snitte',),
'snitten': ('snitte',),
'snittene': ('snitte',),
'snitter': ('snitte',),
'snittebønna': ('snittebønne',),
'snittebønne': ('snittebønne',),
'snittebønnen': ('snittebønne',),
'snittebønnene': ('snittebønne',),
'snittebønner': ('snittebønne',),
'snittflata': ('snittflate',),
'snittflate': ('snittflate',),
'snittflaten': ('snittflate',),
'snittflatene': ('snittflate',),
'snittflater': ('snittflate',),
'snittmønster': ('snittmønster',),
'snittmønsteret': ('snittmønster',),
'snittmønstra': ('snittmønster',),
'snittmønstre': ('snittmønster',),
'snittmønstrene': ('snittmønster',),
'snittmønstret': ('snittmønster',),
'snittverk': ('snittverk',),
'snittverka': ('snittverk',),
'snittverkene': ('snittverk',),
'snittverker': ('snittverk',),
'snittverket': ('snittverk',),
'sniva': ('snive',),
'snive': ('snive',),
'sniven': ('snive',),
'snivene': ('snive',),
'sniver': ('snive',),
'sno': ('sno',),
'snoa': ('sno',),
'snoen': ('sno',),
'snoene': ('sno',),
'snoer': ('sno',),
'snobb': ('snobb',),
'snobben': ('snobb',),
'snobbene': ('snobb',),
'snobber': ('snobb',),
'snobberi': ('snobberi',),
'snobberia': ('snobberi',),
'snobberiene': ('snobberi',),
'snobberier': ('snobberi',),
'snobberiet': ('snobberi',),
'snobbeskap': ('snobbeskap',),
'snobbeskapen': ('snobbeskap',),
'snobbeskapene': ('snobbeskap',),
'snobbeskaper': ('snobbeskap',),
'snobbisme': ('snobbisme',),
'snobbismen': ('snobbisme',),
'snobbismene': ('snobbisme',),
'snobbismer': ('snobbisme',),
'snok': ('snok',),
'snoken': ('snok',),
'snokene': ('snok',),
'snoker': ('snok',),
'snoker': ('snoker',),
'snokere': ('snoker',),
'snokeren': ('snoker',),
'snokerer': ('snoker',),
'snokerne': ('snoker',),
'snop': ('snop',),
'snopa': ('snop',),
'snopene': ('snop',),
'snopet': ('snop',),
'snor': ('snor',),
'snora': ('snor',),
'snoren': ('snor',),
'snorene': ('snor',),
'snorer': ('snor',),
'snoreloft': ('snoreloft',),
'snorelofta': ('snoreloft',),
'snoreloftene': ('snoreloft',),
'snoreloftet': ('snoreloft',),
'snork': ('snork',),
'snorka': ('snork',),
'snorken': ('snork',),
'snorkene': ('snork',),
'snorket': ('snork',),
'snorkel': ('snorkel',),
'snorkelen': ('snorkel',),
'snorklene': ('snorkel',),
'snorkler': ('snorkel',),
'snorloft': ('snorloft',),
'snorlofta': ('snorloft',),
'snorloftene': ('snorloft',),
'snorloftet': ('snorloft',),
'snowmobil': ('snowmobil',),
'snowmobilen': ('snowmobil',),
'snowmobilene': ('snowmobil',),
'snowmobiler': ('snowmobil',),
'snu': ('snu',),
'snuen': ('snu',),
'snuene': ('snu',),
'snuer': ('snu',),
'snubbord': ('snubbord',),
'snubborda': ('snubbord',),
'snubbordene': ('snubbord',),
'snubbordet': ('snubbord',),
'snublesnor': ('snublesnor',),
'snublesnora': ('snublesnor',),
'snublesnoren': ('snublesnor',),
'snublesnorene': ('snublesnor',),
'snublesnorer': ('snublesnor',),
'snublestein': ('snublestein',),
'snublesteinen': ('snublestein',),
'snublesteinene': ('snublestein',),
'snublesteiner': ('snublestein',),
'snue': ('snue',),
'snuen': ('snue',),
'snuene': ('snue',),
'snuer': ('snue',),
'snufs': ('snufs',),
'snufsa': ('snufs',),
'snufsen': ('snufs',),
'snufsene': ('snufs',),
'snufset': ('snufs',),
'snunad': ('snunad',),
'snunaden': ('snunad',),
'snunadene': ('snunad',),
'snunader': ('snunad',),
'snuoperasjon': ('snuoperasjon',),
'snuoperasjonen': ('snuoperasjon',),
'snuoperasjonene': ('snuoperasjon',),
'snuoperasjoner': ('snuoperasjon',),
'snuplass': ('snuplass',),
'snuplassen': ('snuplass',),
'snuplassene': ('snuplass',),
'snuplasser': ('snuplass',),
'snupp': ('snupp',),
'snuppen': ('snupp',),
'snuppene': ('snupp',),
'snupper': ('snupp',),
'snuppa': ('snuppe',),
'snuppe': ('snuppe',),
'snuppen': ('snuppe',),
'snuppene': ('snuppe',),
'snupper': ('snuppe',),
'snurp': ('snurp',),
'snurpa': ('snurp',),
'snurpene': ('snurp',),
'snurpet': ('snurp',),
'snurpefangst': ('snurpefangst',),
'snurpefangsten': ('snurpefangst',),
'snurpefangstene': ('snurpefangst',),
'snurpefangster': ('snurpefangst',),
'snurpeflåte': ('snurpeflåte',),
'snurpeflåten': ('snurpeflåte',),
'snurpeflåtene': ('snurpeflåte',),
'snurpeflåter': ('snurpeflåte',),
'snurper': ('snurper',),
'snurpere': ('snurper',),
'snurperen': ('snurper',),
'snurperer': ('snurper',),
'snurperne': ('snurper',),
'snurr': ('snurr',),
'snurren': ('snurr',),
'snurrene': ('snurr',),
'snurrer': ('snurr',),
'snurrebart': ('snurrebart',),
'snurrebarten': ('snurrebart',),
'snurrebartene': ('snurrebart',),
'snurrebarter': ('snurrebart',),
'snurrebass': ('snurrebass',),
'snurrebassen': ('snurrebass',),
'snurrebassene': ('snurrebass',),
'snurrebasser': ('snurrebass',),
'snurrepiperiene': ('snurrepiperier',),
'snurrepiperier': ('snurrepiperier',),
'snurrevad': ('snurrevad',),
'snurrevada': ('snurrevad',),
'snurrevaden': ('snurrevad',),
'snurrevadene': ('snurrevad',),
'snurrevader': ('snurrevad',),
'snurrevadet': ('snurrevad',),
'snurt': ('snurt',),
'snurten': ('snurt',),
'snurtene': ('snurt',),
'snurter': ('snurt',),
'snus': ('snus',),
'snusen': ('snus',),
'snusene': ('snus',),
'snuser': ('snus',),
'snusfornuft': ('snusfornuft',),
'snusfornuften': ('snusfornuft',),
'snusfornuftene': ('snusfornuft',),
'snusfornufter': ('snusfornuft',),
'snushane': ('snushane',),
'snushanen': ('snushane',),
'snushanene': ('snushane',),
'snushaner': ('snushane',),
'snusk': ('snusk',),
'snuska': ('snusk',),
'snuskene': ('snusk',),
'snusket': ('snusk',),
'snut': ('snut',),
'snuten': ('snut',),
'snutene': ('snut',),
'snuter': ('snut',),
'snuta': ('snute',),
'snute': ('snute',),
'snuten': ('snute',),
'snutene': ('snute',),
'snuter': ('snute',),
'snutebille': ('snutebille',),
'snutebillen': ('snutebille',),
'snutebillene': ('snutebille',),
'snutebiller': ('snutebille',),
'snutt': ('snutt',),
'snutten': ('snutt',),
'snuttene': ('snutt',),
'snutter': ('snutt',),
'snyltedyr': ('snyltedyr',),
'snyltedyra': ('snyltedyr',),
'snyltedyrene': ('snyltedyr',),
'snyltedyret': ('snyltedyr',),
'snyltegjest': ('snyltegjest',),
'snyltegjesten': ('snyltegjest',),
'snyltegjestene': ('snyltegjest',),
'snyltegjester': ('snyltegjest',),
'snylteplanta': ('snylteplante',),
'snylteplante': ('snylteplante',),
'snylteplanten': ('snylteplante',),
'snylteplantene': ('snylteplante',),
'snylteplanter': ('snylteplante',),
'snylter': ('snylter',),
'snyltere': ('snylter',),
'snylteren': ('snylter',),
'snylterer': ('snylter',),
'snylterne': ('snylter',),
'snylteri': ('snylteri',),
'snylteria': ('snylteri',),
'snylteriene': ('snylteri',),
'snylterier': ('snylteri',),
'snylteriet': ('snylteri',),
'snyt': ('snyt',),
'snyta': ('snyt',),
'snytene': ('snyt',),
'snytet': ('snyt',),
'snyter': ('snyter',),
'snytere': ('snyter',),
'snyteren': ('snyter',),
'snyterer': ('snyter',),
'snyterne': ('snyter',),
'snyteri': ('snyteri',),
'snyteria': ('snyteri',),
'snyteriene': ('snyteri',),
'snyterier': ('snyteri',),
'snyteriet': ('snyteri',),
'snyteskaft': ('snyteskaft',),
'snyteskafta': ('snyteskaft',),
'snyteskaftene': ('snyteskaft',),
'snyteskafter': ('snyteskaft',),
'snyteskaftet': ('snyteskaft',),
'snåling': ('snåling',),
'snålingen': ('snåling',),
'snålingene': ('snåling',),
'snålinger': ('snåling',),
'snø': ('snø',),
'snøen': ('snø',),
'snøene': ('snø',),
'snøer': ('snø',),
'snøball': ('snøball',),
'snøballen': ('snøball',),
'snøballene': ('snøball',),
'snøballer': ('snøball',),
'snøballkrig': ('snøballkrig',),
'snøballkrigen': ('snøballkrig',),
'snøballkrigene': ('snøballkrig',),
'snøballkriger': ('snøballkrig',),
'snøbil': ('snøbil',),
'snøbilen': ('snøbil',),
'snøbilene': ('snøbil',),
'snøbiler': ('snøbil',),
'snøblindhet': ('snøblindhet',),
'snøblindheta': ('snøblindhet',),
'snøblindheten': ('snøblindhet',),
'snøblindhetene': ('snøblindhet',),
'snøblindheter': ('snøblindhet',),
'snøbre': ('snøbre',),
'snøbreen': ('snøbre',),
'snøbreene': ('snøbre',),
'snøbreer': ('snøbre',),
'snøbrett': ('snøbrett',),
'snøbretta': ('snøbrett',),
'snøbrettene': ('snøbrett',),
'snøbretter': ('snøbrett',),
'snøbrettet': ('snøbrett',),
'snøbrilla': ('snøbrille',),
'snøbrille': ('snøbrille',),
'snøbrillen': ('snøbrille',),
'snøbrillene': ('snøbrille',),
'snøbriller': ('snøbrille',),
'snøbya': ('snøbye',),
'snøbye': ('snøbye',),
'snøbyen': ('snøbye',),
'snøbyene': ('snøbye',),
'snøbyer': ('snøbye',),
'snøbyga': ('snøbyge',),
'snøbyge': ('snøbyge',),
'snøbygen': ('snøbyge',),
'snøbygene': ('snøbyge',),
'snøbyger': ('snøbyge',),
'snøbær': ('snøbær',),
'snøbæra': ('snøbær',),
'snøbærene': ('snøbær',),
'snøbæret': ('snøbær',),
'snøbærbusk': ('snøbærbusk',),
'snøbærbusken': ('snøbærbusk',),
'snøbærbuskene': ('snøbærbusk',),
'snøbærbusker': ('snøbærbusk',),
'snøbøya': ('snøbøye',),
'snøbøye': ('snøbøye',),
'snøbøyen': ('snøbøye',),
'snøbøyene': ('snøbøye',),
'snøbøyer': ('snøbøye',),
'snødrev': ('snødrev',),
'snødreva': ('snødrev',),
'snødrevene': ('snødrev',),
'snødrevet': ('snødrev',),
'snødriva': ('snødrive',),
'snødrive': ('snødrive',),
'snødriven': ('snødrive',),
'snødrivene': ('snødrive',),
'snødriver': ('snødrive',),
'snøfall': ('snøfall',),
'snøfalla': ('snøfall',),
'snøfallene': ('snøfall',),
'snøfallet': ('snøfall',),
'snøffel': ('snøffel',),
'snøffelen': ('snøffel',),
'snøflene': ('snøffel',),
'snøfler': ('snøffel',),
'snøfilla': ('snøfille',),
'snøfille': ('snøfille',),
'snøfillen': ('snøfille',),
'snøfillene': ('snøfille',),
'snøfiller': ('snøfille',),
'snøfjell': ('snøfjell',),
'snøfjella': ('snøfjell',),
'snøfjellene': ('snøfjell',),
'snøfjellet': ('snøfjell',),
'snøfnugg': ('snøfnugg',),
'snøfnugga': ('snøfnugg',),
'snøfnuggene': ('snøfnugg',),
'snøfnugget': ('snøfnugg',),
'snøfokk': ('snøfokk',),
'snøfokka': ('snøfokk',),
'snøfokkene': ('snøfokk',),
'snøfokket': ('snøfokk',),
'snøfonn': ('snøfonn',),
'snøfonna': ('snøfonn',),
'snøfonnen': ('snøfonn',),
'snøfonnene': ('snøfonn',),
'snøfonner': ('snøfonn',),
'snøforskning': ('snøforskning',),
'snøforskninga': ('snøforskning',),
'snøforskningen': ('snøforskning',),
'snøforskningene': ('snøforskning',),
'snøforskninger': ('snøforskning',),
'snøfreser': ('snøfreser',),
'snøfresere': ('snøfreser',),
'snøfreseren': ('snøfreser',),
'snøfreserer': ('snøfreser',),
'snøfreserne': ('snøfreser',),
'snøft': ('snøft',),
'snøfta': ('snøft',),
'snøftene': ('snøft',),
'snøftet': ('snøft',),
'snøføyka': ('snøføyke',),
'snøføyke': ('snøføyke',),
'snøføyken': ('snøføyke',),
'snøføykene': ('snøføyke',),
'snøføyker': ('snøføyke',),
'snøgeit': ('snøgeit',),
'snøgeita': ('snøgeit',),
'snøgeiten': ('snøgeit',),
'snøgeitene': ('snøgeit',),
'snøgeiter': ('snøgeit',),
'snøggtog': ('snøggtog',),
'snøggtoga': ('snøggtog',),
'snøggtogene': ('snøggtog',),
'snøggtoget': ('snøggtog',),
'snøggvending': ('snøggvending',),
'snøggvendinga': ('snøggvending',),
'snøggvendingen': ('snøggvending',),
'snøggvendingene': ('snøggvending',),
'snøggvendinger': ('snøggvending',),
'snøgrensa': ('snøgrense',),
'snøgrense': ('snøgrense',),
'snøgrensen': ('snøgrense',),
'snøgrensene': ('snøgrense',),
'snøgrenser': ('snøgrense',),
'snøgjess': ('snøgås',),
'snøgjessene': ('snøgås',),
'snøgjæsene': ('snøgås',),
'snøgjæser': ('snøgås',),
'snøgås': ('snøgås',),
'snøgåsa': ('snøgås',),
'snøgåsen': ('snøgås',),
'snøhola': ('snøhole',),
'snøhole': ('snøhole',),
'snøholen': ('snøhole',),
'snøholene': ('snøhole',),
'snøholer': ('snøhole',),
'snøhula': ('snøhule',),
'snøhule': ('snøhule',),
'snøhulen': ('snøhule',),
'snøhulene': ('snøhule',),
'snøhuler': ('snøhule',),
'snøis': ('snøis',),
'snøisen': ('snøis',),
'snøisene': ('snøis',),
'snøiser': ('snøis',),
'snøkanon': ('snøkanon',),
'snøkanonen': ('snøkanon',),
'snøkanonene': ('snøkanon',),
'snøkanoner': ('snøkanon',),
'snøkjeda': ('snøkjede',),
'snøkjede': ('snøkjede',),
'snøkjeden': ('snøkjede',),
'snøkjedene': ('snøkjede',),
'snøkjeder': ('snøkjede',),
'snøkjedet': ('snøkjede',),
'snøklokka': ('snøklokke',),
'snøklokke': ('snøklokke',),
'snøklokken': ('snøklokke',),
'snøklokkene': ('snøklokke',),
'snøklokker': ('snøklokke',),
'snøleopard': ('snøleopard',),
'snøleoparden': ('snøleopard',),
'snøleopardene': ('snøleopard',),
'snøleoparder': ('snøleopard',),
'snølinja': ('snølinje',),
'snølinje': ('snølinje',),
'snølinjen': ('snølinje',),
'snølinjene': ('snølinje',),
'snølinjer': ('snølinje',),
'snøloppa': ('snøloppe',),
'snøloppe': ('snøloppe',),
'snøloppen': ('snøloppe',),
'snøloppene': ('snøloppe',),
'snølopper': ('snøloppe',),
'snølås': ('snølås',),
'snølåsa': ('snølås',),
'snølåsen': ('snølås',),
'snølåsene': ('snølås',),
'snølåser': ('snølås',),
'snølåset': ('snølås',),
'snøløsning': ('snøløsning',),
'snøløsninga': ('snøløsning',),
'snøløsningen': ('snøløsning',),
'snøløsningene': ('snøløsning',),
'snøløsninger': ('snøløsning',),
'snøløysing': ('snøløysing',),
'snøløysinga': ('snøløysing',),
'snøløysingen': ('snøløysing',),
'snøløysingene': ('snøløysing',),
'snøløysinger': ('snøløysing',),
'snømann': ('snømann',),
'snømannen': ('snømann',),
'snømenn': ('snømann',),
'snømennene': ('snømann',),
'snømugg': ('snømugg',),
'snømugga': ('snømugg',),
'snømuggen': ('snømugg',),
'snømuggene': ('snømugg',),
'snømugger': ('snømugg',),
'snømugget': ('snømugg',),
'snømus': ('snømus',),
'snømusa': ('snømus',),
'snømusen': ('snømus',),
'snømusene': ('snømus',),
'snømåka': ('snømåke',),
'snømåke': ('snømåke',),
'snømåken': ('snømåke',),
'snømåkene': ('snømåke',),
'snømåker': ('snømåke',),
'snømåking': ('snømåking',),
'snømåkinga': ('snømåking',),
'snømåkingen': ('snømåking',),
'snømåkingene': ('snømåking',),
'snømåkinger': ('snømåking',),
'snøoverbygg': ('snøoverbygg',),
'snøoverbygga': ('snøoverbygg',),
'snøoverbyggene': ('snøoverbygg',),
'snøoverbygget': ('snøoverbygg',),
'snøoverbygning': ('snøoverbygning',),
'snøoverbygninga': ('snøoverbygning',),
'snøoverbygningen': ('snøoverbygning',),
'snøoverbygningene': ('snøoverbygning',),
'snøoverbygninger': ('snøoverbygning',),
'snøplog': ('snøplog',),
'snøplogen': ('snøplog',),
'snøplogene': ('snøplog',),
'snøploger': ('snøplog',),
'snøras': ('snøras',),
'snørasa': ('snøras',),
'snørasene': ('snøras',),
'snøraset': ('snøras',),
'snøra': ('snøre',),
'snøre': ('snøre',),
'snørene': ('snøre',),
'snører': ('snøre',),
'snøret': ('snøre',),
'snøreband': ('snøreband',),
'snørebanda': ('snøreband',),
'snørebandene': ('snøreband',),
'snørebandet': ('snøreband',),
'snørebånd': ('snørebånd',),
'snørebånda': ('snørebånd',),
'snørebåndene': ('snørebånd',),
'snørebåndet': ('snørebånd',),
'snøreliv': ('snøreliv',),
'snøreliva': ('snøreliv',),
'snørelivene': ('snøreliv',),
'snørelivet': ('snøreliv',),
'snøresko': ('snøresko',),
'snøreskoa': ('snøresko',),
'snøreskoen': ('snøresko',),
'snøreskoene': ('snøresko',),
'snøreskor': ('snøresko',),
'snøreskorne': ('snøresko',),
'snørestøvel': ('snørestøvel',),
'snørestøvelen': ('snørestøvel',),
'snørestøvlene': ('snørestøvel',),
'snørestøvler': ('snørestøvel',),
'snøring': ('snøring',),
'snøringa': ('snøring',),
'snøringen': ('snøring',),
'snøringene': ('snøring',),
'snøringer': ('snøring',),
'snørliv': ('snørliv',),
'snørliva': ('snørliv',),
'snørlivene': ('snørliv',),
'snørlivet': ('snørliv',),
'snørr': ('snørr',),
'snørra': ('snørr',),
'snørrene': ('snørr',),
'snørrer': ('snørr',),
'snørret': ('snørr',),
'snørrbrems': ('snørrbrems',),
'snørrbremsen': ('snørrbrems',),
'snørrbremsene': ('snørrbrems',),
'snørrbremser': ('snørrbrems',),
'snørrbremsa': ('snørrbremse',),
'snørrbremse': ('snørrbremse',),
'snørrbremsen': ('snørrbremse',),
'snørrbremsene': ('snørrbremse',),
'snørrbremser': ('snørrbremse',),
'snørrunge': ('snørrunge',),
'snørrungen': ('snørrunge',),
'snørrungene': ('snørrunge',),
'snørrunger': ('snørrunge',),
'snøscooter': ('snøscooter',),
'snøscootere': ('snøscooter',),
'snøscooteren': ('snøscooter',),
'snøscooterer': ('snøscooter',),
'snøscooterne': ('snøscooter',),
'snøsildra': ('snøsildre',),
'snøsildre': ('snøsildre',),
'snøsildren': ('snøsildre',),
'snøsildrene': ('snøsildre',),
'snøsildrer': ('snøsildre',),
'snøskjerm': ('snøskjerm',),
'snøskjermen': ('snøskjerm',),
'snøskjermene': ('snøskjerm',),
'snøskjermer': ('snøskjerm',),
'snøsko': ('snøsko',),
'snøskoa': ('snøsko',),
'snøskoen': ('snøsko',),
'snøskoene': ('snøsko',),
'snøskor': ('snøsko',),
'snøskorne': ('snøsko',),
'snøskred': ('snøskred',),
'snøskreda': ('snøskred',),
'snøskredene': ('snøskred',),
'snøskredet': ('snøskred',),
'snøskuffa': ('snøskuffe',),
'snøskuffe': ('snøskuffe',),
'snøskuffen': ('snøskuffe',),
'snøskuffene': ('snøskuffe',),
'snøskuffer': ('snøskuffe',),
'snøskuter': ('snøskuter',),
'snøskutere': ('snøskuter',),
'snøskuteren': ('snøskuter',),
'snøskuterer': ('snøskuter',),
'snøskuterne': ('snøskuter',),
'snøskøyting': ('snøskøyting',),
'snøskøytinga': ('snøskøyting',),
'snøskøytingen': ('snøskøyting',),
'snøskøytingene': ('snøskøyting',),
'snøskøytinger': ('snøskøyting',),
'snøslaps': ('snøslaps',),
'snøslapsa': ('snøslaps',),
'snøslapsene': ('snøslaps',),
'snøslapset': ('snøslaps',),
'snøsokk': ('snøsokk',),
'snøsokken': ('snøsokk',),
'snøsokkene': ('snøsokk',),
'snøsokker': ('snøsokk',),
'snøspurv': ('snøspurv',),
'snøspurven': ('snøspurv',),
'snøspurvene': ('snøspurv',),
'snøspurver': ('snøspurv',),
'snøstjerna': ('snøstjerne',),
'snøstjerne': ('snøstjerne',),
'snøstjernen': ('snøstjerne',),
'snøstjernene': ('snøstjerne',),
'snøstjerner': ('snøstjerne',),
'snøstorm': ('snøstorm',),
'snøstormen': ('snøstorm',),
'snøstormene': ('snøstorm',),
'snøstormer': ('snøstorm',),
'snøsøta': ('snøsøte',),
'snøsøte': ('snøsøte',),
'snøsøten': ('snøsøte',),
'snøsøtene': ('snøsøte',),
'snøsøter': ('snøsøte',),
'snøtjukka': ('snøtjukke',),
'snøtjukke': ('snøtjukke',),
'snøtjukken': ('snøtjukke',),
'snøtjukkene': ('snøtjukke',),
'snøtjukker': ('snøtjukke',),
'snøtykka': ('snøtykke',),
'snøtykke': ('snøtykke',),
'snøtykken': ('snøtykke',),
'snøtykkene': ('snøtykke',),
'snøtykker': ('snøtykke',),
'snøtykket': ('snøtykke',),
'snøugla': ('snøugle',),
'snøugle': ('snøugle',),
'snøuglen': ('snøugle',),
'snøuglene': ('snøugle',),
'snøugler': ('snøugle',),
'snøvann': ('snøvann',),
'snøvanna': ('snøvann',),
'snøvannene': ('snøvann',),
'snøvannet': ('snøvann',),
'snøvatn': ('snøvatn',),
'snøvatna': ('snøvatn',),
'snøvatnene': ('snøvatn',),
'snøvatnet': ('snøvatn',),
'snøvinter': ('snøvinter',),
'snøvintere': ('snøvinter',),
'snøvinteren': ('snøvinter',),
'snøvinterne': ('snøvinter',),
'snøvintre': ('snøvinter',),
'snøvintrene': ('snøvinter',),
'snøvintrer': ('snøvinter',),
'snøvl': ('snøvl',),
'snøvla': ('snøvl',),
'snøvlene': ('snøvl',),
'snøvlet': ('snøvl',),
'soareen': ('soaré',),
'soareene': ('soaré',),
'soareer': ('soaré',),
'soaré': ('soaré',),
'soaréen': ('soaré',),
'soaréene': ('soaré',),
'soaréer': ('soaré',),
'sobel': ('sobel',),
'sobelen': ('sobel',),
'soblene': ('sobel',),
'sobler': ('sobel',),
'soda': ('soda',),
'sodaen': ('soda',),
'sodaene': ('soda',),
'sodaer': ('soda',),
'sodavann': ('sodavann',),
'sodavanna': ('sodavann',),
'sodavannene': ('sodavann',),
'sodavannet': ('sodavann',),
'sodavatn': ('sodavatn',),
'sodavatna': ('sodavatn',),
'sodavatnene': ('sodavatn',),
'sodavatnet': ('sodavatn',),
'sodd': ('sodd',),
'sodda': ('sodd',),
'soddene': ('sodd',),
'soddet': ('sodd',),
'sodomi': ('sodomi',),
'sodomien': ('sodomi',),
'sodomiene': ('sodomi',),
'sodomier': ('sodomi',),
'sodomitt': ('sodomitt',),
'sodomitten': ('sodomitt',),
'sodomittene': ('sodomitt',),
'sodomitter': ('sodomitt',),
'sofa': ('sofa',),
'sofaen': ('sofa',),
'sofaene': ('sofa',),
'sofaer': ('sofa',),
'sofabenk': ('sofabenk',),
'sofabenken': ('sofabenk',),
'sofabenkene': ('sofabenk',),
'sofabenker': ('sofabenk',),
'sofabonde': ('sofabonde',),
'sofabonden': ('sofabonde',),
'sofabøndene': ('sofabonde',),
'sofabønder': ('sofabonde',),
'sofagruppa': ('sofagruppe',),
'sofagruppe': ('sofagruppe',),
'sofagruppen': ('sofagruppe',),
'sofagruppene': ('sofagruppe',),
'sofagrupper': ('sofagruppe',),
'sofaputa': ('sofapute',),
'sofapute': ('sofapute',),
'sofaputen': ('sofapute',),
'sofaputene': ('sofapute',),
'sofaputer': ('sofapute',),
'sofavelger': ('sofavelger',),
'sofavelgere': ('sofavelger',),
'sofavelgeren': ('sofavelger',),
'sofavelgerer': ('sofavelger',),
'sofavelgerne': ('sofavelger',),
'sofisme': ('sofisme',),
'sofismen': ('sofisme',),
'sofismene': ('sofisme',),
'sofismer': ('sofisme',),
'sofist': ('sofist',),
'sofisten': ('sofist',),
'sofistene': ('sofist',),
'sofister': ('sofist',),
'sofisteri': ('sofisteri',),
'sofisteria': ('sofisteri',),
'sofisteriene': ('sofisteri',),
'sofisterier': ('sofisteri',),
'sofisteriet': ('sofisteri',),
'softdrink': ('softdrink',),
'softdrinken': ('softdrink',),
'softdrinkene': ('softdrink',),
'softdrinker': ('softdrink',),
'softis': ('softis',),
'softisen': ('softis',),
'softisene': ('softis',),
'softiser': ('softis',),
'software': ('software',),
'softwaren': ('software',),
'softwarene': ('software',),
'softwarer': ('software',),
'soga': ('soge',),
'soge': ('soge',),
'sogen': ('soge',),
'sogene': ('soge',),
'soger': ('soge',),
'sogn': ('sogn',),
'sogna': ('sogn',),
'sognene': ('sogn',),
'sognet': ('sogn',),
'sognebarn': ('sognebarn',),
'sognebarna': ('sognebarn',),
'sognebarnene': ('sognebarn',),
'sognebarnet': ('sognebarn',),
'sognebud': ('sognebud',),
'sognebuda': ('sognebud',),
'sognebudene': ('sognebud',),
'sognebudet': ('sognebud',),
'sognekall': ('sognekall',),
'sognekalla': ('sognekall',),
'sognekallene': ('sognekall',),
'sognekallet': ('sognekall',),
'sognekirka': ('sognekirke',),
'sognekirke': ('sognekirke',),
'sognekirken': ('sognekirke',),
'sognekirkene': ('sognekirke',),
'sognekirker': ('sognekirke',),
'sognekjerka': ('sognekjerke',),
'sognekjerke': ('sognekjerke',),
'sognekjerken': ('sognekjerke',),
'sognekjerkene': ('sognekjerke',),
'sognekjerker': ('sognekjerke',),
'sognekjerka': ('sognekjerke',),
'sognekjerke': ('sognekjerke',),
'sognekjerken': ('sognekjerke',),
'sognekjerkene': ('sognekjerke',),
'sognekjerker': ('sognekjerke',),
'sogneprest': ('sogneprest',),
'sognepresten': ('sogneprest',),
'sogneprestene': ('sogneprest',),
'sogneprester': ('sogneprest',),
'sogning': ('sogning',),
'sogningen': ('sogning',),
'sogningene': ('sogning',),
'sogninger': ('sogning',),
'soilrør': ('soilrør',),
'soilrøra': ('soilrør',),
'soilrørene': ('soilrør',),
'soilrøret': ('soilrør',),
'sokk': ('sokk',),
'sokken': ('sokk',),
'sokkene': ('sokk',),
'sokker': ('sokk',),
'sokkeband': ('sokkeband',),
'sokkebanda': ('sokkeband',),
'sokkebandene': ('sokkeband',),
'sokkebandet': ('sokkeband',),
'sokkebånd': ('sokkebånd',),
'sokkebånda': ('sokkebånd',),
'sokkebåndene': ('sokkebånd',),
'sokkebåndet': ('sokkebånd',),
'sokkedans': ('sokkedans',),
'sokkedansen': ('sokkedans',),
'sokkedansene': ('sokkedans',),
'sokkedanser': ('sokkedans',),
'sokkel': ('sokkel',),
'sokkelen': ('sokkel',),
'soklene': ('sokkel',),
'sokler': ('sokkel',),
'sokkelest': ('sokkelest',),
'sokkelesten': ('sokkelest',),
'sokkelestene': ('sokkelest',),
'sokkelester': ('sokkelest',),
'sokkeletasje': ('sokkeletasje',),
'sokkeletasjen': ('sokkeletasje',),
'sokkeletasjene': ('sokkeletasje',),
'sokkeletasjer': ('sokkeletasje',),
'soknebarn': ('soknebarn',),
'soknebarna': ('soknebarn',),
'soknebarnene': ('soknebarn',),
'soknebarnet': ('soknebarn',),
'soknebud': ('soknebud',),
'soknebuda': ('soknebud',),
'soknebudene': ('soknebud',),
'soknebudet': ('soknebud',),
'soknekall': ('soknekall',),
'soknekalla': ('soknekall',),
'soknekallene': ('soknekall',),
'soknekallet': ('soknekall',),
'soknekirka': ('soknekirke',),
'soknekirke': ('soknekirke',),
'soknekirken': ('soknekirke',),
'soknekirkene': ('soknekirke',),
'soknekirker': ('soknekirke',),
'soknekjerka': ('soknekjerke',),
'soknekjerke': ('soknekjerke',),
'soknekjerken': ('soknekjerke',),
'soknekjerkene': ('soknekjerke',),
'soknekjerker': ('soknekjerke',),
'soknekjerka': ('soknekjerke',),
'soknekjerke': ('soknekjerke',),
'soknekjerken': ('soknekjerke',),
'soknekjerkene': ('soknekjerke',),
'soknekjerker': ('soknekjerke',),
'sokneprest': ('sokneprest',),
'soknepresten': ('sokneprest',),
'sokneprestene': ('sokneprest',),
'sokneprester': ('sokneprest',),
'sol': ('sol',),
'solen': ('sol',),
'solene': ('sol',),
'soler': ('sol',),
'sol': ('sol',),
'solen': ('sol',),
'solene': ('sol',),
'soler': ('sol',),
'sol': ('sol',),
'sola': ('sol',),
'solen': ('sol',),
'solene': ('sol',),
'soler': ('sol',),
'solaria': ('solarium',),
'solariene': ('solarium',),
'solarier': ('solarium',),
'solariet': ('solarium',),
'solarium': ('solarium',),
'solarolja': ('solarolje',),
'solarolje': ('solarolje',),
'solaroljen': ('solarolje',),
'solaroljene': ('solarolje',),
'solaroljer': ('solarolje',),
'solarplexus': ('solarplexus',),
'solarplexusen': ('solarplexus',),
'solarplexusene': ('solarplexus',),
'solarplexuser': ('solarplexus',),
'solaveksel': ('solaveksel',),
'solavekselen': ('solaveksel',),
'solavekslene': ('solaveksel',),
'solaveksler': ('solaveksel',),
'solbad': ('solbad',),
'solbada': ('solbad',),
'solbadene': ('solbad',),
'solbadet': ('solbad',),
'solbadolja': ('solbadolje',),
'solbadolje': ('solbadolje',),
'solbadoljen': ('solbadolje',),
'solbadoljene': ('solbadolje',),
'solbadoljer': ('solbadolje',),
'solbatteri': ('solbatteri',),
'solbatteria': ('solbatteri',),
'solbatteriene': ('solbatteri',),
'solbatterier': ('solbatteri',),
'solbatteriet': ('solbatteri',),
'solbrilla': ('solbrille',),
'solbrille': ('solbrille',),
'solbrillen': ('solbrille',),
'solbrillene': ('solbrille',),
'solbriller': ('solbrille',),
'solbær': ('solbær',),
'solbæra': ('solbær',),
'solbærene': ('solbær',),
'solbæret': ('solbær',),
'solbærsaft': ('solbærsaft',),
'solbærsafta': ('solbærsaft',),
'solbærsaften': ('solbærsaft',),
'solbærsaftene': ('solbærsaft',),
'solbærsafter': ('solbærsaft',),
'solcella': ('solcelle',),
'solcelle': ('solcelle',),
'solcellen': ('solcelle',),
'solcellene': ('solcelle',),
'solceller': ('solcelle',),
'solcellepanel': ('solcellepanel',),
'solcellepanela': ('solcellepanel',),
'solcellepanelene': ('solcellepanel',),
'solcellepaneler': ('solcellepanel',),
'solcellepanelet': ('solcellepanel',),
'sold': ('sold',),
'solden': ('sold',),
'soldene': ('sold',),
'solder': ('sold',),
'soldat': ('soldat',),
'soldaten': ('soldat',),
'soldatene': ('soldat',),
'soldater': ('soldat',),
'soldatkeiser': ('soldatkeiser',),
'soldatkeisere': ('soldatkeiser',),
'soldatkeiseren': ('soldatkeiser',),
'soldatkeiserer': ('soldatkeiser',),
'soldatkeiserne': ('soldatkeiser',),
'soldis': ('soldis',),
'soldisen': ('soldis',),
'soldisene': ('soldis',),
'soldiser': ('soldis',),
'soldogg': ('soldogg',),
'soldogga': ('soldogg',),
'soldoggen': ('soldogg',),
'soldoggene': ('soldogg',),
'soldogger': ('soldogg',),
'soldoggfamilie': ('soldoggfamilie',),
'soldoggfamilien': ('soldoggfamilie',),
'soldoggfamiliene': ('soldoggfamilie',),
'soldoggfamilier': ('soldoggfamilie',),
'soldugg': ('soldugg',),
'solduggen': ('soldugg',),
'solduggene': ('soldugg',),
'soldugger': ('soldugg',),
'solduggfamilie': ('solduggfamilie',),
'solduggfamilien': ('solduggfamilie',),
'solduggfamiliene': ('solduggfamilie',),
'solduggfamilier': ('solduggfamilie',),
'soldyrkelse': ('soldyrkelse',),
'soldyrkelsen': ('soldyrkelse',),
'soldyrkelsene': ('soldyrkelse',),
'soldyrkelser': ('soldyrkelse',),
'soldyrker': ('soldyrker',),
'soldyrkere': ('soldyrker',),
'soldyrkeren': ('soldyrker',),
'soldyrkerer': ('soldyrker',),
'soldyrkerne': ('soldyrker',),
'soldyrking': ('soldyrking',),
'soldyrkinga': ('soldyrking',),
'soldyrkingen': ('soldyrking',),
'soldyrkingene': ('soldyrking',),
'soldyrkinger': ('soldyrking',),
'soldøgn': ('soldøgn',),
'soldøgna': ('soldøgn',),
'soldøgnene': ('soldøgn',),
'soldøgnet': ('soldøgn',),
'solefall': ('solefall',),
'solefalla': ('solefall',),
'solefallene': ('solefall',),
'solefallet': ('solefall',),
'soleglad': ('soleglad',),
'soleglada': ('soleglad',),
'solegladene': ('soleglad',),
'solegladet': ('soleglad',),
'soleia': ('soleie',),
'soleie': ('soleie',),
'soleien': ('soleie',),
'soleiene': ('soleie',),
'soleier': ('soleie',),
'soleiefamilie': ('soleiefamilie',),
'soleiefamilien': ('soleiefamilie',),
'soleiefamiliene': ('soleiefamilie',),
'soleiefamilier': ('soleiefamilie',),
'soleihov': ('soleihov',),
'soleihoven': ('soleihov',),
'soleihovene': ('soleihov',),
'soleihover': ('soleihov',),
'soleksem': ('soleksem',),
'soleksema': ('soleksem',),
'soleksemen': ('soleksem',),
'soleksemene': ('soleksem',),
'soleksemer': ('soleksem',),
'soleksemet': ('soleksem',),
'solemerka': ('solemerke',),
'solemerke': ('solemerke',),
'solemerkene': ('solemerke',),
'solemerker': ('solemerke',),
'solemerket': ('solemerke',),
'solenergi': ('solenergi',),
'solenergien': ('solenergi',),
'solenergiene': ('solenergi',),
'solenergier': ('solenergi',),
'solfaktor': ('solfaktor',),
'solfaktoren': ('solfaktor',),
'solfaktorene': ('solfaktor',),
'solfaktorer': ('solfaktor',),
'solfanger': ('solfanger',),
'solfangere': ('solfanger',),
'solfangeren': ('solfanger',),
'solfangerer': ('solfanger',),
'solfangerne': ('solfanger',),
'solfege': ('solfege',),
'solfegen': ('solfege',),
'solfegene': ('solfege',),
'solfeger': ('solfege',),
'solfeggio': ('solfeggio',),
'solfeggioen': ('solfeggio',),
'solfeggioene': ('solfeggio',),
'solfeggioer': ('solfeggio',),
'solfest': ('solfest',),
'solfesten': ('solfest',),
'solfestene': ('solfest',),
'solfester': ('solfest',),
'solfilter': ('solfilter',),
'solfilteret': ('solfilter',),
'solfiltra': ('solfilter',),
'solfiltre': ('solfilter',),
'solfiltrene': ('solfilter',),
'solfiltret': ('solfilter',),
'solfilterkrem': ('solfilterkrem',),
'solfilterkremen': ('solfilterkrem',),
'solfilterkremene': ('solfilterkrem',),
'solfilterkremer': ('solfilterkrem',),
'solflekk': ('solflekk',),
'solflekken': ('solflekk',),
'solflekkene': ('solflekk',),
'solflekker': ('solflekk',),
'solformørkelse': ('solformørkelse',),
'solformørkelsen': ('solformørkelse',),
'solformørkelsene': ('solformørkelse',),
'solformørkelser': ('solformørkelse',),
'solgangsbris': ('solgangsbris',),
'solgangsbrisen': ('solgangsbris',),
'solgangsbrisene': ('solgangsbris',),
'solgangsbriser': ('solgangsbris',),
'solgangsvind': ('solgangsvind',),
'solgangsvinden': ('solgangsvind',),
'solgangsvindene': ('solgangsvind',),
'solgangsvinder': ('solgangsvind',),
'solgløtt': ('solgløtt',),
'solgløtta': ('solgløtt',),
'solgløtten': ('solgløtt',),
'solgløttene': ('solgløtt',),
'solgløtter': ('solgløtt',),
'solgløttet': ('solgløtt',),
'solhatt': ('solhatt',),
'solhatten': ('solhatt',),
'solhattene': ('solhatt',),
'solhatter': ('solhatt',),
'solhylla': ('solhylle',),
'solhylle': ('solhylle',),
'solhyllen': ('solhylle',),
'solhyllene': ('solhylle',),
'solhyller': ('solhylle',),
'solidaritet': ('solidaritet',),
'solidariteten': ('solidaritet',),
'solidaritetene': ('solidaritet',),
'solidariteter': ('solidaritet',),
'solidaritetsfølelse': ('solidaritetsfølelse',),
'solidaritetsfølelsen': ('solidaritetsfølelse',),
'solidaritetsfølelsene': ('solidaritetsfølelse',),
'solidaritetsfølelser': ('solidaritetsfølelse',),
'soliditet': ('soliditet',),
'soliditeten': ('soliditet',),
'soliditetene': ('soliditet',),
'soliditeter': ('soliditet',),
'soling': ('soling',),
'solingen': ('soling',),
'solingene': ('soling',),
'solinger': ('soling',),
'solipsisme': ('solipsisme',),
'solipsismen': ('solipsisme',),
'solipsismene': ('solipsisme',),
'solipsismer': ('solipsisme',),
'solipsist': ('solipsist',),
'solipsisten': ('solipsist',),
'solipsistene': ('solipsist',),
'solipsister': ('solipsist',),
'solist': ('solist',),
'solisten': ('solist',),
'solistene': ('solist',),
'solister': ('solist',),
'solitær': ('solitær',),
'solitæren': ('solitær',),
'solitærene': ('solitær',),
'solitærer': ('solitær',),
'solkors': ('solkors',),
'solkorsa': ('solkors',),
'solkorsene': ('solkors',),
'solkorset': ('solkors',),
'soll': ('soll',),
'sollen': ('soll',),
'sollene': ('soll',),
'soller': ('soll',),
'soll': ('soll',),
'solla': ('soll',),
'sollene': ('soll',),
'sollet': ('soll',),
'sollisitant': ('sollisitant',),
'sollisitanten': ('sollisitant',),
'sollisitantene': ('sollisitant',),
'sollisitanter': ('sollisitant',),
'sollisitasjon': ('sollisitasjon',),
'sollisitasjonen': ('sollisitasjon',),
'sollisitasjonene': ('sollisitasjon',),
'sollisitasjoner': ('sollisitasjon',),
'sollys': ('sollys',),
'sollysa': ('sollys',),
'sollysene': ('sollys',),
'sollyset': ('sollys',),
'solmerka': ('solmerke',),
'solmerke': ('solmerke',),
'solmerkene': ('solmerke',),
'solmerker': ('solmerke',),
'solmerket': ('solmerke',),
'solmisasjon': ('solmisasjon',),
'solmisasjonen': ('solmisasjon',),
'solmisasjonene': ('solmisasjon',),
'solmisasjoner': ('solmisasjon',),
'solnedgang': ('solnedgang',),
'solnedgangen': ('solnedgang',),
'solnedgangene': ('solnedgang',),
'solnedganger': ('solnedgang',),
'solnæra': ('solnære',),
'solnære': ('solnære',),
'solnærene': ('solnære',),
'solnærer': ('solnære',),
'solnæret': ('solnære',),
'soli': ('solo',),
'soliene': ('solo',),
'solo': ('solo',),
'soloen': ('solo',),
'soloene': ('solo',),
'soloer': ('solo',),
'solodanser': ('solodanser',),
'solodansere': ('solodanser',),
'solodanseren': ('solodanser',),
'solodanserer': ('solodanser',),
'solodanserne': ('solodanser',),
'soloparti': ('soloparti',),
'solopartia': ('soloparti',),
'solopartiene': ('soloparti',),
'solopartier': ('soloparti',),
'solopartiet': ('soloparti',),
'soloppgang': ('soloppgang',),
'soloppgangen': ('soloppgang',),
'soloppgangene': ('soloppgang',),
'soloppganger': ('soloppgang',),
'soloprestasjon': ('soloprestasjon',),
'soloprestasjonen': ('soloprestasjon',),
'soloprestasjonene': ('soloprestasjon',),
'soloprestasjoner': ('soloprestasjon',),
'solospell': ('solospell',),
'solospella': ('solospell',),
'solospellene': ('solospell',),
'solospellet': ('solospell',),
'solospill': ('solospill',),
'solospilla': ('solospill',),
'solospillene': ('solospill',),
'solospillet': ('solospill',),
'solpanel': ('solpanel',),
'solpanela': ('solpanel',),
'solpanelene': ('solpanel',),
'solpaneler': ('solpanel',),
'solpanelet': ('solpanel',),
'solrenning': ('solrenning',),
'solrenninga': ('solrenning',),
'solrenningen': ('solrenning',),
'solrenningene': ('solrenning',),
'solrenninger': ('solrenning',),
'solsegl': ('solsegl',),
'solsegla': ('solsegl',),
'solseglene': ('solsegl',),
'solseglet': ('solsegl',),
'solseil': ('solseil',),
'solseila': ('solseil',),
'solseilene': ('solseil',),
'solseilet': ('solseil',),
'solsida': ('solside',),
'solside': ('solside',),
'solsiden': ('solside',),
'solsidene': ('solside',),
'solsider': ('solside',),
'solsikke': ('solsikke',),
'solsikken': ('solsikke',),
'solsikkene': ('solsikke',),
'solsikker': ('solsikke',),
'solskinn': ('solskinn',),
'solskinna': ('solskinn',),
'solskinnene': ('solskinn',),
'solskinnet': ('solskinn',),
'solskinnsbarn': ('solskinnsbarn',),
'solskinnsbarna': ('solskinnsbarn',),
'solskinnsbarnene': ('solskinnsbarn',),
'solskinnsbarnet': ('solskinnsbarn',),
'solskinnshistoria': ('solskinnshistorie',),
'solskinnshistorie': ('solskinnshistorie',),
'solskinnshistorien': ('solskinnshistorie',),
'solskinnshistoriene': ('solskinnshistorie',),
'solskinnshistorier': ('solskinnshistorie',),
'solskiva': ('solskive',),
'solskive': ('solskive',),
'solskiven': ('solskive',),
'solskivene': ('solskive',),
'solskiver': ('solskive',),
'solskjerm': ('solskjerm',),
'solskjermen': ('solskjerm',),
'solskjermene': ('solskjerm',),
'solskjermer': ('solskjerm',),
'solsky': ('solsky',),
'solskya': ('solsky',),
'solskyen': ('solsky',),
'solskyene': ('solsky',),
'solskyer': ('solsky',),
'solslyng': ('solslyng',),
'solslynga': ('solslyng',),
'solslyngen': ('solslyng',),
'solslyngene': ('solslyng',),
'solslynget': ('solslyng',),
'solsmak': ('solsmak',),
'solsmaken': ('solsmak',),
'solsmakene': ('solsmak',),
'solsmaker': ('solsmak',),
'solsteik': ('solsteik',),
'solsteiken': ('solsteik',),
'solsteikene': ('solsteik',),
'solsteiker': ('solsteik',),
'solstek': ('solstek',),
'solsteken': ('solstek',),
'solstekene': ('solstek',),
'solsteker': ('solstek',),
'solstikk': ('solstikk',),
'solstikka': ('solstikk',),
'solstikkene': ('solstikk',),
'solstikket': ('solstikk',),
'solstråle': ('solstråle',),
'solstrålen': ('solstråle',),
'solstrålene': ('solstråle',),
'solstråler': ('solstråle',),
'solstudio': ('solstudio',),
'solstudioa': ('solstudio',),
'solstudioene': ('solstudio',),
'solstudioer': ('solstudio',),
'solstudioet': ('solstudio',),
'solsystem': ('solsystem',),
'solsystema': ('solsystem',),
'solsystemene': ('solsystem',),
'solsystemer': ('solsystem',),
'solsystemet': ('solsystem',),
'soltak': ('soltak',),
'soltaka': ('soltak',),
'soltakene': ('soltak',),
'soltaket': ('soltak',),
'soltid': ('soltid',),
'soltida': ('soltid',),
'soltiden': ('soltid',),
'soltidene': ('soltid',),
'soltider': ('soltid',),
'soltilbeder': ('soltilbeder',),
'soltilbedere': ('soltilbeder',),
'soltilbederen': ('soltilbeder',),
'soltilbederer': ('soltilbeder',),
'soltilbederne': ('soltilbeder',),
'soltopp': ('soltopp',),
'soltoppen': ('soltopp',),
'soltoppene': ('soltopp',),
'soltopper': ('soltopp',),
'solung': ('solung',),
'solungen': ('solung',),
'solungene': ('solung',),
'solunger': ('solung',),
'solur': ('solur',),
'solura': ('solur',),
'solurene': ('solur',),
'soluret': ('solur',),
'solusjon': ('solusjon',),
'solusjonen': ('solusjon',),
'solusjonene': ('solusjon',),
'solusjoner': ('solusjon',),
'solvarme': ('solvarme',),
'solvarmen': ('solvarme',),
'solvarmene': ('solvarme',),
'solvarmer': ('solvarme',),
'solvarmeanlegg': ('solvarmeanlegg',),
'solvarmeanlegga': ('solvarmeanlegg',),
'solvarmeanleggene': ('solvarmeanlegg',),
'solvarmeanlegget': ('solvarmeanlegg',),
'solvegg': ('solvegg',),
'solveggen': ('solvegg',),
'solveggene': ('solvegg',),
'solvegger': ('solvegg',),
'solvendel': ('solvendel',),
'solvendelen': ('solvendel',),
'solvendlene': ('solvendel',),
'solvendler': ('solvendel',),
'solvending': ('solvending',),
'solvendinga': ('solvending',),
'solvendingen': ('solvending',),
'solvendingene': ('solvending',),
'solvendinger': ('solvending',),
'solvens': ('solvens',),
'solvensen': ('solvens',),
'solvensene': ('solvens',),
'solvenser': ('solvens',),
'solvent': ('solvent',),
'solventen': ('solvent',),
'solventene': ('solvent',),
'solventer': ('solvent',),
'solverv': ('solverv',),
'solverva': ('solverv',),
'solvervene': ('solverv',),
'solvervet': ('solverv',),
'solår': ('solår',),
'solåra': ('solår',),
'solårene': ('solår',),
'solåret': ('solår',),
'soløya': ('soløye',),
'soløye': ('soløye',),
'soløyene': ('soløye',),
'soløyer': ('soløye',),
'soløyet': ('soløye',),
'soløyne': ('soløye',),
'soløynene': ('soløye',),
'somali': ('somali',),
'somalien': ('somali',),
'somaliene': ('somali',),
'somalier': ('somali',),
'somalier': ('somalier',),
'somaliere': ('somalier',),
'somalieren': ('somalier',),
'somalierer': ('somalier',),
'somalierne': ('somalier',),
'sombrero': ('sombrero',),
'sombreroen': ('sombrero',),
'sombreroene': ('sombrero',),
'sombreroer': ('sombrero',),
'somlekopp': ('somlekopp',),
'somlekoppen': ('somlekopp',),
'somlekoppene': ('somlekopp',),
'somlekopper': ('somlekopp',),
'somlepave': ('somlepave',),
'somlepaven': ('somlepave',),
'somlepavene': ('somlepave',),
'somlepaver': ('somlepave',),
'somletog': ('somletog',),
'somletoga': ('somletog',),
'somletogene': ('somletog',),
'somletoget': ('somletog',),
'somla': ('sommel',),
'somlene': ('sommel',),
'somler': ('sommel',),
'somlet': ('sommel',),
'sommel': ('sommel',),
'sommelen': ('sommel',),
'sommelet': ('sommel',),
'sommer': ('sommer',),
'sommere': ('sommer',),
'sommeren': ('sommer',),
'sommerne': ('sommer',),
'somre': ('sommer',),
'somrene': ('sommer',),
'somrer': ('sommer',),
'sommerdag': ('sommerdag',),
'sommerdagen': ('sommerdag',),
'sommerdagene': ('sommerdag',),
'sommerdager': ('sommerdag',),
'sommerdekk': ('sommerdekk',),
'sommerdekka': ('sommerdekk',),
'sommerdekkene': ('sommerdekk',),
'sommerdekket': ('sommerdekk',),
'sommerepla': ('sommereple',),
'sommereple': ('sommereple',),
'sommereplene': ('sommereple',),
'sommerepler': ('sommereple',),
'sommereplet': ('sommereple',),
'sommerferie': ('sommerferie',),
'sommerferien': ('sommerferie',),
'sommerferiene': ('sommerferie',),
'sommerferier': ('sommerferie',),
'sommerfjøs': ('sommerfjøs',),
'sommerfjøsa': ('sommerfjøs',),
'sommerfjøsen': ('sommerfjøs',),
'sommerfjøsene': ('sommerfjøs',),
'sommerfjøset': ('sommerfjøs',),
'sommerfrukt': ('sommerfrukt',),
'sommerfrukta': ('sommerfrukt',),
'sommerfrukten': ('sommerfrukt',),
'sommerfruktene': ('sommerfrukt',),
'sommerfrukter': ('sommerfrukt',),
'sommerfugl': ('sommerfugl',),
'sommerfuglen': ('sommerfugl',),
'sommerfuglene': ('sommerfugl',),
'sommerfugler': ('sommerfugl',),
'sommerføra': ('sommerføre',),
'sommerføre': ('sommerføre',),
'sommerførene': ('sommerføre',),
'sommerfører': ('sommerføre',),
'sommerføret': ('sommerføre',),
'sommergjest': ('sommergjest',),
'sommergjesten': ('sommergjest',),
'sommergjestene': ('sommergjest',),
'sommergjester': ('sommergjest',),
'sommerhalvår': ('sommerhalvår',),
'sommerhalvåra': ('sommerhalvår',),
'sommerhalvårene': ('sommerhalvår',),
'sommerhalvåret': ('sommerhalvår',),
'sommerhus': ('sommerhus',),
'sommerhusa': ('sommerhus',),
'sommerhusene': ('sommerhus',),
'sommerhuset': ('sommerhus',),
'sommeridrett': ('sommeridrett',),
'sommeridretten': ('sommeridrett',),
'sommeridrettene': ('sommeridrett',),
'sommeridretter': ('sommeridrett',),
'sommerkjole': ('sommerkjole',),
'sommerkjolen': ('sommerkjole',),
'sommerkjolene': ('sommerkjole',),
'sommerkjoler': ('sommerkjole',),
'sommerkurs': ('sommerkurs',),
'sommerkursa': ('sommerkurs',),
'sommerkursene': ('sommerkurs',),
'sommerkurser': ('sommerkurs',),
'sommerkurset': ('sommerkurs',),
'sommerkursene': ('sommerkursus',),
'sommerkurser': ('sommerkursus',),
'sommerkursus': ('sommerkursus',),
'sommerkursuset': ('sommerkursus',),
'sommerkål': ('sommerkål',),
'sommerkålen': ('sommerkål',),
'sommerkålene': ('sommerkål',),
'sommerkåler': ('sommerkål',),
'sommerleikene': ('sommerleiker',),
'sommerleiker': ('sommerleiker',),
'sommerleir': ('sommerleir',),
'sommerleiren': ('sommerleir',),
'sommerleirene': ('sommerleir',),
'sommerleirer': ('sommerleir',),
'sommerlekene': ('sommerleker',),
'sommerleker': ('sommerleker',),
'sommermål': ('sommermål',),
'sommermåla': ('sommermål',),
'sommermålene': ('sommermål',),
'sommermålet': ('sommermål',),
'sommermåned': ('sommermåned',),
'sommermåneden': ('sommermåned',),
'sommermånedene': ('sommermåned',),
'sommermåneder': ('sommermåned',),
'sommerrug': ('sommerrug',),
'sommerrugen': ('sommerrug',),
'sommerrugene': ('sommerrug',),
'sommerruger': ('sommerrug',),
'sommerruta': ('sommerrute',),
'sommerrute': ('sommerrute',),
'sommerruten': ('sommerrute',),
'sommerrutene': ('sommerrute',),
'sommerruter': ('sommerrute',),
'sommersolverv': ('sommersolverv',),
'sommersolverva': ('sommersolverv',),
'sommersolvervene': ('sommersolverv',),
'sommersolvervet': ('sommersolverv',),
'sommersted': ('sommersted',),
'sommerstedene': ('sommersted',),
'sommersteder': ('sommersted',),
'sommerstedet': ('sommersted',),
'sommertid': ('sommertid',),
'sommertida': ('sommertid',),
'sommertiden': ('sommertid',),
'sommertidene': ('sommertid',),
'sommertider': ('sommertid',),
'somnambulisme': ('somnambulisme',),
'somnambulismen': ('somnambulisme',),
'somnambulismene': ('somnambulisme',),
'somnambulismer': ('somnambulisme',),
'somnambulist': ('somnambulist',),
'somnambulisten': ('somnambulist',),
'somnambulistene': ('somnambulist',),
'somnambulister': ('somnambulist',),
'sonant': ('sonant',),
'sonanten': ('sonant',),
'sonantene': ('sonant',),
'sonanter': ('sonant',),
'sonar': ('sonar',),
'sonaren': ('sonar',),
'sonarene': ('sonar',),
'sonarer': ('sonar',),
'sonate': ('sonate',),
'sonaten': ('sonate',),
'sonatene': ('sonate',),
'sonater': ('sonate',),
'sonatine': ('sonatine',),
'sonatinen': ('sonatine',),
'sonatinene': ('sonatine',),
'sonatiner': ('sonatine',),
'sonde': ('sonde',),
'sonden': ('sonde',),
'sondene': ('sonde',),
'sonder': ('sonde',),
'sondør': ('sondør',),
'sondøren': ('sondør',),
'sondørene': ('sondør',),
'sondører': ('sondør',),
'sona': ('sone',),
'sone': ('sone',),
'sonen': ('sone',),
'sonene': ('sone',),
'soner': ('sone',),
'sonetid': ('sonetid',),
'sonetida': ('sonetid',),
'sonetiden': ('sonetid',),
'sonetidene': ('sonetid',),
'sonetider': ('sonetid',),
'sonett': ('sonett',),
'sonetten': ('sonett',),
'sonettene': ('sonett',),
'sonetter': ('sonett',),
'sonettkrans': ('sonettkrans',),
'sonettkransen': ('sonettkrans',),
'sonettkransene': ('sonettkrans',),
'sonettkranser': ('sonettkrans',),
'soning': ('soning',),
'soninga': ('soning',),
'soningen': ('soning',),
'soningene': ('soning',),
'soninger': ('soning',),
'soningsfange': ('soningsfange',),
'soningsfangen': ('soningsfange',),
'soningsfangene': ('soningsfange',),
'soningsfanger': ('soningsfange',),
'soningsoffer': ('soningsoffer',),
'soningsofferet': ('soningsoffer',),
'soningsofra': ('soningsoffer',),
'soningsofre': ('soningsoffer',),
'soningsofrene': ('soningsoffer',),
'sonobøya': ('sonobøye',),
'sonobøye': ('sonobøye',),
'sonobøyen': ('sonobøye',),
'sonobøyene': ('sonobøye',),
'sonobøyer': ('sonobøye',),
'sonoffer': ('sonoffer',),
'sonofferet': ('sonoffer',),
'sonofra': ('sonoffer',),
'sonofre': ('sonoffer',),
'sonofrene': ('sonoffer',),
'sonoritet': ('sonoritet',),
'sonoriteten': ('sonoritet',),
'sonoritetene': ('sonoritet',),
'sonoriteter': ('sonoritet',),
'sop': ('sop',),
'sopa': ('sop',),
'sopene': ('sop',),
'sopet': ('sop',),
'sopelime': ('sopelime',),
'sopelimen': ('sopelime',),
'sopelimene': ('sopelime',),
'sopelimer': ('sopelime',),
'soper': ('soper',),
'sopere': ('soper',),
'soperen': ('soper',),
'soperer': ('soper',),
'soperne': ('soper',),
'soplime': ('soplime',),
'soplimen': ('soplime',),
'soplimene': ('soplime',),
'soplimer': ('soplime',),
'sopp': ('sopp',),
'soppen': ('sopp',),
'soppene': ('sopp',),
'sopper': ('sopp',),
'soppa': ('soppe',),
'soppe': ('soppe',),
'soppen': ('soppe',),
'soppene': ('soppe',),
'sopper': ('soppe',),
'soppkontroll': ('soppkontroll',),
'soppkontrollen': ('soppkontroll',),
'soppkontrollene': ('soppkontroll',),
'soppkontroller': ('soppkontroll',),
'sopran': ('sopran',),
'sopranen': ('sopran',),
'sopranene': ('sopran',),
'sopraner': ('sopran',),
'sopranfløyta': ('sopranfløyte',),
'sopranfløyte': ('sopranfløyte',),
'sopranfløyten': ('sopranfløyte',),
'sopranfløytene': ('sopranfløyte',),
'sopranfløyter': ('sopranfløyte',),
'sopransaksofon': ('sopransaksofon',),
'sopransaksofonen': ('sopransaksofon',),
'sopransaksofonene': ('sopransaksofon',),
'sopransaksofoner': ('sopransaksofon',),
'sopransangerinna': ('sopransangerinne',),
'sopransangerinne': ('sopransangerinne',),
'sopransangerinnen': ('sopransangerinne',),
'sopransangerinnene': ('sopransangerinne',),
'sopransangerinner': ('sopransangerinne',),
'sorbett': ('sorbett',),
'sorbetten': ('sorbett',),
'sorbettene': ('sorbett',),
'sorbetter': ('sorbett',),
'sordin': ('sordin',),
'sordinen': ('sordin',),
'sordinene': ('sordin',),
'sordiner': ('sordin',),
'sorenskriver': ('sorenskriver',),
'sorenskrivere': ('sorenskriver',),
'sorenskriveren': ('sorenskriver',),
'sorenskriverer': ('sorenskriver',),
'sorenskriverne': ('sorenskriver',),
'sorenskriveri': ('sorenskriveri',),
'sorenskriveria': ('sorenskriveri',),
'sorenskriveriene': ('sorenskriveri',),
'sorenskriverier': ('sorenskriveri',),
'sorenskriveriet': ('sorenskriveri',),
'sorg': ('sorg',),
'sorga': ('sorg',),
'sorgen': ('sorg',),
'sorgene': ('sorg',),
'sorger': ('sorg',),
'soriamoria-slott': ('soriamoria-slott',),
'soriamoria-slotta': ('soriamoria-slott',),
'soriamoria-slottene': ('soriamoria-slott',),
'soriamoria-slottet': ('soriamoria-slott',),
'soroptimist': ('soroptimist',),
'soroptimisten': ('soroptimist',),
'soroptimistene': ('soroptimist',),
'soroptimister': ('soroptimist',),
'sort': ('sort',),
'sorten': ('sort',),
'sortene': ('sort',),
'sorter': ('sort',),
'sortegenskap': ('sortegenskap',),
'sortegenskapen': ('sortegenskap',),
'sortegenskapene': ('sortegenskap',),
'sortegenskaper': ('sortegenskap',),
'sortering': ('sortering',),
'sorteringa': ('sortering',),
'sorteringen': ('sortering',),
'sorteringene': ('sortering',),
'sorteringer': ('sortering',),
'sorteringsanlegg': ('sorteringsanlegg',),
'sorteringsanlegga': ('sorteringsanlegg',),
'sorteringsanleggene': ('sorteringsanlegg',),
'sorteringsanlegget': ('sorteringsanlegg',),
'sorteringsmaskin': ('sorteringsmaskin',),
'sorteringsmaskina': ('sorteringsmaskin',),
'sorteringsmaskinen': ('sorteringsmaskin',),
'sorteringsmaskinene': ('sorteringsmaskin',),
'sorteringsmaskiner': ('sorteringsmaskin',),
'sortforsøk': ('sortforsøk',),
'sortforsøka': ('sortforsøk',),
'sortforsøkene': ('sortforsøk',),
'sortforsøket': ('sortforsøk',),
'sorti': ('sorti',),
'sortien': ('sorti',),
'sortiene': ('sorti',),
'sortier': ('sorti',),
'sortiment': ('sortiment',),
'sortimenta': ('sortiment',),
'sortimentene': ('sortiment',),
'sortimenter': ('sortiment',),
'sortimentet': ('sortiment',),
'sortlista': ('sortliste',),
'sortliste': ('sortliste',),
'sortlisten': ('sortliste',),
'sortlistene': ('sortliste',),
'sortlister': ('sortliste',),
'sortsegenskap': ('sortsegenskap',),
'sortsegenskapen': ('sortsegenskap',),
'sortsegenskapene': ('sortsegenskap',),
'sortsegenskaper': ('sortsegenskap',),
'sortsforsøk': ('sortsforsøk',),
'sortsforsøka': ('sortsforsøk',),
'sortsforsøkene': ('sortsforsøk',),
'sortsforsøket': ('sortsforsøk',),
'sortslista': ('sortsliste',),
'sortsliste': ('sortsliste',),
'sortslisten': ('sortsliste',),
'sortslistene': ('sortsliste',),
'sortslister': ('sortsliste',),
'sosekopp': ('sosekopp',),
'sosekoppen': ('sosekopp',),
'sosekoppene': ('sosekopp',),
'sosekopper': ('sosekopp',),
'sosemikkel': ('sosemikkel',),
'sosemikkelen': ('sosemikkel',),
'sosemiklene': ('sosemikkel',),
'sosemikler': ('sosemikkel',),
'sosial': ('sosial',),
'sosialen': ('sosial',),
'sosialene': ('sosial',),
'sosialer': ('sosial',),
'sosialantropologi': ('sosialantropologi',),
'sosialantropologien': ('sosialantropologi',),
'sosialantropologiene': ('sosialantropologi',),
'sosialantropologier': ('sosialantropologi',),
'sosialarbeider': ('sosialarbeider',),
'sosialarbeidere': ('sosialarbeider',),
'sosialarbeideren': ('sosialarbeider',),
'sosialarbeiderer': ('sosialarbeider',),
'sosialarbeiderne': ('sosialarbeider',),
'sosialdemokrat': ('sosialdemokrat',),
'sosialdemokraten': ('sosialdemokrat',),
'sosialdemokratene': ('sosialdemokrat',),
'sosialdemokrater': ('sosialdemokrat',),
'sosialdemokrati': ('sosialdemokrati',),
'sosialdemokratia': ('sosialdemokrati',),
'sosialdemokratiene': ('sosialdemokrati',),
'sosialdemokratier': ('sosialdemokrati',),
'sosialdemokratiet': ('sosialdemokrati',),
'sosialdepartement': ('sosialdepartement',),
'sosialdepartementa': ('sosialdepartement',),
'sosialdepartementene': ('sosialdepartement',),
'sosialdepartementer': ('sosialdepartement',),
'sosialdepartementet': ('sosialdepartement',),
'sosialetikk': ('sosialetikk',),
'sosialetikken': ('sosialetikk',),
'sosialetikkene': ('sosialetikk',),
'sosialetikker': ('sosialetikk',),
'sosialgruppa': ('sosialgruppe',),
'sosialgruppe': ('sosialgruppe',),
'sosialgruppen': ('sosialgruppe',),
'sosialgruppene': ('sosialgruppe',),
'sosialgrupper': ('sosialgruppe',),
'sosialhjelp': ('sosialhjelp',),
'sosialhjelpa': ('sosialhjelp',),
'sosialhjelpen': ('sosialhjelp',),
'sosialhjelpene': ('sosialhjelp',),
'sosialhjelper': ('sosialhjelp',),
'sosialhjelpssøker': ('sosialhjelpssøker',),
'sosialhjelpssøkere': ('sosialhjelpssøker',),
'sosialhjelpssøkeren': ('sosialhjelpssøker',),
'sosialhjelpssøkerer': ('sosialhjelpssøker',),
'sosialhjelpssøkerne': ('sosialhjelpssøker',),
'sosialhøgskole': ('sosialhøgskole',),
'sosialhøgskolen': ('sosialhøgskole',),
'sosialhøgskolene': ('sosialhøgskole',),
'sosialhøgskoler': ('sosialhøgskole',),
'sosialhøyskole': ('sosialhøyskole',),
'sosialhøyskolen': ('sosialhøyskole',),
'sosialhøyskolene': ('sosialhøyskole',),
'sosialhøyskoler': ('sosialhøyskole',),
'sosialisering': ('sosialisering',),
'sosialiseringa': ('sosialisering',),
'sosialiseringen': ('sosialisering',),
'sosialiseringene': ('sosialisering',),
'sosialiseringer': ('sosialisering',),
'sosialisme': ('sosialisme',),
'sosialismen': ('sosialisme',),
'sosialismene': ('sosialisme',),
'sosialismer': ('sosialisme',),
'sosialist': ('sosialist',),
'sosialisten': ('sosialist',),
'sosialistene': ('sosialist',),
'sosialister': ('sosialist',),
'sosialistparti': ('sosialistparti',),
'sosialistpartia': ('sosialistparti',),
'sosialistpartiene': ('sosialistparti',),
'sosialistpartier': ('sosialistparti',),
'sosialistpartiet': ('sosialistparti',),
'sosialklient': ('sosialklient',),
'sosialklienten': ('sosialklient',),
'sosialklientene': ('sosialklient',),
'sosialklienter': ('sosialklient',),
'sosialkontor': ('sosialkontor',),
'sosialkontora': ('sosialkontor',),
'sosialkontorene': ('sosialkontor',),
'sosialkontorer': ('sosialkontor',),
'sosialkontoret': ('sosialkontor',),
'sosialkurator': ('sosialkurator',),
'sosialkuratoren': ('sosialkurator',),
'sosialkuratorene': ('sosialkurator',),
'sosialkuratorer': ('sosialkurator',),
'sosialkø': ('sosialkø',),
'sosialkøen': ('sosialkø',),
'sosialkøene': ('sosialkø',),
'sosialkøer': ('sosialkø',),
'sosialliberalisme': ('sosialliberalisme',),
'sosialliberalismen': ('sosialliberalisme',),
'sosialliberalismene': ('sosialliberalisme',),
'sosialliberalismer': ('sosialliberalisme',),
'sosiallinja': ('sosiallinje',),
'sosiallinje': ('sosiallinje',),
'sosiallinjen': ('sosiallinje',),
'sosiallinjene': ('sosiallinje',),
'sosiallinjer': ('sosiallinje',),
'sosiallærer': ('sosiallærer',),
'sosiallærere': ('sosiallærer',),
'sosiallæreren': ('sosiallærer',),
'sosiallærerer': ('sosiallærer',),
'sosiallærerne': ('sosiallærer',),
'sosialmedisin': ('sosialmedisin',),
'sosialmedisinen': ('sosialmedisin',),
'sosialmedisinene': ('sosialmedisin',),
'sosialmedisiner': ('sosialmedisin',),
'sosialminister': ('sosialminister',),
'sosialministere': ('sosialminister',),
'sosialministeren': ('sosialminister',),
'sosialministerer': ('sosialminister',),
'sosialministerne': ('sosialminister',),
'sosialministre': ('sosialminister',),
'sosialministrene': ('sosialminister',),
'sosialministrer': ('sosialminister',),
'sosialomsorg': ('sosialomsorg',),
'sosialomsorga': ('sosialomsorg',),
'sosialomsorgen': ('sosialomsorg',),
'sosialomsorgene': ('sosialomsorg',),
'sosialomsorger': ('sosialomsorg',),
'sosialpsykologi': ('sosialpsykologi',),
'sosialpsykologien': ('sosialpsykologi',),
'sosialpsykologiene': ('sosialpsykologi',),
'sosialpsykologier': ('sosialpsykologi',),
'sosialrealisme': ('sosialrealisme',),
'sosialrealismen': ('sosialrealisme',),
'sosialrealismene': ('sosialrealisme',),
'sosialrealismer': ('sosialrealisme',),
'sosialsjef': ('sosialsjef',),
'sosialsjefen': ('sosialsjef',),
'sosialsjefene': ('sosialsjef',),
'sosialsjefer': ('sosialsjef',),
'sosialtrygd': ('sosialtrygd',),
'sosialtrygda': ('sosialtrygd',),
'sosialtrygden': ('sosialtrygd',),
'sosialtrygdene': ('sosialtrygd',),
'sosialtrygder': ('sosialtrygd',),
'sosialøkonom': ('sosialøkonom',),
'sosialøkonomen': ('sosialøkonom',),
'sosialøkonomene': ('sosialøkonom',),
'sosialøkonomer': ('sosialøkonom',),
'sosialøkonomi': ('sosialøkonomi',),
'sosialøkonomien': ('sosialøkonomi',),
'sosialøkonomiene': ('sosialøkonomi',),
'sosialøkonomier': ('sosialøkonomi',),
'sosietet': ('sosietet',),
'sosieteten': ('sosietet',),
'sosietetene': ('sosietet',),
'sosieteter': ('sosietet',),
'sosietetsdama': ('sosietetsdame',),
'sosietetsdame': ('sosietetsdame',),
'sosietetsdamen': ('sosietetsdame',),
'sosietetsdamene': ('sosietetsdame',),
'sosietetsdamer': ('sosietetsdame',),
'sosiolekt': ('sosiolekt',),
'sosiolekten': ('sosiolekt',),
'sosiolektene': ('sosiolekt',),
'sosiolekter': ('sosiolekt',),
'sosiolingvistikk': ('sosiolingvistikk',),
'sosiolingvistikken': ('sosiolingvistikk',),
'sosiolingvistikkene': ('sosiolingvistikk',),
'sosiolingvistikker': ('sosiolingvistikk',),
'sosiolog': ('sosiolog',),
'sosiologen': ('sosiolog',),
'sosiologene': ('sosiolog',),
'sosiologer': ('sosiolog',),
'sosiologi': ('sosiologi',),
'sosiologien': ('sosiologi',),
'sosiologiene': ('sosiologi',),
'sosiologier': ('sosiologi',),
'sosiometri': ('sosiometri',),
'sosiometrien': ('sosiometri',),
'sosiometriene': ('sosiometri',),
'sosiometrier': ('sosiometri',),
'sosionom': ('sosionom',),
'sosionomen': ('sosionom',),
'sosionomene': ('sosionom',),
'sosionomer': ('sosionom',),
'sosiopat': ('sosiopat',),
'sosiopaten': ('sosiopat',),
'sosiopatene': ('sosiopat',),
'sosiopater': ('sosiopat',),
'sosiopati': ('sosiopati',),
'sosiopatien': ('sosiopati',),
'sosiopatiene': ('sosiopati',),
'sosiopatier': ('sosiopati',),
'soss': ('soss',),
'sossen': ('soss',),
'sossene': ('soss',),
'sosser': ('soss',),
'sot': ('sot',),
'sota': ('sot',),
'soten': ('sot',),
'sotene': ('sot',),
'soter': ('sot',),
'sotet': ('sot',),
'sotbrann': ('sotbrann',),
'sotbrannen': ('sotbrann',),
'sotbrannene': ('sotbrann',),
'sotbranner': ('sotbrann',),
'sothøna': ('sothøne',),
'sothøne': ('sothøne',),
'sothønen': ('sothøne',),
'sothønene': ('sothøne',),
'sothøner': ('sothøne',),
'sotluka': ('sotluke',),
'sotluke': ('sotluke',),
'sotluken': ('sotluke',),
'sotlukene': ('sotluke',),
'sotluker': ('sotluke',),
'sott': ('sott',),
'sotta': ('sott',),
'sotten': ('sott',),
'sottene': ('sott',),
'sotter': ('sott',),
'sotteseng': ('sotteseng',),
'sottesenga': ('sotteseng',),
'sottesengen': ('sotteseng',),
'sottesengene': ('sotteseng',),
'sottesenger': ('sotteseng',),
'sou': ('sou',),
'souen': ('sou',),
'souene': ('sou',),
'soul': ('soul',),
'soulen': ('soul',),
'soulene': ('soul',),
'souler': ('soul',),
'sound': ('sound',),
'sounden': ('sound',),
'soundene': ('sound',),
'sounder': ('sound',),
'soussjef': ('soussjef',),
'soussjefen': ('soussjef',),
'soussjefene': ('soussjef',),
'soussjefer': ('soussjef',),
'soveby': ('soveby',),
'sovebyen': ('soveby',),
'sovebyene': ('soveby',),
'sovebyer': ('soveby',),
'sovedokka': ('sovedokke',),
'sovedokke': ('sovedokke',),
'sovedokken': ('sovedokke',),
'sovedokkene': ('sovedokke',),
'sovedokker': ('sovedokke',),
'sovehjerta': ('sovehjerte',),
'sovehjerte': ('sovehjerte',),
'sovehjertene': ('sovehjerte',),
'sovehjerter': ('sovehjerte',),
'sovehjertet': ('sovehjerte',),
'sovekommune': ('sovekommune',),
'sovekommunen': ('sovekommune',),
'sovekommunene': ('sovekommune',),
'sovekommuner': ('sovekommune',),
'sovemedisin': ('sovemedisin',),
'sovemedisinen': ('sovemedisin',),
'sovemedisinene': ('sovemedisin',),
'sovemedisiner': ('sovemedisin',),
'sovemiddel': ('sovemiddel',),
'sovemiddelet': ('sovemiddel',),
'sovemidla': ('sovemiddel',),
'sovemidlene': ('sovemiddel',),
'sovemidler': ('sovemiddel',),
'sovemidlet': ('sovemiddel',),
'sovepose': ('sovepose',),
'soveposen': ('sovepose',),
'soveposene': ('sovepose',),
'soveposer': ('sovepose',),
'soveputa': ('sovepute',),
'sovepute': ('sovepute',),
'soveputen': ('sovepute',),
'soveputene': ('sovepute',),
'soveputer': ('sovepute',),
'soverom': ('soverom',),
'soveromma': ('soverom',),
'soverommene': ('soverom',),
'soverommet': ('soverom',),
'sovesal': ('sovesal',),
'sovesalen': ('sovesal',),
'sovesalene': ('sovesal',),
'sovesaler': ('sovesal',),
'sovesjuka': ('sovesjuke',),
'sovesjuke': ('sovesjuke',),
'sovesjuken': ('sovesjuke',),
'sovesjukene': ('sovesjuke',),
'sovesjuker': ('sovesjuke',),
'sovesofa': ('sovesofa',),
'sovesofaen': ('sovesofa',),
'sovesofaene': ('sovesofa',),
'sovesofaer': ('sovesofa',),
'sovesyka': ('sovesyke',),
'sovesyke': ('sovesyke',),
'sovesyken': ('sovesyke',),
'sovesykene': ('sovesyke',),
'sovesyker': ('sovesyke',),
'sovetablett': ('sovetablett',),
'sovetabletten': ('sovetablett',),
'sovetablettene': ('sovetablett',),
'sovetabletter': ('sovetablett',),
'soveværelsa': ('soveværelse',),
'soveværelse': ('soveværelse',),
'soveværelsene': ('soveværelse',),
'soveværelser': ('soveværelse',),
'soveværelset': ('soveværelse',),
'sovjet': ('sovjet',),
'sovjeta': ('sovjet',),
'sovjetene': ('sovjet',),
'sovjeter': ('sovjet',),
'sovjetet': ('sovjet',),
'sovjetborger': ('sovjetborger',),
'sovjetborgere': ('sovjetborger',),
'sovjetborgeren': ('sovjetborger',),
'sovjetborgerer': ('sovjetborger',),
'sovjetborgerne': ('sovjetborger',),
'sovjetrepublikk': ('sovjetrepublikk',),
'sovjetrepublikken': ('sovjetrepublikk',),
'sovjetrepublikkene': ('sovjetrepublikk',),
'sovjetrepublikker': ('sovjetrepublikk',),
'sovjetrusser': ('sovjetrusser',),
'sovjetrussere': ('sovjetrusser',),
'sovjetrusseren': ('sovjetrusser',),
'sovjetrusserer': ('sovjetrusser',),
'sovjetrusserne': ('sovjetrusser',),
'sovkos': ('sovkos',),
'sovkosa': ('sovkos',),
'sovkosene': ('sovkos',),
'sovkoser': ('sovkos',),
'sovkoset': ('sovkos',),
'soya': ('soya',),
'soyaen': ('soya',),
'soyaene': ('soya',),
'soyaer': ('soya',),
'soyabønna': ('soyabønne',),
'soyabønne': ('soyabønne',),
'soyabønnen': ('soyabønne',),
'soyabønnene': ('soyabønne',),
'soyabønner': ('soyabønne',),
'soyamel': ('soyamel',),
'soyamela': ('soyamel',),
'soyamelene': ('soyamel',),
'soyamelet': ('soyamel',),
'soyamjøl': ('soyamjøl',),
'soyamjøla': ('soyamjøl',),
'soyamjølene': ('soyamjøl',),
'soyamjølet': ('soyamjøl',),
'soyaolja': ('soyaolje',),
'soyaolje': ('soyaolje',),
'soyaoljen': ('soyaolje',),
'soyaoljene': ('soyaolje',),
'soyaoljer': ('soyaolje',),
'spade': ('spade',),
'spaden': ('spade',),
'spadene': ('spade',),
'spader': ('spade',),
'spadestikk': ('spadestikk',),
'spadestikka': ('spadestikk',),
'spadestikkene': ('spadestikk',),
'spadestikket': ('spadestikk',),
'spadetak': ('spadetak',),
'spadetaka': ('spadetak',),
'spadetakene': ('spadetak',),
'spadetaket': ('spadetak',),
'spagat': ('spagat',),
'spagaten': ('spagat',),
'spagatene': ('spagat',),
'spagater': ('spagat',),
'spagetti': ('spagetti',),
'spagettien': ('spagetti',),
'spagettiene': ('spagetti',),
'spagettier': ('spagetti',),
'spaghettiwestern': ('spaghettiwestern',),
'spaghettiwesternen': ('spaghettiwestern',),
'spaghettiwesternene': ('spaghettiwestern',),
'spaghettiwesterner': ('spaghettiwestern',),
'spak': ('spak',),
'spaken': ('spak',),
'spakene': ('spak',),
'spaker': ('spak',),
'spalier': ('spalier',),
'spaliera': ('spalier',),
'spalierene': ('spalier',),
'spalierer': ('spalier',),
'spalieret': ('spalier',),
'spalta': ('spalte',),
'spalte': ('spalte',),
'spalten': ('spalte',),
'spaltene': ('spalte',),
'spalter': ('spalte',),
'spaltegolv': ('spaltegolv',),
'spaltegolva': ('spaltegolv',),
'spaltegolvene': ('spaltegolv',),
'spaltegolvet': ('spaltegolv',),
'spaltegulv': ('spaltegulv',),
'spaltegulva': ('spaltegulv',),
'spaltegulvene': ('spaltegulv',),
'spaltegulvet': ('spaltegulv',),
'spaltemillimeter': ('spaltemillimeter',),
'spaltemillimeteren': ('spaltemillimeter',),
'spaltemillimeterne': ('spaltemillimeter',),
'spalteplass': ('spalteplass',),
'spalteplassen': ('spalteplass',),
'spalteplassene': ('spalteplass',),
'spalteplasser': ('spalteplass',),
'spalteåpning': ('spalteåpning',),
'spalteåpninga': ('spalteåpning',),
'spalteåpningen': ('spalteåpning',),
'spalteåpningene': ('spalteåpning',),
'spalteåpninger': ('spalteåpning',),
'spalting': ('spalting',),
'spaltinga': ('spalting',),
'spaltingen': ('spalting',),
'spaltingene': ('spalting',),
'spaltinger': ('spalting',),
'spaltingsprodukt': ('spaltingsprodukt',),
'spaltingsprodukta': ('spaltingsprodukt',),
'spaltingsproduktene': ('spaltingsprodukt',),
'spaltingsprodukter': ('spaltingsprodukt',),
'spaltingsproduktet': ('spaltingsprodukt',),
'spaltist': ('spaltist',),
'spaltisten': ('spaltist',),
'spaltistene': ('spaltist',),
'spaltister': ('spaltist',),
'spaltning': ('spaltning',),
'spaltninga': ('spaltning',),
'spaltningen': ('spaltning',),
'spaltningene': ('spaltning',),
'spaltninger': ('spaltning',),
'spaltningsprodukt': ('spaltningsprodukt',),
'spaltningsprodukta': ('spaltningsprodukt',),
'spaltningsproduktene': ('spaltningsprodukt',),
'spaltningsprodukter': ('spaltningsprodukt',),
'spaltningsproduktet': ('spaltningsprodukt',),
'spaner': ('spaner',),
'spanere': ('spaner',),
'spaneren': ('spaner',),
'spanerer': ('spaner',),
'spanerne': ('spaner',),
'spaniel': ('spaniel',),
'spanielen': ('spaniel',),
'spanielene': ('spaniel',),
'spanieler': ('spaniel',),
'spanier': ('spanier',),
'spaniere': ('spanier',),
'spanieren': ('spanier',),
'spanierer': ('spanier',),
'spanierne': ('spanier',),
'spaning': ('spaning',),
'spaninga': ('spaning',),
'spaningen': ('spaning',),
'spaningene': ('spaning',),
'spaninger': ('spaning',),
'spaningspatrulje': ('spaningspatrulje',),
'spaningspatruljen': ('spaningspatrulje',),
'spaningspatruljene': ('spaningspatrulje',),
'spaningspatruljer': ('spaningspatrulje',),
'spanjol': ('spanjol',),
'spanjolen': ('spanjol',),
'spanjolene': ('spanjol',),
'spanjoler': ('spanjol',),
'spansk': ('spansk',),
'spansken': ('spansk',),
'spanskene': ('spansk',),
'spansker': ('spansk',),
'spanskesjuka': ('spanskesjuke',),
'spanskesjuke': ('spanskesjuke',),
'spanskesjuken': ('spanskesjuke',),
'spanskesjukene': ('spanskesjuke',),
'spanskesjuker': ('spanskesjuke',),
'spanskesyka': ('spanskesyke',),
'spanskesyke': ('spanskesyke',),
'spanskesyken': ('spanskesyke',),
'spanskesykene': ('spanskesyke',),
'spanskesyker': ('spanskesyke',),
'spanskrør': ('spanskrør',),
'spanskrøra': ('spanskrør',),
'spanskrørene': ('spanskrør',),
'spanskrøret': ('spanskrør',),
'spanskrørspalme': ('spanskrørspalme',),
'spanskrørspalmen': ('spanskrørspalme',),
'spanskrørspalmene': ('spanskrørspalme',),
'spanskrørspalmer': ('spanskrørspalme',),
'spant': ('spant',),
'spanta': ('spant',),
'spantene': ('spant',),
'spanter': ('spant',),
'spantet': ('spant',),
'spar': ('spar',),
'sparen': ('spar',),
'sparene': ('spar',),
'sparer': ('spar',),
'sparagmitt': ('sparagmitt',),
'sparagmitten': ('sparagmitt',),
'sparagmittene': ('sparagmitt',),
'sparagmitter': ('sparagmitt',),
'sparebank': ('sparebank',),
'sparebanken': ('sparebank',),
'sparebankene': ('sparebank',),
'sparebanker': ('sparebank',),
'sparebluss': ('sparebluss',),
'spareblussa': ('sparebluss',),
'spareblussene': ('sparebluss',),
'spareblusset': ('sparebluss',),
'sparebøssa': ('sparebøsse',),
'sparebøsse': ('sparebøsse',),
'sparebøssen': ('sparebøsse',),
'sparebøssene': ('sparebøsse',),
'sparebøsser': ('sparebøsse',),
'sparegris': ('sparegris',),
'sparegrisen': ('sparegris',),
'sparegrisene': ('sparegris',),
'sparegriser': ('sparegris',),
'sparekniv': ('sparekniv',),
'sparekniven': ('sparekniv',),
'spareknivene': ('sparekniv',),
'sparekniver': ('sparekniv',),
'sparekonti': ('sparekonto',),
'sparekontiene': ('sparekonto',),
'sparekonto': ('sparekonto',),
'sparekontoen': ('sparekonto',),
'sparekontoene': ('sparekonto',),
'sparekontoer': ('sparekonto',),
'sparepengene': ('sparepenger',),
'sparepenger': ('sparepenger',),
'sparer': ('sparer',),
'sparere': ('sparer',),
'spareren': ('sparer',),
'sparerer': ('sparer',),
'sparerne': ('sparer',),
'spareskilling': ('spareskilling',),
'spareskillingen': ('spareskilling',),
'spareskillingene': ('spareskilling',),
'spareskillinger': ('spareskilling',),
'spark': ('spark',),
'sparka': ('spark',),
'sparkene': ('spark',),
'sparket': ('spark',),
'sparkebuksa': ('sparkebukse',),
'sparkebukse': ('sparkebukse',),
'sparkebuksen': ('sparkebukse',),
'sparkebuksene': ('sparkebukse',),
'sparkebukser': ('sparkebukse',),
'sparkel': ('sparkel',),
'sparkelen': ('sparkel',),
'sparklene': ('sparkel',),
'sparkler': ('sparkel',),
'sparkelmasse': ('sparkelmasse',),
'sparkelmassen': ('sparkelmasse',),
'sparkelmassene': ('sparkelmasse',),
'sparkelmasser': ('sparkelmasse',),
'sparkepika': ('sparkepike',),
'sparkepike': ('sparkepike',),
'sparkepiken': ('sparkepike',),
'sparkepikene': ('sparkepike',),
'sparkepiker': ('sparkepike',),
'sparkesykkel': ('sparkesykkel',),
'sparkesykkelen': ('sparkesykkel',),
'sparkesyklene': ('sparkesykkel',),
'sparkesykler': ('sparkesykkel',),
'sparkstøtting': ('sparkstøtting',),
'sparkstøttingen': ('sparkstøtting',),
'sparkstøttingene': ('sparkstøtting',),
'sparkstøttinger': ('sparkstøtting',),
'sparksykkel': ('sparksykkel',),
'sparksykkelen': ('sparksykkel',),
'sparksyklene': ('sparksykkel',),
'sparksykler': ('sparksykkel',),
'sparringpartner': ('sparringpartner',),
'sparringpartnere': ('sparringpartner',),
'sparringpartneren': ('sparringpartner',),
'sparringpartnerer': ('sparringpartner',),
'sparringpartnerne': ('sparringpartner',),
'spartakiade': ('spartakiade',),
'spartakiaden': ('spartakiade',),
'spartakiadene': ('spartakiade',),
'spartakiader': ('spartakiade',),
'spartaner': ('spartaner',),
'spartanere': ('spartaner',),
'spartaneren': ('spartaner',),
'spartanerer': ('spartaner',),
'spartanerne': ('spartaner',),
'spas': ('spas',),
'spasen': ('spas',),
'spasene': ('spas',),
'spaser': ('spas',),
'spasersko': ('spasersko',),
'spaserskoa': ('spasersko',),
'spaserskoen': ('spasersko',),
'spaserskoene': ('spasersko',),
'spaserskor': ('spasersko',),
'spaserskorne': ('spasersko',),
'spaserstokk': ('spaserstokk',),
'spaserstokken': ('spaserstokk',),
'spaserstokkene': ('spaserstokk',),
'spaserstokker': ('spaserstokk',),
'spasertur': ('spasertur',),
'spaserturen': ('spasertur',),
'spaserturene': ('spasertur',),
'spaserturer': ('spasertur',),
'spasmaker': ('spasmaker',),
'spasmakere': ('spasmaker',),
'spasmakeren': ('spasmaker',),
'spasmakerer': ('spasmaker',),
'spasmakerne': ('spasmaker',),
'spasme': ('spasme',),
'spasmen': ('spasme',),
'spasmene': ('spasme',),
'spasmer': ('spasme',),
'spastiker': ('spastiker',),
'spastikere': ('spastiker',),
'spastikeren': ('spastiker',),
'spastikerer': ('spastiker',),
'spastikerne': ('spastiker',),
'spat': ('spat',),
'spaten': ('spat',),
'spatene': ('spat',),
'spater': ('spat',),
'spatak': ('spatak',),
'spataka': ('spatak',),
'spatakene': ('spatak',),
'spataket': ('spatak',),
'spatel': ('spatel',),
'spatelen': ('spatel',),
'spatlene': ('spatel',),
'spatler': ('spatel',),
'spatia': ('spatium',),
'spatiene': ('spatium',),
'spatier': ('spatium',),
'spatiet': ('spatium',),
'spatium': ('spatium',),
'spatt': ('spatt',),
'spatten': ('spatt',),
'spattene': ('spatt',),
'spatter': ('spatt',),
'spe': ('spe',),
'speaker': ('speaker',),
'speakere': ('speaker',),
'speakeren': ('speaker',),
'speakerer': ('speaker',),
'speakerne': ('speaker',),
'spedalskhet': ('spedalskhet',),
'spedalskheta': ('spedalskhet',),
'spedalskheten': ('spedalskhet',),
'spedalskhetene': ('spedalskhet',),
'spedalskheter': ('spedalskhet',),
'spedbarn': ('spedbarn',),
'spedbarna': ('spedbarn',),
'spedbarnene': ('spedbarn',),
'spedbarnet': ('spedbarn',),
'spedisjon': ('spedisjon',),
'spedisjonen': ('spedisjon',),
'spedisjonene': ('spedisjon',),
'spedisjoner': ('spedisjon',),
'spedisjonsfirma': ('spedisjonsfirma',),
'spedisjonsfirmaene': ('spedisjonsfirma',),
'spedisjonsfirmaer': ('spedisjonsfirma',),
'spedisjonsfirmaet': ('spedisjonsfirma',),
'speditør': ('speditør',),
'speditøren': ('speditør',),
'speditørene': ('speditør',),
'speditører': ('speditør',),
'spedkalv': ('spedkalv',),
'spedkalven': ('spedkalv',),
'spedkalvene': ('spedkalv',),
'spedkalver': ('spedkalv',),
'speech': ('speech',),
'speechen': ('speech',),
'speechene': ('speech',),
'speecher': ('speech',),
'speed': ('speed',),
'speeden': ('speed',),
'speedene': ('speed',),
'speeder': ('speed',),
'speedbåt': ('speedbåt',),
'speedbåten': ('speedbåt',),
'speedbåtene': ('speedbåt',),
'speedbåter': ('speedbåt',),
'speedometer': ('speedometer',),
'speedometeret': ('speedometer',),
'speedometra': ('speedometer',),
'speedometre': ('speedometer',),
'speedometrene': ('speedometer',),
'speedometret': ('speedometer',),
'speedway': ('speedway',),
'speedwayen': ('speedway',),
'speedwayene': ('speedway',),
'speedwayer': ('speedway',),
'speider': ('speider',),
'speidere': ('speider',),
'speideren': ('speider',),
'speiderer': ('speider',),
'speiderne': ('speider',),
'speiderdrakt': ('speiderdrakt',),
'speiderdrakta': ('speiderdrakt',),
'speiderdrakten': ('speiderdrakt',),
'speiderdraktene': ('speiderdrakt',),
'speiderdrakter': ('speiderdrakt',),
'speiderfly': ('speiderfly',),
'speiderflya': ('speiderfly',),
'speiderflyene': ('speiderfly',),
'speiderflyet': ('speiderfly',),
'speidergutt': ('speidergutt',),
'speidergutten': ('speidergutt',),
'speiderguttene': ('speidergutt',),
'speidergutter': ('speidergutt',),
'speiderjenta': ('speiderjente',),
'speiderjente': ('speiderjente',),
'speiderjenten': ('speiderjente',),
'speiderjentene': ('speiderjente',),
'speiderjenter': ('speiderjente',),
'speiderløfta': ('speiderløfte',),
'speiderløfte': ('speiderløfte',),
'speiderløftene': ('speiderløfte',),
'speiderløfter': ('speiderløfte',),
'speiderløftet': ('speiderløfte',),
'speiderpatrulje': ('speiderpatrulje',),
'speiderpatruljen': ('speiderpatrulje',),
'speiderpatruljene': ('speiderpatrulje',),
'speiderpatruljer': ('speiderpatrulje',),
'speidertropp': ('speidertropp',),
'speidertroppen': ('speidertropp',),
'speidertroppene': ('speidertropp',),
'speidertropper': ('speidertropp',),
'speiding': ('speiding',),
'speidinga': ('speiding',),
'speidingen': ('speiding',),
'speidingene': ('speiding',),
'speidinger': ('speiding',),
'speil': ('speil',),
'speila': ('speil',),
'speilene': ('speil',),
'speilet': ('speil',),
'speilbilda': ('speilbilde',),
'speilbilde': ('speilbilde',),
'speilbildene': ('speilbilde',),
'speilbilder': ('speilbilde',),
'speilbildet': ('speilbilde',),
'speilegg': ('speilegg',),
'speilegga': ('speilegg',),
'speileggene': ('speilegg',),
'speilegget': ('speilegg',),
'speilflata': ('speilflate',),
'speilflate': ('speilflate',),
'speilflaten': ('speilflate',),
'speilflatene': ('speilflate',),
'speilflater': ('speilflate',),
'speilglas': ('speilglas',),
'speilglasa': ('speilglas',),
'speilglasene': ('speilglas',),
'speilglaset': ('speilglas',),
'speilglass': ('speilglass',),
'speilglassa': ('speilglass',),
'speilglassene': ('speilglass',),
'speilglasset': ('speilglass',),
'speiling': ('speiling',),
'speilinga': ('speiling',),
'speilingen': ('speiling',),
'speilingene': ('speiling',),
'speilinger': ('speiling',),
'speilrefleks': ('speilrefleks',),
'speilrefleksen': ('speilrefleks',),
'speilrefleksene': ('speilrefleks',),
'speilreflekser': ('speilrefleks',),
'speilreflekskamera': ('speilreflekskamera',),
'speilreflekskameraene': ('speilreflekskamera',),
'speilreflekskameraer': ('speilreflekskamera',),
'speilreflekskameraet': ('speilreflekskamera',),
'speilsal': ('speilsal',),
'speilsalen': ('speilsal',),
'speilsalene': ('speilsal',),
'speilsaler': ('speilsal',),
'speilskrift': ('speilskrift',),
'speilskrifta': ('speilskrift',),
'speilskriften': ('speilskrift',),
'speilskriftene': ('speilskrift',),
'speilskrifter': ('speilskrift',),
'spekeflesk': ('spekeflesk',),
'spekefleska': ('spekeflesk',),
'spekefleskene': ('spekeflesk',),
'spekeflesket': ('spekeflesk',),
'spekekjøtt': ('spekekjøtt',),
'spekekjøtta': ('spekekjøtt',),
'spekekjøttene': ('spekekjøtt',),
'spekekjøttet': ('spekekjøtt',),
'spekemat': ('spekemat',),
'spekematen': ('spekemat',),
'spekematene': ('spekemat',),
'spekemater': ('spekemat',),
'spekesild': ('spekesild',),
'spekesilda': ('spekesild',),
'spekesilden': ('spekesild',),
'spekesildene': ('spekesild',),
'spekesilder': ('spekesild',),
'spekeskinka': ('spekeskinke',),
'spekeskinke': ('spekeskinke',),
'spekeskinken': ('spekeskinke',),
'spekeskinkene': ('spekeskinke',),
'spekeskinker': ('spekeskinke',),
'spekk': ('spekk',),
'spekka': ('spekk',),
'spekkene': ('spekk',),
'spekket': ('spekk',),
'spekkfinger': ('spekkfinger',),
'spekkfingeren': ('spekkfinger',),
'spekkfingre': ('spekkfinger',),
'spekkfingrene': ('spekkfinger',),
'spekkfingrer': ('spekkfinger',),
'spekkhogger': ('spekkhogger',),
'spekkhoggere': ('spekkhogger',),
'spekkhoggeren': ('spekkhogger',),
'spekkhoggerer': ('spekkhogger',),
'spekkhoggerne': ('spekkhogger',),
'spekkhugger': ('spekkhugger',),
'spekkhuggere': ('spekkhugger',),
'spekkhuggeren': ('spekkhugger',),
'spekkhuggerer': ('spekkhugger',),
'spekkhuggerne': ('spekkhugger',),
'speks': ('speks',),
'speksa': ('speks',),
'speksene': ('speks',),
'spekset': ('speks',),
'spekter': ('spekter',),
'spekteret': ('spekter',),
'spektra': ('spekter',),
'spektre': ('spekter',),
'spektrene': ('spekter',),
'spektret': ('spekter',),
'spektralanalysa': ('spektralanalyse',),
'spektralanalyse': ('spektralanalyse',),
'spektralanalysen': ('spektralanalyse',),
'spektralanalysene': ('spektralanalyse',),
'spektralanalyser': ('spektralanalyse',),
'spektrallinja': ('spektrallinje',),
'spektrallinje': ('spektrallinje',),
'spektrallinjen': ('spektrallinje',),
'spektrallinjene': ('spektrallinje',),
'spektrallinjer': ('spektrallinje',),
'spektrograf': ('spektrograf',),
'spektrografen': ('spektrograf',),
'spektrografene': ('spektrograf',),
'spektrografer': ('spektrograf',),
'spektrogram': ('spektrogram',),
'spektrogramma': ('spektrogram',),
'spektrogrammene': ('spektrogram',),
'spektrogrammet': ('spektrogram',),
'spektrometer': ('spektrometer',),
'spektrometeret': ('spektrometer',),
'spektrometra': ('spektrometer',),
'spektrometre': ('spektrometer',),
'spektrometrene': ('spektrometer',),
'spektrometret': ('spektrometer',),
'spektroskop': ('spektroskop',),
'spektroskopa': ('spektroskop',),
'spektroskopene': ('spektroskop',),
'spektroskoper': ('spektroskop',),
'spektroskopet': ('spektroskop',),
'spektra': ('spektrum',),
'spektraene': ('spektrum',),
'spektre': ('spektrum',),
'spektrene': ('spektrum',),
'spektret': ('spektrum',),
'spektrum': ('spektrum',),
'spektrumet': ('spektrum',),
'spekulant': ('spekulant',),
'spekulanten': ('spekulant',),
'spekulantene': ('spekulant',),
'spekulanter': ('spekulant',),
'spekulasjon': ('spekulasjon',),
'spekulasjonen': ('spekulasjon',),
'spekulasjonene': ('spekulasjon',),
'spekulasjoner': ('spekulasjon',),
'spell': ('spell',),
'spella': ('spell',),
'spellene': ('spell',),
'spellet': ('spell',),
'spelleautomat': ('spelleautomat',),
'spelleautomaten': ('spelleautomat',),
'spelleautomatene': ('spelleautomat',),
'spelleautomater': ('spelleautomat',),
'spellebank': ('spellebank',),
'spellebanken': ('spellebank',),
'spellebankene': ('spellebank',),
'spellebanker': ('spellebank',),
'spellebula': ('spellebule',),
'spellebule': ('spellebule',),
'spellebulen': ('spellebule',),
'spellebulene': ('spellebule',),
'spellebuler': ('spellebule',),
'spelledåsa': ('spelledåse',),
'spelledåse': ('spelledåse',),
'spelledåsen': ('spelledåse',),
'spelledåsene': ('spelledåse',),
'spelledåser': ('spelledåse',),
'spellefilm': ('spellefilm',),
'spellefilmen': ('spellefilm',),
'spellefilmene': ('spellefilm',),
'spellefilmer': ('spellefilm',),
'spellegalskap': ('spellegalskap',),
'spellegalskapen': ('spellegalskap',),
'spellegalskapene': ('spellegalskap',),
'spellegalskaper': ('spellegalskap',),
'spellelykka': ('spellelykke',),
'spellelykke': ('spellelykke',),
'spellelykken': ('spellelykke',),
'spellelykkene': ('spellelykke',),
'spellelykker': ('spellelykke',),
'spellelærer': ('spellelærer',),
'spellelærere': ('spellelærer',),
'spellelæreren': ('spellelærer',),
'spellelærerer': ('spellelærer',),
'spellelærerne': ('spellelærer',),
'spellemann': ('spellemann',),
'spellemannen': ('spellemann',),
'spellemenn': ('spellemann',),
'spellemennene': ('spellemann',),
'spellemannslag': ('spellemannslag',),
'spellemannslaga': ('spellemannslag',),
'spellemannslagene': ('spellemannslag',),
'spellemannslaget': ('spellemannslag',),
'spellemerka': ('spellemerke',),
'spellemerke': ('spellemerke',),
'spellemerkene': ('spellemerke',),
'spellemerker': ('spellemerke',),
'spellemerket': ('spellemerke',),
'spelleomgang': ('spelleomgang',),
'spelleomgangen': ('spelleomgang',),
'spelleomgangene': ('spelleomgang',),
'spelleomganger': ('spelleomgang',),
'spelleplan': ('spelleplan',),
'spelleplanen': ('spelleplan',),
'spelleplanene': ('spelleplan',),
'spelleplaner': ('spelleplan',),
'speller': ('speller',),
'spellere': ('speller',),
'spelleren': ('speller',),
'spellerer': ('speller',),
'spellerne': ('speller',),
'spelleregel': ('spelleregel',),
'spelleregelen': ('spelleregel',),
'spellereglene': ('spelleregel',),
'spelleregler': ('spelleregel',),
'spellerom': ('spellerom',),
'spelleromma': ('spellerom',),
'spellerommene': ('spellerom',),
'spellerommet': ('spellerom',),
'spellesesong': ('spellesesong',),
'spellesesongen': ('spellesesong',),
'spellesesongene': ('spellesesong',),
'spellesesonger': ('spellesesong',),
'spellestil': ('spellestil',),
'spellestilen': ('spellestil',),
'spellestilene': ('spellestil',),
'spellestiler': ('spellestil',),
'spelletime': ('spelletime',),
'spelletimen': ('spelletime',),
'spelletimene': ('spelletime',),
'spelletimer': ('spelletime',),
'spellfugl': ('spellfugl',),
'spellfuglen': ('spellfugl',),
'spellfuglene': ('spellfugl',),
'spellfugler': ('spellfugl',),
'spelljakt': ('spelljakt',),
'spelljakta': ('spelljakt',),
'spelljakten': ('spelljakt',),
'spelljaktene': ('spelljakt',),
'spelljakter': ('spelljakt',),
'spellkort': ('spellkort',),
'spellkorta': ('spellkort',),
'spellkortene': ('spellkort',),
'spellkortet': ('spellkort',),
'spencerjakka': ('spencerjakke',),
'spencerjakke': ('spencerjakke',),
'spencerjakken': ('spencerjakke',),
'spencerjakkene': ('spencerjakke',),
'spencerjakker': ('spencerjakke',),
'spencerkjole': ('spencerkjole',),
'spencerkjolen': ('spencerkjole',),
'spencerkjolene': ('spencerkjole',),
'spencerkjoler': ('spencerkjole',),
'spene': ('spene',),
'spenen': ('spene',),
'spenene': ('spene',),
'spener': ('spene',),
'spenn': ('spenn',),
'spenna': ('spenn',),
'spennene': ('spenn',),
'spennet': ('spenn',),
'spenn': ('spenn',),
'spenna': ('spenn',),
'spennene': ('spenn',),
'spennet': ('spenn',),
'spennbetong': ('spennbetong',),
'spennbetongen': ('spennbetong',),
'spennbetongene': ('spennbetong',),
'spennbetonger': ('spennbetong',),
'spenna': ('spenne',),
'spenne': ('spenne',),
'spennen': ('spenne',),
'spennene': ('spenne',),
'spenner': ('spenne',),
'spennet': ('spenne',),
'spenlene': ('spennel',),
'spenler': ('spennel',),
'spennel': ('spennel',),
'spennelen': ('spennel',),
'spennetak': ('spennetak',),
'spennetaka': ('spennetak',),
'spennetakene': ('spennetak',),
'spennetaket': ('spennetak',),
'spenning': ('spenning',),
'spenninga': ('spenning',),
'spenningen': ('spenning',),
'spenningene': ('spenning',),
'spenninger': ('spenning',),
'spenning': ('spenning',),
'spenninga': ('spenning',),
'spenningen': ('spenning',),
'spenningene': ('spenning',),
'spenninger': ('spenning',),
'spenningsfelt': ('spenningsfelt',),
'spenningsfelta': ('spenningsfelt',),
'spenningsfeltene': ('spenningsfelt',),
'spenningsfelter': ('spenningsfelt',),
'spenningsfeltet': ('spenningsfelt',),
'spenningsmåler': ('spenningsmåler',),
'spenningsmålere': ('spenningsmåler',),
'spenningsmåleren': ('spenningsmåler',),
'spenningsmålerer': ('spenningsmåler',),
'spenningsmålerne': ('spenningsmåler',),
'spenntak': ('spenntak',),
'spenntaka': ('spenntak',),
'spenntakene': ('spenntak',),
'spenntaket': ('spenntak',),
'spennvidda': ('spennvidde',),
'spennvidde': ('spennvidde',),
'spennvidden': ('spennvidde',),
'spennviddene': ('spennvidde',),
'spennvidder': ('spennvidde',),
'spensel': ('spensel',),
'spenselet': ('spensel',),
'spensla': ('spensel',),
'spenslene': ('spensel',),
'spensler': ('spensel',),
'spenslet': ('spensel',),
'spenst': ('spenst',),
'spensten': ('spenst',),
'spenstene': ('spenst',),
'spenster': ('spenst',),
'spenstighet': ('spenstighet',),
'spenstigheta': ('spenstighet',),
'spenstigheten': ('spenstighet',),
'spenstighetene': ('spenstighet',),
'spenstigheter': ('spenstighet',),
'sperma': ('sperma',),
'spermaa': ('sperma',),
'spermaene': ('sperma',),
'spermaet': ('sperma',),
'spermasett': ('spermasett',),
'spermasetten': ('spermasett',),
'spermasettene': ('spermasett',),
'spermasetter': ('spermasett',),
'spermasetthval': ('spermasetthval',),
'spermasetthvalen': ('spermasetthval',),
'spermasetthvalene': ('spermasetthval',),
'spermasetthvaler': ('spermasetthval',),
'spermasettkval': ('spermasettkval',),
'spermasettkvalen': ('spermasettkval',),
'spermasettkvalene': ('spermasettkval',),
'spermasettkvaler': ('spermasettkval',),
'spermasettolja': ('spermasettolje',),
'spermasettolje': ('spermasettolje',),
'spermasettoljen': ('spermasettolje',),
'spermasettoljene': ('spermasettolje',),
'spermasettoljer': ('spermasettolje',),
'spermatologi': ('spermatologi',),
'spermatologien': ('spermatologi',),
'spermatologiene': ('spermatologi',),
'spermatologier': ('spermatologi',),
'spermatozo': ('spermatozo',),
'spermatozoen': ('spermatozo',),
'spermatozoene': ('spermatozo',),
'spermatozoer': ('spermatozo',),
'spermhval': ('spermhval',),
'spermhvalen': ('spermhval',),
'spermhvalene': ('spermhval',),
'spermhvaler': ('spermhval',),
'spermia': ('spermie',),
'spermie': ('spermie',),
'spermien': ('spermie',),
'spermiene': ('spermie',),
'spermier': ('spermie',),
'spermiet': ('spermie',),
'spermia': ('spermium',),
'spermiene': ('spermium',),
'spermier': ('spermium',),
'spermiet': ('spermium',),
'spermium': ('spermium',),
'spermkval': ('spermkval',),
'spermkvalen': ('spermkval',),
'spermkvalene': ('spermkval',),
'spermkvaler': ('spermkval',),
'spermolja': ('spermolje',),
'spermolje': ('spermolje',),
'spermoljen': ('spermolje',),
'spermoljene': ('spermolje',),
'spermoljer': ('spermolje',),
'sperra': ('sperre',),
'sperre': ('sperre',),
'sperren': ('sperre',),
'sperrene': ('sperre',),
'sperrer': ('sperre',),
'sperrebukk': ('sperrebukk',),
'sperrebukken': ('sperrebukk',),
'sperrebukkene': ('sperrebukk',),
'sperrebukker': ('sperrebukk',),
'sperreeld': ('sperreeld',),
'sperreelden': ('sperreeld',),
'sperreeldene': ('sperreeld',),
'sperreelder': ('sperreeld',),
'sperreeld': ('sperreeld',),
'sperreelden': ('sperreeld',),
'sperreeldene': ('sperreeld',),
'sperreelder': ('sperreeld',),
'sperrefrist': ('sperrefrist',),
'sperrefristen': ('sperrefrist',),
'sperrefristene': ('sperrefrist',),
'sperrefrister': ('sperrefrist',),
'sperreild': ('sperreild',),
'sperreilden': ('sperreild',),
'sperreildene': ('sperreild',),
'sperreilder': ('sperreild',),
'sperreild': ('sperreild',),
'sperreilden': ('sperreild',),
'sperreildene': ('sperreild',),
'sperreilder': ('sperreild',),
'sperrekjede': ('sperrekjede',),
'sperrekjeden': ('sperrekjede',),
'sperrekjedene': ('sperrekjede',),
'sperrekjeder': ('sperrekjede',),
'sperretak': ('sperretak',),
'sperretaka': ('sperretak',),
'sperretakene': ('sperretak',),
'sperretaket': ('sperretak',),
'sperreverk': ('sperreverk',),
'sperreverka': ('sperreverk',),
'sperreverkene': ('sperreverk',),
'sperreverker': ('sperreverk',),
'sperreverket': ('sperreverk',),
'sperring': ('sperring',),
'sperringa': ('sperring',),
'sperringen': ('sperring',),
'sperringene': ('sperring',),
'sperringer': ('sperring',),
'speseri': ('speseri',),
'speseria': ('speseri',),
'speseriene': ('speseri',),
'speserier': ('speseri',),
'speseriet': ('speseri',),
'spesialarbeider': ('spesialarbeider',),
'spesialarbeidere': ('spesialarbeider',),
'spesialarbeideren': ('spesialarbeider',),
'spesialarbeiderer': ('spesialarbeider',),
'spesialarbeiderne': ('spesialarbeider',),
'spesialdistanse': ('spesialdistanse',),
'spesialdistansen': ('spesialdistanse',),
'spesialdistansene': ('spesialdistanse',),
'spesialdistanser': ('spesialdistanse',),
'spesiala': ('spesiale',),
'spesiale': ('spesiale',),
'spesialene': ('spesiale',),
'spesialer': ('spesiale',),
'spesialet': ('spesiale',),
'spesialist': ('spesialist',),
'spesialisten': ('spesialist',),
'spesialistene': ('spesialist',),
'spesialister': ('spesialist',),
'spesialitet': ('spesialitet',),
'spesialiteten': ('spesialitet',),
'spesialitetene': ('spesialitet',),
'spesialiteter': ('spesialitet',),
'spesiallærer': ('spesiallærer',),
'spesiallærere': ('spesiallærer',),
'spesiallæreren': ('spesiallærer',),
'spesiallærerer': ('spesiallærer',),
'spesiallærerne': ('spesiallærer',),
'spesialløp': ('spesialløp',),
'spesialløpa': ('spesialløp',),
'spesialløpene': ('spesialløp',),
'spesialløpet': ('spesialløp',),
'spesialordbok': ('spesialordbok',),
'spesialordboka': ('spesialordbok',),
'spesialordboken': ('spesialordbok',),
'spesialordbøkene': ('spesialordbok',),
'spesialordbøker': ('spesialordbok',),
'spesialpedagog': ('spesialpedagog',),
'spesialpedagogen': ('spesialpedagog',),
'spesialpedagogene': ('spesialpedagog',),
'spesialpedagoger': ('spesialpedagog',),
'spesialprevensjon': ('spesialprevensjon',),
'spesialprevensjonen': ('spesialprevensjon',),
'spesialprevensjonene': ('spesialprevensjon',),
'spesialprevensjoner': ('spesialprevensjon',),
'spesialrom': ('spesialrom',),
'spesialromma': ('spesialrom',),
'spesialrommene': ('spesialrom',),
'spesialrommet': ('spesialrom',),
'spesialskole': ('spesialskole',),
'spesialskolen': ('spesialskole',),
'spesialskolene': ('spesialskole',),
'spesialskoler': ('spesialskole',),
'spesialundervisning': ('spesialundervisning',),
'spesialundervisninga': ('spesialundervisning',),
'spesialundervisningen': ('spesialundervisning',),
'spesialundervisningene': ('spesialundervisning',),
'spesialundervisninger': ('spesialundervisning',),
'spesialøvelse': ('spesialøvelse',),
'spesialøvelsen': ('spesialøvelse',),
'spesialøvelsene': ('spesialøvelse',),
'spesialøvelser': ('spesialøvelse',),
'spesialøving': ('spesialøving',),
'spesialøvinga': ('spesialøving',),
'spesialøvingen': ('spesialøving',),
'spesialøvingene': ('spesialøving',),
'spesialøvinger': ('spesialøving',),
'spesidaler': ('spesidaler',),
'spesidalere': ('spesidaler',),
'spesidaleren': ('spesidaler',),
'spesidalerer': ('spesidaler',),
'spesidalerne': ('spesidaler',),
'spesies': ('spesies',),
'spesiesa': ('spesies',),
'spesiesen': ('spesies',),
'spesiesene': ('spesies',),
'spesieset': ('spesies',),
'spesifikasjon': ('spesifikasjon',),
'spesifikasjonen': ('spesifikasjon',),
'spesifikasjonene': ('spesifikasjon',),
'spesifikasjoner': ('spesifikasjon',),
'spesifisitet': ('spesifisitet',),
'spesifisiteten': ('spesifisitet',),
'spesifisitetene': ('spesifisitet',),
'spesifisiteter': ('spesifisitet',),
'spetakkel': ('spetakkel',),
'spetakkelet': ('spetakkel',),
'spetakla': ('spetakkel',),
'spetaklene': ('spetakkel',),
'spetakler': ('spetakkel',),
'spetaklet': ('spetakkel',),
'spett': ('spett',),
'spetten': ('spett',),
'spettene': ('spett',),
'spetter': ('spett',),
'spett': ('spett',),
'spetta': ('spett',),
'spettene': ('spett',),
'spettet': ('spett',),
'spette': ('spette',),
'spetten': ('spette',),
'spettene': ('spette',),
'spetter': ('spette',),
'spetta': ('spette',),
'spette': ('spette',),
'spetten': ('spette',),
'spettene': ('spette',),
'spetter': ('spette',),
'spetta': ('spette',),
'spette': ('spette',),
'spetten': ('spette',),
'spettene': ('spette',),
'spetter': ('spette',),
'spettefugl': ('spettefugl',),
'spettefuglen': ('spettefugl',),
'spettefuglene': ('spettefugl',),
'spettefugler': ('spettefugl',),
'spettmeis': ('spettmeis',),
'spettmeisa': ('spettmeis',),
'spettmeisen': ('spettmeis',),
'spettmeisene': ('spettmeis',),
'spettmeiser': ('spettmeis',),
'spidd': ('spidd',),
'spidda': ('spidd',),
'spiddene': ('spidd',),
'spiddet': ('spidd',),
'spik': ('spik',),
'spika': ('spik',),
'spiken': ('spik',),
'spikene': ('spik',),
'spiker': ('spik',),
'spiker': ('spiker',),
'spikere': ('spiker',),
'spikeren': ('spiker',),
'spikerne': ('spiker',),
'spikre': ('spiker',),
'spikrene': ('spiker',),
'spikrer': ('spiker',),
'spikermatta': ('spikermatte',),
'spikermatte': ('spikermatte',),
'spikermatten': ('spikermatte',),
'spikermattene': ('spikermatte',),
'spikermatter': ('spikermatte',),
'spikerslag': ('spikerslag',),
'spikerslaga': ('spikerslag',),
'spikerslagene': ('spikerslag',),
'spikerslaget': ('spikerslag',),
'spikkefjel': ('spikkefjel',),
'spikkefjela': ('spikkefjel',),
'spikkefjelen': ('spikkefjel',),
'spikkefjelene': ('spikkefjel',),
'spikkefjeler': ('spikkefjel',),
'spikkefjøl': ('spikkefjøl',),
'spikkefjøla': ('spikkefjøl',),
'spikkefjølen': ('spikkefjøl',),
'spikkefjølene': ('spikkefjøl',),
'spikkefjøler': ('spikkefjøl',),
'spil': ('spil',),
'spila': ('spil',),
'spilen': ('spil',),
'spilene': ('spil',),
'spiler': ('spil',),
'spil': ('spil',),
'spila': ('spil',),
'spilen': ('spil',),
'spilene': ('spil',),
'spiler': ('spil',),
'spildra': ('spildre',),
'spildre': ('spildre',),
'spildren': ('spildre',),
'spildrene': ('spildre',),
'spildrer': ('spildre',),
'spila': ('spile',),
'spile': ('spile',),
'spilen': ('spile',),
'spilene': ('spile',),
'spiler': ('spile',),
'spila': ('spile',),
'spile': ('spile',),
'spilen': ('spile',),
'spilene': ('spile',),
'spiler': ('spile',),
'spilkum': ('spilkum',),
'spilkummen': ('spilkum',),
'spilkummene': ('spilkum',),
'spilkummer': ('spilkum',),
'spill': ('spill',),
'spilla': ('spill',),
'spillene': ('spill',),
'spillet': ('spill',),
'spill': ('spill',),
'spilla': ('spill',),
'spillene': ('spill',),
'spillet': ('spill',),
'spill': ('spill',),
'spilla': ('spill',),
'spillene': ('spill',),
'spillet': ('spill',),
'spille': ('spille',),
'spilleautomat': ('spilleautomat',),
'spilleautomaten': ('spilleautomat',),
'spilleautomatene': ('spilleautomat',),
'spilleautomater': ('spilleautomat',),
'spillebank': ('spillebank',),
'spillebanken': ('spillebank',),
'spillebankene': ('spillebank',),
'spillebanker': ('spillebank',),
'spillebula': ('spillebule',),
'spillebule': ('spillebule',),
'spillebulen': ('spillebule',),
'spillebulene': ('spillebule',),
'spillebuler': ('spillebule',),
'spilledåsa': ('spilledåse',),
'spilledåse': ('spilledåse',),
'spilledåsen': ('spilledåse',),
'spilledåsene': ('spilledåse',),
'spilledåser': ('spilledåse',),
'spillefilm': ('spillefilm',),
'spillefilmen': ('spillefilm',),
'spillefilmene': ('spillefilm',),
'spillefilmer': ('spillefilm',),
'spillegalskap': ('spillegalskap',),
'spillegalskapen': ('spillegalskap',),
'spillegalskapene': ('spillegalskap',),
'spillegalskaper': ('spillegalskap',),
'spillelykka': ('spillelykke',),
'spillelykke': ('spillelykke',),
'spillelykken': ('spillelykke',),
'spillelykkene': ('spillelykke',),
'spillelykker': ('spillelykke',),
'spillelærer': ('spillelærer',),
'spillelærere': ('spillelærer',),
'spillelæreren': ('spillelærer',),
'spillelærerer': ('spillelærer',),
'spillelærerne': ('spillelærer',),
'spillemann': ('spillemann',),
'spillemannen': ('spillemann',),
'spillemenn': ('spillemann',),
'spillemennene': ('spillemann',),
'spillemannslag': ('spillemannslag',),
'spillemannslaga': ('spillemannslag',),
'spillemannslagene': ('spillemannslag',),
'spillemannslaget': ('spillemannslag',),
'spillemerka': ('spillemerke',),
'spillemerke': ('spillemerke',),
'spillemerkene': ('spillemerke',),
'spillemerker': ('spillemerke',),
'spillemerket': ('spillemerke',),
'spilleomgang': ('spilleomgang',),
'spilleomgangen': ('spilleomgang',),
'spilleomgangene': ('spilleomgang',),
'spilleomganger': ('spilleomgang',),
'spilleplan': ('spilleplan',),
'spilleplanen': ('spilleplan',),
'spilleplanene': ('spilleplan',),
'spilleplaner': ('spilleplan',),
'spiller': ('spiller',),
'spillere': ('spiller',),
'spilleren': ('spiller',),
'spillerer': ('spiller',),
'spillerne': ('spiller',),
'spilleregel': ('spilleregel',),
'spilleregelen': ('spilleregel',),
'spillereglene': ('spilleregel',),
'spilleregler': ('spilleregel',),
'spillerom': ('spillerom',),
'spilleromma': ('spillerom',),
'spillerommene': ('spillerom',),
'spillerommet': ('spillerom',),
'spillesesong': ('spillesesong',),
'spillesesongen': ('spillesesong',),
'spillesesongene': ('spillesesong',),
'spillesesonger': ('spillesesong',),
'spillestil': ('spillestil',),
'spillestilen': ('spillestil',),
'spillestilene': ('spillestil',),
'spillestiler': ('spillestil',),
'spilletime': ('spilletime',),
'spilletimen': ('spilletime',),
'spilletimene': ('spilletime',),
'spilletimer': ('spilletime',),
'spillfekteri': ('spillfekteri',),
'spillfekteria': ('spillfekteri',),
'spillfekteriene': ('spillfekteri',),
'spillfekterier': ('spillfekteri',),
'spillfekteriet': ('spillfekteri',),
'spillfugl': ('spillfugl',),
'spillfuglen': ('spillfugl',),
'spillfuglene': ('spillfugl',),
'spillfugler': ('spillfugl',),
'spilljakt': ('spilljakt',),
'spilljakta': ('spilljakt',),
'spilljakten': ('spilljakt',),
'spilljaktene': ('spilljakt',),
'spilljakter': ('spilljakt',),
'spillkort': ('spillkort',),
'spillkorta': ('spillkort',),
'spillkortene': ('spillkort',),
'spillkortet': ('spillkort',),
'spillkraft': ('spillkraft',),
'spillkrafta': ('spillkraft',),
'spillkraften': ('spillkraft',),
'spillkreftene': ('spillkraft',),
'spillkrefter': ('spillkraft',),
'spillolja': ('spillolje',),
'spillolje': ('spillolje',),
'spilloljen': ('spillolje',),
'spilloljene': ('spillolje',),
'spilloljer': ('spillolje',),
'spilloppene': ('spillopper',),
'spillopper': ('spillopper',),
'spilloppmaker': ('spilloppmaker',),
'spilloppmakere': ('spilloppmaker',),
'spilloppmakeren': ('spilloppmaker',),
'spilloppmakerer': ('spilloppmaker',),
'spilloppmakerne': ('spilloppmaker',),
'spillvann': ('spillvann',),
'spillvanna': ('spillvann',),
'spillvannene': ('spillvann',),
'spillvannet': ('spillvann',),
'spillvatn': ('spillvatn',),
'spillvatna': ('spillvatn',),
'spillvatnene': ('spillvatn',),
'spillvatnet': ('spillvatn',),
'spiltau': ('spiltau',),
'spiltaua': ('spiltau',),
'spiltauene': ('spiltau',),
'spiltauet': ('spiltau',),
'spinalbedøvelse': ('spinalbedøvelse',),
'spinalbedøvelsen': ('spinalbedøvelse',),
'spinalbedøvelsene': ('spinalbedøvelse',),
'spinalbedøvelser': ('spinalbedøvelse',),
'spinalpunksjon': ('spinalpunksjon',),
'spinalpunksjonen': ('spinalpunksjon',),
'spinalpunksjonene': ('spinalpunksjon',),
'spinalpunksjoner': ('spinalpunksjon',),
'spinat': ('spinat',),
'spinaten': ('spinat',),
'spinatene': ('spinat',),
'spinater': ('spinat',),
'spinatsuppa': ('spinatsuppe',),
'spinatsuppe': ('spinatsuppe',),
'spinatsuppen': ('spinatsuppe',),
'spinatsuppene': ('spinatsuppe',),
'spinatsupper': ('spinatsuppe',),
'spindel': ('spindel',),
'spindelen': ('spindel',),
'spindlene': ('spindel',),
'spindler': ('spindel',),
'spindelvev': ('spindelvev',),
'spindelveva': ('spindelvev',),
'spindelveven': ('spindelvev',),
'spindelvevene': ('spindelvev',),
'spindelvever': ('spindelvev',),
'spindelvevet': ('spindelvev',),
'spinett': ('spinett',),
'spinetta': ('spinett',),
'spinettene': ('spinett',),
'spinetter': ('spinett',),
'spinettet': ('spinett',),
'spinn': ('spinn',),
'spinna': ('spinn',),
'spinnene': ('spinn',),
'spinnet': ('spinn',),
'spinnaker': ('spinnaker',),
'spinnakere': ('spinnaker',),
'spinnakeren': ('spinnaker',),
'spinnakerer': ('spinnaker',),
'spinnakerne': ('spinnaker',),
'spinnemaskin': ('spinnemaskin',),
'spinnemaskina': ('spinnemaskin',),
'spinnemaskinen': ('spinnemaskin',),
'spinnemaskinene': ('spinnemaskin',),
'spinnemaskiner': ('spinnemaskin',),
'spinner': ('spinner',),
'spinnere': ('spinner',),
'spinneren': ('spinner',),
'spinnerer': ('spinner',),
'spinnerne': ('spinner',),
'spinneri': ('spinneri',),
'spinneria': ('spinneri',),
'spinneriene': ('spinneri',),
'spinnerier': ('spinneri',),
'spinneriet': ('spinneri',),
'spinnesida': ('spinneside',),
'spinneside': ('spinneside',),
'spinnesiden': ('spinneside',),
'spinnesidene': ('spinneside',),
'spinnesider': ('spinneside',),
'spinning': ('spinning',),
'spinninga': ('spinning',),
'spinningen': ('spinning',),
'spinningene': ('spinning',),
'spinninger': ('spinning',),
'spinnmøll': ('spinnmøll',),
'spinnmølla': ('spinnmøll',),
'spinnmøllen': ('spinnmøll',),
'spinnmøllene': ('spinnmøll',),
'spinnmøllet': ('spinnmøll',),
'spion': ('spion',),
'spionen': ('spion',),
'spionene': ('spion',),
'spioner': ('spion',),
'spionasje': ('spionasje',),
'spionasjen': ('spionasje',),
'spionasjene': ('spionasje',),
'spionasjer': ('spionasje',),
'spionsatellitt': ('spionsatellitt',),
'spionsatellitten': ('spionsatellitt',),
'spionsatellittene': ('spionsatellitt',),
'spionsatellitter': ('spionsatellitt',),
'spir': ('spir',),
'spiren': ('spir',),
'spirene': ('spir',),
'spirer': ('spir',),
'spir': ('spir',),
'spira': ('spir',),
'spirene': ('spir',),
'spiret': ('spir',),
'spiral': ('spiral',),
'spiralen': ('spiral',),
'spiralene': ('spiral',),
'spiraler': ('spiral',),
'spiralmadrass': ('spiralmadrass',),
'spiralmadrassen': ('spiralmadrass',),
'spiralmadrassene': ('spiralmadrass',),
'spiralmadrasser': ('spiralmadrass',),
'spiraltåka': ('spiraltåke',),
'spiraltåke': ('spiraltåke',),
'spiraltåken': ('spiraltåke',),
'spiraltåkene': ('spiraltåke',),
'spiraltåker': ('spiraltåke',),
'spirant': ('spirant',),
'spiranten': ('spirant',),
'spirantene': ('spirant',),
'spiranter': ('spirant',),
'spira': ('spire',),
'spire': ('spire',),
'spiren': ('spire',),
'spirene': ('spire',),
'spirer': ('spire',),
'spirea': ('spirea',),
'spireaen': ('spirea',),
'spireaene': ('spirea',),
'spireaer': ('spirea',),
'spireevna': ('spireevne',),
'spireevne': ('spireevne',),
'spireevnen': ('spireevne',),
'spireevnene': ('spireevne',),
'spireevner': ('spireevne',),
'spirit': ('spirit',),
'spiriten': ('spirit',),
'spiritene': ('spirit',),
'spiriter': ('spirit',),
'spiritisme': ('spiritisme',),
'spiritismen': ('spiritisme',),
'spiritismene': ('spiritisme',),
'spiritismer': ('spiritisme',),
'spiritist': ('spiritist',),
'spiritisten': ('spiritist',),
'spiritistene': ('spiritist',),
'spiritister': ('spiritist',),
'spiritual': ('spiritual',),
'spiritualen': ('spiritual',),
'spiritualene': ('spiritual',),
'spirituals': ('spiritual',),
'spiritualisme': ('spiritualisme',),
'spiritualismen': ('spiritualisme',),
'spiritualismene': ('spiritualisme',),
'spiritualismer': ('spiritualisme',),
'spiritualist': ('spiritualist',),
'spiritualisten': ('spiritualist',),
'spiritualistene': ('spiritualist',),
'spiritualister': ('spiritualist',),
'spiritualitet': ('spiritualitet',),
'spiritualiteten': ('spiritualitet',),
'spiritualitetene': ('spiritualitet',),
'spiritualiteter': ('spiritualitet',),
'spirituosa': ('spirituosa',),
'spirituosaen': ('spirituosa',),
'spirituosaene': ('spirituosa',),
'spirituosaer': ('spirituosa',),
'spiritus': ('spiritus',),
'spiritusen': ('spiritus',),
'spiritusene': ('spiritus',),
'spirituser': ('spiritus',),
'spirometer': ('spirometer',),
'spirometeret': ('spirometer',),
'spirometra': ('spirometer',),
'spirometre': ('spirometer',),
'spirometrene': ('spirometer',),
'spirometret': ('spirometer',),
'spirrevipp': ('spirrevipp',),
'spirrevippen': ('spirrevipp',),
'spirrevippene': ('spirrevipp',),
'spirrevipper': ('spirrevipp',),
'spis': ('spis',),
'spisen': ('spis',),
'spisene': ('spis',),
'spiser': ('spis',),
'spise': ('spise',),
'spisen': ('spise',),
'spisene': ('spise',),
'spiser': ('spise',),
'spisebestikk': ('spisebestikk',),
'spisebestikka': ('spisebestikk',),
'spisebestikkene': ('spisebestikk',),
'spisebestikket': ('spisebestikk',),
'spisekart': ('spisekart',),
'spisekarta': ('spisekart',),
'spisekartene': ('spisekart',),
'spisekarter': ('spisekart',),
'spisekartet': ('spisekart',),
'spisekrok': ('spisekrok',),
'spisekroken': ('spisekrok',),
'spisekrokene': ('spisekrok',),
'spisekroker': ('spisekrok',),
'spiseplikt': ('spiseplikt',),
'spiseplikta': ('spiseplikt',),
'spiseplikten': ('spiseplikt',),
'spisepliktene': ('spiseplikt',),
'spiseplikter': ('spiseplikt',),
'spiserør': ('spiserør',),
'spiserøra': ('spiserør',),
'spiserørene': ('spiserør',),
'spiserøret': ('spiserør',),
'spisesal': ('spisesal',),
'spisesalen': ('spisesal',),
'spisesalene': ('spisesal',),
'spisesaler': ('spisesal',),
'spiseseddel': ('spiseseddel',),
'spiseseddelen': ('spiseseddel',),
'spiseseddlene': ('spiseseddel',),
'spiseseddler': ('spiseseddel',),
'spiseskei': ('spiseskei',),
'spiseskeia': ('spiseskei',),
'spiseskeien': ('spiseskei',),
'spiseskeiene': ('spiseskei',),
'spiseskeier': ('spiseskei',),
'spiseskje': ('spiseskje',),
'spiseskjea': ('spiseskje',),
'spiseskjeen': ('spiseskje',),
'spiseskjeene': ('spiseskje',),
'spiseskjeer': ('spiseskje',),
'spisested': ('spisested',),
'spisestedene': ('spisested',),
'spisesteder': ('spisested',),
'spisestedet': ('spisested',),
'spisestova': ('spisestove',),
'spisestove': ('spisestove',),
'spisestoven': ('spisestove',),
'spisestovene': ('spisestove',),
'spisestover': ('spisestove',),
'spisestua': ('spisestue',),
'spisestue': ('spisestue',),
'spisestuen': ('spisestue',),
'spisestuene': ('spisestue',),
'spisestuer': ('spisestue',),
'spisevegring': ('spisevegring',),
'spisevegringa': ('spisevegring',),
'spisevegringen': ('spisevegring',),
'spisevegringene': ('spisevegring',),
'spisevegringer': ('spisevegring',),
'spisevogn': ('spisevogn',),
'spisevogna': ('spisevogn',),
'spisevognen': ('spisevogn',),
'spisevognene': ('spisevogn',),
'spisevogner': ('spisevogn',),
'spising': ('spising',),
'spisinga': ('spising',),
'spisingen': ('spising',),
'spisingene': ('spising',),
'spisinger': ('spising',),
'spiskammer': ('spiskammer',),
'spiskammeret': ('spiskammer',),
'spiskamra': ('spiskammer',),
'spiskamre': ('spiskammer',),
'spiskamrene': ('spiskammer',),
'spisning': ('spisning',),
'spisninga': ('spisning',),
'spisningen': ('spisning',),
'spisningene': ('spisning',),
'spisninger': ('spisning',),
'spiss': ('spiss',),
'spissen': ('spiss',),
'spissene': ('spiss',),
'spisser': ('spiss',),
'spiss-slede': ('spiss-slede',),
'spiss-sleden': ('spiss-slede',),
'spiss-sledene': ('spiss-slede',),
'spiss-sleder': ('spiss-slede',),
'spissartikkel': ('spissartikkel',),
'spissartikkelen': ('spissartikkel',),
'spissartiklene': ('spissartikkel',),
'spissartikler': ('spissartikkel',),
'spissboge': ('spissboge',),
'spissbogen': ('spissboge',),
'spissbogene': ('spissboge',),
'spissboger': ('spissboge',),
'spissbogestil': ('spissbogestil',),
'spissbogestilen': ('spissbogestil',),
'spissbogestilene': ('spissbogestil',),
'spissbogestiler': ('spissbogestil',),
'spissborger': ('spissborger',),
'spissborgere': ('spissborger',),
'spissborgeren': ('spissborger',),
'spissborgerer': ('spissborger',),
'spissborgerne': ('spissborger',),
'spissbue': ('spissbue',),
'spissbuen': ('spissbue',),
'spissbuene': ('spissbue',),
'spissbuer': ('spissbue',),
'spissbuestil': ('spissbuestil',),
'spissbuestilen': ('spissbuestil',),
'spissbuestilene': ('spissbuestil',),
'spissbuestiler': ('spissbuestil',),
'spisser': ('spisser',),
'spissere': ('spisser',),
'spisseren': ('spisser',),
'spisserer': ('spisser',),
'spisserne': ('spisser',),
'spissfindighet': ('spissfindighet',),
'spissfindigheta': ('spissfindighet',),
'spissfindigheten': ('spissfindighet',),
'spissfindighetene': ('spissfindighet',),
'spissfindigheter': ('spissfindighet',),
'spissformulering': ('spissformulering',),
'spissformuleringa': ('spissformulering',),
'spissformuleringen': ('spissformulering',),
'spissformuleringene': ('spissformulering',),
'spissformuleringer': ('spissformulering',),
'spissgatter': ('spissgatter',),
'spissgattere': ('spissgatter',),
'spissgatteren': ('spissgatter',),
'spissgatterer': ('spissgatter',),
'spissgatterne': ('spissgatter',),
'spisshund': ('spisshund',),
'spisshunden': ('spisshund',),
'spisshundene': ('spisshund',),
'spisshunder': ('spisshund',),
'spisskarve': ('spisskarve',),
'spisskarven': ('spisskarve',),
'spisskarvene': ('spisskarve',),
'spisskarver': ('spisskarve',),
'spisskompetanse': ('spisskompetanse',),
'spisskompetansen': ('spisskompetanse',),
'spisskompetansene': ('spisskompetanse',),
'spisskompetanser': ('spisskompetanse',),
'spisskum': ('spisskum',),
'spisskummen': ('spisskum',),
'spisskummene': ('spisskum',),
'spisskummer': ('spisskum',),
'spisskål': ('spisskål',),
'spisskålen': ('spisskål',),
'spisskålene': ('spisskål',),
'spisskåler': ('spisskål',),
'spisslede': ('spisslede',),
'spissleden': ('spisslede',),
'spissledene': ('spisslede',),
'spissleder': ('spisslede',),
'spissmus': ('spissmus',),
'spissmusa': ('spissmus',),
'spissmusen': ('spissmus',),
'spissmusene': ('spissmus',),
'spissrot': ('spissrot',),
'spitord': ('spitord',),
'spitorda': ('spitord',),
'spitordene': ('spitord',),
'spitordet': ('spitord',),
'spjeld': ('spjeld',),
'spjelda': ('spjeld',),
'spjeldene': ('spjeld',),
'spjeldet': ('spjeld',),
'spjelk': ('spjelk',),
'spjelken': ('spjelk',),
'spjelkene': ('spjelk',),
'spjelker': ('spjelk',),
'spjert': ('spjert',),
'spjerten': ('spjert',),
'spjertene': ('spjert',),
'spjerter': ('spjert',),
'spjæling': ('spjæling',),
'spjælingen': ('spjæling',),
'spjælingene': ('spjæling',),
'spjælinger': ('spjæling',),
'spleen': ('spleen',),
'spleenen': ('spleen',),
'spleenene': ('spleen',),
'spleener': ('spleen',),
'spleis': ('spleis',),
'spleisen': ('spleis',),
'spleisene': ('spleis',),
'spleiser': ('spleis',),
'spleiselag': ('spleiselag',),
'spleiselaga': ('spleiselag',),
'spleiselagene': ('spleiselag',),
'spleiselaget': ('spleiselag',),
'splid': ('splid',),
'spliden': ('splid',),
'splidene': ('splid',),
'splider': ('splid',),
'splintbomba': ('splintbombe',),
'splintbombe': ('splintbombe',),
'splintbomben': ('splintbombe',),
'splintbombene': ('splintbombe',),
'splintbomber': ('splintbombe',),
'splitt': ('splitt',),
'splitten': ('splitt',),
'splittene': ('splitt',),
'splitter': ('splitt',),
'splittelse': ('splittelse',),
'splittelsen': ('splittelse',),
'splittelsene': ('splittelse',),
'splittelser': ('splittelse',),
'splittethet': ('splittethet',),
'splittetheta': ('splittethet',),
'splittetheten': ('splittethet',),
'splittethetene': ('splittethet',),
'splittetheter': ('splittethet',),
'splittflagg': ('splittflagg',),
'splittflagga': ('splittflagg',),
'splittflaggene': ('splittflagg',),
'splittflagget': ('splittflagg',),
'splitthopp': ('splitthopp',),
'splitthoppa': ('splitthopp',),
'splitthoppene': ('splitthopp',),
'splitthoppet': ('splitthopp',),
'splittkein': ('splittkein',),
'splittkeinen': ('splittkein',),
'splittkeinene': ('splittkein',),
'splittkeiner': ('splittkein',),
'splittkeinski': ('splittkeinski',),
'splittkeinskia': ('splittkeinski',),
'splittkeinskien': ('splittkeinski',),
'splittkeinskiene': ('splittkeinski',),
'splittkeinskier': ('splittkeinski',),
'splittnagle': ('splittnagle',),
'splittnaglen': ('splittnagle',),
'splittnaglene': ('splittnagle',),
'splittnagler': ('splittnagle',),
'spoiler': ('spoiler',),
'spoilere': ('spoiler',),
'spoileren': ('spoiler',),
'spoilerer': ('spoiler',),
'spoilerne': ('spoiler',),
'spole': ('spole',),
'spolen': ('spole',),
'spolene': ('spole',),
'spoler': ('spole',),
'spolebein': ('spolebein',),
'spolebeina': ('spolebein',),
'spolebeinene': ('spolebein',),
'spolebeinet': ('spolebein',),
'spoleben': ('spoleben',),
'spolebena': ('spoleben',),
'spolebenene': ('spoleben',),
'spolebenet': ('spoleben',),
'spolorm': ('spolorm',),
'spolormen': ('spolorm',),
'spolormene': ('spolorm',),
'spolormer': ('spolorm',),
'spon': ('spon',),
'sponen': ('spon',),
'sponene': ('spon',),
'sponer': ('spon',),
'spondeen': ('spondé',),
'spondeene': ('spondé',),
'spondeer': ('spondé',),
'spondé': ('spondé',),
'spondéen': ('spondé',),
'spondéene': ('spondé',),
'spondéer': ('spondé',),
'sponplata': ('sponplate',),
'sponplate': ('sponplate',),
'sponplaten': ('sponplate',),
'sponplatene': ('sponplate',),
'sponplater': ('sponplate',),
'sponsor': ('sponsor',),
'sponsoren': ('sponsor',),
'sponsorene': ('sponsor',),
'sponsorer': ('sponsor',),
'spontak': ('spontak',),
'spontaka': ('spontak',),
'spontakene': ('spontak',),
'spontaket': ('spontak',),
'spontanisme': ('spontanisme',),
'spontanismen': ('spontanisme',),
'spontanismene': ('spontanisme',),
'spontanismer': ('spontanisme',),
'spontanitet': ('spontanitet',),
'spontaniteten': ('spontanitet',),
'spontanitetene': ('spontanitet',),
'spontaniteter': ('spontanitet',),
'spor': ('spor',),
'spora': ('spor',),
'sporene': ('spor',),
'sporet': ('spor',),
'sporbredde': ('sporbredde',),
'sporbredden': ('sporbredde',),
'sporbreddene': ('sporbredde',),
'sporbredder': ('sporbredde',),
'sporbreidd': ('sporbreidd',),
'sporbreidda': ('sporbreidd',),
'sporbreidden': ('sporbreidd',),
'sporbreiddene': ('sporbreidd',),
'sporbreidder': ('sporbreidd',),
'spord': ('spord',),
'sporden': ('spord',),
'spordene': ('spord',),
'sporder': ('spord',),
'spore': ('spore',),
'sporen': ('spore',),
'sporene': ('spore',),
'sporer': ('spore',),
'spore': ('spore',),
'sporen': ('spore',),
'sporene': ('spore',),
'sporer': ('spore',),
'sporehus': ('sporehus',),
'sporehusa': ('sporehus',),
'sporehusene': ('sporehus',),
'sporehuset': ('sporehus',),
'sporeplanta': ('sporeplante',),
'sporeplante': ('sporeplante',),
'sporeplanten': ('sporeplante',),
'sporeplantene': ('sporeplante',),
'sporeplanter': ('sporeplante',),
'sporhund': ('sporhund',),
'sporhunden': ('sporhund',),
'sporhundene': ('sporhund',),
'sporhunder': ('sporhund',),
'sporlys': ('sporlys',),
'sporlysa': ('sporlys',),
'sporlysene': ('sporlys',),
'sporlyset': ('sporlys',),
'sporrenser': ('sporrenser',),
'sporrensere': ('sporrenser',),
'sporrenseren': ('sporrenser',),
'sporrenserer': ('sporrenser',),
'sporrenserne': ('sporrenser',),
'sporsans': ('sporsans',),
'sporsansen': ('sporsans',),
'sporsansene': ('sporsans',),
'sporsanser': ('sporsans',),
'sporskifter': ('sporskifter',),
'sporskiftere': ('sporskifter',),
'sporskifteren': ('sporskifter',),
'sporskifterer': ('sporskifter',),
'sporskifterne': ('sporskifter',),
'sporsløyfa': ('sporsløyfe',),
'sporsløyfe': ('sporsløyfe',),
'sporsløyfen': ('sporsløyfe',),
'sporsløyfene': ('sporsløyfe',),
'sporsløyfer': ('sporsløyfe',),
'sporsnø': ('sporsnø',),
'sporsnøen': ('sporsnø',),
'sporsnøene': ('sporsnø',),
'sporsnøer': ('sporsnø',),
'sporstoff': ('sporstoff',),
'sporstoffa': ('sporstoff',),
'sporstoffene': ('sporstoff',),
'sporstoffer': ('sporstoff',),
'sporstoffet': ('sporstoff',),
'sport': ('sport',),
'sporten': ('sport',),
'sportene': ('sport',),
'sporter': ('sport',),
'sportel': ('sportel',),
'sportelen': ('sportel',),
'sportlene': ('sportel',),
'sportler': ('sportel',),
'sportell': ('sportell',),
'sportella': ('sportell',),
'sportellene': ('sportell',),
'sporteller': ('sportell',),
'sportellet': ('sportell',),
'sportsantrekk': ('sportsantrekk',),
'sportsantrekka': ('sportsantrekk',),
'sportsantrekkene': ('sportsantrekk',),
'sportsantrekket': ('sportsantrekk',),
'sportsbil': ('sportsbil',),
'sportsbilen': ('sportsbil',),
'sportsbilene': ('sportsbil',),
'sportsbiler': ('sportsbil',),
'sportsdans': ('sportsdans',),
'sportsdansen': ('sportsdans',),
'sportsdansene': ('sportsdans',),
'sportsdanser': ('sportsdans',),
'sportsfiska': ('sportsfiske',),
'sportsfiske': ('sportsfiske',),
'sportsfiskene': ('sportsfiske',),
'sportsfisker': ('sportsfiske',),
'sportsfisket': ('sportsfiske',),
'sportsfisker': ('sportsfisker',),
'sportsfiskere': ('sportsfisker',),
'sportsfiskeren': ('sportsfisker',),
'sportsfiskerer': ('sportsfisker',),
'sportsfiskerne': ('sportsfisker',),
'sportsfly': ('sportsfly',),
'sportsflya': ('sportsfly',),
'sportsflyene': ('sportsfly',),
'sportsflyet': ('sportsfly',),
'sportsfolk': ('sportsfolk',),
'sportsfolka': ('sportsfolk',),
'sportsfolkene': ('sportsfolk',),
'sportsfolket': ('sportsfolk',),
'sportsforretning': ('sportsforretning',),
'sportsforretninga': ('sportsforretning',),
'sportsforretningen': ('sportsforretning',),
'sportsforretningene': ('sportsforretning',),
'sportsforretninger': ('sportsforretning',),
'sportsidiot': ('sportsidiot',),
'sportsidioten': ('sportsidiot',),
'sportsidiotene': ('sportsidiot',),
'sportsidioter': ('sportsidiot',),
'sportsjournalist': ('sportsjournalist',),
'sportsjournalisten': ('sportsjournalist',),
'sportsjournalistene': ('sportsjournalist',),
'sportsjournalister': ('sportsjournalist',),
'sportsmann': ('sportsmann',),
'sportsmannen': ('sportsmann',),
'sportsmenn': ('sportsmann',),
'sportsmennene': ('sportsmann',),
'sportsredaktør': ('sportsredaktør',),
'sportsredaktøren': ('sportsredaktør',),
'sportsredaktørene': ('sportsredaktør',),
'sportsredaktører': ('sportsredaktør',),
'sportsreferat': ('sportsreferat',),
'sportsreferata': ('sportsreferat',),
'sportsreferatene': ('sportsreferat',),
'sportsreferater': ('sportsreferat',),
'sportsreferatet': ('sportsreferat',),
'sportsresultat': ('sportsresultat',),
'sportsresultata': ('sportsresultat',),
'sportsresultatene': ('sportsresultat',),
'sportsresultater': ('sportsresultat',),
'sportsresultatet': ('sportsresultat',),
'sportsstjerna': ('sportsstjerne',),
'sportsstjerne': ('sportsstjerne',),
'sportsstjernen': ('sportsstjerne',),
'sportsstjernene': ('sportsstjerne',),
'sportsstjerner': ('sportsstjerne',),
'sportsstrømpa': ('sportsstrømpe',),
'sportsstrømpe': ('sportsstrømpe',),
'sportsstrømpen': ('sportsstrømpe',),
'sportsstrømpene': ('sportsstrømpe',),
'sportsstrømper': ('sportsstrømpe',),
'sportsvogn': ('sportsvogn',),
'sportsvogna': ('sportsvogn',),
'sportsvognen': ('sportsvogn',),
'sportsvognene': ('sportsvogn',),
'sportsvogner': ('sportsvogn',),
'sportsånd': ('sportsånd',),
'sportsånden': ('sportsånd',),
'sportsåndene': ('sportsånd',),
'sportsånder': ('sportsånd',),
'sporveg': ('sporveg',),
'sporvegen': ('sporveg',),
'sporvegene': ('sporveg',),
'sporveger': ('sporveg',),
'sporvei': ('sporvei',),
'sporveien': ('sporvei',),
'sporveiene': ('sporvei',),
'sporveier': ('sporvei',),
'sporveksel': ('sporveksel',),
'sporvekselen': ('sporveksel',),
'sporvekslene': ('sporveksel',),
'sporveksler': ('sporveksel',),
'sporvidda': ('sporvidde',),
'sporvidde': ('sporvidde',),
'sporvidden': ('sporvidde',),
'sporviddene': ('sporvidde',),
'sporvidder': ('sporvidde',),
'sporvogn': ('sporvogn',),
'sporvogna': ('sporvogn',),
'sporvognen': ('sporvogn',),
'sporvognene': ('sporvogn',),
'sporvogner': ('sporvogn',),
'sporvognsbetjening': ('sporvognsbetjening',),
'sporvognsbetjeninga': ('sporvognsbetjening',),
'sporvognsbetjeningen': ('sporvognsbetjening',),
'sporvognsbetjeningene': ('sporvognsbetjening',),
'sporvognsbetjeninger': ('sporvognsbetjening',),
'spotlight': ('spotlight',),
'spotlighta': ('spotlight',),
'spotlighten': ('spotlight',),
'spotlightene': ('spotlight',),
'spotlighter': ('spotlight',),
'spotlightet': ('spotlight',),
'spotlys': ('spotlys',),
'spotlysa': ('spotlys',),
'spotlysene': ('spotlys',),
'spotlyset': ('spotlys',),
'spotmarked': ('spotmarked',),
'spotmarkeda': ('spotmarked',),
'spotmarkedene': ('spotmarked',),
'spotmarkeder': ('spotmarked',),
'spotmarkedet': ('spotmarked',),
'spott': ('spott',),
'spotten': ('spott',),
'spottene': ('spott',),
'spotter': ('spott',),
'spottegauk': ('spottegauk',),
'spottegauken': ('spottegauk',),
'spottegaukene': ('spottegauk',),
'spottegauker': ('spottegauk',),
'spotter': ('spotter',),
'spottere': ('spotter',),
'spotteren': ('spotter',),
'spotterer': ('spotter',),
'spotterne': ('spotter',),
'spottpris': ('spottpris',),
'spottprisen': ('spottpris',),
'spottprisene': ('spottpris',),
'spottpriser': ('spottpris',),
'spove': ('spove',),
'spoven': ('spove',),
'spovene': ('spove',),
'spover': ('spove',),
'sprade': ('sprade',),
'spraden': ('sprade',),
'spradene': ('sprade',),
'sprader': ('sprade',),
'spradebasse': ('spradebasse',),
'spradebassen': ('spradebasse',),
'spradebassene': ('spradebasse',),
'spradebasser': ('spradebasse',),
'sprak': ('sprak',),
'spraka': ('sprak',),
'sprakene': ('sprak',),
'spraket': ('sprak',),
'sprake': ('sprake',),
'spraken': ('sprake',),
'sprakene': ('sprake',),
'spraker': ('sprake',),
'sprang': ('sprang',),
'spranga': ('sprang',),
'sprangene': ('sprang',),
'spranget': ('sprang',),
'sprangridning': ('sprangridning',),
'sprangridninga': ('sprangridning',),
'sprangridningen': ('sprangridning',),
'sprangridningene': ('sprangridning',),
'sprangridninger': ('sprangridning',),
'spray': ('spray',),
'sprayen': ('spray',),
'sprayene': ('spray',),
'sprayer': ('spray',),
'sprayboks': ('sprayboks',),
'sprayboksen': ('sprayboks',),
'sprayboksene': ('sprayboks',),
'spraybokser': ('sprayboks',),
'sprayflaska': ('sprayflaske',),
'sprayflaske': ('sprayflaske',),
'sprayflasken': ('sprayflaske',),
'sprayflaskene': ('sprayflaske',),
'sprayflasker': ('sprayflaske',),
'spredelinsa': ('spredelinse',),
'spredelinse': ('spredelinse',),
'spredelinsen': ('spredelinse',),
'spredelinsene': ('spredelinse',),
'spredelinser': ('spredelinse',),
'spredelinsa': ('spredelinse',),
'spredelinse': ('spredelinse',),
'spredelinsen': ('spredelinse',),
'spredelinsene': ('spredelinse',),
'spredelinser': ('spredelinse',),
'spreder': ('spreder',),
'spredere': ('spreder',),
'sprederen': ('spreder',),
'sprederer': ('spreder',),
'sprederne': ('spreder',),
'spreder': ('spreder',),
'spredere': ('spreder',),
'sprederen': ('spreder',),
'sprederer': ('spreder',),
'sprederne': ('spreder',),
'spredning': ('spredning',),
'spredninga': ('spredning',),
'spredningen': ('spredning',),
'spredningene': ('spredning',),
'spredninger': ('spredning',),
'spreielinsa': ('spreielinse',),
'spreielinse': ('spreielinse',),
'spreielinsen': ('spreielinse',),
'spreielinsene': ('spreielinse',),
'spreielinser': ('spreielinse',),
'spreielinsa': ('spreielinse',),
'spreielinse': ('spreielinse',),
'spreielinsen': ('spreielinse',),
'spreielinsene': ('spreielinse',),
'spreielinser': ('spreielinse',),
'spreier': ('spreier',),
'spreiere': ('spreier',),
'spreieren': ('spreier',),
'spreierer': ('spreier',),
'spreierne': ('spreier',),
'spreier': ('spreier',),
'spreiere': ('spreier',),
'spreieren': ('spreier',),
'spreierer': ('spreier',),
'spreierne': ('spreier',),
'spreking': ('spreking',),
'sprekingen': ('spreking',),
'sprekingene': ('spreking',),
'sprekinger': ('spreking',),
'sprekk': ('sprekk',),
'sprekken': ('sprekk',),
'sprekkene': ('sprekk',),
'sprekker': ('sprekk',),
'sprekkdannelse': ('sprekkdannelse',),
'sprekkdannelsen': ('sprekkdannelse',),
'sprekkdannelsene': ('sprekkdannelse',),
'sprekkdannelser': ('sprekkdannelse',),
'sprekkdanning': ('sprekkdanning',),
'sprekkdanninga': ('sprekkdanning',),
'sprekkdanningen': ('sprekkdanning',),
'sprekkdanningene': ('sprekkdanning',),
'sprekkdanninger': ('sprekkdanning',),
'sprell': ('sprell',),
'sprella': ('sprell',),
'sprellene': ('sprell',),
'sprellet': ('sprell',),
'sprellemann': ('sprellemann',),
'sprellemannen': ('sprellemann',),
'sprellemenn': ('sprellemann',),
'sprellemennene': ('sprellemann',),
'spreng': ('spreng',),
'sprenga': ('spreng',),
'sprengen': ('spreng',),
'sprengene': ('spreng',),
'sprenger': ('spreng',),
'sprenget': ('spreng',),
'sprengkraft': ('sprengkraft',),
'sprengkrafta': ('sprengkraft',),
'sprengkraften': ('sprengkraft',),
'sprengkreftene': ('sprengkraft',),
'sprengkrefter': ('sprengkraft',),
'sprengkulda': ('sprengkulde',),
'sprengkulde': ('sprengkulde',),
'sprengkulden': ('sprengkulde',),
'sprengkuldene': ('sprengkulde',),
'sprengkulder': ('sprengkulde',),
'sprengladning': ('sprengladning',),
'sprengladninga': ('sprengladning',),
'sprengladningen': ('sprengladning',),
'sprengladningene': ('sprengladning',),
'sprengladninger': ('sprengladning',),
'sprengskiva': ('sprengskive',),
'sprengskive': ('sprengskive',),
'sprengskiven': ('sprengskive',),
'sprengskivene': ('sprengskive',),
'sprengskiver': ('sprengskive',),
'sprengstoff': ('sprengstoff',),
'sprengstoffa': ('sprengstoff',),
'sprengstoffene': ('sprengstoff',),
'sprengstoffer': ('sprengstoff',),
'sprengstoffet': ('sprengstoff',),
'sprettert': ('sprettert',),
'spretterten': ('sprettert',),
'sprettertene': ('sprettert',),
'spretterter': ('sprettert',),
'spretthale': ('spretthale',),
'spretthalen': ('spretthale',),
'spretthalene': ('spretthale',),
'spretthaler': ('spretthale',),
'spri': ('spri',),
'spria': ('spri',),
'spriene': ('spri',),
'spriet': ('spri',),
'sprik': ('sprik',),
'sprika': ('sprik',),
'spriken': ('sprik',),
'sprikene': ('sprik',),
'spriker': ('sprik',),
'spriket': ('sprik',),
'spring': ('spring',),
'springen': ('spring',),
'springene': ('spring',),
'springer': ('spring',),
'spring': ('spring',),
'springa': ('spring',),
'springene': ('spring',),
'springet': ('spring',),
'springar': ('springar',),
'springaren': ('springar',),
'springarene': ('springar',),
'springarer': ('springar',),
'springbrett': ('springbrett',),
'springbretta': ('springbrett',),
'springbrettene': ('springbrett',),
'springbretter': ('springbrett',),
'springbrettet': ('springbrett',),
'springdans': ('springdans',),
'springdansen': ('springdans',),
'springdansene': ('springdans',),
'springdanser': ('springdans',),
'springer': ('springer',),
'springere': ('springer',),
'springeren': ('springer',),
'springerer': ('springer',),
'springerne': ('springer',),
'springfjær': ('springfjær',),
'springfjæra': ('springfjær',),
'springfjæren': ('springfjær',),
'springfjærene': ('springfjær',),
'springfjærer': ('springfjær',),
'springfjør': ('springfjør',),
'springfjøra': ('springfjør',),
'springfjøren': ('springfjør',),
'springfjørene': ('springfjør',),
'springfjører': ('springfjør',),
'springflo': ('springflo',),
'springfloa': ('springflo',),
'springfloen': ('springflo',),
'springfloene': ('springflo',),
'springfloer': ('springflo',),
'springhale': ('springhale',),
'springhalen': ('springhale',),
'springhalene': ('springhale',),
'springhaler': ('springhale',),
'springkilde': ('springkilde',),
'springkilden': ('springkilde',),
'springkildene': ('springkilde',),
'springkilder': ('springkilde',),
'springkjelda': ('springkjelde',),
'springkjelde': ('springkjelde',),
'springkjelden': ('springkjelde',),
'springkjeldene': ('springkjelde',),
'springkjelder': ('springkjelde',),
'springkniv': ('springkniv',),
'springkniven': ('springkniv',),
'springknivene': ('springkniv',),
'springkniver': ('springkniv',),
'springleik': ('springleik',),
'springleiken': ('springleik',),
'springleikene': ('springleik',),
'springleiker': ('springleik',),
'springmadrass': ('springmadrass',),
'springmadrassen': ('springmadrass',),
'springmadrassene': ('springmadrass',),
'springmadrasser': ('springmadrass',),
'springmarsj': ('springmarsj',),
'springmarsjen': ('springmarsj',),
'springmarsjene': ('springmarsj',),
'springmarsjer': ('springmarsj',),
'springpengene': ('springpenger',),
'springpenger': ('springpenger',),
'springskalle': ('springskalle',),
'springskallen': ('springskalle',),
'springskallene': ('springskalle',),
'springskaller': ('springskalle',),
'springvann': ('springvann',),
'springvanna': ('springvann',),
'springvannene': ('springvann',),
'springvannet': ('springvann',),
'springvatn': ('springvatn',),
'springvatna': ('springvatn',),
'springvatnene': ('springvatn',),
'springvatnet': ('springvatn',),
'sprinkel': ('sprinkel',),
'sprinkelen': ('sprinkel',),
'sprinklene': ('sprinkel',),
'sprinkler': ('sprinkel',),
'sprinkelverk': ('sprinkelverk',),
'sprinkelverka': ('sprinkelverk',),
'sprinkelverkene': ('sprinkelverk',),
'sprinkelverker': ('sprinkelverk',),
'sprinkelverket': ('sprinkelverk',),
'sprinkler': ('sprinkler',),
'sprinklere': ('sprinkler',),
'sprinkleren': ('sprinkler',),
'sprinklerer': ('sprinkler',),
'sprinklerne': ('sprinkler',),
'sprinkleranlegg': ('sprinkleranlegg',),
'sprinkleranlegga': ('sprinkleranlegg',),
'sprinkleranleggene': ('sprinkleranlegg',),
'sprinkleranlegget': ('sprinkleranlegg',),
'sprint': ('sprint',),
'sprinten': ('sprint',),
'sprintene': ('sprint',),
'sprinter': ('sprint',),
'sprinter': ('sprinter',),
'sprintere': ('sprinter',),
'sprinteren': ('sprinter',),
'sprinterer': ('sprinter',),
'sprinterne': ('sprinter',),
'sprisegl': ('sprisegl',),
'sprisegla': ('sprisegl',),
'spriseglene': ('sprisegl',),
'spriseglet': ('sprisegl',),
'spriseil': ('spriseil',),
'spriseila': ('spriseil',),
'spriseilene': ('spriseil',),
'spriseilet': ('spriseil',),
'spristake': ('spristake',),
'spristaken': ('spristake',),
'spristakene': ('spristake',),
'spristaker': ('spristake',),
'sprit': ('sprit',),
'spriten': ('sprit',),
'spritene': ('sprit',),
'spriter': ('sprit',),
'spritapparat': ('spritapparat',),
'spritapparata': ('spritapparat',),
'spritapparatene': ('spritapparat',),
'spritapparater': ('spritapparat',),
'spritapparatet': ('spritapparat',),
'sprossa': ('sprosse',),
'sprosse': ('sprosse',),
'sprossen': ('sprosse',),
'sprossene': ('sprosse',),
'sprosser': ('sprosse',),
'sprunga': ('sprunge',),
'sprunge': ('sprunge',),
'sprungen': ('sprunge',),
'sprungene': ('sprunge',),
'sprunger': ('sprunge',),
'sprut': ('sprut',),
'spruten': ('sprut',),
'sprutene': ('sprut',),
'spruter': ('sprut',),
'sprutflaska': ('sprutflaske',),
'sprutflaske': ('sprutflaske',),
'sprutflasken': ('sprutflaske',),
'sprutflaskene': ('sprutflaske',),
'sprutflasker': ('sprutflaske',),
'spryd': ('spryd',),
'spryda': ('spryd',),
'sprydene': ('spryd',),
'sprydet': ('spryd',),
'språk': ('språk',),
'språka': ('språk',),
'språkene': ('språk',),
'språket': ('språk',),
'språkakademi': ('språkakademi',),
'språkakademia': ('språkakademi',),
'språkakademiene': ('språkakademi',),
'språkakademier': ('språkakademi',),
'språkakademiet': ('språkakademi',),
'språkatlas': ('språkatlas',),
'språkatlasa': ('språkatlas',),
'språkatlasene': ('språkatlas',),
'språkatlaser': ('språkatlas',),
'språkatlaset': ('språkatlas',),
'språkbarriere': ('språkbarriere',),
'språkbarrieren': ('språkbarriere',),
'språkbarrierene': ('språkbarriere',),
'språkbarrierer': ('språkbarriere',),
'språkblanding': ('språkblanding',),
'språkblandinga': ('språkblanding',),
'språkblandingen': ('språkblanding',),
'språkblandingene': ('språkblanding',),
'språkblandinger': ('språkblanding',),
'språkblomst': ('språkblomst',),
'språkblomsten': ('språkblomst',),
'språkblomstene': ('språkblomst',),
'språkblomster': ('språkblomst',),
'språkbruk': ('språkbruk',),
'språkbruka': ('språkbruk',),
'språkbruken': ('språkbruk',),
'språkbrukene': ('språkbruk',),
'språkbruker': ('språkbruk',),
'språkbruket': ('språkbruk',),
'språkbruksanalysa': ('språkbruksanalyse',),
'språkbruksanalyse': ('språkbruksanalyse',),
'språkbruksanalysen': ('språkbruksanalyse',),
'språkbruksanalysene': ('språkbruksanalyse',),
'språkbruksanalyser': ('språkbruksanalyse',),
'språkdrakt': ('språkdrakt',),
'språkdrakta': ('språkdrakt',),
'språkdrakten': ('språkdrakt',),
'språkdraktene': ('språkdrakt',),
'språkdrakter': ('språkdrakt',),
'språkdyrking': ('språkdyrking',),
'språkdyrkinga': ('språkdyrking',),
'språkdyrkingen': ('språkdyrking',),
'språkdyrkingene': ('språkdyrking',),
'språkdyrkinger': ('språkdyrking',),
'språkfag': ('språkfag',),
'språkfaga': ('språkfag',),
'språkfagene': ('språkfag',),
'språkfaget': ('språkfag',),
'språkfamilie': ('språkfamilie',),
'språkfamilien': ('språkfamilie',),
'språkfamiliene': ('språkfamilie',),
'språkfamilier': ('språkfamilie',),
'språkfolk': ('språkfolk',),
'språkfolka': ('språkfolk',),
'språkfolkene': ('språkfolk',),
'språkfolket': ('språkfolk',),
'språkform': ('språkform',),
'språkforma': ('språkform',),
'språkformen': ('språkform',),
'språkformene': ('språkform',),
'språkformer': ('språkform',),
'språkforsker': ('språkforsker',),
'språkforskere': ('språkforsker',),
'språkforskeren': ('språkforsker',),
'språkforskerer': ('språkforsker',),
'språkforskerne': ('språkforsker',),
'språkforsking': ('språkforsking',),
'språkforskinga': ('språkforsking',),
'språkforskingen': ('språkforsking',),
'språkforskingene': ('språkforsking',),
'språkforskinger': ('språkforsking',),
'språkforskning': ('språkforskning',),
'språkforskninga': ('språkforskning',),
'språkforskningen': ('språkforskning',),
'språkforskningene': ('språkforskning',),
'språkforskninger': ('språkforskning',),
'språkfølelse': ('språkfølelse',),
'språkfølelsen': ('språkfølelse',),
'språkfølelsene': ('språkfølelse',),
'språkfølelser': ('språkfølelse',),
'språkføring': ('språkføring',),
'språkføringa': ('språkføring',),
'språkføringen': ('språkføring',),
'språkføringene': ('språkføring',),
'språkføringer': ('språkføring',),
'språkgeografi': ('språkgeografi',),
'språkgeografien': ('språkgeografi',),
'språkgeografiene': ('språkgeografi',),
'språkgeografier': ('språkgeografi',),
'språkgransker': ('språkgransker',),
'språkgranskere': ('språkgransker',),
'språkgranskeren': ('språkgransker',),
'språkgranskerer': ('språkgransker',),
'språkgranskerne': ('språkgransker',),
'språkgransking': ('språkgransking',),
'språkgranskinga': ('språkgransking',),
'språkgranskingen': ('språkgransking',),
'språkgranskingene': ('språkgransking',),
'språkgranskinger': ('språkgransking',),
'språkhistoria': ('språkhistorie',),
'språkhistorie': ('språkhistorie',),
'språkhistorien': ('språkhistorie',),
'språkhistoriene': ('språkhistorie',),
'språkhistorier': ('språkhistorie',),
'språklaboratoria': ('språklaboratorium',),
'språklaboratoriene': ('språklaboratorium',),
'språklaboratorier': ('språklaboratorium',),
'språklaboratoriet': ('språklaboratorium',),
'språklaboratorium': ('språklaboratorium',),
'språklyd': ('språklyd',),
'språklyden': ('språklyd',),
'språklydene': ('språklyd',),
'språklyder': ('språklyd',),
'språkløshet': ('språkløshet',),
'språkløsheta': ('språkløshet',),
'språkløsheten': ('språkløshet',),
'språkløshetene': ('språkløshet',),
'språkløsheter': ('språkløshet',),
'språknorm': ('språknorm',),
'språknormen': ('språknorm',),
'språknormene': ('språknorm',),
'språknormer': ('språknorm',),
'språknormal': ('språknormal',),
'språknormalen': ('språknormal',),
'språknormalene': ('språknormal',),
'språknormaler': ('språknormal',),
'språknormering': ('språknormering',),
'språknormeringa': ('språknormering',),
'språknormeringen': ('språknormering',),
'språknormeringene': ('språknormering',),
'språknormeringer': ('språknormering',),
'språkplanlegging': ('språkplanlegging',),
'språkplanlegginga': ('språkplanlegging',),
'språkplanleggingen': ('språkplanlegging',),
'språkplanleggingene': ('språkplanlegging',),
'språkplanlegginger': ('språkplanlegging',),
'språkpolitikk': ('språkpolitikk',),
'språkpolitikken': ('språkpolitikk',),
'språkpolitikkene': ('språkpolitikk',),
'språkpolitikker': ('språkpolitikk',),
'språkpsykologi': ('språkpsykologi',),
'språkpsykologien': ('språkpsykologi',),
'språkpsykologiene': ('språkpsykologi',),
'språkpsykologier': ('språkpsykologi',),
'språkreising': ('språkreising',),
'språkreisinga': ('språkreising',),
'språkreisingen': ('språkreising',),
'språkreisingene': ('språkreising',),
'språkreisinger': ('språkreising',),
'språkreisning': ('språkreisning',),
'språkreisninga': ('språkreisning',),
'språkreisningen': ('språkreisning',),
'språkreisningene': ('språkreisning',),
'språkreisninger': ('språkreisning',),
'språkrenser': ('språkrenser',),
'språkrensere': ('språkrenser',),
'språkrenseren': ('språkrenser',),
'språkrenserer': ('språkrenser',),
'språkrenserne': ('språkrenser',),
'språkrensing': ('språkrensing',),
'språkrensinga': ('språkrensing',),
'språkrensingen': ('språkrensing',),
'språkrensingene': ('språkrensing',),
'språkrensinger': ('språkrensing',),
'språkrøkt': ('språkrøkt',),
'språkrøkta': ('språkrøkt',),
'språkrøkten': ('språkrøkt',),
'språkrøktene': ('språkrøkt',),
'språkrøkter': ('språkrøkt',),
'språksosiologi': ('språksosiologi',),
'språksosiologien': ('språksosiologi',),
'språksosiologiene': ('språksosiologi',),
'språksosiologier': ('språksosiologi',),
'språkstrid': ('språkstrid',),
'språkstriden': ('språkstrid',),
'språkstridene': ('språkstrid',),
'språkstrider': ('språkstrid',),
'språksyn': ('språksyn',),
'språksyna': ('språksyn',),
'språksynene': ('språksyn',),
'språksynet': ('språksyn',),
'språkvitenskap': ('språkvitenskap',),
'språkvitenskapen': ('språkvitenskap',),
'språkvitenskapene': ('språkvitenskap',),
'språkvitenskaper': ('språkvitenskap',),
'språkviter': ('språkviter',),
'språkvitere': ('språkviter',),
'språkviteren': ('språkviter',),
'språkviterer': ('språkviter',),
'språkviterne': ('språkviter',),
'språkvitskap': ('språkvitskap',),
'språkvitskapen': ('språkvitskap',),
'språkvitskapene': ('språkvitskap',),
'språkvitskaper': ('språkvitskap',),
'språkøra': ('språkøre',),
'språkøre': ('språkøre',),
'språkørene': ('språkøre',),
'språkører': ('språkøre',),
'språkøret': ('språkøre',),
'sprøyt': ('sprøyt',),
'sprøyta': ('sprøyt',),
'sprøytene': ('sprøyt',),
'sprøytet': ('sprøyt',),
'sprøyt': ('sprøyt',),
'sprøyta': ('sprøyt',),
'sprøyten': ('sprøyt',),
'sprøytene': ('sprøyt',),
'sprøyter': ('sprøyt',),
'sprøytet': ('sprøyt',),
'sprøyta': ('sprøyte',),
'sprøyte': ('sprøyte',),
'sprøyten': ('sprøyte',),
'sprøytene': ('sprøyte',),
'sprøyter': ('sprøyte',),
'sprøytehopp': ('sprøytehopp',),
'sprøytehoppa': ('sprøytehopp',),
'sprøytehoppene': ('sprøytehopp',),
'sprøytehoppet': ('sprøytehopp',),
'sprøytemiddel': ('sprøytemiddel',),
'sprøytemiddelet': ('sprøytemiddel',),
'sprøytemidla': ('sprøytemiddel',),
'sprøytemidlene': ('sprøytemiddel',),
'sprøytemidler': ('sprøytemiddel',),
'sprøytemidlet': ('sprøytemiddel',),
'sprøytenarkoman': ('sprøytenarkoman',),
'sprøytenarkomanen': ('sprøytenarkoman',),
'sprøytenarkomanene': ('sprøytenarkoman',),
'sprøytenarkomaner': ('sprøytenarkoman',),
'sprøytepistol': ('sprøytepistol',),
'sprøytepistolen': ('sprøytepistol',),
'sprøytepistolene': ('sprøytepistol',),
'sprøytepistoler': ('sprøytepistol',),
'sprøytevæska': ('sprøytevæske',),
'sprøytevæske': ('sprøytevæske',),
'sprøytevæsken': ('sprøytevæske',),
'sprøytevæskene': ('sprøytevæske',),
'sprøytevæsker': ('sprøytevæske',),
'spuns': ('spuns',),
'spunsa': ('spuns',),
'spunsene': ('spuns',),
'spunset': ('spuns',),
'spunshol': ('spunshol',),
'spunshola': ('spunshol',),
'spunsholene': ('spunshol',),
'spunsholet': ('spunshol',),
'spunshull': ('spunshull',),
'spunshulla': ('spunshull',),
'spunshullene': ('spunshull',),
'spunshuller': ('spunshull',),
'spunshullet': ('spunshull',),
'spuntvegg': ('spuntvegg',),
'spuntveggen': ('spuntvegg',),
'spuntveggene': ('spuntvegg',),
'spuntvegger': ('spuntvegg',),
'spurlag': ('spurlag',),
'spurlaga': ('spurlag',),
'spurlagene': ('spurlag',),
'spurlaget': ('spurlag',),
'spurt': ('spurt',),
'spurten': ('spurt',),
'spurtene': ('spurt',),
'spurter': ('spurt',),
'spurter': ('spurter',),
'spurtere': ('spurter',),
'spurteren': ('spurter',),
'spurterer': ('spurter',),
'spurterne': ('spurter',),
'spurv': ('spurv',),
'spurven': ('spurv',),
'spurvene': ('spurv',),
'spurver': ('spurv',),
'spurvefugl': ('spurvefugl',),
'spurvefuglen': ('spurvefugl',),
'spurvefuglene': ('spurvefugl',),
'spurvefugler': ('spurvefugl',),
'spurvehauk': ('spurvehauk',),
'spurvehauken': ('spurvehauk',),
'spurvehaukene': ('spurvehauk',),
'spurvehauker': ('spurvehauk',),
'spurveugla': ('spurveugle',),
'spurveugle': ('spurveugle',),
'spurveuglen': ('spurveugle',),
'spurveuglene': ('spurveugle',),
'spurveugler': ('spurveugle',),
'sputnik': ('sputnik',),
'sputniken': ('sputnik',),
'sputnikene': ('sputnik',),
'sputniker': ('sputnik',),
'spy': ('spy',),
'spya': ('spy',),
'spyene': ('spy',),
'spyet': ('spy',),
'spyd': ('spyd',),
'spyda': ('spyd',),
'spydene': ('spyd',),
'spydet': ('spyd',),
'spydighet': ('spydighet',),
'spydigheta': ('spydighet',),
'spydigheten': ('spydighet',),
'spydighetene': ('spydighet',),
'spydigheter': ('spydighet',),
'spydkast': ('spydkast',),
'spydkasta': ('spydkast',),
'spydkastene': ('spydkast',),
'spydkastet': ('spydkast',),
'spydkaster': ('spydkaster',),
'spydkastere': ('spydkaster',),
'spydkasteren': ('spydkaster',),
'spydkasterer': ('spydkaster',),
'spydkasterne': ('spydkaster',),
'spydspiss': ('spydspiss',),
'spydspissen': ('spydspiss',),
'spydspissene': ('spydspiss',),
'spydspisser': ('spydspiss',),
'spyflua': ('spyflue',),
'spyflue': ('spyflue',),
'spyfluen': ('spyflue',),
'spyfluene': ('spyflue',),
'spyfluer': ('spyflue',),
'spygatt': ('spygatt',),
'spygatta': ('spygatt',),
'spygattene': ('spygatt',),
'spygattet': ('spygatt',),
'spyler': ('spyler',),
'spylere': ('spyler',),
'spyleren': ('spyler',),
'spylerer': ('spyler',),
'spylerne': ('spyler',),
'spytt': ('spytt',),
'spytta': ('spytt',),
'spyttene': ('spytt',),
'spyttet': ('spytt',),
'spyttebakk': ('spyttebakk',),
'spyttebakken': ('spyttebakk',),
'spyttebakkene': ('spyttebakk',),
'spyttebakker': ('spyttebakk',),
'spyttebakke': ('spyttebakke',),
'spyttebakken': ('spyttebakke',),
'spyttebakkene': ('spyttebakke',),
'spyttebakker': ('spyttebakke',),
'spytteklysa': ('spytteklyse',),
'spytteklyse': ('spytteklyse',),
'spytteklysen': ('spytteklyse',),
'spytteklysene': ('spytteklyse',),
'spytteklyser': ('spytteklyse',),
'spyttkjertel': ('spyttkjertel',),
'spyttkjertelen': ('spyttkjertel',),
'spyttkjertlene': ('spyttkjertel',),
'spyttkjertler': ('spyttkjertel',),
'spyttslikker': ('spyttslikker',),
'spyttslikkere': ('spyttslikker',),
'spyttslikkeren': ('spyttslikker',),
'spyttslikkerer': ('spyttslikker',),
'spyttslikkerne': ('spyttslikker',),
'spådom': ('spådom',),
'spådommen': ('spådom',),
'spådommene': ('spådom',),
'spådommer': ('spådom',),
'spåkjerring': ('spåkjerring',),
'spåkjerringa': ('spåkjerring',),
'spåkjerringen': ('spåkjerring',),
'spåkjerringene': ('spåkjerring',),
'spåkjerringer': ('spåkjerring',),
'spåkona': ('spåkone',),
'spåkone': ('spåkone',),
'spåkonen': ('spåkone',),
'spåkonene': ('spåkone',),
'spåkoner': ('spåkone',),
'spåmann': ('spåmann',),
'spåmannen': ('spåmann',),
'spåmenn': ('spåmann',),
'spåmennene': ('spåmann',),
'spæl': ('spæl',),
'spælen': ('spæl',),
'spælene': ('spæl',),
'spæler': ('spæl',),
'spælsau': ('spælsau',),
'spælsauen': ('spælsau',),
'spælsauene': ('spælsau',),
'spælsauer': ('spælsau',),
'spøk': ('spøk',),
'spøken': ('spøk',),
'spøkene': ('spøk',),
'spøker': ('spøk',),
'spøkefugl': ('spøkefugl',),
'spøkefuglen': ('spøkefugl',),
'spøkefuglene': ('spøkefugl',),
'spøkefugler': ('spøkefugl',),
'spøkelsa': ('spøkelse',),
'spøkelse': ('spøkelse',),
'spøkelsene': ('spøkelse',),
'spøkelser': ('spøkelse',),
'spøkelset': ('spøkelse',),
'spøkelsesby': ('spøkelsesby',),
'spøkelsesbyen': ('spøkelsesby',),
'spøkelsesbyene': ('spøkelsesby',),
'spøkelsesbyer': ('spøkelsesby',),
'spøkelseshus': ('spøkelseshus',),
'spøkelseshusa': ('spøkelseshus',),
'spøkelseshusene': ('spøkelseshus',),
'spøkelseshuset': ('spøkelseshus',),
'spøkeri': ('spøkeri',),
'spøkeria': ('spøkeri',),
'spøkeriene': ('spøkeri',),
'spøkerier': ('spøkeri',),
'spøkeriet': ('spøkeri',),
'spørrekonkurranse': ('spørrekonkurranse',),
'spørrekonkurransen': ('spørrekonkurranse',),
'spørrekonkurransene': ('spørrekonkurranse',),
'spørrekonkurranser': ('spørrekonkurranse',),
'spørreleik': ('spørreleik',),
'spørreleiken': ('spørreleik',),
'spørreleikene': ('spørreleik',),
'spørreleiker': ('spørreleik',),
'spørrelek': ('spørrelek',),
'spørreleken': ('spørrelek',),
'spørrelekene': ('spørrelek',),
'spørreleker': ('spørrelek',),
'spørremelding': ('spørremelding',),
'spørremeldinga': ('spørremelding',),
'spørremeldingen': ('spørremelding',),
'spørremeldingene': ('spørremelding',),
'spørremeldinger': ('spørremelding',),
'spørreord': ('spørreord',),
'spørreorda': ('spørreord',),
'spørreordene': ('spørreord',),
'spørreordet': ('spørreord',),
'spørrer': ('spørrer',),
'spørrere': ('spørrer',),
'spørreren': ('spørrer',),
'spørrerer': ('spørrer',),
'spørrerne': ('spørrer',),
'spørresetning': ('spørresetning',),
'spørresetninga': ('spørresetning',),
'spørresetningen': ('spørresetning',),
'spørresetningene': ('spørresetning',),
'spørresetninger': ('spørresetning',),
'spørreskjema': ('spørreskjema',),
'spørreskjemaene': ('spørreskjema',),
'spørreskjemaer': ('spørreskjema',),
'spørreskjemaet': ('spørreskjema',),
'spørrespalta': ('spørrespalte',),
'spørrespalte': ('spørrespalte',),
'spørrespalten': ('spørrespalte',),
'spørrespaltene': ('spørrespalte',),
'spørrespalter': ('spørrespalte',),
'spørretime': ('spørretime',),
'spørretimen': ('spørretime',),
'spørretimene': ('spørretime',),
'spørretimer': ('spørretime',),
'spørsmål': ('spørsmål',),
'spørsmåla': ('spørsmål',),
'spørsmålene': ('spørsmål',),
'spørsmålet': ('spørsmål',),
'spørsmålstegn': ('spørsmålstegn',),
'spørsmålstegna': ('spørsmålstegn',),
'spørsmålstegnene': ('spørsmålstegn',),
'spørsmålstegnet': ('spørsmålstegn',),
'spøtt': ('spøtt',),
'spøtta': ('spøtt',),
'spøttene': ('spøtt',),
'spøttet': ('spøtt',),
'squaw': ('squaw',),
'squawen': ('squaw',),
'squawene': ('squaw',),
'squawer': ('squaw',),
'srilanker': ('srilanker',),
'srilankere': ('srilanker',),
'srilankeren': ('srilanker',),
'srilankerer': ('srilanker',),
'srilankerne': ('srilanker',),
'stab': ('stab',),
'staben': ('stab',),
'stabene': ('stab',),
'staber': ('stab',),
'stabbe': ('stabbe',),
'stabben': ('stabbe',),
'stabbene': ('stabbe',),
'stabber': ('stabbe',),
'stabbestein': ('stabbestein',),
'stabbesteinen': ('stabbestein',),
'stabbesteinene': ('stabbestein',),
'stabbesteiner': ('stabbestein',),
'stabbur': ('stabbur',),
'stabbura': ('stabbur',),
'stabburene': ('stabbur',),
'stabburet': ('stabbur',),
'stabeis': ('stabeis',),
'stabeisen': ('stabeis',),
'stabeisene': ('stabeis',),
'stabeiser': ('stabeis',),
'stabel': ('stabel',),
'stabelen': ('stabel',),
'stablene': ('stabel',),
'stabler': ('stabel',),
'stabelavløpning': ('stabelavløpning',),
'stabelavløpninga': ('stabelavløpning',),
'stabelavløpningen': ('stabelavløpning',),
'stabelavløpningene': ('stabelavløpning',),
'stabelavløpninger': ('stabelavløpning',),
'stabelhengsel': ('stabelhengsel',),
'stabelhengselen': ('stabelhengsel',),
'stabelhengselet': ('stabelhengsel',),
'stabelhengsla': ('stabelhengsel',),
'stabelhengslene': ('stabelhengsel',),
'stabelhengsler': ('stabelhengsel',),
'stabelhengslet': ('stabelhengsel',),
'stabelhengsla': ('stabelhengsle',),
'stabelhengsle': ('stabelhengsle',),
'stabelhengslen': ('stabelhengsle',),
'stabelhengslene': ('stabelhengsle',),
'stabelhengsler': ('stabelhengsle',),
'stabelhengslet': ('stabelhengsle',),
'stabilisator': ('stabilisator',),
'stabilisatoren': ('stabilisator',),
'stabilisatorene': ('stabilisator',),
'stabilisatorer': ('stabilisator',),
'stabilitet': ('stabilitet',),
'stabiliteten': ('stabilitet',),
'stabilitetene': ('stabilitet',),
'stabiliteter': ('stabilitet',),
'stabskompani': ('stabskompani',),
'stabskompania': ('stabskompani',),
'stabskompaniene': ('stabskompani',),
'stabskompanier': ('stabskompani',),
'stabskompaniet': ('stabskompani',),
'stabsoffiser': ('stabsoffiser',),
'stabsoffiseren': ('stabsoffiser',),
'stabsoffiserene': ('stabsoffiser',),
'stabsoffiserer': ('stabsoffiser',),
'stabukk': ('stabukk',),
'stabukken': ('stabukk',),
'stabukkene': ('stabukk',),
'stabukker': ('stabukk',),
'stad': ('stad',),
'staden': ('stad',),
'stedene': ('stad',),
'steder': ('stad',),
'stad': ('stad',),
'stadfestelse': ('stadfestelse',),
'stadfestelsen': ('stadfestelse',),
'stadfestelsene': ('stadfestelse',),
'stadfestelser': ('stadfestelse',),
'stadfesting': ('stadfesting',),
'stadfestinga': ('stadfesting',),
'stadfestingen': ('stadfesting',),
'stadfestingene': ('stadfesting',),
'stadfestinger': ('stadfesting',),
'stadighet': ('stadighet',),
'stadigheta': ('stadighet',),
'stadigheten': ('stadighet',),
'stadighetene': ('stadighet',),
'stadigheter': ('stadighet',),
'stadion': ('stadion',),
'stadiona': ('stadion',),
'stadionene': ('stadion',),
'stadioner': ('stadion',),
'stadionet': ('stadion',),
'stadia': ('stadium',),
'stadiene': ('stadium',),
'stadier': ('stadium',),
'stadiet': ('stadium',),
'stadium': ('stadium',),
'stadsfysikus': ('stadsfysikus',),
'stadsfysikusen': ('stadsfysikus',),
'stadsfysikusene': ('stadsfysikus',),
'stadsfysikuser': ('stadsfysikus',),
'stafett': ('stafett',),
'stafetten': ('stafett',),
'stafettene': ('stafett',),
'stafetter': ('stafett',),
'stafettløp': ('stafettløp',),
'stafettløpa': ('stafettløp',),
'stafettløpene': ('stafettløp',),
'stafettløpet': ('stafettløp',),
'stafettpinne': ('stafettpinne',),
'stafettpinnen': ('stafettpinne',),
'stafettpinnene': ('stafettpinne',),
'stafettpinner': ('stafettpinne',),
'staffasje': ('staffasje',),
'staffasjen': ('staffasje',),
'staffasjene': ('staffasje',),
'staffasjer': ('staffasje',),
'staffasjefigur': ('staffasjefigur',),
'staffasjefiguren': ('staffasjefigur',),
'staffasjefigurene': ('staffasjefigur',),
'staffasjefigurer': ('staffasjefigur',),
'staffeli': ('staffeli',),
'staffelia': ('staffeli',),
'staffeliene': ('staffeli',),
'staffelier': ('staffeli',),
'staffeliet': ('staffeli',),
'stafylokokk': ('stafylokokk',),
'stafylokokken': ('stafylokokk',),
'stafylokokkene': ('stafylokokk',),
'stafylokokker': ('stafylokokk',),
'stag': ('stag',),
'staga': ('stag',),
'stagene': ('stag',),
'staget': ('stag',),
'stagflasjon': ('stagflasjon',),
'stagflasjonen': ('stagflasjon',),
'stagflasjonene': ('stagflasjon',),
'stagflasjoner': ('stagflasjon',),
'stagnasjon': ('stagnasjon',),
'stagnasjonen': ('stagnasjon',),
'stagnasjonene': ('stagnasjon',),
'stagnasjoner': ('stagnasjon',),
'stagsegl': ('stagsegl',),
'stagsegla': ('stagsegl',),
'stagseglene': ('stagsegl',),
'stagseglet': ('stagsegl',),
'stagseil': ('stagseil',),
'stagseila': ('stagseil',),
'stagseilene': ('stagseil',),
'stagseilet': ('stagseil',),
'stahet': ('stahet',),
'staheta': ('stahet',),
'staheten': ('stahet',),
'stahetene': ('stahet',),
'staheter': ('stahet',),
'stake': ('stake',),
'staken': ('stake',),
'stakene': ('stake',),
'staker': ('stake',),
'stakitt': ('stakitt',),
'stakitta': ('stakitt',),
'stakitten': ('stakitt',),
'stakittene': ('stakitt',),
'stakitter': ('stakitt',),
'stakittet': ('stakitt',),
'stakittgjerda': ('stakittgjerde',),
'stakittgjerde': ('stakittgjerde',),
'stakittgjerdene': ('stakittgjerde',),
'stakittgjerder': ('stakittgjerde',),
'stakittgjerdet': ('stakittgjerde',),
'stakk': ('stakk',),
'stakken': ('stakk',),
'stakkene': ('stakk',),
'stakker': ('stakk',),
'stakk': ('stakk',),
'stakken': ('stakk',),
'stakkene': ('stakk',),
'stakker': ('stakk',),
'stakkar': ('stakkar',),
'stakkaren': ('stakkar',),
'stakkarene': ('stakkar',),
'stakkarer': ('stakkar',),
'stakkarsdom': ('stakkarsdom',),
'stakkarsdommen': ('stakkarsdom',),
'stakkarsdommene': ('stakkarsdom',),
'stakkarsdommer': ('stakkarsdom',),
'stakkarsting': ('stakkarsting',),
'stakkarstinga': ('stakkarsting',),
'stakkarstingen': ('stakkarsting',),
'stakkarstingene': ('stakkarsting',),
'stakkato': ('stakkato',),
'stakkatoa': ('stakkato',),
'stakkatoene': ('stakkato',),
'stakkatoer': ('stakkato',),
'stakkatoet': ('stakkato',),
'stalagmitt': ('stalagmitt',),
'stalagmitten': ('stalagmitt',),
'stalagmittene': ('stalagmitt',),
'stalagmitter': ('stalagmitt',),
'stalaktitt': ('stalaktitt',),
'stalaktitten': ('stalaktitt',),
'stalaktittene': ('stalaktitt',),
'stalaktitter': ('stalaktitt',),
'stalinisme': ('stalinisme',),
'stalinismen': ('stalinisme',),
'stalinismene': ('stalinisme',),
'stalinismer': ('stalinisme',),
'stalinist': ('stalinist',),
'stalinisten': ('stalinist',),
'stalinistene': ('stalinist',),
'stalinister': ('stalinist',),
'stalinorgel': ('stalinorgel',),
'stalinorgelet': ('stalinorgel',),
'stalinorgla': ('stalinorgel',),
'stalinorglene': ('stalinorgel',),
'stalinorgler': ('stalinorgel',),
'stalinorglet': ('stalinorgel',),
'stall': ('stall',),
'stallen': ('stall',),
'stallene': ('stall',),
'staller': ('stall',),
'stallar': ('stallar',),
'stallaren': ('stallar',),
'stallarene': ('stallar',),
'stallarer': ('stallar',),
'stallare': ('stallare',),
'stallaren': ('stallare',),
'stallarene': ('stallare',),
'stallarer': ('stallare',),
'stallbror': ('stallbror',),
'stallbroren': ('stallbror',),
'stallbrødre': ('stallbror',),
'stallbrødrene': ('stallbror',),
'stallkar': ('stallkar',),
'stallkaren': ('stallkar',),
'stallkarene': ('stallkar',),
'stallkarer': ('stallkar',),
'stalltips': ('stalltips',),
'stalltipsa': ('stalltips',),
'stalltipsene': ('stalltips',),
'stalltipset': ('stalltips',),
'stalltrev': ('stalltrev',),
'stalltreva': ('stalltrev',),
'stalltrevene': ('stalltrev',),
'stalltrevet': ('stalltrev',),
'stam': ('stam',),
'stammen': ('stam',),
'stammene': ('stam',),
'stammer': ('stam',),
'stamaksje': ('stamaksje',),
'stamaksjen': ('stamaksje',),
'stamaksjene': ('stamaksje',),
'stamaksjer': ('stamaksje',),
'stambane': ('stambane',),
'stambanen': ('stambane',),
'stambanene': ('stambane',),
'stambaner': ('stambane',),
'stambok': ('stambok',),
'stamboka': ('stambok',),
'stamboken': ('stambok',),
'stambøkene': ('stambok',),
'stambøker': ('stambok',),
'stamfisk': ('stamfisk',),
'stamfisken': ('stamfisk',),
'stamfiskene': ('stamfisk',),
'stamfisker': ('stamfisk',),
'stamflyplass': ('stamflyplass',),
'stamflyplassen': ('stamflyplass',),
'stamflyplassene': ('stamflyplass',),
'stamflyplasser': ('stamflyplass',),
'stamgjest': ('stamgjest',),
'stamgjesten': ('stamgjest',),
'stamgjestene': ('stamgjest',),
'stamgjester': ('stamgjest',),
'stamhus': ('stamhus',),
'stamhusa': ('stamhus',),
'stamhusene': ('stamhus',),
'stamhuset': ('stamhus',),
'stamme': ('stamme',),
'stammen': ('stamme',),
'stammene': ('stamme',),
'stammer': ('stamme',),
'stammefeide': ('stammefeide',),
'stammefeiden': ('stammefeide',),
'stammefeidene': ('stammefeide',),
'stammefeider': ('stammefeide',),
'stammefrende': ('stammefrende',),
'stammefrenden': ('stammefrende',),
'stammefrendene': ('stammefrende',),
'stammefrender': ('stammefrende',),
'stammehøvding': ('stammehøvding',),
'stammehøvdingen': ('stammehøvding',),
'stammehøvdingene': ('stammehøvding',),
'stammehøvdinger': ('stammehøvding',),
'stammekrig': ('stammekrig',),
'stammekrigen': ('stammekrig',),
'stammekrigene': ('stammekrig',),
'stammekriger': ('stammekrig',),
'stammor': ('stammor',),
'stammora': ('stammor',),
'stammoren': ('stammor',),
'stammødre': ('stammor',),
'stammødrene': ('stammor',),
'stammødrer': ('stammor',),
'stamn': ('stamn',),
'stamnen': ('stamn',),
'stamnene': ('stamn',),
'stamner': ('stamn',),
'stamp': ('stamp',),
'stampa': ('stamp',),
'stampene': ('stamp',),
'stampet': ('stamp',),
'stampa': ('stampe',),
'stampe': ('stampe',),
'stampen': ('stampe',),
'stampene': ('stampe',),
'stamper': ('stampe',),
'stampe': ('stampe',),
'stampemelding': ('stampemelding',),
'stampemeldinga': ('stampemelding',),
'stampemeldingen': ('stampemelding',),
'stampemeldingene': ('stampemelding',),
'stampemeldinger': ('stampemelding',),
'stampeseddel': ('stampeseddel',),
'stampeseddelen': ('stampeseddel',),
'stampeseddlene': ('stampeseddel',),
'stampeseddler': ('stampeseddel',),
'stampesjø': ('stampesjø',),
'stampesjøen': ('stampesjø',),
'stampesjøene': ('stampesjø',),
'stampesjøer': ('stampesjø',),
'stampeverk': ('stampeverk',),
'stampeverka': ('stampeverk',),
'stampeverkene': ('stampeverk',),
'stampeverker': ('stampeverk',),
'stampeverket': ('stampeverk',),
'stamruta': ('stamrute',),
'stamrute': ('stamrute',),
'stamruten': ('stamrute',),
'stamrutene': ('stamrute',),
'stamruter': ('stamrute',),
'stamtavla': ('stamtavle',),
'stamtavle': ('stamtavle',),
'stamtavlen': ('stamtavle',),
'stamtavlene': ('stamtavle',),
'stamtavler': ('stamtavle',),
'stamveg': ('stamveg',),
'stamvegen': ('stamveg',),
'stamvegene': ('stamveg',),
'stamveger': ('stamveg',),
'stamvei': ('stamvei',),
'stamveien': ('stamvei',),
'stamveiene': ('stamvei',),
'stamveier': ('stamvei',),
'stand-in': ('stand-in',),
'stand-inen': ('stand-in',),
'stand-inene': ('stand-in',),
'stand-iner': ('stand-in',),
'standard': ('standard',),
'standarden': ('standard',),
'standardene': ('standard',),
'standarder': ('standard',),
'standardmodell': ('standardmodell',),
'standardmodellen': ('standardmodell',),
'standardmodellene': ('standardmodell',),
'standardmodeller': ('standardmodell',),
'standardmål': ('standardmål',),
'standardmåla': ('standardmål',),
'standardmålene': ('standardmål',),
'standardmålet': ('standardmål',),
'standardpakning': ('standardpakning',),
'standardpakninga': ('standardpakning',),
'standardpakningen': ('standardpakning',),
'standardpakningene': ('standardpakning',),
'standardpakninger': ('standardpakning',),
'standardutgava': ('standardutgave',),
'standardutgave': ('standardutgave',),
'standardutgaven': ('standardutgave',),
'standardutgavene': ('standardutgave',),
'standardutgaver': ('standardutgave',),
'standardutstyr': ('standardutstyr',),
'standardutstyra': ('standardutstyr',),
'standardutstyrene': ('standardutstyr',),
'standardutstyret': ('standardutstyr',),
'standardverk': ('standardverk',),
'standardverka': ('standardverk',),
'standardverkene': ('standardverk',),
'standardverker': ('standardverk',),
'standardverket': ('standardverk',),
'standart': ('standart',),
'standarten': ('standart',),
'standartene': ('standart',),
'standarter': ('standart',),
'standbein': ('standbein',),
'standbeina': ('standbein',),
'standbeinene': ('standbein',),
'standbeinet': ('standbein',),
'standben': ('standben',),
'standbena': ('standben',),
'standbenene': ('standben',),
'standbenet': ('standben',),
'stander': ('stander',),
'standere': ('stander',),
'standeren': ('stander',),
'standerer': ('stander',),
'standerne': ('stander',),
'standfugl': ('standfugl',),
'standfuglen': ('standfugl',),
'standfuglene': ('standfugl',),
'standfugler': ('standfugl',),
'standkvarter': ('standkvarter',),
'standkvartera': ('standkvarter',),
'standkvarterene': ('standkvarter',),
'standkvarterer': ('standkvarter',),
'standkvarteret': ('standkvarter',),
'standplass': ('standplass',),
'standplassen': ('standplass',),
'standplassene': ('standplass',),
'standplasser': ('standplass',),
'standpunkt': ('standpunkt',),
'standpunkta': ('standpunkt',),
'standpunktene': ('standpunkt',),
'standpunkter': ('standpunkt',),
'standpunktet': ('standpunkt',),
'standpunktkarakter': ('standpunktkarakter',),
'standpunktkarakteren': ('standpunktkarakter',),
'standpunktkarakterene': ('standpunktkarakter',),
'standpunktkarakterer': ('standpunktkarakter',),
'standpunkttagen': ('standpunkttagen',),
'standpunkttaing': ('standpunkttaing',),
'standpunkttainga': ('standpunkttaing',),
'standpunkttaingen': ('standpunkttaing',),
'standpunkttaingene': ('standpunkttaing',),
'standpunkttainger': ('standpunkttaing',),
'standpunkttaken': ('standpunkttaken',),
'standpunkttaking': ('standpunkttaking',),
'standpunkttakinga': ('standpunkttaking',),
'standpunkttakingen': ('standpunkttaking',),
'standpunkttakingene': ('standpunkttaking',),
'standpunkttakinger': ('standpunkttaking',),
'standrett': ('standrett',),
'standretten': ('standrett',),
'standrettene': ('standrett',),
'standretter': ('standrett',),
'standsforskjell': ('standsforskjell',),
'standsforskjellen': ('standsforskjell',),
'standsforskjellene': ('standsforskjell',),
'standsforskjeller': ('standsforskjell',),
'standsperson': ('standsperson',),
'standspersonen': ('standsperson',),
'standspersonene': ('standsperson',),
'standspersoner': ('standsperson',),
'stang': ('stang',),
'stanga': ('stang',),
'stangen': ('stang',),
'stengene': ('stang',),
'stenger': ('stang',),
'stangfiska': ('stangfiske',),
'stangfiske': ('stangfiske',),
'stangfiskene': ('stangfiske',),
'stangfisker': ('stangfiske',),
'stangfisket': ('stangfiske',),
'stangselleri': ('stangselleri',),
'stangsellerien': ('stangselleri',),
'stangselleriene': ('stangselleri',),
'stangsellerier': ('stangselleri',),
'stank': ('stank',),
'stanken': ('stank',),
'stankene': ('stank',),
'stanker': ('stank',),
'stankelbein': ('stankelbein',),
'stankelbeina': ('stankelbein',),
'stankelbeinen': ('stankelbein',),
'stankelbeinene': ('stankelbein',),
'stankelbeinet': ('stankelbein',),
'stankelben': ('stankelben',),
'stankelbena': ('stankelben',),
'stankelbenen': ('stankelben',),
'stankelbenene': ('stankelben',),
'stankelbenet': ('stankelben',),
'stanksopp': ('stanksopp',),
'stanksoppen': ('stanksopp',),
'stanksoppene': ('stanksopp',),
'stanksopper': ('stanksopp',),
'stanniol': ('stanniol',),
'stanniola': ('stanniol',),
'stanniolene': ('stanniol',),
'stanniolet': ('stanniol',),
'stans': ('stans',),
'stansen': ('stans',),
'stansene': ('stans',),
'stanser': ('stans',),
'stanse': ('stanse',),
'stansen': ('stanse',),
'stansene': ('stanse',),
'stanser': ('stanse',),
'stansemaskin': ('stansemaskin',),
'stansemaskina': ('stansemaskin',),
'stansemaskinen': ('stansemaskin',),
'stansemaskinene': ('stansemaskin',),
'stansemaskiner': ('stansemaskin',),
'stanseverktøy': ('stanseverktøy',),
'stanseverktøya': ('stanseverktøy',),
'stanseverktøyene': ('stanseverktøy',),
'stanseverktøyer': ('stanseverktøy',),
'stanseverktøyet': ('stanseverktøy',),
'stapel': ('stapel',),
'stapelen': ('stapel',),
'staplene': ('stapel',),
'stapler': ('stapel',),
'stapelplass': ('stapelplass',),
'stapelplassen': ('stapelplass',),
'stapelplassene': ('stapelplass',),
'stapelplasser': ('stapelplass',),
'stapelvara': ('stapelvare',),
'stapelvare': ('stapelvare',),
'stapelvaren': ('stapelvare',),
'stapelvarene': ('stapelvare',),
'stapelvarer': ('stapelvare',),
'stappa': ('stappe',),
'stappe': ('stappe',),
'stappen': ('stappe',),
'stappene': ('stappe',),
'stapper': ('stappe',),
'star': ('star',),
'staren': ('star',),
'starene': ('star',),
'starer': ('star',),
'stare': ('stare',),
'staren': ('stare',),
'starene': ('stare',),
'starer': ('stare',),
'starr': ('starr',),
'starren': ('starr',),
'starrene': ('starr',),
'starrer': ('starr',),
'starr': ('starr',),
'starren': ('starr',),
'starrene': ('starr',),
'starrer': ('starr',),
'starrgras': ('starrgras',),
'starrgrasa': ('starrgras',),
'starrgrasene': ('starrgras',),
'starrgraset': ('starrgras',),
'starrgras': ('starrgras',),
'starrgrasa': ('starrgras',),
'starrgrasene': ('starrgras',),
'starrgraset': ('starrgras',),
'starrgress': ('starrgress',),
'starrgressa': ('starrgress',),
'starrgressene': ('starrgress',),
'starrgresset': ('starrgress',),
'starrmyr': ('starrmyr',),
'starrmyra': ('starrmyr',),
'starrmyren': ('starrmyr',),
'starrmyrene': ('starrmyr',),
'starrmyrer': ('starrmyr',),
'starrmyr': ('starrmyr',),
'starrmyra': ('starrmyr',),
'starrmyren': ('starrmyr',),
'starrmyrene': ('starrmyr',),
'starrmyrer': ('starrmyr',),
'start': ('start',),
'starten': ('start',),
'startene': ('start',),
'starter': ('start',),
'startbane': ('startbane',),
'startbanen': ('startbane',),
'startbanene': ('startbane',),
'startbaner': ('startbane',),
'startblokk': ('startblokk',),
'startblokka': ('startblokk',),
'startblokken': ('startblokk',),
'startblokkene': ('startblokk',),
'startblokker': ('startblokk',),
'starter': ('starter',),
'startere': ('starter',),
'starteren': ('starter',),
'starterer': ('starter',),
'starterne': ('starter',),
'startflagg': ('startflagg',),
'startflagga': ('startflagg',),
'startflaggene': ('startflagg',),
'startflagget': ('startflagg',),
'startforbud': ('startforbud',),
'startforbuda': ('startforbud',),
'startforbudene': ('startforbud',),
'startforbudet': ('startforbud',),
'startgrop': ('startgrop',),
'startgropa': ('startgrop',),
'startgropen': ('startgrop',),
'startgropene': ('startgrop',),
'startgroper': ('startgrop',),
'startkapital': ('startkapital',),
'startkapitalen': ('startkapital',),
'startkapitalene': ('startkapital',),
'startkapitaler': ('startkapital',),
'startkontingent': ('startkontingent',),
'startkontingenten': ('startkontingent',),
'startkontingentene': ('startkontingent',),
'startkontingenter': ('startkontingent',),
'startmotor': ('startmotor',),
'startmotoren': ('startmotor',),
'startmotorene': ('startmotor',),
'startmotorer': ('startmotor',),
'startnummer': ('startnummer',),
'startnummeret': ('startnummer',),
'startnumra': ('startnummer',),
'startnumre': ('startnummer',),
'startnumrene': ('startnummer',),
'startpistol': ('startpistol',),
'startpistolen': ('startpistol',),
'startpistolene': ('startpistol',),
'startpistoler': ('startpistol',),
'startsignal': ('startsignal',),
'startsignala': ('startsignal',),
'startsignalene': ('startsignal',),
'startsignaler': ('startsignal',),
'startsignalet': ('startsignal',),
'startskott': ('startskott',),
'startskotta': ('startskott',),
'startskottene': ('startskott',),
'startskottet': ('startskott',),
'startskudd': ('startskudd',),
'startskudda': ('startskudd',),
'startskuddene': ('startskudd',),
'startskuddet': ('startskudd',),
'startstrek': ('startstrek',),
'startstreken': ('startstrek',),
'startstrekene': ('startstrek',),
'startstreker': ('startstrek',),
'stas': ('stas',),
'stasen': ('stas',),
'stasene': ('stas',),
'staser': ('stas',),
'stasjon': ('stasjon',),
'stasjonen': ('stasjon',),
'stasjonene': ('stasjon',),
'stasjoner': ('stasjon',),
'stasjonsbetjent': ('stasjonsbetjent',),
'stasjonsbetjenten': ('stasjonsbetjent',),
'stasjonsbetjentene': ('stasjonsbetjent',),
'stasjonsbetjenter': ('stasjonsbetjent',),
'stasjonsby': ('stasjonsby',),
'stasjonsbyen': ('stasjonsby',),
'stasjonsbyene': ('stasjonsby',),
'stasjonsbyer': ('stasjonsby',),
'stasjonsmester': ('stasjonsmester',),
'stasjonsmestere': ('stasjonsmester',),
'stasjonsmesteren': ('stasjonsmester',),
'stasjonsmesterer': ('stasjonsmester',),
'stasjonsmesterne': ('stasjonsmester',),
'stasjonsmestre': ('stasjonsmester',),
'stasjonsmestrene': ('stasjonsmester',),
'stasjonsmestrer': ('stasjonsmester',),
'stasjonssjef': ('stasjonssjef',),
'stasjonssjefen': ('stasjonssjef',),
'stasjonssjefene': ('stasjonssjef',),
'stasjonssjefer': ('stasjonssjef',),
'stasjonsvogn': ('stasjonsvogn',),
'stasjonsvogna': ('stasjonsvogn',),
'stasjonsvognen': ('stasjonsvogn',),
'stasjonsvognene': ('stasjonsvogn',),
'stasjonsvogner': ('stasjonsvogn',),
'staskar': ('staskar',),
'staskaren': ('staskar',),
'staskarene': ('staskar',),
'staskarer': ('staskar',),
'stasklær': ('stasklær',),
'stasklærne': ('stasklær',),
'stat': ('stat',),
'staten': ('stat',),
'statene': ('stat',),
'stater': ('stat',),
'statiker': ('statiker',),
'statikere': ('statiker',),
'statikeren': ('statiker',),
'statikerer': ('statiker',),
'statikerne': ('statiker',),
'statikk': ('statikk',),
'statikken': ('statikk',),
'statikkene': ('statikk',),
'statikker': ('statikk',),
'statist': ('statist',),
'statisten': ('statist',),
'statistene': ('statist',),
'statister': ('statist',),
'statisteri': ('statisteri',),
'statisteria': ('statisteri',),
'statisteriene': ('statisteri',),
'statisterier': ('statisteri',),
'statisteriet': ('statisteri',),
'statistiker': ('statistiker',),
'statistikere': ('statistiker',),
'statistikeren': ('statistiker',),
'statistikerer': ('statistiker',),
'statistikerne': ('statistiker',),
'statistikk': ('statistikk',),
'statistikken': ('statistikk',),
'statistikkene': ('statistikk',),
'statistikker': ('statistikk',),
'stativ': ('stativ',),
'stativa': ('stativ',),
'stativene': ('stativ',),
'stativer': ('stativ',),
'stativet': ('stativ',),
'stator': ('stator',),
'statoren': ('stator',),
'statorene': ('stator',),
'statorer': ('stator',),
'statsadvokat': ('statsadvokat',),
'statsadvokaten': ('statsadvokat',),
'statsadvokatene': ('statsadvokat',),
'statsadvokater': ('statsadvokat',),
'statsallmenning': ('statsallmenning',),
'statsallmenningen': ('statsallmenning',),
'statsallmenningene': ('statsallmenning',),
'statsallmenninger': ('statsallmenning',),
'statsamatør': ('statsamatør',),
'statsamatøren': ('statsamatør',),
'statsamatørene': ('statsamatør',),
'statsamatører': ('statsamatør',),
'statsarkiv': ('statsarkiv',),
'statsarkiva': ('statsarkiv',),
'statsarkivene': ('statsarkiv',),
'statsarkiver': ('statsarkiv',),
'statsarkivet': ('statsarkiv',),
'statsbank': ('statsbank',),
'statsbanken': ('statsbank',),
'statsbankene': ('statsbank',),
'statsbanker': ('statsbank',),
'statsbesøk': ('statsbesøk',),
'statsbesøka': ('statsbesøk',),
'statsbesøkene': ('statsbesøk',),
'statsbesøket': ('statsbesøk',),
'statsborger': ('statsborger',),
'statsborgere': ('statsborger',),
'statsborgeren': ('statsborger',),
'statsborgerer': ('statsborger',),
'statsborgerne': ('statsborger',),
'statsborgerskap': ('statsborgerskap',),
'statsborgerskapa': ('statsborgerskap',),
'statsborgerskapene': ('statsborgerskap',),
'statsborgerskapet': ('statsborgerskap',),
'statsbudsjett': ('statsbudsjett',),
'statsbudsjetta': ('statsbudsjett',),
'statsbudsjettene': ('statsbudsjett',),
'statsbudsjetter': ('statsbudsjett',),
'statsbudsjettet': ('statsbudsjett',),
'statsdrift': ('statsdrift',),
'statsdrifta': ('statsdrift',),
'statsdriften': ('statsdrift',),
'statsdriftene': ('statsdrift',),
'statsdrifter': ('statsdrift',),
'statsforfatning': ('statsforfatning',),
'statsforfatninga': ('statsforfatning',),
'statsforfatningen': ('statsforfatning',),
'statsforfatningene': ('statsforfatning',),
'statsforfatninger': ('statsforfatning',),
'statsforvaltning': ('statsforvaltning',),
'statsforvaltninga': ('statsforvaltning',),
'statsforvaltningen': ('statsforvaltning',),
'statsforvaltningene': ('statsforvaltning',),
'statsforvaltninger': ('statsforvaltning',),
'statsgaranti': ('statsgaranti',),
'statsgarantien': ('statsgaranti',),
'statsgarantiene': ('statsgaranti',),
'statsgarantier': ('statsgaranti',),
'statshemmelighet': ('statshemmelighet',),
'statshemmeligheta': ('statshemmelighet',),
'statshemmeligheten': ('statshemmelighet',),
'statshemmelighetene': ('statshemmelighet',),
'statshemmeligheter': ('statshemmelighet',),
'statskalender': ('statskalender',),
'statskalendere': ('statskalender',),
'statskalenderen': ('statskalender',),
'statskalenderer': ('statskalender',),
'statskalenderne': ('statskalender',),
'statskalendre': ('statskalender',),
'statskalendrene': ('statskalender',),
'statskalendrer': ('statskalender',),
'statskapitalisme': ('statskapitalisme',),
'statskapitalismen': ('statskapitalisme',),
'statskapitalismene': ('statskapitalisme',),
'statskapitalismer': ('statskapitalisme',),
'statskassa': ('statskasse',),
'statskasse': ('statskasse',),
'statskassen': ('statskasse',),
'statskassene': ('statskasse',),
'statskasser': ('statskasse',),
'statskirka': ('statskirke',),
'statskirke': ('statskirke',),
'statskirken': ('statskirke',),
'statskirkene': ('statskirke',),
'statskirker': ('statskirke',),
'statskjerka': ('statskjerke',),
'statskjerke': ('statskjerke',),
'statskjerken': ('statskjerke',),
'statskjerkene': ('statskjerke',),
'statskjerker': ('statskjerke',),
'statskraft': ('statskraft',),
'statskrafta': ('statskraft',),
'statskraften': ('statskraft',),
'statskreftene': ('statskraft',),
'statskrefter': ('statskraft',),
'statskupp': ('statskupp',),
'statskuppa': ('statskupp',),
'statskuppene': ('statskupp',),
'statskuppet': ('statskupp',),
'statslos': ('statslos',),
'statslosen': ('statslos',),
'statslosene': ('statslos',),
'statsloser': ('statslos',),
'statsmakt': ('statsmakt',),
'statsmakta': ('statsmakt',),
'statsmakten': ('statsmakt',),
'statsmaktene': ('statsmakt',),
'statsmakter': ('statsmakt',),
'statsmann': ('statsmann',),
'statsmannen': ('statsmann',),
'statsmenn': ('statsmann',),
'statsmennene': ('statsmann',),
'statsmeteorolog': ('statsmeteorolog',),
'statsmeteorologen': ('statsmeteorolog',),
'statsmeteorologene': ('statsmeteorolog',),
'statsmeteorologer': ('statsmeteorolog',),
'statsminister': ('statsminister',),
'statsministere': ('statsminister',),
'statsministeren': ('statsminister',),
'statsministerer': ('statsminister',),
'statsministerne': ('statsminister',),
'statsministre': ('statsminister',),
'statsministrene': ('statsminister',),
'statsministrer': ('statsminister',),
'statsmonopol': ('statsmonopol',),
'statsmonopola': ('statsmonopol',),
'statsmonopolene': ('statsmonopol',),
'statsmonopoler': ('statsmonopol',),
'statsmonopolet': ('statsmonopol',),
'statsobligasjon': ('statsobligasjon',),
'statsobligasjonen': ('statsobligasjon',),
'statsobligasjonene': ('statsobligasjon',),
'statsobligasjoner': ('statsobligasjon',),
'statsoverhoda': ('statsoverhode',),
'statsoverhode': ('statsoverhode',),
'statsoverhodene': ('statsoverhode',),
'statsoverhoder': ('statsoverhode',),
'statsoverhodet': ('statsoverhode',),
'statsregnskap': ('statsregnskap',),
'statsregnskapa': ('statsregnskap',),
'statsregnskapene': ('statsregnskap',),
'statsregnskaper': ('statsregnskap',),
'statsregnskapet': ('statsregnskap',),
'statsrekneskap': ('statsrekneskap',),
'statsrekneskapen': ('statsrekneskap',),
'statsrekneskapene': ('statsrekneskap',),
'statsrekneskaper': ('statsrekneskap',),
'statsreligion': ('statsreligion',),
'statsreligionen': ('statsreligion',),
'statsreligionene': ('statsreligion',),
'statsreligioner': ('statsreligion',),
'statsrett': ('statsrett',),
'statsretten': ('statsrett',),
'statsrettene': ('statsrett',),
'statsretter': ('statsrett',),
'statsråd': ('statsråd',),
'statsråden': ('statsråd',),
'statsrådene': ('statsråd',),
'statsråder': ('statsråd',),
'statsråd': ('statsråd',),
'statsråda': ('statsråd',),
'statsrådene': ('statsråd',),
'statsrådet': ('statsråd',),
'statsrådpost': ('statsrådpost',),
'statsrådposten': ('statsrådpost',),
'statsrådpostene': ('statsrådpost',),
'statsrådposter': ('statsrådpost',),
'statsrådsak': ('statsrådsak',),
'statsrådsaka': ('statsrådsak',),
'statsrådsaken': ('statsrådsak',),
'statsrådsakene': ('statsrådsak',),
'statsrådsaker': ('statsrådsak',),
'statsrådssekretær': ('statsrådssekretær',),
'statsrådssekretæren': ('statsrådssekretær',),
'statsrådssekretærene': ('statsrådssekretær',),
'statsrådssekretærer': ('statsrådssekretær',),
'statssekretær': ('statssekretær',),
'statssekretæren': ('statssekretær',),
'statssekretærene': ('statssekretær',),
'statssekretærer': ('statssekretær',),
'statssjef': ('statssjef',),
'statssjefen': ('statssjef',),
'statssjefene': ('statssjef',),
'statssjefer': ('statssjef',),
'statsskatt': ('statsskatt',),
'statsskatten': ('statsskatt',),
'statsskattene': ('statsskatt',),
'statsskatter': ('statsskatt',),
'statsskog': ('statsskog',),
'statsskogen': ('statsskog',),
'statsskogene': ('statsskog',),
'statsskoger': ('statsskog',),
'statsstipend': ('statsstipend',),
'statsstipenda': ('statsstipend',),
'statsstipendene': ('statsstipend',),
'statsstipender': ('statsstipend',),
'statsstipendet': ('statsstipend',),
'statsstipendiat': ('statsstipendiat',),
'statsstipendiaten': ('statsstipendiat',),
'statsstipendiatene': ('statsstipendiat',),
'statsstipendiater': ('statsstipendiat',),
'statsstipendia': ('statsstipendium',),
'statsstipendiene': ('statsstipendium',),
'statsstipendier': ('statsstipendium',),
'statsstipendiet': ('statsstipendium',),
'statsstipendium': ('statsstipendium',),
'statsstyra': ('statsstyre',),
'statsstyre': ('statsstyre',),
'statsstyrene': ('statsstyre',),
'statsstyrer': ('statsstyre',),
'statsstyret': ('statsstyre',),
'statsstøtta': ('statsstøtte',),
'statsstøtte': ('statsstøtte',),
'statsstøtten': ('statsstøtte',),
'statsstøttene': ('statsstøtte',),
'statsstøtter': ('statsstøtte',),
'statstilskott': ('statstilskott',),
'statstilskotta': ('statstilskott',),
'statstilskottene': ('statstilskott',),
'statstilskottet': ('statstilskott',),
'statstilskudd': ('statstilskudd',),
'statstilskudda': ('statstilskudd',),
'statstilskuddene': ('statstilskudd',),
'statstilskuddet': ('statstilskudd',),
'statstjenestemann': ('statstjenestemann',),
'statstjenestemannen': ('statstjenestemann',),
'statstjenestemenn': ('statstjenestemann',),
'statstjenestemennene': ('statstjenestemann',),
'statsvitenskap': ('statsvitenskap',),
'statsvitenskapen': ('statsvitenskap',),
'statsvitenskapene': ('statsvitenskap',),
'statsvitenskaper': ('statsvitenskap',),
'statsviter': ('statsviter',),
'statsvitere': ('statsviter',),
'statsviteren': ('statsviter',),
'statsviterer': ('statsviter',),
'statsviterne': ('statsviter',),
'statsvitskap': ('statsvitskap',),
'statsvitskapen': ('statsvitskap',),
'statsvitskapene': ('statsvitskap',),
'statsvitskaper': ('statsvitskap',),
'stattholder': ('stattholder',),
'stattholdere': ('stattholder',),
'stattholderen': ('stattholder',),
'stattholderer': ('stattholder',),
'stattholderne': ('stattholder',),
'statue': ('statue',),
'statuen': ('statue',),
'statuene': ('statue',),
'statuer': ('statue',),
'statuett': ('statuett',),
'statuetten': ('statuett',),
'statuettene': ('statuett',),
'statuetter': ('statuett',),
'statur': ('statur',),
'staturen': ('statur',),
'staturene': ('statur',),
'staturer': ('statur',),
'status': ('status',),
'statusen': ('status',),
'statusene': ('status',),
'statuser': ('status',),
'status quo': ('status quo',),
'statusjag': ('statusjag',),
'statusjaga': ('statusjag',),
'statusjagene': ('statusjag',),
'statusjaget': ('statusjag',),
'statussymbol': ('statussymbol',),
'statussymbola': ('statussymbol',),
'statussymbolene': ('statussymbol',),
'statussymboler': ('statussymbol',),
'statussymbolet': ('statussymbol',),
'statutt': ('statutt',),
'statutta': ('statutt',),
'statutten': ('statutt',),
'statuttene': ('statutt',),
'statutter': ('statutt',),
'statuttet': ('statutt',),
'staude': ('staude',),
'stauden': ('staude',),
'staudene': ('staude',),
'stauder': ('staude',),
'staup': ('staup',),
'staupa': ('staup',),
'staupene': ('staup',),
'staupet': ('staup',),
'staup': ('staup',),
'staupa': ('staup',),
'staupene': ('staup',),
'staupet': ('staup',),
'staur': ('staur',),
'stauren': ('staur',),
'staurene': ('staur',),
'staurer': ('staur',),
'staurhval': ('staurhval',),
'staurhvalen': ('staurhval',),
'staurhvalene': ('staurhval',),
'staurhvaler': ('staurhval',),
'staurkval': ('staurkval',),
'staurkvalen': ('staurkval',),
'staurkvalene': ('staurkval',),
'staurkvaler': ('staurkval',),
'staurlag': ('staurlag',),
'staurlaga': ('staurlag',),
'staurlagene': ('staurlag',),
'staurlaget': ('staurlag',),
'staurstang': ('staurstang',),
'staurstanga': ('staurstang',),
'staurstangen': ('staurstang',),
'staurstengene': ('staurstang',),
'staurstenger': ('staurstang',),
'staut': ('staut',),
'stauta': ('staut',),
'stauten': ('staut',),
'stautene': ('staut',),
'stauter': ('staut',),
'stautet': ('staut',),
'staut': ('staut',),
'stav': ('stav',),
'staven': ('stav',),
'stavene': ('stav',),
'staver': ('stav',),
'stavbakterie': ('stavbakterie',),
'stavbakterien': ('stavbakterie',),
'stavbakteriene': ('stavbakterie',),
'stavbakterier': ('stavbakterie',),
'stavelse': ('stavelse',),
'stavelsen': ('stavelse',),
'stavelsene': ('stavelse',),
'stavelser': ('stavelse',),
'stavelsesaksent': ('stavelsesaksent',),
'stavelsesaksenten': ('stavelsesaksent',),
'stavelsesaksentene': ('stavelsesaksent',),
'stavelsesaksenter': ('stavelsesaksent',),
'stavelsesskrift': ('stavelsesskrift',),
'stavelsesskrifta': ('stavelsesskrift',),
'stavelsesskriften': ('stavelsesskrift',),
'stavelsesskriftene': ('stavelsesskrift',),
'stavelsesskrifter': ('stavelsesskrift',),
'stavelsestrykk': ('stavelsestrykk',),
'stavelsestrykka': ('stavelsestrykk',),
'stavelsestrykkene': ('stavelsestrykk',),
'stavelsestrykket': ('stavelsestrykk',),
'stavemåte': ('stavemåte',),
'stavemåten': ('stavemåte',),
'stavemåtene': ('stavemåte',),
'stavemåter': ('stavemåte',),
'stavhopp': ('stavhopp',),
'stavhoppa': ('stavhopp',),
'stavhoppene': ('stavhopp',),
'stavhoppet': ('stavhopp',),
'stavhopper': ('stavhopper',),
'stavhoppere': ('stavhopper',),
'stavhopperen': ('stavhopper',),
'stavhopperer': ('stavhopper',),
'stavhopperne': ('stavhopper',),
'staving': ('staving',),
'stavinga': ('staving',),
'stavingen': ('staving',),
'stavingene': ('staving',),
'stavinger': ('staving',),
'stavingsaksent': ('stavingsaksent',),
'stavingsaksenten': ('stavingsaksent',),
'stavingsaksentene': ('stavingsaksent',),
'stavingsaksenter': ('stavingsaksent',),
'stavingsskrift': ('stavingsskrift',),
'stavingsskrifta': ('stavingsskrift',),
'stavingsskriften': ('stavingsskrift',),
'stavingsskriftene': ('stavingsskrift',),
'stavingsskrifter': ('stavingsskrift',),
'stavingstrykk': ('stavingstrykk',),
'stavingstrykka': ('stavingstrykk',),
'stavingstrykkene': ('stavingstrykk',),
'stavingstrykket': ('stavingstrykk',),
'stavkirka': ('stavkirke',),
'stavkirke': ('stavkirke',),
'stavkirken': ('stavkirke',),
'stavkirkene': ('stavkirke',),
'stavkirker': ('stavkirke',),
'stavkjerka': ('stavkjerke',),
'stavkjerke': ('stavkjerke',),
'stavkjerken': ('stavkjerke',),
'stavkjerkene': ('stavkjerke',),
'stavkjerker': ('stavkjerke',),
'stavn': ('stavn',),
'stavnen': ('stavn',),
'stavnene': ('stavn',),
'stavner': ('stavn',),
'stavn': ('stavn',),
'stavnen': ('stavn',),
'stavnene': ('stavn',),
'stavner': ('stavn',),
'stavnsband': ('stavnsband',),
'stavnsbanda': ('stavnsband',),
'stavnsbandene': ('stavnsband',),
'stavnsbandet': ('stavnsband',),
'stavnsbånd': ('stavnsbånd',),
'stavnsbånda': ('stavnsbånd',),
'stavnsbåndene': ('stavnsbånd',),
'stavnsbåndet': ('stavnsbånd',),
'stavsprang': ('stavsprang',),
'stavspranga': ('stavsprang',),
'stavsprangene': ('stavsprang',),
'stavspranget': ('stavsprang',),
'stavtak': ('stavtak',),
'stavtaka': ('stavtak',),
'stavtakene': ('stavtak',),
'stavtaket': ('stavtak',),
'stayer': ('stayer',),
'stayere': ('stayer',),
'stayeren': ('stayer',),
'stayerer': ('stayer',),
'stayerne': ('stayer',),
'stayerevna': ('stayerevne',),
'stayerevne': ('stayerevne',),
'stayerevnen': ('stayerevne',),
'stayerevnene': ('stayerevne',),
'stayerevner': ('stayerevne',),
'ste': ('ste',),
'stea': ('ste',),
'steene': ('ste',),
'steet': ('ste',),
'steamer': ('steamer',),
'steamere': ('steamer',),
'steameren': ('steamer',),
'steamerer': ('steamer',),
'steamerne': ('steamer',),
'stearin': ('stearin',),
'stearinen': ('stearin',),
'stearinene': ('stearin',),
'steariner': ('stearin',),
'stearinlys': ('stearinlys',),
'stearinlysa': ('stearinlys',),
'stearinlysene': ('stearinlys',),
'stearinlyset': ('stearinlys',),
'stebarn': ('stebarn',),
'stebarna': ('stebarn',),
'stebarnene': ('stebarn',),
'stebarnet': ('stebarn',),
'sted': ('sted',),
'stedene': ('sted',),
'steder': ('sted',),
'stedet': ('sted',),
'stedatter': ('stedatter',),
'stedattera': ('stedatter',),
'stedatteren': ('stedatter',),
'stedøtre': ('stedatter',),
'stedøtrene': ('stedatter',),
'stedøtrer': ('stedatter',),
'stedfortreder': ('stedfortreder',),
'stedfortredere': ('stedfortreder',),
'stedfortrederen': ('stedfortreder',),
'stedfortrederer': ('stedfortreder',),
'stedfortrederne': ('stedfortreder',),
'stedsadverb': ('stedsadverb',),
'stedsadverba': ('stedsadverb',),
'stedsadverbene': ('stedsadverb',),
'stedsadverber': ('stedsadverb',),
'stedsadverbet': ('stedsadverb',),
'stedsadverbial': ('stedsadverbial',),
'stedsadverbiala': ('stedsadverbial',),
'stedsadverbialene': ('stedsadverbial',),
'stedsadverbialer': ('stedsadverbial',),
'stedsadverbialet': ('stedsadverbial',),
'stedsadverbia': ('stedsadverbium',),
'stedsadverbiene': ('stedsadverbium',),
'stedsadverbier': ('stedsadverbium',),
'stedsadverbiet': ('stedsadverbium',),
'stedsadverbium': ('stedsadverbium',),
'stedsangivelse': ('stedsangivelse',),
'stedsangivelsen': ('stedsangivelse',),
'stedsangivelsene': ('stedsangivelse',),
'stedsangivelser': ('stedsangivelse',),
'stedsans': ('stedsans',),
'stedsansen': ('stedsans',),
'stedsansene': ('stedsans',),
'stedsanser': ('stedsans',),
'stedsnavn': ('stedsnavn',),
'stedsnavna': ('stedsnavn',),
'stedsnavnene': ('stedsnavn',),
'stedsnavnet': ('stedsnavn',),
'steeple-chasa': ('steeple-chase',),
'steeple-chase': ('steeple-chase',),
'steeple-chasene': ('steeple-chase',),
'steeple-chaset': ('steeple-chase',),
'stefar': ('stefar',),
'stefaren': ('stefar',),
'stefedre': ('stefar',),
'stefedrene': ('stefar',),
'steg': ('steg',),
'stega': ('steg',),
'stegene': ('steg',),
'steget': ('steg',),
'stegg': ('stegg',),
'steggen': ('stegg',),
'steggene': ('stegg',),
'stegger': ('stegg',),
'stegjern': ('stegjern',),
'stegjerna': ('stegjern',),
'stegjernene': ('stegjern',),
'stegjernet': ('stegjern',),
'steik': ('steik',),
'steiken': ('steik',),
'steikene': ('steik',),
'steiker': ('steik',),
'steik': ('steik',),
'steika': ('steik',),
'steiken': ('steik',),
'steikene': ('steik',),
'steiker': ('steik',),
'steikefat': ('steikefat',),
'steikefata': ('steikefat',),
'steikefatene': ('steikefat',),
'steikefater': ('steikefat',),
'steikefatet': ('steikefat',),
'steikefisk': ('steikefisk',),
'steikefisken': ('steikefisk',),
'steikefiskene': ('steikefisk',),
'steikefisker': ('steikefisk',),
'steikeomn': ('steikeomn',),
'steikeomnen': ('steikeomn',),
'steikeomnene': ('steikeomn',),
'steikeomner': ('steikeomn',),
'steikeovn': ('steikeovn',),
'steikeovnen': ('steikeovn',),
'steikeovnene': ('steikeovn',),
'steikeovner': ('steikeovn',),
'steikepanna': ('steikepanne',),
'steikepanne': ('steikepanne',),
'steikepannen': ('steikepanne',),
'steikepannene': ('steikepanne',),
'steikepanner': ('steikepanne',),
'steiketermometer': ('steiketermometer',),
'steiketermometeret': ('steiketermometer',),
'steiketermometra': ('steiketermometer',),
'steiketermometre': ('steiketermometer',),
'steiketermometrene': ('steiketermometer',),
'steiketermometret': ('steiketermometer',),
'steile': ('steile',),
'steilen': ('steile',),
'steilene': ('steile',),
'steiler': ('steile',),
'steilskrift': ('steilskrift',),
'steilskrifta': ('steilskrift',),
'steilskriften': ('steilskrift',),
'steilskriftene': ('steilskrift',),
'steilskrifter': ('steilskrift',),
'stein': ('stein',),
'steinen': ('stein',),
'steinene': ('stein',),
'steiner': ('stein',),
'steinalder': ('steinalder',),
'steinaldere': ('steinalder',),
'steinalderen': ('steinalder',),
'steinalderer': ('steinalder',),
'steinalderne': ('steinalder',),
'steinaldre': ('steinalder',),
'steinaldrene': ('steinalder',),
'steinaldrer': ('steinalder',),
'steinansikt': ('steinansikt',),
'steinansikta': ('steinansikt',),
'steinansiktene': ('steinansikt',),
'steinansikter': ('steinansikt',),
'steinansiktet': ('steinansikt',),
'steinbed': ('steinbed',),
'steinbeda': ('steinbed',),
'steinbedene': ('steinbed',),
'steinbedet': ('steinbed',),
'steinbit': ('steinbit',),
'steinbiten': ('steinbit',),
'steinbitene': ('steinbit',),
'steinbiter': ('steinbit',),
'steinbrott': ('steinbrott',),
'steinbrotta': ('steinbrott',),
'steinbrottene': ('steinbrott',),
'steinbrottet': ('steinbrott',),
'steinbrudd': ('steinbrudd',),
'steinbrudda': ('steinbrudd',),
'steinbruddene': ('steinbrudd',),
'steinbruddet': ('steinbrudd',),
'steinbukk': ('steinbukk',),
'steinbukken': ('steinbukk',),
'steinbukkene': ('steinbukk',),
'steinbukker': ('steinbukk',),
'steindulp': ('steindulp',),
'steindulpen': ('steindulp',),
'steindulpene': ('steindulp',),
'steindulper': ('steindulp',),
'steinflua': ('steinflue',),
'steinflue': ('steinflue',),
'steinfluen': ('steinflue',),
'steinfluene': ('steinflue',),
'steinfluer': ('steinflue',),
'steinfrukt': ('steinfrukt',),
'steinfrukta': ('steinfrukt',),
'steinfrukten': ('steinfrukt',),
'steinfruktene': ('steinfrukt',),
'steinfrukter': ('steinfrukt',),
'steinfruktfamilie': ('steinfruktfamilie',),
'steinfruktfamilien': ('steinfruktfamilie',),
'steinfruktfamiliene': ('steinfruktfamilie',),
'steinfruktfamilier': ('steinfruktfamilie',),
'steinhogger': ('steinhogger',),
'steinhoggere': ('steinhogger',),
'steinhoggeren': ('steinhogger',),
'steinhoggerer': ('steinhogger',),
'steinhoggerne': ('steinhogger',),
'steinhugger': ('steinhugger',),
'steinhuggere': ('steinhugger',),
'steinhuggeren': ('steinhugger',),
'steinhuggerer': ('steinhugger',),
'steinhuggerne': ('steinhugger',),
'steining': ('steining',),
'steininga': ('steining',),
'steiningen': ('steining',),
'steiningene': ('steining',),
'steininger': ('steining',),
'steinkast': ('steinkast',),
'steinkasta': ('steinkast',),
'steinkastene': ('steinkast',),
'steinkastet': ('steinkast',),
'steinkobbe': ('steinkobbe',),
'steinkobben': ('steinkobbe',),
'steinkobbene': ('steinkobbe',),
'steinkobber': ('steinkobbe',),
'steinkol': ('steinkol',),
'steinkola': ('steinkol',),
'steinkolene': ('steinkol',),
'steinkolet': ('steinkol',),
'steinkolavleiring': ('steinkolavleiring',),
'steinkolavleiringa': ('steinkolavleiring',),
'steinkolavleiringen': ('steinkolavleiring',),
'steinkolavleiringene': ('steinkolavleiring',),
'steinkolavleiringer': ('steinkolavleiring',),
'steinkull': ('steinkull',),
'steinkulla': ('steinkull',),
'steinkullene': ('steinkull',),
'steinkullet': ('steinkull',),
'steinkullavleiring': ('steinkullavleiring',),
'steinkullavleiringa': ('steinkullavleiring',),
'steinkullavleiringen': ('steinkullavleiring',),
'steinkullavleiringene': ('steinkullavleiring',),
'steinkullavleiringer': ('steinkullavleiring',),
'steinrøys': ('steinrøys',),
'steinrøysa': ('steinrøys',),
'steinrøysen': ('steinrøys',),
'steinrøysene': ('steinrøys',),
'steinrøyser': ('steinrøys',),
'steinsalt': ('steinsalt',),
'steinsalta': ('steinsalt',),
'steinsaltene': ('steinsalt',),
'steinsalter': ('steinsalt',),
'steinsaltet': ('steinsalt',),
'steinskvett': ('steinskvett',),
'steinskvetten': ('steinskvett',),
'steinskvettene': ('steinskvett',),
'steinskvetter': ('steinskvett',),
'steinsopp': ('steinsopp',),
'steinsoppen': ('steinsopp',),
'steinsoppene': ('steinsopp',),
'steinsopper': ('steinsopp',),
'steinsprang': ('steinsprang',),
'steinspranga': ('steinsprang',),
'steinsprangene': ('steinsprang',),
'steinspranget': ('steinsprang',),
'steinsprut': ('steinsprut',),
'steinspruten': ('steinsprut',),
'steinsprutene': ('steinsprut',),
'steinspruter': ('steinsprut',),
'steinstøtta': ('steinstøtte',),
'steinstøtte': ('steinstøtte',),
'steinstøtten': ('steinstøtte',),
'steinstøttene': ('steinstøtte',),
'steinstøtter': ('steinstøtte',),
'steinsvans': ('steinsvans',),
'steinsvansen': ('steinsvans',),
'steinsvansene': ('steinsvans',),
'steinsvanser': ('steinsvans',),
'steintavla': ('steintavle',),
'steintavle': ('steintavle',),
'steintavlen': ('steintavle',),
'steintavlene': ('steintavle',),
'steintavler': ('steintavle',),
'steintipp': ('steintipp',),
'steintippen': ('steintipp',),
'steintippene': ('steintipp',),
'steintipper': ('steintipp',),
'steintrykk': ('steintrykk',),
'steintrykka': ('steintrykk',),
'steintrykkene': ('steintrykk',),
'steintrykket': ('steintrykk',),
'steintøy': ('steintøy',),
'steintøya': ('steintøy',),
'steintøyene': ('steintøy',),
'steintøyer': ('steintøy',),
'steintøyet': ('steintøy',),
'steinull': ('steinull',),
'steinulla': ('steinull',),
'steinullen': ('steinull',),
'steinullene': ('steinull',),
'steinuller': ('steinull',),
'steinvender': ('steinvender',),
'steinvendere': ('steinvender',),
'steinvenderen': ('steinvender',),
'steinvenderer': ('steinvender',),
'steinvenderne': ('steinvender',),
'steinørken': ('steinørken',),
'steinørkenen': ('steinørken',),
'steinørkenene': ('steinørken',),
'steinørkener': ('steinørken',),
'stek': ('stek',),
'steken': ('stek',),
'stekene': ('stek',),
'steker': ('stek',),
'stek': ('stek',),
'steka': ('stek',),
'steken': ('stek',),
'stekene': ('stek',),
'steker': ('stek',),
'stekefat': ('stekefat',),
'stekefata': ('stekefat',),
'stekefatene': ('stekefat',),
'stekefater': ('stekefat',),
'stekefatet': ('stekefat',),
'stekefisk': ('stekefisk',),
'stekefisken': ('stekefisk',),
'stekefiskene': ('stekefisk',),
'stekefisker': ('stekefisk',),
'stekeomn': ('stekeomn',),
'stekeomnen': ('stekeomn',),
'stekeomnene': ('stekeomn',),
'stekeomner': ('stekeomn',),
'stekeovn': ('stekeovn',),
'stekeovnen': ('stekeovn',),
'stekeovnene': ('stekeovn',),
'stekeovner': ('stekeovn',),
'stekepanna': ('stekepanne',),
'stekepanne': ('stekepanne',),
'stekepannen': ('stekepanne',),
'stekepannene': ('stekepanne',),
'stekepanner': ('stekepanne',),
'steketermometer': ('steketermometer',),
'steketermometeret': ('steketermometer',),
'steketermometra': ('steketermometer',),
'steketermometre': ('steketermometer',),
'steketermometrene': ('steketermometer',),
'steketermometret': ('steketermometer',),
'stele': ('stele',),
'stelen': ('stele',),
'stelene': ('stele',),
'steler': ('stele',),
'steler': ('steler',),
'stelere': ('steler',),
'steleren': ('steler',),
'stelerer': ('steler',),
'stelerne': ('steler',),
'steler': ('steler',),
'stelere': ('steler',),
'steleren': ('steler',),
'stelerer': ('steler',),
'stelerne': ('steler',),
'stell': ('stell',),
'stella': ('stell',),
'stellene': ('stell',),
'stellet': ('stell',),
'stella': ('stella',),
'stellebord': ('stellebord',),
'stelleborda': ('stellebord',),
'stellebordene': ('stellebord',),
'stelleborder': ('stellebord',),
'stellebordet': ('stellebord',),
'stellerand': ('stellerand',),
'stelleranda': ('stellerand',),
'stelleranden': ('stellerand',),
'stellerendene': ('stellerand',),
'stellerender': ('stellerand',),
'stemjern': ('stemjern',),
'stemjerna': ('stemjern',),
'stemjernene': ('stemjern',),
'stemjernet': ('stemjern',),
'stemme': ('stemme',),
'stemmen': ('stemme',),
'stemmene': ('stemme',),
'stemmer': ('stemme',),
'stemmeband': ('stemmeband',),
'stemmebanda': ('stemmeband',),
'stemmebandene': ('stemmeband',),
'stemmebandet': ('stemmeband',),
'stemmebruk': ('stemmebruk',),
'stemmebruka': ('stemmebruk',),
'stemmebruken': ('stemmebruk',),
'stemmebrukene': ('stemmebruk',),
'stemmebruker': ('stemmebruk',),
'stemmebruket': ('stemmebruk',),
'stemmebånd': ('stemmebånd',),
'stemmebånda': ('stemmebånd',),
'stemmebåndene': ('stemmebånd',),
'stemmebåndet': ('stemmebånd',),
'stemmegaffel': ('stemmegaffel',),
'stemmegaffelen': ('stemmegaffel',),
'stemmegaflene': ('stemmegaffel',),
'stemmegafler': ('stemmegaffel',),
'stemmegiing': ('stemmegiing',),
'stemmegiinga': ('stemmegiing',),
'stemmegiingen': ('stemmegiing',),
'stemmegiingene': ('stemmegiing',),
'stemmegiinger': ('stemmegiing',),
'stemmegiving': ('stemmegiving',),
'stemmegivinga': ('stemmegiving',),
'stemmegivingen': ('stemmegiving',),
'stemmegivingene': ('stemmegiving',),
'stemmegivinger': ('stemmegiving',),
'stemmegivning': ('stemmegivning',),
'stemmegivninga': ('stemmegivning',),
'stemmegivningen': ('stemmegivning',),
'stemmegivningene': ('stemmegivning',),
'stemmegivninger': ('stemmegivning',),
'stemmekveg': ('stemmekveg',),
'stemmekvega': ('stemmekveg',),
'stemmekvegene': ('stemmekveg',),
'stemmekveget': ('stemmekveg',),
'stemmeleia': ('stemmeleie',),
'stemmeleie': ('stemmeleie',),
'stemmeleiene': ('stemmeleie',),
'stemmeleier': ('stemmeleie',),
'stemmeleiet': ('stemmeleie',),
'stemmeprakt': ('stemmeprakt',),
'stemmeprakta': ('stemmeprakt',),
'stemmeprakten': ('stemmeprakt',),
'stemmepraktene': ('stemmeprakt',),
'stemmeprakter': ('stemmeprakt',),
'stemmer': ('stemmer',),
'stemmere': ('stemmer',),
'stemmeren': ('stemmer',),
'stemmerer': ('stemmer',),
'stemmerne': ('stemmer',),
'stemmerett': ('stemmerett',),
'stemmeretten': ('stemmerett',),
'stemmerettene': ('stemmerett',),
'stemmeretter': ('stemmerett',),
'stemmeseddel': ('stemmeseddel',),
'stemmeseddelen': ('stemmeseddel',),
'stemmesedlene': ('stemmeseddel',),
'stemmesedler': ('stemmeseddel',),
'stemmeskifta': ('stemmeskifte',),
'stemmeskifte': ('stemmeskifte',),
'stemmeskiftene': ('stemmeskifte',),
'stemmeskifter': ('stemmeskifte',),
'stemmeskiftet': ('stemmeskifte',),
'stemmeskifting': ('stemmeskifting',),
'stemmeskiftinga': ('stemmeskifting',),
'stemmeskiftingen': ('stemmeskifting',),
'stemmeskiftingene': ('stemmeskifting',),
'stemmeskiftinger': ('stemmeskifting',),
'stemna': ('stemne',),
'stemne': ('stemne',),
'stemnen': ('stemne',),
'stemnene': ('stemne',),
'stemner': ('stemne',),
'stemnet': ('stemne',),
'stevna': ('stevne',),
'stevne': ('stevne',),
'stevnene': ('stevne',),
'stevner': ('stevne',),
'stevnet': ('stevne',),
'stemnedag': ('stemnedag',),
'stemnedagen': ('stemnedag',),
'stemnedagene': ('stemnedag',),
'stemnedager': ('stemnedag',),
'stemnedag': ('stemnedag',),
'stemnedagen': ('stemnedag',),
'stemnedagene': ('stemnedag',),
'stemnedager': ('stemnedag',),
'stemnelei': ('stemnelei',),
'stemneleia': ('stemnelei',),
'stemneleien': ('stemnelei',),
'stemneleiene': ('stemnelei',),
'stemneleier': ('stemnelei',),
'stemnelei': ('stemnelei',),
'stemneleia': ('stemnelei',),
'stemneleien': ('stemnelei',),
'stemneleiene': ('stemnelei',),
'stemneleier': ('stemnelei',),
'stemnemøta': ('stemnemøte',),
'stemnemøte': ('stemnemøte',),
'stemnemøtene': ('stemnemøte',),
'stemnemøter': ('stemnemøte',),
'stemnemøtet': ('stemnemøte',),
'stemnemøta': ('stemnemøte',),
'stemnemøte': ('stemnemøte',),
'stemnemøtene': ('stemnemøte',),
'stemnemøter': ('stemnemøte',),
'stemnemøtet': ('stemnemøte',),
'stillverk': ('stillverk',),
'stillverka': ('stillverk',),
'stillverkene': ('stillverk',),
'stillverker': ('stillverk',),
'stillverket': ('stillverk',),
'stillæra': ('stillære',),
'stillære': ('stillære',),
'stillæren': ('stillære',),
'stillærene': ('stillære',),
'stillærer': ('stillære',),
'stilmøbel': ('stilmøbel',),
'stilmøbelet': ('stilmøbel',),
'stilmøbla': ('stilmøbel',),
'stilmøblene': ('stilmøbel',),
'stilmøbler': ('stilmøbel',),
'stilmøblet': ('stilmøbel',),
'stiloppgava': ('stiloppgave',),
'stiloppgave': ('stiloppgave',),
'stiloppgaven': ('stiloppgave',),
'stiloppgavene': ('stiloppgave',),
'stiloppgaver': ('stiloppgave',),
'stilperiode': ('stilperiode',),
'stilperioden': ('stilperiode',),
'stilperiodene': ('stilperiode',),
'stilperioder': ('stilperiode',),
'stilsans': ('stilsans',),
'stilsansen': ('stilsans',),
'stilsansene': ('stilsans',),
'stilsanser': ('stilsans',),
'stilskriving': ('stilskriving',),
'stilskrivinga': ('stilskriving',),
'stilskrivingen': ('stilskriving',),
'stilskrivingene': ('stilskriving',),
'stilskrivinger': ('stilskriving',),
'stilskrivning': ('stilskrivning',),
'stilskrivninga': ('stilskrivning',),
'stilskrivningen': ('stilskrivning',),
'stilskrivningene': ('stilskrivning',),
'stilskrivninger': ('stilskrivning',),
'stim': ('stim',),
'stimen': ('stim',),
'stimene': ('stim',),
'stimer': ('stim',),
'stim': ('stim',),
'stima': ('stim',),
'stimene': ('stim',),
'stimet': ('stim',),
'stim': ('stim',),
'stima': ('stim',),
'stimen': ('stim',),
'stimene': ('stim',),
'stimer': ('stim',),
'stimet': ('stim',),
'stimann': ('stimann',),
'stimannen': ('stimann',),
'stimenn': ('stimann',),
'stimennene': ('stimann',),
'stimbåt': ('stimbåt',),
'stimbåten': ('stimbåt',),
'stimbåtene': ('stimbåt',),
'stimbåter': ('stimbåt',),
'stimfisk': ('stimfisk',),
'stimfisken': ('stimfisk',),
'stimfiskene': ('stimfisk',),
'stimfisker': ('stimfisk',),
'stimlene': ('stimmel',),
'stimler': ('stimmel',),
'stimmel': ('stimmel',),
'stimmelen': ('stimmel',),
'stimrens': ('stimrens',),
'stimrensen': ('stimrens',),
'stimrensene': ('stimrens',),
'stimrenser': ('stimrens',),
'stimulans': ('stimulans',),
'stimulansen': ('stimulans',),
'stimulansene': ('stimulans',),
'stimulanser': ('stimulans',),
'stimulator': ('stimulator',),
'stimulatoren': ('stimulator',),
'stimulatorene': ('stimulator',),
'stimulatorer': ('stimulator',),
'stimuli': ('stimulus',),
'stimuliene': ('stimulus',),
'stimulus': ('stimulus',),
'stimulusen': ('stimulus',),
'sting': ('sting',),
'stinga': ('sting',),
'stingene': ('sting',),
'stinget': ('sting',),
'stingsild': ('stingsild',),
'stingsilda': ('stingsild',),
'stingsilden': ('stingsild',),
'stingsildene': ('stingsild',),
'stingsilder': ('stingsild',),
'stinkador': ('stinkador',),
'stinkadoren': ('stinkador',),
'stinkadorene': ('stinkador',),
'stinkadorer': ('stinkador',),
'stinkbomba': ('stinkbombe',),
'stinkbombe': ('stinkbombe',),
'stinkbomben': ('stinkbombe',),
'stinkbombene': ('stinkbombe',),
'stinkbomber': ('stinkbombe',),
'stinkdyr': ('stinkdyr',),
'stinkdyra': ('stinkdyr',),
'stinkdyrene': ('stinkdyr',),
'stinkdyret': ('stinkdyr',),
'stinta': ('stinte',),
'stinte': ('stinte',),
'stinten': ('stinte',),
'stintene': ('stinte',),
'stinter': ('stinte',),
'stipend': ('stipend',),
'stipenda': ('stipend',),
'stipendene': ('stipend',),
'stipender': ('stipend',),
'stipendet': ('stipend',),
'stipendiat': ('stipendiat',),
'stipendiaten': ('stipendiat',),
'stipendiatene': ('stipendiat',),
'stipendiater': ('stipendiat',),
'stipendiereisa': ('stipendiereise',),
'stipendiereise': ('stipendiereise',),
'stipendiereisen': ('stipendiereise',),
'stipendiereisene': ('stipendiereise',),
'stipendiereiser': ('stipendiereise',),
'stipendia': ('stipendium',),
'stipendiene': ('stipendium',),
'stipendier': ('stipendium',),
'stipendiet': ('stipendium',),
'stipendium': ('stipendium',),
'stipendreisa': ('stipendreise',),
'stipendreise': ('stipendreise',),
'stipendreisen': ('stipendreise',),
'stipendreisene': ('stipendreise',),
'stipendreiser': ('stipendreise',),
'stipulasjon': ('stipulasjon',),
'stipulasjonen': ('stipulasjon',),
'stipulasjonene': ('stipulasjon',),
'stipulasjoner': ('stipulasjon',),
'stivelse': ('stivelse',),
'stivelsen': ('stivelse',),
'stivelsene': ('stivelse',),
'stivelser': ('stivelse',),
'stivetøy': ('stivetøy',),
'stivetøya': ('stivetøy',),
'stivetøyene': ('stivetøy',),
'stivetøyer': ('stivetøy',),
'stivetøyet': ('stivetøy',),
'stivkrampe': ('stivkrampe',),
'stivkrampen': ('stivkrampe',),
'stivkrampene': ('stivkrampe',),
'stivkramper': ('stivkrampe',),
'stivnakke': ('stivnakke',),
'stivnakken': ('stivnakke',),
'stivnakkene': ('stivnakke',),
'stivnakker': ('stivnakke',),
'stivsinn': ('stivsinn',),
'stivsinna': ('stivsinn',),
'stivsinnene': ('stivsinn',),
'stivsinnet': ('stivsinn',),
'stjeler': ('stjeler',),
'stjelere': ('stjeler',),
'stjeleren': ('stjeler',),
'stjelerer': ('stjeler',),
'stjelerne': ('stjeler',),
'stjeler': ('stjeler',),
'stjelere': ('stjeler',),
'stjeleren': ('stjeler',),
'stjelerer': ('stjeler',),
'stjelerne': ('stjeler',),
'stjerna': ('stjerne',),
'stjerne': ('stjerne',),
'stjernen': ('stjerne',),
'stjernene': ('stjerne',),
'stjerner': ('stjerne',),
'stjernebilda': ('stjernebilde',),
'stjernebilde': ('stjernebilde',),
'stjernebildene': ('stjernebilde',),
'stjernebilder': ('stjernebilde',),
'stjernebildet': ('stjernebilde',),
'stjerneblom': ('stjerneblom',),
'stjerneblommen': ('stjerneblom',),
'stjerneblommene': ('stjerneblom',),
'stjerneblommer': ('stjerneblom',),
'stjerneform': ('stjerneform',),
'stjerneforma': ('stjerneform',),
'stjerneformen': ('stjerneform',),
'stjerneformene': ('stjerneform',),
'stjerneformer': ('stjerneform',),
'stjerneglans': ('stjerneglans',),
'stjerneglansen': ('stjerneglans',),
'stjerneglansene': ('stjerneglans',),
'stjerneglanser': ('stjerneglans',),
'stjernegris': ('stjernegris',),
'stjernegrisen': ('stjernegris',),
'stjernegrisene': ('stjernegris',),
'stjernegriser': ('stjernegris',),
'stjernehimlene': ('stjernehimmel',),
'stjernehimler': ('stjernehimmel',),
'stjernehimmel': ('stjernehimmel',),
'stjernehimmelen': ('stjernehimmel',),
'stjernehop': ('stjernehop',),
'stjernehopen': ('stjernehop',),
'stjernehopene': ('stjernehop',),
'stjernehoper': ('stjernehop',),
'stjernehær': ('stjernehær',),
'stjernehæren': ('stjernehær',),
'stjernehærene': ('stjernehær',),
'stjernehærer': ('stjernehær',),
'stjerneidrett': ('stjerneidrett',),
'stjerneidretten': ('stjerneidrett',),
'stjerneidrettene': ('stjerneidrett',),
'stjerneidretter': ('stjerneidrett',),
'stjernekart': ('stjernekart',),
'stjernekarta': ('stjernekart',),
'stjernekartene': ('stjernekart',),
'stjernekarter': ('stjernekart',),
'stjernekartet': ('stjernekart',),
'stjernekiker': ('stjernekiker',),
'stjernekikere': ('stjernekiker',),
'stjernekikeren': ('stjernekiker',),
'stjernekikerer': ('stjernekiker',),
'stjernekikerne': ('stjernekiker',),
'stjernekikker': ('stjernekikker',),
'stjernekikkere': ('stjernekikker',),
'stjernekikkeren': ('stjernekikker',),
'stjernekikkerer': ('stjernekikker',),
'stjernekikkerne': ('stjernekikker',),
'stjernekikkert': ('stjernekikkert',),
'stjernekikkerten': ('stjernekikkert',),
'stjernekikkertene': ('stjernekikkert',),
'stjernekikkerter': ('stjernekikkert',),
'stjernenøkkel': ('stjernenøkkel',),
'stjernenøkkelen': ('stjernenøkkel',),
'stjernenøklene': ('stjernenøkkel',),
'stjernenøkler': ('stjernenøkkel',),
'stjernerap': ('stjernerap',),
'stjernerapa': ('stjernerap',),
'stjernerapene': ('stjernerap',),
'stjernerapet': ('stjernerap',),
'stjerneskott': ('stjerneskott',),
'stjerneskotta': ('stjerneskott',),
'stjerneskottene': ('stjerneskott',),
'stjerneskottet': ('stjerneskott',),
'stjerneskrue': ('stjerneskrue',),
'stjerneskruen': ('stjerneskrue',),
'stjerneskruene': ('stjerneskrue',),
'stjerneskruer': ('stjerneskrue',),
'stjerneskudd': ('stjerneskudd',),
'stjerneskudda': ('stjerneskudd',),
'stjerneskuddene': ('stjerneskudd',),
'stjerneskuddet': ('stjerneskudd',),
'stjernesmell': ('stjernesmell',),
'stjernesmella': ('stjernesmell',),
'stjernesmellen': ('stjernesmell',),
'stjernesmellene': ('stjernesmell',),
'stjernesmeller': ('stjernesmell',),
'stjernesmellet': ('stjernesmell',),
'stjernetegn': ('stjernetegn',),
'stjernetegna': ('stjernetegn',),
'stjernetegnene': ('stjernetegn',),
'stjernetegnet': ('stjernetegn',),
'stjernetrekker': ('stjernetrekker',),
'stjernetrekkere': ('stjernetrekker',),
'stjernetrekkeren': ('stjernetrekker',),
'stjernetrekkerer': ('stjernetrekker',),
'stjernetrekkerne': ('stjernetrekker',),
'stjernetåka': ('stjernetåke',),
'stjernetåke': ('stjernetåke',),
'stjernetåken': ('stjernetåke',),
'stjernetåkene': ('stjernetåke',),
'stjernetåker': ('stjernetåke',),
'stjernevrimlene': ('stjernevrimmel',),
'stjernevrimler': ('stjernevrimmel',),
'stjernevrimmel': ('stjernevrimmel',),
'stjernevrimmelen': ('stjernevrimmel',),
'stjert': ('stjert',),
'stjerten': ('stjert',),
'stjertene': ('stjert',),
'stjerter': ('stjert',),
'stjertand': ('stjertand',),
'stjertanda': ('stjertand',),
'stjertanden': ('stjertand',),
'stjertendene': ('stjertand',),
'stjertender': ('stjertand',),
'stjertmeis': ('stjertmeis',),
'stjertmeisa': ('stjertmeis',),
'stjertmeisen': ('stjertmeis',),
'stjertmeisene': ('stjertmeis',),
'stjertmeiser': ('stjertmeis',),
'sto': ('sto',),
'stoa': ('sto',),
'stoene': ('sto',),
'stoet': ('sto',),
'stoa': ('stoa',),
'stoaen': ('stoa',),
'stoaene': ('stoa',),
'stoaer': ('stoa',),
'stockholmer': ('stockholmer',),
'stockholmere': ('stockholmer',),
'stockholmeren': ('stockholmer',),
'stockholmerer': ('stockholmer',),
'stockholmerne': ('stockholmer',),
'stodder': ('stodder',),
'stoddere': ('stodder',),
'stodderen': ('stodder',),
'stodderer': ('stodder',),
'stodderne': ('stodder',),
'stoff': ('stoff',),
'stoffa': ('stoff',),
'stoffene': ('stoff',),
'stoffer': ('stoff',),
'stoffet': ('stoff',),
'stoffmisbruk': ('stoffmisbruk',),
'stoffmisbruka': ('stoffmisbruk',),
'stoffmisbruken': ('stoffmisbruk',),
'stoffmisbrukene': ('stoffmisbruk',),
'stoffmisbruker': ('stoffmisbruk',),
'stoffmisbruket': ('stoffmisbruk',),
'stoffmisbruker': ('stoffmisbruker',),
'stoffmisbrukere': ('stoffmisbruker',),
'stoffmisbrukeren': ('stoffmisbruker',),
'stoffmisbrukerer': ('stoffmisbruker',),
'stoffmisbrukerne': ('stoffmisbruker',),
'stoffnavn': ('stoffnavn',),
'stoffnavna': ('stoffnavn',),
'stoffnavnene': ('stoffnavn',),
'stoffnavnet': ('stoffnavn',),
'stoffskifta': ('stoffskifte',),
'stoffskifte': ('stoffskifte',),
'stoffskiftene': ('stoffskifte',),
'stoffskifter': ('stoffskifte',),
'stoffskiftet': ('stoffskifte',),
'stoiker': ('stoiker',),
'stoikere': ('stoiker',),
'stoikeren': ('stoiker',),
'stoikerer': ('stoiker',),
'stoikerne': ('stoiker',),
'stoisisme': ('stoisisme',),
'stoisismen': ('stoisisme',),
'stoisismene': ('stoisisme',),
'stoisismer': ('stoisisme',),
'stokk': ('stokk',),
'stokken': ('stokk',),
'stokkene': ('stokk',),
'stokker': ('stokk',),
'stokkand': ('stokkand',),
'stokkanda': ('stokkand',),
'stokkanden': ('stokkand',),
'stokkendene': ('stokkand',),
'stokkender': ('stokkand',),
'stokkefar': ('stokkefar',),
'stokkefara': ('stokkefar',),
'stokkefarene': ('stokkefar',),
'stokkefaret': ('stokkefar',),
'stokkeld': ('stokkeld',),
'stokkelden': ('stokkeld',),
'stokkeldene': ('stokkeld',),
'stokkelder': ('stokkeld',),
'stokkeld': ('stokkeld',),
'stokkelden': ('stokkeld',),
'stokkeldene': ('stokkeld',),
'stokkelder': ('stokkeld',),
'stokkfisk': ('stokkfisk',),
'stokkfisken': ('stokkfisk',),
'stokkfiskene': ('stokkfisk',),
'stokkfisker': ('stokkfisk',),
'stokkild': ('stokkild',),
'stokkilden': ('stokkild',),
'stokkildene': ('stokkild',),
'stokkilder': ('stokkild',),
'stokkild': ('stokkild',),
'stokkilden': ('stokkild',),
'stokkildene': ('stokkild',),
'stokkilder': ('stokkild',),
'stokkmaur': ('stokkmaur',),
'stokkmauren': ('stokkmaur',),
'stokkmaurene': ('stokkmaur',),
'stokkrosa': ('stokkrose',),
'stokkrose': ('stokkrose',),
'stokkrosen': ('stokkrose',),
'stokkrosene': ('stokkrose',),
'stokkroser': ('stokkrose',),
'stokkverk': ('stokkverk',),
'stokkverka': ('stokkverk',),
'stokkverkene': ('stokkverk',),
'stokkverker': ('stokkverk',),
'stokkverket': ('stokkverk',),
'stol': ('stol',),
'stolen': ('stol',),
'stolene': ('stol',),
'stoler': ('stol',),
'stola': ('stola',),
'stolaen': ('stola',),
'stolaene': ('stola',),
'stolaer': ('stola',),
'stolbein': ('stolbein',),
'stolbeina': ('stolbein',),
'stolbeinene': ('stolbein',),
'stolbeinet': ('stolbein',),
'stolben': ('stolben',),
'stolbena': ('stolben',),
'stolbenene': ('stolben',),
'stolbenet': ('stolben',),
'stolheis': ('stolheis',),
'stolheisen': ('stolheis',),
'stolheisene': ('stolheis',),
'stolheiser': ('stolheis',),
'stolkjerra': ('stolkjerre',),
'stolkjerre': ('stolkjerre',),
'stolkjerren': ('stolkjerre',),
'stolkjerrene': ('stolkjerre',),
'stolkjerrer': ('stolkjerre',),
'stoll': ('stoll',),
'stollen': ('stoll',),
'stollene': ('stoll',),
'stoller': ('stoll',),
'stolpe': ('stolpe',),
'stolpen': ('stolpe',),
'stolpene': ('stolpe',),
'stolper': ('stolpe',),
'stolpediagram': ('stolpediagram',),
'stolpediagramma': ('stolpediagram',),
'stolpediagrammene': ('stolpediagram',),
'stolpediagrammer': ('stolpediagram',),
'stolpediagrammet': ('stolpediagram',),
'stolpesjø': ('stolpesjø',),
'stolpesjøen': ('stolpesjø',),
'stolpesjøene': ('stolpesjø',),
'stolpesjøer': ('stolpesjø',),
'stolpesko': ('stolpesko',),
'stolpeskoa': ('stolpesko',),
'stolpeskoen': ('stolpesko',),
'stolpeskoene': ('stolpesko',),
'stolpeskor': ('stolpesko',),
'stolpeskorne': ('stolpesko',),
'stolrygg': ('stolrygg',),
'stolryggen': ('stolrygg',),
'stolryggene': ('stolrygg',),
'stolrygger': ('stolrygg',),
'stolseta': ('stolsete',),
'stolsete': ('stolsete',),
'stolsetene': ('stolsete',),
'stolseter': ('stolsete',),
'stolsetet': ('stolsete',),
'stolstiller': ('stolstiller',),
'stolstillere': ('stolstiller',),
'stolstilleren': ('stolstiller',),
'stolstillerer': ('stolstiller',),
'stolstillerne': ('stolstiller',),
'stolthet': ('stolthet',),
'stoltheta': ('stolthet',),
'stoltheten': ('stolthet',),
'stolthetene': ('stolthet',),
'stoltheter': ('stolthet',),
'stomp': ('stomp',),
'stompen': ('stomp',),
'stompene': ('stomp',),
'stomper': ('stomp',),
'stopp': ('stopp',),
'stoppen': ('stopp',),
'stoppene': ('stopp',),
'stopper': ('stopp',),
'stopp': ('stopp',),
'stoppa': ('stopp',),
'stoppen': ('stopp',),
'stoppene': ('stopp',),
'stoppet': ('stopp',),
'stoppegarn': ('stoppegarn',),
'stoppegarna': ('stoppegarn',),
'stoppegarnene': ('stoppegarn',),
'stoppegarnet': ('stoppegarn',),
'stoppeklokka': ('stoppeklokke',),
'stoppeklokke': ('stoppeklokke',),
'stoppeklokken': ('stoppeklokke',),
'stoppeklokkene': ('stoppeklokke',),
'stoppeklokker': ('stoppeklokke',),
'stoppekorg': ('stoppekorg',),
'stoppekorga': ('stoppekorg',),
'stoppekorgen': ('stoppekorg',),
'stoppekorgene': ('stoppekorg',),
'stoppekorger': ('stoppekorg',),
'stoppekran': ('stoppekran',),
'stoppekrana': ('stoppekran',),
'stoppekranen': ('stoppekran',),
'stoppekranene': ('stoppekran',),
'stoppekraner': ('stoppekran',),
'stoppekurv': ('stoppekurv',),
'stoppekurva': ('stoppekurv',),
'stoppekurven': ('stoppekurv',),
'stoppekurvene': ('stoppekurv',),
'stoppekurver': ('stoppekurv',),
'stoppenål': ('stoppenål',),
'stoppenåla': ('stoppenål',),
'stoppenålen': ('stoppenål',),
'stoppenålene': ('stoppenål',),
'stoppenåler': ('stoppenål',),
'stoppeplikt': ('stoppeplikt',),
'stoppeplikta': ('stoppeplikt',),
'stoppeplikten': ('stoppeplikt',),
'stoppepliktene': ('stoppeplikt',),
'stoppeplikter': ('stoppeplikt',),
'stopper': ('stopper',),
'stoppere': ('stopper',),
'stopperen': ('stopper',),
'stopperer': ('stopper',),
'stopperne': ('stopper',),
'stoppesakene': ('stoppesaker',),
'stoppesaker': ('stoppesaker',),
'stoppesko': ('stoppesko',),
'stoppeskoa': ('stoppesko',),
'stoppeskoen': ('stoppesko',),
'stoppeskoene': ('stoppesko',),
'stoppeskor': ('stoppesko',),
'stoppeskorne': ('stoppesko',),
'stoppested': ('stoppested',),
'stoppestedene': ('stoppested',),
'stoppesteder': ('stoppested',),
'stoppestedet': ('stoppested',),
'stopplys': ('stopplys',),
'stopplysa': ('stopplys',),
'stopplysene': ('stopplys',),
'stopplyset': ('stopplys',),
'stoppsignal': ('stoppsignal',),
'stoppsignala': ('stoppsignal',),
'stoppsignalene': ('stoppsignal',),
'stoppsignaler': ('stoppsignal',),
'stoppsignalet': ('stoppsignal',),
'stoppskilt': ('stoppskilt',),
'stoppskilta': ('stoppskilt',),
'stoppskiltene': ('stoppskilt',),
'stoppskilter': ('stoppskilt',),
'stoppskiltet': ('stoppskilt',),
'stoppskiva': ('stoppskive',),
'stoppskive': ('stoppskive',),
'stoppskiven': ('stoppskive',),
'stoppskivene': ('stoppskive',),
'stoppskiver': ('stoppskive',),
'storbakke': ('storbakke',),
'storbakken': ('storbakke',),
'storbakkene': ('storbakke',),
'storbakker': ('storbakke',),
'storband': ('storband',),
'storbanda': ('storband',),
'storbandene': ('storband',),
'storbandet': ('storband',),
'storbonde': ('storbonde',),
'storbonden': ('storbonde',),
'storbøndene': ('storbonde',),
'storbønder': ('storbonde',),
'storby': ('storby',),
'storbyen': ('storby',),
'storbyene': ('storby',),
'storbyer': ('storby',),
'storebror': ('storebror',),
'storebroren': ('storebror',),
'storebrødre': ('storebror',),
'storebrødrene': ('storebror',),
'storeslem': ('storeslem',),
'storeslemmen': ('storeslem',),
'storeslemmene': ('storeslem',),
'storeslemmer': ('storeslem',),
'storesøster': ('storesøster',),
'storesøstera': ('storesøster',),
'storesøsteren': ('storesøster',),
'storesøstre': ('storesøster',),
'storesøstrene': ('storesøster',),
'storesøstrer': ('storesøster',),
'storeter': ('storeter',),
'storetere': ('storeter',),
'storeteren': ('storeter',),
'storeterer': ('storeter',),
'storeterne': ('storeter',),
'storfag': ('storfag',),
'storfaga': ('storfag',),
'storfagene': ('storfag',),
'storfaget': ('storfag',),
'storfamilie': ('storfamilie',),
'storfamilien': ('storfamilie',),
'storfamiliene': ('storfamilie',),
'storfamilier': ('storfamilie',),
'storfamn': ('storfamn',),
'storfamnen': ('storfamn',),
'storfamnene': ('storfamn',),
'storfamner': ('storfamn',),
'storfavn': ('storfavn',),
'storfavnen': ('storfavn',),
'storfavnene': ('storfavn',),
'storfavner': ('storfavn',),
'storfe': ('storfe',),
'storfea': ('storfe',),
'storfeene': ('storfe',),
'storfeet': ('storfe',),
'storfisk': ('storfisk',),
'storfisken': ('storfisk',),
'storfiskene': ('storfisk',),
'storfisker': ('storfisk',),
'storflyplass': ('storflyplass',),
'storflyplassen': ('storflyplass',),
'storflyplassene': ('storflyplass',),
'storflyplasser': ('storflyplass',),
'storfugl': ('storfugl',),
'storfuglen': ('storfugl',),
'storfuglene': ('storfugl',),
'storfugler': ('storfugl',),
'storfyrste': ('storfyrste',),
'storfyrsten': ('storfyrste',),
'storfyrstene': ('storfyrste',),
'storfyrster': ('storfyrste',),
'storhav': ('storhav',),
'storhava': ('storhav',),
'storhavene': ('storhav',),
'storhavet': ('storhav',),
'storr': ('storr',),
'storren': ('storr',),
'storrene': ('storr',),
'storrer': ('storr',),
'storr': ('storr',),
'storren': ('storr',),
'storrene': ('storr',),
'storrer': ('storr',),
'storreingjøring': ('storreingjøring',),
'storreingjøringa': ('storreingjøring',),
'storreingjøringen': ('storreingjøring',),
'storreingjøringene': ('storreingjøring',),
'storreingjøringer': ('storreingjøring',),
'storrengjøring': ('storrengjøring',),
'storrengjøringa': ('storrengjøring',),
'storrengjøringen': ('storrengjøring',),
'storrengjøringene': ('storrengjøring',),
'storrengjøringer': ('storrengjøring',),
'storrgras': ('storrgras',),
'storrgrasa': ('storrgras',),
'storrgrasene': ('storrgras',),
'storrgraset': ('storrgras',),
'storrgress': ('storrgress',),
'storrgressa': ('storrgress',),
'storrgressene': ('storrgress',),
'storrgresset': ('storrgress',),
'storrmyr': ('storrmyr',),
'storrmyra': ('storrmyr',),
'storrmyren': ('storrmyr',),
'storrmyrene': ('storrmyr',),
'storrmyrer': ('storrmyr',),
'storrmyr': ('storrmyr',),
'storrmyra': ('storrmyr',),
'storrmyren': ('storrmyr',),
'storrmyrene': ('storrmyr',),
'storrmyrer': ('storrmyr',),
'storrusser': ('storrusser',),
'storrussere': ('storrusser',),
'storrusseren': ('storrusser',),
'storrusserer': ('storrusser',),
'storrusserne': ('storrusser',),
'storsegl': ('storsegl',),
'storsegla': ('storsegl',),
'storseglene': ('storsegl',),
'storseglet': ('storsegl',),
'storseil': ('storseil',),
'storseila': ('storseil',),
'storseilene': ('storseil',),
'storseilet': ('storseil',),
'storsild': ('storsild',),
'storsilda': ('storsild',),
'storsilden': ('storsild',),
'storsildene': ('storsild',),
'storsilder': ('storsild',),
'storsinn': ('storsinn',),
'storsinna': ('storsinn',),
'storsinnene': ('storsinn',),
'storsinnet': ('storsinn',),
'storsirkel': ('storsirkel',),
'storsirkelen': ('storsirkel',),
'storsirklene': ('storsirkel',),
'storsirkler': ('storsirkel',),
'storskarv': ('storskarv',),
'storskarven': ('storskarv',),
'storskarvene': ('storskarv',),
'storskarver': ('storskarv',),
'storskole': ('storskole',),
'storskolen': ('storskole',),
'storskolene': ('storskole',),
'storskoler': ('storskole',),
'storslalåm': ('storslalåm',),
'storslalåmen': ('storslalåm',),
'storslalåmene': ('storslalåm',),
'storslalåmer': ('storslalåm',),
'storslegga': ('storslegge',),
'storslegge': ('storslegge',),
'storsleggen': ('storslegge',),
'storsleggene': ('storslegge',),
'storslegger': ('storslegge',),
'storspove': ('storspove',),
'storspoven': ('storspove',),
'storspovene': ('storspove',),
'storspover': ('storspove',),
'storstova': ('storstove',),
'storstove': ('storstove',),
'storstoven': ('storstove',),
'storstovene': ('storstove',),
'storstover': ('storstove',),
'storstua': ('storstue',),
'storstue': ('storstue',),
'storstuen': ('storstue',),
'storstuene': ('storstue',),
'storstuer': ('storstue',),
'stortalenhet': ('stortalenhet',),
'stortalenheta': ('stortalenhet',),
'stortalenheten': ('stortalenhet',),
'stortalenhetene': ('stortalenhet',),
'stortalenheter': ('stortalenhet',),
'storting': ('storting',),
'stortinga': ('storting',),
'stortingene': ('storting',),
'stortinget': ('storting',),
'stortingsgruppa': ('stortingsgruppe',),
'stortingsgruppe': ('stortingsgruppe',),
'stortingsgruppen': ('stortingsgruppe',),
'stortingsgruppene': ('stortingsgruppe',),
'stortingsgrupper': ('stortingsgruppe',),
'stortingsmann': ('stortingsmann',),
'stortingsmannen': ('stortingsmann',),
'stortingsmenn': ('stortingsmann',),
'stortingsmennene': ('stortingsmann',),
'stortingsmelding': ('stortingsmelding',),
'stortingsmeldinga': ('stortingsmelding',),
'stortingsmeldingen': ('stortingsmelding',),
'stortingsmeldingene': ('stortingsmelding',),
'stortingsmeldinger': ('stortingsmelding',),
'stortingspresident': ('stortingspresident',),
'stortingspresidenten': ('stortingspresident',),
'stortingspresidentene': ('stortingspresident',),
'stortingspresidenter': ('stortingspresident',),
'stortingsproposisjon': ('stortingsproposisjon',),
'stortingsproposisjonen': ('stortingsproposisjon',),
'stortingsproposisjonene': ('stortingsproposisjon',),
'stortingsproposisjoner': ('stortingsproposisjon',),
'stortingsrepresentant': ('stortingsrepresentant',),
'stortingsrepresentanten': ('stortingsrepresentant',),
'stortingsrepresentantene': ('stortingsrepresentant',),
'stortingsrepresentanter': ('stortingsrepresentant',),
'stortingstidende': ('stortingstidende',),
'stortingstidenden': ('stortingstidende',),
'stortingstidendene': ('stortingstidende',),
'stortingstidender': ('stortingstidende',),
'stortingsvalg': ('stortingsvalg',),
'stortingsvalga': ('stortingsvalg',),
'stortingsvalgene': ('stortingsvalg',),
'stortingsvalget': ('stortingsvalg',),
'stortromma': ('stortromme',),
'stortromme': ('stortromme',),
'stortrommen': ('stortromme',),
'stortrommene': ('stortromme',),
'stortrommer': ('stortromme',),
'stortå': ('stortå',),
'stortåa': ('stortå',),
'stortåen': ('stortå',),
'stortær': ('stortå',),
'stortærne': ('stortå',),
'storvask': ('storvask',),
'storvasken': ('storvask',),
'storvaskene': ('storvask',),
'storvasker': ('storvask',),
'storveg': ('storveg',),
'storvegen': ('storveg',),
'storvegene': ('storveg',),
'storveger': ('storveg',),
'storvei': ('storvei',),
'storveien': ('storvei',),
'storveiene': ('storvei',),
'storveier': ('storvei',),
'storverk': ('storverk',),
'storverka': ('storverk',),
'storverkene': ('storverk',),
'storverker': ('storverk',),
'storverket': ('storverk',),
'storvilt': ('storvilt',),
'storvilta': ('storvilt',),
'storviltene': ('storvilt',),
'storviltet': ('storvilt',),
'storviltjakt': ('storviltjakt',),
'storviltjakta': ('storviltjakt',),
'storviltjakten': ('storviltjakt',),
'storviltjaktene': ('storviltjakt',),
'storviltjakter': ('storviltjakt',),
'storviltjeger': ('storviltjeger',),
'storviltjegere': ('storviltjeger',),
'storviltjegeren': ('storviltjeger',),
'storviltjegerer': ('storviltjeger',),
'storviltjegerne': ('storviltjeger',),
'story': ('story',),
'storyen': ('story',),
'storyene': ('story',),
'storyer': ('story',),
'stova': ('stove',),
'stove': ('stove',),
'stoven': ('stove',),
'stovene': ('stove',),
'stover': ('stove',),
'stovebygning': ('stovebygning',),
'stovebygninga': ('stovebygning',),
'stovebygningen': ('stovebygning',),
'stovebygningene': ('stovebygning',),
'stovebygninger': ('stovebygning',),
'stovedør': ('stovedør',),
'stovedøra': ('stovedør',),
'stovedøren': ('stovedør',),
'stovedørene': ('stovedør',),
'stovedører': ('stovedør',),
'stovegolv': ('stovegolv',),
'stovegolva': ('stovegolv',),
'stovegolvene': ('stovegolv',),
'stovegolvet': ('stovegolv',),
'stovegris': ('stovegris',),
'stovegrisen': ('stovegris',),
'stovegrisene': ('stovegris',),
'stovegriser': ('stovegris',),
'stoveplanta': ('stoveplante',),
'stoveplante': ('stoveplante',),
'stoveplanten': ('stoveplante',),
'stoveplantene': ('stoveplante',),
'stoveplanter': ('stoveplante',),
'stoveur': ('stoveur',),
'stoveura': ('stoveur',),
'stoveurene': ('stoveur',),
'stoveuret': ('stoveur',),
'strabas': ('strabas',),
'strabasen': ('strabas',),
'strabasene': ('strabas',),
'strabaser': ('strabas',),
'stradivarius': ('stradivarius',),
'stradivariusen': ('stradivarius',),
'stradivariusene': ('stradivarius',),
'stradivariuser': ('stradivarius',),
'straff': ('straff',),
'straffen': ('straff',),
'straffene': ('straff',),
'straffer': ('straff',),
'straff-fange': ('straff-fange',),
'straff-fangen': ('straff-fange',),
'straff-fangene': ('straff-fange',),
'straff-fanger': ('straff-fange',),
'straff-forfølging': ('straff-forfølging',),
'straff-forfølginga': ('straff-forfølging',),
'straff-forfølgingen': ('straff-forfølging',),
'straff-forfølgingene': ('straff-forfølging',),
'straff-forfølginger': ('straff-forfølging',),
'straff-forfølgning': ('straff-forfølgning',),
'straff-forfølgninga': ('straff-forfølgning',),
'straff-forfølgningen': ('straff-forfølgning',),
'straff-forfølgningene': ('straff-forfølgning',),
'straff-forfølgninger': ('straff-forfølgning',),
'straffange': ('straffange',),
'straffangen': ('straffange',),
'straffangene': ('straffange',),
'straffanger': ('straffange',),
'straffansvar': ('straffansvar',),
'straffansvara': ('straffansvar',),
'straffansvarene': ('straffansvar',),
'straffansvaret': ('straffansvar',),
'straffarbeid': ('straffarbeid',),
'straffarbeida': ('straffarbeid',),
'straffarbeidene': ('straffarbeid',),
'straffarbeider': ('straffarbeid',),
'straffarbeidet': ('straffarbeid',),
'straffe': ('straffe',),
'straffen': ('straffe',),
'straffene': ('straffe',),
'straffer': ('straffe',),
'straffeanstalt': ('straffeanstalt',),
'straffeanstalten': ('straffeanstalt',),
'straffeanstaltene': ('straffeanstalt',),
'straffeanstalter': ('straffeanstalt',),
'straffedom': ('straffedom',),
'straffedommen': ('straffedom',),
'straffedommene': ('straffedom',),
'straffedommer': ('straffedom',),
'straffeeksersis': ('straffeeksersis',),
'straffeeksersisen': ('straffeeksersis',),
'straffeeksersisene': ('straffeeksersis',),
'straffeeksersiser': ('straffeeksersis',),
'straffefelt': ('straffefelt',),
'straffefelta': ('straffefelt',),
'straffefeltene': ('straffefelt',),
'straffefelter': ('straffefelt',),
'straffefeltet': ('straffefelt',),
'straffeforfølging': ('straffeforfølging',),
'straffeforfølginga': ('straffeforfølging',),
'straffeforfølgingen': ('straffeforfølging',),
'straffeforfølgingene': ('straffeforfølging',),
'straffeforfølginger': ('straffeforfølging',),
'straffeforfølgning': ('straffeforfølgning',),
'straffeforfølgninga': ('straffeforfølgning',),
'straffeforfølgningen': ('straffeforfølgning',),
'straffeforfølgningene': ('straffeforfølgning',),
'straffeforfølgninger': ('straffeforfølgning',),
'straffekast': ('straffekast',),
'straffekasta': ('straffekast',),
'straffekastene': ('straffekast',),
'straffekastet': ('straffekast',),
'straffelov': ('straffelov',),
'straffeloven': ('straffelov',),
'straffelovene': ('straffelov',),
'straffelover': ('straffelov',),
'straffeporto': ('straffeporto',),
'straffeportoen': ('straffeporto',),
'straffeportoene': ('straffeporto',),
'straffeportoer': ('straffeporto',),
'straffepreken': ('straffepreken',),
'straffeprekenen': ('straffepreken',),
'straffeprekenene': ('straffepreken',),
'straffeprekener': ('straffepreken',),
'strafferegister': ('strafferegister',),
'strafferegisteret': ('strafferegister',),
'strafferegistra': ('strafferegister',),
'strafferegistre': ('strafferegister',),
'strafferegistrene': ('strafferegister',),
'strafferegistret': ('strafferegister',),
'strafferett': ('strafferett',),
'strafferetten': ('strafferett',),
'strafferettene': ('strafferett',),
'strafferetter': ('strafferett',),
'strafferunde': ('strafferunde',),
'strafferunden': ('strafferunde',),
'strafferundene': ('strafferunde',),
'strafferunder': ('strafferunde',),
'straffesak': ('straffesak',),
'straffesaka': ('straffesak',),
'straffesaken': ('straffesak',),
'straffesakene': ('straffesak',),
'straffesaker': ('straffesak',),
'straffeslag': ('straffeslag',),
'straffeslaga': ('straffeslag',),
'straffeslagene': ('straffeslag',),
'straffeslaget': ('straffeslag',),
'straffespark': ('straffespark',),
'straffesparka': ('straffespark',),
'straffesparkene': ('straffespark',),
'straffesparket': ('straffespark',),
'straffesparkkonkurranse': ('straffesparkkonkurranse',),
'straffesparkkonkurransen': ('straffesparkkonkurranse',),
'straffesparkkonkurransene': ('straffesparkkonkurranse',),
'straffesparkkonkurranser': ('straffesparkkonkurranse',),
'straffeutmåling': ('straffeutmåling',),
'straffeutmålinga': ('straffeutmåling',),
'straffeutmålingen': ('straffeutmåling',),
'straffeutmålingene': ('straffeutmåling',),
'straffeutmålinger': ('straffeutmåling',),
'straffforfølgning': ('straffforfølgning',),
'straffforfølgninga': ('straffforfølgning',),
'straffforfølgningen': ('straffforfølgning',),
'straffforfølgningene': ('straffforfølgning',),
'straffforfølgninger': ('straffforfølgning',),
'strafforfølging': ('strafforfølging',),
'strafforfølginga': ('strafforfølging',),
'strafforfølgingen': ('strafforfølging',),
'strafforfølgingene': ('strafforfølging',),
'strafforfølginger': ('strafforfølging',),
'strafforfølgning': ('strafforfølgning',),
'strafforfølgninga': ('strafforfølgning',),
'strafforfølgningen': ('strafforfølgning',),
'strafforfølgningene': ('strafforfølgning',),
'strafforfølgninger': ('strafforfølgning',),
'straffskyld': ('straffskyld',),
'straffskylda': ('straffskyld',),
'straffskylden': ('straffskyld',),
'straffskyldene': ('straffskyld',),
'straffskylder': ('straffskyld',),
'straffutmåling': ('straffutmåling',),
'straffutmålinga': ('straffutmåling',),
'straffutmålingen': ('straffutmåling',),
'straffutmålingene': ('straffutmåling',),
'straffutmålinger': ('straffutmåling',),
'straight': ('straight',),
'straighten': ('straight',),
'straightene': ('straight',),
'straighter': ('straight',),
'straight flush': ('straight flush',),
'straight flushen': ('straight flush',),
'straight flushene': ('straight flush',),
'straight flusher': ('straight flush',),
'straksene': ('strakser',),
'strakser': ('strakser',),
'straksløsning': ('straksløsning',),
'straksløsninga': ('straksløsning',),
'straksløsningen': ('straksløsning',),
'straksløsningene': ('straksløsning',),
'straksløsninger': ('straksløsning',),
'straksløysing': ('straksløysing',),
'straksløysinga': ('straksløysing',),
'straksløysingen': ('straksløysing',),
'straksløysingene': ('straksløysing',),
'straksløysinger': ('straksløysing',),
'straksplan': ('straksplan',),
'straksplanen': ('straksplan',),
'straksplanene': ('straksplan',),
'straksplaner': ('straksplan',),
'stramei': ('stramei',),
'strameien': ('stramei',),
'strameiene': ('stramei',),
'strameier': ('stramei',),
'strammer': ('strammer',),
'strammere': ('strammer',),
'strammeren': ('strammer',),
'strammerer': ('strammer',),
'strammerne': ('strammer',),
'strand': ('strand',),
'stranda': ('strand',),
'stranden': ('strand',),
'strendene': ('strand',),
'strender': ('strand',),
'strandarve': ('strandarve',),
'strandarven': ('strandarve',),
'strandarvene': ('strandarve',),
'strandarver': ('strandarve',),
'strandbredd': ('strandbredd',),
'strandbredda': ('strandbredd',),
'strandbredden': ('strandbredd',),
'strandbreddene': ('strandbredd',),
'strandbredder': ('strandbredd',),
'strandflata': ('strandflate',),
'strandflate': ('strandflate',),
'strandflaten': ('strandflate',),
'strandflatene': ('strandflate',),
'strandflater': ('strandflate',),
'strandhogg': ('strandhogg',),
'strandhogga': ('strandhogg',),
'strandhoggene': ('strandhogg',),
'strandhogget': ('strandhogg',),
'strandhugg': ('strandhugg',),
'strandhugga': ('strandhugg',),
'strandhuggene': ('strandhugg',),
'strandhugget': ('strandhugg',),
'strandlinja': ('strandlinje',),
'strandlinje': ('strandlinje',),
'strandlinjen': ('strandlinje',),
'strandlinjene': ('strandlinje',),
'strandlinjer': ('strandlinje',),
'strandlov': ('strandlov',),
'strandloven': ('strandlov',),
'strandlovene': ('strandlov',),
'strandlover': ('strandlov',),
'strandplanlov': ('strandplanlov',),
'strandplanloven': ('strandplanlov',),
'strandplanlovene': ('strandplanlov',),
'strandplanlover': ('strandplanlov',),
'strandrett': ('strandrett',),
'strandretten': ('strandrett',),
'strandrettene': ('strandrett',),
'strandretter': ('strandrett',),
'strandrug': ('strandrug',),
'strandrugen': ('strandrug',),
'strandrugene': ('strandrug',),
'strandruger': ('strandrug',),
'strandsnipa': ('strandsnipe',),
'strandsnipe': ('strandsnipe',),
'strandsnipen': ('strandsnipe',),
'strandsnipene': ('strandsnipe',),
'strandsniper': ('strandsnipe',),
'strandsted': ('strandsted',),
'strandstedene': ('strandsted',),
'strandsteder': ('strandsted',),
'strandstedet': ('strandsted',),
'strange': ('strange',),
'strangen': ('strange',),
'strangene': ('strange',),
'stranger': ('strange',),
'strangulasjon': ('strangulasjon',),
'strangulasjonen': ('strangulasjon',),
'strangulasjonene': ('strangulasjon',),
'strangulasjoner': ('strangulasjon',),
'strant': ('strant',),
'stranten': ('strant',),
'strantene': ('strant',),
'stranter': ('strant',),
'strateg': ('strateg',),
'strategen': ('strateg',),
'strategene': ('strateg',),
'strateger': ('strateg',),
'strategi': ('strategi',),
'strategien': ('strategi',),
'strategiene': ('strategi',),
'strategier': ('strategi',),
'stratenrøver': ('stratenrøver',),
'stratenrøvere': ('stratenrøver',),
'stratenrøveren': ('stratenrøver',),
'stratenrøverer': ('stratenrøver',),
'stratenrøverne': ('stratenrøver',),
'stratokumulus': ('stratokumulus',),
'stratokumulusen': ('stratokumulus',),
'stratokumulusene': ('stratokumulus',),
'stratokumuluser': ('stratokumulus',),
'stratosfære': ('stratosfære',),
'stratosfæren': ('stratosfære',),
'stratosfærene': ('stratosfære',),
'stratosfærer': ('stratosfære',),
'stratt': ('stratt',),
'stratten': ('stratt',),
'strattene': ('stratt',),
'stratter': ('stratt',),
'stratte': ('stratte',),
'stratten': ('stratte',),
'strattene': ('stratte',),
'stratter': ('stratte',),
'strata': ('stratum',),
'strataene': ('stratum',),
'stratum': ('stratum',),
'stratumet': ('stratum',),
'stratus': ('stratus',),
'stratussky': ('stratussky',),
'stratusskya': ('stratussky',),
'stratusskyen': ('stratussky',),
'stratusskyene': ('stratussky',),
'stratusskyer': ('stratussky',),
'streben': ('streben',),
'strebenen': ('streben',),
'strebenene': ('streben',),
'strebener': ('streben',),
'streber': ('streber',),
'strebere': ('streber',),
'streberen': ('streber',),
'streberer': ('streber',),
'streberne': ('streber',),
'strebing': ('strebing',),
'strebinga': ('strebing',),
'strebingen': ('strebing',),
'strebingene': ('strebing',),
'strebinger': ('strebing',),
'streda': ('strede',),
'strede': ('strede',),
'stredene': ('strede',),
'streder': ('strede',),
'stredet': ('strede',),
'streif': ('streif',),
'streifa': ('streif',),
'streifene': ('streif',),
'streifet': ('streif',),
'streifdyr': ('streifdyr',),
'streifdyra': ('streifdyr',),
'streifdyrene': ('streifdyr',),
'streifdyret': ('streifdyr',),
'streifer': ('streifer',),
'streifere': ('streifer',),
'streiferen': ('streifer',),
'streiferer': ('streifer',),
'streiferne': ('streifer',),
'streiffugl': ('streiffugl',),
'streiffuglen': ('streiffugl',),
'streiffuglene': ('streiffugl',),
'streiffugler': ('streiffugl',),
'streiflys': ('streiflys',),
'streiflysa': ('streiflys',),
'streiflysene': ('streiflys',),
'streiflyset': ('streiflys',),
'streifskott': ('streifskott',),
'streifskotta': ('streifskott',),
'streifskottene': ('streifskott',),
'streifskottet': ('streifskott',),
'streifskudd': ('streifskudd',),
'streifskudda': ('streifskudd',),
'streifskuddene': ('streifskudd',),
'streifskuddet': ('streifskudd',),
'streifsår': ('streifsår',),
'streifsåra': ('streifsår',),
'streifsårene': ('streifsår',),
'streifsåret': ('streifsår',),
'streiftog': ('streiftog',),
'streiftoga': ('streiftog',),
'streiftogene': ('streiftog',),
'streiftoget': ('streiftog',),
'streik': ('streik',),
'streiken': ('streik',),
'streikene': ('streik',),
'streiker': ('streik',),
'streikebryter': ('streikebryter',),
'streikebrytere': ('streikebryter',),
'streikebryteren': ('streikebryter',),
'streikebryterer': ('streikebryter',),
'streikebryterne': ('streikebryter',),
'streikebryteri': ('streikebryteri',),
'streikebryteria': ('streikebryteri',),
'streikebryteriene': ('streikebryteri',),
'streikebryterier': ('streikebryteri',),
'streikebryteriet': ('streikebryteri',),
'streikekassa': ('streikekasse',),
'streikekasse': ('streikekasse',),
'streikekassen': ('streikekasse',),
'streikekassene': ('streikekasse',),
'streikekasser': ('streikekasse',),
'streikerett': ('streikerett',),
'streikeretten': ('streikerett',),
'streikerettene': ('streikerett',),
'streikeretter': ('streikerett',),
'streikevakt': ('streikevakt',),
'streikevakta': ('streikevakt',),
'streikevakten': ('streikevakt',),
'streikevaktene': ('streikevakt',),
'streikevakter': ('streikevakt',),
'streikevarsel': ('streikevarsel',),
'streikevarselet': ('streikevarsel',),
'streikevarsla': ('streikevarsel',),
'streikevarslene': ('streikevarsel',),
'streikevarsler': ('streikevarsel',),
'streikevarslet': ('streikevarsel',),
'streiting': ('streiting',),
'streitingen': ('streiting',),
'streitingene': ('streiting',),
'streitinger': ('streiting',),
'strek': ('strek',),
'streken': ('strek',),
'strekene': ('strek',),
'streker': ('strek',),
'strekk': ('strekk',),
'strekka': ('strekk',),
'strekkene': ('strekk',),
'strekket': ('strekk',),
'strekk': ('strekk',),
'strekka': ('strekk',),
'strekken': ('strekk',),
'strekkene': ('strekk',),
'strekker': ('strekk',),
'strekket': ('strekk',),
'strekkbandasje': ('strekkbandasje',),
'strekkbandasjen': ('strekkbandasje',),
'strekkbandasjene': ('strekkbandasje',),
'strekkbandasjer': ('strekkbandasje',),
'strekkbuksa': ('strekkbukse',),
'strekkbukse': ('strekkbukse',),
'strekkbuksen': ('strekkbukse',),
'strekkbuksene': ('strekkbukse',),
'strekkbukser': ('strekkbukse',),
'strekkemuskel': ('strekkemuskel',),
'strekkemuskelen': ('strekkemuskel',),
'strekkemusklene': ('strekkemuskel',),
'strekkemuskler': ('strekkemuskel',),
'strekker': ('strekker',),
'strekkere': ('strekker',),
'strekkeren': ('strekker',),
'strekkerer': ('strekker',),
'strekkerne': ('strekker',),
'strekkfasthet': ('strekkfasthet',),
'strekkfastheta': ('strekkfasthet',),
'strekkfastheten': ('strekkfasthet',),
'strekkfasthetene': ('strekkfasthet',),
'strekkfastheter': ('strekkfasthet',),
'strekkfisk': ('strekkfisk',),
'strekkfisken': ('strekkfisk',),
'strekkfiskene': ('strekkfisk',),
'strekkfisker': ('strekkfisk',),
'strekkode': ('strekkode',),
'strekkoden': ('strekkode',),
'strekkodene': ('strekkode',),
'strekkoder': ('strekkode',),
'strekmål': ('strekmål',),
'strekmåla': ('strekmål',),
'strekmålene': ('strekmål',),
'strekmålet': ('strekmål',),
'strekmåt': ('strekmåt',),
'strekmåta': ('strekmåt',),
'strekmåtene': ('strekmåt',),
'strekmåtet': ('strekmåt',),
'strekning': ('strekning',),
'strekninga': ('strekning',),
'strekningen': ('strekning',),
'strekningene': ('strekning',),
'strekninger': ('strekning',),
'strekspiller': ('strekspiller',),
'strekspillere': ('strekspiller',),
'strekspilleren': ('strekspiller',),
'strekspillerer': ('strekspiller',),
'strekspillerne': ('strekspiller',),
'streng': ('streng',),
'strengen': ('streng',),
'strengene': ('streng',),
'strenger': ('streng',),
'strengeinstrument': ('strengeinstrument',),
'strengeinstrumenta': ('strengeinstrument',),
'strengeinstrumentene': ('strengeinstrument',),
'strengeinstrumenter': ('strengeinstrument',),
'strengeinstrumentet': ('strengeinstrument',),
'strengel': ('strengel',),
'strengelen': ('strengel',),
'strenglene': ('strengel',),
'strengler': ('strengel',),
'strengemusikk': ('strengemusikk',),
'strengemusikken': ('strengemusikk',),
'strengemusikkene': ('strengemusikk',),
'strengemusikker': ('strengemusikk',),
'streptokokk': ('streptokokk',),
'streptokokken': ('streptokokk',),
'streptokokkene': ('streptokokk',),
'streptokokker': ('streptokokk',),
'streptomycin': ('streptomycin',),
'streptomycina': ('streptomycin',),
'streptomycinene': ('streptomycin',),
'streptomycinet': ('streptomycin',),
'stress': ('stress',),
'stressa': ('stress',),
'stressen': ('stress',),
'stressene': ('stress',),
'stresser': ('stress',),
'stresset': ('stress',),
'stress-situasjon': ('stress-situasjon',),
'stress-situasjonen': ('stress-situasjon',),
'stress-situasjonene': ('stress-situasjon',),
'stress-situasjoner': ('stress-situasjon',),
'stress-sjukdom': ('stress-sjukdom',),
'stress-sjukdommen': ('stress-sjukdom',),
'stress-sjukdommene': ('stress-sjukdom',),
'stress-sjukdommer': ('stress-sjukdom',),
'stress-sykdom': ('stress-sykdom',),
'stress-sykdommen': ('stress-sykdom',),
'stress-sykdommene': ('stress-sykdom',),
'stress-sykdommer': ('stress-sykdom',),
'stressfaktor': ('stressfaktor',),
'stressfaktoren': ('stressfaktor',),
'stressfaktorene': ('stressfaktor',),
'stressfaktorer': ('stressfaktor',),
'stressituasjon': ('stressituasjon',),
'stressituasjonen': ('stressituasjon',),
'stressituasjonene': ('stressituasjon',),
'stressituasjoner': ('stressituasjon',),
'stressjukdom': ('stressjukdom',),
'stressjukdommen': ('stressjukdom',),
'stressjukdommene': ('stressjukdom',),
'stressjukdommer': ('stressjukdom',),
'stresskoffert': ('stresskoffert',),
'stresskofferten': ('stresskoffert',),
'stresskoffertene': ('stresskoffert',),
'stresskofferter': ('stresskoffert',),
'stressor': ('stressor',),
'stressoren': ('stressor',),
'stressorene': ('stressor',),
'stressorer': ('stressor',),
'stressykdom': ('stressykdom',),
'stressykdommen': ('stressykdom',),
'stressykdommene': ('stressykdom',),
'stressykdommer': ('stressykdom',),
'stretch': ('stretch',),
'stretchen': ('stretch',),
'stretchene': ('stretch',),
'stretcher': ('stretch',),
'strev': ('strev',),
'streva': ('strev',),
'strevene': ('strev',),
'strevet': ('strev',),
'strever': ('strever',),
'strevere': ('strever',),
'streveren': ('strever',),
'streverer': ('strever',),
'streverne': ('strever',),
'stri': ('stri',),
'stria': ('stri',),
'strien': ('stri',),
'striene': ('stri',),
'strier': ('stri',),
'stribukk': ('stribukk',),
'stribukken': ('stribukk',),
'stribukkene': ('stribukk',),
'stribukker': ('stribukk',),
'stribukk': ('stribukk',),
'stribukken': ('stribukk',),
'stribukkene': ('stribukk',),
'stribukker': ('stribukk',),
'strid': ('strid',),
'striden': ('strid',),
'stridene': ('strid',),
'strider': ('strid',),
'stridbukk': ('stridbukk',),
'stridbukken': ('stridbukk',),
'stridbukkene': ('stridbukk',),
'stridbukker': ('stridbukk',),
'stridbukk': ('stridbukk',),
'stridbukken': ('stridbukk',),
'stridbukkene': ('stridbukk',),
'stridbukker': ('stridbukk',),
'stridighet': ('stridighet',),
'stridigheta': ('stridighet',),
'stridigheten': ('stridighet',),
'stridighetene': ('stridighet',),
'stridigheter': ('stridighet',),
'stridregn': ('stridregn',),
'stridregna': ('stridregn',),
'stridregnene': ('stridregn',),
'stridregnet': ('stridregn',),
'stridsgass': ('stridsgass',),
'stridsgassen': ('stridsgass',),
'stridsgassene': ('stridsgass',),
'stridsgasser': ('stridsgass',),
'stridshanske': ('stridshanske',),
'stridshansken': ('stridshanske',),
'stridshanskene': ('stridshanske',),
'stridshansker': ('stridshanske',),
'stridshoda': ('stridshode',),
'stridshode': ('stridshode',),
'stridshodene': ('stridshode',),
'stridshoder': ('stridshode',),
'stridshodet': ('stridshode',),
'stridsmann': ('stridsmann',),
'stridsmannen': ('stridsmann',),
'stridsmenn': ('stridsmann',),
'stridsmennene': ('stridsmann',),
'stridsporsjon': ('stridsporsjon',),
'stridsporsjonen': ('stridsporsjon',),
'stridsporsjonene': ('stridsporsjon',),
'stridsporsjoner': ('stridsporsjon',),
'stridsrop': ('stridsrop',),
'stridsropa': ('stridsrop',),
'stridsropene': ('stridsrop',),
'stridsropet': ('stridsrop',),
'stridsspørsmål': ('stridsspørsmål',),
'stridsspørsmåla': ('stridsspørsmål',),
'stridsspørsmålene': ('stridsspørsmål',),
'stridsspørsmålet': ('stridsspørsmål',),
'stridsvogn': ('stridsvogn',),
'stridsvogna': ('stridsvogn',),
'stridsvognen': ('stridsvogn',),
'stridsvognene': ('stridsvogn',),
'stridsvogner': ('stridsvogn',),
'stridsvognfella': ('stridsvognfelle',),
'stridsvognfelle': ('stridsvognfelle',),
'stridsvognfellen': ('stridsvognfelle',),
'stridsvognfellene': ('stridsvognfelle',),
'stridsvognfeller': ('stridsvognfelle',),
'stridsøks': ('stridsøks',),
'stridsøksa': ('stridsøks',),
'stridsøksen': ('stridsøks',),
'stridsøksene': ('stridsøks',),
'stridsøkser': ('stridsøks',),
'strie': ('strie',),
'strien': ('strie',),
'striene': ('strie',),
'strier': ('strie',),
'striesekk': ('striesekk',),
'striesekken': ('striesekk',),
'striesekkene': ('striesekk',),
'striesekker': ('striesekk',),
'strieskjorta': ('strieskjorte',),
'strieskjorte': ('strieskjorte',),
'strieskjorten': ('strieskjorte',),
'strieskjortene': ('strieskjorte',),
'strieskjorter': ('strieskjorte',),
'strietapet': ('strietapet',),
'strietapeta': ('strietapet',),
'strietapetene': ('strietapet',),
'strietapeter': ('strietapet',),
'strietapetet': ('strietapet',),
'strigle': ('strigle',),
'striglen': ('strigle',),
'striglene': ('strigle',),
'strigler': ('strigle',),
'strikk': ('strikk',),
'strikken': ('strikk',),
'strikkene': ('strikk',),
'strikker': ('strikk',),
'strikkball': ('strikkball',),
'strikkballen': ('strikkball',),
'strikkballene': ('strikkball',),
'strikkballer': ('strikkball',),
'strikka': ('strikke',),
'strikke': ('strikke',),
'strikken': ('strikke',),
'strikkene': ('strikke',),
'strikker': ('strikke',),
'strikkegarn': ('strikkegarn',),
'strikkegarna': ('strikkegarn',),
'strikkegarnene': ('strikkegarn',),
'strikkegarnet': ('strikkegarn',),
'strikkelua': ('strikkelue',),
'strikkelue': ('strikkelue',),
'strikkeluen': ('strikkelue',),
'strikkeluene': ('strikkelue',),
'strikkeluer': ('strikkelue',),
'strikkeluva': ('strikkeluve',),
'strikkeluve': ('strikkeluve',),
'strikkeluven': ('strikkeluve',),
'strikkeluvene': ('strikkeluve',),
'strikkeluver': ('strikkeluve',),
'strikkemaskin': ('strikkemaskin',),
'strikkemaskina': ('strikkemaskin',),
'strikkemaskinen': ('strikkemaskin',),
'strikkemaskinene': ('strikkemaskin',),
'strikkemaskiner': ('strikkemaskin',),
'strikkemønster': ('strikkemønster',),
'strikkemønsteret': ('strikkemønster',),
'strikkemønstra': ('strikkemønster',),
'strikkemønstre': ('strikkemønster',),
'strikkemønstrene': ('strikkemønster',),
'strikkemønstret': ('strikkemønster',),
'strikkeoppskrift': ('strikkeoppskrift',),
'strikkeoppskrifta': ('strikkeoppskrift',),
'strikkeoppskriften': ('strikkeoppskrift',),
'strikkeoppskriftene': ('strikkeoppskrift',),
'strikkeoppskrifter': ('strikkeoppskrift',),
'strikkepinne': ('strikkepinne',),
'strikkepinnen': ('strikkepinne',),
'strikkepinnene': ('strikkepinne',),
'strikkepinner': ('strikkepinne',),
'strikketøy': ('strikketøy',),
'strikketøya': ('strikketøy',),
'strikketøyene': ('strikketøy',),
'strikketøyer': ('strikketøy',),
'strikketøyet': ('strikketøy',),
'strikkhopp': ('strikkhopp',),
'strikkhoppa': ('strikkhopp',),
'strikkhoppene': ('strikkhopp',),
'strikkhoppet': ('strikkhopp',),
'strikkhopping': ('strikkhopping',),
'strikkhoppinga': ('strikkhopping',),
'strikkhoppingen': ('strikkhopping',),
'strikkhoppingene': ('strikkhopping',),
'strikkhoppinger': ('strikkhopping',),
'stril': ('stril',),
'strilen': ('stril',),
'strilene': ('stril',),
'striler': ('stril',),
'strilemål': ('strilemål',),
'strilemåla': ('strilemål',),
'strilemålene': ('strilemål',),
'strilemålet': ('strilemål',),
'strima': ('strime',),
'strime': ('strime',),
'strimen': ('strime',),
'strimene': ('strime',),
'strimer': ('strime',),
'strimlene': ('strimmel',),
'strimler': ('strimmel',),
'strimmel': ('strimmel',),
'strimmelen': ('strimmel',),
'stringendo': ('stringendo',),
'stringendoa': ('stringendo',),
'stringendoene': ('stringendo',),
'stringendoer': ('stringendo',),
'stringendoet': ('stringendo',),
'stringens': ('stringens',),
'stringensen': ('stringens',),
'stringensene': ('stringens',),
'stringenser': ('stringens',),
'stripa': ('stripe',),
'stripe': ('stripe',),
'stripen': ('stripe',),
'stripene': ('stripe',),
'striper': ('stripe',),
'stripp': ('stripp',),
'strippen': ('stripp',),
'strippene': ('stripp',),
'stripper': ('stripp',),
'stripper': ('stripper',),
'strippere': ('stripper',),
'stripperen': ('stripper',),
'stripperer': ('stripper',),
'stripperne': ('stripper',),
'stripperska': ('stripperske',),
'stripperske': ('stripperske',),
'strippersken': ('stripperske',),
'stripperskene': ('stripperske',),
'strippersker': ('stripperske',),
'striptease': ('striptease',),
'stripteasen': ('striptease',),
'stripteasene': ('striptease',),
'stripteaser': ('striptease',),
'stripteasedanserinna': ('stripteasedanserinne',),
'stripteasedanserinne': ('stripteasedanserinne',),
'stripteasedanserinnen': ('stripteasedanserinne',),
'stripteasedanserinnene': ('stripteasedanserinne',),
'stripteasedanserinner': ('stripteasedanserinne',),
'striskjorta': ('striskjorte',),
'striskjorte': ('striskjorte',),
'striskjorten': ('striskjorte',),
'striskjortene': ('striskjorte',),
'striskjorter': ('striskjorte',),
'strofa': ('strofe',),
'strofe': ('strofe',),
'strofen': ('strofe',),
'strofene': ('strofe',),
'strofer': ('strofe',),
'stroke': ('stroke',),
'stroken': ('stroke',),
'strokene': ('stroke',),
'stroker': ('stroke',),
'strontium': ('strontium',),
'strontiuma': ('strontium',),
'strontiumene': ('strontium',),
'strontiumet': ('strontium',),
'stropp': ('stropp',),
'stroppen': ('stropp',),
'stroppene': ('stropp',),
'stropper': ('stropp',),
'strossa': ('strosse',),
'strosse': ('strosse',),
'strossen': ('strosse',),
'strossene': ('strosse',),
'strosser': ('strosse',),
'struktur': ('struktur',),
'strukturen': ('struktur',),
'strukturene': ('struktur',),
'strukturer': ('struktur',),
'strukturalisme': ('strukturalisme',),
'strukturalismen': ('strukturalisme',),
'strukturalismene': ('strukturalisme',),
'strukturalismer': ('strukturalisme',),
'strukturalist': ('strukturalist',),
'strukturalisten': ('strukturalist',),
'strukturalistene': ('strukturalist',),
'strukturalister': ('strukturalist',),
'strukturanalysa': ('strukturanalyse',),
'strukturanalyse': ('strukturanalyse',),
'strukturanalysen': ('strukturanalyse',),
'strukturanalysene': ('strukturanalyse',),
'strukturanalyser': ('strukturanalyse',),
'strukturbehandling': ('strukturbehandling',),
'strukturbehandlinga': ('strukturbehandling',),
'strukturbehandlingen': ('strukturbehandling',),
'strukturbehandlingene': ('strukturbehandling',),
'strukturbehandlinger': ('strukturbehandling',),
'strukturendring': ('strukturendring',),
'strukturendringa': ('strukturendring',),
'strukturendringen': ('strukturendring',),
'strukturendringene': ('strukturendring',),
'strukturendringer': ('strukturendring',),
'strukturrasjonalisering': ('strukturrasjonalisering',),
'strukturrasjonaliseringa': ('strukturrasjonalisering',),
'strukturrasjonaliseringen': ('strukturrasjonalisering',),
'strukturrasjonaliseringene': ('strukturrasjonalisering',),
'strukturrasjonaliseringer': ('strukturrasjonalisering',),
'struma': ('struma',),
'strumaen': ('struma',),
'strumaene': ('struma',),
'strumaer': ('struma',),
'strupe': ('strupe',),
'strupen': ('strupe',),
'strupene': ('strupe',),
'struper': ('strupe',),
'strupehoda': ('strupehode',),
'strupehode': ('strupehode',),
'strupehodene': ('strupehode',),
'strupehoder': ('strupehode',),
'strupehodet': ('strupehode',),
'strupehoste': ('strupehoste',),
'strupehosten': ('strupehoste',),
'strupehostene': ('strupehoste',),
'strupehoster': ('strupehoste',),
'strupekreft': ('strupekreft',),
'strupekreften': ('strupekreft',),
'strupekreftene': ('strupekreft',),
'strupekrefter': ('strupekreft',),
'strupelyd': ('strupelyd',),
'strupelyden': ('strupelyd',),
'strupelydene': ('strupelyd',),
'strupelyder': ('strupelyd',),
'struper': ('struper',),
'strupere': ('struper',),
'struperen': ('struper',),
'struperer': ('struper',),
'struperne': ('struper',),
'strupetak': ('strupetak',),
'strupetaka': ('strupetak',),
'strupetakene': ('strupetak',),
'strupetaket': ('strupetak',),
'strut': ('strut',),
'struten': ('strut',),
'strutene': ('strut',),
'struter': ('strut',),
'struts': ('struts',),
'strutsen': ('struts',),
'strutsene': ('struts',),
'strutser': ('struts',),
'strutsepolitikk': ('strutsepolitikk',),
'strutsepolitikken': ('strutsepolitikk',),
'strutsepolitikkene': ('strutsepolitikk',),
'strutsepolitikker': ('strutsepolitikk',),
'stry': ('stry',),
'strya': ('stry',),
'stryene': ('stry',),
'stryet': ('stry',),
'stryk': ('stryk',),
'stryka': ('stryk',),
'strykene': ('stryk',),
'stryket': ('stryk',),
'stryk': ('stryk',),
'stryka': ('stryk',),
'stryken': ('stryk',),
'strykene': ('stryk',),
'stryker': ('stryk',),
'stryket': ('stryk',),
'strykebrett': ('strykebrett',),
'strykebretta': ('strykebrett',),
'strykebrettene': ('strykebrett',),
'strykebretter': ('strykebrett',),
'strykebrettet': ('strykebrett',),
'strykeinstrument': ('strykeinstrument',),
'strykeinstrumenta': ('strykeinstrument',),
'strykeinstrumentene': ('strykeinstrument',),
'strykeinstrumenter': ('strykeinstrument',),
'strykeinstrumentet': ('strykeinstrument',),
'strykejern': ('strykejern',),
'strykejerna': ('strykejern',),
'strykejernene': ('strykejern',),
'strykejernet': ('strykejern',),
'strykekandidat': ('strykekandidat',),
'strykekandidaten': ('strykekandidat',),
'strykekandidatene': ('strykekandidat',),
'strykekandidater': ('strykekandidat',),
'strykekarakter': ('strykekarakter',),
'strykekarakteren': ('strykekarakter',),
'strykekarakterene': ('strykekarakter',),
'strykekarakterer': ('strykekarakter',),
'strykekvartett': ('strykekvartett',),
'strykekvartetten': ('strykekvartett',),
'strykekvartettene': ('strykekvartett',),
'strykekvartetter': ('strykekvartett',),
'strykekvintett': ('strykekvintett',),
'strykekvintetten': ('strykekvintett',),
'strykekvintettene': ('strykekvintett',),
'strykekvintetter': ('strykekvintett',),
'strykeorkester': ('strykeorkester',),
'strykeorkesteret': ('strykeorkester',),
'strykeorkestra': ('strykeorkester',),
'strykeorkestre': ('strykeorkester',),
'strykeorkestrene': ('strykeorkester',),
'strykeorkestret': ('strykeorkester',),
'strykeprosent': ('strykeprosent',),
'strykeprosenten': ('strykeprosent',),
'strykeprosentene': ('strykeprosent',),
'strykeprosenter': ('strykeprosent',),
'stryker': ('stryker',),
'strykere': ('stryker',),
'strykeren': ('stryker',),
'strykerer': ('stryker',),
'strykerne': ('stryker',),
'strykeri': ('strykeri',),
'strykeria': ('strykeri',),
'strykeriene': ('strykeri',),
'strykerier': ('strykeri',),
'strykeriet': ('strykeri',),
'stryketøy': ('stryketøy',),
'stryketøya': ('stryketøy',),
'stryketøyene': ('stryketøy',),
'stryketøyer': ('stryketøy',),
'stryketøyet': ('stryketøy',),
'strykkandidat': ('strykkandidat',),
'strykkandidaten': ('strykkandidat',),
'strykkandidatene': ('strykkandidat',),
'strykkandidater': ('strykkandidat',),
'strykkarakter': ('strykkarakter',),
'strykkarakteren': ('strykkarakter',),
'strykkarakterene': ('strykkarakter',),
'strykkarakterer': ('strykkarakter',),
'stryknin': ('stryknin',),
'stryknina': ('stryknin',),
'strykninen': ('stryknin',),
'strykninene': ('stryknin',),
'strykniner': ('stryknin',),
'strykninet': ('stryknin',),
'strykprosent': ('strykprosent',),
'strykprosenten': ('strykprosent',),
'strykprosentene': ('strykprosent',),
'strykprosenter': ('strykprosent',),
'strå': ('strå',),
'stråa': ('strå',),
'stråene': ('strå',),
'strået': ('strå',),
'stråhatt': ('stråhatt',),
'stråhatten': ('stråhatt',),
'stråhattene': ('stråhatt',),
'stråhatter': ('stråhatt',),
'stråle': ('stråle',),
'strålen': ('stråle',),
'strålene': ('stråle',),
'stråler': ('stråle',),
'strålebehandling': ('strålebehandling',),
'strålebehandlinga': ('strålebehandling',),
'strålebehandlingen': ('strålebehandling',),
'strålebehandlingene': ('strålebehandling',),
'strålebehandlinger': ('strålebehandling',),
'stråleglans': ('stråleglans',),
'stråleglansen': ('stråleglans',),
'stråleglansene': ('stråleglans',),
'stråleglanser': ('stråleglans',),
'strålehygiene': ('strålehygiene',),
'strålehygienen': ('strålehygiene',),
'strålehygienene': ('strålehygiene',),
'strålehygiener': ('strålehygiene',),
'stråleia': ('stråleie',),
'stråleie': ('stråleie',),
'stråleiene': ('stråleie',),
'stråleier': ('stråleie',),
'stråleiet': ('stråleie',),
'strålekrans': ('strålekrans',),
'strålekransen': ('strålekrans',),
'strålekransene': ('strålekrans',),
'strålekranser': ('strålekrans',),
'strålekreft': ('strålekreft',),
'strålekreften': ('strålekreft',),
'strålekreftene': ('strålekreft',),
'strålekrefter': ('strålekreft',),
'stråleomn': ('stråleomn',),
'stråleomnen': ('stråleomn',),
'stråleomnene': ('stråleomn',),
'stråleomner': ('stråleomn',),
'stråleovn': ('stråleovn',),
'stråleovnen': ('stråleovn',),
'stråleovnene': ('stråleovn',),
'stråleovner': ('stråleovn',),
'stråleskinn': ('stråleskinn',),
'stråleskinna': ('stråleskinn',),
'stråleskinnene': ('stråleskinn',),
'stråleskinnet': ('stråleskinn',),
'strålesopp': ('strålesopp',),
'strålesoppen': ('strålesopp',),
'strålesoppene': ('strålesopp',),
'strålesopper': ('strålesopp',),
'strålevarme': ('strålevarme',),
'strålevarmen': ('strålevarme',),
'strålevarmene': ('strålevarme',),
'strålevarmer': ('strålevarme',),
'strålevern': ('strålevern',),
'stråleverna': ('strålevern',),
'strålevernene': ('strålevern',),
'strålevernet': ('strålevern',),
'strålingsenergi': ('strålingsenergi',),
'strålingsenergien': ('strålingsenergi',),
'strålingsenergiene': ('strålingsenergi',),
'strålingsenergier': ('strålingsenergi',),
'strålingsfare': ('strålingsfare',),
'strålingsfaren': ('strålingsfare',),
'strålingsfarene': ('strålingsfare',),
'strålingsfarer': ('strålingsfare',),
'stråmann': ('stråmann',),
'stråmannen': ('stråmann',),
'stråmenn': ('stråmann',),
'stråmennene': ('stråmann',),
'stråmatta': ('stråmatte',),
'stråmatte': ('stråmatte',),
'stråmatten': ('stråmatte',),
'stråmattene': ('stråmatte',),
'stråmatter': ('stråmatte',),
'stråtak': ('stråtak',),
'stråtaka': ('stråtak',),
'stråtakene': ('stråtak',),
'stråtaket': ('stråtak',),
'strø': ('strø',),
'strøa': ('strø',),
'strøene': ('strø',),
'strøet': ('strø',),
'strø': ('strø',),
'strøa': ('strø',),
'strøene': ('strø',),
'strøet': ('strø',),
'strøbemerkning': ('strøbemerkning',),
'strøbemerkninga': ('strøbemerkning',),
'strøbemerkningen': ('strøbemerkning',),
'strøbemerkningene': ('strøbemerkning',),
'strøbemerkninger': ('strøbemerkning',),
'strøbil': ('strøbil',),
'strøbilen': ('strøbil',),
'strøbilene': ('strøbil',),
'strøbiler': ('strøbil',),
'strøbord': ('strøbord',),
'strøborda': ('strøbord',),
'strøbordene': ('strøbord',),
'strøborder': ('strøbord',),
'strøbordet': ('strøbord',),
'strøjobb': ('strøjobb',),
'strøjobben': ('strøjobb',),
'strøjobbene': ('strøjobb',),
'strøjobber': ('strøjobb',),
'strøk': ('strøk',),
'strøka': ('strøk',),
'strøkene': ('strøk',),
'strøket': ('strøk',),
'strøm': ('strøm',),
'strømmen': ('strøm',),
'strømmene': ('strøm',),
'strømmer': ('strøm',),
'strømbrott': ('strømbrott',),
'strømbrotta': ('strømbrott',),
'strømbrottene': ('strømbrott',),
'strømbrottet': ('strømbrott',),
'strømbrudd': ('strømbrudd',),
'strømbrudda': ('strømbrudd',),
'strømbruddene': ('strømbrudd',),
'strømbruddet': ('strømbrudd',),
'strømbryter': ('strømbryter',),
'strømbrytere': ('strømbryter',),
'strømbryteren': ('strømbryter',),
'strømbryterer': ('strømbryter',),
'strømbryterne': ('strømbryter',),
'strømdrag': ('strømdrag',),
'strømdraga': ('strømdrag',),
'strømdragene': ('strømdrag',),
'strømdraget': ('strømdrag',),
'strømforbruk': ('strømforbruk',),
'strømforbruka': ('strømforbruk',),
'strømforbrukene': ('strømforbruk',),
'strømforbruket': ('strømforbruk',),
'strømforhold': ('strømforhold',),
'strømforholda': ('strømforhold',),
'strømforholdene': ('strømforhold',),
'strømforholdet': ('strømforhold',),
'strømkilde': ('strømkilde',),
'strømkilden': ('strømkilde',),
'strømkildene': ('strømkilde',),
'strømkilder': ('strømkilde',),
'strømkjelda': ('strømkjelde',),
'strømkjelde': ('strømkjelde',),
'strømkjelden': ('strømkjelde',),
'strømkjeldene': ('strømkjelde',),
'strømkjelder': ('strømkjelde',),
'strømkrets': ('strømkrets',),
'strømkretsen': ('strømkrets',),
'strømkretsene': ('strømkrets',),
'strømkretser': ('strømkrets',),
'strømlinja': ('strømlinje',),
'strømlinje': ('strømlinje',),
'strømlinjen': ('strømlinje',),
'strømlinjene': ('strømlinje',),
'strømlinjer': ('strømlinje',),
'strømlinjeform': ('strømlinjeform',),
'strømlinjeforma': ('strømlinjeform',),
'strømlinjeformen': ('strømlinjeform',),
'strømlinjeformene': ('strømlinjeform',),
'strømlinjeformer': ('strømlinjeform',),
'strømming': ('strømming',),
'strømmingen': ('strømming',),
'strømmingene': ('strømming',),
'strømminger': ('strømming',),
'strømmåler': ('strømmåler',),
'strømmålere': ('strømmåler',),
'strømmåleren': ('strømmåler',),
'strømmålerer': ('strømmåler',),
'strømmålerne': ('strømmåler',),
'strømning': ('strømning',),
'strømninga': ('strømning',),
'strømningen': ('strømning',),
'strømningene': ('strømning',),
'strømninger': ('strømning',),
'strømpa': ('strømpe',),
'strømpe': ('strømpe',),
'strømpen': ('strømpe',),
'strømpene': ('strømpe',),
'strømper': ('strømpe',),
'strømpeband': ('strømpeband',),
'strømpebanda': ('strømpeband',),
'strømpebandene': ('strømpeband',),
'strømpebandet': ('strømpeband',),
'strømpebuksa': ('strømpebukse',),
'strømpebukse': ('strømpebukse',),
'strømpebuksen': ('strømpebukse',),
'strømpebuksene': ('strømpebukse',),
'strømpebukser': ('strømpebukse',),
'strømpebånd': ('strømpebånd',),
'strømpebånda': ('strømpebånd',),
'strømpebåndene': ('strømpebånd',),
'strømpebåndet': ('strømpebånd',),
'strømpeleist': ('strømpeleist',),
'strømpeleisten': ('strømpeleist',),
'strømpeleistene': ('strømpeleist',),
'strømpeleister': ('strømpeleist',),
'strømpelest': ('strømpelest',),
'strømpelesten': ('strømpelest',),
'strømpelestene': ('strømpelest',),
'strømpelester': ('strømpelest',),
'strømrasjonering': ('strømrasjonering',),
'strømrasjoneringa': ('strømrasjonering',),
'strømrasjoneringen': ('strømrasjonering',),
'strømrasjoneringene': ('strømrasjonering',),
'strømrasjoneringer': ('strømrasjonering',),
'strømregning': ('strømregning',),
'strømregninga': ('strømregning',),
'strømregningen': ('strømregning',),
'strømregningene': ('strømregning',),
'strømregninger': ('strømregning',),
'strømrekning': ('strømrekning',),
'strømrekninga': ('strømrekning',),
'strømrekningen': ('strømrekning',),
'strømrekningene': ('strømrekning',),
'strømrekninger': ('strømrekning',),
'strømsild': ('strømsild',),
'strømsilda': ('strømsild',),
'strømsilden': ('strømsild',),
'strømsildene': ('strømsild',),
'strømsilder': ('strømsild',),
'strømstans': ('strømstans',),
'strømstansen': ('strømstans',),
'strømstansene': ('strømstans',),
'strømstanser': ('strømstans',),
'strømstyrke': ('strømstyrke',),
'strømstyrken': ('strømstyrke',),
'strømstyrkene': ('strømstyrke',),
'strømstyrker': ('strømstyrke',),
'strømutkobling': ('strømutkobling',),
'strømutkoblinga': ('strømutkobling',),
'strømutkoblingen': ('strømutkobling',),
'strømutkoblingene': ('strømutkobling',),
'strømutkoblinger': ('strømutkobling',),
'strømutkopling': ('strømutkopling',),
'strømutkoplinga': ('strømutkopling',),
'strømutkoplingen': ('strømutkopling',),
'strømutkoplingene': ('strømutkopling',),
'strømutkoplinger': ('strømutkopling',),
'strømvender': ('strømvender',),
'strømvendere': ('strømvender',),
'strømvenderen': ('strømvender',),
'strømvenderer': ('strømvender',),
'strømvenderne': ('strømvender',),
'strøsla': ('strøssel',),
'strøslene': ('strøssel',),
'strøsler': ('strøssel',),
'strøslet': ('strøssel',),
'strøssel': ('strøssel',),
'strøsselet': ('strøssel',),
'strøsukker': ('strøsukker',),
'strøsukkera': ('strøsukker',),
'strøsukkere': ('strøsukker',),
'strøsukkerene': ('strøsukker',),
'strøsukkeret': ('strøsukker',),
'strøsukkerne': ('strøsukker',),
'strøtanke': ('strøtanke',),
'strøtanken': ('strøtanke',),
'strøtankene': ('strøtanke',),
'strøtanker': ('strøtanke',),
'stubb': ('stubb',),
'stubben': ('stubb',),
'stubbene': ('stubb',),
'stubber': ('stubb',),
'stubbdrift': ('stubbdrift',),
'stubbdrifta': ('stubbdrift',),
'stubbdriften': ('stubbdrift',),
'stubbdriftene': ('stubbdrift',),
'stubbdrifter': ('stubbdrift',),
'stubbe': ('stubbe',),
'stubben': ('stubbe',),
'stubbene': ('stubbe',),
'stubber': ('stubbe',),
'stubbebryter': ('stubbebryter',),
'stubbebrytere': ('stubbebryter',),
'stubbebryteren': ('stubbebryter',),
'stubbebryterer': ('stubbebryter',),
'stubbebryterne': ('stubbebryter',),
'stubbeloft': ('stubbeloft',),
'stubbelofta': ('stubbeloft',),
'stubbeloftene': ('stubbeloft',),
'stubbeloftet': ('stubbeloft',),
'stubbmark': ('stubbmark',),
'stubbmarka': ('stubbmark',),
'stubbmarken': ('stubbmark',),
'stubbmarkene': ('stubbmark',),
'stubbmarker': ('stubbmark',),
'stubbåker': ('stubbåker',),
'stubbåkere': ('stubbåker',),
'stubbåkeren': ('stubbåker',),
'stubbåkerne': ('stubbåker',),
'stubbåkre': ('stubbåker',),
'stubbåkrene': ('stubbåker',),
'stubbåkrer': ('stubbåker',),
'student': ('student',),
'studenten': ('student',),
'studentene': ('student',),
'studenter': ('student',),
'studentby': ('studentby',),
'studentbyen': ('studentby',),
'studentbyene': ('studentby',),
'studentbyer': ('studentby',),
'studenteksamen': ('studenteksamen',),
'studenteksamenen': ('studenteksamen',),
'studenteksamenene': ('studenteksamen',),
'studenteksamener': ('studenteksamen',),
'studentfabrikk': ('studentfabrikk',),
'studentfabrikken': ('studentfabrikk',),
'studentfabrikkene': ('studentfabrikk',),
'studentfabrikker': ('studentfabrikk',),
'studentheim': ('studentheim',),
'studentheimen': ('studentheim',),
'studentheimene': ('studentheim',),
'studentheimer': ('studentheim',),
'studenthjem': ('studenthjem',),
'studenthjemma': ('studenthjem',),
'studenthjemmene': ('studenthjem',),
'studenthjemmet': ('studenthjem',),
'studentlua': ('studentlue',),
'studentlue': ('studentlue',),
'studentluen': ('studentlue',),
'studentluene': ('studentlue',),
'studentluer': ('studentlue',),
'studentluva': ('studentluve',),
'studentluve': ('studentluve',),
'studentluven': ('studentluve',),
'studentluvene': ('studentluve',),
'studentluver': ('studentluve',),
'studentmoderasjon': ('studentmoderasjon',),
'studentmoderasjonen': ('studentmoderasjon',),
'studentmoderasjonene': ('studentmoderasjon',),
'studentmoderasjoner': ('studentmoderasjon',),
'studentsamfunn': ('studentsamfunn',),
'studentsamfunna': ('studentsamfunn',),
'studentsamfunnene': ('studentsamfunn',),
'studentsamfunnet': ('studentsamfunn',),
'studentsang': ('studentsang',),
'studentsangen': ('studentsang',),
'studentsangene': ('studentsang',),
'studentsanger': ('studentsang',),
'studentuka': ('studentuke',),
'studentuke': ('studentuke',),
'studentuken': ('studentuke',),
'studentukene': ('studentuke',),
'studentuker': ('studentuke',),
'studentveka': ('studentveke',),
'studentveke': ('studentveke',),
'studentveken': ('studentveke',),
'studentvekene': ('studentveke',),
'studentveker': ('studentveke',),
'studerkammer': ('studerkammer',),
'studerkammeret': ('studerkammer',),
'studerkamra': ('studerkammer',),
'studerkamre': ('studerkammer',),
'studerkamrene': ('studerkammer',),
'studie': ('studie',),
'studien': ('studie',),
'studiene': ('studie',),
'studier': ('studie',),
'studiebegrensning': ('studiebegrensning',),
'studiebegrensninga': ('studiebegrensning',),
'studiebegrensningen': ('studiebegrensning',),
'studiebegrensningene': ('studiebegrensning',),
'studiebegrensninger': ('studiebegrensning',),
'studiekamerat': ('studiekamerat',),
'studiekameraten': ('studiekamerat',),
'studiekameratene': ('studiekamerat',),
'studiekamerater': ('studiekamerat',),
'studieleder': ('studieleder',),
'studieledere': ('studieleder',),
'studielederen': ('studieleder',),
'studielederer': ('studieleder',),
'studielederne': ('studieleder',),
'studielån': ('studielån',),
'studielåna': ('studielån',),
'studielånene': ('studielån',),
'studielånet': ('studielån',),
'studieplan': ('studieplan',),
'studieplanen': ('studieplan',),
'studieplanene': ('studieplan',),
'studieplaner': ('studieplan',),
'studiereisa': ('studiereise',),
'studiereise': ('studiereise',),
'studiereisen': ('studiereise',),
'studiereisene': ('studiereise',),
'studiereiser': ('studiereise',),
'studierektor': ('studierektor',),
'studierektoren': ('studierektor',),
'studierektorene': ('studierektor',),
'studierektorer': ('studierektor',),
'studiering': ('studiering',),
'studieringen': ('studiering',),
'studieringene': ('studiering',),
'studieringer': ('studiering',),
'studiesirkel': ('studiesirkel',),
'studiesirkelen': ('studiesirkel',),
'studiesirklene': ('studiesirkel',),
'studiesirkler': ('studiesirkel',),
'studietid': ('studietid',),
'studietida': ('studietid',),
'studietiden': ('studietid',),
'studietidene': ('studietid',),
'studietider': ('studietid',),
'studina': ('studine',),
'studine': ('studine',),
'studinen': ('studine',),
'studinene': ('studine',),
'studiner': ('studine',),
'studio': ('studio',),
'studioa': ('studio',),
'studioene': ('studio',),
'studioer': ('studio',),
'studioet': ('studio',),
'studiosus perpetuus': ('studiosus perpetuus',),
'studia': ('studium',),
'studiene': ('studium',),
'studier': ('studium',),
'studiet': ('studium',),
'studium': ('studium',),
'stua': ('stue',),
'stue': ('stue',),
'stuen': ('stue',),
'stuene': ('stue',),
'stuer': ('stue',),
'stuebygning': ('stuebygning',),
'stuebygninga': ('stuebygning',),
'stuebygningen': ('stuebygning',),
'stuebygningene': ('stuebygning',),
'stuebygninger': ('stuebygning',),
'stuedør': ('stuedør',),
'stuedøra': ('stuedør',),
'stuedøren': ('stuedør',),
'stuedørene': ('stuedør',),
'stuedører': ('stuedør',),
'stuegolv': ('stuegolv',),
'stuegolva': ('stuegolv',),
'stuegolvene': ('stuegolv',),
'stuegolvet': ('stuegolv',),
'stuegris': ('stuegris',),
'stuegrisen': ('stuegris',),
'stuegrisene': ('stuegris',),
'stuegriser': ('stuegris',),
'stuegulv': ('stuegulv',),
'stuegulva': ('stuegulv',),
'stuegulvene': ('stuegulv',),
'stuegulvet': ('stuegulv',),
'stuepika': ('stuepike',),
'stuepike': ('stuepike',),
'stuepiken': ('stuepike',),
'stuepikene': ('stuepike',),
'stuepiker': ('stuepike',),
'stueplanta': ('stueplante',),
'stueplante': ('stueplante',),
'stueplanten': ('stueplante',),
'stueplantene': ('stueplante',),
'stueplanter': ('stueplante',),
'stuer': ('stuer',),
'stuere': ('stuer',),
'stueren': ('stuer',),
'stuerer': ('stuer',),
'stuerne': ('stuer',),
'stuer': ('stuer',),
'stuere': ('stuer',),
'stueren': ('stuer',),
'stuerer': ('stuer',),
'stuerne': ('stuer',),
'stuert': ('stuert',),
'stuerten': ('stuert',),
'stuertene': ('stuert',),
'stuerter': ('stuert',),
'stueur': ('stueur',),
'stueura': ('stueur',),
'stueurene': ('stueur',),
'stueuret': ('stueur',),
'stuing': ('stuing',),
'stuinga': ('stuing',),
'stuingen': ('stuing',),
'stuingene': ('stuing',),
'stuinger': ('stuing',),
'stukk': ('stukk',),
'stukken': ('stukk',),
'stukkene': ('stukk',),
'stukker': ('stukk',),
'stukkatur': ('stukkatur',),
'stukkaturen': ('stukkatur',),
'stukkaturene': ('stukkatur',),
'stukkaturer': ('stukkatur',),
'stukkatør': ('stukkatør',),
'stukkatøren': ('stukkatør',),
'stukkatørene': ('stukkatør',),
'stukkatører': ('stukkatør',),
'stump': ('stump',),
'stumpen': ('stump',),
'stumpene': ('stump',),
'stumper': ('stump',),
'stumpeski': ('stumpeski',),
'stumpeskia': ('stumpeski',),
'stumpeskien': ('stumpeski',),
'stumpeskiene': ('stumpeski',),
'stumpeskier': ('stumpeski',),
'stumpnesa': ('stumpnese',),
'stumpnese': ('stumpnese',),
'stumpnesen': ('stumpnese',),
'stumpnesene': ('stumpnese',),
'stumpneser': ('stumpnese',),
'stumtjener': ('stumtjener',),
'stumtjenere': ('stumtjener',),
'stumtjeneren': ('stumtjener',),
'stumtjenerer': ('stumtjener',),
'stumtjenerne': ('stumtjener',),
'stund': ('stund',),
'stunda': ('stund',),
'stunden': ('stund',),
'stundene': ('stund',),
'stunder': ('stund',),
'stuntmann': ('stuntmann',),
'stuntmannen': ('stuntmann',),
'stuntmenn': ('stuntmann',),
'stuntmennene': ('stuntmann',),
'stup': ('stup',),
'stupa': ('stup',),
'stupene': ('stup',),
'stupet': ('stup',),
'stupa': ('stupa',),
'stupaen': ('stupa',),
'stupaene': ('stupa',),
'stupaer': ('stupa',),
'stupebrett': ('stupebrett',),
'stupebretta': ('stupebrett',),
'stupebrettene': ('stupebrett',),
'stupebretter': ('stupebrett',),
'stupebrettet': ('stupebrett',),
'stuper': ('stuper',),
'stupere': ('stuper',),
'stuperen': ('stuper',),
'stuperer': ('stuper',),
'stuperne': ('stuper',),
'stupiditet': ('stupiditet',),
'stupiditeten': ('stupiditet',),
'stupiditetene': ('stupiditet',),
'stupiditeter': ('stupiditet',),
'stupmørka': ('stupmørke',),
'stupmørke': ('stupmørke',),
'stupmørkene': ('stupmørke',),
'stupmørker': ('stupmørke',),
'stupmørket': ('stupmørke',),
'stuss': ('stuss',),
'stussen': ('stuss',),
'stussene': ('stuss',),
'stusser': ('stuss',),
'stuss': ('stuss',),
'stussen': ('stuss',),
'stussene': ('stuss',),
'stusser': ('stuss',),
'stuss': ('stuss',),
'stussen': ('stuss',),
'stussene': ('stuss',),
'stusser': ('stuss',),
'stut': ('stut',),
'stuten': ('stut',),
'stutene': ('stut',),
'stuter': ('stut',),
'stutt-trøya': ('stutt-trøye',),
'stutt-trøye': ('stutt-trøye',),
'stutt-trøyen': ('stutt-trøye',),
'stutt-trøyene': ('stutt-trøye',),
'stutt-trøyer': ('stutt-trøye',),
'stutteri': ('stutteri',),
'stutteria': ('stutteri',),
'stutteriene': ('stutteri',),
'stutterier': ('stutteri',),
'stutteriet': ('stutteri',),
'stutting': ('stutting',),
'stuttingen': ('stutting',),
'stuttingene': ('stutting',),
'stuttinger': ('stutting',),
'stuttorv': ('stuttorv',),
'stuttorva': ('stuttorv',),
'stuttorvene': ('stuttorv',),
'stuttorvet': ('stuttorv',),
'stuttrøya': ('stuttrøye',),
'stuttrøye': ('stuttrøye',),
'stuttrøyen': ('stuttrøye',),
'stuttrøyene': ('stuttrøye',),
'stuttrøyer': ('stuttrøye',),
'stuv': ('stuv',),
'stuven': ('stuv',),
'stuvene': ('stuv',),
'stuver': ('stuv',),
'stuver': ('stuver',),
'stuvere': ('stuver',),
'stuveren': ('stuver',),
'stuverer': ('stuver',),
'stuverne': ('stuver',),
'stuver': ('stuver',),
'stuvere': ('stuver',),
'stuveren': ('stuver',),
'stuverer': ('stuver',),
'stuverne': ('stuver',),
'styggedom': ('styggedom',),
'styggedommen': ('styggedom',),
'styggedommene': ('styggedom',),
'styggedommer': ('styggedom',),
'styggelsa': ('styggelse',),
'styggelse': ('styggelse',),
'styggelsene': ('styggelse',),
'styggelser': ('styggelse',),
'styggelset': ('styggelse',),
'styggemannen': ('styggemannen',),
'styggen': ('styggen',),
'styggevær': ('styggevær',),
'styggeværa': ('styggevær',),
'styggeværene': ('styggevær',),
'styggeværer': ('styggevær',),
'styggeværet': ('styggevær',),
'stygging': ('stygging',),
'styggingen': ('stygging',),
'styggingene': ('stygging',),
'stygginger': ('stygging',),
'styggvær': ('styggvær',),
'styggværa': ('styggvær',),
'styggværene': ('styggvær',),
'styggværet': ('styggvær',),
'stykk': ('stykk',),
'stykka': ('stykke',),
'stykke': ('stykke',),
'stykkene': ('stykke',),
'stykker': ('stykke',),
'stykket': ('stykke',),
'stykkgods': ('stykkgods',),
'stykkgodsa': ('stykkgods',),
'stykkgodsene': ('stykkgods',),
'stykkgodset': ('stykkgods',),
'stykkgodsbåt': ('stykkgodsbåt',),
'stykkgodsbåten': ('stykkgodsbåt',),
'stykkgodsbåtene': ('stykkgodsbåt',),
'stykkgodsbåter': ('stykkgodsbåt',),
'stykkgodsfart': ('stykkgodsfart',),
'stykkgodsfarten': ('stykkgodsfart',),
'stykkgodsfartene': ('stykkgodsfart',),
'stykkgodsfarter': ('stykkgodsfart',),
'stykkpris': ('stykkpris',),
'stykkprisen': ('stykkpris',),
'stykkprisene': ('stykkpris',),
'stykkpriser': ('stykkpris',),
'stykksalg': ('stykksalg',),
'stykksalga': ('stykksalg',),
'stykksalgene': ('stykksalg',),
'stykksalget': ('stykksalg',),
'stylte': ('stylte',),
'stylten': ('stylte',),
'styltene': ('stylte',),
'stylter': ('stylte',),
'styltra': ('styltre',),
'styltre': ('styltre',),
'styltren': ('styltre',),
'styltrene': ('styltre',),
'styltrer': ('styltre',),
'stymper': ('stymper',),
'stympere': ('stymper',),
'stymperen': ('stymper',),
'stymperer': ('stymper',),
'stymperne': ('stymper',),
'styrbord': ('styrbord',),
'styra': ('styre',),
'styre': ('styre',),
'styrene': ('styre',),
'styrer': ('styre',),
'styret': ('styre',),
'styrefjær': ('styrefjær',),
'styrefjæra': ('styrefjær',),
'styrefjæren': ('styrefjær',),
'styrefjærene': ('styrefjær',),
'styrefjærer': ('styrefjær',),
'styrefjør': ('styrefjør',),
'styrefjøra': ('styrefjør',),
'styrefjøren': ('styrefjør',),
'styrefjørene': ('styrefjør',),
'styrefjører': ('styrefjør',),
'styreform': ('styreform',),
'styreforma': ('styreform',),
'styreformen': ('styreform',),
'styreformene': ('styreform',),
'styreformer': ('styreform',),
'styreformann': ('styreformann',),
'styreformannen': ('styreformann',),
'styreformenn': ('styreformann',),
'styreformennene': ('styreformann',),
'styrehus': ('styrehus',),
'styrehusa': ('styrehus',),
'styrehusene': ('styrehus',),
'styrehuset': ('styrehus',),
'styreinnretning': ('styreinnretning',),
'styreinnretninga': ('styreinnretning',),
'styreinnretningen': ('styreinnretning',),
'styreinnretningene': ('styreinnretning',),
'styreinnretninger': ('styreinnretning',),
'styrelse': ('styrelse',),
'styrelsen': ('styrelse',),
'styrelsene': ('styrelse',),
'styrelser': ('styrelse',),
'styremakt': ('styremakt',),
'styremakta': ('styremakt',),
'styremakten': ('styremakt',),
'styremaktene': ('styremakt',),
'styremakter': ('styremakt',),
'styremedlem': ('styremedlem',),
'styremedlemma': ('styremedlem',),
'styremedlemmene': ('styremedlem',),
'styremedlemmer': ('styremedlem',),
'styremedlemmet': ('styremedlem',),
'styremøta': ('styremøte',),
'styremøte': ('styremøte',),
'styremøtene': ('styremøte',),
'styremøter': ('styremøte',),
'styremøtet': ('styremøte',),
'styren': ('styren',),
'styrena': ('styren',),
'styrenene': ('styren',),
'styrenet': ('styren',),
'styrer': ('styrer',),
'styrere': ('styrer',),
'styreren': ('styrer',),
'styrerer': ('styrer',),
'styrerne': ('styrer',),
'styresett': ('styresett',),
'styresetta': ('styresett',),
'styresettene': ('styresett',),
'styresettet': ('styresett',),
'styresmakt': ('styresmakt',),
'styresmakta': ('styresmakt',),
'styresmakten': ('styresmakt',),
'styresmaktene': ('styresmakt',),
'styresmakter': ('styresmakt',),
'styresnekka': ('styresnekke',),
'styresnekke': ('styresnekke',),
'styresnekken': ('styresnekke',),
'styresnekkene': ('styresnekke',),
'styresnekker': ('styresnekke',),
'styresnø': ('styresnø',),
'styresnøen': ('styresnø',),
'styresnøene': ('styresnø',),
'styresnøer': ('styresnø',),
'styrestang': ('styrestang',),
'styrestanga': ('styrestang',),
'styrestangen': ('styrestang',),
'styrestengene': ('styrestang',),
'styrestenger': ('styrestang',),
'styrestrek': ('styrestrek',),
'styrestreken': ('styrestrek',),
'styrestrekene': ('styrestrek',),
'styrestreker': ('styrestrek',),
'styrevol': ('styrevol',),
'styrevolen': ('styrevol',),
'styrevolene': ('styrevol',),
'styrevoler': ('styrevol',),
'styreåra': ('styreåre',),
'styreåre': ('styreåre',),
'styreåren': ('styreåre',),
'styreårene': ('styreåre',),
'styreårer': ('styreåre',),
'styring': ('styring',),
'styringa': ('styring',),
'styringen': ('styring',),
'styringene': ('styring',),
'styringer': ('styring',),
'styringsregel': ('styringsregel',),
'styringsregelen': ('styringsregel',),
'styringsreglene': ('styringsregel',),
'styringsregler': ('styringsregel',),
'styringsrett': ('styringsrett',),
'styringsretten': ('styringsrett',),
'styringsrettene': ('styringsrett',),
'styringsretter': ('styringsrett',),
'styringsverk': ('styringsverk',),
'styringsverka': ('styringsverk',),
'styringsverkene': ('styringsverk',),
'styringsverker': ('styringsverk',),
'styringsverket': ('styringsverk',),
'styrke': ('styrke',),
'styrken': ('styrke',),
'styrkene': ('styrke',),
'styrker': ('styrke',),
'styrkebelta': ('styrkebelte',),
'styrkebelte': ('styrkebelte',),
'styrkebeltene': ('styrkebelte',),
'styrkebelter': ('styrkebelte',),
'styrkebeltet': ('styrkebelte',),
'styrkedrikk': ('styrkedrikk',),
'styrkedrikken': ('styrkedrikk',),
'styrkedrikkene': ('styrkedrikk',),
'styrkedrikker': ('styrkedrikk',),
'styrkedråpe': ('styrkedråpe',),
'styrkedråpen': ('styrkedråpe',),
'styrkedråpene': ('styrkedråpe',),
'styrkedråper': ('styrkedråpe',),
'styrkeforhold': ('styrkeforhold',),
'styrkeforholda': ('styrkeforhold',),
'styrkeforholdene': ('styrkeforhold',),
'styrkeforholdet': ('styrkeforhold',),
'styrkelse': ('styrkelse',),
'styrkelsen': ('styrkelse',),
'styrkelsene': ('styrkelse',),
'styrkelser': ('styrkelse',),
'styrkeløft': ('styrkeløft',),
'styrkeløfta': ('styrkeløft',),
'styrkeløftene': ('styrkeløft',),
'styrkeløftet': ('styrkeløft',),
'styrkeprøva': ('styrkeprøve',),
'styrkeprøve': ('styrkeprøve',),
'styrkeprøven': ('styrkeprøve',),
'styrkeprøvene': ('styrkeprøve',),
'styrkeprøver': ('styrkeprøve',),
'styrketrening': ('styrketrening',),
'styrketreninga': ('styrketrening',),
'styrketreningen': ('styrketrening',),
'styrketreningene': ('styrketrening',),
'styrketreninger': ('styrketrening',),
'styrking': ('styrking',),
'styrkinga': ('styrking',),
'styrkingen': ('styrking',),
'styrkingene': ('styrking',),
'styrkinger': ('styrking',),
'styrkning': ('styrkning',),
'styrkninga': ('styrkning',),
'styrkningen': ('styrkning',),
'styrkningene': ('styrkning',),
'styrkninger': ('styrkning',),
'styrmann': ('styrmann',),
'styrmannen': ('styrmann',),
'styrmenn': ('styrmann',),
'styrmennene': ('styrmann',),
'styrmannseksamen': ('styrmannseksamen',),
'styrmannseksamenen': ('styrmannseksamen',),
'styrmannseksamenene': ('styrmannseksamen',),
'styrmannseksamener': ('styrmannseksamen',),
'styrt': ('styrt',),
'styrten': ('styrt',),
'styrtene': ('styrt',),
'styrter': ('styrt',),
'styrthjelm': ('styrthjelm',),
'styrthjelmen': ('styrthjelm',),
'styrthjelmene': ('styrthjelm',),
'styrthjelmer': ('styrthjelm',),
'styrtning': ('styrtning',),
'styrtninga': ('styrtning',),
'styrtningen': ('styrtning',),
'styrtningene': ('styrtning',),
'styrtninger': ('styrtning',),
'styrtregn': ('styrtregn',),
'styrtregna': ('styrtregn',),
'styrtregnene': ('styrtregn',),
'styrtregnet': ('styrtregn',),
'styrtsjø': ('styrtsjø',),
'styrtsjøen': ('styrtsjø',),
'styrtsjøene': ('styrtsjø',),
'styrtsjøer': ('styrtsjø',),
'styrvol': ('styrvol',),
'styrvolen': ('styrvol',),
'styrvolene': ('styrvol',),
'styrvoler': ('styrvol',),
'styv': ('styv',),
'styven': ('styv',),
'styvene': ('styv',),
'styver': ('styv',),
'styver': ('styver',),
'styvere': ('styver',),
'styveren': ('styver',),
'styverer': ('styver',),
'styverne': ('styver',),
'stå': ('stå',),
'ståen': ('stå',),
'ståene': ('stå',),
'ståer': ('stå',),
'stå': ('stå',),
'ståhei': ('ståhei',),
'ståheien': ('ståhei',),
'ståheiene': ('ståhei',),
'ståheier': ('ståhei',),
'ståk': ('ståk',),
'ståka': ('ståk',),
'ståkene': ('ståk',),
'ståket': ('ståk',),
'ståkarakter': ('ståkarakter',),
'ståkarakteren': ('ståkarakter',),
'ståkarakterene': ('ståkarakter',),
'ståkarakterer': ('ståkarakter',),
'stål': ('stål',),
'ståla': ('stål',),
'stålene': ('stål',),
'stålet': ('stål',),
'stål': ('stål',),
'ståla': ('stål',),
'stålene': ('stål',),
'stålet': ('stål',),
'stålampa': ('stålampe',),
'stålampe': ('stålampe',),
'stålampen': ('stålampe',),
'stålampene': ('stålampe',),
'stålamper': ('stålampe',),
'stålis': ('stålis',),
'stålisen': ('stålis',),
'stålisene': ('stålis',),
'ståliser': ('stålis',),
'stålorm': ('stålorm',),
'stålormen': ('stålorm',),
'stålormene': ('stålorm',),
'stålormer': ('stålorm',),
'stålplast': ('stålplast',),
'stålplasten': ('stålplast',),
'stålplastene': ('stålplast',),
'stålplaster': ('stålplast',),
'stålpuss': ('stålpuss',),
'stålpussen': ('stålpuss',),
'stålpussene': ('stålpuss',),
'stålpusser': ('stålpuss',),
'stålrør': ('stålrør',),
'stålrøra': ('stålrør',),
'stålrørene': ('stålrør',),
'stålrøret': ('stålrør',),
'ståltråd': ('ståltråd',),
'ståltråden': ('ståltråd',),
'ståltrådene': ('ståltråd',),
'ståltråder': ('ståltråd',),
'stålull': ('stålull',),
'stålulla': ('stålull',),
'stålullen': ('stålull',),
'stålullene': ('stålull',),
'ståluller': ('stålull',),
'ståman': ('ståman',),
'ståmana': ('ståman',),
'ståmanen': ('ståman',),
'ståmanene': ('ståman',),
'ståmaner': ('ståman',),
'ståpikk': ('ståpikk',),
'ståpikken': ('ståpikk',),
'ståpikkene': ('ståpikk',),
'ståpikker': ('ståpikk',),
'ståplass': ('ståplass',),
'ståplassen': ('ståplass',),
'ståplassene': ('ståplass',),
'ståplasser': ('ståplass',),
'ståsted': ('ståsted',),
'ståstedene': ('ståsted',),
'ståsteder': ('ståsted',),
'ståstedet': ('ståsted',),
'stø': ('stø',),
'støa': ('stø',),
'støene': ('stø',),
'støet': ('stø',),
'stø': ('stø',),
'støa': ('stø',),
'støen': ('stø',),
'støene': ('stø',),
'støer': ('stø',),
'støkk': ('støkk',),
'støkken': ('støkk',),
'støkkene': ('støkk',),
'støkker': ('støkk',),
'støl': ('støl',),
'stølen': ('støl',),
'stølene': ('støl',),
'støler': ('støl',),
'stønad': ('stønad',),
'stønaden': ('stønad',),
'stønadene': ('stønad',),
'stønader': ('stønad',),
'stønn': ('stønn',),
'stønna': ('stønn',),
'stønnene': ('stønn',),
'stønnet': ('stønn',),
'støp': ('støp',),
'støpa': ('støp',),
'støpen': ('støp',),
'støpene': ('støp',),
'støper': ('støp',),
'støpet': ('støp',),
'støpegods': ('støpegods',),
'støpegodsa': ('støpegods',),
'støpegodsene': ('støpegods',),
'støpegodset': ('støpegods',),
'støpejern': ('støpejern',),
'støpejerna': ('støpejern',),
'støpejernene': ('støpejern',),
'støpejernet': ('støpejern',),
'støper': ('støper',),
'støpere': ('støper',),
'støperen': ('støper',),
'støperer': ('støper',),
'støperne': ('støper',),
'støperi': ('støperi',),
'støperia': ('støperi',),
'støperiene': ('støperi',),
'støperier': ('støperi',),
'støperiet': ('støperi',),
'støpesand': ('støpesand',),
'støpesanden': ('støpesand',),
'støpesandene': ('støpesand',),
'støpesander': ('støpesand',),
'støpeskei': ('støpeskei',),
'støpeskeia': ('støpeskei',),
'støpeskeien': ('støpeskei',),
'støpeskeiene': ('støpeskei',),
'støpeskeier': ('støpeskei',),
'støpeskje': ('støpeskje',),
'støpeskjea': ('støpeskje',),
'støpeskjeen': ('støpeskje',),
'støpeskjeene': ('støpeskje',),
'støpeskjeer': ('støpeskje',),
'støpning': ('støpning',),
'støpninga': ('støpning',),
'støpningen': ('støpning',),
'støpningene': ('støpning',),
'støpninger': ('støpning',),
'støpsel': ('støpsel',),
'støpselet': ('støpsel',),
'støpsla': ('støpsel',),
'støpslene': ('støpsel',),
'støpsler': ('støpsel',),
'støpslet': ('støpsel',),
'støpul': ('støpul',),
'støpulen': ('støpul',),
'støpulene': ('støpul',),
'støpuler': ('støpul',),
'stør': ('stør',),
'støren': ('stør',),
'størene': ('stør',),
'stører': ('stør',),
'størhus': ('størhus',),
'størhusa': ('størhus',),
'størhusene': ('størhus',),
'størhuset': ('størhus',),
'størja': ('størje',),
'størje': ('størje',),
'størjen': ('størje',),
'størjene': ('størje',),
'størjer': ('størje',),
'størknepunkt': ('størknepunkt',),
'størknepunkta': ('størknepunkt',),
'størknepunktene': ('størknepunkt',),
'størknepunkter': ('størknepunkt',),
'størknepunktet': ('størknepunkt',),
'størrelse': ('størrelse',),
'størrelsen': ('størrelse',),
'størrelsene': ('størrelse',),
'størrelser': ('størrelse',),
'størrelsesorden': ('størrelsesorden',),
'størrelsesordenen': ('størrelsesorden',),
'størrelsesordenene': ('størrelsesorden',),
'størrelsesordener': ('størrelsesorden',),
'størstedel': ('størstedel',),
'størstedelen': ('størstedel',),
'størstedelene': ('størstedel',),
'størstedeler': ('størstedel',),
'størstepart': ('størstepart',),
'størsteparten': ('størstepart',),
'størstepartene': ('størstepart',),
'størsteparter': ('størstepart',),
'støt': ('støt',),
'støta': ('støt',),
'støtene': ('støt',),
'støtet': ('støt',),
'støtdemper': ('støtdemper',),
'støtdempere': ('støtdemper',),
'støtdemperen': ('støtdemper',),
'støtdemperer': ('støtdemper',),
'støtdemperne': ('støtdemper',),
'støtfanger': ('støtfanger',),
'støtfangere': ('støtfanger',),
'støtfangeren': ('støtfanger',),
'støtfangerer': ('støtfanger',),
'støtfangerne': ('støtfanger',),
'støtputa': ('støtpute',),
'støtpute': ('støtpute',),
'støtputen': ('støtpute',),
'støtputene': ('støtpute',),
'støtputer': ('støtpute',),
'støttann': ('støttann',),
'støttanna': ('støttann',),
'støttannen': ('støttann',),
'støttennene': ('støttann',),
'støttenner': ('støttann',),
'støtta': ('støtte',),
'støtte': ('støtte',),
'støtten': ('støtte',),
'støttene': ('støtte',),
'støtter': ('støtte',),
'støtteaksjon': ('støtteaksjon',),
'støtteaksjonen': ('støtteaksjon',),
'støtteaksjonene': ('støtteaksjon',),
'støtteaksjoner': ('støtteaksjon',),
'støttebruk': ('støttebruk',),
'støttebruka': ('støttebruk',),
'støttebrukene': ('støttebruk',),
'støttebruket': ('støttebruk',),
'støttefag': ('støttefag',),
'støttefaga': ('støttefag',),
'støttefagene': ('støttefag',),
'støttefaget': ('støttefag',),
'støttekjøp': ('støttekjøp',),
'støttekjøpa': ('støttekjøp',),
'støttekjøpene': ('støttekjøp',),
'støttekjøpet': ('støttekjøp',),
'støttekompani': ('støttekompani',),
'støttekompania': ('støttekompani',),
'støttekompaniene': ('støttekompani',),
'støttekompanier': ('støttekompani',),
'støttekompaniet': ('støttekompani',),
'støttekontakt': ('støttekontakt',),
'støttekontakten': ('støttekontakt',),
'støttekontaktene': ('støttekontakt',),
'støttekontakter': ('støttekontakt',),
'støttepunkt': ('støttepunkt',),
'støttepunkta': ('støttepunkt',),
'støttepunktene': ('støttepunkt',),
'støttepunkter': ('støttepunkt',),
'støttepunktet': ('støttepunkt',),
'støttespeller': ('støttespeller',),
'støttespellere': ('støttespeller',),
'støttespelleren': ('støttespeller',),
'støttespellerer': ('støttespeller',),
'støttespellerne': ('støttespeller',),
'støttespiller': ('støttespiller',),
'støttespillere': ('støttespiller',),
'støttespilleren': ('støttespiller',),
'støttespillerer': ('støttespiller',),
'støttespillerne': ('støttespiller',),
'støttetropp': ('støttetropp',),
'støttetroppen': ('støttetropp',),
'støttetroppene': ('støttetropp',),
'støttetropper': ('støttetropp',),
'støtteundervisning': ('støtteundervisning',),
'støtteundervisninga': ('støtteundervisning',),
'støtteundervisningen': ('støtteundervisning',),
'støtteundervisningene': ('støtteundervisning',),
'støtteundervisninger': ('støtteundervisning',),
'støttevev': ('støttevev',),
'støtteveva': ('støttevev',),
'støttevevene': ('støttevev',),
'støttevevet': ('støttevev',),
'støtting': ('støtting',),
'støttingen': ('støtting',),
'støttingene': ('støtting',),
'støttinger': ('støtting',),
'støtvåpen': ('støtvåpen',),
'støtvåpenet': ('støtvåpen',),
'støtvåpna': ('støtvåpen',),
'støtvåpnene': ('støtvåpen',),
'støv': ('støv',),
'støva': ('støv',),
'støvene': ('støv',),
'støvet': ('støv',),
'støvbrett': ('støvbrett',),
'støvbretta': ('støvbrett',),
'støvbrettene': ('støvbrett',),
'støvbretter': ('støvbrett',),
'støvbrettet': ('støvbrett',),
'støvbærer': ('støvbærer',),
'støvbærere': ('støvbærer',),
'støvbæreren': ('støvbærer',),
'støvbærerer': ('støvbærer',),
'støvbærerne': ('støvbærer',),
'støvdrager': ('støvdrager',),
'støvdragere': ('støvdrager',),
'støvdrageren': ('støvdrager',),
'støvdragerer': ('støvdrager',),
'støvdragerne': ('støvdrager',),
'støveklut': ('støveklut',),
'støvekluten': ('støveklut',),
'støveklutene': ('støveklut',),
'støvekluter': ('støveklut',),
'støvel': ('støvel',),
'støvelen': ('støvel',),
'støvlene': ('støvel',),
'støvler': ('støvel',),
'støvelskaft': ('støvelskaft',),
'støvelskafta': ('støvelskaft',),
'støvelskaftene': ('støvelskaft',),
'støvelskafter': ('støvelskaft',),
'støvelskaftet': ('støvelskaft',),
'støver': ('støver',),
'støvere': ('støver',),
'støveren': ('støver',),
'støverer': ('støver',),
'støverne': ('støver',),
'støvfilter': ('støvfilter',),
'støvfilteret': ('støvfilter',),
'støvfiltra': ('støvfilter',),
'støvfiltre': ('støvfilter',),
'støvfiltrene': ('støvfilter',),
'støvfiltret': ('støvfilter',),
'støvfnugg': ('støvfnugg',),
'støvfnugga': ('støvfnugg',),
'støvfnuggene': ('støvfnugg',),
'støvfnugget': ('støvfnugg',),
'støvfrakk': ('støvfrakk',),
'støvfrakken': ('støvfrakk',),
'støvfrakkene': ('støvfrakk',),
'støvfrakker': ('støvfrakk',),
'støvlett': ('støvlett',),
'støvletten': ('støvlett',),
'støvlettene': ('støvlett',),
'støvletter': ('støvlett',),
'støvsamler': ('støvsamler',),
'støvsamlere': ('støvsamler',),
'støvsamleren': ('støvsamler',),
'støvsamlerer': ('støvsamler',),
'støvsamlerne': ('støvsamler',),
'støvsky': ('støvsky',),
'støvskya': ('støvsky',),
'støvskyen': ('støvsky',),
'støvskyene': ('støvsky',),
'støvskyer': ('støvsky',),
'støvsuger': ('støvsuger',),
'støvsugere': ('støvsuger',),
'støvsugeren': ('støvsuger',),
'støvsugerer': ('støvsuger',),
'støvsugerne': ('støvsuger',),
'støvveg': ('støvveg',),
'støvvegen': ('støvveg',),
'støvvegene': ('støvveg',),
'støvveger': ('støvveg',),
'støvvei': ('støvvei',),
'støvveien': ('støvvei',),
'støvveiene': ('støvvei',),
'støvveier': ('støvvei',),
'støy': ('støy',),
'støyen': ('støy',),
'støyene': ('støy',),
'støyer': ('støy',),
'støydemper': ('støydemper',),
'støydempere': ('støydemper',),
'støydemperen': ('støydemper',),
'støydemperer': ('støydemper',),
'støydemperne': ('støydemper',),
'støykilde': ('støykilde',),
'støykilden': ('støykilde',),
'støykildene': ('støykilde',),
'støykilder': ('støykilde',),
'støykjelda': ('støykjelde',),
'støykjelde': ('støykjelde',),
'støykjelden': ('støykjelde',),
'støykjeldene': ('støykjelde',),
'støykjelder': ('støykjelde',),
'støyp': ('støyp',),
'støypen': ('støyp',),
'støypene': ('støyp',),
'støyper': ('støyp',),
'støypegods': ('støypegods',),
'støypegodsa': ('støypegods',),
'støypegodsene': ('støypegods',),
'støypegodset': ('støypegods',),
'støypejern': ('støypejern',),
'støypejerna': ('støypejern',),
'støypejernene': ('støypejern',),
'støypejernet': ('støypejern',),
'støyper': ('støyper',),
'støypere': ('støyper',),
'støyperen': ('støyper',),
'støyperer': ('støyper',),
'støyperne': ('støyper',),
'støyperi': ('støyperi',),
'støyperia': ('støyperi',),
'støyperiene': ('støyperi',),
'støyperier': ('støyperi',),
'støyperiet': ('støyperi',),
'støypesand': ('støypesand',),
'støypesanden': ('støypesand',),
'støypesandene': ('støypesand',),
'støypesander': ('støypesand',),
'støypeskei': ('støypeskei',),
'støypeskeia': ('støypeskei',),
'støypeskeien': ('støypeskei',),
'støypeskeiene': ('støypeskei',),
'støypeskeier': ('støypeskei',),
'støypeskje': ('støypeskje',),
'støypeskjea': ('støypeskje',),
'støypeskjeen': ('støypeskje',),
'støypeskjeene': ('støypeskje',),
'støypeskjeer': ('støypeskje',),
'støyplaga': ('støyplage',),
'støyplage': ('støyplage',),
'støyplagen': ('støyplage',),
'støyplagene': ('støyplage',),
'støyplager': ('støyplage',),
'støysender': ('støysender',),
'støysendere': ('støysender',),
'støysenderen': ('støysender',),
'støysenderer': ('støysender',),
'støysenderne': ('støysender',),
'støyskjerm': ('støyskjerm',),
'støyskjermen': ('støyskjerm',),
'støyskjermene': ('støyskjerm',),
'støyskjermer': ('støyskjerm',),
'støyskjerming': ('støyskjerming',),
'støyskjerminga': ('støyskjerming',),
'støyskjermingen': ('støyskjerming',),
'støyskjermingene': ('støyskjerming',),
'støyskjerminger': ('støyskjerming',),
'støysona': ('støysone',),
'støysone': ('støysone',),
'støysonen': ('støysone',),
'støysonene': ('støysone',),
'støysoner': ('støysone',),
'støyt': ('støyt',),
'støyten': ('støyt',),
'støytene': ('støyt',),
'støyter': ('støyt',),
'støyt': ('støyt',),
'støyten': ('støyt',),
'støytene': ('støyt',),
'støyter': ('støyt',),
'støytdemper': ('støytdemper',),
'støytdempere': ('støytdemper',),
'støytdemperen': ('støytdemper',),
'støytdemperer': ('støytdemper',),
'støytdemperne': ('støytdemper',),
'støytfanger': ('støytfanger',),
'støytfangere': ('støytfanger',),
'støytfangeren': ('støytfanger',),
'støytfangerer': ('støytfanger',),
'støytfangerne': ('støytfanger',),
'støytputa': ('støytpute',),
'støytpute': ('støytpute',),
'støytputen': ('støytpute',),
'støytputene': ('støytpute',),
'støytputer': ('støytpute',),
'støyttann': ('støyttann',),
'støyttanna': ('støyttann',),
'støyttannen': ('støyttann',),
'støyttennene': ('støyttann',),
'støyttenner': ('støyttann',),
'støytvåpen': ('støytvåpen',),
'støytvåpenet': ('støytvåpen',),
'støytvåpna': ('støytvåpen',),
'støytvåpnene': ('støytvåpen',),
'su': ('su',),
'sua': ('su',),
'suen': ('su',),
'suene': ('su',),
'suer': ('su',),
'su': ('su',),
'sua': ('su',),
'suen': ('su',),
'suene': ('su',),
'suer': ('su',),
'subb': ('subb',),
'subben': ('subb',),
'subbene': ('subb',),
'subber': ('subb',),
'subb': ('subb',),
'subba': ('subb',),
'subbene': ('subb',),
'subbet': ('subb',),
'subba': ('subbe',),
'subbe': ('subbe',),
'subben': ('subbe',),
'subbene': ('subbe',),
'subber': ('subbe',),
'subbeføra': ('subbeføre',),
'subbeføre': ('subbeføre',),
'subbeførene': ('subbeføre',),
'subbefører': ('subbeføre',),
'subbeføret': ('subbeføre',),
'subjekt': ('subjekt',),
'subjekta': ('subjekt',),
'subjektene': ('subjekt',),
'subjekter': ('subjekt',),
'subjektet': ('subjekt',),
'subjektivisme': ('subjektivisme',),
'subjektivismen': ('subjektivisme',),
'subjektivismene': ('subjektivisme',),
'subjektivismer': ('subjektivisme',),
'subjektivitet': ('subjektivitet',),
'subjektiviteten': ('subjektivitet',),
'subjektivitetene': ('subjektivitet',),
'subjektiviteter': ('subjektivitet',),
'subjektsdel': ('subjektsdel',),
'subjektsdelen': ('subjektsdel',),
'subjektsdelene': ('subjektsdel',),
'subjektsdeler': ('subjektsdel',),
'subjektsform': ('subjektsform',),
'subjektsforma': ('subjektsform',),
'subjektsformen': ('subjektsform',),
'subjektsformene': ('subjektsform',),
'subjektsformer': ('subjektsform',),
'subjektsgenitiv': ('subjektsgenitiv',),
'subjektsgenitiven': ('subjektsgenitiv',),
'subjektsgenitivene': ('subjektsgenitiv',),
'subjektsgenitiver': ('subjektsgenitiv',),
'subkontinent': ('subkontinent',),
'subkontinenta': ('subkontinent',),
'subkontinentene': ('subkontinent',),
'subkontinenter': ('subkontinent',),
'subkontinentet': ('subkontinent',),
'subkultur': ('subkultur',),
'subkulturen': ('subkultur',),
'subkulturene': ('subkultur',),
'subkulturer': ('subkultur',),
'sublimasjon': ('sublimasjon',),
'sublimasjonen': ('sublimasjon',),
'sublimasjonene': ('sublimasjon',),
'sublimasjoner': ('sublimasjon',),
'sublimat': ('sublimat',),
'sublimata': ('sublimat',),
'sublimatene': ('sublimat',),
'sublimater': ('sublimat',),
'sublimatet': ('sublimat',),
'sublimitet': ('sublimitet',),
'sublimiteten': ('sublimitet',),
'sublimitetene': ('sublimitet',),
'sublimiteter': ('sublimitet',),
'subordinasjon': ('subordinasjon',),
'subordinasjonen': ('subordinasjon',),
'subordinasjonene': ('subordinasjon',),
'subordinasjoner': ('subordinasjon',),
'subsidie': ('subsidie',),
'subsidien': ('subsidie',),
'subsidiene': ('subsidie',),
'subsidier': ('subsidie',),
'subsidiepolitikk': ('subsidiepolitikk',),
'subsidiepolitikken': ('subsidiepolitikk',),
'subsidiepolitikkene': ('subsidiepolitikk',),
'subsidiepolitikker': ('subsidiepolitikk',),
'subsistens': ('subsistens',),
'subsistensen': ('subsistens',),
'subsistensene': ('subsistens',),
'subsistenser': ('subsistens',),
'subskribent': ('subskribent',),
'subskribenten': ('subskribent',),
'subskribentene': ('subskribent',),
'subskribenter': ('subskribent',),
'subskripsjon': ('subskripsjon',),
'subskripsjonen': ('subskripsjon',),
'subskripsjonene': ('subskripsjon',),
'subskripsjoner': ('subskripsjon',),
'subskripsjonsinnbydelse': ('subskripsjonsinnbydelse',),
'subskripsjonsinnbydelsen': ('subskripsjonsinnbydelse',),
'subskripsjonsinnbydelsene': ('subskripsjonsinnbydelse',),
'subskripsjonsinnbydelser': ('subskripsjonsinnbydelse',),
'subskripsjonspris': ('subskripsjonspris',),
'subskripsjonsprisen': ('subskripsjonspris',),
'subskripsjonsprisene': ('subskripsjonspris',),
'subskripsjonspriser': ('subskripsjonspris',),
'substans': ('substans',),
'substansen': ('substans',),
'substansene': ('substans',),
'substanser': ('substans',),
'substantiv': ('substantiv',),
'substantiva': ('substantiv',),
'substantivene': ('substantiv',),
'substantiver': ('substantiv',),
'substantivet': ('substantiv',),
'substantivsjuka': ('substantivsjuke',),
'substantivsjuke': ('substantivsjuke',),
'substantivsjuken': ('substantivsjuke',),
'substantivsjukene': ('substantivsjuke',),
'substantivsjuker': ('substantivsjuke',),
'substantivsyka': ('substantivsyke',),
'substantivsyke': ('substantivsyke',),
'substantivsyken': ('substantivsyke',),
'substantivsykene': ('substantivsyke',),
'substantivsyker': ('substantivsyke',),
'substitusjon': ('substitusjon',),
'substitusjonen': ('substitusjon',),
'substitusjonene': ('substitusjon',),
'substitusjoner': ('substitusjon',),
'substitutt': ('substitutt',),
'substitutten': ('substitutt',),
'substituttene': ('substitutt',),
'substitutter': ('substitutt',),
'substitutt': ('substitutt',),
'substitutta': ('substitutt',),
'substituttene': ('substitutt',),
'substitutter': ('substitutt',),
'substituttet': ('substitutt',),
'substrat': ('substrat',),
'substrata': ('substrat',),
'substratene': ('substrat',),
'substrater': ('substrat',),
'substratet': ('substrat',),
'subsumpsjon': ('subsumpsjon',),
'subsumpsjonen': ('subsumpsjon',),
'subsumpsjonene': ('subsumpsjon',),
'subsumpsjoner': ('subsumpsjon',),
'subtilitet': ('subtilitet',),
'subtiliteten': ('subtilitet',),
'subtilitetene': ('subtilitet',),
'subtiliteter': ('subtilitet',),
'subtrahend': ('subtrahend',),
'subtrahenden': ('subtrahend',),
'subtrahendene': ('subtrahend',),
'subtrahender': ('subtrahend',),
'subtraksjon': ('subtraksjon',),
'subtraksjonen': ('subtraksjon',),
'subtraksjonene': ('subtraksjon',),
'subtraksjoner': ('subtraksjon',),
'subtrope': ('subtrope',),
'subtropen': ('subtrope',),
'subtropene': ('subtrope',),
'subtroper': ('subtrope',),
'subus': ('subus',),
'subusen': ('subus',),
'subusene': ('subus',),
'subuser': ('subus',),
'subvensjon': ('subvensjon',),
'subvensjonen': ('subvensjon',),
'subvensjonene': ('subvensjon',),
'subvensjoner': ('subvensjon',),
'subway': ('subway',),
'subwayen': ('subway',),
'subwayene': ('subway',),
'subwayer': ('subway',),
'sudaner': ('sudaner',),
'sudanere': ('sudaner',),
'sudaneren': ('sudaner',),
'sudanerer': ('sudaner',),
'sudanerne': ('sudaner',),
'sudettysker': ('sudettysker',),
'sudettyskere': ('sudettysker',),
'sudettyskeren': ('sudettysker',),
'sudettyskerer': ('sudettysker',),
'sudettyskerne': ('sudettysker',),
'suffiks': ('suffiks',),
'suffiksa': ('suffiks',),
'suffiksene': ('suffiks',),
'suffikser': ('suffiks',),
'suffikset': ('suffiks',),
'suffisanse': ('suffisanse',),
'suffisansen': ('suffisanse',),
'suffisansene': ('suffisanse',),
'suffisanser': ('suffisanse',),
'suffleen': ('sufflé',),
'suffleene': ('sufflé',),
'suffleer': ('sufflé',),
'sufflé': ('sufflé',),
'suffléen': ('sufflé',),
'suffléene': ('sufflé',),
'suffléer': ('sufflé',),
'suffli': ('suffli',),
'sufflien': ('suffli',),
'suffliene': ('suffli',),
'sufflier': ('suffli',),
'sufflør': ('sufflør',),
'suffløren': ('sufflør',),
'sufflørene': ('sufflør',),
'sufflører': ('sufflør',),
'suffløsa': ('suffløse',),
'suffløse': ('suffløse',),
'suffløsen': ('suffløse',),
'suffløsene': ('suffløse',),
'suffløser': ('suffløse',),
'suffragetta': ('suffragette',),
'suffragette': ('suffragette',),
'suffragetten': ('suffragette',),
'suffragettene': ('suffragette',),
'suffragetter': ('suffragette',),
'sug': ('sug',),
'suga': ('sug',),
'sugene': ('sug',),
'suget': ('sug',),
'sugefisk': ('sugefisk',),
'sugefisken': ('sugefisk',),
'sugefiskene': ('sugefisk',),
'sugefisker': ('sugefisk',),
'sugekopp': ('sugekopp',),
'sugekoppen': ('sugekopp',),
'sugekoppene': ('sugekopp',),
'sugekopper': ('sugekopp',),
'sugelam': ('sugelam',),
'sugelamma': ('sugelam',),
'sugelammene': ('sugelam',),
'sugelammet': ('sugelam',),
'sugemerka': ('sugemerke',),
'sugemerke': ('sugemerke',),
'sugemerkene': ('sugemerke',),
'sugemerker': ('sugemerke',),
'sugemerket': ('sugemerke',),
'sugemunn': ('sugemunn',),
'sugemunnen': ('sugemunn',),
'sugemunnene': ('sugemunn',),
'sugemunner': ('sugemunn',),
'sugepumpa': ('sugepumpe',),
'sugepumpe': ('sugepumpe',),
'sugepumpen': ('sugepumpe',),
'sugepumpene': ('sugepumpe',),
'sugepumper': ('sugepumpe',),
'suger': ('suger',),
'sugere': ('suger',),
'sugeren': ('suger',),
'sugerer': ('suger',),
'sugerne': ('suger',),
'sugerør': ('sugerør',),
'sugerøra': ('sugerør',),
'sugerørene': ('sugerør',),
'sugerøret': ('sugerør',),
'sugeskål': ('sugeskål',),
'sugeskåla': ('sugeskål',),
'sugeskålen': ('sugeskål',),
'sugeskålene': ('sugeskål',),
'sugeskåler': ('sugeskål',),
'sugetablett': ('sugetablett',),
'sugetabletten': ('sugetablett',),
'sugetablettene': ('sugetablett',),
'sugetabletter': ('sugetablett',),
'sugg': ('sugg',),
'suggen': ('sugg',),
'suggene': ('sugg',),
'sugger': ('sugg',),
'sugga': ('sugge',),
'sugge': ('sugge',),
'suggen': ('sugge',),
'suggene': ('sugge',),
'sugger': ('sugge',),
'suggesjon': ('suggesjon',),
'suggesjonen': ('suggesjon',),
'suggesjonene': ('suggesjon',),
'suggesjoner': ('suggesjon',),
'suite': ('suite',),
'suiten': ('suite',),
'suitene': ('suite',),
'suiter': ('suite',),
'sujett': ('sujett',),
'sujetta': ('sujett',),
'sujettene': ('sujett',),
'sujetter': ('sujett',),
'sujettet': ('sujett',),
'sukat': ('sukat',),
'sukaten': ('sukat',),
'sukatene': ('sukat',),
'sukater': ('sukat',),
'sukett': ('sukett',),
'suketten': ('sukett',),
'sukettene': ('sukett',),
'suketter': ('sukett',),
'sukk': ('sukk',),
'sukka': ('sukk',),
'sukken': ('sukk',),
'sukkene': ('sukk',),
'sukket': ('sukk',),
'sukkel': ('sukkel',),
'sukkelet': ('sukkel',),
'sukla': ('sukkel',),
'suklene': ('sukkel',),
'suklet': ('sukkel',),
'sukker': ('sukker',),
'sukkera': ('sukker',),
'sukkere': ('sukker',),
'sukkerene': ('sukker',),
'sukkeret': ('sukker',),
'sukkerne': ('sukker',),
'sukkerbeta': ('sukkerbete',),
'sukkerbete': ('sukkerbete',),
'sukkerbeten': ('sukkerbete',),
'sukkerbetene': ('sukkerbete',),
'sukkerbeter': ('sukkerbete',),
'sukkerbit': ('sukkerbit',),
'sukkerbiten': ('sukkerbit',),
'sukkerbitene': ('sukkerbit',),
'sukkerbiter': ('sukkerbit',),
'sukkerbrød': ('sukkerbrød',),
'sukkerbrøda': ('sukkerbrød',),
'sukkerbrødene': ('sukkerbrød',),
'sukkerbrødet': ('sukkerbrød',),
'sukkerert': ('sukkerert',),
'sukkererta': ('sukkerert',),
'sukkererten': ('sukkerert',),
'sukkerertene': ('sukkerert',),
'sukkererter': ('sukkerert',),
'sukkerglasur': ('sukkerglasur',),
'sukkerglasuren': ('sukkerglasur',),
'sukkerglasurene': ('sukkerglasur',),
'sukkerglasurer': ('sukkerglasur',),
'sukkerkulør': ('sukkerkulør',),
'sukkerkuløren': ('sukkerkulør',),
'sukkerkulørene': ('sukkerkulør',),
'sukkerkulører': ('sukkerkulør',),
'sukkerlake': ('sukkerlake',),
'sukkerlaken': ('sukkerlake',),
'sukkerlakene': ('sukkerlake',),
'sukkerlaker': ('sukkerlake',),
'sukkermaur': ('sukkermaur',),
'sukkermauren': ('sukkermaur',),
'sukkermaurene': ('sukkermaur',),
'sukkerroe': ('sukkerroe',),
'sukkerroen': ('sukkerroe',),
'sukkerroene': ('sukkerroe',),
'sukkerroer': ('sukkerroe',),
'sukkerrør': ('sukkerrør',),
'sukkerrøra': ('sukkerrør',),
'sukkerrørene': ('sukkerrør',),
'sukkerrøret': ('sukkerrør',),
'sukkersjuka': ('sukkersjuke',),
'sukkersjuke': ('sukkersjuke',),
'sukkersjuken': ('sukkersjuke',),
'sukkersjukene': ('sukkersjuke',),
'sukkersjuker': ('sukkersjuke',),
'sukkerslag': ('sukkerslag',),
'sukkerslaga': ('sukkerslag',),
'sukkerslagene': ('sukkerslag',),
'sukkerslaget': ('sukkerslag',),
'sukkersyka': ('sukkersyke',),
'sukkersyke': ('sukkersyke',),
'sukkersyken': ('sukkersyke',),
'sukkersykene': ('sukkersyke',),
'sukkersyker': ('sukkersyke',),
'sukkertøy': ('sukkertøy',),
'sukkertøya': ('sukkertøy',),
'sukkertøyene': ('sukkertøy',),
'sukkertøyer': ('sukkertøy',),
'sukkertøyet': ('sukkertøy',),
'sukkerunge': ('sukkerunge',),
'sukkerungen': ('sukkerunge',),
'sukkerungene': ('sukkerunge',),
'sukkerunger': ('sukkerunge',),
'sukkervann': ('sukkervann',),
'sukkervanna': ('sukkervann',),
'sukkervannene': ('sukkervann',),
'sukkervannet': ('sukkervann',),
'sukkervatn': ('sukkervatn',),
'sukkervatna': ('sukkervatn',),
'sukkervatnene': ('sukkervatn',),
'sukkervatnet': ('sukkervatn',),
'sukl': ('sukl',),
'sukla': ('sukl',),
'suklene': ('sukl',),
'suklet': ('sukl',),
'suksesjon': ('suksesjon',),
'suksesjonen': ('suksesjon',),
'suksesjonene': ('suksesjon',),
'suksesjoner': ('suksesjon',),
'suksess': ('suksess',),
'suksessen': ('suksess',),
'suksessene': ('suksess',),
'suksesser': ('suksess',),
'sul': ('sul',),
'sula': ('sul',),
'sulene': ('sul',),
'sulet': ('sul',),
'sulamitt': ('sulamitt',),
'sulamitten': ('sulamitt',),
'sulamittene': ('sulamitt',),
'sulamitter': ('sulamitt',),
'sula': ('sule',),
'sule': ('sule',),
'sulen': ('sule',),
'sulene': ('sule',),
'suler': ('sule',),
'sula': ('sule',),
'sule': ('sule',),
'sulen': ('sule',),
'sulene': ('sule',),
'suler': ('sule',),
'sulfapreparat': ('sulfapreparat',),
'sulfapreparata': ('sulfapreparat',),
'sulfapreparatene': ('sulfapreparat',),
'sulfapreparater': ('sulfapreparat',),
'sulfapreparatet': ('sulfapreparat',),
'sulfat': ('sulfat',),
'sulfata': ('sulfat',),
'sulfatene': ('sulfat',),
'sulfater': ('sulfat',),
'sulfatet': ('sulfat',),
'sulfatcellulose': ('sulfatcellulose',),
'sulfatcellulosen': ('sulfatcellulose',),
'sulfatcellulosene': ('sulfatcellulose',),
'sulfatcelluloser': ('sulfatcellulose',),
'sulfid': ('sulfid',),
'sulfida': ('sulfid',),
'sulfidene': ('sulfid',),
'sulfider': ('sulfid',),
'sulfidet': ('sulfid',),
'sulfitt': ('sulfitt',),
'sulfitta': ('sulfitt',),
'sulfitten': ('sulfitt',),
'sulfittene': ('sulfitt',),
'sulfitter': ('sulfitt',),
'sulfittet': ('sulfitt',),
'sulfittcellulose': ('sulfittcellulose',),
'sulfittcellulosen': ('sulfittcellulose',),
'sulfittcellulosene': ('sulfittcellulose',),
'sulfittcelluloser': ('sulfittcellulose',),
'sulfittlut': ('sulfittlut',),
'sulfittluta': ('sulfittlut',),
'sulfittluten': ('sulfittlut',),
'sulfittlutene': ('sulfittlut',),
'sulfittluter': ('sulfittlut',),
'sulfittsprit': ('sulfittsprit',),
'sulfittspriten': ('sulfittsprit',),
'sulfittspritene': ('sulfittsprit',),
'sulfittspriter': ('sulfittsprit',),
'sulfonamid': ('sulfonamid',),
'sulfonamida': ('sulfonamid',),
'sulfonamidene': ('sulfonamid',),
'sulfonamider': ('sulfonamid',),
'sulfonamidet': ('sulfonamid',),
'sulky': ('sulky',),
'sulkyen': ('sulky',),
'sulkyene': ('sulky',),
'sulkyer': ('sulky',),
'sull': ('sull',),
'sullen': ('sull',),
'sullene': ('sull',),
'suller': ('sull',),
'sullik': ('sullik',),
'sulliken': ('sullik',),
'sullikene': ('sullik',),
'sulliker': ('sullik',),
'sult': ('sult',),
'sulten': ('sult',),
'sultene': ('sult',),
'sulter': ('sult',),
'sultan': ('sultan',),
'sultanen': ('sultan',),
'sultanene': ('sultan',),
'sultaner': ('sultan',),
'sultanat': ('sultanat',),
'sultanata': ('sultanat',),
'sultanatene': ('sultanat',),
'sultanater': ('sultanat',),
'sultanatet': ('sultanat',),
'sultandømma': ('sultandømme',),
'sultandømme': ('sultandømme',),
'sultandømmene': ('sultandømme',),
'sultandømmer': ('sultandømme',),
'sultandømmet': ('sultandømme',),
'sultegrensa': ('sultegrense',),
'sultegrense': ('sultegrense',),
'sultegrensen': ('sultegrense',),
'sultegrensene': ('sultegrense',),
'sultegrenser': ('sultegrense',),
'sultelønn': ('sultelønn',),
'sultelønna': ('sultelønn',),
'sultelønnen': ('sultelønn',),
'sultelønnene': ('sultelønn',),
'sultelønner': ('sultelønn',),
'sultestreik': ('sultestreik',),
'sultestreiken': ('sultestreik',),
'sultestreikene': ('sultestreik',),
'sultestreiker': ('sultestreik',),
'sum': ('sum',),
'summen': ('sum',),
'summene': ('sum',),
'summer': ('sum',),
'sum': ('sum',),
'summa': ('sum',),
'summene': ('sum',),
'summet': ('sum',),
'sumerer': ('sumerer',),
'sumerere': ('sumerer',),
'sumereren': ('sumerer',),
'sumererer': ('sumerer',),
'sumererne': ('sumerer',),
'summer': ('summer',),
'summere': ('summer',),
'summeren': ('summer',),
'summerer': ('summer',),
'summerne': ('summer',),
'summetone': ('summetone',),
'summetonen': ('summetone',),
'summetonene': ('summetone',),
'summetoner': ('summetone',),
'sump': ('sump',),
'sumpen': ('sump',),
'sumpene': ('sump',),
'sumper': ('sump',),
'sumpfeber': ('sumpfeber',),
'sumpfebere': ('sumpfeber',),
'sumpfeberen': ('sumpfeber',),
'sumpfeberer': ('sumpfeber',),
'sumpfeberne': ('sumpfeber',),
'sumpfebre': ('sumpfeber',),
'sumpfebrene': ('sumpfeber',),
'sumpfebrer': ('sumpfeber',),
'sumpgass': ('sumpgass',),
'sumpgassen': ('sumpgass',),
'sumpgassene': ('sumpgass',),
'sumpgasser': ('sumpgass',),
'sumpland': ('sumpland',),
'sumplanda': ('sumpland',),
'sumplandene': ('sumpland',),
'sumplandet': ('sumpland',),
'sumpplanta': ('sumpplante',),
'sumpplante': ('sumpplante',),
'sumpplanten': ('sumpplante',),
'sumpplantene': ('sumpplante',),
'sumpplanter': ('sumpplante',),
'sund': ('sund',),
'sunda': ('sund',),
'sundene': ('sund',),
'sundet': ('sund',),
'sundaneser': ('sundaneser',),
'sundanesere': ('sundaneser',),
'sundaneseren': ('sundaneser',),
'sundaneserer': ('sundaneser',),
'sundaneserne': ('sundaneser',),
'sundmage': ('sundmage',),
'sundmagen': ('sundmage',),
'sundmagene': ('sundmage',),
'sundmager': ('sundmage',),
'sundmann': ('sundmann',),
'sundmannen': ('sundmann',),
'sundmenn': ('sundmann',),
'sundmennene': ('sundmann',),
'sundmave': ('sundmave',),
'sundmaven': ('sundmave',),
'sundmavene': ('sundmave',),
'sundmaver': ('sundmave',),
'sundpengene': ('sundpenger',),
'sundpenger': ('sundpenger',),
'sunna': ('sunna',),
'sunnaen': ('sunna',),
'sunnaene': ('sunna',),
'sunnaer': ('sunna',),
'sunnfjording': ('sunnfjording',),
'sunnfjordingen': ('sunnfjording',),
'sunnfjordingene': ('sunnfjording',),
'sunnfjordinger': ('sunnfjording',),
'sunnhet': ('sunnhet',),
'sunnheta': ('sunnhet',),
'sunnheten': ('sunnhet',),
'sunnhetene': ('sunnhet',),
'sunnheter': ('sunnhet',),
'sunnhetsapostel': ('sunnhetsapostel',),
'sunnhetsapostelen': ('sunnhetsapostel',),
'sunnhetsapostlene': ('sunnhetsapostel',),
'sunnhetsapostler': ('sunnhetsapostel',),
'sunnhetstegn': ('sunnhetstegn',),
'sunnhetstegna': ('sunnhetstegn',),
'sunnhetstegnene': ('sunnhetstegn',),
'sunnhetstegnet': ('sunnhetstegn',),
'sunnhetstilstand': ('sunnhetstilstand',),
'sunnhetstilstanden': ('sunnhetstilstand',),
'sunnhetstilstandene': ('sunnhetstilstand',),
'sunnhetstilstander': ('sunnhetstilstand',),
'sunnimuslim': ('sunnimuslim',),
'sunnimuslimen': ('sunnimuslim',),
'sunnimuslimene': ('sunnimuslim',),
'sunnimuslimer': ('sunnimuslim',),
'sunnisme': ('sunnisme',),
'sunnismen': ('sunnisme',),
'sunnismene': ('sunnisme',),
'sunnismer': ('sunnisme',),
'sunnitt': ('sunnitt',),
'sunnitten': ('sunnitt',),
'sunnittene': ('sunnitt',),
'sunnitter': ('sunnitt',),
'sunnmøring': ('sunnmøring',),
'sunnmøringen': ('sunnmøring',),
'sunnmøringene': ('sunnmøring',),
'sunnmøringer': ('sunnmøring',),
'sup': ('sup',),
'supen': ('sup',),
'supene': ('sup',),
'super': ('sup',),
'supeen': ('supé',),
'supeene': ('supé',),
'supeer': ('supé',),
'supé': ('supé',),
'supéen': ('supé',),
'supéene': ('supé',),
'supéer': ('supé',),
'super': ('super',),
'supere': ('super',),
'superen': ('super',),
'superer': ('super',),
'superne': ('super',),
'super G': ('super G',),
'super Gen': ('super G',),
'super Gene': ('super G',),
'super Ger': ('super G',),
'superbensin': ('superbensin',),
'superbensinen': ('superbensin',),
'superbensinene': ('superbensin',),
'superbensiner': ('superbensin',),
'superellipse': ('superellipse',),
'superellipsen': ('superellipse',),
'superellipsene': ('superellipse',),
'superellipser': ('superellipse',),
'superfosfat': ('superfosfat',),
'superfosfata': ('superfosfat',),
'superfosfatene': ('superfosfat',),
'superfosfater': ('superfosfat',),
'superfosfatet': ('superfosfat',),
'superintendent': ('superintendent',),
'superintendenten': ('superintendent',),
'superintendentene': ('superintendent',),
'superintendenter': ('superintendent',),
'superior': ('superior',),
'superioren': ('superior',),
'superiorene': ('superior',),
'superiorer': ('superior',),
'superkargo': ('superkargo',),
'superkargoen': ('superkargo',),
'superkargoene': ('superkargo',),
'superkargoer': ('superkargo',),
'superlativ': ('superlativ',),
'superlativen': ('superlativ',),
'superlativene': ('superlativ',),
'superlativer': ('superlativ',),
'superlativ': ('superlativ',),
'superlativa': ('superlativ',),
'superlativene': ('superlativ',),
'superlativer': ('superlativ',),
'superlativet': ('superlativ',),
'superleder': ('superleder',),
'superledere': ('superleder',),
'superlederen': ('superleder',),
'superlederer': ('superleder',),
'superlederne': ('superleder',),
'superledning': ('superledning',),
'superledninga': ('superledning',),
'superledningen': ('superledning',),
'superledningene': ('superledning',),
'superledninger': ('superledning',),
'supermakt': ('supermakt',),
'supermakta': ('supermakt',),
'supermakten': ('supermakt',),
'supermaktene': ('supermakt',),
'supermakter': ('supermakt',),
'supermann': ('supermann',),
'supermannen': ('supermann',),
'supermenn': ('supermann',),
'supermennene': ('supermann',),
'supermarked': ('supermarked',),
'supermarkeda': ('supermarked',),
'supermarkedene': ('supermarked',),
'supermarkeder': ('supermarked',),
'supermarkedet': ('supermarked',),
'supermarknad': ('supermarknad',),
'supermarknaden': ('supermarknad',),
'supermarknadene': ('supermarknad',),
'supermarknader': ('supermarknad',),
'supernova': ('supernova',),
'supernovaen': ('supernova',),
'supernovaene': ('supernova',),
'supernovaer': ('supernova',),
'superoksid': ('superoksid',),
'superoksida': ('superoksid',),
'superoksidene': ('superoksid',),
'superoksider': ('superoksid',),
'superoksidet': ('superoksid',),
'supersoni': ('supersoni',),
'supersonien': ('supersoni',),
'supersoniene': ('supersoni',),
'supersonier': ('supersoni',),
'superstorslalåm': ('superstorslalåm',),
'superstorslalåmen': ('superstorslalåm',),
'superstorslalåmene': ('superstorslalåm',),
'superstorslalåmer': ('superstorslalåm',),
'supertanker': ('supertanker',),
'supertankere': ('supertanker',),
'supertankeren': ('supertanker',),
'supertankerer': ('supertanker',),
'supertankerne': ('supertanker',),
'supertungvekt': ('supertungvekt',),
'supertungvekta': ('supertungvekt',),
'supertungvekten': ('supertungvekt',),
'supertungvektene': ('supertungvekt',),
'supertungvekter': ('supertungvekt',),
'supertungvekter': ('supertungvekter',),
'supertungvektere': ('supertungvekter',),
'supertungvekteren': ('supertungvekter',),
'supertungvekterer': ('supertungvekter',),
'supertungvekterne': ('supertungvekter',),
'supertungvektklassa': ('supertungvektklasse',),
'supertungvektklasse': ('supertungvektklasse',),
'supertungvektklassen': ('supertungvektklasse',),
'supertungvektklassene': ('supertungvektklasse',),
'supertungvektklasser': ('supertungvektklasse',),
'supertungvektsklassa': ('supertungvektsklasse',),
'supertungvektsklasse': ('supertungvektsklasse',),
'supertungvektsklassen': ('supertungvektsklasse',),
'supertungvektsklassene': ('supertungvektsklasse',),
'supertungvektsklasser': ('supertungvektsklasse',),
'supervisor': ('supervisor',),
'supervisoren': ('supervisor',),
'supervisorene': ('supervisor',),
'supervisorer': ('supervisor',),
'supinasjon': ('supinasjon',),
'supinasjonen': ('supinasjon',),
'supinasjonene': ('supinasjon',),
'supinasjoner': ('supinasjon',),
'supina': ('supinum',),
'supinaene': ('supinum',),
'supinene': ('supinum',),
'supiner': ('supinum',),
'supinum': ('supinum',),
'supinumet': ('supinum',),
'suppa': ('suppe',),
'suppe': ('suppe',),
'suppen': ('suppe',),
'suppene': ('suppe',),
'supper': ('suppe',),
'suppeausa': ('suppeause',),
'suppeause': ('suppeause',),
'suppeausen': ('suppeause',),
'suppeausene': ('suppeause',),
'suppeauser': ('suppeause',),
'suppeblokk': ('suppeblokk',),
'suppeblokka': ('suppeblokk',),
'suppeblokken': ('suppeblokk',),
'suppeblokkene': ('suppeblokk',),
'suppeblokker': ('suppeblokk',),
'suppedas': ('suppedas',),
'suppedasen': ('suppedas',),
'suppedasene': ('suppedas',),
'suppedaser': ('suppedas',),
'suppekjøtt': ('suppekjøtt',),
'suppekjøtta': ('suppekjøtt',),
'suppekjøttene': ('suppekjøtt',),
'suppekjøttet': ('suppekjøtt',),
'suppepose': ('suppepose',),
'suppeposen': ('suppepose',),
'suppeposene': ('suppepose',),
'suppeposer': ('suppepose',),
'supperåd': ('supperåd',),
'supperåda': ('supperåd',),
'supperådene': ('supperåd',),
'supperådet': ('supperåd',),
'suppeøsa': ('suppeøse',),
'suppeøse': ('suppeøse',),
'suppeøsen': ('suppeøse',),
'suppeøsene': ('suppeøse',),
'suppeøser': ('suppeøse',),
'suppleant': ('suppleant',),
'suppleanten': ('suppleant',),
'suppleantene': ('suppleant',),
'suppleanter': ('suppleant',),
'supplement': ('supplement',),
'supplementa': ('supplement',),
'supplementene': ('supplement',),
'supplementer': ('supplement',),
'supplementet': ('supplement',),
'supplementsbind': ('supplementsbind',),
'supplementsbinda': ('supplementsbind',),
'supplementsbindene': ('supplementsbind',),
'supplementsbindet': ('supplementsbind',),
'supplementvinkel': ('supplementvinkel',),
'supplementvinkelen': ('supplementvinkel',),
'supplementvinklene': ('supplementvinkel',),
'supplementvinkler': ('supplementvinkel',),
'suppleringsvalg': ('suppleringsvalg',),
'suppleringsvalga': ('suppleringsvalg',),
'suppleringsvalgene': ('suppleringsvalg',),
'suppleringsvalget': ('suppleringsvalg',),
'supplikant': ('supplikant',),
'supplikanten': ('supplikant',),
'supplikantene': ('supplikant',),
'supplikanter': ('supplikant',),
'supplikk': ('supplikk',),
'supplikken': ('supplikk',),
'supplikkene': ('supplikk',),
'supplikker': ('supplikk',),
'supporter': ('supporter',),
'supportere': ('supporter',),
'supporteren': ('supporter',),
'supporterer': ('supporter',),
'supporterne': ('supporter',),
'supradental': ('supradental',),
'supradentalen': ('supradental',),
'supradentalene': ('supradental',),
'supradentaler': ('supradental',),
'supraleder': ('supraleder',),
'supraledere': ('supraleder',),
'supralederen': ('supraleder',),
'supralederer': ('supraleder',),
'supralederne': ('supraleder',),
'supraledning': ('supraledning',),
'supraledninga': ('supraledning',),
'supraledningen': ('supraledning',),
'supraledningene': ('supraledning',),
'supraledninger': ('supraledning',),
'supranaturalisme': ('supranaturalisme',),
'supranaturalismen': ('supranaturalisme',),
'supranaturalismene': ('supranaturalisme',),
'supranaturalismer': ('supranaturalisme',),
'supremati': ('supremati',),
'suprematia': ('supremati',),
'suprematiene': ('supremati',),
'suprematier': ('supremati',),
'suprematiet': ('supremati',),
'surbrød': ('surbrød',),
'surbrøda': ('surbrød',),
'surbrødene': ('surbrød',),
'surbrødet': ('surbrød',),
'surdeig': ('surdeig',),
'surdeigen': ('surdeig',),
'surdeigene': ('surdeig',),
'surdeiger': ('surdeig',),
'surfebrett': ('surfebrett',),
'surfebretta': ('surfebrett',),
'surfebrettene': ('surfebrett',),
'surfebretter': ('surfebrett',),
'surfebrettet': ('surfebrett',),
'surfer': ('surfer',),
'surfere': ('surfer',),
'surferen': ('surfer',),
'surferer': ('surfer',),
'surferne': ('surfer',),
'surfing': ('surfing',),
'surfinga': ('surfing',),
'surfingen': ('surfing',),
'surfingene': ('surfing',),
'surfinger': ('surfing',),
'surfingbrett': ('surfingbrett',),
'surfingbretta': ('surfingbrett',),
'surfingbrettene': ('surfingbrett',),
'surfingbretter': ('surfingbrett',),
'surfingbrettet': ('surfingbrett',),
'surfriding': ('surfriding',),
'surfridingen': ('surfriding',),
'surfridingene': ('surfriding',),
'surfridinger': ('surfriding',),
'surhet': ('surhet',),
'surheta': ('surhet',),
'surheten': ('surhet',),
'surhetene': ('surhet',),
'surheter': ('surhet',),
'surhetsgrad': ('surhetsgrad',),
'surhetsgraden': ('surhetsgrad',),
'surhetsgradene': ('surhetsgrad',),
'surhetsgrader': ('surhetsgrad',),
'surimi': ('surimi',),
'surimien': ('surimi',),
'surimiene': ('surimi',),
'surimier': ('surimi',),
'surinamer': ('surinamer',),
'surinameren': ('surinamer',),
'surinamerene': ('surinamer',),
'surinamerer': ('surinamer',),
'surkål': ('surkål',),
'surkålen': ('surkål',),
'surkålene': ('surkål',),
'surkåler': ('surkål',),
'surl': ('surl',),
'surla': ('surl',),
'surlene': ('surl',),
'surlet': ('surl',),
'surmelk': ('surmelk',),
'surmelka': ('surmelk',),
'surmelken': ('surmelk',),
'surmelkene': ('surmelk',),
'surmelker': ('surmelk',),
'surost': ('surost',),
'surosten': ('surost',),
'surostene': ('surost',),
'suroster': ('surost',),
'surprim': ('surprim',),
'surprima': ('surprim',),
'surprimen': ('surprim',),
'surprimene': ('surprim',),
'surprimer': ('surprim',),
'surprimet': ('surprim',),
'surr': ('surr',),
'surra': ('surr',),
'surren': ('surr',),
'surrene': ('surr',),
'surret': ('surr',),
'surrealisme': ('surrealisme',),
'surrealismen': ('surrealisme',),
'surrealismene': ('surrealisme',),
'surrealismer': ('surrealisme',),
'surrealist': ('surrealist',),
'surrealisten': ('surrealist',),
'surrealistene': ('surrealist',),
'surrealister': ('surrealist',),
'surring': ('surring',),
'surringa': ('surring',),
'surringen': ('surring',),
'surringene': ('surring',),
'surringer': ('surring',),
'surrogat': ('surrogat',),
'surrogata': ('surrogat',),
'surrogatene': ('surrogat',),
'surrogater': ('surrogat',),
'surrogatet': ('surrogat',),
'sursild': ('sursild',),
'sursilda': ('sursild',),
'sursilden': ('sursild',),
'sursildene': ('sursild',),
'sursilder': ('sursild',),
'surstoff': ('surstoff',),
'surstoffa': ('surstoff',),
'surstoffene': ('surstoff',),
'surstoffer': ('surstoff',),
'surstoffet': ('surstoff',),
'surveymetode': ('surveymetode',),
'surveymetoden': ('surveymetode',),
'surveymetodene': ('surveymetode',),
'surveymetoder': ('surveymetode',),
'surveyundersøkelse': ('surveyundersøkelse',),
'surveyundersøkelsen': ('surveyundersøkelse',),
'surveyundersøkelsene': ('surveyundersøkelse',),
'surveyundersøkelser': ('surveyundersøkelse',),
'sus': ('sus',),
'susa': ('sus',),
'susen': ('sus',),
'susene': ('sus',),
'suset': ('sus',),
'susafon': ('susafon',),
'susafonen': ('susafon',),
'susafonene': ('susafon',),
'susafoner': ('susafon',),
'susekopp': ('susekopp',),
'susekoppen': ('susekopp',),
'susekoppene': ('susekopp',),
'susekopper': ('susekopp',),
'suseladd': ('suseladd',),
'suseladden': ('suseladd',),
'suseladdene': ('suseladd',),
'suseladder': ('suseladd',),
'suser': ('suser',),
'susere': ('suser',),
'suseren': ('suser',),
'suserer': ('suser',),
'suserne': ('suser',),
'susl': ('susl',),
'susla': ('susl',),
'suslene': ('susl',),
'suslet': ('susl',),
'susnebba': ('susnebbe',),
'susnebbe': ('susnebbe',),
'susnebben': ('susnebbe',),
'susnebbene': ('susnebbe',),
'susnebber': ('susnebbe',),
'susp': ('susp',),
'suspen': ('susp',),
'suspene': ('susp',),
'susper': ('susp',),
'suspensjon': ('suspensjon',),
'suspensjonen': ('suspensjon',),
'suspensjonene': ('suspensjon',),
'suspensjoner': ('suspensjon',),
'suspensoria': ('suspensorium',),
'suspensoriene': ('suspensorium',),
'suspensorier': ('suspensorium',),
'suspensoriet': ('suspensorium',),
'suspensorium': ('suspensorium',),
'suss': ('suss',),
'sussa': ('suss',),
'sussen': ('suss',),
'sussene': ('suss',),
'susser': ('suss',),
'susset': ('suss',),
'sussebass': ('sussebass',),
'sussebassen': ('sussebass',),
'sussebassene': ('sussebass',),
'sussebasser': ('sussebass',),
'sut': ('sut',),
'suta': ('sut',),
'suten': ('sut',),
'sutene': ('sut',),
'suter': ('sut',),
'sutenør': ('sutenør',),
'sutenøren': ('sutenør',),
'sutenørene': ('sutenør',),
'sutenører': ('sutenør',),
'sutt': ('sutt',),
'sutten': ('sutt',),
'suttene': ('sutt',),
'sutter': ('sutt',),
'sutteklut': ('sutteklut',),
'suttekluten': ('sutteklut',),
'sutteklutene': ('sutteklut',),
'suttekluter': ('sutteklut',),
'sutra': ('sutter',),
'sutre': ('sutter',),
'sutrene': ('sutter',),
'sutrer': ('sutter',),
'sutret': ('sutter',),
'sutter': ('sutter',),
'sutteret': ('sutter',),
'sutur': ('sutur',),
'suturen': ('sutur',),
'suturene': ('sutur',),
'suturer': ('sutur',),
'suvenir': ('suvenir',),
'suveniren': ('suvenir',),
'suvenirene': ('suvenir',),
'suvenirer': ('suvenir',),
'suveren': ('suveren',),
'suverenen': ('suveren',),
'suverenene': ('suveren',),
'suverener': ('suveren',),
'suverenitet': ('suverenitet',),
'suvereniteten': ('suverenitet',),
'suverenitetene': ('suverenitet',),
'suvereniteter': ('suverenitet',),
'suvl': ('suvl',),
'suvla': ('suvl',),
'suvlene': ('suvl',),
'suvlet': ('suvl',),
'suzerenitet': ('suzerenitet',),
'suzereniteten': ('suzerenitet',),
'suzerenitetene': ('suzerenitet',),
'suzereniteter': ('suzerenitet',),
'sva': ('sva',),
'svaa': ('sva',),
'svaene': ('sva',),
'svaet': ('sva',),
'svaber': ('svaber',),
'svabere': ('svaber',),
'svaberen': ('svaber',),
'svaberer': ('svaber',),
'svaberne': ('svaber',),
'svaberg': ('svaberg',),
'svaberga': ('svaberg',),
'svabergene': ('svaberg',),
'svaberget': ('svaberg',),
'svada': ('svada',),
'svadaen': ('svada',),
'svadaene': ('svada',),
'svadaer': ('svada',),
'svakhet': ('svakhet',),
'svakheta': ('svakhet',),
'svakheten': ('svakhet',),
'svakhetene': ('svakhet',),
'svakheter': ('svakhet',),
'svakstrøm': ('svakstrøm',),
'svakstrømmen': ('svakstrøm',),
'svakstrømmene': ('svakstrøm',),
'svakstrømmer': ('svakstrøm',),
'svakstrømsingeniør': ('svakstrømsingeniør',),
'svakstrømsingeniøren': ('svakstrømsingeniør',),
'svakstrømsingeniørene': ('svakstrømsingeniør',),
'svakstrømsingeniører': ('svakstrømsingeniør',),
'sval': ('sval',),
'svala': ('sval',),
'svalen': ('sval',),
'svalene': ('sval',),
'svaler': ('sval',),
'svala': ('svale',),
'svale': ('svale',),
'svalen': ('svale',),
'svalene': ('svale',),
'svaler': ('svale',),
'svalereda': ('svalerede',),
'svalerede': ('svalerede',),
'svaleredene': ('svalerede',),
'svalereder': ('svalerede',),
'svaleredet': ('svalerede',),
'svalereir': ('svalereir',),
'svalereira': ('svalereir',),
'svalereirene': ('svalereir',),
'svalereiret': ('svalereir',),
'svalestup': ('svalestup',),
'svalestupa': ('svalestup',),
'svalestupene': ('svalestup',),
'svalestupet': ('svalestup',),
'svaleurt': ('svaleurt',),
'svaleurta': ('svaleurt',),
'svaleurten': ('svaleurt',),
'svaleurtene': ('svaleurt',),
'svaleurter': ('svaleurt',),
'svalgang': ('svalgang',),
'svalgangen': ('svalgang',),
'svalgangene': ('svalgang',),
'svalganger': ('svalgang',),
'svamp': ('svamp',),
'svampen': ('svamp',),
'svampene': ('svamp',),
'svamper': ('svamp',),
'svana': ('svane',),
'svane': ('svane',),
'svanen': ('svane',),
'svanene': ('svane',),
'svaner': ('svane',),
'svanehals': ('svanehals',),
'svanehalsen': ('svanehals',),
'svanehalsene': ('svanehals',),
'svanehalser': ('svanehals',),
'svanesang': ('svanesang',),
'svanesangen': ('svanesang',),
'svanesangene': ('svanesang',),
'svanesanger': ('svanesang',),
'svang': ('svang',),
'svange': ('svange',),
'svangen': ('svange',),
'svangene': ('svange',),
'svanger': ('svange',),
'svangerskap': ('svangerskap',),
'svangerskapa': ('svangerskap',),
'svangerskapene': ('svangerskap',),
'svangerskapet': ('svangerskap',),
'svangerskapsavbrott': ('svangerskapsavbrott',),
'svangerskapsavbrotta': ('svangerskapsavbrott',),
'svangerskapsavbrottene': ('svangerskapsavbrott',),
'svangerskapsavbrottet': ('svangerskapsavbrott',),
'svangerskapsavbrudd': ('svangerskapsavbrudd',),
'svangerskapsavbrudda': ('svangerskapsavbrudd',),
'svangerskapsavbruddene': ('svangerskapsavbrudd',),
'svangerskapsavbruddet': ('svangerskapsavbrudd',),
'svangerskapspermisjon': ('svangerskapspermisjon',),
'svangerskapspermisjonen': ('svangerskapspermisjon',),
'svangerskapspermisjonene': ('svangerskapspermisjon',),
'svangerskapspermisjoner': ('svangerskapspermisjon',),
'svans': ('svans',),
'svansen': ('svans',),
'svansene': ('svans',),
'svanser': ('svans',),
'svar': ('svar',),
'svara': ('svar',),
'svarene': ('svar',),
'svaret': ('svar',),
'svarabhaktivokal': ('svarabhaktivokal',),
'svarabhaktivokalen': ('svarabhaktivokal',),
'svarabhaktivokalene': ('svarabhaktivokal',),
'svarabhaktivokaler': ('svarabhaktivokal',),
'svarbrev': ('svarbrev',),
'svarbreva': ('svarbrev',),
'svarbrevene': ('svarbrev',),
'svarbrever': ('svarbrev',),
'svarbrevet': ('svarbrev',),
'svarer': ('svarer',),
'svarere': ('svarer',),
'svareren': ('svarer',),
'svarerer': ('svarer',),
'svarerne': ('svarer',),
'svarfrist': ('svarfrist',),
'svarfristen': ('svarfrist',),
'svarfristene': ('svarfrist',),
'svarfrister': ('svarfrist',),
'svarord': ('svarord',),
'svarorda': ('svarord',),
'svarordene': ('svarord',),
'svarordet': ('svarord',),
'svarporto': ('svarporto',),
'svarportoen': ('svarporto',),
'svarportoene': ('svarporto',),
'svarportoer': ('svarporto',),
'svart': ('svart',),
'svart-hvitt-bilda': ('svart-hvitt-bilde',),
'svart-hvitt-bilde': ('svart-hvitt-bilde',),
'svart-hvitt-bildene': ('svart-hvitt-bilde',),
'svart-hvitt-bilder': ('svart-hvitt-bilde',),
'svart-hvitt-bildet': ('svart-hvitt-bilde',),
'svart-hvitt-tenkning': ('svart-hvitt-tenkning',),
'svart-hvitt-tenkninga': ('svart-hvitt-tenkning',),
'svart-hvitt-tenkningen': ('svart-hvitt-tenkning',),
'svart-hvitt-tenkningene': ('svart-hvitt-tenkning',),
'svart-hvitt-tenkninger': ('svart-hvitt-tenkning',),
'svart-kvitt': ('svart-kvitt',),
'svart-kvitt-bilda': ('svart-kvitt-bilde',),
'svart-kvitt-bilde': ('svart-kvitt-bilde',),
'svart-kvitt-bildene': ('svart-kvitt-bilde',),
'svart-kvitt-bilder': ('svart-kvitt-bilde',),
'svart-kvitt-bildet': ('svart-kvitt-bilde',),
'svart-kvitt-tenkning': ('svart-kvitt-tenkning',),
'svart-kvitt-tenkninga': ('svart-kvitt-tenkning',),
'svart-kvitt-tenkningen': ('svart-kvitt-tenkning',),
'svart-kvitt-tenkningene': ('svart-kvitt-tenkning',),
'svart-kvitt-tenkninger': ('svart-kvitt-tenkning',),
'svarta': ('svarta',),
'svartand': ('svartand',),
'svartanda': ('svartand',),
'svartanden': ('svartand',),
'svartendene': ('svartand',),
'svartender': ('svartand',),
'svartbak': ('svartbak',),
'svartbaken': ('svartbak',),
'svartbakene': ('svartbak',),
'svartbaker': ('svartbak',),
'svartebok': ('svartebok',),
'svarteboka': ('svartebok',),
'svarteboken': ('svartebok',),
'svartebøkene': ('svartebok',),
'svartebøker': ('svartebok',),
'svartebørs': ('svartebørs',),
'svartebørsen': ('svartebørs',),
'svartebørsene': ('svartebørs',),
'svartebørser': ('svartebørs',),
'svartedauden': ('svartedauden',),
'svartekunst': ('svartekunst',),
'svartekunsten': ('svartekunst',),
'svartekunstene': ('svartekunst',),
'svartekunster': ('svartekunst',),
'svartelista': ('svarteliste',),
'svarteliste': ('svarteliste',),
'svartelisten': ('svarteliste',),
'svartelistene': ('svarteliste',),
'svartelister': ('svarteliste',),
'svartemannen': ('svartemannen',),
'svartemarja': ('svartemarje',),
'svartemarje': ('svartemarje',),
'svartemarjen': ('svartemarje',),
'svartemarjene': ('svartemarje',),
'svartemarjer': ('svartemarje',),
'svarten': ('svarten',),
'svarteper': ('svarteper',),
'svarteperen': ('svarteper',),
'svarteperene': ('svarteper',),
'svarteperer': ('svarteper',),
'svarthyll': ('svarthyll',),
'svarthyllen': ('svarthyll',),
'svarthyllene': ('svarthyll',),
'svarthyller': ('svarthyll',),
'svarting': ('svarting',),
'svartingen': ('svarting',),
'svartingene': ('svarting',),
'svartinger': ('svarting',),
'svartjord': ('svartjord',),
'svartjorda': ('svartjord',),
'svartjorden': ('svartjord',),
'svartjordene': ('svartjord',),
'svartjorder': ('svartjord',),
'svartkatt': ('svartkatt',),
'svartkatten': ('svartkatt',),
'svartkattene': ('svartkatt',),
'svartkatter': ('svartkatt',),
'svartkopp': ('svartkopp',),
'svartkoppen': ('svartkopp',),
'svartkoppene': ('svartkopp',),
'svartkopper': ('svartkopp',),
'svartkvist': ('svartkvist',),
'svartkvisten': ('svartkvist',),
'svartkvistene': ('svartkvist',),
'svartkvister': ('svartkvist',),
'svartolder': ('svartolder',),
'svartoldere': ('svartolder',),
'svartolderen': ('svartolder',),
'svartolderne': ('svartolder',),
'svartoldra': ('svartolder',),
'svartoldre': ('svartolder',),
'svartoldrene': ('svartolder',),
'svartoldrer': ('svartolder',),
'svartor': ('svartor',),
'svartora': ('svartor',),
'svartoren': ('svartor',),
'svartorene': ('svartor',),
'svartorer': ('svartor',),
'svartrot': ('svartrot',),
'svartrota': ('svartrot',),
'svartroten': ('svartrot',),
'svartrøttene': ('svartrot',),
'svartrøtter': ('svartrot',),
'svartsinn': ('svartsinn',),
'svartsinna': ('svartsinn',),
'svartsinnene': ('svartsinn',),
'svartsinnet': ('svartsinn',),
'svartsjuka': ('svartsjuke',),
'svartsjuke': ('svartsjuke',),
'svartsjuken': ('svartsjuke',),
'svartsjukene': ('svartsjuke',),
'svartsjuker': ('svartsjuke',),
'svartskjorta': ('svartskjorte',),
'svartskjorte': ('svartskjorte',),
'svartskjorten': ('svartskjorte',),
'svartskjortene': ('svartskjorte',),
'svartskjorter': ('svartskjorte',),
'svartsladd': ('svartsladd',),
'svartsladden': ('svartsladd',),
'svartsladdene': ('svartsladd',),
'svartsladder': ('svartsladd',),
'svartspett': ('svartspett',),
'svartspetten': ('svartspett',),
'svartspettene': ('svartspett',),
'svartspetter': ('svartspett',),
'svartspetta': ('svartspette',),
'svartspette': ('svartspette',),
'svartspetten': ('svartspette',),
'svartspettene': ('svartspette',),
'svartspetter': ('svartspette',),
'svartsyn': ('svartsyn',),
'svartsyna': ('svartsyn',),
'svartsynene': ('svartsyn',),
'svartsynet': ('svartsyn',),
'svarttrast': ('svarttrast',),
'svarttrasten': ('svarttrast',),
'svarttrastene': ('svarttrast',),
'svarttraster': ('svarttrast',),
'svarttrost': ('svarttrost',),
'svarttrosten': ('svarttrost',),
'svarttrostene': ('svarttrost',),
'svarttroster': ('svarttrost',),
'svartår': ('svartår',),
'svartåra': ('svartår',),
'svartårene': ('svartår',),
'svartåret': ('svartår',),
'svarv': ('svarv',),
'svarven': ('svarv',),
'svarvene': ('svarv',),
'svarver': ('svarv',),
'svarver': ('svarver',),
'svarvere': ('svarver',),
'svarveren': ('svarver',),
'svarverer': ('svarver',),
'svarverne': ('svarver',),
'svastika': ('svastika',),
'svastikaen': ('svastika',),
'svastikaene': ('svastika',),
'svastikaer': ('svastika',),
'sve': ('sve',),
'svea': ('sve',),
'sveen': ('sve',),
'sveene': ('sve',),
'sveer': ('sve',),
'svear': ('svear',),
'svearne': ('svear',),
'svebruk': ('svebruk',),
'svebruka': ('svebruk',),
'svebrukene': ('svebruk',),
'svebruket': ('svebruk',),
'sved': ('sved',),
'svei': ('svei',),
'sveien': ('svei',),
'sveiene': ('svei',),
'sveier': ('svei',),
'sveig': ('sveig',),
'sveigen': ('sveig',),
'sveigene': ('sveig',),
'sveiger': ('sveig',),
'svein': ('svein',),
'sveinen': ('svein',),
'sveinene': ('svein',),
'sveiner': ('svein',),
'sveip': ('sveip',),
'sveipen': ('sveip',),
'sveipene': ('sveip',),
'sveiper': ('sveip',),
'sveip': ('sveip',),
'sveipa': ('sveip',),
'sveipene': ('sveip',),
'sveipet': ('sveip',),
'sveiper': ('sveiper',),
'sveipere': ('sveiper',),
'sveiperen': ('sveiper',),
'sveiperer': ('sveiper',),
'sveiperne': ('sveiper',),
'sveiseapparat': ('sveiseapparat',),
'sveiseapparata': ('sveiseapparat',),
'sveiseapparatene': ('sveiseapparat',),
'sveiseapparater': ('sveiseapparat',),
'sveiseapparatet': ('sveiseapparat',),
'sveiseflamme': ('sveiseflamme',),
'sveiseflammen': ('sveiseflamme',),
'sveiseflammene': ('sveiseflamme',),
'sveiseflammer': ('sveiseflamme',),
'sveisejern': ('sveisejern',),
'sveisejerna': ('sveisejern',),
'sveisejernene': ('sveisejern',),
'sveisejernet': ('sveisejern',),
'sveiser': ('sveiser',),
'sveisere': ('sveiser',),
'sveiseren': ('sveiser',),
'sveiserer': ('sveiser',),
'sveiserne': ('sveiser',),
'sveiser': ('sveiser',),
'sveisere': ('sveiser',),
'sveiseren': ('sveiser',),
'sveiserer': ('sveiser',),
'sveiserne': ('sveiser',),
'sveisjern': ('sveisjern',),
'sveisjerna': ('sveisjern',),
'sveisjernene': ('sveisjern',),
'sveisjernet': ('sveisjern',),
'sveit': ('sveit',),
'sveita': ('sveit',),
'sveiten': ('sveit',),
'sveitene': ('sveit',),
'sveiter': ('sveit',),
'sveitser': ('sveitser',),
'sveitsere': ('sveitser',),
'sveitseren': ('sveitser',),
'sveitserer': ('sveitser',),
'sveitserne': ('sveitser',),
'sveitserfranc': ('sveitserfranc',),
'sveitserfrancen': ('sveitserfranc',),
'sveitserfrancene': ('sveitserfranc',),
'sveitsergarde': ('sveitsergarde',),
'sveitsergarden': ('sveitsergarde',),
'sveitsergardene': ('sveitsergarde',),
'sveitsergarder': ('sveitsergarde',),
'sveitserost': ('sveitserost',),
'sveitserosten': ('sveitserost',),
'sveitserostene': ('sveitserost',),
'sveitseroster': ('sveitserost',),
'sveitserstil': ('sveitserstil',),
'sveitserstilen': ('sveitserstil',),
'sveitserstilene': ('sveitserstil',),
'sveitserstiler': ('sveitserstil',),
'sveitserur': ('sveitserur',),
'sveitserura': ('sveitserur',),
'sveitserurene': ('sveitserur',),
'sveitseruret': ('sveitserur',),
'sveiv': ('sveiv',),
'sveiven': ('sveiv',),
'sveivene': ('sveiv',),
'sveiver': ('sveiv',),
'sveiv': ('sveiv',),
'sveiva': ('sveiv',),
'sveiven': ('sveiv',),
'sveivene': ('sveiv',),
'sveiver': ('sveiv',),
'svekk': ('svekk',),
'svekken': ('svekk',),
'svekkene': ('svekk',),
'svekker': ('svekk',),
'svekkelse': ('svekkelse',),
'svekkelsen': ('svekkelse',),
'svekkelsene': ('svekkelse',),
'svekkelser': ('svekkelse',),
'svekling': ('svekling',),
'sveklingen': ('svekling',),
'sveklingene': ('svekling',),
'sveklinger': ('svekling',),
'svele': ('svele',),
'svelen': ('svele',),
'svelene': ('svele',),
'sveler': ('svele',),
'svelg': ('svelg',),
'svelgen': ('svelg',),
'svelgene': ('svelg',),
'svelger': ('svelg',),
'svelg': ('svelg',),
'svelga': ('svelg',),
'svelgene': ('svelg',),
'svelget': ('svelg',),
'svelging': ('svelging',),
'svelginga': ('svelging',),
'svelgingen': ('svelging',),
'svelgingene': ('svelging',),
'svelginger': ('svelging',),
'svell': ('svell',),
'svella': ('svell',),
'svellene': ('svell',),
'svellet': ('svell',),
'svelta': ('svelte',),
'svelte': ('svelte',),
'svelten': ('svelte',),
'sveltene': ('svelte',),
'svelter': ('svelte',),
'sveltihel': ('sveltihel',),
'sveltihjel': ('sveltihjel',),
'svenn': ('svenn',),
'svennen': ('svenn',),
'svennene': ('svenn',),
'svenner': ('svenn',),
'svennebrev': ('svennebrev',),
'svennebreva': ('svennebrev',),
'svennebrevene': ('svennebrev',),
'svennebrever': ('svennebrev',),
'svennebrevet': ('svennebrev',),
'svenneprøva': ('svenneprøve',),
'svenneprøve': ('svenneprøve',),
'svenneprøven': ('svenneprøve',),
'svenneprøvene': ('svenneprøve',),
'svenneprøver': ('svenneprøve',),
'svennestykka': ('svennestykke',),
'svennestykke': ('svennestykke',),
'svennestykkene': ('svennestykke',),
'svennestykker': ('svennestykke',),
'svennestykket': ('svennestykke',),
'svensk': ('svensk',),
'svensken': ('svensk',),
'svenskene': ('svensk',),
'svensker': ('svensk',),
'svenske': ('svenske',),
'svensken': ('svenske',),
'svenskene': ('svenske',),
'svensker': ('svenske',),
'svensketelt': ('svensketelt',),
'svensketelta': ('svensketelt',),
'svensketeltene': ('svensketelt',),
'svensketelter': ('svensketelt',),
'svensketeltet': ('svensketelt',),
'svepa': ('svepe',),
'svepe': ('svepe',),
'svepen': ('svepe',),
'svepene': ('svepe',),
'sveper': ('svepe',),
'svepesnert': ('svepesnert',),
'svepesnerten': ('svepesnert',),
'svepesnertene': ('svepesnert',),
'svepesnerter': ('svepesnert',),
'sverd': ('sverd',),
'sverda': ('sverd',),
'sverdene': ('sverd',),
'sverdet': ('sverd',),
'sverddans': ('sverddans',),
'sverddansen': ('sverddans',),
'sverddansene': ('sverddans',),
'sverddanser': ('sverddans',),
'sverdfisk': ('sverdfisk',),
'sverdfisken': ('sverdfisk',),
'sverdfiskene': ('sverdfisk',),
'sverdfisker': ('sverdfisk',),
'sverdlilja': ('sverdlilje',),
'sverdlilje': ('sverdlilje',),
'sverdliljen': ('sverdlilje',),
'sverdliljene': ('sverdlilje',),
'sverdliljer': ('sverdlilje',),
'sverdsida': ('sverdside',),
'sverdside': ('sverdside',),
'sverdsiden': ('sverdside',),
'sverdsidene': ('sverdside',),
'sverdsider': ('sverdside',),
'sverdslag': ('sverdslag',),
'sverdslaga': ('sverdslag',),
'sverdslagene': ('sverdslag',),
'sverdslaget': ('sverdslag',),
'sverdsluker': ('sverdsluker',),
'sverdslukere': ('sverdsluker',),
'sverdslukeren': ('sverdsluker',),
'sverdslukerer': ('sverdsluker',),
'sverdslukerne': ('sverdsluker',),
'sverm': ('sverm',),
'svermen': ('sverm',),
'svermene': ('sverm',),
'svermer': ('sverm',),
'svermer': ('svermer',),
'svermere': ('svermer',),
'svermeren': ('svermer',),
'svermerer': ('svermer',),
'svermerne': ('svermer',),
'svermeri': ('svermeri',),
'svermeria': ('svermeri',),
'svermeriene': ('svermeri',),
'svermerier': ('svermeri',),
'svermeriet': ('svermeri',),
'svesisme': ('svesisme',),
'svesismen': ('svesisme',),
'svesismene': ('svesisme',),
'svesismer': ('svesisme',),
'svette': ('svette',),
'svetten': ('svette',),
'svettene': ('svette',),
'svetter': ('svette',),
'svettedråpe': ('svettedråpe',),
'svettedråpen': ('svettedråpe',),
'svettedråpene': ('svettedråpe',),
'svettedråper': ('svettedråpe',),
'svettekjertel': ('svettekjertel',),
'svettekjertelen': ('svettekjertel',),
'svettekjertlene': ('svettekjertel',),
'svettekjertler': ('svettekjertel',),
'svettelukt': ('svettelukt',),
'svettelukta': ('svettelukt',),
'svettelukten': ('svettelukt',),
'svetteluktene': ('svettelukt',),
'svettelukter': ('svettelukt',),
'svettereim': ('svettereim',),
'svettereima': ('svettereim',),
'svettereimen': ('svettereim',),
'svettereimene': ('svettereim',),
'svettereimer': ('svettereim',),
'svev': ('svev',),
'sveva': ('svev',),
'svevene': ('svev',),
'svevet': ('svev',),
'svevebane': ('svevebane',),
'svevebanen': ('svevebane',),
'svevebanene': ('svevebane',),
'svevebaner': ('svevebane',),
'svevebåt': ('svevebåt',),
'svevebåten': ('svevebåt',),
'svevebåtene': ('svevebåt',),
'svevebåter': ('svevebåt',),
'svevkurve': ('svevkurve',),
'svevkurven': ('svevkurve',),
'svevkurvene': ('svevkurve',),
'svevkurver': ('svevkurve',),
'svibel': ('svibel',),
'svibelen': ('svibel',),
'sviblene': ('svibel',),
'svibler': ('svibel',),
'svibelløk': ('svibelløk',),
'svibelløken': ('svibelløk',),
'svibelløkene': ('svibelløk',),
'svibelløker': ('svibelløk',),
'svibrent': ('svibrent',),
'svibruk': ('svibruk',),
'svibruka': ('svibruk',),
'svibrukene': ('svibruk',),
'svibruket': ('svibruk',),
'svie': ('svie',),
'svien': ('svie',),
'sviene': ('svie',),
'svier': ('svie',),
'svigerdatter': ('svigerdatter',),
'svigerdattera': ('svigerdatter',),
'svigerdatteren': ('svigerdatter',),
'svigerdøtre': ('svigerdatter',),
'svigerdøtrene': ('svigerdatter',),
'svigerdøtrer': ('svigerdatter',),
'svigerinna': ('svigerinne',),
'svigerinne': ('svigerinne',),
'svigerinnen': ('svigerinne',),
'svigerinnene': ('svigerinne',),
'svigerinner': ('svigerinne',),
'svigermor': ('svigermor',),
'svigermora': ('svigermor',),
'svigermoren': ('svigermor',),
'svigermødre': ('svigermor',),
'svigermødrene': ('svigermor',),
'svigermødrer': ('svigermor',),
'svigermorseta': ('svigermorsete',),
'svigermorsete': ('svigermorsete',),
'svigermorsetene': ('svigermorsete',),
'svigermorseter': ('svigermorsete',),
'svigermorsetet': ('svigermorsete',),
'svigersønn': ('svigersønn',),
'svigersønnen': ('svigersønn',),
'svigersønnene': ('svigersønn',),
'svigersønner': ('svigersønn',),
'svijern': ('svijern',),
'svijerna': ('svijern',),
'svijernene': ('svijern',),
'svijernet': ('svijern',),
'svik': ('svik',),
'svika': ('svik',),
'svikene': ('svik',),
'sviket': ('svik',),
'sviker': ('sviker',),
'svikere': ('sviker',),
'svikeren': ('sviker',),
'svikerer': ('sviker',),
'svikerne': ('sviker',),
'svikferd': ('svikferd',),
'svikferda': ('svikferd',),
'svikferden': ('svikferd',),
'svikferdene': ('svikferd',),
'svikferder': ('svikferd',),
'sviknott': ('sviknott',),
'sviknotten': ('sviknott',),
'sviknottene': ('sviknott',),
'svikråd': ('svikråd',),
'svikråda': ('svikråd',),
'svikrådene': ('svikråd',),
'svikrådet': ('svikråd',),
'svikt': ('svikt',),
'svikten': ('svikt',),
'sviktene': ('svikt',),
'svikter': ('svikt',),
'sviktbrett': ('sviktbrett',),
'sviktbretta': ('sviktbrett',),
'sviktbrettene': ('sviktbrett',),
'sviktbretter': ('sviktbrett',),
'sviktbrettet': ('sviktbrett',),
'sviktstup': ('sviktstup',),
'sviktstupa': ('sviktstup',),
'sviktstupene': ('sviktstup',),
'sviktstupet': ('sviktstup',),
'sviktvaffel': ('sviktvaffel',),
'sviktvaffelen': ('sviktvaffel',),
'sviktvaflene': ('sviktvaffel',),
'sviktvafler': ('sviktvaffel',),
'svill': ('svill',),
'svilla': ('svill',),
'svillen': ('svill',),
'svillene': ('svill',),
'sviller': ('svill',),
'svilla': ('sville',),
'sville': ('sville',),
'svillen': ('sville',),
'svillene': ('sville',),
'sviller': ('sville',),
'svime': ('svime',),
'svimen': ('svime',),
'svimene': ('svime',),
'svimer': ('svime',),
'svimerka': ('svimerke',),
'svimerke': ('svimerke',),
'svimerkene': ('svimerke',),
'svimerker': ('svimerke',),
'svimerket': ('svimerke',),
'svimling': ('svimling',),
'svimlingen': ('svimling',),
'svimlingene': ('svimling',),
'svimlinger': ('svimling',),
'svin': ('svin',),
'svina': ('svin',),
'svinene': ('svin',),
'svinet': ('svin',),
'svindel': ('svindel',),
'svindelen': ('svindel',),
'svindlene': ('svindel',),
'svindler': ('svindel',),
'svindelaffære': ('svindelaffære',),
'svindelaffæren': ('svindelaffære',),
'svindelaffærene': ('svindelaffære',),
'svindelaffærer': ('svindelaffære',),
'svindler': ('svindler',),
'svindlere': ('svindler',),
'svindleren': ('svindler',),
'svindlerer': ('svindler',),
'svindlerne': ('svindler',),
'svindleri': ('svindleri',),
'svindleria': ('svindleri',),
'svindleriene': ('svindleri',),
'svindlerier': ('svindleri',),
'svindleriet': ('svindleri',),
'svineal': ('svineal',),
'svinealen': ('svineal',),
'svinealene': ('svineal',),
'svinealer': ('svineal',),
'svinearbeid': ('svinearbeid',),
'svinearbeida': ('svinearbeid',),
'svinearbeidene': ('svinearbeid',),
'svinearbeider': ('svinearbeid',),
'svinearbeidet': ('svinearbeid',),
'svineavl': ('svineavl',),
'svineavlen': ('svineavl',),
'svineavlene': ('svineavl',),
'svineavler': ('svineavl',),
'svinebeist': ('svinebeist',),
'svinebeista': ('svinebeist',),
'svinebeistene': ('svinebeist',),
'svinebeistet': ('svinebeist',),
'svinebest': ('svinebest',),
'svinebesta': ('svinebest',),
'svinebestene': ('svinebest',),
'svinebestet': ('svinebest',),
'svineblom': ('svineblom',),
'svineblommen': ('svineblom',),
'svineblommene': ('svineblom',),
'svineblommer': ('svineblom',),
'svinefylking': ('svinefylking',),
'svinefylkinga': ('svinefylking',),
'svinefylkingen': ('svinefylking',),
'svinefylkingene': ('svinefylking',),
'svinefylkinger': ('svinefylking',),
'svinehell': ('svinehell',),
'svinehella': ('svinehell',),
'svinehellene': ('svinehell',),
'svinehellet': ('svinehell',),
'svinehund': ('svinehund',),
'svinehunden': ('svinehund',),
'svinehundene': ('svinehund',),
'svinehunder': ('svinehund',),
'svinekjøtt': ('svinekjøtt',),
'svinekjøtta': ('svinekjøtt',),
'svinekjøttene': ('svinekjøtt',),
'svinekjøttet': ('svinekjøtt',),
'svinelær': ('svinelær',),
'svinelæra': ('svinelær',),
'svinelærene': ('svinelær',),
'svinelæret': ('svinelær',),
'svinepakk': ('svinepakk',),
'svinepakka': ('svinepakk',),
'svinepakkene': ('svinepakk',),
'svinepakket': ('svinepakk',),
'svinepels': ('svinepels',),
'svinepelsen': ('svinepels',),
'svinepelsene': ('svinepels',),
'svinepelser': ('svinepels',),
'svinepest': ('svinepest',),
'svinepesta': ('svinepest',),
'svinepesten': ('svinepest',),
'svinepestene': ('svinepest',),
'svinepester': ('svinepest',),
'svineri': ('svineri',),
'svineria': ('svineri',),
'svineriene': ('svineri',),
'svinerier': ('svineri',),
'svineriet': ('svineri',),
'svinesteik': ('svinesteik',),
'svinesteika': ('svinesteik',),
'svinesteiken': ('svinesteik',),
'svinesteikene': ('svinesteik',),
'svinesteiker': ('svinesteik',),
'svinesti': ('svinesti',),
'svinestien': ('svinesti',),
'svinestiene': ('svinesti',),
'svinestier': ('svinesti',),
'sving': ('sving',),
'svingen': ('sving',),
'svingene': ('sving',),
'svinger': ('sving',),
'svingdør': ('svingdør',),
'svingdøra': ('svingdør',),
'svingdøren': ('svingdør',),
'svingdørene': ('svingdør',),
'svingdører': ('svingdør',),
'svingdørspasient': ('svingdørspasient',),
'svingdørspasienten': ('svingdørspasient',),
'svingdørspasientene': ('svingdørspasient',),
'svingdørspasienter': ('svingdørspasient',),
'svingel': ('svingel',),
'svingelen': ('svingel',),
'svinglene': ('svingel',),
'svingler': ('svingel',),
'svingetal': ('svingetal',),
'svingetala': ('svingetal',),
'svingetalene': ('svingetal',),
'svingetalet': ('svingetal',),
'svingetall': ('svingetall',),
'svingetalla': ('svingetall',),
'svingetallene': ('svingetall',),
'svingetallet': ('svingetall',),
'svingetid': ('svingetid',),
'svingetida': ('svingetid',),
'svingetiden': ('svingetid',),
'svingetidene': ('svingetid',),
'svingetider': ('svingetid',),
'svinghjul': ('svinghjul',),
'svinghjula': ('svinghjul',),
'svinghjulene': ('svinghjul',),
'svinghjulet': ('svinghjul',),
'svingning': ('svingning',),
'svingninga': ('svingning',),
'svingningen': ('svingning',),
'svingningene': ('svingning',),
'svingninger': ('svingning',),
'svingom': ('svingom',),
'svingomen': ('svingom',),
'svingomene': ('svingom',),
'svingomer': ('svingom',),
'svingstang': ('svingstang',),
'svingstanga': ('svingstang',),
'svingstangen': ('svingstang',),
'svingstengene': ('svingstang',),
'svingstenger': ('svingstang',),
'svingteknikk': ('svingteknikk',),
'svingteknikken': ('svingteknikk',),
'svingteknikkene': ('svingteknikk',),
'svingteknikker': ('svingteknikk',),
'svinkeærend': ('svinkeærend',),
'svinkeærenda': ('svinkeærend',),
'svinkeærendene': ('svinkeærend',),
'svinkeærender': ('svinkeærend',),
'svinkeærendet': ('svinkeærend',),
'svinn': ('svinn',),
'svinna': ('svinn',),
'svinnene': ('svinn',),
'svinnet': ('svinn',),
'svinnprosent': ('svinnprosent',),
'svinnprosenten': ('svinnprosent',),
'svinnprosentene': ('svinnprosent',),
'svinnprosenter': ('svinnprosent',),
'svinnsott': ('svinnsott',),
'svinnsotta': ('svinnsott',),
'svinnsotten': ('svinnsott',),
'svinnsottene': ('svinnsott',),
'svinnsotter': ('svinnsott',),
'svint': ('svint',),
'svinten': ('svint',),
'svintene': ('svint',),
'svinter': ('svint',),
'svip': ('svip',),
'svipen': ('svip',),
'svipene': ('svip',),
'sviper': ('svip',),
'svipp': ('svipp',),
'svippen': ('svipp',),
'svippene': ('svipp',),
'svipper': ('svipp',),
'svipptur': ('svipptur',),
'svippturen': ('svipptur',),
'svippturene': ('svipptur',),
'svippturer': ('svipptur',),
'svipptursekk': ('svipptursekk',),
'svipptursekken': ('svipptursekk',),
'svipptursekkene': ('svipptursekk',),
'svipptursekker': ('svipptursekk',),
'svir': ('svir',),
'sviren': ('svir',),
'svirene': ('svir',),
'svirer': ('svir',),
'svirebror': ('svirebror',),
'svirebroren': ('svirebror',),
'svirebrødre': ('svirebror',),
'svirebrødrene': ('svirebror',),
'svirelag': ('svirelag',),
'svirelaga': ('svirelag',),
'svirelagene': ('svirelag',),
'svirelaget': ('svirelag',),
'svirydningsbruk': ('svirydningsbruk',),
'svirydningsbruka': ('svirydningsbruk',),
'svirydningsbrukene': ('svirydningsbruk',),
'svirydningsbruket': ('svirydningsbruk',),
'sviska': ('sviske',),
'sviske': ('sviske',),
'svisken': ('sviske',),
'sviskene': ('sviske',),
'svisker': ('sviske',),
'sviskegraut': ('sviskegraut',),
'sviskegrauten': ('sviskegraut',),
'sviskegrautene': ('sviskegraut',),
'sviskegrauter': ('sviskegraut',),
'sviskekompott': ('sviskekompott',),
'sviskekompotten': ('sviskekompott',),
'sviskekompottene': ('sviskekompott',),
'sviskekompotter': ('sviskekompott',),
'svoger': ('svoger',),
'svogere': ('svoger',),
'svogeren': ('svoger',),
'svogerer': ('svoger',),
'svogerne': ('svoger',),
'svolk': ('svolk',),
'svolken': ('svolk',),
'svolkene': ('svolk',),
'svolker': ('svolk',),
'svor': ('svor',),
'svoren': ('svor',),
'svorene': ('svor',),
'svorer': ('svor',),
'svovel': ('svovel',),
'svovela': ('svovel',),
'svovelen': ('svovel',),
'svovelene': ('svovel',),
'svoveler': ('svovel',),
'svovelet': ('svovel',),
'svovelblomme': ('svovelblomme',),
'svovelblommen': ('svovelblomme',),
'svovelblommene': ('svovelblomme',),
'svovelblommer': ('svovelblomme',),
'svoveldioksid': ('svoveldioksid',),
'svoveldioksida': ('svoveldioksid',),
'svoveldioksidene': ('svoveldioksid',),
'svoveldioksider': ('svoveldioksid',),
'svoveldioksidet': ('svoveldioksid',),
'svovelkis': ('svovelkis',),
'svovelkisen': ('svovelkis',),
'svovelkisene': ('svovelkis',),
'svovelkiser': ('svovelkis',),
'svovelpredikant': ('svovelpredikant',),
'svovelpredikanten': ('svovelpredikant',),
'svovelpredikantene': ('svovelpredikant',),
'svovelpredikanter': ('svovelpredikant',),
'svovelpøl': ('svovelpøl',),
'svovelpølen': ('svovelpøl',),
'svovelpølene': ('svovelpøl',),
'svovelpøler': ('svovelpøl',),
'svovelstikk': ('svovelstikk',),
'svovelstikka': ('svovelstikk',),
'svovelstikken': ('svovelstikk',),
'svovelstikkene': ('svovelstikk',),
'svovelstikker': ('svovelstikk',),
'svovelstikka': ('svovelstikke',),
'svovelstikke': ('svovelstikke',),
'svovelstikken': ('svovelstikke',),
'svovelstikkene': ('svovelstikke',),
'svovelstikker': ('svovelstikke',),
'svovelsyra': ('svovelsyre',),
'svovelsyre': ('svovelsyre',),
'svovelsyren': ('svovelsyre',),
'svovelsyrene': ('svovelsyre',),
'svovelsyrer': ('svovelsyre',),
'svovelsyrling': ('svovelsyrling',),
'svovelsyrlingen': ('svovelsyrling',),
'svovelsyrlingene': ('svovelsyrling',),
'svovelsyrlinger': ('svovelsyrling',),
'svull': ('svull',),
'svullen': ('svull',),
'svullene': ('svull',),
'svuller': ('svull',),
'svulst': ('svulst',),
'svulsten': ('svulst',),
'svulstene': ('svulst',),
'svulster': ('svulst',),
'svulstighet': ('svulstighet',),
'svulstigheta': ('svulstighet',),
'svulstigheten': ('svulstighet',),
'svulstighetene': ('svulstighet',),
'svulstigheter': ('svulstighet',),
'svupp': ('svupp',),
'svuppa': ('svupp',),
'svuppen': ('svupp',),
'svuppene': ('svupp',),
'svuppet': ('svupp',),
'sværing': ('sværing',),
'sværingen': ('sværing',),
'sværingene': ('sværing',),
'sværinger': ('sværing',),
'sværvekter': ('sværvekter',),
'sværvektere': ('sværvekter',),
'sværvekteren': ('sværvekter',),
'sværvekterer': ('sværvekter',),
'sværvekterne': ('sværvekter',),
'svæva': ('svæve',),
'svæve': ('svæve',),
'svæven': ('svæve',),
'svævene': ('svæve',),
'svæver': ('svæve',),
'svøm': ('svøm',),
'svømmebasseng': ('svømmebasseng',),
'svømmebassenga': ('svømmebasseng',),
'svømmebassengene': ('svømmebasseng',),
'svømmebassenger': ('svømmebasseng',),
'svømmebassenget': ('svømmebasseng',),
'svømmebelta': ('svømmebelte',),
'svømmebelte': ('svømmebelte',),
'svømmebeltene': ('svømmebelte',),
'svømmebelter': ('svømmebelte',),
'svømmebeltet': ('svømmebelte',),
'svømmeblæra': ('svømmeblære',),
'svømmeblære': ('svømmeblære',),
'svømmeblæren': ('svømmeblære',),
'svømmeblærene': ('svømmeblære',),
'svømmeblærer': ('svømmeblære',),
'svømmefugl': ('svømmefugl',),
'svømmefuglen': ('svømmefugl',),
'svømmefuglene': ('svømmefugl',),
'svømmefugler': ('svømmefugl',),
'svømmehall': ('svømmehall',),
'svømmehallen': ('svømmehall',),
'svømmehallene': ('svømmehall',),
'svømmehaller': ('svømmehall',),
'svømmehud': ('svømmehud',),
'svømmehuda': ('svømmehud',),
'svømmehuden': ('svømmehud',),
'svømmehudene': ('svømmehud',),
'svømmehuder': ('svømmehud',),
'svømmeknapp': ('svømmeknapp',),
'svømmeknappen': ('svømmeknapp',),
'svømmeknappene': ('svømmeknapp',),
'svømmeknapper': ('svømmeknapp',),
'svømmer': ('svømmer',),
'svømmere': ('svømmer',),
'svømmeren': ('svømmer',),
'svømmerer': ('svømmer',),
'svømmerne': ('svømmer',),
'svømmerska': ('svømmerske',),
'svømmerske': ('svømmerske',),
'svømmersken': ('svømmerske',),
'svømmerskene': ('svømmerske',),
'svømmersker': ('svømmerske',),
'svømmesnipa': ('svømmesnipe',),
'svømmesnipe': ('svømmesnipe',),
'svømmesnipen': ('svømmesnipe',),
'svømmesnipene': ('svømmesnipe',),
'svømmesniper': ('svømmesnipe',),
'svømmestadion': ('svømmestadion',),
'svømmestadiona': ('svømmestadion',),
'svømmestadionene': ('svømmestadion',),
'svømmestadioner': ('svømmestadion',),
'svømmestadionet': ('svømmestadion',),
'svømmetak': ('svømmetak',),
'svømmetaka': ('svømmetak',),
'svømmetakene': ('svømmetak',),
'svømmetaket': ('svømmetak',),
'svøp': ('svøp',),
'svøpa': ('svøp',),
'svøpene': ('svøp',),
'svøpet': ('svøp',),
'svøpe': ('svøpe',),
'svøpen': ('svøpe',),
'svøpene': ('svøpe',),
'svøper': ('svøpe',),
'swagger': ('swagger',),
'swaggere': ('swagger',),
'swaggeren': ('swagger',),
'swaggerer': ('swagger',),
'swaggerne': ('swagger',),
'swahili': ('swahili',),
'swahilien': ('swahili',),
'swahiliene': ('swahili',),
'swahilier': ('swahili',),
'swazi': ('swazi',),
'swazien': ('swazi',),
'swaziene': ('swazi',),
'swazier': ('swazi',),
'swazilender': ('swazilender',),
'swazilendere': ('swazilender',),
'swazilenderen': ('swazilender',),
'swazilenderer': ('swazilender',),
'swazilenderne': ('swazilender',),
'swazilending': ('swazilending',),
'swazilendingen': ('swazilending',),
'swazilendingene': ('swazilending',),
'swazilendinger': ('swazilending',),
'sweater': ('sweater',),
'sweatere': ('sweater',),
'sweateren': ('sweater',),
'sweaterer': ('sweater',),
'sweaterne': ('sweater',),
'sweeper': ('sweeper',),
'sweepere': ('sweeper',),
'sweeperen': ('sweeper',),
'sweeperer': ('sweeper',),
'sweeperne': ('sweeper',),
'swimmingpool': ('swimmingpool',),
'swimmingpoolen': ('swimmingpool',),
'swimmingpoolene': ('swimmingpool',),
'swimmingpooler': ('swimmingpool',),
'swing': ('swing',),
'swingen': ('swing',),
'swingene': ('swing',),
'swinger': ('swing',),
'swissroll': ('swissroll',),
'swissrollen': ('swissroll',),
'swissrollene': ('swissroll',),
'swissroller': ('swissroll',),
'sybaritt': ('sybaritt',),
'sybaritten': ('sybaritt',),
'sybarittene': ('sybaritt',),
'sybaritter': ('sybaritt',),
'syd': ('syd',),
'sydama': ('sydame',),
'sydame': ('sydame',),
'sydamen': ('sydame',),
'sydamene': ('sydame',),
'sydamer': ('sydame',),
'sydeuropeer': ('sydeuropeer',),
'sydeuropeere': ('sydeuropeer',),
'sydeuropeeren': ('sydeuropeer',),
'sydeuropeerer': ('sydeuropeer',),
'sydeuropeerne': ('sydeuropeer',),
'sydfrukt': ('sydfrukt',),
'sydfrukta': ('sydfrukt',),
'sydfrukten': ('sydfrukt',),
'sydfruktene': ('sydfrukt',),
'sydfrukter': ('sydfrukt',),
'sydhavsøy': ('sydhavsøy',),
'sydhavsøya': ('sydhavsøy',),
'sydhavsøyen': ('sydhavsøy',),
'sydhavsøyene': ('sydhavsøy',),
'sydhavsøyer': ('sydhavsøy',),
'sydhelling': ('sydhelling',),
'sydhellinga': ('sydhelling',),
'sydhellingen': ('sydhelling',),
'sydhellingene': ('sydhelling',),
'sydhellinger': ('sydhelling',),
'sydlending': ('sydlending',),
'sydlendingen': ('sydlending',),
'sydlendingene': ('sydlending',),
'sydlendinger': ('sydlending',),
'sydost': ('sydost',),
'sydosten': ('sydost',),
'sydostene': ('sydost',),
'sydoster': ('sydost',),
'sydost': ('sydost',),
'sydpol': ('sydpol',),
'sydpolen': ('sydpol',),
'sydpolene': ('sydpol',),
'sydpoler': ('sydpol',),
'sydpolsfarer': ('sydpolsfarer',),
'sydpolsfarere': ('sydpolsfarer',),
'sydpolsfareren': ('sydpolsfarer',),
'sydpolsfarerer': ('sydpolsfarer',),
'sydpolsfarerne': ('sydpolsfarer',),
'sydsame': ('sydsame',),
'sydsamen': ('sydsame',),
'sydsamene': ('sydsame',),
'sydsamer': ('sydsame',),
'sydsamisk': ('sydsamisk',),
'sydsamisken': ('sydsamisk',),
'sydsamiskene': ('sydsamisk',),
'sydsamisker': ('sydsamisk',),
'sydstat': ('sydstat',),
'sydstaten': ('sydstat',),
'sydstatene': ('sydstat',),
'sydstater': ('sydstat',),
'sydvegg': ('sydvegg',),
'sydveggen': ('sydvegg',),
'sydveggene': ('sydvegg',),
'sydvegger': ('sydvegg',),
'sydvest': ('sydvest',),
'sydvest': ('sydvest',),
'sydøst': ('sydøst',),
'sydøsten': ('sydøst',),
'sydøstene': ('sydøst',),
'sydøster': ('sydøst',),
'sydøst': ('sydøst',),
'syenitt': ('syenitt',),
'syenitten': ('syenitt',),
'syenittene': ('syenitt',),
'syenitter': ('syenitt',),
'syer': ('syer',),
'syere': ('syer',),
'syeren': ('syer',),
'syerer': ('syer',),
'syerne': ('syer',),
'syerska': ('syerske',),
'syerske': ('syerske',),
'syersken': ('syerske',),
'syerskene': ('syerske',),
'syersker': ('syerske',),
'syfilis': ('syfilis',),
'syfilisen': ('syfilis',),
'syfilisene': ('syfilis',),
'syfiliser': ('syfilis',),
'syfilitiker': ('syfilitiker',),
'syfilitikere': ('syfilitiker',),
'syfilitikeren': ('syfilitiker',),
'syfilitikerer': ('syfilitiker',),
'syfilitikerne': ('syfilitiker',),
'sykdom': ('sykdom',),
'sykdommen': ('sykdom',),
'sykdommene': ('sykdom',),
'sykdommer': ('sykdom',),
'sykdomsforfall': ('sykdomsforfall',),
'sykdomsforfalla': ('sykdomsforfall',),
'sykdomsforfallene': ('sykdomsforfall',),
'sykdomsforfallet': ('sykdomsforfall',),
'sykdomstilfella': ('sykdomstilfelle',),
'sykdomstilfelle': ('sykdomstilfelle',),
'sykdomstilfellene': ('sykdomstilfelle',),
'sykdomstilfeller': ('sykdomstilfelle',),
'sykdomstilfellet': ('sykdomstilfelle',),
'syka': ('syke',),
'syke': ('syke',),
'syken': ('syke',),
'sykene': ('syke',),
'syker': ('syke',),
'sykebesøk': ('sykebesøk',),
'sykebesøka': ('sykebesøk',),
'sykebesøkene': ('sykebesøk',),
'sykebesøket': ('sykebesøk',),
'sykebil': ('sykebil',),
'sykebilen': ('sykebil',),
'sykebilene': ('sykebil',),
'sykebiler': ('sykebil',),
'sykebåra': ('sykebåre',),
'sykebåre': ('sykebåre',),
'sykebåren': ('sykebåre',),
'sykebårene': ('sykebåre',),
'sykebårer': ('sykebåre',),
'sykegymnast': ('sykegymnast',),
'sykegymnasten': ('sykegymnast',),
'sykegymnastene': ('sykegymnast',),
'sykegymnaster': ('sykegymnast',),
'sykegymnastikk': ('sykegymnastikk',),
'sykegymnastikken': ('sykegymnastikk',),
'sykegymnastikkene': ('sykegymnastikk',),
'sykegymnastikker': ('sykegymnastikk',),
'sykeheim': ('sykeheim',),
'sykeheimen': ('sykeheim',),
'sykeheimene': ('sykeheim',),
'sykeheimer': ('sykeheim',),
'sykehjem': ('sykehjem',),
'sykehjemma': ('sykehjem',),
'sykehjemmene': ('sykehjem',),
'sykehjemmet': ('sykehjem',),
'sykehotell': ('sykehotell',),
'sykehotella': ('sykehotell',),
'sykehotellene': ('sykehotell',),
'sykehoteller': ('sykehotell',),
'sykehotellet': ('sykehotell',),
'sykehus': ('sykehus',),
'sykehusa': ('sykehus',),
'sykehusene': ('sykehus',),
'sykehuset': ('sykehus',),
'sykejournal': ('sykejournal',),
'sykejournalen': ('sykejournal',),
'sykejournalene': ('sykejournal',),
'sykejournaler': ('sykejournal',),
'sykekassa': ('sykekasse',),
'sykekasse': ('sykekasse',),
'sykekassen': ('sykekasse',),
'sykekassene': ('sykekasse',),
'sykekasser': ('sykekasse',),
'sykeleia': ('sykeleie',),
'sykeleie': ('sykeleie',),
'sykeleiene': ('sykeleie',),
'sykeleier': ('sykeleie',),
'sykeleiet': ('sykeleie',),
'sykelista': ('sykeliste',),
'sykeliste': ('sykeliste',),
'sykelisten': ('sykeliste',),
'sykelistene': ('sykeliste',),
'sykelister': ('sykeliste',),
'sykelønn': ('sykelønn',),
'sykelønna': ('sykelønn',),
'sykelønnen': ('sykelønn',),
'sykelønnene': ('sykelønn',),
'sykelønner': ('sykelønn',),
'sykemelding': ('sykemelding',),
'sykemeldinga': ('sykemelding',),
'sykemeldingen': ('sykemelding',),
'sykemeldingene': ('sykemelding',),
'sykemeldinger': ('sykemelding',),
'sykepasser': ('sykepasser',),
'sykepassere': ('sykepasser',),
'sykepasseren': ('sykepasser',),
'sykepasserer': ('sykepasser',),
'sykepasserne': ('sykepasser',),
'sykepengene': ('sykepenger',),
'sykepenger': ('sykepenger',),
'sykepleia': ('sykepleie',),
'sykepleie': ('sykepleie',),
'sykepleien': ('sykepleie',),
'sykepleiene': ('sykepleie',),
'sykepleier': ('sykepleie',),
'sykepleier': ('sykepleier',),
'sykepleiere': ('sykepleier',),
'sykepleieren': ('sykepleier',),
'sykepleierer': ('sykepleier',),
'sykepleierne': ('sykepleier',),
'sykepleierelev': ('sykepleierelev',),
'sykepleiereleven': ('sykepleierelev',),
'sykepleierelevene': ('sykepleierelev',),
'sykepleierelever': ('sykepleierelev',),
'sykepleierskole': ('sykepleierskole',),
'sykepleierskolen': ('sykepleierskole',),
'sykepleierskolene': ('sykepleierskole',),
'sykepleierskoler': ('sykepleierskole',),
'sykesal': ('sykesal',),
'sykesalen': ('sykesal',),
'sykesalene': ('sykesal',),
'sykesaler': ('sykesal',),
'sykeseng': ('sykeseng',),
'sykesenga': ('sykeseng',),
'sykesengen': ('sykeseng',),
'sykesengene': ('sykeseng',),
'sykesenger': ('sykeseng',),
'sykestova': ('sykestove',),
'sykestove': ('sykestove',),
'sykestoven': ('sykestove',),
'sykestovene': ('sykestove',),
'sykestover': ('sykestove',),
'sykestova': ('sykestove',),
'sykestove': ('sykestove',),
'sykestoven': ('sykestove',),
'sykestovene': ('sykestove',),
'sykestover': ('sykestove',),
'sykestua': ('sykestue',),
'sykestue': ('sykestue',),
'sykestuen': ('sykestue',),
'sykestuene': ('sykestue',),
'sykestuer': ('sykestue',),
'sykesøster': ('sykesøster',),
'sykesøstera': ('sykesøster',),
'sykesøsteren': ('sykesøster',),
'sykesøstre': ('sykesøster',),
'sykesøstrene': ('sykesøster',),
'sykesøstrer': ('sykesøster',),
'syketransport': ('syketransport',),
'syketransporten': ('syketransport',),
'syketransportene': ('syketransport',),
'syketransporter': ('syketransport',),
'sykkel': ('sykkel',),
'sykkelen': ('sykkel',),
'syklene': ('sykkel',),
'sykler': ('sykkel',),
'sykkelritt': ('sykkelritt',),
'sykkelritta': ('sykkelritt',),
'sykkelrittene': ('sykkelritt',),
'sykkelrittet': ('sykkelritt',),
'sykkelrytter': ('sykkelrytter',),
'sykkelryttere': ('sykkelrytter',),
'sykkelrytteren': ('sykkelrytter',),
'sykkelrytterer': ('sykkelrytter',),
'sykkelrytterne': ('sykkelrytter',),
'sykkelstall': ('sykkelstall',),
'sykkelstallen': ('sykkelstall',),
'sykkelstallene': ('sykkelstall',),
'sykkelstaller': ('sykkelstall',),
'sykkelsti': ('sykkelsti',),
'sykkelstien': ('sykkelsti',),
'sykkelstiene': ('sykkelsti',),
'sykkelstier': ('sykkelsti',),
'syklist': ('syklist',),
'syklisten': ('syklist',),
'syklistene': ('syklist',),
'syklister': ('syklist',),
'syklon': ('syklon',),
'syklonen': ('syklon',),
'syklonene': ('syklon',),
'sykloner': ('syklon',),
'syklotron': ('syklotron',),
'syklotronen': ('syklotron',),
'syklotronene': ('syklotron',),
'syklotroner': ('syklotron',),
'syklubb': ('syklubb',),
'syklubben': ('syklubb',),
'syklubbene': ('syklubb',),
'syklubber': ('syklubb',),
'syklus': ('syklus',),
'syklusen': ('syklus',),
'syklusene': ('syklus',),
'sykluser': ('syklus',),
'sykmelding': ('sykmelding',),
'sykmeldinga': ('sykmelding',),
'sykmeldingen': ('sykmelding',),
'sykmeldingene': ('sykmelding',),
'sykmeldinger': ('sykmelding',),
'sykorg': ('sykorg',),
'sykorga': ('sykorg',),
'sykorgen': ('sykorg',),
'sykorgene': ('sykorg',),
'sykorger': ('sykorg',),
'sykurv': ('sykurv',),
'sykurva': ('sykurv',),
'sykurven': ('sykurv',),
'sykurvene': ('sykurv',),
'sykurver': ('sykurv',),
'syl': ('syl',),
'sylen': ('syl',),
'sylene': ('syl',),
'syler': ('syl',),
'sylfe': ('sylfe',),
'sylfen': ('sylfe',),
'sylfene': ('sylfe',),
'sylfer': ('sylfe',),
'sylfida': ('sylfide',),
'sylfide': ('sylfide',),
'sylfiden': ('sylfide',),
'sylfidene': ('sylfide',),
'sylfider': ('sylfide',),
'sylinder': ('sylinder',),
'sylindere': ('sylinder',),
'sylinderen': ('sylinder',),
'sylinderer': ('sylinder',),
'sylinderne': ('sylinder',),
'sylindre': ('sylinder',),
'sylindrene': ('sylinder',),
'sylindrer': ('sylinder',),
'syll': ('syll',),
'sylla': ('syll',),
'syllen': ('syll',),
'syllene': ('syll',),
'syller': ('syll',),
'syllogisme': ('syllogisme',),
'syllogismen': ('syllogisme',),
'syllogismene': ('syllogisme',),
'syllogismer': ('syllogisme',),
'sylspiss': ('sylspiss',),
'sylspissen': ('sylspiss',),
'sylspissene': ('sylspiss',),
'sylspisser': ('sylspiss',),
'sylta': ('sylte',),
'sylte': ('sylte',),
'sylten': ('sylte',),
'syltene': ('sylte',),
'sylter': ('sylte',),
'sylteagurk': ('sylteagurk',),
'sylteagurken': ('sylteagurk',),
'sylteagurkene': ('sylteagurk',),
'sylteagurker': ('sylteagurk',),
'sylteflesk': ('sylteflesk',),
'syltefleska': ('sylteflesk',),
'syltefleskene': ('sylteflesk',),
'sylteflesket': ('sylteflesk',),
'sylteglas': ('sylteglas',),
'sylteglasa': ('sylteglas',),
'sylteglasene': ('sylteglas',),
'sylteglaset': ('sylteglas',),
'sylteglass': ('sylteglass',),
'sylteglassa': ('sylteglass',),
'sylteglassene': ('sylteglass',),
'sylteglasset': ('sylteglass',),
'syltelabb': ('syltelabb',),
'syltelabben': ('syltelabb',),
'syltelabbene': ('syltelabb',),
'syltelabber': ('syltelabb',),
'syltesukker': ('syltesukker',),
'syltesukkera': ('syltesukker',),
'syltesukkere': ('syltesukker',),
'syltesukkerene': ('syltesukker',),
'syltesukkeret': ('syltesukker',),
'syltesukkerne': ('syltesukker',),
'syltetøy': ('syltetøy',),
'syltetøya': ('syltetøy',),
'syltetøyene': ('syltetøy',),
'syltetøyer': ('syltetøy',),
'syltetøyet': ('syltetøy',),
'syltevoks': ('syltevoks',),
'syltevoksa': ('syltevoks',),
'syltevoksen': ('syltevoks',),
'syltevoksene': ('syltevoks',),
'syltevokser': ('syltevoks',),
'syltevokset': ('syltevoks',),
'symaskin': ('symaskin',),
'symaskina': ('symaskin',),
'symaskinen': ('symaskin',),
'symaskinene': ('symaskin',),
'symaskiner': ('symaskin',),
'symbiont': ('symbiont',),
'symbionten': ('symbiont',),
'symbiontene': ('symbiont',),
'symbionter': ('symbiont',),
'symbiose': ('symbiose',),
'symbiosen': ('symbiose',),
'symbiosene': ('symbiose',),
'symbioser': ('symbiose',),
'symbol': ('symbol',),
'symbola': ('symbol',),
'symbolene': ('symbol',),
'symboler': ('symbol',),
'symbolet': ('symbol',),
'symbolikk': ('symbolikk',),
'symbolikken': ('symbolikk',),
'symbolikkene': ('symbolikk',),
'symbolikker': ('symbolikk',),
'symbolisme': ('symbolisme',),
'symbolismen': ('symbolisme',),
'symbolismene': ('symbolisme',),
'symbolismer': ('symbolisme',),
'symbolist': ('symbolist',),
'symbolisten': ('symbolist',),
'symbolistene': ('symbolist',),
'symbolister': ('symbolist',),
'symfoni': ('symfoni',),
'symfonien': ('symfoni',),
'symfoniene': ('symfoni',),
'symfonier': ('symfoni',),
'symfoniker': ('symfoniker',),
'symfonikere': ('symfoniker',),
'symfonikeren': ('symfoniker',),
'symfonikerer': ('symfoniker',),
'symfonikerne': ('symfoniker',),
'symfoniorkester': ('symfoniorkester',),
'symfoniorkesteret': ('symfoniorkester',),
'symfoniorkestra': ('symfoniorkester',),
'symfoniorkestre': ('symfoniorkester',),
'symfoniorkestrene': ('symfoniorkester',),
'symfoniorkestret': ('symfoniorkester',),
'symmetri': ('symmetri',),
'symmetrien': ('symmetri',),
'symmetriene': ('symmetri',),
'symmetrier': ('symmetri',),
'symmetriplan': ('symmetriplan',),
'symmetriplana': ('symmetriplan',),
'symmetriplanene': ('symmetriplan',),
'symmetriplanet': ('symmetriplan',),
'sympati': ('sympati',),
'sympatien': ('sympati',),
'sympatiene': ('sympati',),
'sympatier': ('sympati',),
'sympatistreik': ('sympatistreik',),
'sympatistreiken': ('sympatistreik',),
'sympatistreikene': ('sympatistreik',),
'sympatistreiker': ('sympatistreik',),
'sympatisør': ('sympatisør',),
'sympatisøren': ('sympatisør',),
'sympatisørene': ('sympatisør',),
'sympatisører': ('sympatisør',),
'symposia': ('symposion',),
'symposiene': ('symposion',),
'symposier': ('symposion',),
'symposiet': ('symposion',),
'symposion': ('symposion',),
'symposia': ('symposium',),
'symposiene': ('symposium',),
'symposier': ('symposium',),
'symposiet': ('symposium',),
'symposium': ('symposium',),
'symptom': ('symptom',),
'symptoma': ('symptom',),
'symptomene': ('symptom',),
'symptomer': ('symptom',),
'symptomet': ('symptom',),
'symra': ('symre',),
'symre': ('symre',),
'symren': ('symre',),
'symrene': ('symre',),
'symrer': ('symre',),
'syn': ('syn',),
'syna': ('syn',),
'synene': ('syn',),
'syner': ('syn',),
'synet': ('syn',),
'synagoge': ('synagoge',),
'synagogen': ('synagoge',),
'synagogene': ('synagoge',),
'synagoger': ('synagoge',),
'synd': ('synd',),
'synda': ('synd',),
'synden': ('synd',),
'syndene': ('synd',),
'synder': ('synd',),
'syndebukk': ('syndebukk',),
'syndebukken': ('syndebukk',),
'syndebukkene': ('syndebukk',),
'syndebukker': ('syndebukk',),
'syndefall': ('syndefall',),
'syndefalla': ('syndefall',),
'syndefallene': ('syndefall',),
'syndefallet': ('syndefall',),
'synder': ('synder',),
'syndere': ('synder',),
'synderen': ('synder',),
'synderer': ('synder',),
'synderne': ('synder',),
'synderegister': ('synderegister',),
'synderegisteret': ('synderegister',),
'synderegistra': ('synderegister',),
'synderegistre': ('synderegister',),
'synderegistrene': ('synderegister',),
'synderegistret': ('synderegister',),
'syndese': ('syndese',),
'syndesen': ('syndese',),
'syndesene': ('syndese',),
'syndeser': ('syndese',),
'syndflod': ('syndflod',),
'syndfloda': ('syndflod',),
'syndfloden': ('syndflod',),
'syndflodene': ('syndflod',),
'syndfloder': ('syndflod',),
'syndikalisme': ('syndikalisme',),
'syndikalismen': ('syndikalisme',),
'syndikalismene': ('syndikalisme',),
'syndikalismer': ('syndikalisme',),
'syndikalist': ('syndikalist',),
'syndikalisten': ('syndikalist',),
'syndikalistene': ('syndikalist',),
'syndikalister': ('syndikalist',),
'syndikat': ('syndikat',),
'syndikata': ('syndikat',),
'syndikatene': ('syndikat',),
'syndikater': ('syndikat',),
'syndikatet': ('syndikat',),
'syndrom': ('syndrom',),
'syndroma': ('syndrom',),
'syndromene': ('syndrom',),
'syndromer': ('syndrom',),
'syndromet': ('syndrom',),
'syndsforlatelse': ('syndsforlatelse',),
'syndsforlatelsen': ('syndsforlatelse',),
'syndsforlatelsene': ('syndsforlatelse',),
'syndsforlatelser': ('syndsforlatelse',),
'syne': ('syne',),
'synergi': ('synergi',),
'synergien': ('synergi',),
'synergiene': ('synergi',),
'synergier': ('synergi',),
'synergisme': ('synergisme',),
'synergismen': ('synergisme',),
'synergismene': ('synergisme',),
'synergismer': ('synergisme',),
'synergist': ('synergist',),
'synergisten': ('synergist',),
'synergistene': ('synergist',),
'synergister': ('synergist',),
'synestesi': ('synestesi',),
'synestesien': ('synestesi',),
'synestesiene': ('synestesi',),
'synestesier': ('synestesi',),
'synfaring': ('synfaring',),
'synfaringa': ('synfaring',),
'synfaringen': ('synfaring',),
'synfaringene': ('synfaring',),
'synfaringer': ('synfaring',),
'syngedama': ('syngedame',),
'syngedame': ('syngedame',),
'syngedamen': ('syngedame',),
'syngedamene': ('syngedame',),
'syngedamer': ('syngedame',),
'syngespell': ('syngespell',),
'syngespella': ('syngespell',),
'syngespellene': ('syngespell',),
'syngespellet': ('syngespell',),
'syngespill': ('syngespill',),
'syngespilla': ('syngespill',),
'syngespillene': ('syngespill',),
'syngespillet': ('syngespill',),
'syning': ('syning',),
'syninga': ('syning',),
'syningen': ('syning',),
'syningene': ('syning',),
'syninger': ('syning',),
'syning': ('syning',),
'syninga': ('syning',),
'syningen': ('syning',),
'syningene': ('syning',),
'syninger': ('syning',),
'synkekum': ('synkekum',),
'synkekummen': ('synkekum',),
'synkekummene': ('synkekum',),
'synkekummer': ('synkekum',),
'synkemina': ('synkemine',),
'synkemine': ('synkemine',),
'synkeminen': ('synkemine',),
'synkeminene': ('synkemine',),
'synkeminer': ('synkemine',),
'synkope': ('synkope',),
'synkopen': ('synkope',),
'synkopene': ('synkope',),
'synkoper': ('synkope',),
'synkretisme': ('synkretisme',),
'synkretismen': ('synkretisme',),
'synkretismene': ('synkretisme',),
'synkretismer': ('synkretisme',),
'synkroni': ('synkroni',),
'synkronien': ('synkroni',),
'synkroniene': ('synkroni',),
'synkronier': ('synkroni',),
'synkronisme': ('synkronisme',),
'synkronismen': ('synkronisme',),
'synkronismene': ('synkronisme',),
'synkronismer': ('synkronisme',),
'synkronmotor': ('synkronmotor',),
'synkronmotoren': ('synkronmotor',),
'synkronmotorene': ('synkronmotor',),
'synkronmotorer': ('synkronmotor',),
'synkronsvømming': ('synkronsvømming',),
'synkronsvømminga': ('synkronsvømming',),
'synkronsvømmingen': ('synkronsvømming',),
'synkronsvømmingene': ('synkronsvømming',),
'synkronsvømminger': ('synkronsvømming',),
'synkrotron': ('synkrotron',),
'synkrotronen': ('synkrotron',),
'synkrotronene': ('synkrotron',),
'synkrotroner': ('synkrotron',),
'synkverving': ('synkverving',),
'synkvervinga': ('synkverving',),
'synkvervingen': ('synkverving',),
'synkvervingene': ('synkverving',),
'synkvervinger': ('synkverving',),
'synode': ('synode',),
'synoden': ('synode',),
'synodene': ('synode',),
'synoder': ('synode',),
'synonym': ('synonym',),
'synonyma': ('synonym',),
'synonymene': ('synonym',),
'synonymer': ('synonym',),
'synonymet': ('synonym',),
'synonymi': ('synonymi',),
'synonymien': ('synonymi',),
'synonymiene': ('synonymi',),
'synonymier': ('synonymi',),
'synonymikk': ('synonymikk',),
'synonymikken': ('synonymikk',),
'synonymikkene': ('synonymikk',),
'synonymikker': ('synonymikk',),
'synonymitet': ('synonymitet',),
'synonymiteten': ('synonymitet',),
'synonymitetene': ('synonymitet',),
'synonymiteter': ('synonymitet',),
'synonymordbok': ('synonymordbok',),
'synonymordboka': ('synonymordbok',),
'synonymordboken': ('synonymordbok',),
'synonymordbøkene': ('synonymordbok',),
'synonymordbøker': ('synonymordbok',),
'synops': ('synops',),
'synopsen': ('synops',),
'synopsene': ('synops',),
'synopser': ('synops',),
'synopsis': ('synopsis',),
'synopsisen': ('synopsis',),
'synopsisene': ('synopsis',),
'synopsiser': ('synopsis',),
'synoptiker': ('synoptiker',),
'synoptikere': ('synoptiker',),
'synoptikeren': ('synoptiker',),
'synoptikerer': ('synoptiker',),
'synoptikerne': ('synoptiker',),
'synsbedrag': ('synsbedrag',),
'synsbedraga': ('synsbedrag',),
'synsbedragene': ('synsbedrag',),
'synsbedraget': ('synsbedrag',),
'synser': ('synser',),
'synsere': ('synser',),
'synseren': ('synser',),
'synserer': ('synser',),
'synserne': ('synser',),
'synsfelt': ('synsfelt',),
'synsfelta': ('synsfelt',),
'synsfeltene': ('synsfelt',),
'synsfelter': ('synsfelt',),
'synsfeltet': ('synsfelt',),
'synsing': ('synsing',),
'synsinga': ('synsing',),
'synsingen': ('synsing',),
'synsingene': ('synsing',),
'synsinger': ('synsing',),
'synsinntrykk': ('synsinntrykk',),
'synsinntrykka': ('synsinntrykk',),
'synsinntrykkene': ('synsinntrykk',),
'synsinntrykket': ('synsinntrykk',),
'synskrets': ('synskrets',),
'synskretsen': ('synskrets',),
'synskretsene': ('synskrets',),
'synskretser': ('synskrets',),
'synsmåte': ('synsmåte',),
'synsmåten': ('synsmåte',),
'synsmåtene': ('synsmåte',),
'synsmåter': ('synsmåte',),
'synsnerve': ('synsnerve',),
'synsnerven': ('synsnerve',),
'synsnervene': ('synsnerve',),
'synsnerver': ('synsnerve',),
'synspunkt': ('synspunkt',),
'synspunkta': ('synspunkt',),
'synspunktene': ('synspunkt',),
'synspunkter': ('synspunkt',),
'synspunktet': ('synspunkt',),
'synssans': ('synssans',),
'synssansen': ('synssans',),
'synssansene': ('synssans',),
'synssanser': ('synssans',),
'synssentra': ('synssentrum',),
'synssentraene': ('synssentrum',),
'synssentre': ('synssentrum',),
'synssentrene': ('synssentrum',),
'synssentret': ('synssentrum',),
'synssentrum': ('synssentrum',),
'synssentrumet': ('synssentrum',),
'synsvidda': ('synsvidde',),
'synsvidde': ('synsvidde',),
'synsvidden': ('synsvidde',),
'synsviddene': ('synsvidde',),
'synsvidder': ('synsvidde',),
'synsvinkel': ('synsvinkel',),
'synsvinkelen': ('synsvinkel',),
'synsvinklene': ('synsvinkel',),
'synsvinkler': ('synsvinkel',),
'synt': ('synt',),
'synten': ('synt',),
'syntene': ('synt',),
'synter': ('synt',),
'syntagma': ('syntagme',),
'syntagme': ('syntagme',),
'syntagmene': ('syntagme',),
'syntagmer': ('syntagme',),
'syntagmet': ('syntagme',),
'syntaks': ('syntaks',),
'syntaksen': ('syntaks',),
'syntaksene': ('syntaks',),
'syntakser': ('syntaks',),
'syntese': ('syntese',),
'syntesen': ('syntese',),
'syntesene': ('syntese',),
'synteser': ('syntese',),
'syntetfiber': ('syntetfiber',),
'syntetfibere': ('syntetfiber',),
'syntetfiberen': ('syntetfiber',),
'syntetfiberer': ('syntetfiber',),
'syntetfiberne': ('syntetfiber',),
'syntetfibre': ('syntetfiber',),
'syntetfibrene': ('syntetfiber',),
'syntetfibrer': ('syntetfiber',),
'syntetstoff': ('syntetstoff',),
'syntetstoffa': ('syntetstoff',),
'syntetstoffene': ('syntetstoff',),
'syntetstoffer': ('syntetstoff',),
'syntetstoffet': ('syntetstoff',),
'synthesizer': ('synthesizer',),
'synthesizere': ('synthesizer',),
'synthesizeren': ('synthesizer',),
'synthesizerer': ('synthesizer',),
'synthesizerne': ('synthesizer',),
'synål': ('synål',),
'synåla': ('synål',),
'synålen': ('synål',),
'synålene': ('synål',),
'synåler': ('synål',),
'sypika': ('sypike',),
'sypike': ('sypike',),
'sypiken': ('sypike',),
'sypikene': ('sypike',),
'sypiker': ('sypike',),
'sypress': ('sypress',),
'sypressen': ('sypress',),
'sypressene': ('sypress',),
'sypresser': ('sypress',),
'syra': ('syre',),
'syre': ('syre',),
'syren': ('syre',),
'syrene': ('syre',),
'syrer': ('syre',),
'syra': ('syre',),
'syre': ('syre',),
'syren': ('syre',),
'syrene': ('syre',),
'syrer': ('syre',),
'syrebad': ('syrebad',),
'syrebada': ('syrebad',),
'syrebadene': ('syrebad',),
'syrebadet': ('syrebad',),
'syrebeis': ('syrebeis',),
'syrebeisen': ('syrebeis',),
'syrebeisene': ('syrebeis',),
'syrebeiser': ('syrebeis',),
'syrer': ('syrer',),
'syrere': ('syrer',),
'syreren': ('syrer',),
'syrerer': ('syrer',),
'syrerne': ('syrer',),
'syrin': ('syrin',),
'syrinen': ('syrin',),
'syrinene': ('syrin',),
'syriner': ('syrin',),
'syrinbusk': ('syrinbusk',),
'syrinbusken': ('syrinbusk',),
'syrinbuskene': ('syrinbusk',),
'syrinbusker': ('syrinbusk',),
'syrintre': ('syrintre',),
'syrintrea': ('syrintre',),
'syrintreet': ('syrintre',),
'syrintrær': ('syrintre',),
'syrintrærne': ('syrintre',),
'syrling': ('syrling',),
'syrlingen': ('syrling',),
'syrlingene': ('syrling',),
'syrlinger': ('syrling',),
'sysakene': ('sysaker',),
'sysaker': ('sysaker',),
'syskrin': ('syskrin',),
'syskrina': ('syskrin',),
'syskrinene': ('syskrin',),
'syskrinet': ('syskrin',),
'sysla': ('sysle',),
'sysle': ('sysle',),
'syslen': ('sysle',),
'syslene': ('sysle',),
'sysler': ('sysle',),
'syslemann': ('syslemann',),
'syslemannen': ('syslemann',),
'syslemenn': ('syslemann',),
'syslemennene': ('syslemann',),
'syslene': ('syssel',),
'sysler': ('syssel',),
'syssel': ('syssel',),
'sysselen': ('syssel',),
'sysselmann': ('sysselmann',),
'sysselmannen': ('sysselmann',),
'sysselmenn': ('sysselmann',),
'sysselmennene': ('sysselmann',),
'sysselsetting': ('sysselsetting',),
'sysselsettinga': ('sysselsetting',),
'sysselsettingen': ('sysselsetting',),
'sysselsettingene': ('sysselsetting',),
'sysselsettinger': ('sysselsetting',),
'system': ('system',),
'systema': ('system',),
'systemene': ('system',),
'systemer': ('system',),
'systemet': ('system',),
'systemanalysa': ('systemanalyse',),
'systemanalyse': ('systemanalyse',),
'systemanalysen': ('systemanalyse',),
'systemanalysene': ('systemanalyse',),
'systemanalyser': ('systemanalyse',),
'systematiker': ('systematiker',),
'systematikere': ('systematiker',),
'systematikeren': ('systematiker',),
'systematikerer': ('systematiker',),
'systematikerne': ('systematiker',),
'systematikk': ('systematikk',),
'systematikken': ('systematikk',),
'systematikkene': ('systematikk',),
'systematikker': ('systematikk',),
'systemering': ('systemering',),
'systemeringa': ('systemering',),
'systemeringen': ('systemering',),
'systemeringene': ('systemering',),
'systemeringer': ('systemering',),
'systemskifta': ('systemskifte',),
'systemskifte': ('systemskifte',),
'systemskiftene': ('systemskifte',),
'systemskifter': ('systemskifte',),
'systemskiftet': ('systemskifte',),
'systova': ('systove',),
'systove': ('systove',),
'systoven': ('systove',),
'systovene': ('systove',),
'systover': ('systove',),
'systua': ('systue',),
'systue': ('systue',),
'systuen': ('systue',),
'systuene': ('systue',),
'systuer': ('systue',),
'syt': ('syt',),
'syta': ('syt',),
'sytene': ('syt',),
'sytet': ('syt',),
'sytråd': ('sytråd',),
'sytråden': ('sytråd',),
'sytrådene': ('sytråd',),
'sytråder': ('sytråd',),
'syttendel': ('syttendel',),
'syttendelen': ('syttendel',),
'syttendelene': ('syttendel',),
'syttendeler': ('syttendel',),
'syttendemaitale': ('syttendemaitale',),
'syttendemaitalen': ('syttendemaitale',),
'syttendemaitalene': ('syttendemaitale',),
'syttendemaitaler': ('syttendemaitale',),
'syttendemaitog': ('syttendemaitog',),
'syttendemaitoga': ('syttendemaitog',),
'syttendemaitogene': ('syttendemaitog',),
'syttendemaitoget': ('syttendemaitog',),
'syttenhundretall': ('syttenhundretall',),
'syttenhundretalla': ('syttenhundretall',),
'syttenhundretallene': ('syttenhundretall',),
'syttenhundretallet': ('syttenhundretall',),
'syttenårsalder': ('syttenårsalder',),
'syttenårsaldere': ('syttenårsalder',),
'syttenårsalderen': ('syttenårsalder',),
'syttenårsalderer': ('syttenårsalder',),
'syttenårsalderne': ('syttenårsalder',),
'syttenårsaldre': ('syttenårsalder',),
'syttenårsaldrene': ('syttenårsalder',),
'syttenårsaldrer': ('syttenårsalder',),
'syttidel': ('syttidel',),
'syttidelen': ('syttidel',),
'syttidelene': ('syttidel',),
'syttideler': ('syttidel',),
'syttiår': ('syttiår',),
'syttiåra': ('syttiår',),
'syttiårene': ('syttiår',),
'syttiåret': ('syttiår',),
'syttiåring': ('syttiåring',),
'syttiåringen': ('syttiåring',),
'syttiåringene': ('syttiåring',),
'syttiåringer': ('syttiåring',),
'syttiårsdag': ('syttiårsdag',),
'syttiårsdagen': ('syttiårsdag',),
'syttiårsdagene': ('syttiårsdag',),
'syttiårsdager': ('syttiårsdag',),
'sytøy': ('sytøy',),
'sytøya': ('sytøy',),
'sytøyene': ('sytøy',),
'sytøyer': ('sytøy',),
'sytøyet': ('sytøy',),
'så': ('så',),
'såen': ('så',),
'såene': ('så',),
'såer': ('så',),
'så': ('så',),
'såa': ('så',),
'såen': ('så',),
'såene': ('så',),
'såer': ('så',),
'såerla': ('såerle',),
'såerle': ('såerle',),
'såerlen': ('såerle',),
'såerlene': ('såerle',),
'såerler': ('såerle',),
'såfrø': ('såfrø',),
'såfrøa': ('såfrø',),
'såfrøene': ('såfrø',),
'såfrøet': ('såfrø',),
'sågidder': ('sågidder',),
'sågiddera': ('sågidder',),
'sågiddere': ('sågidder',),
'sågidderene': ('sågidder',),
'sågidderet': ('sågidder',),
'sågidderne': ('sågidder',),
'såkorn': ('såkorn',),
'såkorna': ('såkorn',),
'såkornene': ('såkorn',),
'såkornet': ('såkorn',),
'sål': ('sål',),
'såla': ('sål',),
'sålen': ('sål',),
'sålene': ('sål',),
'såler': ('sål',),
'sålet': ('sål',),
'såld': ('såld',),
'sålda': ('såld',),
'såldene': ('såld',),
'såldet': ('såld',),
'såle': ('såle',),
'sålen': ('såle',),
'sålene': ('såle',),
'såler': ('såle',),
'sålegjenger': ('sålegjenger',),
'sålegjengere': ('sålegjenger',),
'sålegjengeren': ('sålegjenger',),
'sålegjengerer': ('sålegjenger',),
'sålegjengerne': ('sålegjenger',),
'sålelær': ('sålelær',),
'sålelæra': ('sålelær',),
'sålelærene': ('sålelær',),
'sålelæret': ('sålelær',),
'såmannssøndag': ('såmannssøndag',),
'såmannssøndagen': ('såmannssøndag',),
'såmannssøndagene': ('såmannssøndag',),
'såmannssøndager': ('såmannssøndag',),
'såmaskin': ('såmaskin',),
'såmaskina': ('såmaskin',),
'såmaskinen': ('såmaskin',),
'såmaskinene': ('såmaskin',),
'såmaskiner': ('såmaskin',),
'såpa': ('såpe',),
'såpe': ('såpe',),
'såpen': ('såpe',),
'såpene': ('såpe',),
'såper': ('såpe',),
'såpebobla': ('såpeboble',),
'såpeboble': ('såpeboble',),
'såpeboblen': ('såpeboble',),
'såpeboblene': ('såpeboble',),
'såpebobler': ('såpeboble',),
'såpekoker': ('såpekoker',),
'såpekokere': ('såpekoker',),
'såpekokeren': ('såpekoker',),
'såpekokerer': ('såpekoker',),
'såpekokerne': ('såpekoker',),
'såpekopp': ('såpekopp',),
'såpekoppen': ('såpekopp',),
'såpekoppene': ('såpekopp',),
'såpekopper': ('såpekopp',),
'såpeopera': ('såpeopera',),
'såpeoperaen': ('såpeopera',),
'såpeoperaene': ('såpeopera',),
'såpeoperaer': ('såpeopera',),
'såpepulver': ('såpepulver',),
'såpepulvera': ('såpepulver',),
'såpepulvere': ('såpepulver',),
'såpepulveret': ('såpepulver',),
'såpepulverne': ('såpepulver',),
'såpevann': ('såpevann',),
'såpevanna': ('såpevann',),
'såpevannene': ('såpevann',),
'såpevannet': ('såpevann',),
'såpevatn': ('såpevatn',),
'såpevatna': ('såpevatn',),
'såpevatnene': ('såpevatn',),
'såpevatnet': ('såpevatn',),
'sår': ('sår',),
'såra': ('sår',),
'sårene': ('sår',),
'såret': ('sår',),
'sårfeber': ('sårfeber',),
'sårfebere': ('sårfeber',),
'sårfeberen': ('sårfeber',),
'sårfeberne': ('sårfeber',),
'sårfebre': ('sårfeber',),
'sårfebrene': ('sårfeber',),
'sårfebrer': ('sårfeber',),
'sårsalva': ('sårsalve',),
'sårsalve': ('sårsalve',),
'sårsalven': ('sårsalve',),
'sårsalvene': ('sårsalve',),
'sårsalver': ('sårsalve',),
'såsiss': ('såsiss',),
'såsissen': ('såsiss',),
'såsissene': ('såsiss',),
'såsisser': ('såsiss',),
'såsiss': ('såsiss',),
'såsissen': ('såsiss',),
'såsissene': ('såsiss',),
'såsisser': ('såsiss',),
'såta': ('såte',),
'såte': ('såte',),
'såten': ('såte',),
'såtene': ('såte',),
'såter': ('såte',),
'såtid': ('såtid',),
'såtida': ('såtid',),
'såtiden': ('såtid',),
'såtidene': ('såtid',),
'såtider': ('såtid',),
'såvara': ('såvare',),
'såvare': ('såvare',),
'såvaren': ('såvare',),
'såvarene': ('såvare',),
'såvarer': ('såvare',),
'sæd': ('sæd',),
'sæden': ('sæd',),
'sædene': ('sæd',),
'sæder': ('sæd',),
'sædavgang': ('sædavgang',),
'sædavgangen': ('sædavgang',),
'sædavgangene': ('sædavgang',),
'sædavganger': ('sædavgang',),
'sædcella': ('sædcelle',),
'sædcelle': ('sædcelle',),
'sædcellen': ('sædcelle',),
'sædcellene': ('sædcelle',),
'sædceller': ('sædcelle',),
'sædgjess': ('sædgås',),
'sædgjessene': ('sædgås',),
'sædgjæsene': ('sædgås',),
'sædgjæser': ('sædgås',),
'sædgås': ('sædgås',),
'sædgåsa': ('sædgås',),
'sædgåsen': ('sædgås',),
'sædoverføring': ('sædoverføring',),
'sædoverføringa': ('sædoverføring',),
'sædoverføringen': ('sædoverføring',),
'sædoverføringene': ('sædoverføring',),
'sædoverføringer': ('sædoverføring',),
'sædstasjon': ('sædstasjon',),
'sædstasjonen': ('sædstasjon',),
'sædstasjonene': ('sædstasjon',),
'sædstasjoner': ('sædstasjon',),
'sælebot': ('sælebot',),
'sælebota': ('sælebot',),
'sæleboten': ('sælebot',),
'sælebotene': ('sælebot',),
'sæleboter': ('sælebot',),
'sælehus': ('sælehus',),
'sælehusa': ('sælehus',),
'sælehusene': ('sælehus',),
'sælehuset': ('sælehus',),
'særdeleshet': ('særdeleshet',),
'særdelesheten': ('særdeleshet',),
'særdeleshetene': ('særdeleshet',),
'særdelesheter': ('særdeleshet',),
'særdomstol': ('særdomstol',),
'særdomstolen': ('særdomstol',),
'særdomstolene': ('særdomstol',),
'særdomstoler': ('særdomstol',),
'særegenhet': ('særegenhet',),
'særegenheta': ('særegenhet',),
'særegenheten': ('særegenhet',),
'særegenhetene': ('særegenhet',),
'særegenheter': ('særegenhet',),
'særeia': ('særeie',),
'særeie': ('særeie',),
'særeiene': ('særeie',),
'særeier': ('særeie',),
'særeiet': ('særeie',),
'særfradrag': ('særfradrag',),
'særfradraga': ('særfradrag',),
'særfradragene': ('særfradrag',),
'særfradraget': ('særfradrag',),
'særhet': ('særhet',),
'særheta': ('særhet',),
'særheten': ('særhet',),
'særhetene': ('særhet',),
'særheter': ('særhet',),
'særinteresse': ('særinteresse',),
'særinteressen': ('særinteresse',),
'særinteressene': ('særinteresse',),
'særinteresser': ('særinteresse',),
'særkjenna': ('særkjenne',),
'særkjenne': ('særkjenne',),
'særkjennene': ('særkjenne',),
'særkjenner': ('særkjenne',),
'særkjennet': ('særkjenne',),
'særklassa': ('særklasse',),
'særklasse': ('særklasse',),
'særklassen': ('særklasse',),
'særklassene': ('særklasse',),
'særklasser': ('særklasse',),
'særling': ('særling',),
'særlingen': ('særling',),
'særlingene': ('særling',),
'særlinger': ('særling',),
'særlov': ('særlov',),
'særloven': ('særlov',),
'særlovene': ('særlov',),
'særlover': ('særlov',),
'særmerka': ('særmerke',),
'særmerke': ('særmerke',),
'særmerkene': ('særmerke',),
'særmerker': ('særmerke',),
'særmerket': ('særmerke',),
'særoppgava': ('særoppgave',),
'særoppgave': ('særoppgave',),
'særoppgaven': ('særoppgave',),
'særoppgavene': ('særoppgave',),
'særoppgaver': ('særoppgave',),
'særpreg': ('særpreg',),
'særprega': ('særpreg',),
'særpregene': ('særpreg',),
'særpreget': ('særpreg',),
'særskole': ('særskole',),
'særskolen': ('særskole',),
'særskolene': ('særskole',),
'særskoler': ('særskole',),
'særspråk': ('særspråk',),
'særspråka': ('særspråk',),
'særspråkene': ('særspråk',),
'særspråket': ('særspråk',),
'særstilling': ('særstilling',),
'særstillinga': ('særstilling',),
'særstillingen': ('særstilling',),
'særstillingene': ('særstilling',),
'særstillinger': ('særstilling',),
'særsyn': ('særsyn',),
'særsyna': ('særsyn',),
'særsynene': ('særsyn',),
'særsynet': ('særsyn',),
'særtrekk': ('særtrekk',),
'særtrekka': ('særtrekk',),
'særtrekkene': ('særtrekk',),
'særtrekket': ('særtrekk',),
'særtrykk': ('særtrykk',),
'særtrykka': ('særtrykk',),
'særtrykkene': ('særtrykk',),
'særtrykket': ('særtrykk',),
'særutvalg': ('særutvalg',),
'særutvalga': ('særutvalg',),
'særutvalgene': ('særutvalg',),
'særutvalget': ('særutvalg',),
'særvota': ('særvotum',),
'særvotaene': ('særvotum',),
'særvotum': ('særvotum',),
'særvotumet': ('særvotum',),
'sættargjerd': ('sættargjerd',),
'sættargjerda': ('sættargjerd',),
'sættargjerden': ('sættargjerd',),
'sættargjerdene': ('sættargjerd',),
'sættargjerder': ('sættargjerd',),
'sødme': ('sødme',),
'sødmen': ('sødme',),
'sødmene': ('sødme',),
'sødmer': ('sødme',),
'søk': ('søk',),
'søka': ('søk',),
'søkene': ('søk',),
'søket': ('søk',),
'søkelys': ('søkelys',),
'søkelysa': ('søkelys',),
'søkelysene': ('søkelys',),
'søkelyset': ('søkelys',),
'søken': ('søken',),
'søker': ('søker',),
'søkere': ('søker',),
'søkeren': ('søker',),
'søkerer': ('søker',),
'søkerne': ('søker',),
'søkk': ('søkk',),
'søkka': ('søkk',),
'søkkene': ('søkk',),
'søkket': ('søkk',),
'søkka': ('søkke',),
'søkke': ('søkke',),
'søkkene': ('søkke',),
'søkker': ('søkke',),
'søkket': ('søkke',),
'søkkemyr': ('søkkemyr',),
'søkkemyra': ('søkkemyr',),
'søkkemyren': ('søkkemyr',),
'søkkemyrene': ('søkkemyr',),
'søkkemyrer': ('søkkemyr',),
'søkn': ('søkn',),
'søkna': ('søkn',),
'søknen': ('søkn',),
'søknene': ('søkn',),
'søkner': ('søkn',),
'søknad': ('søknad',),
'søknaden': ('søknad',),
'søknadene': ('søknad',),
'søknader': ('søknad',),
'søknadsfrist': ('søknadsfrist',),
'søknadsfristen': ('søknadsfrist',),
'søknadsfristene': ('søknadsfrist',),
'søknadsfrister': ('søknadsfrist',),
'søknadsskjema': ('søknadsskjema',),
'søknadsskjemaene': ('søknadsskjema',),
'søknadsskjemaer': ('søknadsskjema',),
'søknadsskjemaet': ('søknadsskjema',),
'søkning': ('søkning',),
'søkninga': ('søkning',),
'søkningen': ('søkning',),
'søkningene': ('søkning',),
'søkninger': ('søkning',),
'søksmål': ('søksmål',),
'søksmåla': ('søksmål',),
'søksmålene': ('søksmål',),
'søksmålet': ('søksmål',),
'søl': ('søl',),
'søla': ('søl',),
'sølene': ('søl',),
'sølet': ('søl',),
'søl': ('søl',),
'søla': ('søl',),
'sølene': ('søl',),
'sølet': ('søl',),
'søla': ('søle',),
'søle': ('søle',),
'sølen': ('søle',),
'sølene': ('søle',),
'søler': ('søle',),
'sølekopp': ('sølekopp',),
'sølekoppen': ('sølekopp',),
'sølekoppene': ('sølekopp',),
'sølekopper': ('sølekopp',),
'sølepytt': ('sølepytt',),
'sølepytten': ('sølepytt',),
'sølepyttene': ('sølepytt',),
'sølepytter': ('sølepytt',),
'sølevann': ('sølevann',),
'sølevanna': ('sølevann',),
'sølevannene': ('sølevann',),
'sølevannet': ('sølevann',),
'sølevatn': ('sølevatn',),
'sølevatna': ('sølevatn',),
'sølevatnene': ('sølevatn',),
'sølevatnet': ('sølevatn',),
'sølibat': ('sølibat',),
'sølibata': ('sølibat',),
'sølibatene': ('sølibat',),
'sølibater': ('sølibat',),
'sølibatet': ('sølibat',),
'sølja': ('sølje',),
'sølje': ('sølje',),
'søljen': ('sølje',),
'søljene': ('sølje',),
'søljer': ('sølje',),
'sølv': ('sølv',),
'sølva': ('sølv',),
'sølvene': ('sølv',),
'sølvet': ('sølv',),
'sølvalder': ('sølvalder',),
'sølvaldere': ('sølvalder',),
'sølvalderen': ('sølvalder',),
'sølvalderer': ('sølvalder',),
'sølvalderne': ('sølvalder',),
'sølvaldre': ('sølvalder',),
'sølvaldrene': ('sølvalder',),
'sølvaldrer': ('sølvalder',),
'sølvbromid': ('sølvbromid',),
'sølvbromida': ('sølvbromid',),
'sølvbromidene': ('sølvbromid',),
'sølvbromider': ('sølvbromid',),
'sølvbromidet': ('sølvbromid',),
'sølvbryllup': ('sølvbryllup',),
'sølvbryllupa': ('sølvbryllup',),
'sølvbryllupene': ('sølvbryllup',),
'sølvbrylluper': ('sølvbryllup',),
'sølvbryllupet': ('sølvbryllup',),
'sølvklorid': ('sølvklorid',),
'sølvklorida': ('sølvklorid',),
'sølvkloridene': ('sølvklorid',),
'sølvklorider': ('sølvklorid',),
'sølvkloridet': ('sølvklorid',),
'sølvkre': ('sølvkre',),
'sølvkrea': ('sølvkre',),
'sølvkreene': ('sølvkre',),
'sølvkreet': ('sølvkre',),
'sølvmedalje': ('sølvmedalje',),
'sølvmedaljen': ('sølvmedalje',),
'sølvmedaljene': ('sølvmedalje',),
'sølvmedaljer': ('sølvmedalje',),
'sølvnitrat': ('sølvnitrat',),
'sølvnitrata': ('sølvnitrat',),
'sølvnitratene': ('sølvnitrat',),
'sølvnitrater': ('sølvnitrat',),
'sølvnitratet': ('sølvnitrat',),
'sølvpapir': ('sølvpapir',),
'sølvpapira': ('sølvpapir',),
'sølvpapirene': ('sølvpapir',),
'sølvpapirer': ('sølvpapir',),
'sølvpapiret': ('sølvpapir',),
'sølvpenge': ('sølvpenge',),
'sølvpengen': ('sølvpenge',),
'sølvpengene': ('sølvpenge',),
'sølvpenger': ('sølvpenge',),
'sølvpil': ('sølvpil',),
'sølvpila': ('sølvpil',),
'sølvpilen': ('sølvpil',),
'sølvpilene': ('sølvpil',),
'sølvpiler': ('sølvpil',),
'sølvplata': ('sølvplate',),
'sølvplate': ('sølvplate',),
'sølvplaten': ('sølvplate',),
'sølvplatene': ('sølvplate',),
'sølvplater': ('sølvplate',),
'sølvplett': ('sølvplett',),
'sølvpletten': ('sølvplett',),
'sølvplettene': ('sølvplett',),
'sølvpletter': ('sølvplett',),
'sølvrev': ('sølvrev',),
'sølvreven': ('sølvrev',),
'sølvrevene': ('sølvrev',),
'sølvrever': ('sølvrev',),
'sølvsmed': ('sølvsmed',),
'sølvsmeden': ('sølvsmed',),
'sølvsmedene': ('sølvsmed',),
'sølvsmeder': ('sølvsmed',),
'sølvsmia': ('sølvsmie',),
'sølvsmie': ('sølvsmie',),
'sølvsmien': ('sølvsmie',),
'sølvsmiene': ('sølvsmie',),
'sølvsmier': ('sølvsmie',),
'sølvtøy': ('sølvtøy',),
'sølvtøya': ('sølvtøy',),
'sølvtøyene': ('sølvtøy',),
'sølvtøyer': ('sølvtøy',),
'sølvtøyet': ('sølvtøy',),
'søm': ('søm',),
'sømmen': ('søm',),
'sømmene': ('søm',),
'sømmer': ('søm',),
'søm': ('søm',),
'sømma': ('søm',),
'sømmene': ('søm',),
'sømmet': ('søm',),
'sømd': ('sømd',),
'sømda': ('sømd',),
'sømden': ('sømd',),
'sømdene': ('sømd',),
'sømder': ('sømd',),
'sømmelighet': ('sømmelighet',),
'sømmeligheta': ('sømmelighet',),
'sømmeligheten': ('sømmelighet',),
'sømmelighetene': ('sømmelighet',),
'sømmeligheter': ('sømmelighet',),
'søndag': ('søndag',),
'søndagen': ('søndag',),
'søndagene': ('søndag',),
'søndager': ('søndag',),
'søndagsklær': ('søndagsklær',),
'søndagsklærne': ('søndagsklær',),
'søndagsskole': ('søndagsskole',),
'søndagsskolen': ('søndagsskole',),
'søndagsskolene': ('søndagsskole',),
'søndagsskoler': ('søndagsskole',),
'sønn': ('sønn',),
'sønnen': ('sønn',),
'sønnene': ('sønn',),
'sønner': ('sønn',),
'sønnadrag': ('sønnadrag',),
'sønnadraga': ('sønnadrag',),
'sønnadragene': ('sønnadrag',),
'sønnadraget': ('sønnadrag',),
'sønnavind': ('sønnavind',),
'sønnavinden': ('sønnavind',),
'sønnavindene': ('sønnavind',),
'sønnavinder': ('sønnavind',),
'sønnedatter': ('sønnedatter',),
'sønnedattera': ('sønnedatter',),
'sønnedatteren': ('sønnedatter',),
'sønnedøtre': ('sønnedatter',),
'sønnedøtrene': ('sønnedatter',),
'sønnedøtrer': ('sønnedatter',),
'sønnesønn': ('sønnesønn',),
'sønnesønnen': ('sønnesønn',),
'sønnesønnene': ('sønnesønn',),
'sønnesønner': ('sønnesønn',),
'søpla': ('søppel',),
'søplene': ('søppel',),
'søpler': ('søppel',),
'søplet': ('søppel',),
'søppel': ('søppel',),
'søppelen': ('søppel',),
'søppelet': ('søppel',),
'søppelbil': ('søppelbil',),
'søppelbilen': ('søppelbil',),
'søppelbilene': ('søppelbil',),
'søppelbiler': ('søppelbil',),
'søppelbrett': ('søppelbrett',),
'søppelbretta': ('søppelbrett',),
'søppelbrettene': ('søppelbrett',),
'søppelbretter': ('søppelbrett',),
'søppelbrettet': ('søppelbrett',),
'søppeldunk': ('søppeldunk',),
'søppeldunken': ('søppeldunk',),
'søppeldunkene': ('søppeldunk',),
'søppeldunker': ('søppeldunk',),
'søppelfylling': ('søppelfylling',),
'søppelfyllinga': ('søppelfylling',),
'søppelfyllingen': ('søppelfylling',),
'søppelfyllingene': ('søppelfylling',),
'søppelfyllinger': ('søppelfylling',),
'søppelkjører': ('søppelkjører',),
'søppelkjørere': ('søppelkjører',),
'søppelkjøreren': ('søppelkjører',),
'søppelkjørerer': ('søppelkjører',),
'søppelkjørerne': ('søppelkjører',),
'søppelsjakt': ('søppelsjakt',),
'søppelsjakta': ('søppelsjakt',),
'søppelsjakten': ('søppelsjakt',),
'søppelsjaktene': ('søppelsjakt',),
'søppelsjakter': ('søppelsjakt',),
'sør': ('sør',),
'sørafrikaner': ('sørafrikaner',),
'sørafrikanere': ('sørafrikaner',),
'sørafrikaneren': ('sørafrikaner',),
'sørafrikanerer': ('sørafrikaner',),
'sørafrikanerne': ('sørafrikaner',),
'søramerikaner': ('søramerikaner',),
'søramerikanere': ('søramerikaner',),
'søramerikaneren': ('søramerikaner',),
'søramerikanerer': ('søramerikaner',),
'søramerikanerne': ('søramerikaner',),
'søraust': ('søraust',),
'sørausten': ('søraust',),
'søraustene': ('søraust',),
'sørauster': ('søraust',),
'søraust': ('søraust',),
'søreuropeer': ('søreuropeer',),
'søreuropeere': ('søreuropeer',),
'søreuropeeren': ('søreuropeer',),
'søreuropeerer': ('søreuropeer',),
'søreuropeerne': ('søreuropeer',),
'sørgebind': ('sørgebind',),
'sørgebinda': ('sørgebind',),
'sørgebindene': ('sørgebind',),
'sørgebindet': ('sørgebind',),
'sørgebud': ('sørgebud',),
'sørgebuda': ('sørgebud',),
'sørgebudene': ('sørgebud',),
'sørgebudet': ('sørgebud',),
'sørgebudskap': ('sørgebudskap',),
'sørgebudskapa': ('sørgebudskap',),
'sørgebudskapene': ('sørgebudskap',),
'sørgebudskaper': ('sørgebudskap',),
'sørgebudskapet': ('sørgebudskap',),
'sørgeflor': ('sørgeflor',),
'sørgeflora': ('sørgeflor',),
'sørgeflorene': ('sørgeflor',),
'sørgefloret': ('sørgeflor',),
'sørgekona': ('sørgekone',),
'sørgekone': ('sørgekone',),
'sørgekonen': ('sørgekone',),
'sørgekonene': ('sørgekone',),
'sørgekoner': ('sørgekone',),
'sørgemarsj': ('sørgemarsj',),
'sørgemarsjen': ('sørgemarsj',),
'sørgemarsjene': ('sørgemarsj',),
'sørgemarsjer': ('sørgemarsj',),
'sørgerand': ('sørgerand',),
'sørgeranda': ('sørgerand',),
'sørgeranden': ('sørgerand',),
'sørgerendene': ('sørgerand',),
'sørgerender': ('sørgerand',),
'sørgespill': ('sørgespill',),
'sørgespilla': ('sørgespill',),
'sørgespillene': ('sørgespill',),
'sørgespillet': ('sørgespill',),
'sørhelling': ('sørhelling',),
'sørhellinga': ('sørhelling',),
'sørhellingen': ('sørhelling',),
'sørhellingene': ('sørhelling',),
'sørhellinger': ('sørhelling',),
'søring': ('søring',),
'søringen': ('søring',),
'søringene': ('søring',),
'søringer': ('søring',),
'sørkoreaner': ('sørkoreaner',),
'sørkoreanere': ('sørkoreaner',),
'sørkoreaneren': ('sørkoreaner',),
'sørkoreanerer': ('sørkoreaner',),
'sørkoreanerne': ('sørkoreaner',),
'sørlending': ('sørlending',),
'sørlendingen': ('sørlending',),
'sørlendingene': ('sørlending',),
'sørlendinger': ('sørlending',),
'sørpa': ('sørpe',),
'sørpe': ('sørpe',),
'sørpen': ('sørpe',),
'sørpene': ('sørpe',),
'sørper': ('sørpe',),
'sørpeføra': ('sørpeføre',),
'sørpeføre': ('sørpeføre',),
'sørpeførene': ('sørpeføre',),
'sørpefører': ('sørpeføre',),
'sørpeføret': ('sørpeføre',),
'sørpol': ('sørpol',),
'sørpolen': ('sørpol',),
'sørpolene': ('sørpol',),
'sørpoler': ('sørpol',),
'sørpolsfarer': ('sørpolsfarer',),
'sørpolsfarere': ('sørpolsfarer',),
'sørpolsfareren': ('sørpolsfarer',),
'sørpolsfarerer': ('sørpolsfarer',),
'sørpolsfarerne': ('sørpolsfarer',),
'sørsame': ('sørsame',),
'sørsamen': ('sørsame',),
'sørsamene': ('sørsame',),
'sørsamer': ('sørsame',),
'sørsamisk': ('sørsamisk',),
'sørsamisken': ('sørsamisk',),
'sørsamiskene': ('sørsamisk',),
'sørsamisker': ('sørsamisk',),
'sørstat': ('sørstat',),
'sørstaten': ('sørstat',),
'sørstatene': ('sørstat',),
'sørstater': ('sørstat',),
'sørtrønder': ('sørtrønder',),
'sørtrøndere': ('sørtrønder',),
'sørtrønderen': ('sørtrønder',),
'sørtrønderer': ('sørtrønder',),
'sørtrønderne': ('sørtrønder',),
'sørvegg': ('sørvegg',),
'sørveggen': ('sørvegg',),
'sørveggene': ('sørvegg',),
'sørvegger': ('sørvegg',),
'sørvest': ('sørvest',),
'sørvesten': ('sørvest',),
'sørvestene': ('sørvest',),
'sørvester': ('sørvest',),
'sørvest': ('sørvest',),
'sørvest': ('sørvest',),
'søryemenitt': ('søryemenitt',),
'søryemenitten': ('søryemenitt',),
'søryemenittene': ('søryemenitt',),
'søryemenitter': ('søryemenitt',),
'sørøst': ('sørøst',),
'sørøsten': ('sørøst',),
'sørøstene': ('sørøst',),
'sørøster': ('sørøst',),
'sørøst': ('sørøst',),
'søsken': ('søsken',),
'søskena': ('søsken',),
'søskenet': ('søsken',),
'søsknene': ('søsken',),
'søskenbarn': ('søskenbarn',),
'søskenbarna': ('søskenbarn',),
'søskenbarnene': ('søskenbarn',),
'søskenbarnet': ('søskenbarn',),
'søskenflokk': ('søskenflokk',),
'søskenflokken': ('søskenflokk',),
'søskenflokkene': ('søskenflokk',),
'søskenflokker': ('søskenflokk',),
'søster': ('søster',),
'søstera': ('søster',),
'søsteren': ('søster',),
'søstre': ('søster',),
'søstrene': ('søster',),
'søstrer': ('søster',),
'søsterdatter': ('søsterdatter',),
'søsterdattera': ('søsterdatter',),
'søsterdatteren': ('søsterdatter',),
'søsterdøtre': ('søsterdatter',),
'søsterdøtrene': ('søsterdatter',),
'søsterdøtrer': ('søsterdatter',),
'søsterheim': ('søsterheim',),
'søsterheimen': ('søsterheim',),
'søsterheimene': ('søsterheim',),
'søsterheimer': ('søsterheim',),
'søsterhjem': ('søsterhjem',),
'søsterhjemma': ('søsterhjem',),
'søsterhjemmene': ('søsterhjem',),
'søsterhjemmet': ('søsterhjem',),
'søsterselskap': ('søsterselskap',),
'søsterselskapa': ('søsterselskap',),
'søsterselskapene': ('søsterselskap',),
'søsterselskaper': ('søsterselskap',),
'søsterselskapet': ('søsterselskap',),
'søsterskip': ('søsterskip',),
'søsterskipa': ('søsterskip',),
'søsterskipene': ('søsterskip',),
'søsterskipet': ('søsterskip',),
'søstersønn': ('søstersønn',),
'søstersønnen': ('søstersønn',),
'søstersønnene': ('søstersønn',),
'søstersønner': ('søstersønn',),
'søta': ('søta',),
'søta': ('søte',),
'søte': ('søte',),
'søten': ('søte',),
'søtene': ('søte',),
'søter': ('søte',),
'søten': ('søten',),
'søterot': ('søterot',),
'søterota': ('søterot',),
'søteroten': ('søterot',),
'søterotene': ('søterot',),
'søterotfamilie': ('søterotfamilie',),
'søterotfamilien': ('søterotfamilie',),
'søterotfamiliene': ('søterotfamilie',),
'søterotfamilier': ('søterotfamilie',),
'søtgras': ('søtgras',),
'søtgrasa': ('søtgras',),
'søtgrasene': ('søtgras',),
'søtgraset': ('søtgras',),
'søtgress': ('søtgress',),
'søtgressa': ('søtgress',),
'søtgressene': ('søtgress',),
'søtgresset': ('søtgress',),
'søtingsmiddel': ('søtingsmiddel',),
'søtingsmiddelet': ('søtingsmiddel',),
'søtingsmidla': ('søtingsmiddel',),
'søtingsmidlene': ('søtingsmiddel',),
'søtingsmidler': ('søtingsmiddel',),
'søtingsmidlet': ('søtingsmiddel',),
'søtkirsebær': ('søtkirsebær',),
'søtkirsebæra': ('søtkirsebær',),
'søtkirsebærene': ('søtkirsebær',),
'søtkirsebæret': ('søtkirsebær',),
'søtmelk': ('søtmelk',),
'søtmelka': ('søtmelk',),
'søtmelken': ('søtmelk',),
'søtmelkene': ('søtmelk',),
'søtmelker': ('søtmelk',),
'søtningsmiddel': ('søtningsmiddel',),
'søtningsmiddelet': ('søtningsmiddel',),
'søtningsmidla': ('søtningsmiddel',),
'søtningsmidlene': ('søtningsmiddel',),
'søtningsmidler': ('søtningsmiddel',),
'søtningsmidlet': ('søtningsmiddel',),
'søtost': ('søtost',),
'søtosten': ('søtost',),
'søtostene': ('søtost',),
'søtoster': ('søtost',),
'søtpotet': ('søtpotet',),
'søtpoteten': ('søtpotet',),
'søtpotetene': ('søtpotet',),
'søtpoteter': ('søtpotet',),
'søtprim': ('søtprim',),
'søtprima': ('søtprim',),
'søtprimen': ('søtprim',),
'søtprimene': ('søtprim',),
'søtprimer': ('søtprim',),
'søtprimet': ('søtprim',),
'søtsakene': ('søtsaker',),
'søtsaker': ('søtsaker',),
'søtstoff': ('søtstoff',),
'søtstoffa': ('søtstoff',),
'søtstoffene': ('søtstoff',),
'søtstoffer': ('søtstoff',),
'søtstoffet': ('søtstoff',),
'søtsuppa': ('søtsuppe',),
'søtsuppe': ('søtsuppe',),
'søtsuppen': ('søtsuppe',),
'søtsuppene': ('søtsuppe',),
'søtsupper': ('søtsuppe',),
'søtvier': ('søtvier',),
'søtviere': ('søtvier',),
'søtvieren': ('søtvier',),
'søtvierer': ('søtvier',),
'søtvierne': ('søtvier',),
'søtvierfamilie': ('søtvierfamilie',),
'søtvierfamilien': ('søtvierfamilie',),
'søtvierfamiliene': ('søtvierfamilie',),
'søtvierfamilier': ('søtvierfamilie',),
'søvn': ('søvn',),
'søvnen': ('søvn',),
'søvnene': ('søvn',),
'søvner': ('søvn',),
'søvngjenger': ('søvngjenger',),
'søvngjengere': ('søvngjenger',),
'søvngjengeren': ('søvngjenger',),
'søvngjengerer': ('søvngjenger',),
'søvngjengerne': ('søvngjenger',),
'søvnløshet': ('søvnløshet',),
'søvnløsheta': ('søvnløshet',),
'søvnløsheten': ('søvnløshet',),
'søvnløshetene': ('søvnløshet',),
'søvnløsheter': ('søvnløshet',),
'søvnløysa': ('søvnløyse',),
'søvnløyse': ('søvnløyse',),
'søvnløysen': ('søvnløyse',),
'søvnløysene': ('søvnløyse',),
'søvnløyser': ('søvnløyse',),
'søya': ('søye',),
'søye': ('søye',),
'søyen': ('søye',),
'søyene': ('søye',),
'søyer': ('søye',),
'søyla': ('søyle',),
'søyle': ('søyle',),
'søylen': ('søyle',),
'søylene': ('søyle',),
'søyler': ('søyle',),
'søylediagram': ('søylediagram',),
'søylediagramma': ('søylediagram',),
'søylediagrammene': ('søylediagram',),
'søylediagrammer': ('søylediagram',),
'søylediagrammet': ('søylediagram',),
'søylehall': ('søylehall',),
'søylehallen': ('søylehall',),
'søylehallene': ('søylehall',),
'søylehaller': ('søylehall',),
'søylehelgen': ('søylehelgen',),
'søylehelgenen': ('søylehelgen',),
'søylehelgenene': ('søylehelgen',),
'søylehelgener': ('søylehelgen',),
't': ('t',),
't\'en': ('t',),
't-en': ('t',),
't-ene': ('t',),
't-er': ('t',),
'tête-à-tête': ('tête-à-tête',),
'tête-à-têten': ('tête-à-tête',),
'tête-à-têtene': ('tête-à-tête',),
'tête-à-têter': ('tête-à-tête',),
'tabasko': ('tabasko',),
'tabaskoen': ('tabasko',),
'tabaskoene': ('tabasko',),
'tabaskoer': ('tabasko',),
'tabbe': ('tabbe',),
'tabben': ('tabbe',),
'tabbene': ('tabbe',),
'tabber': ('tabbe',),
'tabbeforsikring': ('tabbeforsikring',),
'tabbeforsikringa': ('tabbeforsikring',),
'tabbeforsikringen': ('tabbeforsikring',),
'tabbeforsikringene': ('tabbeforsikring',),
'tabbeforsikringer': ('tabbeforsikring',),
'tabbekvote': ('tabbekvote',),
'tabbekvoten': ('tabbekvote',),
'tabbekvotene': ('tabbekvote',),
'tabbekvoter': ('tabbekvote',),
'tabell': ('tabell',),
'tabellen': ('tabell',),
'tabellene': ('tabell',),
'tabeller': ('tabell',),
'tabellform': ('tabellform',),
'tabellforma': ('tabellform',),
'tabellformen': ('tabellform',),
'tabellformene': ('tabellform',),
'tabellformer': ('tabellform',),
'tabellpunkt': ('tabellpunkt',),
'tabellpunkta': ('tabellpunkt',),
'tabellpunktene': ('tabellpunkt',),
'tabellpunkter': ('tabellpunkt',),
'tabellpunktet': ('tabellpunkt',),
'tabernakel': ('tabernakel',),
'tabernakelet': ('tabernakel',),
'tabernakla': ('tabernakel',),
'tabernaklene': ('tabernakel',),
'tabernakler': ('tabernakel',),
'tabernaklet': ('tabernakel',),
'tablett': ('tablett',),
'tabletten': ('tablett',),
'tablettene': ('tablett',),
'tabletter': ('tablett',),
'tablettform': ('tablettform',),
'tablettforma': ('tablettform',),
'tablettformen': ('tablettform',),
'tablettformene': ('tablettform',),
'tablettformer': ('tablettform',),
'tablettmisbruker': ('tablettmisbruker',),
'tablettmisbrukere': ('tablettmisbruker',),
'tablettmisbrukeren': ('tablettmisbruker',),
'tablettmisbrukerer': ('tablettmisbruker',),
'tablettmisbrukerne': ('tablettmisbruker',),
'tabloidavis': ('tabloidavis',),
'tabloidavisa': ('tabloidavis',),
'tabloidavisen': ('tabloidavis',),
'tabloidavisene': ('tabloidavis',),
'tabloidaviser': ('tabloidavis',),
'tabloidformat': ('tabloidformat',),
'tabloidformata': ('tabloidformat',),
'tabloidformatene': ('tabloidformat',),
'tabloidformatet': ('tabloidformat',),
'tablå': ('tablå',),
'tablåa': ('tablå',),
'tablåene': ('tablå',),
'tablåer': ('tablå',),
'tablået': ('tablå',),
'tabu': ('tabu',),
'tabua': ('tabu',),
'tabuene': ('tabu',),
'tabuer': ('tabu',),
'tabuet': ('tabu',),
'tabula': ('tabula',),
'tabulaen': ('tabula',),
'tabulaene': ('tabula',),
'tabulaer': ('tabula',),
'tabulasjon': ('tabulasjon',),
'tabulasjonen': ('tabulasjon',),
'tabulasjonene': ('tabulasjon',),
'tabulasjoner': ('tabulasjon',),
'tabulator': ('tabulator',),
'tabulatoren': ('tabulator',),
'tabulatorene': ('tabulator',),
'tabulatorer': ('tabulator',),
'tabulatur': ('tabulatur',),
'tabulaturen': ('tabulatur',),
'tabulaturene': ('tabulatur',),
'tabulaturer': ('tabulatur',),
'tabulering': ('tabulering',),
'tabuleringa': ('tabulering',),
'tabuleringen': ('tabulering',),
'tabuleringene': ('tabulering',),
'tabuleringer': ('tabulering',),
'tabuord': ('tabuord',),
'tabuorda': ('tabuord',),
'tabuordene': ('tabuord',),
'tabuordet': ('tabuord',),
'taburett': ('taburett',),
'taburetten': ('taburett',),
'taburettene': ('taburett',),
'taburetter': ('taburett',),
'tadsjik': ('tadsjik',),
'tadsjiken': ('tadsjik',),
'tadsjikene': ('tadsjik',),
'tadsjiker': ('tadsjik',),
'tadsjiker': ('tadsjiker',),
'tadsjikere': ('tadsjiker',),
'tadsjikeren': ('tadsjiker',),
'tadsjikerer': ('tadsjiker',),
'tadsjikerne': ('tadsjiker',),
'tadsjikisk': ('tadsjikisk',),
'tadsjikisken': ('tadsjikisk',),
'tadsjikiskene': ('tadsjikisk',),
'tadsjikisker': ('tadsjikisk',),
'taffel': ('taffel',),
'taffelet': ('taffel',),
'tafla': ('taffel',),
'taflene': ('taffel',),
'tafler': ('taffel',),
'taflet': ('taffel',),
'taffeland': ('taffeland',),
'taffelanda': ('taffeland',),
'taffelanden': ('taffeland',),
'taffelendene': ('taffeland',),
'taffelender': ('taffeland',),
'taffelfjell': ('taffelfjell',),
'taffelfjella': ('taffelfjell',),
'taffelfjellene': ('taffelfjell',),
'taffelfjellet': ('taffelfjell',),
'taffelmusikk': ('taffelmusikk',),
'taffelmusikken': ('taffelmusikk',),
'taffelmusikkene': ('taffelmusikk',),
'taffelmusikker': ('taffelmusikk',),
'taffelpiano': ('taffelpiano',),
'taffelpianoa': ('taffelpiano',),
'taffelpianoene': ('taffelpiano',),
'taffelpianoer': ('taffelpiano',),
'taffelpianoet': ('taffelpiano',),
'taffelstein': ('taffelstein',),
'taffelsteinen': ('taffelstein',),
'taffelsteinene': ('taffelstein',),
'taffelsteiner': ('taffelstein',),
'taffelur': ('taffelur',),
'taffelura': ('taffelur',),
'taffelurene': ('taffelur',),
'taffeluret': ('taffelur',),
'taffia': ('taffia',),
'taffiaen': ('taffia',),
'taffiaene': ('taffia',),
'taffiaer': ('taffia',),
'tafs': ('tafs',),
'tafsen': ('tafs',),
'tafsene': ('tafs',),
'tafser': ('tafs',),
'tafs': ('tafs',),
'tafsa': ('tafs',),
'tafsene': ('tafs',),
'tafset': ('tafs',),
'tafsa': ('tafse',),
'tafse': ('tafse',),
'tafsen': ('tafse',),
'tafsene': ('tafse',),
'tafser': ('tafse',),
'taft': ('taft',),
'tafta': ('taft',),
'taften': ('taft',),
'taftene': ('taft',),
'tafter': ('taft',),
'taftet': ('taft',),
'tagetes': ('tagetes',),
'tagetesen': ('tagetes',),
'tagetesene': ('tagetes',),
'tageteser': ('tagetes',),
'tagg': ('tagg',),
'taggen': ('tagg',),
'taggene': ('tagg',),
'tagger': ('tagg',),
'taggbregna': ('taggbregne',),
'taggbregne': ('taggbregne',),
'taggbregnen': ('taggbregne',),
'taggbregnene': ('taggbregne',),
'taggbregner': ('taggbregne',),
'taggmakrell': ('taggmakrell',),
'taggmakrellen': ('taggmakrell',),
'taggmakrellene': ('taggmakrell',),
'taggmakreller': ('taggmakrell',),
'tagl': ('tagl',),
'tagla': ('tagl',),
'taglene': ('tagl',),
'taglet': ('tagl',),
'tahitier': ('tahitier',),
'tahitiere': ('tahitier',),
'tahitieren': ('tahitier',),
'tahitierer': ('tahitier',),
'tahitierne': ('tahitier',),
'tai': ('tai',),
'taifun': ('taifun',),
'taifunen': ('taifun',),
'taifunene': ('taifun',),
'taifuner': ('taifun',),
'taiga': ('taiga',),
'taigaen': ('taiga',),
'taigaene': ('taiga',),
'taigaer': ('taiga',),
'taiwaner': ('taiwaner',),
'taiwanere': ('taiwaner',),
'taiwaneren': ('taiwaner',),
'taiwanerer': ('taiwaner',),
'taiwanerne': ('taiwaner',),
'taja': ('taje',),
'taje': ('taje',),
'tajene': ('taje',),
'tajer': ('taje',),
'tajet': ('taje',),
'tak': ('tak',),
'taka': ('tak',),
'takene': ('tak',),
'taket': ('tak',),
'tak': ('tak',),
'taka': ('tak',),
'takene': ('tak',),
'taket': ('tak',),
'takbjelke': ('takbjelke',),
'takbjelken': ('takbjelke',),
'takbjelkene': ('takbjelke',),
'takbjelker': ('takbjelke',),
'takdrypp': ('takdrypp',),
'takdryppa': ('takdrypp',),
'takdryppene': ('takdrypp',),
'takdryppet': ('takdrypp',),
'take-off': ('take-off',),
'take-offen': ('take-off',),
'take-offene': ('take-off',),
'take-offer': ('take-off',),
'takgrind': ('takgrind',),
'takgrinda': ('takgrind',),
'takgrinden': ('takgrind',),
'takgrindene': ('takgrind',),
'takgrinder': ('takgrind',),
'takhalm': ('takhalm',),
'takhalmen': ('takhalm',),
'takhalmene': ('takhalm',),
'takhalmer': ('takhalm',),
'takhatt': ('takhatt',),
'takhatten': ('takhatt',),
'takhattene': ('takhatt',),
'takhatter': ('takhatt',),
'takhelling': ('takhelling',),
'takhellinga': ('takhelling',),
'takhellingen': ('takhelling',),
'takhellingene': ('takhelling',),
'takhellinger': ('takhelling',),
'takhøgd': ('takhøgd',),
'takhøgda': ('takhøgd',),
'takhøgdene': ('takhøgd',),
'takhøgder': ('takhøgd',),
'takhøyde': ('takhøyde',),
'takhøyden': ('takhøyde',),
'takhøydene': ('takhøyde',),
'takhøyder': ('takhøyde',),
'takk': ('takk',),
'takken': ('takk',),
'takkene': ('takk',),
'takker': ('takk',),
'takk': ('takk',),
'takka': ('takk',),
'takken': ('takk',),
'takkene': ('takk',),
'takker': ('takk',),
'takkam': ('takkam',),
'takkammen': ('takkam',),
'takkammene': ('takkam',),
'takkammer': ('takkam',),
'takka': ('takke',),
'takke': ('takke',),
'takken': ('takke',),
'takkene': ('takke',),
'takker': ('takke',),
'takkel': ('takkel',),
'takkelet': ('takkel',),
'takla': ('takkel',),
'taklene': ('takkel',),
'takler': ('takkel',),
'taklet': ('takkel',),
'takkelasje': ('takkelasje',),
'takkelasjen': ('takkelasje',),
'takkelasjene': ('takkelasje',),
'takkelasjer': ('takkelasje',),
'takkelloft': ('takkelloft',),
'takkellofta': ('takkelloft',),
'takkelloftene': ('takkelloft',),
'takkelloftet': ('takkelloft',),
'takkevers': ('takkevers',),
'takkeversa': ('takkevers',),
'takkeversene': ('takkevers',),
'takkeverset': ('takkevers',),
'takknemlighet': ('takknemlighet',),
'takknemligheta': ('takknemlighet',),
'takknemligheten': ('takknemlighet',),
'takknemlighetene': ('takknemlighet',),
'takknemligheter': ('takknemlighet',),
'takknemlighetsgjeld': ('takknemlighetsgjeld',),
'takknemlighetsgjelda': ('takknemlighetsgjeld',),
'takknemlighetsgjelden': ('takknemlighetsgjeld',),
'takknemlighetsgjeldene': ('takknemlighetsgjeld',),
'takknemlighetsgjelder': ('takknemlighetsgjeld',),
'takkoffer': ('takkoffer',),
'takkofferet': ('takkoffer',),
'takkofra': ('takkoffer',),
'takkofre': ('takkoffer',),
'takkofrene': ('takkoffer',),
'takkonstruksjon': ('takkonstruksjon',),
'takkonstruksjonen': ('takkonstruksjon',),
'takkonstruksjonene': ('takkonstruksjon',),
'takkonstruksjoner': ('takkonstruksjon',),
'takksemd': ('takksemd',),
'takksemda': ('takksemd',),
'takksemden': ('takksemd',),
'takksemdene': ('takksemd',),
'takksemder': ('takksemd',),
'takksigelse': ('takksigelse',),
'takksigelsen': ('takksigelse',),
'takksigelsene': ('takksigelse',),
'takksigelser': ('takksigelse',),
'taklekt': ('taklekt',),
'taklekta': ('taklekt',),
'taklekten': ('taklekt',),
'taklektene': ('taklekt',),
'taklekter': ('taklekt',),
'taklekta': ('taklekte',),
'taklekte': ('taklekte',),
'taklekten': ('taklekte',),
'taklektene': ('taklekte',),
'taklekter': ('taklekte',),
'takling': ('takling',),
'taklinga': ('takling',),
'taklingen': ('takling',),
'taklingene': ('takling',),
'taklinger': ('takling',),
'taklist': ('taklist',),
'taklista': ('taklist',),
'taklisten': ('taklist',),
'taklistene': ('taklist',),
'taklister': ('taklist',),
'taklokk': ('taklokk',),
'taklokken': ('taklokk',),
'taklokkene': ('taklokk',),
'taklokker': ('taklokk',),
'takløk': ('takløk',),
'takløken': ('takløk',),
'takløkene': ('takløk',),
'takløker': ('takløk',),
'takometer': ('takometer',),
'takometeret': ('takometer',),
'takometra': ('takometer',),
'takometre': ('takometer',),
'takometrene': ('takometer',),
'takometret': ('takometer',),
'takpanna': ('takpanne',),
'takpanne': ('takpanne',),
'takpannen': ('takpanne',),
'takpannene': ('takpanne',),
'takpanner': ('takpanne',),
'takpapp': ('takpapp',),
'takpappen': ('takpapp',),
'takpappene': ('takpapp',),
'takpapper': ('takpapp',),
'takrenna': ('takrenne',),
'takrenne': ('takrenne',),
'takrennen': ('takrenne',),
'takrennene': ('takrenne',),
'takrenner': ('takrenne',),
'takrygg': ('takrygg',),
'takryggen': ('takrygg',),
'takryggene': ('takrygg',),
'takrygger': ('takrygg',),
'takrytter': ('takrytter',),
'takryttere': ('takrytter',),
'takrytteren': ('takrytter',),
'takrytterer': ('takrytter',),
'takrytterne': ('takrytter',),
'takrør': ('takrør',),
'takrøra': ('takrør',),
'takrørene': ('takrør',),
'takrøret': ('takrør',),
'taks': ('taks',),
'taksen': ('taks',),
'taksene': ('taks',),
'takser': ('taks',),
'taksameter': ('taksameter',),
'taksameteret': ('taksameter',),
'taksametra': ('taksameter',),
'taksametre': ('taksameter',),
'taksametrene': ('taksameter',),
'taksametret': ('taksameter',),
'taksasjon': ('taksasjon',),
'taksasjonen': ('taksasjon',),
'taksasjonene': ('taksasjon',),
'taksasjoner': ('taksasjon',),
'taksator': ('taksator',),
'taksatoren': ('taksator',),
'taksatorene': ('taksator',),
'taksatorer': ('taksator',),
'taksiene': ('taksis',),
'taksier': ('taksis',),
'taksis': ('taksis',),
'taksisen': ('taksis',),
'taksisene': ('taksis',),
'taksiser': ('taksis',),
'takskjegg': ('takskjegg',),
'takskjegga': ('takskjegg',),
'takskjeggene': ('takskjegg',),
'takskjegget': ('takskjegg',),
'takson': ('takson',),
'taksona': ('takson',),
'taksonene': ('takson',),
'taksoner': ('takson',),
'taksonet': ('takson',),
'taksonom': ('taksonom',),
'taksonomen': ('taksonom',),
'taksonomene': ('taksonom',),
'taksonomer': ('taksonom',),
'taksonomi': ('taksonomi',),
'taksonomien': ('taksonomi',),
'taksonomiene': ('taksonomi',),
'taksonomier': ('taksonomi',),
'taksonomiker': ('taksonomiker',),
'taksonomikere': ('taksonomiker',),
'taksonomikeren': ('taksonomiker',),
'taksonomikerer': ('taksonomiker',),
'taksonomikerne': ('taksonomiker',),
'taksperra': ('taksperre',),
'taksperre': ('taksperre',),
'taksperren': ('taksperre',),
'taksperrene': ('taksperre',),
'taksperrer': ('taksperre',),
'takst': ('takst',),
'taksten': ('takst',),
'takstene': ('takst',),
'takster': ('takst',),
'takstgrensa': ('takstgrense',),
'takstgrense': ('takstgrense',),
'takstgrensen': ('takstgrense',),
'takstgrensene': ('takstgrense',),
'takstgrenser': ('takstgrense',),
'takstmann': ('takstmann',),
'takstmannen': ('takstmann',),
'takstmenn': ('takstmann',),
'takstmennene': ('takstmann',),
'takstol': ('takstol',),
'takstolen': ('takstol',),
'takstolene': ('takstol',),
'takstoler': ('takstol',),
'takstsona': ('takstsone',),
'takstsone': ('takstsone',),
'takstsonen': ('takstsone',),
'takstsonene': ('takstsone',),
'takstsoner': ('takstsone',),
'taksvala': ('taksvale',),
'taksvale': ('taksvale',),
'taksvalen': ('taksvale',),
'taksvalene': ('taksvale',),
'taksvaler': ('taksvale',),
'taktart': ('taktart',),
'taktarta': ('taktart',),
'taktarten': ('taktart',),
'taktartene': ('taktart',),
'taktarter': ('taktart',),
'taktekker': ('taktekker',),
'taktekkere': ('taktekker',),
'taktekkeren': ('taktekker',),
'taktekkerer': ('taktekker',),
'taktekkerne': ('taktekker',),
'taktekking': ('taktekking',),
'taktekkinga': ('taktekking',),
'taktekkingen': ('taktekking',),
'taktekkingene': ('taktekking',),
'taktekkinger': ('taktekking',),
'takterrasse': ('takterrasse',),
'takterrassen': ('takterrasse',),
'takterrassene': ('takterrasse',),
'takterrasser': ('takterrasse',),
'taktfølelse': ('taktfølelse',),
'taktfølelsen': ('taktfølelse',),
'taktfølelsene': ('taktfølelse',),
'taktfølelser': ('taktfølelse',),
'taktiker': ('taktiker',),
'taktikere': ('taktiker',),
'taktikeren': ('taktiker',),
'taktikerer': ('taktiker',),
'taktikerne': ('taktiker',),
'taktikk': ('taktikk',),
'taktikken': ('taktikk',),
'taktikkene': ('taktikk',),
'taktikker': ('taktikk',),
'taktløshet': ('taktløshet',),
'taktløsheta': ('taktløshet',),
'taktløsheten': ('taktløshet',),
'taktløshetene': ('taktløshet',),
'taktløsheter': ('taktløshet',),
'taktløysa': ('taktløyse',),
'taktløyse': ('taktløyse',),
'taktløysen': ('taktløyse',),
'taktløysene': ('taktløyse',),
'taktløyser': ('taktløyse',),
'taktslag': ('taktslag',),
'taktslaga': ('taktslag',),
'taktslagene': ('taktslag',),
'taktslaget': ('taktslag',),
'taktstokk': ('taktstokk',),
'taktstokken': ('taktstokk',),
'taktstokkene': ('taktstokk',),
'taktstokker': ('taktstokk',),
'takvarme': ('takvarme',),
'takvarmen': ('takvarme',),
'takvarmene': ('takvarme',),
'takvarmer': ('takvarme',),
'takverdi': ('takverdi',),
'takverdien': ('takverdi',),
'takverdiene': ('takverdi',),
'takverdier': ('takverdi',),
'takvinkel': ('takvinkel',),
'takvinkelen': ('takvinkel',),
'takvinklene': ('takvinkel',),
'takvinkler': ('takvinkel',),
'takymeter': ('takymeter',),
'takymeteret': ('takymeter',),
'takymetra': ('takymeter',),
'takymetre': ('takymeter',),
'takymetrene': ('takymeter',),
'takymetret': ('takymeter',),
'takås': ('takås',),
'takåsen': ('takås',),
'takåsene': ('takås',),
'takåser': ('takås',),
'tal': ('tal',),
'tala': ('tal',),
'talene': ('tal',),
'talet': ('tal',),
'tal': ('tal',),
'tala': ('tal',),
'talene': ('tal',),
'talet': ('tal',),
'talatrast': ('talatrast',),
'talatrasten': ('talatrast',),
'talatrastene': ('talatrast',),
'talatraster': ('talatrast',),
'talatrost': ('talatrost',),
'talatrosten': ('talatrost',),
'talatrostene': ('talatrost',),
'talatroster': ('talatrost',),
'tale': ('tale',),
'talen': ('tale',),
'talene': ('tale',),
'taler': ('tale',),
'talefeil': ('talefeil',),
'talefeilen': ('talefeil',),
'talefeilene': ('talefeil',),
'taleflom': ('taleflom',),
'taleflommen': ('taleflom',),
'taleflommene': ('taleflom',),
'taleflommer': ('taleflom',),
'talefridom': ('talefridom',),
'talefridommen': ('talefridom',),
'talefridommene': ('talefridom',),
'talefridommer': ('talefridom',),
'talefrihet': ('talefrihet',),
'talefriheta': ('talefrihet',),
'talefriheten': ('talefrihet',),
'talefrihetene': ('talefrihet',),
'talefriheter': ('talefrihet',),
'talegava': ('talegave',),
'talegave': ('talegave',),
'talegaven': ('talegave',),
'talegavene': ('talegave',),
'talegaver': ('talegave',),
'talekor': ('talekor',),
'talekora': ('talekor',),
'talekorene': ('talekor',),
'talekoret': ('talekor',),
'talekunst': ('talekunst',),
'talekunsten': ('talekunst',),
'talekunstene': ('talekunst',),
'talekunster': ('talekunst',),
'talemål': ('talemål',),
'talemåla': ('talemål',),
'talemålene': ('talemål',),
'talemålet': ('talemål',),
'talemålsnormal': ('talemålsnormal',),
'talemålsnormalen': ('talemålsnormal',),
'talemålsnormalene': ('talemålsnormal',),
'talemålsnormaler': ('talemålsnormal',),
'talemålsnormering': ('talemålsnormering',),
'talemålsnormeringa': ('talemålsnormering',),
'talemålsnormeringen': ('talemålsnormering',),
'talemålsnormeringene': ('talemålsnormering',),
'talemålsnormeringer': ('talemålsnormering',),
'talemåte': ('talemåte',),
'talemåten': ('talemåte',),
'talemåtene': ('talemåte',),
'talemåter': ('talemåte',),
'talent': ('talent',),
'talenten': ('talent',),
'talentene': ('talent',),
'talenter': ('talent',),
'talent': ('talent',),
'talenta': ('talent',),
'talentene': ('talent',),
'talentet': ('talent',),
'talentspeider': ('talentspeider',),
'talentspeidere': ('talentspeider',),
'talentspeideren': ('talentspeider',),
'talentspeiderer': ('talentspeider',),
'talentspeiderne': ('talentspeider',),
'taleorgan': ('taleorgan',),
'taleorgana': ('taleorgan',),
'taleorganene': ('taleorgan',),
'taleorganer': ('taleorgan',),
'taleorganet': ('taleorgan',),
'talepedagog': ('talepedagog',),
'talepedagogen': ('talepedagog',),
'talepedagogene': ('talepedagog',),
'talepedagoger': ('talepedagog',),
'taler': ('taler',),
'talere': ('taler',),
'taleren': ('taler',),
'talerer': ('taler',),
'talerne': ('taler',),
'talerlista': ('talerliste',),
'talerliste': ('talerliste',),
'talerlisten': ('talerliste',),
'talerlistene': ('talerliste',),
'talerlister': ('talerliste',),
'talerstol': ('talerstol',),
'talerstolen': ('talerstol',),
'talerstolene': ('talerstol',),
'talerstoler': ('talerstol',),
'talerør': ('talerør',),
'talerøra': ('talerør',),
'talerørene': ('talerør',),
'talerøret': ('talerør',),
'talesentra': ('talesentrum',),
'talesentraene': ('talesentrum',),
'talesentre': ('talesentrum',),
'talesentrene': ('talesentrum',),
'talesentret': ('talesentrum',),
'talesentrum': ('talesentrum',),
'talesentrumet': ('talesentrum',),
'talespråk': ('talespråk',),
'talespråka': ('talespråk',),
'talespråkene': ('talespråk',),
'talespråket': ('talespråk',),
'talestrøm': ('talestrøm',),
'talestrømmen': ('talestrøm',),
'talestrømmene': ('talestrøm',),
'talestrømmer': ('talestrøm',),
'taletid': ('taletid',),
'taletida': ('taletid',),
'taletiden': ('taletid',),
'taletidene': ('taletid',),
'taletider': ('taletid',),
'talg': ('talg',),
'talga': ('talg',),
'talgen': ('talg',),
'talgene': ('talg',),
'talger': ('talg',),
'talgkjertel': ('talgkjertel',),
'talgkjertelen': ('talgkjertel',),
'talgkjertlene': ('talgkjertel',),
'talgkjertler': ('talgkjertel',),
'talgmeis': ('talgmeis',),
'talgmeisa': ('talgmeis',),
'talgmeisen': ('talgmeis',),
'talgmeisene': ('talgmeis',),
'talgmeiser': ('talgmeis',),
'talgokse': ('talgokse',),
'talgoksen': ('talgokse',),
'talgoksene': ('talgokse',),
'talgokser': ('talgokse',),
'talgsky': ('talgsky',),
'talgskya': ('talgsky',),
'talgskyen': ('talgsky',),
'talgskyene': ('talgsky',),
'talgskyer': ('talgsky',),
'talgtit': ('talgtit',),
'talgtiten': ('talgtit',),
'talgtitene': ('talgtit',),
'talgtiter': ('talgtit',),
'talgtita': ('talgtite',),
'talgtite': ('talgtite',),
'talgtiten': ('talgtite',),
'talgtitene': ('talgtite',),
'talgtiter': ('talgtite',),
'talisman': ('talisman',),
'talismanen': ('talisman',),
'talismanene': ('talisman',),
'talismaner': ('talisman',),
'talja': ('talje',),
'talje': ('talje',),
'taljen': ('talje',),
'taljene': ('talje',),
'taljer': ('talje',),
'talja': ('talje',),
'talje': ('talje',),
'taljen': ('talje',),
'taljene': ('talje',),
'taljer': ('talje',),
'talk': ('talk',),
'talken': ('talk',),
'talkene': ('talk',),
'talker': ('talk',),
'talkum': ('talkum',),
'talkumen': ('talkum',),
'talkumene': ('talkum',),
'talkumer': ('talkum',),
'tall': ('tall',),
'talla': ('tall',),
'tallene': ('tall',),
'tallet': ('tall',),
'tall': ('tall',),
'talla': ('tall',),
'tallene': ('tall',),
'tallet': ('tall',),
'tall': ('tall',),
'talla': ('tall',),
'tallen': ('tall',),
'tallene': ('tall',),
'taller': ('tall',),
'talle': ('talle',),
'tallen': ('talle',),
'tallene': ('talle',),
'taller': ('talle',),
'tallerken': ('tallerken',),
'tallerkenen': ('tallerken',),
'tallerkenene': ('tallerken',),
'tallerkener': ('tallerken',),
'tallerkendemper': ('tallerkendemper',),
'tallerkendempere': ('tallerkendemper',),
'tallerkendemperen': ('tallerkendemper',),
'tallerkendemperer': ('tallerkendemper',),
'tallerkendemperne': ('tallerkendemper',),
'tallerkenhylla': ('tallerkenhylle',),
'tallerkenhylle': ('tallerkenhylle',),
'tallerkenhyllen': ('tallerkenhylle',),
'tallerkenhyllene': ('tallerkenhylle',),
'tallerkenhyller': ('tallerkenhylle',),
'tallerkenrett': ('tallerkenrett',),
'tallerkenretten': ('tallerkenrett',),
'tallerkenrettene': ('tallerkenrett',),
'tallerkenretter': ('tallerkenrett',),
'tallerkenslikker': ('tallerkenslikker',),
'tallerkenslikkere': ('tallerkenslikker',),
'tallerkenslikkeren': ('tallerkenslikker',),
'tallerkenslikkerer': ('tallerkenslikker',),
'tallerkenslikkerne': ('tallerkenslikker',),
'tallmagi': ('tallmagi',),
'tallmagien': ('tallmagi',),
'tallmagiene': ('tallmagi',),
'tallmagier': ('tallmagi',),
'tallmagi': ('tallmagi',),
'tallmagien': ('tallmagi',),
'tallmagiene': ('tallmagi',),
'tallmagier': ('tallmagi',),
'tallmaterial': ('tallmaterial',),
'tallmateriala': ('tallmaterial',),
'tallmaterialene': ('tallmaterial',),
'tallmaterialer': ('tallmaterial',),
'tallmaterialet': ('tallmaterial',),
'tallmateriala': ('tallmateriale',),
'tallmateriale': ('tallmateriale',),
'tallmaterialene': ('tallmateriale',),
'tallmaterialer': ('tallmateriale',),
'tallmaterialet': ('tallmateriale',),
'tallord': ('tallord',),
'tallorda': ('tallord',),
'tallordene': ('tallord',),
'tallordet': ('tallord',),
'tallord': ('tallord',),
'tallorda': ('tallord',),
'tallordene': ('tallord',),
'tallordet': ('tallord',),
'tallrekka': ('tallrekke',),
'tallrekke': ('tallrekke',),
'tallrekken': ('tallrekke',),
'tallrekkene': ('tallrekke',),
'tallrekker': ('tallrekke',),
'tallrekka': ('tallrekke',),
'tallrekke': ('tallrekke',),
'tallrekken': ('tallrekke',),
'tallrekkene': ('tallrekke',),
'tallrekker': ('tallrekke',),
'tallskiva': ('tallskive',),
'tallskive': ('tallskive',),
'tallskiven': ('tallskive',),
'tallskivene': ('tallskive',),
'tallskiver': ('tallskive',),
'tallskiva': ('tallskive',),
'tallskive': ('tallskive',),
'tallskiven': ('tallskive',),
'tallskivene': ('tallskive',),
'tallskiver': ('tallskive',),
'tallsystem': ('tallsystem',),
'tallsystema': ('tallsystem',),
'tallsystemene': ('tallsystem',),
'tallsystemer': ('tallsystem',),
'tallsystemet': ('tallsystem',),
'tallsystem': ('tallsystem',),
'tallsystema': ('tallsystem',),
'tallsystemene': ('tallsystem',),
'tallsystemer': ('tallsystem',),
'tallsystemet': ('tallsystem',),
'talltegn': ('talltegn',),
'talltegna': ('talltegn',),
'talltegnene': ('talltegn',),
'talltegnet': ('talltegn',),
'talltegn': ('talltegn',),
'talltegna': ('talltegn',),
'talltegnene': ('talltegn',),
'talltegnet': ('talltegn',),
'tallunderlag': ('tallunderlag',),
'tallunderlaga': ('tallunderlag',),
'tallunderlagene': ('tallunderlag',),
'tallunderlaget': ('tallunderlag',),
'tallunderlag': ('tallunderlag',),
'tallunderlaga': ('tallunderlag',),
'tallunderlagene': ('tallunderlag',),
'tallunderlaget': ('tallunderlag',),
'tallus': ('tallus',),
'tallusa': ('tallus',),
'tallusene': ('tallus',),
'talluser': ('tallus',),
'talluset': ('tallus',),
'tallverdi': ('tallverdi',),
'tallverdien': ('tallverdi',),
'tallverdiene': ('tallverdi',),
'tallverdier': ('tallverdi',),
'tallverdi': ('tallverdi',),
'tallverdien': ('tallverdi',),
'tallverdiene': ('tallverdi',),
'tallverdier': ('tallverdi',),
'tally': ('tally',),
'tallyen': ('tally',),
'tallyene': ('tally',),
'tallyer': ('tally',),
'tallybok': ('tallybok',),
'tallyboka': ('tallybok',),
'tallyboken': ('tallybok',),
'tallybøkene': ('tallybok',),
'tallybøker': ('tallybok',),
'tallymann': ('tallymann',),
'tallymannen': ('tallymann',),
'tallymenn': ('tallymann',),
'tallymennene': ('tallymann',),
'talmagi': ('talmagi',),
'talmagien': ('talmagi',),
'talmagiene': ('talmagi',),
'talmagier': ('talmagi',),
'talmaterial': ('talmaterial',),
'talmateriala': ('talmaterial',),
'talmaterialene': ('talmaterial',),
'talmaterialer': ('talmaterial',),
'talmaterialet': ('talmaterial',),
'talmateriala': ('talmateriale',),
'talmateriale': ('talmateriale',),
'talmaterialene': ('talmateriale',),
'talmaterialer': ('talmateriale',),
'talmaterialet': ('talmateriale',),
'talmateriala': ('talmateriale',),
'talmateriale': ('talmateriale',),
'talmaterialene': ('talmateriale',),
'talmaterialer': ('talmateriale',),
'talmaterialet': ('talmateriale',),
'talmud': ('talmud',),
'talmuden': ('talmud',),
'talmudene': ('talmud',),
'talmuder': ('talmud',),
'talmudisme': ('talmudisme',),
'talmudismen': ('talmudisme',),
'talmudismene': ('talmudisme',),
'talmudismer': ('talmudisme',),
'talmudist': ('talmudist',),
'talmudisten': ('talmudist',),
'talmudistene': ('talmudist',),
'talmudister': ('talmudist',),
'talong': ('talong',),
'talongen': ('talong',),
'talongene': ('talong',),
'talonger': ('talong',),
'talord': ('talord',),
'talorda': ('talord',),
'talordene': ('talord',),
'talordet': ('talord',),
'talord': ('talord',),
'talorda': ('talord',),
'talordene': ('talord',),
'talordet': ('talord',),
'talrekka': ('talrekke',),
'talrekke': ('talrekke',),
'talrekken': ('talrekke',),
'talrekkene': ('talrekke',),
'talrekker': ('talrekke',),
'talrekka': ('talrekke',),
'talrekke': ('talrekke',),
'talrekken': ('talrekke',),
'talrekkene': ('talrekke',),
'talrekker': ('talrekke',),
'talskiva': ('talskive',),
'talskive': ('talskive',),
'talskiven': ('talskive',),
'talskivene': ('talskive',),
'talskiver': ('talskive',),
'talskiva': ('talskive',),
'talskive': ('talskive',),
'talskiven': ('talskive',),
'talskivene': ('talskive',),
'talskiver': ('talskive',),
'talskvinna': ('talskvinne',),
'talskvinne': ('talskvinne',),
'talskvinnen': ('talskvinne',),
'talskvinnene': ('talskvinne',),
'talskvinner': ('talskvinne',),
'talsmann': ('talsmann',),
'talsmannen': ('talsmann',),
'talsmenn': ('talsmann',),
'talsmennene': ('talsmann',),
'talsystem': ('talsystem',),
'talsystema': ('talsystem',),
'talsystemene': ('talsystem',),
'talsystemer': ('talsystem',),
'talsystemet': ('talsystem',),
'talsystem': ('talsystem',),
'talsystema': ('talsystem',),
'talsystemene': ('talsystem',),
'talsystemer': ('talsystem',),
'talsystemet': ('talsystem',),
'taltegn': ('taltegn',),
'taltegna': ('taltegn',),
'taltegnene': ('taltegn',),
'taltegnet': ('taltegn',),
'taltegn': ('taltegn',),
'taltegna': ('taltegn',),
'taltegnene': ('taltegn',),
'taltegnet': ('taltegn',),
'talunderlag': ('talunderlag',),
'talunderlaga': ('talunderlag',),
'talunderlagene': ('talunderlag',),
'talunderlaget': ('talunderlag',),
'talunderlag': ('talunderlag',),
'talunderlaga': ('talunderlag',),
'talunderlagene': ('talunderlag',),
'talunderlaget': ('talunderlag',),
'talverdi': ('talverdi',),
'talverdien': ('talverdi',),
'talverdiene': ('talverdi',),
'talverdier': ('talverdi',),
'talverdi': ('talverdi',),
'talverdien': ('talverdi',),
'talverdiene': ('talverdi',),
'talverdier': ('talverdi',),
'tambak': ('tambak',),
'tambaken': ('tambak',),
'tambakene': ('tambak',),
'tambaker': ('tambak',),
'tambur': ('tambur',),
'tamburen': ('tambur',),
'tamburene': ('tambur',),
'tamburer': ('tambur',),
'tamburin': ('tamburin',),
'tamburinen': ('tamburin',),
'tamburinene': ('tamburin',),
'tamburiner': ('tamburin',),
'tamburmajor': ('tamburmajor',),
'tamburmajoren': ('tamburmajor',),
'tamburmajorene': ('tamburmajor',),
'tamburmajorer': ('tamburmajor',),
'tamp': ('tamp',),
'tampen': ('tamp',),
'tampene': ('tamp',),
'tamper': ('tamp',),
'tampong': ('tampong',),
'tampongen': ('tampong',),
'tampongene': ('tampong',),
'tamponger': ('tampong',),
'tamrein': ('tamrein',),
'tamreinen': ('tamrein',),
'tamreinene': ('tamrein',),
'tamreiner': ('tamrein',),
'tamtam': ('tamtam',),
'tamtammen': ('tamtam',),
'tamtammene': ('tamtam',),
'tamtammer': ('tamtam',),
'tamtamtromma': ('tamtamtromme',),
'tamtamtromme': ('tamtamtromme',),
'tamtamtrommen': ('tamtamtromme',),
'tamtamtrommene': ('tamtamtromme',),
'tamtamtrommer': ('tamtamtromme',),
'tan': ('tan',),
'tana': ('tan',),
'tanene': ('tan',),
'tanet': ('tan',),
'tandem': ('tandem',),
'tandemen': ('tandem',),
'tandemene': ('tandem',),
'tandemer': ('tandem',),
'tandemmotor': ('tandemmotor',),
'tandemmotoren': ('tandemmotor',),
'tandemmotorene': ('tandemmotor',),
'tandemmotorer': ('tandemmotor',),
'tandemsykkel': ('tandemsykkel',),
'tandemsykkelen': ('tandemsykkel',),
'tandemsyklene': ('tandemsykkel',),
'tandemsykler': ('tandemsykkel',),
'tane': ('tane',),
'tanen': ('tane',),
'tanene': ('tane',),
'taner': ('tane',),
'tang': ('tang',),
'tanga': ('tang',),
'tangen': ('tang',),
'tangene': ('tang',),
'tanger': ('tang',),
'tanget': ('tang',),
'tang': ('tang',),
'tanga': ('tang',),
'tangen': ('tang',),
'tengene': ('tang',),
'tenger': ('tang',),
'tanga': ('tanga',),
'tangaen': ('tanga',),
'tangaene': ('tanga',),
'tangaer': ('tanga',),
'tangbrosma': ('tangbrosme',),
'tangbrosme': ('tangbrosme',),
'tangbrosmen': ('tangbrosme',),
'tangbrosmene': ('tangbrosme',),
'tangbrosmer': ('tangbrosme',),
'tange': ('tange',),
'tangen': ('tange',),
'tangene': ('tange',),
'tanger': ('tange',),
'tangens': ('tangens',),
'tangensen': ('tangens',),
'tangensene': ('tangens',),
'tangenser': ('tangens',),
'tangent': ('tangent',),
'tangenten': ('tangent',),
'tangentene': ('tangent',),
'tangenter': ('tangent',),
'tangentplan': ('tangentplan',),
'tangentplana': ('tangentplan',),
'tangentplanene': ('tangentplan',),
'tangentplanet': ('tangentplan',),
'tangerin': ('tangerin',),
'tangerinen': ('tangerin',),
'tangerinene': ('tangerin',),
'tangeriner': ('tangerin',),
'tangering': ('tangering',),
'tangeringa': ('tangering',),
'tangeringen': ('tangering',),
'tangeringene': ('tangering',),
'tangeringer': ('tangering',),
'tangforløsning': ('tangforløsning',),
'tangforløsninga': ('tangforløsning',),
'tangforløsningen': ('tangforløsning',),
'tangforløsningene': ('tangforløsning',),
'tangforløsninger': ('tangforløsning',),
'tangfødsel': ('tangfødsel',),
'tangfødselen': ('tangfødsel',),
'tangfødslene': ('tangfødsel',),
'tangfødsler': ('tangfødsel',),
'tangkvabbe': ('tangkvabbe',),
'tangkvabben': ('tangkvabbe',),
'tangkvabbene': ('tangkvabbe',),
'tangkvabber': ('tangkvabbe',),
'tangloppa': ('tangloppe',),
'tangloppe': ('tangloppe',),
'tangloppen': ('tangloppe',),
'tangloppene': ('tangloppe',),
'tanglopper': ('tangloppe',),
'tanglus': ('tanglus',),
'tanglusa': ('tanglus',),
'tanglusen': ('tanglus',),
'tanglusene': ('tanglus',),
'tangmeisel': ('tangmeisel',),
'tangmeiselen': ('tangmeisel',),
'tangmeislene': ('tangmeisel',),
'tangmeisler': ('tangmeisel',),
'tangmel': ('tangmel',),
'tangmela': ('tangmel',),
'tangmelene': ('tangmel',),
'tangmelet': ('tangmel',),
'tangmjøl': ('tangmjøl',),
'tangmjøla': ('tangmjøl',),
'tangmjølene': ('tangmjøl',),
'tangmjølet': ('tangmjøl',),
'tangnål': ('tangnål',),
'tangnåla': ('tangnål',),
'tangnålen': ('tangnål',),
'tangnålene': ('tangnål',),
'tangnåler': ('tangnål',),
'tango': ('tango',),
'tangoen': ('tango',),
'tangoene': ('tango',),
'tangoer': ('tango',),
'tangsnella': ('tangsnelle',),
'tangsnelle': ('tangsnelle',),
'tangsnellen': ('tangsnelle',),
'tangsnellene': ('tangsnelle',),
'tangsneller': ('tangsnelle',),
'tangsprell': ('tangsprell',),
'tangsprella': ('tangsprell',),
'tangsprellene': ('tangsprell',),
'tangsprellet': ('tangsprell',),
'tank': ('tank',),
'tanken': ('tank',),
'tankene': ('tank',),
'tanker': ('tank',),
'tank': ('tank',),
'tanken': ('tank',),
'tankene': ('tank',),
'tanker': ('tank',),
'tank': ('tank',),
'tanken': ('tank',),
'tankene': ('tank',),
'tanker': ('tank',),
'tankbil': ('tankbil',),
'tankbilen': ('tankbil',),
'tankbilene': ('tankbil',),
'tankbiler': ('tankbil',),
'tankbåt': ('tankbåt',),
'tankbåten': ('tankbåt',),
'tankbåtene': ('tankbåt',),
'tankbåter': ('tankbåt',),
'tankdekk': ('tankdekk',),
'tankdekka': ('tankdekk',),
'tankdekkene': ('tankdekk',),
'tankdekket': ('tankdekk',),
'tanke': ('tanke',),
'tanken': ('tanke',),
'tankene': ('tanke',),
'tanker': ('tanke',),
'tankearbeid': ('tankearbeid',),
'tankearbeida': ('tankearbeid',),
'tankearbeidene': ('tankearbeid',),
'tankearbeider': ('tankearbeid',),
'tankearbeidet': ('tankearbeid',),
'tankebane': ('tankebane',),
'tankebanen': ('tankebane',),
'tankebanene': ('tankebane',),
'tankebaner': ('tankebane',),
'tankebygning': ('tankebygning',),
'tankebygninga': ('tankebygning',),
'tankebygningen': ('tankebygning',),
'tankebygningene': ('tankebygning',),
'tankebygninger': ('tankebygning',),
'tankeeksperiment': ('tankeeksperiment',),
'tankeeksperimenta': ('tankeeksperiment',),
'tankeeksperimentene': ('tankeeksperiment',),
'tankeeksperimenter': ('tankeeksperiment',),
'tankeeksperimentet': ('tankeeksperiment',),
'tankeflukt': ('tankeflukt',),
'tankeflukta': ('tankeflukt',),
'tankeflukten': ('tankeflukt',),
'tankefluktene': ('tankeflukt',),
'tankeflukter': ('tankeflukt',),
'tankegang': ('tankegang',),
'tankegangen': ('tankegang',),
'tankegangene': ('tankegang',),
'tankeganger': ('tankegang',),
'tankegods': ('tankegods',),
'tankegodsa': ('tankegods',),
'tankegodsene': ('tankegods',),
'tankegodset': ('tankegods',),
'tankegymnastikk': ('tankegymnastikk',),
'tankegymnastikken': ('tankegymnastikk',),
'tankegymnastikkene': ('tankegymnastikk',),
'tankegymnastikker': ('tankegymnastikk',),
'tankekors': ('tankekors',),
'tankekorsa': ('tankekors',),
'tankekorsene': ('tankekors',),
'tankekorset': ('tankekors',),
'tankeleser': ('tankeleser',),
'tankelesere': ('tankeleser',),
'tankeleseren': ('tankeleser',),
'tankeleserer': ('tankeleser',),
'tankeleserne': ('tankeleser',),
'tankelesing': ('tankelesing',),
'tankelesinga': ('tankelesing',),
'tankelesingen': ('tankelesing',),
'tankelesingene': ('tankelesing',),
'tankelesinger': ('tankelesing',),
'tankelesning': ('tankelesning',),
'tankelesninga': ('tankelesning',),
'tankelesningen': ('tankelesning',),
'tankelesningene': ('tankelesning',),
'tankelesninger': ('tankelesning',),
'tankeløshet': ('tankeløshet',),
'tankeløsheta': ('tankeløshet',),
'tankeløsheten': ('tankeløshet',),
'tankeløshetene': ('tankeløshet',),
'tankeløsheter': ('tankeløshet',),
'tankeløysa': ('tankeløyse',),
'tankeløyse': ('tankeløyse',),
'tankeløysen': ('tankeløyse',),
'tankeløysene': ('tankeløyse',),
'tankeløyser': ('tankeløyse',),
'tankemodell': ('tankemodell',),
'tankemodellen': ('tankemodell',),
'tankemodellene': ('tankemodell',),
'tankemodeller': ('tankemodell',),
'tankeoverføring': ('tankeoverføring',),
'tankeoverføringa': ('tankeoverføring',),
'tankeoverføringen': ('tankeoverføring',),
'tankeoverføringene': ('tankeoverføring',),
'tankeoverføringer': ('tankeoverføring',),
'tanker': ('tanker',),
'tankere': ('tanker',),
'tankeren': ('tanker',),
'tankerer': ('tanker',),
'tankerne': ('tanker',),
'tankerekka': ('tankerekke',),
'tankerekke': ('tankerekke',),
'tankerekken': ('tankerekke',),
'tankerekkene': ('tankerekke',),
'tankerekker': ('tankerekke',),
'tankeretning': ('tankeretning',),
'tankeretninga': ('tankeretning',),
'tankeretningen': ('tankeretning',),
'tankeretningene': ('tankeretning',),
'tankeretninger': ('tankeretning',),
'tankesprang': ('tankesprang',),
'tankespranga': ('tankesprang',),
'tankesprangene': ('tankesprang',),
'tankespranget': ('tankesprang',),
'tankestiller': ('tankestiller',),
'tankestillere': ('tankestiller',),
'tankestilleren': ('tankestiller',),
'tankestillerer': ('tankestiller',),
'tankestillerne': ('tankestiller',),
'tankestrek': ('tankestrek',),
'tankestreken': ('tankestrek',),
'tankestrekene': ('tankestrek',),
'tankestreker': ('tankestrek',),
'tankevekker': ('tankevekker',),
'tankevekkere': ('tankevekker',),
'tankevekkeren': ('tankevekker',),
'tankevekkerer': ('tankevekker',),
'tankevekkerne': ('tankevekker',),
'tankeverden': ('tankeverden',),
'tankeverdenen': ('tankeverden',),
'tankeverdenene': ('tankeverden',),
'tankeverdener': ('tankeverden',),
'tankevirksomhet': ('tankevirksomhet',),
'tankevirksomheta': ('tankevirksomhet',),
'tankevirksomheten': ('tankevirksomhet',),
'tankevirksomhetene': ('tankevirksomhet',),
'tankevirksomheter': ('tankevirksomhet',),
'tankfart': ('tankfart',),
'tankfarten': ('tankfart',),
'tankfartene': ('tankfart',),
'tankfarter': ('tankfart',),
'tankfartøy': ('tankfartøy',),
'tankfartøya': ('tankfartøy',),
'tankfartøyene': ('tankfartøy',),
'tankfartøyer': ('tankfartøy',),
'tankfartøyet': ('tankfartøy',),
'tankgrav': ('tankgrav',),
'tankgrava': ('tankgrav',),
'tankgraven': ('tankgrav',),
'tankgravene': ('tankgrav',),
'tankgraver': ('tankgrav',),
'tanklokomotiv': ('tanklokomotiv',),
'tanklokomotiva': ('tanklokomotiv',),
'tanklokomotivene': ('tanklokomotiv',),
'tanklokomotiver': ('tanklokomotiv',),
'tanklokomotivet': ('tanklokomotiv',),
'tankrate': ('tankrate',),
'tankraten': ('tankrate',),
'tankratene': ('tankrate',),
'tankrater': ('tankrate',),
'tanks': ('tanks',),
'tanksen': ('tanks',),
'tanksene': ('tanks',),
'tankser': ('tanks',),
'tanks': ('tanks',),
'tanksen': ('tanks',),
'tanksene': ('tanks',),
'tankser': ('tanks',),
'tankskip': ('tankskip',),
'tankskipa': ('tankskip',),
'tankskipene': ('tankskip',),
'tankskipet': ('tankskip',),
'tanktonnasje': ('tanktonnasje',),
'tanktonnasjen': ('tanktonnasje',),
'tanktonnasjene': ('tanktonnasje',),
'tanktonnasjer': ('tanktonnasje',),
'tankvogn': ('tankvogn',),
'tankvogna': ('tankvogn',),
'tankvognen': ('tankvogn',),
'tankvognene': ('tankvogn',),
'tankvogner': ('tankvogn',),
'tann': ('tann',),
'tanna': ('tann',),
'tannen': ('tann',),
'tennene': ('tann',),
'tenner': ('tann',),
'tannbein': ('tannbein',),
'tannbeina': ('tannbein',),
'tannbeinene': ('tannbein',),
'tannbeinet': ('tannbein',),
'tannbelegg': ('tannbelegg',),
'tannbelegga': ('tannbelegg',),
'tannbeleggene': ('tannbelegg',),
'tannbelegget': ('tannbelegg',),
'tannben': ('tannben',),
'tannbena': ('tannben',),
'tannbenene': ('tannben',),
'tannbenet': ('tannben',),
'tannbyll': ('tannbyll',),
'tannbyllen': ('tannbyll',),
'tannbyllene': ('tannbyll',),
'tannbyller': ('tannbyll',),
'tannbørste': ('tannbørste',),
'tannbørsten': ('tannbørste',),
'tannbørstene': ('tannbørste',),
'tannbørster': ('tannbørste',),
'tanne': ('tanne',),
'tannen': ('tanne',),
'tannene': ('tanne',),
'tanner': ('tanne',),
'tannemalje': ('tannemalje',),
'tannemaljen': ('tannemalje',),
'tannemaljene': ('tannemalje',),
'tannemaljer': ('tannemalje',),
'tanngard': ('tanngard',),
'tanngarden': ('tanngard',),
'tanngardene': ('tanngard',),
'tanngarder': ('tanngard',),
'tannglas': ('tannglas',),
'tannglasa': ('tannglas',),
'tannglasene': ('tannglas',),
'tannglaset': ('tannglas',),
'tannglass': ('tannglass',),
'tannglassa': ('tannglass',),
'tannglassene': ('tannglass',),
'tannglasset': ('tannglass',),
'tannhals': ('tannhals',),
'tannhalsen': ('tannhals',),
'tannhalsene': ('tannhals',),
'tannhalser': ('tannhals',),
'tannhjul': ('tannhjul',),
'tannhjula': ('tannhjul',),
'tannhjulene': ('tannhjul',),
'tannhjulet': ('tannhjul',),
'tannhjulspumpa': ('tannhjulspumpe',),
'tannhjulspumpe': ('tannhjulspumpe',),
'tannhjulspumpen': ('tannhjulspumpe',),
'tannhjulspumpene': ('tannhjulspumpe',),
'tannhjulspumper': ('tannhjulspumpe',),
'tannhval': ('tannhval',),
'tannhvalen': ('tannhval',),
'tannhvalene': ('tannhval',),
'tannhvaler': ('tannhval',),
'tannin': ('tannin',),
'tannina': ('tannin',),
'tanninene': ('tannin',),
'tanninet': ('tannin',),
'tannkjøtt': ('tannkjøtt',),
'tannkjøtta': ('tannkjøtt',),
'tannkjøttene': ('tannkjøtt',),
'tannkjøttet': ('tannkjøtt',),
'tannklinikk': ('tannklinikk',),
'tannklinikken': ('tannklinikk',),
'tannklinikkene': ('tannklinikk',),
'tannklinikker': ('tannklinikk',),
'tannkrem': ('tannkrem',),
'tannkremen': ('tannkrem',),
'tannkremene': ('tannkrem',),
'tannkremer': ('tannkrem',),
'tannkval': ('tannkval',),
'tannkvalen': ('tannkval',),
'tannkvalene': ('tannkval',),
'tannkvaler': ('tannkval',),
'tannlege': ('tannlege',),
'tannlegen': ('tannlege',),
'tannlegene': ('tannlege',),
'tannleger': ('tannlege',),
'tannlegeassistent': ('tannlegeassistent',),
'tannlegeassistenten': ('tannlegeassistent',),
'tannlegeassistentene': ('tannlegeassistent',),
'tannlegeassistenter': ('tannlegeassistent',),
'tannpasta': ('tannpasta',),
'tannpastaen': ('tannpasta',),
'tannpastaene': ('tannpasta',),
'tannpastaer': ('tannpasta',),
'tannpina': ('tannpine',),
'tannpine': ('tannpine',),
'tannpinen': ('tannpine',),
'tannpinene': ('tannpine',),
'tannpiner': ('tannpine',),
'tannpirker': ('tannpirker',),
'tannpirkere': ('tannpirker',),
'tannpirkeren': ('tannpirker',),
'tannpirkerer': ('tannpirker',),
'tannpirkerne': ('tannpirker',),
'tannpleier': ('tannpleier',),
'tannpleiere': ('tannpleier',),
'tannpleieren': ('tannpleier',),
'tannpleierer': ('tannpleier',),
'tannpleierne': ('tannpleier',),
'tannregulering': ('tannregulering',),
'tannreguleringa': ('tannregulering',),
'tannreguleringen': ('tannregulering',),
'tannreguleringene': ('tannregulering',),
'tannreguleringer': ('tannregulering',),
'tannrotbetennelse': ('tannrotbetennelse',),
'tannrotbetennelsen': ('tannrotbetennelse',),
'tannrotbetennelsene': ('tannrotbetennelse',),
'tannrotbetennelser': ('tannrotbetennelse',),
'tannråte': ('tannråte',),
'tannråten': ('tannråte',),
'tannråtene': ('tannråte',),
'tannråter': ('tannråte',),
'tannrøkt': ('tannrøkt',),
'tannrøkta': ('tannrøkt',),
'tannrøkten': ('tannrøkt',),
'tannrøktene': ('tannrøkt',),
'tannrøkter': ('tannrøkt',),
'tannstang': ('tannstang',),
'tannstanga': ('tannstang',),
'tannstangen': ('tannstang',),
'tannstengene': ('tannstang',),
'tannstenger': ('tannstang',),
'tannstein': ('tannstein',),
'tannsteinen': ('tannstein',),
'tannsteinene': ('tannstein',),
'tannsteiner': ('tannstein',),
'tannstikka': ('tannstikke',),
'tannstikke': ('tannstikke',),
'tannstikken': ('tannstikke',),
'tannstikkene': ('tannstikke',),
'tannstikker': ('tannstikke',),
'tannstikker': ('tannstikker',),
'tannstikkere': ('tannstikker',),
'tannstikkeren': ('tannstikker',),
'tannstikkerer': ('tannstikker',),
'tannstikkerne': ('tannstikker',),
'tanntekniker': ('tanntekniker',),
'tannteknikere': ('tanntekniker',),
'tannteknikeren': ('tanntekniker',),
'tannteknikerer': ('tanntekniker',),
'tannteknikerne': ('tanntekniker',),
'tanntråd': ('tanntråd',),
'tanntråden': ('tanntråd',),
'tanntrådene': ('tanntråd',),
'tanntråder': ('tanntråd',),
'tannverk': ('tannverk',),
'tannverken': ('tannverk',),
'tannverkene': ('tannverk',),
'tannverker': ('tannverk',),
'tant': ('tant',),
'tanta': ('tant',),
'tanten': ('tant',),
'tantene': ('tant',),
'tanter': ('tant',),
'tantet': ('tant',),
'tantal': ('tantal',),
'tantala': ('tantal',),
'tantalene': ('tantal',),
'tantalet': ('tantal',),
'tantaluskval': ('tantaluskval',),
'tantaluskvalen': ('tantaluskval',),
'tantaluskvalene': ('tantaluskval',),
'tantaluskvaler': ('tantaluskval',),
'tanta': ('tante',),
'tante': ('tante',),
'tanten': ('tante',),
'tantene': ('tante',),
'tanter': ('tante',),
'tantetegning': ('tantetegning',),
'tantetegninga': ('tantetegning',),
'tantetegningen': ('tantetegning',),
'tantetegningene': ('tantetegning',),
'tantetegninger': ('tantetegning',),
'tantiema': ('tantieme',),
'tantieme': ('tantieme',),
'tantiemene': ('tantieme',),
'tantiemer': ('tantieme',),
'tantiemet': ('tantieme',),
'tanzanianer': ('tanzanianer',),
'tanzanianere': ('tanzanianer',),
'tanzanianeren': ('tanzanianer',),
'tanzanianerer': ('tanzanianer',),
'tanzanianerne': ('tanzanianer',),
'taoisme': ('taoisme',),
'taoismen': ('taoisme',),
'taoismene': ('taoisme',),
'taoismer': ('taoisme',),
'tap': ('tap',),
'tapa': ('tap',),
'tapene': ('tap',),
'tapet': ('tap',),
'tape': ('tape',),
'tapen': ('tape',),
'tapene': ('tape',),
'taper': ('tape',),
'taper': ('taper',),
'tapere': ('taper',),
'taperen': ('taper',),
'taperer': ('taper',),
'taperne': ('taper',),
'tapesnivå': ('tapesnivå',),
'tapesnivåa': ('tapesnivå',),
'tapesnivåene': ('tapesnivå',),
'tapesnivåer': ('tapesnivå',),
'tapesnivået': ('tapesnivå',),
'tapestid': ('tapestid',),
'tapestida': ('tapestid',),
'tapestiden': ('tapestid',),
'tapestidene': ('tapestid',),
'tapestider': ('tapestid',),
'tapet': ('tapet',),
'tapeta': ('tapet',),
'tapetene': ('tapet',),
'tapeter': ('tapet',),
'tapetet': ('tapet',),
'tapetkniv': ('tapetkniv',),
'tapetkniven': ('tapetkniv',),
'tapetknivene': ('tapetkniv',),
'tapetkniver': ('tapetkniv',),
'tapetrull': ('tapetrull',),
'tapetrullen': ('tapetrull',),
'tapetrullene': ('tapetrull',),
'tapetruller': ('tapetrull',),
'tapetserer': ('tapetserer',),
'tapetserere': ('tapetserer',),
'tapetsereren': ('tapetserer',),
'tapetsererer': ('tapetserer',),
'tapetsererne': ('tapetserer',),
'tapioka': ('tapioka',),
'tapiokaen': ('tapioka',),
'tapiokaene': ('tapioka',),
'tapiokaer': ('tapioka',),
'tapir': ('tapir',),
'tapiren': ('tapir',),
'tapirene': ('tapir',),
'tapirer': ('tapir',),
'tapisseri': ('tapisseri',),
'tapisseria': ('tapisseri',),
'tapisseriene': ('tapisseri',),
'tapisserier': ('tapisseri',),
'tapisseriet': ('tapisseri',),
'tapning': ('tapning',),
'tapninga': ('tapning',),
'tapningen': ('tapning',),
'tapningene': ('tapning',),
'tapninger': ('tapning',),
'tapp': ('tapp',),
'tappen': ('tapp',),
'tappene': ('tapp',),
'tapper': ('tapp',),
'tappenstrek': ('tappenstrek',),
'tappenstreken': ('tappenstrek',),
'tappenstrekene': ('tappenstrek',),
'tappenstreker': ('tappenstrek',),
'tapper': ('tapper',),
'tappere': ('tapper',),
'tapperen': ('tapper',),
'tapperer': ('tapper',),
'tapperne': ('tapper',),
'tapperhet': ('tapperhet',),
'tapperheta': ('tapperhet',),
'tapperheten': ('tapperhet',),
'tapperhetene': ('tapperhet',),
'tapperheter': ('tapperhet',),
'tapperi': ('tapperi',),
'tapperia': ('tapperi',),
'tapperiene': ('tapperi',),
'tapperier': ('tapperi',),
'tapperiet': ('tapperi',),
'tapping': ('tapping',),
'tappinga': ('tapping',),
'tappingen': ('tapping',),
'tappingene': ('tapping',),
'tappinger': ('tapping',),
'taps- og vinningskonti': ('taps- og vinningskonto',),
'taps- og vinningskontiene': ('taps- og vinningskonto',),
'taps- og vinningskonto': ('taps- og vinningskonto',),
'taps- og vinningskontoen': ('taps- og vinningskonto',),
'taps- og vinningskontoene': ('taps- og vinningskonto',),
'taps- og vinningskontoer': ('taps- og vinningskonto',),
'tapslista': ('tapsliste',),
'tapsliste': ('tapsliste',),
'tapslisten': ('tapsliste',),
'tapslistene': ('tapsliste',),
'tapslister': ('tapsliste',),
'tara': ('tara',),
'taraen': ('tara',),
'taraene': ('tara',),
'taraer': ('tara',),
'tarantell': ('tarantell',),
'tarantellen': ('tarantell',),
'tarantellene': ('tarantell',),
'taranteller': ('tarantell',),
'tare': ('tare',),
'taren': ('tare',),
'tarene': ('tare',),
'tarer': ('tare',),
'taretorsk': ('taretorsk',),
'taretorsken': ('taretorsk',),
'taretorskene': ('taretorsk',),
'taretorsker': ('taretorsk',),
'taretrål': ('taretrål',),
'taretrålen': ('taretrål',),
'taretrålene': ('taretrål',),
'taretråler': ('taretrål',),
'tariff': ('tariff',),
'tariffen': ('tariff',),
'tariffene': ('tariff',),
'tariffer': ('tariff',),
'tariff-forhandling': ('tariff-forhandling',),
'tariff-forhandlinga': ('tariff-forhandling',),
'tariff-forhandlingen': ('tariff-forhandling',),
'tariff-forhandlingene': ('tariff-forhandling',),
'tariff-forhandlinger': ('tariff-forhandling',),
'tariffavtale': ('tariffavtale',),
'tariffavtalen': ('tariffavtale',),
'tariffavtalene': ('tariffavtale',),
'tariffavtaler': ('tariffavtale',),
'tariffoppgjør': ('tariffoppgjør',),
'tariffoppgjøra': ('tariffoppgjør',),
'tariffoppgjørene': ('tariffoppgjør',),
'tariffoppgjøret': ('tariffoppgjør',),
'tarifforhandling': ('tarifforhandling',),
'tarifforhandlinga': ('tarifforhandling',),
'tarifforhandlingen': ('tarifforhandling',),
'tarifforhandlingene': ('tarifforhandling',),
'tarifforhandlinger': ('tarifforhandling',),
'tariffrevisjon': ('tariffrevisjon',),
'tariffrevisjonen': ('tariffrevisjon',),
'tariffrevisjonene': ('tariffrevisjon',),
'tariffrevisjoner': ('tariffrevisjon',),
'tarm': ('tarm',),
'tarmen': ('tarm',),
'tarmene': ('tarm',),
'tarmer': ('tarm',),
'tarmbakterie': ('tarmbakterie',),
'tarmbakterien': ('tarmbakterie',),
'tarmbakteriene': ('tarmbakterie',),
'tarmbakterier': ('tarmbakterie',),
'tarmkanal': ('tarmkanal',),
'tarmkanalen': ('tarmkanal',),
'tarmkanalene': ('tarmkanal',),
'tarmkanaler': ('tarmkanal',),
'tarmsaft': ('tarmsaft',),
'tarmsafta': ('tarmsaft',),
'tarmsaften': ('tarmsaft',),
'tarmsaftene': ('tarmsaft',),
'tarmsafter': ('tarmsaft',),
'tarmslyng': ('tarmslyng',),
'tarmslynga': ('tarmslyng',),
'tarmslyngen': ('tarmslyng',),
'tarmslyngene': ('tarmslyng',),
'tarmslynget': ('tarmslyng',),
'tarmtott': ('tarmtott',),
'tarmtotten': ('tarmtott',),
'tarmtottene': ('tarmtott',),
'tarmtotter': ('tarmtott',),
'tars': ('tars',),
'tarsen': ('tars',),
'tarsene': ('tars',),
'tarser': ('tars',),
'tarse': ('tarse',),
'tarsen': ('tarse',),
'tarsene': ('tarse',),
'tarser': ('tarse',),
'tart': ('tart',),
'tarten': ('tart',),
'tartene': ('tart',),
'tarter': ('tart',),
'tartan': ('tartan',),
'tartana': ('tartan',),
'tartanene': ('tartan',),
'tartanet': ('tartan',),
'tartan': ('tartan',),
'tartana': ('tartan',),
'tartanene': ('tartan',),
'tartanet': ('tartan',),
'tartandekka': ('tartandekke',),
'tartandekke': ('tartandekke',),
'tartandekkene': ('tartandekke',),
'tartandekker': ('tartandekke',),
'tartandekket': ('tartandekke',),
'tartar': ('tartar',),
'tartaren': ('tartar',),
'tartarene': ('tartar',),
'tartarer': ('tartar',),
'tartargjess': ('tartargås',),
'tartargjessene': ('tartargås',),
'tartargjæsene': ('tartargås',),
'tartargjæser': ('tartargås',),
'tartargås': ('tartargås',),
'tartargåsa': ('tartargås',),
'tartargåsen': ('tartargås',),
'tartarsmørbrød': ('tartarsmørbrød',),
'tartarsmørbrøda': ('tartarsmørbrød',),
'tartarsmørbrødene': ('tartarsmørbrød',),
'tartarsmørbrødet': ('tartarsmørbrød',),
'tarv': ('tarv',),
'tarva': ('tarv',),
'tarven': ('tarv',),
'tarvene': ('tarv',),
'tarver': ('tarv',),
'tarvet': ('tarv',),
'taska': ('taske',),
'taske': ('taske',),
'tasken': ('taske',),
'taskene': ('taske',),
'tasker': ('taske',),
'taskekrabba': ('taskekrabbe',),
'taskekrabbe': ('taskekrabbe',),
'taskekrabben': ('taskekrabbe',),
'taskekrabbene': ('taskekrabbe',),
'taskekrabber': ('taskekrabbe',),
'taskenspill': ('taskenspill',),
'taskenspilla': ('taskenspill',),
'taskenspillene': ('taskenspill',),
'taskenspillet': ('taskenspill',),
'taskenspiller': ('taskenspiller',),
'taskenspillere': ('taskenspiller',),
'taskenspilleren': ('taskenspiller',),
'taskenspillerer': ('taskenspiller',),
'taskenspillerne': ('taskenspiller',),
'taskenspilleri': ('taskenspilleri',),
'taskenspilleria': ('taskenspilleri',),
'taskenspilleriene': ('taskenspilleri',),
'taskenspillerier': ('taskenspilleri',),
'taskenspilleriet': ('taskenspilleri',),
'tasmanier': ('tasmanier',),
'tasmaniere': ('tasmanier',),
'tasmanieren': ('tasmanier',),
'tasmanierer': ('tasmanier',),
'tasmanierne': ('tasmanier',),
'tass': ('tass',),
'tassen': ('tass',),
'tassene': ('tass',),
'tasser': ('tass',),
'tast': ('tast',),
'tasten': ('tast',),
'tastene': ('tast',),
'taster': ('tast',),
'tastafon': ('tastafon',),
'tastafonen': ('tastafon',),
'tastafonene': ('tastafon',),
'tastafoner': ('tastafon',),
'tastatur': ('tastatur',),
'tastatura': ('tastatur',),
'tastaturene': ('tastatur',),
'tastaturer': ('tastatur',),
'tastaturet': ('tastatur',),
'tastbord': ('tastbord',),
'tastborda': ('tastbord',),
'tastbordene': ('tastbord',),
'tastborder': ('tastbord',),
'tastbordet': ('tastbord',),
'tatar': ('tatar',),
'tataren': ('tatar',),
'tatarene': ('tatar',),
'tatarer': ('tatar',),
'tatargjess': ('tatargås',),
'tatargjessene': ('tatargås',),
'tatargjæsene': ('tatargås',),
'tatargjæser': ('tatargås',),
'tatargås': ('tatargås',),
'tatargåsa': ('tatargås',),
'tatargåsen': ('tatargås',),
'tatarsmørbrød': ('tatarsmørbrød',),
'tatarsmørbrøda': ('tatarsmørbrød',),
'tatarsmørbrødene': ('tatarsmørbrød',),
'tatarsmørbrødet': ('tatarsmørbrød',),
'tater': ('tater',),
'tatere': ('tater',),
'tateren': ('tater',),
'taterer': ('tater',),
'taterne': ('tater',),
'taterspråk': ('taterspråk',),
'taterspråka': ('taterspråk',),
'taterspråkene': ('taterspråk',),
'taterspråket': ('taterspråk',),
'tatoverer': ('tatoverer',),
'tatoverere': ('tatoverer',),
'tatovereren': ('tatoverer',),
'tatovererer': ('tatoverer',),
'tatovererne': ('tatoverer',),
'tatovering': ('tatovering',),
'tatoveringa': ('tatovering',),
'tatoveringen': ('tatovering',),
'tatoveringene': ('tatovering',),
'tatoveringer': ('tatovering',),
'tau': ('tau',),
'taua': ('tau',),
'tauene': ('tau',),
'tauet': ('tau',),
'taubane': ('taubane',),
'taubanen': ('taubane',),
'taubanene': ('taubane',),
'taubaner': ('taubane',),
'taubåt': ('taubåt',),
'taubåten': ('taubåt',),
'taubåtene': ('taubåt',),
'taubåter': ('taubåt',),
'taus': ('taus',),
'tausa': ('taus',),
'tausen': ('taus',),
'tausene': ('taus',),
'tauser': ('taus',),
'taushet': ('taushet',),
'tausheta': ('taushet',),
'tausheten': ('taushet',),
'taushetene': ('taushet',),
'tausheter': ('taushet',),
'taushetsløfta': ('taushetsløfte',),
'taushetsløfte': ('taushetsløfte',),
'taushetsløftene': ('taushetsløfte',),
'taushetsløfter': ('taushetsløfte',),
'taushetsløftet': ('taushetsløfte',),
'taushetsplikt': ('taushetsplikt',),
'taushetsplikta': ('taushetsplikt',),
'taushetsplikten': ('taushetsplikt',),
'taushetspliktene': ('taushetsplikt',),
'taushetsplikter': ('taushetsplikt',),
'taustige': ('taustige',),
'taustigen': ('taustige',),
'taustigene': ('taustige',),
'taustiger': ('taustige',),
'taustump': ('taustump',),
'taustumpen': ('taustump',),
'taustumpene': ('taustump',),
'taustumper': ('taustump',),
'tautologi': ('tautologi',),
'tautologien': ('tautologi',),
'tautologiene': ('tautologi',),
'tautologier': ('tautologi',),
'tautrekking': ('tautrekking',),
'tautrekkinga': ('tautrekking',),
'tautrekkingen': ('tautrekking',),
'tautrekkingene': ('tautrekking',),
'tautrekkinger': ('tautrekking',),
'tauverk': ('tauverk',),
'tauverka': ('tauverk',),
'tauverkene': ('tauverk',),
'tauverker': ('tauverk',),
'tauverket': ('tauverk',),
'tave': ('tave',),
'taven': ('tave',),
'tavene': ('tave',),
'taver': ('tave',),
'tavern': ('tavern',),
'tavernen': ('tavern',),
'tavernene': ('tavern',),
'taverner': ('tavern',),
'taverna': ('taverna',),
'tavernaen': ('taverna',),
'tavernaene': ('taverna',),
'tavernaer': ('taverna',),
'tavl': ('tavl',),
'tavla': ('tavl',),
'tavlene': ('tavl',),
'tavlet': ('tavl',),
'tavla': ('tavle',),
'tavle': ('tavle',),
'tavlen': ('tavle',),
'tavlene': ('tavle',),
'tavler': ('tavle',),
'taxi': ('taxi',),
'taxien': ('taxi',),
'taxiene': ('taxi',),
'taxier': ('taxi',),
'taxibåt': ('taxibåt',),
'taxibåten': ('taxibåt',),
'taxibåtene': ('taxibåt',),
'taxibåter': ('taxibåt',),
'taxifly': ('taxifly',),
'taxiflya': ('taxifly',),
'taxiflyene': ('taxifly',),
'taxiflyet': ('taxifly',),
'tbc-vaksina': ('tbc-vaksine',),
'tbc-vaksine': ('tbc-vaksine',),
'tbc-vaksinen': ('tbc-vaksine',),
'tbc-vaksinene': ('tbc-vaksine',),
'tbc-vaksiner': ('tbc-vaksine',),
'tchader': ('tchader',),
'tchadere': ('tchader',),
'tchaderen': ('tchader',),
'tchaderer': ('tchader',),
'tchaderne': ('tchader',),
'te': ('te',),
'teen': ('te',),
'teene': ('te',),
'teer': ('te',),
'teak': ('teak',),
'teaken': ('teak',),
'teakene': ('teak',),
'teaker': ('teak',),
'team': ('team',),
'teama': ('team',),
'teamene': ('team',),
'teamet': ('team',),
'teamarbeid': ('teamarbeid',),
'teamarbeida': ('teamarbeid',),
'teamarbeidene': ('teamarbeid',),
'teamarbeider': ('teamarbeid',),
'teamarbeidet': ('teamarbeid',),
'teamwork': ('teamwork',),
'teater': ('teater',),
'teateret': ('teater',),
'teatra': ('teater',),
'teatre': ('teater',),
'teatrene': ('teater',),
'teatret': ('teater',),
'teatergjenger': ('teatergjenger',),
'teatergjengere': ('teatergjenger',),
'teatergjengeren': ('teatergjenger',),
'teatergjengerer': ('teatergjenger',),
'teatergjengerne': ('teatergjenger',),
'teatersesong': ('teatersesong',),
'teatersesongen': ('teatersesong',),
'teatersesongene': ('teatersesong',),
'teatersesonger': ('teatersesong',),
'teatersport': ('teatersport',),
'teatersporten': ('teatersport',),
'teatersportene': ('teatersport',),
'teatersporter': ('teatersport',),
'teaterstykka': ('teaterstykke',),
'teaterstykke': ('teaterstykke',),
'teaterstykkene': ('teaterstykke',),
'teaterstykker': ('teaterstykke',),
'teaterstykket': ('teaterstykke',),
'teblad': ('teblad',),
'teblada': ('teblad',),
'tebladene': ('teblad',),
'teblader': ('teblad',),
'tebladet': ('teblad',),
'tebord': ('tebord',),
'teborda': ('tebord',),
'tebordene': ('tebord',),
'teborder': ('tebord',),
'tebordet': ('tebord',),
'tebrød': ('tebrød',),
'tebrøda': ('tebrød',),
'tebrødene': ('tebrød',),
'tebrødet': ('tebrød',),
'tebusk': ('tebusk',),
'tebusken': ('tebusk',),
'tebuskene': ('tebusk',),
'tebusker': ('tebusk',),
'technetium': ('technetium',),
'technetiuma': ('technetium',),
'technetiumene': ('technetium',),
'technetiumet': ('technetium',),
'teddy': ('teddy',),
'teddyen': ('teddy',),
'teddyene': ('teddy',),
'teddyer': ('teddy',),
'teddybjørn': ('teddybjørn',),
'teddybjørnen': ('teddybjørn',),
'teddybjørnene': ('teddybjørn',),
'teddybjørner': ('teddybjørn',),
'tedeum': ('tedeum',),
'tedeuma': ('tedeum',),
'tedeumene': ('tedeum',),
'tedeumet': ('tedeum',),
'tee': ('tee',),
'tee-en': ('tee',),
'tee-ene': ('tee',),
'tee-er': ('tee',),
'teenager': ('teenager',),
'teenagere': ('teenager',),
'teenageren': ('teenager',),
'teenagerer': ('teenager',),
'teenagerne': ('teenager',),
'tefat': ('tefat',),
'tefata': ('tefat',),
'tefatene': ('tefat',),
'tefater': ('tefat',),
'tefatet': ('tefat',),
'teflon': ('teflon',),
'teflona': ('teflon',),
'teflonene': ('teflon',),
'teflonet': ('teflon',),
'teft': ('teft',),
'teften': ('teft',),
'teftene': ('teft',),
'tefter': ('teft',),
'tega': ('tege',),
'tege': ('tege',),
'tegen': ('tege',),
'tegene': ('tege',),
'teger': ('tege',),
'tegl': ('tegl',),
'tegla': ('tegl',),
'teglene': ('tegl',),
'teglet': ('tegl',),
'teglstein': ('teglstein',),
'teglsteinen': ('teglstein',),
'teglsteinene': ('teglstein',),
'teglsteiner': ('teglstein',),
'teglverk': ('teglverk',),
'teglverka': ('teglverk',),
'teglverkene': ('teglverk',),
'teglverker': ('teglverk',),
'teglverket': ('teglverk',),
'tegn': ('tegn',),
'tegna': ('tegn',),
'tegnene': ('tegn',),
'tegnet': ('tegn',),
'tegnebestikk': ('tegnebestikk',),
'tegnebestikka': ('tegnebestikk',),
'tegnebestikkene': ('tegnebestikk',),
'tegnebestikket': ('tegnebestikk',),
'tegnebord': ('tegnebord',),
'tegneborda': ('tegnebord',),
'tegnebordene': ('tegnebord',),
'tegneborder': ('tegnebord',),
'tegnebordet': ('tegnebord',),
'tegnebrett': ('tegnebrett',),
'tegnebretta': ('tegnebrett',),
'tegnebrettene': ('tegnebrett',),
'tegnebretter': ('tegnebrett',),
'tegnebrettet': ('tegnebrett',),
'tegnefilm': ('tegnefilm',),
'tegnefilmen': ('tegnefilm',),
'tegnefilmene': ('tegnefilm',),
'tegnefilmer': ('tegnefilm',),
'tegnekontor': ('tegnekontor',),
'tegnekontora': ('tegnekontor',),
'tegnekontorene': ('tegnekontor',),
'tegnekontorer': ('tegnekontor',),
'tegnekontoret': ('tegnekontor',),
'tegner': ('tegner',),
'tegnere': ('tegner',),
'tegneren': ('tegner',),
'tegnerer': ('tegner',),
'tegnerne': ('tegner',),
'tegnesal': ('tegnesal',),
'tegnesalen': ('tegnesal',),
'tegnesalene': ('tegnesal',),
'tegnesaler': ('tegnesal',),
'tegneserie': ('tegneserie',),
'tegneserien': ('tegneserie',),
'tegneseriene': ('tegneserie',),
'tegneserier': ('tegneserie',),
'tegnestift': ('tegnestift',),
'tegnestiften': ('tegnestift',),
'tegnestiftene': ('tegnestift',),
'tegnestifter': ('tegnestift',),
'tegnforklaring': ('tegnforklaring',),
'tegnforklaringa': ('tegnforklaring',),
'tegnforklaringen': ('tegnforklaring',),
'tegnforklaringene': ('tegnforklaring',),
'tegnforklaringer': ('tegnforklaring',),
'tegning': ('tegning',),
'tegninga': ('tegning',),
'tegningen': ('tegning',),
'tegningene': ('tegning',),
'tegninger': ('tegning',),
'tegning': ('tegning',),
'tegninga': ('tegning',),
'tegningen': ('tegning',),
'tegningene': ('tegning',),
'tegninger': ('tegning',),
'tegningformat': ('tegningformat',),
'tegningformata': ('tegningformat',),
'tegningformatene': ('tegningformat',),
'tegningformater': ('tegningformat',),
'tegningformatet': ('tegningformat',),
'tegningkopi': ('tegningkopi',),
'tegningkopien': ('tegningkopi',),
'tegningkopiene': ('tegningkopi',),
'tegningkopier': ('tegningkopi',),
'tegningsfrist': ('tegningsfrist',),
'tegningsfristen': ('tegningsfrist',),
'tegningsfristene': ('tegningsfrist',),
'tegningsfrister': ('tegningsfrist',),
'tegningslista': ('tegningsliste',),
'tegningsliste': ('tegningsliste',),
'tegningslisten': ('tegningsliste',),
'tegningslistene': ('tegningsliste',),
'tegningslister': ('tegningsliste',),
'tegningsrett': ('tegningsrett',),
'tegningsretten': ('tegningsrett',),
'tegningsrettene': ('tegningsrett',),
'tegningsretter': ('tegningsrett',),
'tegnruta': ('tegnrute',),
'tegnrute': ('tegnrute',),
'tegnruten': ('tegnrute',),
'tegnrutene': ('tegnrute',),
'tegnruter': ('tegnrute',),
'tegnsetning': ('tegnsetning',),
'tegnsetninga': ('tegnsetning',),
'tegnsetningen': ('tegnsetning',),
'tegnsetningene': ('tegnsetning',),
'tegnsetninger': ('tegnsetning',),
'tegnsetting': ('tegnsetting',),
'tegnsettinga': ('tegnsetting',),
'tegnsettingen': ('tegnsetting',),
'tegnsettingene': ('tegnsetting',),
'tegnsettinger': ('tegnsetting',),
'tegnspråk': ('tegnspråk',),
'tegnspråka': ('tegnspråk',),
'tegnspråkene': ('tegnspråk',),
'tegnspråket': ('tegnspråk',),
'teiebær': ('teiebær',),
'teiebæra': ('teiebær',),
'teiebærene': ('teiebær',),
'teiebæret': ('teiebær',),
'teiebær': ('teiebær',),
'teiebæra': ('teiebær',),
'teiebærene': ('teiebær',),
'teiebæret': ('teiebær',),
'teig': ('teig',),
'teigen': ('teig',),
'teigene': ('teig',),
'teiger': ('teig',),
'teigblanding': ('teigblanding',),
'teigblandinga': ('teigblanding',),
'teigblandingen': ('teigblanding',),
'teigblandingene': ('teigblanding',),
'teigblandinger': ('teigblanding',),
'teiggrøft': ('teiggrøft',),
'teiggrøfta': ('teiggrøft',),
'teiggrøften': ('teiggrøft',),
'teiggrøftene': ('teiggrøft',),
'teiggrøfter': ('teiggrøft',),
'teighogst': ('teighogst',),
'teighogsten': ('teighogst',),
'teighogstene': ('teighogst',),
'teighogster': ('teighogst',),
'teighugst': ('teighugst',),
'teighugsten': ('teighugst',),
'teighugstene': ('teighugst',),
'teighugster': ('teighugst',),
'teigplog': ('teigplog',),
'teigplogen': ('teigplog',),
'teigplogene': ('teigplog',),
'teigploger': ('teigplog',),
'tein': ('tein',),
'teinen': ('tein',),
'teinene': ('tein',),
'teiner': ('tein',),
'tein': ('tein',),
'teina': ('tein',),
'teinen': ('tein',),
'teinene': ('tein',),
'teiner': ('tein',),
'teinet': ('tein',),
'teina': ('teine',),
'teine': ('teine',),
'teinen': ('teine',),
'teinene': ('teine',),
'teiner': ('teine',),
'teinekalv': ('teinekalv',),
'teinekalven': ('teinekalv',),
'teinekalvene': ('teinekalv',),
'teinekalver': ('teinekalv',),
'teinelag': ('teinelag',),
'teinelaga': ('teinelag',),
'teinelagene': ('teinelag',),
'teinelaget': ('teinelag',),
'teint': ('teint',),
'teinten': ('teint',),
'teintene': ('teint',),
'teinter': ('teint',),
'teinung': ('teinung',),
'teinungen': ('teinung',),
'teinungene': ('teinung',),
'teinunger': ('teinung',),
'teip': ('teip',),
'teipen': ('teip',),
'teipene': ('teip',),
'teiper': ('teip',),
'teisme': ('teisme',),
'teismen': ('teisme',),
'teismene': ('teisme',),
'teismer': ('teisme',),
'teist': ('teist',),
'teisten': ('teist',),
'teistene': ('teist',),
'teister': ('teist',),
'teist': ('teist',),
'teisten': ('teist',),
'teistene': ('teist',),
'teister': ('teist',),
'teiste': ('teiste',),
'teisten': ('teiste',),
'teistene': ('teiste',),
'teister': ('teiste',),
'teiting': ('teiting',),
'teitingen': ('teiting',),
'teitingene': ('teiting',),
'teitinger': ('teiting',),
'tek': ('tek',),
'teken': ('tek',),
'tekene': ('tek',),
'teker': ('tek',),
'tekjøkken': ('tekjøkken',),
'tekjøkkena': ('tekjøkken',),
'tekjøkkenene': ('tekjøkken',),
'tekjøkkener': ('tekjøkken',),
'tekjøkkenet': ('tekjøkken',),
'tekka': ('tekke',),
'tekke': ('tekke',),
'tekken': ('tekke',),
'tekkene': ('tekke',),
'tekker': ('tekke',),
'tekker': ('tekker',),
'tekkere': ('tekker',),
'tekkeren': ('tekker',),
'tekkerer': ('tekker',),
'tekkerne': ('tekker',),
'tekniker': ('tekniker',),
'teknikere': ('tekniker',),
'teknikeren': ('tekniker',),
'teknikerer': ('tekniker',),
'teknikerne': ('tekniker',),
'teknikk': ('teknikk',),
'teknikken': ('teknikk',),
'teknikkene': ('teknikk',),
'teknikker': ('teknikk',),
'teknokrat': ('teknokrat',),
'teknokraten': ('teknokrat',),
'teknokratene': ('teknokrat',),
'teknokrater': ('teknokrat',),
'teknokrati': ('teknokrati',),
'teknokratia': ('teknokrati',),
'teknokratiene': ('teknokrati',),
'teknokratier': ('teknokrati',),
'teknokratiet': ('teknokrati',),
'teknolog': ('teknolog',),
'teknologen': ('teknolog',),
'teknologene': ('teknolog',),
'teknologer': ('teknolog',),
'teknologi': ('teknologi',),
'teknologien': ('teknologi',),
'teknologiene': ('teknologi',),
'teknologier': ('teknologi',),
'tekoindustri': ('tekoindustri',),
'tekoindustrien': ('tekoindustri',),
'tekoindustriene': ('tekoindustri',),
'tekoindustrier': ('tekoindustri',),
'tekst': ('tekst',),
'teksta': ('tekst',),
'teksten': ('tekst',),
'tekstene': ('tekst',),
'tekster': ('tekst',),
'tekst-TV': ('tekst-TV',),
'tekst-TVen': ('tekst-TV',),
'tekst-TVene': ('tekst-TV',),
'tekst-TVer': ('tekst-TV',),
'tekst-tv': ('tekst-tv',),
'tekst-tven': ('tekst-tv',),
'tekst-tvene': ('tekst-tv',),
'tekst-tver': ('tekst-tv',),
'tekstanalysa': ('tekstanalyse',),
'tekstanalyse': ('tekstanalyse',),
'tekstanalysen': ('tekstanalyse',),
'tekstanalysene': ('tekstanalyse',),
'tekstanalyser': ('tekstanalyse',),
'tekstbehandling': ('tekstbehandling',),
'tekstbehandlinga': ('tekstbehandling',),
'tekstbehandlingen': ('tekstbehandling',),
'tekstbehandlingene': ('tekstbehandling',),
'tekstbehandlinger': ('tekstbehandling',),
'tekstbehandlingsmaskin': ('tekstbehandlingsmaskin',),
'tekstbehandlingsmaskina': ('tekstbehandlingsmaskin',),
'tekstbehandlingsmaskinen': ('tekstbehandlingsmaskin',),
'tekstbehandlingsmaskinene': ('tekstbehandlingsmaskin',),
'tekstbehandlingsmaskiner': ('tekstbehandlingsmaskin',),
'tekstforfatter': ('tekstforfatter',),
'tekstforfattere': ('tekstforfatter',),
'tekstforfatteren': ('tekstforfatter',),
'tekstforfatterer': ('tekstforfatter',),
'tekstforfatterne': ('tekstforfatter',),
'tekstil': ('tekstil',),
'tekstila': ('tekstil',),
'tekstilen': ('tekstil',),
'tekstilene': ('tekstil',),
'tekstiler': ('tekstil',),
'tekstilet': ('tekstil',),
'tekstilarbeider': ('tekstilarbeider',),
'tekstilarbeidere': ('tekstilarbeider',),
'tekstilarbeideren': ('tekstilarbeider',),
'tekstilarbeiderer': ('tekstilarbeider',),
'tekstilarbeiderne': ('tekstilarbeider',),
'tekstilfiber': ('tekstilfiber',),
'tekstilfibere': ('tekstilfiber',),
'tekstilfiberen': ('tekstilfiber',),
'tekstilfiberer': ('tekstilfiber',),
'tekstilfiberne': ('tekstilfiber',),
'tekstilfibre': ('tekstilfiber',),
'tekstilfibrene': ('tekstilfiber',),
'tekstilfibrer': ('tekstilfiber',),
'tekstilforming': ('tekstilforming',),
'tekstilforminga': ('tekstilforming',),
'tekstilformingen': ('tekstilforming',),
'tekstilformingene': ('tekstilforming',),
'tekstilforminger': ('tekstilforming',),
'tekstilindustri': ('tekstilindustri',),
'tekstilindustrien': ('tekstilindustri',),
'tekstilindustriene': ('tekstilindustri',),
'tekstilindustrier': ('tekstilindustri',),
'tekstilkunst': ('tekstilkunst',),
'tekstilkunsten': ('tekstilkunst',),
'tekstilkunstene': ('tekstilkunst',),
'tekstilkunster': ('tekstilkunst',),
'tekstkritikk': ('tekstkritikk',),
'tekstkritikken': ('tekstkritikk',),
'tekstkritikkene': ('tekstkritikk',),
'tekstkritikker': ('tekstkritikk',),
'tekstrekka': ('tekstrekke',),
'tekstrekke': ('tekstrekke',),
'tekstrekken': ('tekstrekke',),
'tekstrekkene': ('tekstrekke',),
'tekstrekker': ('tekstrekke',),
'tekstreklame': ('tekstreklame',),
'tekstreklamen': ('tekstreklame',),
'tekstreklamene': ('tekstreklame',),
'tekstreklamer': ('tekstreklame',),
'teksttelefon': ('teksttelefon',),
'teksttelefonen': ('teksttelefon',),
'teksttelefonene': ('teksttelefon',),
'teksttelefoner': ('teksttelefon',),
'tekstur': ('tekstur',),
'teksturen': ('tekstur',),
'teksturene': ('tekstur',),
'teksturer': ('tekstur',),
'tektonikk': ('tektonikk',),
'tektonikken': ('tektonikk',),
'tektonikkene': ('tektonikk',),
'tektonikker': ('tektonikk',),
'tel': ('tel',),
'tela': ('tel',),
'telene': ('tel',),
'telet': ('tel',),
'teledøl': ('teledøl',),
'teledølen': ('teledøl',),
'teledølene': ('teledøl',),
'teledøler': ('teledøl',),
'telefaks': ('telefaks',),
'telefaksen': ('telefaks',),
'telefaksene': ('telefaks',),
'telefakser': ('telefaks',),
'telefon': ('telefon',),
'telefonen': ('telefon',),
'telefonene': ('telefon',),
'telefoner': ('telefon',),
'telefonabonnent': ('telefonabonnent',),
'telefonabonnenten': ('telefonabonnent',),
'telefonabonnentene': ('telefonabonnent',),
'telefonabonnenter': ('telefonabonnent',),
'telefonannonsa': ('telefonannonse',),
'telefonannonse': ('telefonannonse',),
'telefonannonsen': ('telefonannonse',),
'telefonannonsene': ('telefonannonse',),
'telefonannonser': ('telefonannonse',),
'telefonavis': ('telefonavis',),
'telefonavisa': ('telefonavis',),
'telefonavisen': ('telefonavis',),
'telefonavisene': ('telefonavis',),
'telefonaviser': ('telefonavis',),
'telefonavlytting': ('telefonavlytting',),
'telefonavlyttinga': ('telefonavlytting',),
'telefonavlyttingen': ('telefonavlytting',),
'telefonavlyttingene': ('telefonavlytting',),
'telefonavlyttinger': ('telefonavlytting',),
'telefonboks': ('telefonboks',),
'telefonboksen': ('telefonboks',),
'telefonboksene': ('telefonboks',),
'telefonbokser': ('telefonboks',),
'telefonforsterker': ('telefonforsterker',),
'telefonforsterkere': ('telefonforsterker',),
'telefonforsterkeren': ('telefonforsterker',),
'telefonforsterkerer': ('telefonforsterker',),
'telefonforsterkerne': ('telefonforsterker',),
'telefoni': ('telefoni',),
'telefonien': ('telefoni',),
'telefoniene': ('telefoni',),
'telefonier': ('telefoni',),
'telefonkatalog': ('telefonkatalog',),
'telefonkatalogen': ('telefonkatalog',),
'telefonkatalogene': ('telefonkatalog',),
'telefonkataloger': ('telefonkatalog',),
'telefonkiosk': ('telefonkiosk',),
'telefonkiosken': ('telefonkiosk',),
'telefonkioskene': ('telefonkiosk',),
'telefonkiosker': ('telefonkiosk',),
'telefonkø': ('telefonkø',),
'telefonkøen': ('telefonkø',),
'telefonkøene': ('telefonkø',),
'telefonkøer': ('telefonkø',),
'telefonlinja': ('telefonlinje',),
'telefonlinje': ('telefonlinje',),
'telefonlinjen': ('telefonlinje',),
'telefonlinjene': ('telefonlinje',),
'telefonlinjer': ('telefonlinje',),
'telefonnummer': ('telefonnummer',),
'telefonnummeret': ('telefonnummer',),
'telefonnumra': ('telefonnummer',),
'telefonnumre': ('telefonnummer',),
'telefonnumrene': ('telefonnummer',),
'telefonregning': ('telefonregning',),
'telefonregninga': ('telefonregning',),
'telefonregningen': ('telefonregning',),
'telefonregningene': ('telefonregning',),
'telefonregninger': ('telefonregning',),
'telefonrekning': ('telefonrekning',),
'telefonrekninga': ('telefonrekning',),
'telefonrekningen': ('telefonrekning',),
'telefonrekningene': ('telefonrekning',),
'telefonrekninger': ('telefonrekning',),
'telefonrør': ('telefonrør',),
'telefonrøra': ('telefonrør',),
'telefonrørene': ('telefonrør',),
'telefonrøret': ('telefonrør',),
'telefonsentral': ('telefonsentral',),
'telefonsentralen': ('telefonsentral',),
'telefonsentralene': ('telefonsentral',),
'telefonsentraler': ('telefonsentral',),
'telefonskrekk': ('telefonskrekk',),
'telefonskrekken': ('telefonskrekk',),
'telefonskrekkene': ('telefonskrekk',),
'telefonskrekker': ('telefonskrekk',),
'telefonstolpe': ('telefonstolpe',),
'telefonstolpen': ('telefonstolpe',),
'telefonstolpene': ('telefonstolpe',),
'telefonstolper': ('telefonstolpe',),
'telefonsvarer': ('telefonsvarer',),
'telefonsvarere': ('telefonsvarer',),
'telefonsvareren': ('telefonsvarer',),
'telefonsvarerer': ('telefonsvarer',),
'telefonsvarerne': ('telefonsvarer',),
'telefontang': ('telefontang',),
'telefontanga': ('telefontang',),
'telefontangen': ('telefontang',),
'telefontengene': ('telefontang',),
'telefontenger': ('telefontang',),
'telefonterror': ('telefonterror',),
'telefonterroren': ('telefonterror',),
'telefonterrorene': ('telefonterror',),
'telefonterrorer': ('telefonterror',),
'telefontråd': ('telefontråd',),
'telefontråden': ('telefontråd',),
'telefontrådene': ('telefontråd',),
'telefontråder': ('telefontråd',),
'telefonur': ('telefonur',),
'telefonura': ('telefonur',),
'telefonurene': ('telefonur',),
'telefonuret': ('telefonur',),
'telefonvakt': ('telefonvakt',),
'telefonvakta': ('telefonvakt',),
'telefonvakten': ('telefonvakt',),
'telefonvaktene': ('telefonvakt',),
'telefonvakter': ('telefonvakt',),
'telefonveksler': ('telefonveksler',),
'telefonvekslere': ('telefonveksler',),
'telefonveksleren': ('telefonveksler',),
'telefonvekslerer': ('telefonveksler',),
'telefonvekslerne': ('telefonveksler',),
'telefoto': ('telefoto',),
'telefotoa': ('telefoto',),
'telefotoene': ('telefoto',),
'telefotoer': ('telefoto',),
'telefotoet': ('telefoto',),
'telegraf': ('telegraf',),
'telegrafen': ('telegraf',),
'telegrafene': ('telegraf',),
'telegrafer': ('telegraf',),
'telegrafalfabet': ('telegrafalfabet',),
'telegrafalfabeta': ('telegrafalfabet',),
'telegrafalfabetene': ('telegrafalfabet',),
'telegrafalfabeter': ('telegrafalfabet',),
'telegrafalfabetet': ('telegrafalfabet',),
'telegrafi': ('telegrafi',),
'telegrafien': ('telegrafi',),
'telegrafiene': ('telegrafi',),
'telegrafier': ('telegrafi',),
'telegrafist': ('telegrafist',),
'telegrafisten': ('telegrafist',),
'telegrafistene': ('telegrafist',),
'telegrafister': ('telegrafist',),
'telegrafnøkkel': ('telegrafnøkkel',),
'telegrafnøkkelen': ('telegrafnøkkel',),
'telegrafnøklene': ('telegrafnøkkel',),
'telegrafnøkler': ('telegrafnøkkel',),
'telegrafstolpe': ('telegrafstolpe',),
'telegrafstolpen': ('telegrafstolpe',),
'telegrafstolpene': ('telegrafstolpe',),
'telegrafstolper': ('telegrafstolpe',),
'telegram': ('telegram',),
'telegramma': ('telegram',),
'telegrammene': ('telegram',),
'telegrammer': ('telegram',),
'telegrammet': ('telegram',),
'telegramadressa': ('telegramadresse',),
'telegramadresse': ('telegramadresse',),
'telegramadressen': ('telegramadresse',),
'telegramadressene': ('telegramadresse',),
'telegramadresser': ('telegramadresse',),
'telegramblankett': ('telegramblankett',),
'telegramblanketten': ('telegramblankett',),
'telegramblankettene': ('telegramblankett',),
'telegramblanketter': ('telegramblankett',),
'telegrambyrå': ('telegrambyrå',),
'telegrambyråa': ('telegrambyrå',),
'telegrambyråene': ('telegrambyrå',),
'telegrambyråer': ('telegrambyrå',),
'telegrambyrået': ('telegrambyrå',),
'telegramstil': ('telegramstil',),
'telegramstilen': ('telegramstil',),
'telegramstilene': ('telegramstil',),
'telegramstiler': ('telegramstil',),
'telehiv': ('telehiv',),
'telehiva': ('telehiv',),
'telehiven': ('telehiv',),
'telehivene': ('telehiv',),
'telehiver': ('telehiv',),
'telehivet': ('telehiv',),
'telehivhiving': ('telehivhiving',),
'telehivhivinga': ('telehivhiving',),
'telehivhivingen': ('telehivhiving',),
'telehivhivingene': ('telehivhiving',),
'telehivhivinger': ('telehivhiving',),
'telehivhivning': ('telehivhivning',),
'telehivhivninga': ('telehivhivning',),
'telehivhivningen': ('telehivhivning',),
'telehivhivningene': ('telehivhivning',),
'telehivhivninger': ('telehivhivning',),
'telekinese': ('telekinese',),
'telekinesen': ('telekinese',),
'telekinesene': ('telekinese',),
'telekineser': ('telekinese',),
'telekommunikasjon': ('telekommunikasjon',),
'telekommunikasjonen': ('telekommunikasjon',),
'telekommunikasjonene': ('telekommunikasjon',),
'telekommunikasjoner': ('telekommunikasjon',),
'telekommunikasjonsmiddel': ('telekommunikasjonsmiddel',),
'telekommunikasjonsmiddelet': ('telekommunikasjonsmiddel',),
'telekommunikasjonsmidla': ('telekommunikasjonsmiddel',),
'telekommunikasjonsmidlene': ('telekommunikasjonsmiddel',),
'telekommunikasjonsmidler': ('telekommunikasjonsmiddel',),
'telekommunikasjonsmidlet': ('telekommunikasjonsmiddel',),
'telekommunikasjonsnett': ('telekommunikasjonsnett',),
'telekommunikasjonsnetta': ('telekommunikasjonsnett',),
'telekommunikasjonsnettene': ('telekommunikasjonsnett',),
'telekommunikasjonsnettet': ('telekommunikasjonsnett',),
'teleks': ('teleks',),
'teleksen': ('teleks',),
'teleksene': ('teleks',),
'telekser': ('teleks',),
'teleksabonnent': ('teleksabonnent',),
'teleksabonnenten': ('teleksabonnent',),
'teleksabonnentene': ('teleksabonnent',),
'teleksabonnenter': ('teleksabonnent',),
'teleksapparat': ('teleksapparat',),
'teleksapparata': ('teleksapparat',),
'teleksapparatene': ('teleksapparat',),
'teleksapparater': ('teleksapparat',),
'teleksapparatet': ('teleksapparat',),
'teleksoperatør': ('teleksoperatør',),
'teleksoperatøren': ('teleksoperatør',),
'teleksoperatørene': ('teleksoperatør',),
'teleksoperatører': ('teleksoperatør',),
'telelinsa': ('telelinse',),
'telelinse': ('telelinse',),
'telelinsen': ('telelinse',),
'telelinsene': ('telelinse',),
'telelinser': ('telelinse',),
'telelinsa': ('telelinse',),
'telelinse': ('telelinse',),
'telelinsen': ('telelinse',),
'telelinsene': ('telelinse',),
'telelinser': ('telelinse',),
'teleløsning': ('teleløsning',),
'teleløsninga': ('teleløsning',),
'teleløsningen': ('teleløsning',),
'teleløsningene': ('teleløsning',),
'teleløsninger': ('teleløsning',),
'teleløysing': ('teleløysing',),
'teleløysinga': ('teleløysing',),
'teleløysingen': ('teleløysing',),
'teleløysingene': ('teleløysing',),
'teleløysinger': ('teleløysing',),
'telemarking': ('telemarking',),
'telemarkingen': ('telemarking',),
'telemarkingene': ('telemarking',),
'telemarkinger': ('telemarking',),
'telemarksfe': ('telemarksfe',),
'telemarksfea': ('telemarksfe',),
'telemarksfeene': ('telemarksfe',),
'telemarksfeet': ('telemarksfe',),
'telemarkssving': ('telemarkssving',),
'telemarkssvingen': ('telemarkssving',),
'telemarkssvingene': ('telemarkssving',),
'telemarkssvinger': ('telemarkssving',),
'telematikk': ('telematikk',),
'telematikken': ('telematikk',),
'telematikkene': ('telematikk',),
'telematikker': ('telematikk',),
'telemeter': ('telemeter',),
'telemeteret': ('telemeter',),
'telemetra': ('telemeter',),
'telemetre': ('telemeter',),
'telemetrene': ('telemeter',),
'telemetret': ('telemeter',),
'telemetrering': ('telemetrering',),
'telemetreringa': ('telemetrering',),
'telemetreringen': ('telemetrering',),
'telemetreringene': ('telemetrering',),
'telemetreringer': ('telemetrering',),
'telemetri': ('telemetri',),
'telemetrien': ('telemetri',),
'telemetriene': ('telemetri',),
'telemetrier': ('telemetri',),
'telenett': ('telenett',),
'telenetta': ('telenett',),
'telenettene': ('telenett',),
'telenettet': ('telenett',),
'teleobjektiv': ('teleobjektiv',),
'teleobjektiva': ('teleobjektiv',),
'teleobjektivene': ('teleobjektiv',),
'teleobjektiver': ('teleobjektiv',),
'teleobjektivet': ('teleobjektiv',),
'teleologi': ('teleologi',),
'teleologien': ('teleologi',),
'teleologiene': ('teleologi',),
'teleologier': ('teleologi',),
'telepati': ('telepati',),
'telepatien': ('telepati',),
'telepatiene': ('telepati',),
'telepatier': ('telepati',),
'teleplasma': ('teleplasma',),
'teleplasmaene': ('teleplasma',),
'teleplasmaer': ('teleplasma',),
'teleplasmaet': ('teleplasma',),
'teleprinter': ('teleprinter',),
'teleprintere': ('teleprinter',),
'teleprinteren': ('teleprinter',),
'teleprinterer': ('teleprinter',),
'teleprinterne': ('teleprinter',),
'telesamband': ('telesamband',),
'telesambanda': ('telesamband',),
'telesambandene': ('telesamband',),
'telesambandet': ('telesamband',),
'telesatellitt': ('telesatellitt',),
'telesatellitten': ('telesatellitt',),
'telesatellittene': ('telesatellitt',),
'telesatellitter': ('telesatellitt',),
'teleskop': ('teleskop',),
'teleskopa': ('teleskop',),
'teleskopene': ('teleskop',),
'teleskoper': ('teleskop',),
'teleskopet': ('teleskop',),
'teleskopantenna': ('teleskopantenne',),
'teleskopantenne': ('teleskopantenne',),
'teleskopantennen': ('teleskopantenne',),
'teleskopantennene': ('teleskopantenne',),
'teleskopantenner': ('teleskopantenne',),
'teleskopfiskestang': ('teleskopfiskestang',),
'teleskopfiskestanga': ('teleskopfiskestang',),
'teleskopfiskestangen': ('teleskopfiskestang',),
'teleskopfiskestengene': ('teleskopfiskestang',),
'teleskopfiskestenger': ('teleskopfiskestang',),
'teleskopord': ('teleskopord',),
'teleskoporda': ('teleskopord',),
'teleskopordene': ('teleskopord',),
'teleskopordet': ('teleskopord',),
'teleskopøya': ('teleskopøye',),
'teleskopøye': ('teleskopøye',),
'teleskopøyene': ('teleskopøye',),
'teleskopøyer': ('teleskopøye',),
'teleskopøyet': ('teleskopøye',),
'teleskopøyne': ('teleskopøye',),
'teleskopøynene': ('teleskopøye',),
'teleskott': ('teleskott',),
'teleskotta': ('teleskott',),
'teleskottene': ('teleskott',),
'teleskottet': ('teleskott',),
'teleslynga': ('teleslynge',),
'teleslynge': ('teleslynge',),
'teleslyngen': ('teleslynge',),
'teleslyngene': ('teleslynge',),
'teleslynger': ('teleslynge',),
'telespole': ('telespole',),
'telespolen': ('telespole',),
'telespolene': ('telespole',),
'telespoler': ('telespole',),
'telestesi': ('telestesi',),
'telestesien': ('telestesi',),
'telestesiene': ('telestesi',),
'telestesier': ('telestesi',),
'teleteknikk': ('teleteknikk',),
'teleteknikken': ('teleteknikk',),
'teleteknikkene': ('teleteknikk',),
'teleteknikker': ('teleteknikk',),
'teleteks': ('teleteks',),
'teleteksen': ('teleteks',),
'teleteksene': ('teleteks',),
'teletekser': ('teleteks',),
'teletype': ('teletype',),
'teletypen': ('teletype',),
'teletypene': ('teletype',),
'teletyper': ('teletype',),
'teletypeoperatør': ('teletypeoperatør',),
'teletypeoperatøren': ('teletypeoperatør',),
'teletypeoperatørene': ('teletypeoperatør',),
'teletypeoperatører': ('teletypeoperatør',),
'televerk': ('televerk',),
'televerka': ('televerk',),
'televerkene': ('televerk',),
'televerker': ('televerk',),
'televerket': ('televerk',),
'televisjon': ('televisjon',),
'televisjonen': ('televisjon',),
'televisjonene': ('televisjon',),
'televisjoner': ('televisjon',),
'telg': ('telg',),
'telgen': ('telg',),
'telgene': ('telg',),
'telger': ('telg',),
'telging': ('telging',),
'telginga': ('telging',),
'telgingen': ('telging',),
'telgingene': ('telging',),
'telginger': ('telging',),
'telgjekniv': ('telgjekniv',),
'telgjekniven': ('telgjekniv',),
'telgjeknivene': ('telgjekniv',),
'telgjekniver': ('telgjekniv',),
'telleapparat': ('telleapparat',),
'telleapparata': ('telleapparat',),
'telleapparatene': ('telleapparat',),
'telleapparater': ('telleapparat',),
'telleapparatet': ('telleapparat',),
'tellekorps': ('tellekorps',),
'tellekorpsa': ('tellekorps',),
'tellekorpsene': ('tellekorps',),
'tellekorpset': ('tellekorps',),
'tellepengene': ('tellepenger',),
'tellepenger': ('tellepenger',),
'teller': ('teller',),
'tellere': ('teller',),
'telleren': ('teller',),
'tellerer': ('teller',),
'tellerne': ('teller',),
'tellerskritt': ('tellerskritt',),
'tellerskritta': ('tellerskritt',),
'tellerskrittene': ('tellerskritt',),
'tellerskrittet': ('tellerskritt',),
'tellerør': ('tellerør',),
'tellerøra': ('tellerør',),
'tellerørene': ('tellerør',),
'tellerøret': ('tellerør',),
'telleverk': ('telleverk',),
'telleverka': ('telleverk',),
'telleverkene': ('telleverk',),
'telleverker': ('telleverk',),
'telleverket': ('telleverk',),
'telling': ('telling',),
'tellinga': ('telling',),
'tellingen': ('telling',),
'tellingene': ('telling',),
'tellinger': ('telling',),
'tellur': ('tellur',),
'tellura': ('tellur',),
'tellurene': ('tellur',),
'telluret': ('tellur',),
'telluria': ('tellurium',),
'telluriene': ('tellurium',),
'tellurier': ('tellurium',),
'telluriet': ('tellurium',),
'tellurium': ('tellurium',),
'telna': ('telne',),
'telne': ('telne',),
'telnen': ('telne',),
'telnene': ('telne',),
'telner': ('telne',),
'telt': ('telt',),
'telta': ('telt',),
'teltene': ('telt',),
'telter': ('telt',),
'teltet': ('telt',),
'teltduk': ('teltduk',),
'teltduken': ('teltduk',),
'teltdukene': ('teltduk',),
'teltduker': ('teltduk',),
'telthus': ('telthus',),
'telthusa': ('telthus',),
'telthusene': ('telthus',),
'telthuset': ('telthus',),
'teltknapp': ('teltknapp',),
'teltknappen': ('teltknapp',),
'teltknappene': ('teltknapp',),
'teltknapper': ('teltknapp',),
'teltplugg': ('teltplugg',),
'teltpluggen': ('teltplugg',),
'teltpluggene': ('teltplugg',),
'teltplugger': ('teltplugg',),
'teltslåing': ('teltslåing',),
'teltslåinga': ('teltslåing',),
'teltslåingen': ('teltslåing',),
'teltslåingene': ('teltslåing',),
'teltslåinger': ('teltslåing',),
'teltstang': ('teltstang',),
'teltstanga': ('teltstang',),
'teltstangen': ('teltstang',),
'teltstengene': ('teltstang',),
'teltstenger': ('teltstang',),
'telttur': ('telttur',),
'teltturen': ('telttur',),
'teltturene': ('telttur',),
'teltturer': ('telttur',),
'teltvogn': ('teltvogn',),
'teltvogna': ('teltvogn',),
'teltvognen': ('teltvogn',),
'teltvognene': ('teltvogn',),
'teltvogner': ('teltvogn',),
'tema': ('tema',),
'temaene': ('tema',),
'temaer': ('tema',),
'temaet': ('tema',),
'temahefta': ('temahefte',),
'temahefte': ('temahefte',),
'temaheftene': ('temahefte',),
'temahefter': ('temahefte',),
'temaheftet': ('temahefte',),
'temakveld': ('temakveld',),
'temakvelden': ('temakveld',),
'temakveldene': ('temakveld',),
'temakvelder': ('temakveld',),
'temaskin': ('temaskin',),
'temaskina': ('temaskin',),
'temaskinen': ('temaskin',),
'temaskinene': ('temaskin',),
'temaskiner': ('temaskin',),
'tematikk': ('tematikk',),
'tematikken': ('tematikk',),
'tematikkene': ('tematikk',),
'tematikker': ('tematikk',),
'temmer': ('temmer',),
'temmere': ('temmer',),
'temmeren': ('temmer',),
'temmerer': ('temmer',),
'temmerne': ('temmer',),
'temp': ('temp',),
'tempen': ('temp',),
'tempene': ('temp',),
'temper': ('temp',),
'tempel': ('tempel',),
'tempelet': ('tempel',),
'templa': ('tempel',),
'templene': ('tempel',),
'templer': ('tempel',),
'templet': ('tempel',),
'tempelherre': ('tempelherre',),
'tempelherren': ('tempelherre',),
'tempelherrene': ('tempelherre',),
'tempelherrer': ('tempelherre',),
'tempelherreorden': ('tempelherreorden',),
'tempelherreordenen': ('tempelherreorden',),
'tempelherreordenene': ('tempelherreorden',),
'tempelherreordener': ('tempelherreorden',),
'tempera': ('tempera',),
'temperament': ('temperament',),
'temperamenta': ('temperament',),
'temperamentene': ('temperament',),
'temperamenter': ('temperament',),
'temperamentet': ('temperament',),
'temperatur': ('temperatur',),
'temperaturen': ('temperatur',),
'temperaturene': ('temperatur',),
'temperaturer': ('temperatur',),
'tempi': ('tempo',),
'tempiene': ('tempo',),
'tempo': ('tempo',),
'tempoa': ('tempo',),
'tempoene': ('tempo',),
'tempoer': ('tempo',),
'tempoet': ('tempo',),
'tempoplan': ('tempoplan',),
'tempoplanen': ('tempoplan',),
'tempoplanene': ('tempoplan',),
'tempoplaner': ('tempoplan',),
'temporitt': ('temporitt',),
'temporitta': ('temporitt',),
'temporittene': ('temporitt',),
'temporittet': ('temporitt',),
'tempotrening': ('tempotrening',),
'tempotreninga': ('tempotrening',),
'tempotreningen': ('tempotrening',),
'tempotreningene': ('tempotrening',),
'tempotreninger': ('tempotrening',),
'tempora': ('tempus',),
'temporaene': ('tempus',),
'tempus': ('tempus',),
'tempusa': ('tempus',),
'tempusene': ('tempus',),
'tempuset': ('tempus',),
'tenar': ('tenar',),
'tenaren': ('tenar',),
'tenarene': ('tenar',),
'tenarer': ('tenar',),
'tendens': ('tendens',),
'tendensen': ('tendens',),
'tendensene': ('tendens',),
'tendenser': ('tendens',),
'tendensdikting': ('tendensdikting',),
'tendensdiktinga': ('tendensdikting',),
'tendensdiktingen': ('tendensdikting',),
'tendensdiktingene': ('tendensdikting',),
'tendensdiktinger': ('tendensdikting',),
'tendensdiktning': ('tendensdiktning',),
'tendensdiktninga': ('tendensdiktning',),
'tendensdiktningen': ('tendensdiktning',),
'tendensdiktningene': ('tendensdiktning',),
'tendensdiktninger': ('tendensdiktning',),
'tendenslitteratur': ('tendenslitteratur',),
'tendenslitteraturen': ('tendenslitteratur',),
'tendenslitteraturene': ('tendenslitteratur',),
'tendenslitteraturer': ('tendenslitteratur',),
'tendenstrekning': ('tendenstrekning',),
'tendenstrekninga': ('tendenstrekning',),
'tendenstrekningen': ('tendenstrekning',),
'tendenstrekningene': ('tendenstrekning',),
'tendenstrekninger': ('tendenstrekning',),
'tender': ('tender',),
'tendere': ('tender',),
'tenderen': ('tender',),
'tenderer': ('tender',),
'tenderne': ('tender',),
'tenkeboks': ('tenkeboks',),
'tenkeboksen': ('tenkeboks',),
'tenkeboksene': ('tenkeboks',),
'tenkebokser': ('tenkeboks',),
'tenkeevna': ('tenkeevne',),
'tenkeevne': ('tenkeevne',),
'tenkeevnen': ('tenkeevne',),
'tenkeevnene': ('tenkeevne',),
'tenkeevner': ('tenkeevne',),
'tenkemåte': ('tenkemåte',),
'tenkemåten': ('tenkemåte',),
'tenkemåtene': ('tenkemåte',),
'tenkemåter': ('tenkemåte',),
'tenkepause': ('tenkepause',),
'tenkepausen': ('tenkepause',),
'tenkepausene': ('tenkepause',),
'tenkepauser': ('tenkepause',),
'tenkeplata': ('tenkeplate',),
'tenkeplate': ('tenkeplate',),
'tenkeplaten': ('tenkeplate',),
'tenkeplatene': ('tenkeplate',),
'tenkeplater': ('tenkeplate',),
'tenker': ('tenker',),
'tenkere': ('tenker',),
'tenkeren': ('tenker',),
'tenkerer': ('tenker',),
'tenkerne': ('tenker',),
'tenkning': ('tenkning',),
'tenkninga': ('tenkning',),
'tenkningen': ('tenkning',),
'tenkningene': ('tenkning',),
'tenkninger': ('tenkning',),
'tenksomhet': ('tenksomhet',),
'tenksomheta': ('tenksomhet',),
'tenksomheten': ('tenksomhet',),
'tenksomhetene': ('tenksomhet',),
'tenksomheter': ('tenksomhet',),
'tennar': ('tennar',),
'tennaren': ('tennar',),
'tennarene': ('tennar',),
'tennarer': ('tennar',),
'tenner': ('tenner',),
'tennere': ('tenner',),
'tenneren': ('tenner',),
'tennerer': ('tenner',),
'tennerne': ('tenner',),
'tenning': ('tenning',),
'tenninga': ('tenning',),
'tenningen': ('tenning',),
'tenningene': ('tenning',),
'tenninger': ('tenning',),
'tenningsnøkkel': ('tenningsnøkkel',),
'tenningsnøkkelen': ('tenningsnøkkel',),
'tenningsnøklene': ('tenningsnøkkel',),
'tenningsnøkler': ('tenningsnøkkel',),
'tennis': ('tennis',),
'tennisen': ('tennis',),
'tennisene': ('tennis',),
'tenniser': ('tennis',),
'tennisarm': ('tennisarm',),
'tennisarmen': ('tennisarm',),
'tennisarmene': ('tennisarm',),
'tennisarmer': ('tennisarm',),
'tennisball': ('tennisball',),
'tennisballen': ('tennisball',),
'tennisballene': ('tennisball',),
'tennisballer': ('tennisball',),
'tennisbane': ('tennisbane',),
'tennisbanen': ('tennisbane',),
'tennisbanene': ('tennisbane',),
'tennisbaner': ('tennisbane',),
'tennismatch': ('tennismatch',),
'tennismatchen': ('tennismatch',),
'tennismatchene': ('tennismatch',),
'tennismatcher': ('tennismatch',),
'tennisracket': ('tennisracket',),
'tennisracketen': ('tennisracket',),
'tennisracketene': ('tennisracket',),
'tennisracketer': ('tennisracket',),
'tennisspeller': ('tennisspeller',),
'tennisspellere': ('tennisspeller',),
'tennisspelleren': ('tennisspeller',),
'tennisspellerer': ('tennisspeller',),
'tennisspellerne': ('tennisspeller',),
'tennisspiller': ('tennisspiller',),
'tennisspillere': ('tennisspiller',),
'tennisspilleren': ('tennisspiller',),
'tennisspillerer': ('tennisspiller',),
'tennisspillerne': ('tennisspiller',),
'tennmekanisme': ('tennmekanisme',),
'tennmekanismen': ('tennmekanisme',),
'tennmekanismene': ('tennmekanisme',),
'tennmekanismer': ('tennmekanisme',),
'tennmiddel': ('tennmiddel',),
'tennmiddelet': ('tennmiddel',),
'tennmidla': ('tennmiddel',),
'tennmidlene': ('tennmiddel',),
'tennmidler': ('tennmiddel',),
'tennmidlet': ('tennmiddel',),
'tennplugg': ('tennplugg',),
'tennpluggen': ('tennplugg',),
'tennpluggene': ('tennplugg',),
'tennplugger': ('tennplugg',),
'tennsats': ('tennsats',),
'tennsatsen': ('tennsats',),
'tennsatsene': ('tennsats',),
'tennsatser': ('tennsats',),
'tennvæska': ('tennvæske',),
'tennvæske': ('tennvæske',),
'tennvæsken': ('tennvæske',),
'tennvæskene': ('tennvæske',),
'tennvæsker': ('tennvæske',),
'tenor': ('tenor',),
'tenoren': ('tenor',),
'tenorene': ('tenor',),
'tenorer': ('tenor',),
'tensid': ('tensid',),
'tensida': ('tensid',),
'tensidene': ('tensid',),
'tensider': ('tensid',),
'tensidet': ('tensid',),
'tensjon': ('tensjon',),
'tensjonen': ('tensjon',),
'tensjonene': ('tensjon',),
'tensjoner': ('tensjon',),
'tentakel': ('tentakel',),
'tentakelen': ('tentakel',),
'tentaklene': ('tentakel',),
'tentakler': ('tentakel',),
'tentamen': ('tentamen',),
'tentamenen': ('tentamen',),
'tentamenene': ('tentamen',),
'tentamener': ('tentamen',),
'tenår': ('tenår',),
'tenåra': ('tenår',),
'tenårene': ('tenår',),
'tenåret': ('tenår',),
'tenåring': ('tenåring',),
'tenåringen': ('tenåring',),
'tenåringene': ('tenåring',),
'tenåringer': ('tenåring',),
'tenåringsekteskap': ('tenåringsekteskap',),
'tenåringsekteskapa': ('tenåringsekteskap',),
'tenåringsekteskapene': ('tenåringsekteskap',),
'tenåringsekteskaper': ('tenåringsekteskap',),
'tenåringsekteskapet': ('tenåringsekteskap',),
'tenåringsforeldre': ('tenåringsforeldre',),
'tenåringsforeldrene': ('tenåringsforeldre',),
'teodiceen': ('teodicé',),
'teodiceene': ('teodicé',),
'teodiceer': ('teodicé',),
'teodicé': ('teodicé',),
'teodicéen': ('teodicé',),
'teodicéene': ('teodicé',),
'teodicéer': ('teodicé',),
'teodolitt': ('teodolitt',),
'teodolitten': ('teodolitt',),
'teodolittene': ('teodolitt',),
'teodolitter': ('teodolitt',),
'teokrat': ('teokrat',),
'teokraten': ('teokrat',),
'teokratene': ('teokrat',),
'teokrater': ('teokrat',),
'teokrati': ('teokrati',),
'teokratia': ('teokrati',),
'teokratiene': ('teokrati',),
'teokratier': ('teokrati',),
'teokratiet': ('teokrati',),
'teolog': ('teolog',),
'teologen': ('teolog',),
'teologene': ('teolog',),
'teologer': ('teolog',),
'teologi': ('teologi',),
'teologien': ('teologi',),
'teologiene': ('teologi',),
'teologier': ('teologi',),
'teorem': ('teorem',),
'teorema': ('teorem',),
'teoremene': ('teorem',),
'teoremer': ('teorem',),
'teoremet': ('teorem',),
'teoretiker': ('teoretiker',),
'teoretikere': ('teoretiker',),
'teoretikeren': ('teoretiker',),
'teoretikerer': ('teoretiker',),
'teoretikerne': ('teoretiker',),
'teori': ('teori',),
'teorien': ('teori',),
'teoriene': ('teori',),
'teorier': ('teori',),
'teosof': ('teosof',),
'teosofen': ('teosof',),
'teosofene': ('teosof',),
'teosofer': ('teosof',),
'teosofi': ('teosofi',),
'teosofien': ('teosofi',),
'teosofiene': ('teosofi',),
'teosofier': ('teosofi',),
'tepose': ('tepose',),
'teposen': ('tepose',),
'teposene': ('tepose',),
'teposer': ('tepose',),
'teppa': ('teppe',),
'teppe': ('teppe',),
'teppene': ('teppe',),
'tepper': ('teppe',),
'teppet': ('teppe',),
'teppebanker': ('teppebanker',),
'teppebankere': ('teppebanker',),
'teppebankeren': ('teppebanker',),
'teppebankerer': ('teppebanker',),
'teppebankerne': ('teppebanker',),
'teppefall': ('teppefall',),
'teppefalla': ('teppefall',),
'teppefallene': ('teppefall',),
'teppefallet': ('teppefall',),
'teppeflis': ('teppeflis',),
'teppeflisa': ('teppeflis',),
'teppeflisen': ('teppeflis',),
'teppeflisene': ('teppeflis',),
'teppefliser': ('teppeflis',),
'teppelegger': ('teppelegger',),
'teppeleggere': ('teppelegger',),
'teppeleggeren': ('teppelegger',),
'teppeleggerer': ('teppelegger',),
'teppeleggerne': ('teppelegger',),
'tepperot': ('tepperot',),
'tepperota': ('tepperot',),
'tepperoten': ('tepperot',),
'tepperotene': ('tepperot',),
'tequila': ('tequila',),
'tequilaen': ('tequila',),
'tequilaene': ('tequila',),
'tequilaer': ('tequila',),
'terapeut': ('terapeut',),
'terapeuten': ('terapeut',),
'terapeutene': ('terapeut',),
'terapeuter': ('terapeut',),
'terapi': ('terapi',),
'terapien': ('terapi',),
'terapiene': ('terapi',),
'terapier': ('terapi',),
'terawatt': ('terawatt',),
'terawatten': ('terawatt',),
'terawattene': ('terawatt',),
'terbium': ('terbium',),
'terbiuma': ('terbium',),
'terbiumene': ('terbium',),
'terbiumet': ('terbium',),
'term': ('term',),
'termen': ('term',),
'termene': ('term',),
'termer': ('term',),
'termalkilde': ('termalkilde',),
'termalkilden': ('termalkilde',),
'termalkildene': ('termalkilde',),
'termalkilder': ('termalkilde',),
'termalkjelda': ('termalkjelde',),
'termalkjelde': ('termalkjelde',),
'termalkjelden': ('termalkjelde',),
'termalkjeldene': ('termalkjelde',),
'termalkjelder': ('termalkjelde',),
'terme': ('terme',),
'termen': ('terme',),
'termene': ('terme',),
'termer': ('terme',),
'termin': ('termin',),
'terminen': ('termin',),
'terminene': ('termin',),
'terminer': ('termin',),
'terminal': ('terminal',),
'terminalen': ('terminal',),
'terminalene': ('terminal',),
'terminaler': ('terminal',),
'terminlista': ('terminliste',),
'terminliste': ('terminliste',),
'terminlisten': ('terminliste',),
'terminlistene': ('terminliste',),
'terminlister': ('terminliste',),
'terminologi': ('terminologi',),
'terminologien': ('terminologi',),
'terminologiene': ('terminologi',),
'terminologier': ('terminologi',),
'termini': ('terminus',),
'terminiene': ('terminus',),
'terminus': ('terminus',),
'terminusen': ('terminus',),
'termitt': ('termitt',),
'termitten': ('termitt',),
'termittene': ('termitt',),
'termitter': ('termitt',),
'termitt': ('termitt',),
'termitta': ('termitt',),
'termitten': ('termitt',),
'termittene': ('termitt',),
'termitter': ('termitt',),
'termittet': ('termitt',),
'termitt-tua': ('termitt-tue',),
'termitt-tue': ('termitt-tue',),
'termitt-tuen': ('termitt-tue',),
'termitt-tuene': ('termitt-tue',),
'termitt-tuer': ('termitt-tue',),
'termittmaur': ('termittmaur',),
'termittmauren': ('termittmaur',),
'termittmaurene': ('termittmaur',),
'termitttuva': ('termitttuve',),
'termitttuve': ('termitttuve',),
'termitttuven': ('termitttuve',),
'termitttuvene': ('termitttuve',),
'termitttuver': ('termitttuve',),
'termittua': ('termittue',),
'termittue': ('termittue',),
'termittuen': ('termittue',),
'termittuene': ('termittue',),
'termittuer': ('termittue',),
'termobenk': ('termobenk',),
'termobenken': ('termobenk',),
'termobenkene': ('termobenk',),
'termobenker': ('termobenk',),
'termodynamikk': ('termodynamikk',),
'termodynamikken': ('termodynamikk',),
'termodynamikkene': ('termodynamikk',),
'termodynamikker': ('termodynamikk',),
'termoelektrisitet': ('termoelektrisitet',),
'termoelektrisiteten': ('termoelektrisitet',),
'termoelektrisitetene': ('termoelektrisitet',),
'termoelektrisiteter': ('termoelektrisitet',),
'termograf': ('termograf',),
'termografen': ('termograf',),
'termografene': ('termograf',),
'termografer': ('termograf',),
'termografi': ('termografi',),
'termografien': ('termografi',),
'termografiene': ('termografi',),
'termografier': ('termografi',),
'termogram': ('termogram',),
'termogramma': ('termogram',),
'termogrammene': ('termogram',),
'termogrammer': ('termogram',),
'termogrammet': ('termogram',),
'termokanna': ('termokanne',),
'termokanne': ('termokanne',),
'termokannen': ('termokanne',),
'termokannene': ('termokanne',),
'termokanner': ('termokanne',),
'termometer': ('termometer',),
'termometeret': ('termometer',),
'termometra': ('termometer',),
'termometre': ('termometer',),
'termometrene': ('termometer',),
'termometret': ('termometer',),
'termopanruta': ('termopanrute',),
'termopanrute': ('termopanrute',),
'termopanruten': ('termopanrute',),
'termopanrutene': ('termopanrute',),
'termopanruter': ('termopanrute',),
'termoplast': ('termoplast',),
'termoplasten': ('termoplast',),
'termoplastene': ('termoplast',),
'termoplaster': ('termoplast',),
'termoplastisitet': ('termoplastisitet',),
'termoplastisiteten': ('termoplastisitet',),
'termoplastisitetene': ('termoplastisitet',),
'termoplastisiteter': ('termoplastisitet',),
'termos': ('termos',),
'termosen': ('termos',),
'termosene': ('termos',),
'termoser': ('termos',),
'termosflaska': ('termosflaske',),
'termosflaske': ('termosflaske',),
'termosflasken': ('termosflaske',),
'termosflaskene': ('termosflaske',),
'termosflasker': ('termosflaske',),
'termostat': ('termostat',),
'termostaten': ('termostat',),
'termostatene': ('termostat',),
'termostater': ('termostat',),
'termotaksiene': ('termotaksis',),
'termotaksier': ('termotaksis',),
'termotaksis': ('termotaksis',),
'termotaksisen': ('termotaksis',),
'termotaksisene': ('termotaksis',),
'termotaksiser': ('termotaksis',),
'terna': ('terne',),
'terne': ('terne',),
'ternen': ('terne',),
'ternene': ('terne',),
'terner': ('terne',),
'terna': ('terne',),
'terne': ('terne',),
'ternen': ('terne',),
'ternene': ('terne',),
'terner': ('terne',),
'terning': ('terning',),
'terningen': ('terning',),
'terningene': ('terning',),
'terninger': ('terning',),
'terningkast': ('terningkast',),
'terningkasta': ('terningkast',),
'terningkastene': ('terningkast',),
'terningkastet': ('terningkast',),
'terningspell': ('terningspell',),
'terningspella': ('terningspell',),
'terningspellene': ('terningspell',),
'terningspellet': ('terningspell',),
'terningspill': ('terningspill',),
'terningspilla': ('terningspill',),
'terningspillene': ('terningspill',),
'terningspillet': ('terningspill',),
'terningøya': ('terningøye',),
'terningøye': ('terningøye',),
'terningøyene': ('terningøye',),
'terningøyer': ('terningøye',),
'terningøyet': ('terningøye',),
'terningøyne': ('terningøye',),
'terningøynene': ('terningøye',),
'terp': ('terp',),
'terpa': ('terp',),
'terpene': ('terp',),
'terpet': ('terp',),
'terpentin': ('terpentin',),
'terpentina': ('terpentin',),
'terpentinen': ('terpentin',),
'terpentinene': ('terpentin',),
'terpentiner': ('terpentin',),
'terpentinet': ('terpentin',),
'terpentinolja': ('terpentinolje',),
'terpentinolje': ('terpentinolje',),
'terpentinoljen': ('terpentinolje',),
'terpentinoljene': ('terpentinolje',),
'terpentinoljer': ('terpentinolje',),
'terra': ('terra',),
'terrakotta': ('terrakotta',),
'terrakottaen': ('terrakotta',),
'terrakottaene': ('terrakotta',),
'terrakottaer': ('terrakotta',),
'terraria': ('terrarium',),
'terrariene': ('terrarium',),
'terrarier': ('terrarium',),
'terrariet': ('terrarium',),
'terrarium': ('terrarium',),
'terrasse': ('terrasse',),
'terrassen': ('terrasse',),
'terrassene': ('terrasse',),
'terrasser': ('terrasse',),
'terrassehus': ('terrassehus',),
'terrassehusa': ('terrassehus',),
'terrassehusene': ('terrassehus',),
'terrassehuset': ('terrassehus',),
'terrasso': ('terrasso',),
'terrassoen': ('terrasso',),
'terrassoene': ('terrasso',),
'terrassoer': ('terrasso',),
'terrazzo': ('terrazzo',),
'terrazzoen': ('terrazzo',),
'terrazzoene': ('terrazzo',),
'terrazzoer': ('terrazzo',),
'terreng': ('terreng',),
'terrenga': ('terreng',),
'terrengene': ('terreng',),
'terrenget': ('terreng',),
'terrengløp': ('terrengløp',),
'terrengløpa': ('terrengløp',),
'terrengløpene': ('terrengløp',),
'terrengløpet': ('terrengløp',),
'terrengløypa': ('terrengløype',),
'terrengløype': ('terrengløype',),
'terrengløypen': ('terrengløype',),
'terrengløypene': ('terrengløype',),
'terrengløyper': ('terrengløype',),
'terrengsykkel': ('terrengsykkel',),
'terrengsykkelen': ('terrengsykkel',),
'terrengsyklene': ('terrengsykkel',),
'terrengsykler': ('terrengsykkel',),
'terrier': ('terrier',),
'terriere': ('terrier',),
'terrieren': ('terrier',),
'terrierer': ('terrier',),
'terrierne': ('terrier',),
'terrin': ('terrin',),
'terrinen': ('terrin',),
'terrinene': ('terrin',),
'terriner': ('terrin',),
'territorialfarvann': ('territorialfarvann',),
'territorialfarvanna': ('territorialfarvann',),
'territorialfarvannene': ('territorialfarvann',),
'territorialfarvannet': ('territorialfarvann',),
'territorialfarvatn': ('territorialfarvatn',),
'territorialfarvatna': ('territorialfarvatn',),
'territorialfarvatnene': ('territorialfarvatn',),
'territorialfarvatnet': ('territorialfarvatn',),
'territorialgrensa': ('territorialgrense',),
'territorialgrense': ('territorialgrense',),
'territorialgrensen': ('territorialgrense',),
'territorialgrensene': ('territorialgrense',),
'territorialgrenser': ('territorialgrense',),
'territorialprinsipp': ('territorialprinsipp',),
'territorialprinsippa': ('territorialprinsipp',),
'territorialprinsippene': ('territorialprinsipp',),
'territorialprinsipper': ('territorialprinsipp',),
'territorialprinsippet': ('territorialprinsipp',),
'territoria': ('territorium',),
'territoriene': ('territorium',),
'territorier': ('territorium',),
'territoriet': ('territorium',),
'territorium': ('territorium',),
'terror': ('terror',),
'terroren': ('terror',),
'terrorene': ('terror',),
'terrorer': ('terror',),
'terrorbalanse': ('terrorbalanse',),
'terrorbalansen': ('terrorbalanse',),
'terrorbalansene': ('terrorbalanse',),
'terrorbalanser': ('terrorbalanse',),
'terrorbombing': ('terrorbombing',),
'terrorbombinga': ('terrorbombing',),
'terrorbombingen': ('terrorbombing',),
'terrorbombingene': ('terrorbombing',),
'terrorbombinger': ('terrorbombing',),
'terrorbølga': ('terrorbølge',),
'terrorbølge': ('terrorbølge',),
'terrorbølgen': ('terrorbølge',),
'terrorbølgene': ('terrorbølge',),
'terrorbølger': ('terrorbølge',),
'terrorbølgja': ('terrorbølgje',),
'terrorbølgje': ('terrorbølgje',),
'terrorbølgjen': ('terrorbølgje',),
'terrorbølgjene': ('terrorbølgje',),
'terrorbølgjer': ('terrorbølgje',),
'terrorisme': ('terrorisme',),
'terrorismen': ('terrorisme',),
'terrorismene': ('terrorisme',),
'terrorismer': ('terrorisme',),
'terrorist': ('terrorist',),
'terroristen': ('terrorist',),
'terroristene': ('terrorist',),
'terrorister': ('terrorist',),
'terrorvelda': ('terrorvelde',),
'terrorvelde': ('terrorvelde',),
'terrorveldene': ('terrorvelde',),
'terrorvelder': ('terrorvelde',),
'terrorveldet': ('terrorvelde',),
'terrorvirksomhet': ('terrorvirksomhet',),
'terrorvirksomheta': ('terrorvirksomhet',),
'terrorvirksomheten': ('terrorvirksomhet',),
'terrorvirksomhetene': ('terrorvirksomhet',),
'terrorvirksomheter': ('terrorvirksomhet',),
'ters': ('ters',),
'tersen': ('ters',),
'tersene': ('ters',),
'terser': ('ters',),
'ters': ('ters',),
'tersen': ('ters',),
'tersene': ('ters',),
'terser': ('ters',),
'tersett': ('tersett',),
'tersetten': ('tersett',),
'tersettene': ('tersett',),
'tersetter': ('tersett',),
'terskel': ('terskel',),
'terskelen': ('terskel',),
'tersklene': ('terskel',),
'terskler': ('terskel',),
'terskelverdi': ('terskelverdi',),
'terskelverdien': ('terskelverdi',),
'terskelverdiene': ('terskelverdi',),
'terskelverdier': ('terskelverdi',),
'tert': ('tert',),
'terten': ('tert',),
'tertene': ('tert',),
'terter': ('tert',),
'terta': ('terte',),
'terte': ('terte',),
'terten': ('terte',),
'tertene': ('terte',),
'terter': ('terte',),
'tertedeig': ('tertedeig',),
'tertedeigen': ('tertedeig',),
'tertedeigene': ('tertedeig',),
'tertedeiger': ('tertedeig',),
'tertial': ('tertial',),
'tertiala': ('tertial',),
'tertialene': ('tertial',),
'tertialer': ('tertial',),
'tertialet': ('tertial',),
'tertialrapport': ('tertialrapport',),
'tertialrapporten': ('tertialrapport',),
'tertialrapportene': ('tertialrapport',),
'tertialrapporter': ('tertialrapport',),
'tertialregnskap': ('tertialregnskap',),
'tertialregnskapa': ('tertialregnskap',),
'tertialregnskapene': ('tertialregnskap',),
'tertialregnskaper': ('tertialregnskap',),
'tertialregnskapet': ('tertialregnskap',),
'tertialrekneskap': ('tertialrekneskap',),
'tertialrekneskapen': ('tertialrekneskap',),
'tertialrekneskapene': ('tertialrekneskap',),
'tertialrekneskaper': ('tertialrekneskap',),
'tertit': ('tertit',),
'tertiten': ('tertit',),
'tertitene': ('tertit',),
'tertiter': ('tertit',),
'tertiær': ('tertiær',),
'tertiæren': ('tertiær',),
'tertiærene': ('tertiær',),
'tertiærer': ('tertiær',),
'tertiærformasjon': ('tertiærformasjon',),
'tertiærformasjonen': ('tertiærformasjon',),
'tertiærformasjonene': ('tertiærformasjon',),
'tertiærformasjoner': ('tertiærformasjon',),
'tertiærnæring': ('tertiærnæring',),
'tertiærnæringa': ('tertiærnæring',),
'tertiærnæringen': ('tertiærnæring',),
'tertiærnæringene': ('tertiærnæring',),
'tertiærnæringer': ('tertiærnæring',),
'tertiærperiode': ('tertiærperiode',),
'tertiærperioden': ('tertiærperiode',),
'tertiærperiodene': ('tertiærperiode',),
'tertiærperioder': ('tertiærperiode',),
'tertiærsystem': ('tertiærsystem',),
'tertiærsystema': ('tertiærsystem',),
'tertiærsystemene': ('tertiærsystem',),
'tertiærsystemer': ('tertiærsystem',),
'tertiærsystemet': ('tertiærsystem',),
'terylena': ('terylene',),
'terylene': ('terylene',),
'terylenene': ('terylene',),
'terylener': ('terylene',),
'terylenet': ('terylene',),
'tesaurus': ('tesaurus',),
'tesaurusen': ('tesaurus',),
'tesaurusene': ('tesaurus',),
'tesauruser': ('tesaurus',),
'tese': ('tese',),
'tesen': ('tese',),
'tesene': ('tese',),
'teser': ('tese',),
'tesa': ('tese',),
'tese': ('tese',),
'tesen': ('tese',),
'tesene': ('tese',),
'teser': ('tese',),
'teservisa': ('teservise',),
'teservise': ('teservise',),
'teservisene': ('teservise',),
'teserviser': ('teservise',),
'teserviset': ('teservise',),
'tesil': ('tesil',),
'tesilen': ('tesil',),
'tesilene': ('tesil',),
'tesiler': ('tesil',),
'teskei': ('teskei',),
'teskeia': ('teskei',),
'teskeien': ('teskei',),
'teskeiene': ('teskei',),
'teskeier': ('teskei',),
'teskje': ('teskje',),
'teskjea': ('teskje',),
'teskjeen': ('teskje',),
'teskjeene': ('teskje',),
'teskjeer': ('teskje',),
'tesla': ('tesla',),
'teslaen': ('tesla',),
'teslaene': ('tesla',),
'test': ('test',),
'testen': ('test',),
'testene': ('test',),
'tester': ('test',),
'testament': ('testament',),
'testamenta': ('testament',),
'testamentene': ('testament',),
'testamenter': ('testament',),
'testamentet': ('testament',),
'testamenta': ('testamente',),
'testamente': ('testamente',),
'testamentene': ('testamente',),
'testamenter': ('testamente',),
'testamentet': ('testamente',),
'testamenta': ('testamente',),
'testamente': ('testamente',),
'testamentene': ('testamente',),
'testamenter': ('testamente',),
'testamentet': ('testamente',),
'testamentfullbyrder': ('testamentfullbyrder',),
'testamentfullbyrdere': ('testamentfullbyrder',),
'testamentfullbyrderen': ('testamentfullbyrder',),
'testamentfullbyrderer': ('testamentfullbyrder',),
'testamentfullbyrderne': ('testamentfullbyrder',),
'testamentsfullbyrder': ('testamentsfullbyrder',),
'testamentsfullbyrdere': ('testamentsfullbyrder',),
'testamentsfullbyrderen': ('testamentsfullbyrder',),
'testamentsfullbyrderer': ('testamentsfullbyrder',),
'testamentsfullbyrderne': ('testamentsfullbyrder',),
'testasjon': ('testasjon',),
'testasjonen': ('testasjon',),
'testasjonene': ('testasjon',),
'testasjoner': ('testasjon',),
'testasjonsfrihet': ('testasjonsfrihet',),
'testasjonsfriheta': ('testasjonsfrihet',),
'testasjonsfriheten': ('testasjonsfrihet',),
'testasjonsfrihetene': ('testasjonsfrihet',),
'testasjonsfriheter': ('testasjonsfrihet',),
'testator': ('testator',),
'testatoren': ('testator',),
'testatorene': ('testator',),
'testatorer': ('testator',),
'tester': ('tester',),
'testere': ('tester',),
'testeren': ('tester',),
'testerer': ('tester',),
'testerne': ('tester',),
'testflyger': ('testflyger',),
'testflygere': ('testflyger',),
'testflygeren': ('testflyger',),
'testflygerer': ('testflyger',),
'testflygerne': ('testflyger',),
'testfører': ('testfører',),
'testførere': ('testfører',),
'testføreren': ('testfører',),
'testførerer': ('testfører',),
'testførerne': ('testfører',),
'testikkel': ('testikkel',),
'testikkelen': ('testikkel',),
'testiklene': ('testikkel',),
'testikler': ('testikkel',),
'testikkelpung': ('testikkelpung',),
'testikkelpungen': ('testikkelpung',),
'testikkelpungene': ('testikkelpung',),
'testikkelpunger': ('testikkelpung',),
'testimonia': ('testimonium',),
'testimoniene': ('testimonium',),
'testimonier': ('testimonium',),
'testimoniet': ('testimonium',),
'testimonium': ('testimonium',),
'testing': ('testing',),
'testinga': ('testing',),
'testingen': ('testing',),
'testingene': ('testing',),
'testinger': ('testing',),
'testløp': ('testløp',),
'testløpa': ('testløp',),
'testløpene': ('testløp',),
'testløpet': ('testløp',),
'testosteron': ('testosteron',),
'testosterona': ('testosteron',),
'testosteronene': ('testosteron',),
'testosteronet': ('testosteron',),
'tet': ('tet',),
'teten': ('tet',),
'tetene': ('tet',),
'teter': ('tet',),
'tetgruppa': ('tetgruppe',),
'tetgruppe': ('tetgruppe',),
'tetgruppen': ('tetgruppe',),
'tetgruppene': ('tetgruppe',),
'tetgrupper': ('tetgruppe',),
'tetning': ('tetning',),
'tetninga': ('tetning',),
'tetningen': ('tetning',),
'tetningene': ('tetning',),
'tetninger': ('tetning',),
'tetningskjerne': ('tetningskjerne',),
'tetningskjernen': ('tetningskjerne',),
'tetningskjernene': ('tetningskjerne',),
'tetningskjerner': ('tetningskjerne',),
'tetningslist': ('tetningslist',),
'tetningslista': ('tetningslist',),
'tetningslisten': ('tetningslist',),
'tetningslistene': ('tetningslist',),
'tetningslister': ('tetningslist',),
'tetningsmaterial': ('tetningsmaterial',),
'tetningsmateriala': ('tetningsmaterial',),
'tetningsmaterialene': ('tetningsmaterial',),
'tetningsmaterialer': ('tetningsmaterial',),
'tetningsmaterialet': ('tetningsmaterial',),
'tetningsmateriala': ('tetningsmateriale',),
'tetningsmateriale': ('tetningsmateriale',),
'tetningsmaterialene': ('tetningsmateriale',),
'tetningsmaterialer': ('tetningsmateriale',),
'tetningsmaterialet': ('tetningsmateriale',),
'tetningsmiddel': ('tetningsmiddel',),
'tetningsmiddelet': ('tetningsmiddel',),
'tetningsmidla': ('tetningsmiddel',),
'tetningsmidlene': ('tetningsmiddel',),
'tetningsmidler': ('tetningsmiddel',),
'tetningsmidlet': ('tetningsmiddel',),
'tetningsring': ('tetningsring',),
'tetningsringen': ('tetningsring',),
'tetningsringene': ('tetningsring',),
'tetningsringer': ('tetningsring',),
'tetraeder': ('tetraeder',),
'tetraederet': ('tetraeder',),
'tetraedra': ('tetraeder',),
'tetraedre': ('tetraeder',),
'tetraedrene': ('tetraeder',),
'tetraedret': ('tetraeder',),
'tetragon': ('tetragon',),
'tetragonen': ('tetragon',),
'tetragonene': ('tetragon',),
'tetragoner': ('tetragon',),
'tetrapod': ('tetrapod',),
'tetrapoden': ('tetrapod',),
'tetrapodene': ('tetrapod',),
'tetrapoder': ('tetrapod',),
'tetsjikt': ('tetsjikt',),
'tetsjikta': ('tetsjikt',),
'tetsjiktene': ('tetsjikt',),
'tetsjiktet': ('tetsjikt',),
'tettbebyggelse': ('tettbebyggelse',),
'tettbebyggelsen': ('tettbebyggelse',),
'tettbebyggelsene': ('tettbebyggelse',),
'tettbebyggelser': ('tettbebyggelse',),
'tette': ('tette',),
'tetten': ('tette',),
'tettene': ('tette',),
'tetter': ('tette',),
'tettegras': ('tettegras',),
'tettegrasa': ('tettegras',),
'tettegrasene': ('tettegras',),
'tettegraset': ('tettegras',),
'tettegress': ('tettegress',),
'tettegressa': ('tettegress',),
'tettegressene': ('tettegress',),
'tettegresset': ('tettegress',),
'tettelist': ('tettelist',),
'tettelista': ('tettelist',),
'tettelisten': ('tettelist',),
'tettelistene': ('tettelist',),
'tettelister': ('tettelist',),
'tettemelk': ('tettemelk',),
'tettemelka': ('tettemelk',),
'tettemelken': ('tettemelk',),
'tettemelkene': ('tettemelk',),
'tettemelker': ('tettemelk',),
'tettemjølk': ('tettemjølk',),
'tettemjølka': ('tettemjølk',),
'tettemjølken': ('tettemjølk',),
'tettemjølkene': ('tettemjølk',),
'tettemjølker': ('tettemjølk',),
'tettgrend': ('tettgrend',),
'tettgrenda': ('tettgrend',),
'tettgrenden': ('tettgrend',),
'tettgrendene': ('tettgrend',),
'tettgrender': ('tettgrend',),
'tetthet': ('tetthet',),
'tettheta': ('tetthet',),
'tettheten': ('tetthet',),
'tetthetene': ('tetthet',),
'tettheter': ('tetthet',),
'tettingsmaterial': ('tettingsmaterial',),
'tettingsmateriala': ('tettingsmaterial',),
'tettingsmaterialene': ('tettingsmaterial',),
'tettingsmaterialer': ('tettingsmaterial',),
'tettingsmaterialet': ('tettingsmaterial',),
'tettingsmateriala': ('tettingsmateriale',),
'tettingsmateriale': ('tettingsmateriale',),
'tettingsmaterialene': ('tettingsmateriale',),
'tettingsmaterialer': ('tettingsmateriale',),
'tettingsmaterialet': ('tettingsmateriale',),
'tettingsmiddel': ('tettingsmiddel',),
'tettingsmiddelet': ('tettingsmiddel',),
'tettingsmidla': ('tettingsmiddel',),
'tettingsmidlene': ('tettingsmiddel',),
'tettingsmidler': ('tettingsmiddel',),
'tettingsmidlet': ('tettingsmiddel',),
'tettsted': ('tettsted',),
'tettstedene': ('tettsted',),
'tettsteder': ('tettsted',),
'tettstedet': ('tettsted',),
'teutoner': ('teutoner',),
'teutonere': ('teutoner',),
'teutoneren': ('teutoner',),
'teutonerer': ('teutoner',),
'teutonerne': ('teutoner',),
'tev': ('tev',),
'teven': ('tev',),
'tevene': ('tev',),
'tever': ('tev',),
'tevann': ('tevann',),
'tevanna': ('tevann',),
'tevannene': ('tevann',),
'tevannet': ('tevann',),
'tevarmer': ('tevarmer',),
'tevarmere': ('tevarmer',),
'tevarmeren': ('tevarmer',),
'tevarmerer': ('tevarmer',),
'tevarmerne': ('tevarmer',),
'tevatn': ('tevatn',),
'tevatna': ('tevatn',),
'tevatnene': ('tevatn',),
'tevatnet': ('tevatn',),
'teva': ('teve',),
'teve': ('teve',),
'teven': ('teve',),
'tevene': ('teve',),
'tever': ('teve',),
'teva': ('teve',),
'teve': ('teve',),
'teven': ('teve',),
'tevene': ('teve',),
'tever': ('teve',),
'tevling': ('tevling',),
'tevlinga': ('tevling',),
'tevlingen': ('tevling',),
'tevlingene': ('tevling',),
'tevlinger': ('tevling',),
'tex': ('tex',),
'texen': ('tex',),
'texene': ('tex',),
'tg-grammatikk': ('tg-grammatikk',),
'tg-grammatikken': ('tg-grammatikk',),
'tg-grammatikkene': ('tg-grammatikk',),
'tg-grammatikker': ('tg-grammatikk',),
'thai': ('thai',),
'thaien': ('thai',),
'thaiene': ('thai',),
'thaier': ('thai',),
'thailender': ('thailender',),
'thailendere': ('thailender',),
'thailenderen': ('thailender',),
'thailenderer': ('thailender',),
'thailenderne': ('thailender',),
'thailending': ('thailending',),
'thailendingen': ('thailending',),
'thailendingene': ('thailending',),
'thailendinger': ('thailending',),
'thalidomid': ('thalidomid',),
'thalidomida': ('thalidomid',),
'thalidomidene': ('thalidomid',),
'thalidomidet': ('thalidomid',),
'thalidomidbarn': ('thalidomidbarn',),
'thalidomidbarna': ('thalidomidbarn',),
'thalidomidbarnene': ('thalidomidbarn',),
'thalidomidbarnet': ('thalidomidbarn',),
'thallium': ('thallium',),
'thalliuma': ('thallium',),
'thalliumene': ('thallium',),
'thalliumet': ('thallium',),
'thomisme': ('thomisme',),
'thomismen': ('thomisme',),
'thomismene': ('thomisme',),
'thomismer': ('thomisme',),
'thomist': ('thomist',),
'thomisten': ('thomist',),
'thomistene': ('thomist',),
'thomister': ('thomist',),
'thorium': ('thorium',),
'thoriuma': ('thorium',),
'thoriumene': ('thorium',),
'thoriumet': ('thorium',),
'thorn': ('thorn',),
'thornen': ('thorn',),
'thornene': ('thorn',),
'thorner': ('thorn',),
'thranitt': ('thranitt',),
'thranitten': ('thranitt',),
'thranittene': ('thranitt',),
'thranitter': ('thranitt',),
'thranittbevegelse': ('thranittbevegelse',),
'thranittbevegelsen': ('thranittbevegelse',),
'thranittbevegelsene': ('thranittbevegelse',),
'thranittbevegelser': ('thranittbevegelse',),
'thriller': ('thriller',),
'thrillere': ('thriller',),
'thrilleren': ('thriller',),
'thrillerer': ('thriller',),
'thrillerne': ('thriller',),
'thulium': ('thulium',),
'thuliuma': ('thulium',),
'thuliumene': ('thulium',),
'thuliumet': ('thulium',),
'ti': ('ti',),
'tien': ('ti',),
'tiene': ('ti',),
'tier': ('ti',),
'tiara': ('tiara',),
'tiaraen': ('tiara',),
'tiaraene': ('tiara',),
'tiaraer': ('tiara',),
'tibetaner': ('tibetaner',),
'tibetanere': ('tibetaner',),
'tibetaneren': ('tibetaner',),
'tibetanerer': ('tibetaner',),
'tibetanerne': ('tibetaner',),
'tibetansk': ('tibetansk',),
'tibetansken': ('tibetansk',),
'tibetanskene': ('tibetansk',),
'tibetansker': ('tibetansk',),
'tid': ('tid',),
'tida': ('tid',),
'tiden': ('tid',),
'tidene': ('tid',),
'tider': ('tid',),
'tidbolk': ('tidbolk',),
'tidbolken': ('tidbolk',),
'tidbolkene': ('tidbolk',),
'tidbolker': ('tidbolk',),
'tidel': ('tidel',),
'tidelen': ('tidel',),
'tidelene': ('tidel',),
'tideler': ('tidel',),
'tidende': ('tidende',),
'tidenden': ('tidende',),
'tidendene': ('tidende',),
'tidender': ('tidende',),
'tidevann': ('tidevann',),
'tidevanna': ('tidevann',),
'tidevannene': ('tidevann',),
'tidevannet': ('tidevann',),
'tidevannsbelta': ('tidevannsbelte',),
'tidevannsbelte': ('tidevannsbelte',),
'tidevannsbeltene': ('tidevannsbelte',),
'tidevannsbelter': ('tidevannsbelte',),
'tidevannsbeltet': ('tidevannsbelte',),
'tidevannsbølga': ('tidevannsbølge',),
'tidevannsbølge': ('tidevannsbølge',),
'tidevannsbølgen': ('tidevannsbølge',),
'tidevannsbølgene': ('tidevannsbølge',),
'tidevannsbølger': ('tidevannsbølge',),
'tidevannsbølgja': ('tidevannsbølgje',),
'tidevannsbølgje': ('tidevannsbølgje',),
'tidevannsbølgjen': ('tidevannsbølgje',),
'tidevannsbølgjene': ('tidevannsbølgje',),
'tidevannsbølgjer': ('tidevannsbølgje',),
'tidevannsforskjell': ('tidevannsforskjell',),
'tidevannsforskjellen': ('tidevannsforskjell',),
'tidevannsforskjellene': ('tidevannsforskjell',),
'tidevannsforskjeller': ('tidevannsforskjell',),
'tidevannsstrøm': ('tidevannsstrøm',),
'tidevannsstrømmen': ('tidevannsstrøm',),
'tidevannsstrømmene': ('tidevannsstrøm',),
'tidevannsstrømmer': ('tidevannsstrøm',),
'tideverv': ('tideverv',),
'tideverva': ('tideverv',),
'tidevervene': ('tideverv',),
'tidevervet': ('tideverv',),
'tidlaus': ('tidlaus',),
'tidlausen': ('tidlaus',),
'tidlausene': ('tidlaus',),
'tidlauser': ('tidlaus',),
'tidliggrønnsak': ('tidliggrønnsak',),
'tidliggrønnsaka': ('tidliggrønnsak',),
'tidliggrønnsaken': ('tidliggrønnsak',),
'tidliggrønnsakene': ('tidliggrønnsak',),
'tidliggrønnsaker': ('tidliggrønnsak',),
'tidligpotet': ('tidligpotet',),
'tidligpoteten': ('tidligpotet',),
'tidligpotetene': ('tidligpotet',),
'tidligpoteter': ('tidligpotet',),
'tidløs': ('tidløs',),
'tidløsen': ('tidløs',),
'tidløsene': ('tidløs',),
'tidløser': ('tidløs',),
'tidsadverb': ('tidsadverb',),
'tidsadverba': ('tidsadverb',),
'tidsadverbene': ('tidsadverb',),
'tidsadverber': ('tidsadverb',),
'tidsadverbet': ('tidsadverb',),
'tidsalder': ('tidsalder',),
'tidsaldere': ('tidsalder',),
'tidsalderen': ('tidsalder',),
'tidsalderer': ('tidsalder',),
'tidsalderne': ('tidsalder',),
'tidsaldre': ('tidsalder',),
'tidsaldrene': ('tidsalder',),
'tidsaldrer': ('tidsalder',),
'tidsangivelse': ('tidsangivelse',),
'tidsangivelsen': ('tidsangivelse',),
'tidsangivelsene': ('tidsangivelse',),
'tidsangivelser': ('tidsangivelse',),
'tidsbefraktning': ('tidsbefraktning',),
'tidsbefraktninga': ('tidsbefraktning',),
'tidsbefraktningen': ('tidsbefraktning',),
'tidsbefraktningene': ('tidsbefraktning',),
'tidsbefraktninger': ('tidsbefraktning',),
'tidsbegrensning': ('tidsbegrensning',),
'tidsbegrensninga': ('tidsbegrensning',),
'tidsbegrensningen': ('tidsbegrensning',),
'tidsbegrensningene': ('tidsbegrensning',),
'tidsbegrensninger': ('tidsbegrensning',),
'tidsbegrep': ('tidsbegrep',),
'tidsbegrepa': ('tidsbegrep',),
'tidsbegrepene': ('tidsbegrep',),
'tidsbegreper': ('tidsbegrep',),
'tidsbegrepet': ('tidsbegrep',),
'tidsbryter': ('tidsbryter',),
'tidsbrytere': ('tidsbryter',),
'tidsbryteren': ('tidsbryter',),
'tidsbryterer': ('tidsbryter',),
'tidsbryterne': ('tidsbryter',),
'tidsfaktor': ('tidsfaktor',),
'tidsfaktoren': ('tidsfaktor',),
'tidsfaktorene': ('tidsfaktor',),
'tidsfaktorer': ('tidsfaktor',),
'tidsfordriv': ('tidsfordriv',),
'tidsfordriva': ('tidsfordriv',),
'tidsfordrivene': ('tidsfordriv',),
'tidsfordrivet': ('tidsfordriv',),
'tidsforskjell': ('tidsforskjell',),
'tidsforskjellen': ('tidsforskjell',),
'tidsforskjellene': ('tidsforskjell',),
'tidsforskjeller': ('tidsforskjell',),
'tidsfrist': ('tidsfrist',),
'tidsfristen': ('tidsfrist',),
'tidsfristene': ('tidsfrist',),
'tidsfrister': ('tidsfrist',),
'tidsfølga': ('tidsfølge',),
'tidsfølge': ('tidsfølge',),
'tidsfølgen': ('tidsfølge',),
'tidsfølgene': ('tidsfølge',),
'tidsfølger': ('tidsfølge',),
'tidsfølgja': ('tidsfølgje',),
'tidsfølgje': ('tidsfølgje',),
'tidsfølgjen': ('tidsfølgje',),
'tidsfølgjene': ('tidsfølgje',),
'tidsfølgjer': ('tidsfølgje',),
'tidskoloritt': ('tidskoloritt',),
'tidskoloritten': ('tidskoloritt',),
'tidskolorittene': ('tidskoloritt',),
'tidskoloritter': ('tidskoloritt',),
'tidskonjunksjon': ('tidskonjunksjon',),
'tidskonjunksjonen': ('tidskonjunksjon',),
'tidskonjunksjonene': ('tidskonjunksjon',),
'tidskonjunksjoner': ('tidskonjunksjon',),
'tidsnød': ('tidsnød',),
'tidsnøda': ('tidsnød',),
'tidsnøden': ('tidsnød',),
'tidsnødene': ('tidsnød',),
'tidsnøder': ('tidsnød',),
'tidsplan': ('tidsplan',),
'tidsplanen': ('tidsplan',),
'tidsplanene': ('tidsplan',),
'tidsplaner': ('tidsplan',),
'tidspress': ('tidspress',),
'tidspressa': ('tidspress',),
'tidspressene': ('tidspress',),
'tidspresset': ('tidspress',),
'tidspunkt': ('tidspunkt',),
'tidspunkta': ('tidspunkt',),
'tidspunktene': ('tidspunkt',),
'tidspunkter': ('tidspunkt',),
'tidspunktet': ('tidspunkt',),
'tidsramma': ('tidsramme',),
'tidsramme': ('tidsramme',),
'tidsrammen': ('tidsramme',),
'tidsrammene': ('tidsramme',),
'tidsrammer': ('tidsramme',),
'tidsregning': ('tidsregning',),
'tidsregninga': ('tidsregning',),
'tidsregningen': ('tidsregning',),
'tidsregningene': ('tidsregning',),
'tidsregninger': ('tidsregning',),
'tidsrekning': ('tidsrekning',),
'tidsrekninga': ('tidsrekning',),
'tidsrekningen': ('tidsrekning',),
'tidsrekningene': ('tidsrekning',),
'tidsrekninger': ('tidsrekning',),
'tidsrom': ('tidsrom',),
'tidsromma': ('tidsrom',),
'tidsrommene': ('tidsrom',),
'tidsrommet': ('tidsrom',),
'tidssetning': ('tidssetning',),
'tidssetninga': ('tidssetning',),
'tidssetningen': ('tidssetning',),
'tidssetningene': ('tidssetning',),
'tidssetninger': ('tidssetning',),
'tidssignal': ('tidssignal',),
'tidssignala': ('tidssignal',),
'tidssignalene': ('tidssignal',),
'tidssignaler': ('tidssignal',),
'tidssignalet': ('tidssignal',),
'tidsskifta': ('tidsskifte',),
'tidsskifte': ('tidsskifte',),
'tidsskiftene': ('tidsskifte',),
'tidsskifter': ('tidsskifte',),
'tidsskiftet': ('tidsskifte',),
'tidsskjema': ('tidsskjema',),
'tidsskjemaene': ('tidsskjema',),
'tidsskjemaer': ('tidsskjema',),
'tidsskjemaet': ('tidsskjema',),
'tidsskrift': ('tidsskrift',),
'tidsskrifta': ('tidsskrift',),
'tidsskriftene': ('tidsskrift',),
'tidsskrifter': ('tidsskrift',),
'tidsskriftet': ('tidsskrift',),
'tidssona': ('tidssone',),
'tidssone': ('tidssone',),
'tidssonen': ('tidssone',),
'tidssonene': ('tidssone',),
'tidssoner': ('tidssone',),
'tidsspilla': ('tidsspille',),
'tidsspille': ('tidsspille',),
'tidsspillene': ('tidsspille',),
'tidsspiller': ('tidsspille',),
'tidsspillet': ('tidsspille',),
'tidsstudie': ('tidsstudie',),
'tidsstudien': ('tidsstudie',),
'tidsstudiene': ('tidsstudie',),
'tidsstudier': ('tidsstudie',),
'tidsstudia': ('tidsstudium',),
'tidsstudiene': ('tidsstudium',),
'tidsstudier': ('tidsstudium',),
'tidsstudiet': ('tidsstudium',),
'tidsstudium': ('tidsstudium',),
'tidtaker': ('tidtaker',),
'tidtakere': ('tidtaker',),
'tidtakeren': ('tidtaker',),
'tidtakerer': ('tidtaker',),
'tidtakerne': ('tidtaker',),
'tidtrøyta': ('tidtrøyte',),
'tidtrøyte': ('tidtrøyte',),
'tidtrøyten': ('tidtrøyte',),
'tidtrøytene': ('tidtrøyte',),
'tidtrøyter': ('tidtrøyte',),
'tidtrøytet': ('tidtrøyte',),
'tidvass-strøm': ('tidvass-strøm',),
'tidvass-strømmen': ('tidvass-strøm',),
'tidvass-strømmene': ('tidvass-strøm',),
'tidvass-strømmer': ('tidvass-strøm',),
'tidvassbelta': ('tidvassbelte',),
'tidvassbelte': ('tidvassbelte',),
'tidvassbeltene': ('tidvassbelte',),
'tidvassbelter': ('tidvassbelte',),
'tidvassbeltet': ('tidvassbelte',),
'tidvassbølga': ('tidvassbølge',),
'tidvassbølge': ('tidvassbølge',),
'tidvassbølgen': ('tidvassbølge',),
'tidvassbølgene': ('tidvassbølge',),
'tidvassbølger': ('tidvassbølge',),
'tidvassbølgja': ('tidvassbølgje',),
'tidvassbølgje': ('tidvassbølgje',),
'tidvassbølgjen': ('tidvassbølgje',),
'tidvassbølgjene': ('tidvassbølgje',),
'tidvassbølgjer': ('tidvassbølgje',),
'tidvassforskjell': ('tidvassforskjell',),
'tidvassforskjellen': ('tidvassforskjell',),
'tidvassforskjellene': ('tidvassforskjell',),
'tidvassforskjeller': ('tidvassforskjell',),
'tidvassstrøm': ('tidvassstrøm',),
'tidvassstrømmen': ('tidvassstrøm',),
'tidvassstrømmene': ('tidvassstrøm',),
'tidvassstrømmer': ('tidvassstrøm',),
'tidvasstrøm': ('tidvasstrøm',),
'tidvasstrømmen': ('tidvasstrøm',),
'tidvasstrømmene': ('tidvasstrøm',),
'tidvasstrømmer': ('tidvasstrøm',),
'tidvatn': ('tidvatn',),
'tidvatna': ('tidvatn',),
'tidvatnene': ('tidvatn',),
'tidvatnet': ('tidvatn',),
'tidvatnbelta': ('tidvatnbelte',),
'tidvatnbelte': ('tidvatnbelte',),
'tidvatnbeltene': ('tidvatnbelte',),
'tidvatnbelter': ('tidvatnbelte',),
'tidvatnbeltet': ('tidvatnbelte',),
'tidvatnbølga': ('tidvatnbølge',),
'tidvatnbølge': ('tidvatnbølge',),
'tidvatnbølgen': ('tidvatnbølge',),
'tidvatnbølgene': ('tidvatnbølge',),
'tidvatnbølger': ('tidvatnbølge',),
'tidvatnbølgja': ('tidvatnbølgje',),
'tidvatnbølgje': ('tidvatnbølgje',),
'tidvatnbølgjen': ('tidvatnbølgje',),
'tidvatnbølgjene': ('tidvatnbølgje',),
'tidvatnbølgjer': ('tidvatnbølgje',),
'tidvatnforskjell': ('tidvatnforskjell',),
'tidvatnforskjellen': ('tidvatnforskjell',),
'tidvatnforskjellene': ('tidvatnforskjell',),
'tidvatnforskjeller': ('tidvatnforskjell',),
'tidvatnstrøm': ('tidvatnstrøm',),
'tidvatnstrømmen': ('tidvatnstrøm',),
'tidvatnstrømmene': ('tidvatnstrøm',),
'tidvatnstrømmer': ('tidvatnstrøm',),
'tiende': ('tiende',),
'tienden': ('tiende',),
'tiendene': ('tiende',),
'tiender': ('tiende',),
'tiendedel': ('tiendedel',),
'tiendedelen': ('tiendedel',),
'tiendedelene': ('tiendedel',),
'tiendedeler': ('tiendedel',),
'tieplikt': ('tieplikt',),
'tieplikta': ('tieplikt',),
'tieplikten': ('tieplikt',),
'tiepliktene': ('tieplikt',),
'tieplikter': ('tieplikt',),
'tier': ('tier',),
'tiere': ('tier',),
'tieren': ('tier',),
'tierer': ('tier',),
'tierne': ('tier',),
'tiger': ('tiger',),
'tigere': ('tiger',),
'tigeren': ('tiger',),
'tigerer': ('tiger',),
'tigerne': ('tiger',),
'tigre': ('tiger',),
'tigrene': ('tiger',),
'tigrer': ('tiger',),
'tigerhai': ('tigerhai',),
'tigerhaien': ('tigerhai',),
'tigerhaiene': ('tigerhai',),
'tigerhaier': ('tigerhai',),
'tigersoleia': ('tigersoleie',),
'tigersoleie': ('tigersoleie',),
'tigersoleien': ('tigersoleie',),
'tigersoleiene': ('tigersoleie',),
'tigersoleier': ('tigersoleie',),
'tigersprang': ('tigersprang',),
'tigerspranga': ('tigersprang',),
'tigersprangene': ('tigersprang',),
'tigerspranget': ('tigersprang',),
'tigger': ('tigger',),
'tiggere': ('tigger',),
'tiggeren': ('tigger',),
'tiggerer': ('tigger',),
'tiggerne': ('tigger',),
'tiggerbrev': ('tiggerbrev',),
'tiggerbreva': ('tiggerbrev',),
'tiggerbrevene': ('tiggerbrev',),
'tiggerbrever': ('tiggerbrev',),
'tiggerbrevet': ('tiggerbrev',),
'tiggergang': ('tiggergang',),
'tiggergangen': ('tiggergang',),
'tiggergangene': ('tiggergang',),
'tiggerganger': ('tiggergang',),
'tiggeri': ('tiggeri',),
'tiggeria': ('tiggeri',),
'tiggeriene': ('tiggeri',),
'tiggerier': ('tiggeri',),
'tiggeriet': ('tiggeri',),
'tiggermunk': ('tiggermunk',),
'tiggermunken': ('tiggermunk',),
'tiggermunkene': ('tiggermunk',),
'tiggermunker': ('tiggermunk',),
'tiggerstav': ('tiggerstav',),
'tiggerstaven': ('tiggerstav',),
'tiggerstavene': ('tiggerstav',),
'tiggerstaver': ('tiggerstav',),
'tiggersti': ('tiggersti',),
'tiggerstien': ('tiggersti',),
'tiggerstiene': ('tiggersti',),
'tiggerstier': ('tiggersti',),
'tik': ('tik',),
'tika': ('tik',),
'tiken': ('tik',),
'tikene': ('tik',),
'tiker': ('tik',),
'tikamp': ('tikamp',),
'tikampen': ('tikamp',),
'tikampene': ('tikamp',),
'tikamper': ('tikamp',),
'tikant': ('tikant',),
'tikanten': ('tikant',),
'tikantene': ('tikant',),
'tikanter': ('tikant',),
'tikjemper': ('tikjemper',),
'tikjempere': ('tikjemper',),
'tikjemperen': ('tikjemper',),
'tikjemperer': ('tikjemper',),
'tikjemperne': ('tikjemper',),
'tikk': ('tikk',),
'tikken': ('tikk',),
'tikkene': ('tikk',),
'tikker': ('tikk',),
'tikk': ('tikk',),
'tikka': ('tikk',),
'tikkene': ('tikk',),
'tikket': ('tikk',),
'tikka': ('tikke',),
'tikke': ('tikke',),
'tikken': ('tikke',),
'tikkene': ('tikke',),
'tikker': ('tikke',),
'tikrona': ('tikrone',),
'tikrone': ('tikrone',),
'tikronen': ('tikrone',),
'tikronene': ('tikrone',),
'tikroner': ('tikrone',),
'tikroning': ('tikroning',),
'tikroningen': ('tikroning',),
'tikroningene': ('tikroning',),
'tikroninger': ('tikroning',),
'tiksotropi': ('tiksotropi',),
'tiksotropien': ('tiksotropi',),
'tiksotropiene': ('tiksotropi',),
'tiksotropier': ('tiksotropi',),
'tilbakebetalingsmetode': ('tilbakebetalingsmetode',),
'tilbakebetalingsmetoden': ('tilbakebetalingsmetode',),
'tilbakebetalingsmetodene': ('tilbakebetalingsmetode',),
'tilbakebetalingsmetoder': ('tilbakebetalingsmetode',),
'tilbakeblikk': ('tilbakeblikk',),
'tilbakeblikka': ('tilbakeblikk',),
'tilbakeblikkene': ('tilbakeblikk',),
'tilbakeblikket': ('tilbakeblikk',),
'tilbakefall': ('tilbakefall',),
'tilbakefalla': ('tilbakefall',),
'tilbakefallene': ('tilbakefall',),
'tilbakefallet': ('tilbakefall',),
'tilbakegang': ('tilbakegang',),
'tilbakegangen': ('tilbakegang',),
'tilbakegangene': ('tilbakegang',),
'tilbakeganger': ('tilbakegang',),
'tilbakeholdenhet': ('tilbakeholdenhet',),
'tilbakeholdenheta': ('tilbakeholdenhet',),
'tilbakeholdenheten': ('tilbakeholdenhet',),
'tilbakeholdenhetene': ('tilbakeholdenhet',),
'tilbakeholdenheter': ('tilbakeholdenhet',),
'tilbakeholdsrett': ('tilbakeholdsrett',),
'tilbakeholdsretten': ('tilbakeholdsrett',),
'tilbakeholdsrettene': ('tilbakeholdsrett',),
'tilbakeholdsretter': ('tilbakeholdsrett',),
'tilbakekjøp': ('tilbakekjøp',),
'tilbakekjøpa': ('tilbakekjøp',),
'tilbakekjøpene': ('tilbakekjøp',),
'tilbakekjøpet': ('tilbakekjøp',),
'tilbakekobling': ('tilbakekobling',),
'tilbakekoblinga': ('tilbakekobling',),
'tilbakekoblingen': ('tilbakekobling',),
'tilbakekoblingene': ('tilbakekobling',),
'tilbakekoblinger': ('tilbakekobling',),
'tilbakekomst': ('tilbakekomst',),
'tilbakekomsten': ('tilbakekomst',),
'tilbakekomstene': ('tilbakekomst',),
'tilbakekomster': ('tilbakekomst',),
'tilbakekopling': ('tilbakekopling',),
'tilbakekoplinga': ('tilbakekopling',),
'tilbakekoplingen': ('tilbakekopling',),
'tilbakekoplingene': ('tilbakekopling',),
'tilbakekoplinger': ('tilbakekopling',),
'tilbakeliggenhet': ('tilbakeliggenhet',),
'tilbakeliggenheta': ('tilbakeliggenhet',),
'tilbakeliggenheten': ('tilbakeliggenhet',),
'tilbakeliggenhetene': ('tilbakeliggenhet',),
'tilbakeliggenheter': ('tilbakeliggenhet',),
'tilbakemelding': ('tilbakemelding',),
'tilbakemeldinga': ('tilbakemelding',),
'tilbakemeldingen': ('tilbakemelding',),
'tilbakemeldingene': ('tilbakemelding',),
'tilbakemeldinger': ('tilbakemelding',),
'tilbakeslag': ('tilbakeslag',),
'tilbakeslaga': ('tilbakeslag',),
'tilbakeslagene': ('tilbakeslag',),
'tilbakeslaget': ('tilbakeslag',),
'tilbakeslagsventil': ('tilbakeslagsventil',),
'tilbakeslagsventilen': ('tilbakeslagsventil',),
'tilbakeslagsventilene': ('tilbakeslagsventil',),
'tilbakeslagsventiler': ('tilbakeslagsventil',),
'tilbakespell': ('tilbakespell',),
'tilbakespella': ('tilbakespell',),
'tilbakespellene': ('tilbakespell',),
'tilbakespellet': ('tilbakespell',),
'tilbakespill': ('tilbakespill',),
'tilbakespilla': ('tilbakespill',),
'tilbakespillene': ('tilbakespill',),
'tilbakespillet': ('tilbakespill',),
'tilbaketog': ('tilbaketog',),
'tilbaketoga': ('tilbaketog',),
'tilbaketogene': ('tilbaketog',),
'tilbaketoget': ('tilbaketog',),
'tilbaketrekking': ('tilbaketrekking',),
'tilbaketrekkinga': ('tilbaketrekking',),
'tilbaketrekkingen': ('tilbaketrekking',),
'tilbaketrekkingene': ('tilbaketrekking',),
'tilbaketrekkinger': ('tilbaketrekking',),
'tilbaketrekning': ('tilbaketrekning',),
'tilbaketrekninga': ('tilbaketrekning',),
'tilbaketrekningen': ('tilbaketrekning',),
'tilbaketrekningene': ('tilbaketrekning',),
'tilbaketrekninger': ('tilbaketrekning',),
'tilbaketur': ('tilbaketur',),
'tilbaketuren': ('tilbaketur',),
'tilbaketurene': ('tilbaketur',),
'tilbaketurer': ('tilbaketur',),
'tilbakevending': ('tilbakevending',),
'tilbakevendinga': ('tilbakevending',),
'tilbakevendingen': ('tilbakevending',),
'tilbakevendingene': ('tilbakevending',),
'tilbakevendinger': ('tilbakevending',),
'tilbeder': ('tilbeder',),
'tilbedere': ('tilbeder',),
'tilbederen': ('tilbeder',),
'tilbederer': ('tilbeder',),
'tilbederne': ('tilbeder',),
'tilbehør': ('tilbehør',),
'tilbehøra': ('tilbehør',),
'tilbehørene': ('tilbehør',),
'tilbehøret': ('tilbehør',),
'tilberedelse': ('tilberedelse',),
'tilberedelsen': ('tilberedelse',),
'tilberedelsene': ('tilberedelse',),
'tilberedelser': ('tilberedelse',),
'tilberedning': ('tilberedning',),
'tilberedninga': ('tilberedning',),
'tilberedningen': ('tilberedning',),
'tilberedningene': ('tilberedning',),
'tilberedninger': ('tilberedning',),
'tilblivelse': ('tilblivelse',),
'tilblivelsen': ('tilblivelse',),
'tilblivelsene': ('tilblivelse',),
'tilblivelser': ('tilblivelse',),
'tilbliving': ('tilbliving',),
'tilblivinga': ('tilbliving',),
'tilblivingen': ('tilbliving',),
'tilblivingene': ('tilbliving',),
'tilblivinger': ('tilbliving',),
'tilbringer': ('tilbringer',),
'tilbringere': ('tilbringer',),
'tilbringeren': ('tilbringer',),
'tilbringerer': ('tilbringer',),
'tilbringerne': ('tilbringer',),
'tilbringerbuss': ('tilbringerbuss',),
'tilbringerbussen': ('tilbringerbuss',),
'tilbringerbussene': ('tilbringerbuss',),
'tilbringerbusser': ('tilbringerbuss',),
'tilbringertjeneste': ('tilbringertjeneste',),
'tilbringertjenesten': ('tilbringertjeneste',),
'tilbringertjenestene': ('tilbringertjeneste',),
'tilbringertjenester': ('tilbringertjeneste',),
'tilbud': ('tilbud',),
'tilbuda': ('tilbud',),
'tilbudene': ('tilbud',),
'tilbudet': ('tilbud',),
'tilbudspris': ('tilbudspris',),
'tilbudsprisen': ('tilbudspris',),
'tilbudsprisene': ('tilbudspris',),
'tilbudspriser': ('tilbudspris',),
'tilbudsvara': ('tilbudsvare',),
'tilbudsvare': ('tilbudsvare',),
'tilbudsvaren': ('tilbudsvare',),
'tilbudsvarene': ('tilbudsvare',),
'tilbudsvarer': ('tilbudsvare',),
'tilbygg': ('tilbygg',),
'tilbygga': ('tilbygg',),
'tilbyggene': ('tilbygg',),
'tilbygget': ('tilbygg',),
'tilbøyelighet': ('tilbøyelighet',),
'tilbøyeligheta': ('tilbøyelighet',),
'tilbøyeligheten': ('tilbøyelighet',),
'tilbøyelighetene': ('tilbøyelighet',),
'tilbøyeligheter': ('tilbøyelighet',),
'tilde': ('tilde',),
'tilden': ('tilde',),
'tildene': ('tilde',),
'tilder': ('tilde',),
'tildragelse': ('tildragelse',),
'tildragelsen': ('tildragelse',),
'tildragelsene': ('tildragelse',),
'tildragelser': ('tildragelse',),
'tildriv': ('tildriv',),
'tildriva': ('tildriv',),
'tildrivene': ('tildriv',),
'tildrivet': ('tildriv',),
'tila': ('tile',),
'tile': ('tile',),
'tilene': ('tile',),
'tiler': ('tile',),
'tilet': ('tile',),
'tilfang': ('tilfang',),
'tilfanga': ('tilfang',),
'tilfangene': ('tilfang',),
'tilfanget': ('tilfang',),
'tilfarer': ('tilfarer',),
'tilfarere': ('tilfarer',),
'tilfareren': ('tilfarer',),
'tilfarerer': ('tilfarer',),
'tilfarerne': ('tilfarer',),
'tilfart': ('tilfart',),
'tilfarten': ('tilfart',),
'tilfartene': ('tilfart',),
'tilfarter': ('tilfart',),
'tilfartsveg': ('tilfartsveg',),
'tilfartsvegen': ('tilfartsveg',),
'tilfartsvegene': ('tilfartsveg',),
'tilfartsveger': ('tilfartsveg',),
'tilfartsvei': ('tilfartsvei',),
'tilfartsveien': ('tilfartsvei',),
'tilfartsveiene': ('tilfartsvei',),
'tilfartsveier': ('tilfartsvei',),
'tilfeldighet': ('tilfeldighet',),
'tilfeldigheta': ('tilfeldighet',),
'tilfeldigheten': ('tilfeldighet',),
'tilfeldighetene': ('tilfeldighet',),
'tilfeldigheter': ('tilfeldighet',),
'tilfella': ('tilfelle',),
'tilfelle': ('tilfelle',),
'tilfellene': ('tilfelle',),
'tilfeller': ('tilfelle',),
'tilfellet': ('tilfelle',),
'tilflukt': ('tilflukt',),
'tilflukta': ('tilflukt',),
'tilflukten': ('tilflukt',),
'tilfluktene': ('tilflukt',),
'tilflukter': ('tilflukt',),
'tilfluktsrom': ('tilfluktsrom',),
'tilfluktsromma': ('tilfluktsrom',),
'tilfluktsrommene': ('tilfluktsrom',),
'tilfluktsrommet': ('tilfluktsrom',),
'tilfluktssted': ('tilfluktssted',),
'tilfluktsstedene': ('tilfluktssted',),
'tilfluktssteder': ('tilfluktssted',),
'tilfluktsstedet': ('tilfluktssted',),
'tilflytningsstrøk': ('tilflytningsstrøk',),
'tilflytningsstrøka': ('tilflytningsstrøk',),
'tilflytningsstrøkene': ('tilflytningsstrøk',),
'tilflytningsstrøket': ('tilflytningsstrøk',),
'tilflyttingsstrøk': ('tilflyttingsstrøk',),
'tilflyttingsstrøka': ('tilflyttingsstrøk',),
'tilflyttingsstrøkene': ('tilflyttingsstrøk',),
'tilflyttingsstrøket': ('tilflyttingsstrøk',),
'tilfredshet': ('tilfredshet',),
'tilfredsheta': ('tilfredshet',),
'tilfredsheten': ('tilfredshet',),
'tilfredshetene': ('tilfredshet',),
'tilfredsheter': ('tilfredshet',),
'tilfredsstillelse': ('tilfredsstillelse',),
'tilfredsstillelsen': ('tilfredsstillelse',),
'tilfredsstillelsene': ('tilfredsstillelse',),
'tilfredsstillelser': ('tilfredsstillelse',),
'tilførsel': ('tilførsel',),
'tilførselen': ('tilførsel',),
'tilførslene': ('tilførsel',),
'tilførsler': ('tilførsel',),
'tilførselslinja': ('tilførselslinje',),
'tilførselslinje': ('tilførselslinje',),
'tilførselslinjen': ('tilførselslinje',),
'tilførselslinjene': ('tilførselslinje',),
'tilførselslinjer': ('tilførselslinje',),
'tilførsla': ('tilførsle',),
'tilførsle': ('tilførsle',),
'tilførslen': ('tilførsle',),
'tilførslene': ('tilførsle',),
'tilførsler': ('tilførsle',),
'tilføyelse': ('tilføyelse',),
'tilføyelsen': ('tilføyelse',),
'tilføyelsene': ('tilføyelse',),
'tilføyelser': ('tilføyelse',),
'tilgang': ('tilgang',),
'tilgangen': ('tilgang',),
'tilgangene': ('tilgang',),
'tilganger': ('tilgang',),
'tilgift': ('tilgift',),
'tilgifta': ('tilgift',),
'tilgiften': ('tilgift',),
'tilgiftene': ('tilgift',),
'tilgifter': ('tilgift',),
'tilgivelse': ('tilgivelse',),
'tilgivelsen': ('tilgivelse',),
'tilgivelsene': ('tilgivelse',),
'tilgivelser': ('tilgivelse',),
'tilgjengelighet': ('tilgjengelighet',),
'tilgjengeligheta': ('tilgjengelighet',),
'tilgjengeligheten': ('tilgjengelighet',),
'tilgjengelighetene': ('tilgjengelighet',),
'tilgjengeligheter': ('tilgjengelighet',),
'tilgjorthet': ('tilgjorthet',),
'tilgjortheta': ('tilgjorthet',),
'tilgjortheten': ('tilgjorthet',),
'tilgjorthetene': ('tilgjorthet',),
'tilgjortheter': ('tilgjorthet',),
'tilgodehavende': ('tilgodehavende',),
'tilgodehavendene': ('tilgodehavende',),
'tilgodehavender': ('tilgodehavende',),
'tilgodehavendet': ('tilgodehavende',),
'tilgodelapp': ('tilgodelapp',),
'tilgodelappen': ('tilgodelapp',),
'tilgodelappene': ('tilgodelapp',),
'tilgodelapper': ('tilgodelapp',),
'tilgrising': ('tilgrising',),
'tilgrisinga': ('tilgrising',),
'tilgrisingen': ('tilgrising',),
'tilgrisingene': ('tilgrising',),
'tilgrisinger': ('tilgrising',),
'tilhenger': ('tilhenger',),
'tilhengere': ('tilhenger',),
'tilhengeren': ('tilhenger',),
'tilhengerer': ('tilhenger',),
'tilhengerne': ('tilhenger',),
'tilhengerfesta': ('tilhengerfeste',),
'tilhengerfeste': ('tilhengerfeste',),
'tilhengerfestene': ('tilhengerfeste',),
'tilhengerfester': ('tilhengerfeste',),
'tilhengerfestet': ('tilhengerfeste',),
'tilhengerskare': ('tilhengerskare',),
'tilhengerskaren': ('tilhengerskare',),
'tilhengerskarene': ('tilhengerskare',),
'tilhengerskarer': ('tilhengerskare',),
'tilhengervogn': ('tilhengervogn',),
'tilhengervogna': ('tilhengervogn',),
'tilhengervognen': ('tilhengervogn',),
'tilhengervognene': ('tilhengervogn',),
'tilhengervogner': ('tilhengervogn',),
'tilhold': ('tilhold',),
'tilholda': ('tilhold',),
'tilholdene': ('tilhold',),
'tilholdet': ('tilhold',),
'tilholdssted': ('tilholdssted',),
'tilholdsstedene': ('tilholdssted',),
'tilholdssteder': ('tilholdssted',),
'tilholdsstedet': ('tilholdssted',),
'tilhører': ('tilhører',),
'tilhørere': ('tilhører',),
'tilhøreren': ('tilhører',),
'tilhørerer': ('tilhører',),
'tilhørerne': ('tilhører',),
'tilhørerskare': ('tilhørerskare',),
'tilhørerskaren': ('tilhørerskare',),
'tilhørerskarene': ('tilhørerskare',),
'tilhørerskarer': ('tilhørerskare',),
'tilhørighet': ('tilhørighet',),
'tilhørigheta': ('tilhørighet',),
'tilhørigheten': ('tilhørighet',),
'tilhørighetene': ('tilhørighet',),
'tilhørigheter': ('tilhørighet',),
'tilhøva': ('tilhøve',),
'tilhøve': ('tilhøve',),
'tilhøvene': ('tilhøve',),
'tilhøver': ('tilhøve',),
'tilhøvet': ('tilhøve',),
'tilintetgjørelse': ('tilintetgjørelse',),
'tilintetgjørelsen': ('tilintetgjørelse',),
'tilintetgjørelsene': ('tilintetgjørelse',),
'tilintetgjørelser': ('tilintetgjørelse',),
'tilintetgjøring': ('tilintetgjøring',),
'tilintetgjøringa': ('tilintetgjøring',),
'tilintetgjøringen': ('tilintetgjøring',),
'tilintetgjøringene': ('tilintetgjøring',),
'tilintetgjøringer': ('tilintetgjøring',),
'tiljamning': ('tiljamning',),
'tiljamninga': ('tiljamning',),
'tiljamningen': ('tiljamning',),
'tiljamningene': ('tiljamning',),
'tiljamninger': ('tiljamning',),
'tilja': ('tilje',),
'tilje': ('tilje',),
'tiljen': ('tilje',),
'tiljene': ('tilje',),
'tiljer': ('tilje',),
'tiljevning': ('tiljevning',),
'tiljevninga': ('tiljevning',),
'tiljevningen': ('tiljevning',),
'tiljevningene': ('tiljevning',),
'tiljevninger': ('tiljevning',),
'tilkallelse': ('tilkallelse',),
'tilkallelsen': ('tilkallelse',),
'tilkallelsene': ('tilkallelse',),
'tilkallelser': ('tilkallelse',),
'tilkalling': ('tilkalling',),
'tilkallinga': ('tilkalling',),
'tilkallingen': ('tilkalling',),
'tilkallingene': ('tilkalling',),
'tilkallinger': ('tilkalling',),
'tilknappethet': ('tilknappethet',),
'tilknappetheta': ('tilknappethet',),
'tilknappetheten': ('tilknappethet',),
'tilknappethetene': ('tilknappethet',),
'tilknappetheter': ('tilknappethet',),
'tilknytingsavgift': ('tilknytingsavgift',),
'tilknytingsavgifta': ('tilknytingsavgift',),
'tilknytingsavgiften': ('tilknytingsavgift',),
'tilknytingsavgiftene': ('tilknytingsavgift',),
'tilknytingsavgifter': ('tilknytingsavgift',),
'tilknytning': ('tilknytning',),
'tilknytninga': ('tilknytning',),
'tilknytningen': ('tilknytning',),
'tilknytningene': ('tilknytning',),
'tilknytninger': ('tilknytning',),
'tilknytningsavgift': ('tilknytningsavgift',),
'tilknytningsavgifta': ('tilknytningsavgift',),
'tilknytningsavgiften': ('tilknytningsavgift',),
'tilknytningsavgiftene': ('tilknytningsavgift',),
'tilknytningsavgifter': ('tilknytningsavgift',),
'tilknytningspunkt': ('tilknytningspunkt',),
'tilknytningspunkta': ('tilknytningspunkt',),
'tilknytningspunktene': ('tilknytningspunkt',),
'tilknytningspunkter': ('tilknytningspunkt',),
'tilknytningspunktet': ('tilknytningspunkt',),
'tilknyttingsavgift': ('tilknyttingsavgift',),
'tilknyttingsavgifta': ('tilknyttingsavgift',),
'tilknyttingsavgiften': ('tilknyttingsavgift',),
'tilknyttingsavgiftene': ('tilknyttingsavgift',),
'tilknyttingsavgifter': ('tilknyttingsavgift',),
'tilknyttingspunkt': ('tilknyttingspunkt',),
'tilknyttingspunkta': ('tilknyttingspunkt',),
'tilknyttingspunktene': ('tilknyttingspunkt',),
'tilknyttingspunkter': ('tilknyttingspunkt',),
'tilknyttingspunktet': ('tilknyttingspunkt',),
'tilkomst': ('tilkomst',),
'tilkomsten': ('tilkomst',),
'tilkomstene': ('tilkomst',),
'tilkomster': ('tilkomst',),
'tillatelse': ('tillatelse',),
'tillatelsen': ('tillatelse',),
'tillatelsene': ('tillatelse',),
'tillatelser': ('tillatelse',),
'tillegg': ('tillegg',),
'tillegga': ('tillegg',),
'tilleggene': ('tillegg',),
'tillegget': ('tillegg',),
'tilleggsbind': ('tilleggsbind',),
'tilleggsbinda': ('tilleggsbind',),
'tilleggsbindene': ('tilleggsbind',),
'tilleggsbindet': ('tilleggsbind',),
'tilleggsjord': ('tilleggsjord',),
'tilleggsjorda': ('tilleggsjord',),
'tilleggsjorden': ('tilleggsjord',),
'tilleggsjordene': ('tilleggsjord',),
'tilleggsjorder': ('tilleggsjord',),
'tilleggsskatt': ('tilleggsskatt',),
'tilleggsskatten': ('tilleggsskatt',),
'tilleggsskattene': ('tilleggsskatt',),
'tilleggsskatter': ('tilleggsskatt',),
'tilleggsspørsmål': ('tilleggsspørsmål',),
'tilleggsspørsmåla': ('tilleggsspørsmål',),
'tilleggsspørsmålene': ('tilleggsspørsmål',),
'tilleggsspørsmålet': ('tilleggsspørsmål',),
'tilleggsstraff': ('tilleggsstraff',),
'tilleggsstraffen': ('tilleggsstraff',),
'tilleggsstraffene': ('tilleggsstraff',),
'tilleggsstraffer': ('tilleggsstraff',),
'tillempelse': ('tillempelse',),
'tillempelsen': ('tillempelse',),
'tillempelsene': ('tillempelse',),
'tillempelser': ('tillempelse',),
'tillempning': ('tillempning',),
'tillempninga': ('tillempning',),
'tillempningen': ('tillempning',),
'tillempningene': ('tillempning',),
'tillempninger': ('tillempning',),
'tillempningsevna': ('tillempningsevne',),
'tillempningsevne': ('tillempningsevne',),
'tillempningsevnen': ('tillempningsevne',),
'tillempningsevnene': ('tillempningsevne',),
'tillempningsevner': ('tillempningsevne',),
'tillit': ('tillit',),
'tillita': ('tillit',),
'tilliten': ('tillit',),
'tillitene': ('tillit',),
'tilliter': ('tillit',),
'tillitsbrott': ('tillitsbrott',),
'tillitsbrotta': ('tillitsbrott',),
'tillitsbrottene': ('tillitsbrott',),
'tillitsbrottet': ('tillitsbrott',),
'tillitsbrudd': ('tillitsbrudd',),
'tillitsbrudda': ('tillitsbrudd',),
'tillitsbruddene': ('tillitsbrudd',),
'tillitsbruddet': ('tillitsbrudd',),
'tillitserklæring': ('tillitserklæring',),
'tillitserklæringa': ('tillitserklæring',),
'tillitserklæringen': ('tillitserklæring',),
'tillitserklæringene': ('tillitserklæring',),
'tillitserklæringer': ('tillitserklæring',),
'tillitsforhold': ('tillitsforhold',),
'tillitsforholda': ('tillitsforhold',),
'tillitsforholdene': ('tillitsforhold',),
'tillitsforholdet': ('tillitsforhold',),
'tillitskrisa': ('tillitskrise',),
'tillitskrise': ('tillitskrise',),
'tillitskrisen': ('tillitskrise',),
'tillitskrisene': ('tillitskrise',),
'tillitskriser': ('tillitskrise',),
'tillitskvinna': ('tillitskvinne',),
'tillitskvinne': ('tillitskvinne',),
'tillitskvinnen': ('tillitskvinne',),
'tillitskvinnene': ('tillitskvinne',),
'tillitskvinner': ('tillitskvinne',),
'tillitsmann': ('tillitsmann',),
'tillitsmannen': ('tillitsmann',),
'tillitsmenn': ('tillitsmann',),
'tillitsmennene': ('tillitsmann',),
'tillitsverv': ('tillitsverv',),
'tillitsverva': ('tillitsverv',),
'tillitsvervene': ('tillitsverv',),
'tillitsvervet': ('tillitsverv',),
'tillitsvota': ('tillitsvotum',),
'tillitsvotaene': ('tillitsvotum',),
'tillitsvotum': ('tillitsvotum',),
'tillitsvotumet': ('tillitsvotum',),
'tillokkelse': ('tillokkelse',),
'tillokkelsen': ('tillokkelse',),
'tillokkelsene': ('tillokkelse',),
'tillokkelser': ('tillokkelse',),
'tilløp': ('tilløp',),
'tilløpa': ('tilløp',),
'tilløpene': ('tilløp',),
'tilløpet': ('tilløp',),
'tilnavn': ('tilnavn',),
'tilnavna': ('tilnavn',),
'tilnavnene': ('tilnavn',),
'tilnavnet': ('tilnavn',),
'tilnærmelse': ('tilnærmelse',),
'tilnærmelsen': ('tilnærmelse',),
'tilnærmelsene': ('tilnærmelse',),
'tilnærmelser': ('tilnærmelse',),
'tilnærming': ('tilnærming',),
'tilnærminga': ('tilnærming',),
'tilnærmingen': ('tilnærming',),
'tilnærmingene': ('tilnærming',),
'tilnærminger': ('tilnærming',),
'tilnærmingsmåte': ('tilnærmingsmåte',),
'tilnærmingsmåten': ('tilnærmingsmåte',),
'tilnærmingsmåtene': ('tilnærmingsmåte',),
'tilnærmingsmåter': ('tilnærmingsmåte',),
'tilpasning': ('tilpasning',),
'tilpasninga': ('tilpasning',),
'tilpasningen': ('tilpasning',),
'tilpasningene': ('tilpasning',),
'tilpasninger': ('tilpasning',),
'tilpasningsevna': ('tilpasningsevne',),
'tilpasningsevne': ('tilpasningsevne',),
'tilpasningsevnen': ('tilpasningsevne',),
'tilpasningsevnene': ('tilpasningsevne',),
'tilpasningsevner': ('tilpasningsevne',),
'tilpassing': ('tilpassing',),
'tilpassinga': ('tilpassing',),
'tilpassingen': ('tilpassing',),
'tilpassingene': ('tilpassing',),
'tilpassinger': ('tilpassing',),
'tilpassingsevna': ('tilpassingsevne',),
'tilpassingsevne': ('tilpassingsevne',),
'tilpassingsevnen': ('tilpassingsevne',),
'tilpassingsevnene': ('tilpassingsevne',),
'tilpassingsevner': ('tilpassingsevne',),
'tilrop': ('tilrop',),
'tilropa': ('tilrop',),
'tilropene': ('tilrop',),
'tilropet': ('tilrop',),
'tilror': ('tilror',),
'tilroren': ('tilror',),
'tilrorene': ('tilror',),
'tilrorer': ('tilror',),
'tilråding': ('tilråding',),
'tilrådinga': ('tilråding',),
'tilrådingen': ('tilråding',),
'tilrådingene': ('tilråding',),
'tilrådinger': ('tilråding',),
'tilråing': ('tilråing',),
'tilråinga': ('tilråing',),
'tilråingen': ('tilråing',),
'tilråingene': ('tilråing',),
'tilråinger': ('tilråing',),
'tilsagn': ('tilsagn',),
'tilsagna': ('tilsagn',),
'tilsagnene': ('tilsagn',),
'tilsagnet': ('tilsagn',),
'tilsats': ('tilsats',),
'tilsatsen': ('tilsats',),
'tilsatsene': ('tilsats',),
'tilsatser': ('tilsats',),
'tilsetning': ('tilsetning',),
'tilsetninga': ('tilsetning',),
'tilsetningen': ('tilsetning',),
'tilsetningene': ('tilsetning',),
'tilsetninger': ('tilsetning',),
'tilsetningsstoff': ('tilsetningsstoff',),
'tilsetningsstoffa': ('tilsetningsstoff',),
'tilsetningsstoffene': ('tilsetningsstoff',),
'tilsetningsstoffer': ('tilsetningsstoff',),
'tilsetningsstoffet': ('tilsetningsstoff',),
'tilsetting': ('tilsetting',),
'tilsettinga': ('tilsetting',),
'tilsettingen': ('tilsetting',),
'tilsettingene': ('tilsetting',),
'tilsettinger': ('tilsetting',),
'tilsig': ('tilsig',),
'tilsiga': ('tilsig',),
'tilsigene': ('tilsig',),
'tilsiget': ('tilsig',),
'tilsigelse': ('tilsigelse',),
'tilsigelsen': ('tilsigelse',),
'tilsigelsene': ('tilsigelse',),
'tilsigelser': ('tilsigelse',),
'tilsiing': ('tilsiing',),
'tilsiinga': ('tilsiing',),
'tilsiingen': ('tilsiing',),
'tilsiingene': ('tilsiing',),
'tilsiinger': ('tilsiing',),
'tilsiter': ('tilsiter',),
'tilsitere': ('tilsiter',),
'tilsiteren': ('tilsiter',),
'tilsiterer': ('tilsiter',),
'tilsiterne': ('tilsiter',),
'tilskikkelse': ('tilskikkelse',),
'tilskikkelsen': ('tilskikkelse',),
'tilskikkelsene': ('tilskikkelse',),
'tilskikkelser': ('tilskikkelse',),
'tilskjærer': ('tilskjærer',),
'tilskjærere': ('tilskjærer',),
'tilskjæreren': ('tilskjærer',),
'tilskjærerer': ('tilskjærer',),
'tilskjærerne': ('tilskjærer',),
'tilskott': ('tilskott',),
'tilskotta': ('tilskott',),
'tilskottene': ('tilskott',),
'tilskottet': ('tilskott',),
'tilskudd': ('tilskudd',),
'tilskudda': ('tilskudd',),
'tilskuddene': ('tilskudd',),
'tilskuddet': ('tilskudd',),
'tilskuer': ('tilskuer',),
'tilskuere': ('tilskuer',),
'tilskueren': ('tilskuer',),
'tilskuerer': ('tilskuer',),
'tilskuerne': ('tilskuer',),
'tilskyndelse': ('tilskyndelse',),
'tilskyndelsen': ('tilskyndelse',),
'tilskyndelsene': ('tilskyndelse',),
'tilskyndelser': ('tilskyndelse',),
'tilskynding': ('tilskynding',),
'tilskyndinga': ('tilskynding',),
'tilskyndingen': ('tilskynding',),
'tilskyndingene': ('tilskynding',),
'tilskyndinger': ('tilskynding',),
'tilslag': ('tilslag',),
'tilslaga': ('tilslag',),
'tilslagene': ('tilslag',),
'tilslaget': ('tilslag',),
'tilslag': ('tilslag',),
'tilslaga': ('tilslag',),
'tilslagene': ('tilslag',),
'tilslaget': ('tilslag',),
'tilslutning': ('tilslutning',),
'tilslutninga': ('tilslutning',),
'tilslutningen': ('tilslutning',),
'tilslutningene': ('tilslutning',),
'tilslutninger': ('tilslutning',),
'tilsnakkelse': ('tilsnakkelse',),
'tilsnakkelsen': ('tilsnakkelse',),
'tilsnakkelsene': ('tilsnakkelse',),
'tilsnakkelser': ('tilsnakkelse',),
'tilsnikelse': ('tilsnikelse',),
'tilsnikelsen': ('tilsnikelse',),
'tilsnikelsene': ('tilsnikelse',),
'tilsnikelser': ('tilsnikelse',),
'tilsnitt': ('tilsnitt',),
'tilsnitta': ('tilsnitt',),
'tilsnittene': ('tilsnitt',),
'tilsnittet': ('tilsnitt',),
'tilsprang': ('tilsprang',),
'tilspranga': ('tilsprang',),
'tilsprangene': ('tilsprang',),
'tilspranget': ('tilsprang',),
'tilstand': ('tilstand',),
'tilstanden': ('tilstand',),
'tilstandene': ('tilstand',),
'tilstander': ('tilstand',),
'tilstandsdiagram': ('tilstandsdiagram',),
'tilstandsdiagramma': ('tilstandsdiagram',),
'tilstandsdiagrammene': ('tilstandsdiagram',),
'tilstandsdiagrammer': ('tilstandsdiagram',),
'tilstandsdiagrammet': ('tilstandsdiagram',),
'tilstandsligning': ('tilstandsligning',),
'tilstandsligninga': ('tilstandsligning',),
'tilstandsligningen': ('tilstandsligning',),
'tilstandsligningene': ('tilstandsligning',),
'tilstandsligninger': ('tilstandsligning',),
'tilstandslikning': ('tilstandslikning',),
'tilstandslikninga': ('tilstandslikning',),
'tilstandslikningen': ('tilstandslikning',),
'tilstandslikningene': ('tilstandslikning',),
'tilstandslikninger': ('tilstandslikning',),
'tilstandsrapport': ('tilstandsrapport',),
'tilstandsrapporten': ('tilstandsrapport',),
'tilstandsrapportene': ('tilstandsrapport',),
'tilstandsrapporter': ('tilstandsrapport',),
'tilstedeværelse': ('tilstedeværelse',),
'tilstedeværelsen': ('tilstedeværelse',),
'tilstedeværelsene': ('tilstedeværelse',),
'tilstedeværelser': ('tilstedeværelse',),
'tilstelling': ('tilstelling',),
'tilstellinga': ('tilstelling',),
'tilstellingen': ('tilstelling',),
'tilstellingene': ('tilstelling',),
'tilstellinger': ('tilstelling',),
'tilstelning': ('tilstelning',),
'tilstelninga': ('tilstelning',),
'tilstelningen': ('tilstelning',),
'tilstelningene': ('tilstelning',),
'tilstelninger': ('tilstelning',),
'tilstramming': ('tilstramming',),
'tilstramminga': ('tilstramming',),
'tilstrammingen': ('tilstramming',),
'tilstrammingene': ('tilstramming',),
'tilstramminger': ('tilstramming',),
'tilstramning': ('tilstramning',),
'tilstramninga': ('tilstramning',),
'tilstramningen': ('tilstramning',),
'tilstramningene': ('tilstramning',),
'tilstramninger': ('tilstramning',),
'tilstrømming': ('tilstrømming',),
'tilstrømminga': ('tilstrømming',),
'tilstrømmingen': ('tilstrømming',),
'tilstrømmingene': ('tilstrømming',),
'tilstrømminger': ('tilstrømming',),
'tilstrømning': ('tilstrømning',),
'tilstrømninga': ('tilstrømning',),
'tilstrømningen': ('tilstrømning',),
'tilstrømningene': ('tilstrømning',),
'tilstrømninger': ('tilstrømning',),
'tilståelse': ('tilståelse',),
'tilståelsen': ('tilståelse',),
'tilståelsene': ('tilståelse',),
'tilståelser': ('tilståelse',),
'tilsvar': ('tilsvar',),
'tilsvara': ('tilsvar',),
'tilsvarene': ('tilsvar',),
'tilsvaret': ('tilsvar',),
'tilsyn': ('tilsyn',),
'tilsyna': ('tilsyn',),
'tilsynene': ('tilsyn',),
'tilsynet': ('tilsyn',),
'tilsynsfører': ('tilsynsfører',),
'tilsynsførere': ('tilsynsfører',),
'tilsynsføreren': ('tilsynsfører',),
'tilsynsførerer': ('tilsynsfører',),
'tilsynsførerne': ('tilsynsfører',),
'tilsynsråd': ('tilsynsråd',),
'tilsynsråda': ('tilsynsråd',),
'tilsynsrådene': ('tilsynsråd',),
'tilsynsrådet': ('tilsynsråd',),
'tiltak': ('tiltak',),
'tiltaka': ('tiltak',),
'tiltakene': ('tiltak',),
'tiltaket': ('tiltak',),
'tiltakslyst': ('tiltakslyst',),
'tiltakslysta': ('tiltakslyst',),
'tiltakslysten': ('tiltakslyst',),
'tiltakslystene': ('tiltakslyst',),
'tiltakslyster': ('tiltakslyst',),
'tiltaksløshet': ('tiltaksløshet',),
'tiltaksløsheta': ('tiltaksløshet',),
'tiltaksløsheten': ('tiltaksløshet',),
'tiltaksløshetene': ('tiltaksløshet',),
'tiltaksløsheter': ('tiltaksløshet',),
'tiltaksløysa': ('tiltaksløyse',),
'tiltaksløyse': ('tiltaksløyse',),
'tiltaksløysen': ('tiltaksløyse',),
'tiltaksløysene': ('tiltaksløyse',),
'tiltaksløyser': ('tiltaksløyse',),
'tiltaksnemnd': ('tiltaksnemnd',),
'tiltaksnemnda': ('tiltaksnemnd',),
'tiltaksnemnden': ('tiltaksnemnd',),
'tiltaksnemndene': ('tiltaksnemnd',),
'tiltaksnemnder': ('tiltaksnemnd',),
'tiltakssjef': ('tiltakssjef',),
'tiltakssjefen': ('tiltakssjef',),
'tiltakssjefene': ('tiltakssjef',),
'tiltakssjefer': ('tiltakssjef',),
'tiltale': ('tiltale',),
'tiltalen': ('tiltale',),
'tiltalene': ('tiltale',),
'tiltaler': ('tiltale',),
'tiltalebenk': ('tiltalebenk',),
'tiltalebenken': ('tiltalebenk',),
'tiltalebenkene': ('tiltalebenk',),
'tiltalebenker': ('tiltalebenk',),
'tiltalebeslutning': ('tiltalebeslutning',),
'tiltalebeslutninga': ('tiltalebeslutning',),
'tiltalebeslutningen': ('tiltalebeslutning',),
'tiltalebeslutningene': ('tiltalebeslutning',),
'tiltalebeslutninger': ('tiltalebeslutning',),
'tiltaleboks': ('tiltaleboks',),
'tiltaleboksen': ('tiltaleboks',),
'tiltaleboksene': ('tiltaleboks',),
'tiltalebokser': ('tiltaleboks',),
'tiltalepunkt': ('tiltalepunkt',),
'tiltalepunkta': ('tiltalepunkt',),
'tiltalepunktene': ('tiltalepunkt',),
'tiltalepunkter': ('tiltalepunkt',),
'tiltalepunktet': ('tiltalepunkt',),
'tiltallsystem': ('tiltallsystem',),
'tiltallsystema': ('tiltallsystem',),
'tiltallsystemene': ('tiltallsystem',),
'tiltallsystemer': ('tiltallsystem',),
'tiltallsystemet': ('tiltallsystem',),
'tiltjukning': ('tiltjukning',),
'tiltjukninga': ('tiltjukning',),
'tiltjukningen': ('tiltjukning',),
'tiltjukningene': ('tiltjukning',),
'tiltjukninger': ('tiltjukning',),
'tiltredelseserklæring': ('tiltredelseserklæring',),
'tiltredelseserklæringa': ('tiltredelseserklæring',),
'tiltredelseserklæringen': ('tiltredelseserklæring',),
'tiltredelseserklæringene': ('tiltredelseserklæring',),
'tiltredelseserklæringer': ('tiltredelseserklæring',),
'tiltredelsesforelesning': ('tiltredelsesforelesning',),
'tiltredelsesforelesninga': ('tiltredelsesforelesning',),
'tiltredelsesforelesningen': ('tiltredelsesforelesning',),
'tiltredelsesforelesningene': ('tiltredelsesforelesning',),
'tiltredelsesforelesninger': ('tiltredelsesforelesning',),
'tiltredelsespreken': ('tiltredelsespreken',),
'tiltredelsesprekenen': ('tiltredelsespreken',),
'tiltredelsesprekenene': ('tiltredelsespreken',),
'tiltredelsesprekener': ('tiltredelsespreken',),
'tiltrekkingskraft': ('tiltrekkingskraft',),
'tiltrekkingskrafta': ('tiltrekkingskraft',),
'tiltrekkingskraften': ('tiltrekkingskraft',),
'tiltrekkingskreftene': ('tiltrekkingskraft',),
'tiltrekkingskrefter': ('tiltrekkingskraft',),
'tiltrekning': ('tiltrekning',),
'tiltrekninga': ('tiltrekning',),
'tiltrekningen': ('tiltrekning',),
'tiltrekningene': ('tiltrekning',),
'tiltrekninger': ('tiltrekning',),
'tiltrekningskraft': ('tiltrekningskraft',),
'tiltrekningskrafta': ('tiltrekningskraft',),
'tiltrekningskraften': ('tiltrekningskraft',),
'tiltrekningskreftene': ('tiltrekningskraft',),
'tiltrekningskrefter': ('tiltrekningskraft',),
'tiltro': ('tiltro',),
'tiltroa': ('tiltro',),
'tiltroen': ('tiltro',),
'tiltroene': ('tiltro',),
'tiltroer': ('tiltro',),
'tiltykning': ('tiltykning',),
'tiltykninga': ('tiltykning',),
'tiltykningen': ('tiltykning',),
'tiltykningene': ('tiltykning',),
'tiltykninger': ('tiltykning',),
'tilvalgsfag': ('tilvalgsfag',),
'tilvalgsfaga': ('tilvalgsfag',),
'tilvalgsfagene': ('tilvalgsfag',),
'tilvalgsfaget': ('tilvalgsfag',),
'tilvekst': ('tilvekst',),
'tilveksten': ('tilvekst',),
'tilvekstene': ('tilvekst',),
'tilvekster': ('tilvekst',),
'tilvirker': ('tilvirker',),
'tilvirkere': ('tilvirker',),
'tilvirkeren': ('tilvirker',),
'tilvirkerer': ('tilvirker',),
'tilvirkerne': ('tilvirker',),
'tilvirking': ('tilvirking',),
'tilvirkinga': ('tilvirking',),
'tilvirkingen': ('tilvirking',),
'tilvirkingene': ('tilvirking',),
'tilvirkinger': ('tilvirking',),
'tilvirkning': ('tilvirkning',),
'tilvirkninga': ('tilvirkning',),
'tilvirkningen': ('tilvirkning',),
'tilvirkningene': ('tilvirkning',),
'tilvirkninger': ('tilvirkning',),
'tilvising': ('tilvising',),
'tilvisinga': ('tilvising',),
'tilvisingen': ('tilvising',),
'tilvisingene': ('tilvising',),
'tilvisinger': ('tilvising',),
'tilvær': ('tilvær',),
'tilværa': ('tilvær',),
'tilværene': ('tilvær',),
'tilværet': ('tilvær',),
'tilværa': ('tilvære',),
'tilvære': ('tilvære',),
'tilværene': ('tilvære',),
'tilværer': ('tilvære',),
'tilværet': ('tilvære',),
'tilværelse': ('tilværelse',),
'tilværelsen': ('tilværelse',),
'tilværelsene': ('tilværelse',),
'tilværelser': ('tilværelse',),
'timbal': ('timbal',),
'timbalen': ('timbal',),
'timbalene': ('timbal',),
'timbaler': ('timbal',),
'timbalis': ('timbalis',),
'timbalisen': ('timbalis',),
'timbalisene': ('timbalis',),
'timbaliser': ('timbalis',),
'timbre': ('timbre',),
'timbren': ('timbre',),
'timbrene': ('timbre',),
'timbrer': ('timbre',),
'time': ('time',),
'timen': ('time',),
'timene': ('time',),
'timer': ('time',),
'timebetaling': ('timebetaling',),
'timebetalinga': ('timebetaling',),
'timebetalingen': ('timebetaling',),
'timebetalingene': ('timebetaling',),
'timebetalinger': ('timebetaling',),
'timecharter': ('timecharter',),
'timecharteret': ('timecharter',),
'timechartra': ('timecharter',),
'timechartrene': ('timecharter',),
'timechartrer': ('timecharter',),
'timechartret': ('timecharter',),
'timeglas': ('timeglas',),
'timeglasa': ('timeglas',),
'timeglasene': ('timeglas',),
'timeglaset': ('timeglas',),
'timeglass': ('timeglass',),
'timeglassa': ('timeglass',),
'timeglassene': ('timeglass',),
'timeglasset': ('timeglass',),
'timelærer': ('timelærer',),
'timelærere': ('timelærer',),
'timelæreren': ('timelærer',),
'timelærerer': ('timelærer',),
'timelærerne': ('timelærer',),
'timelønn': ('timelønn',),
'timelønna': ('timelønn',),
'timelønnen': ('timelønn',),
'timelønnene': ('timelønn',),
'timelønner': ('timelønn',),
'timeplan': ('timeplan',),
'timeplanen': ('timeplan',),
'timeplanene': ('timeplan',),
'timeplaner': ('timeplan',),
'timetall': ('timetall',),
'timetalla': ('timetall',),
'timetallene': ('timetall',),
'timetallet': ('timetall',),
'timeverk': ('timeverk',),
'timeverka': ('timeverk',),
'timeverkene': ('timeverk',),
'timeverker': ('timeverk',),
'timeverket': ('timeverk',),
'timeviser': ('timeviser',),
'timevisere': ('timeviser',),
'timeviseren': ('timeviser',),
'timeviserer': ('timeviser',),
'timeviserne': ('timeviser',),
'timian': ('timian',),
'timianen': ('timian',),
'timianene': ('timian',),
'timianer': ('timian',),
'timokrati': ('timokrati',),
'timokratia': ('timokrati',),
'timokratiene': ('timokrati',),
'timokratier': ('timokrati',),
'timokratiet': ('timokrati',),
'timotei': ('timotei',),
'timoteien': ('timotei',),
'timoteiene': ('timotei',),
'timoteier': ('timotei',),
'tind': ('tind',),
'tinden': ('tind',),
'tindene': ('tind',),
'tinder': ('tind',),
'tindebestiger': ('tindebestiger',),
'tindebestigere': ('tindebestiger',),
'tindebestigeren': ('tindebestiger',),
'tindebestigerer': ('tindebestiger',),
'tindebestigerne': ('tindebestiger',),
'tindebestigning': ('tindebestigning',),
'tindebestigninga': ('tindebestigning',),
'tindebestigningen': ('tindebestigning',),
'tindebestigningene': ('tindebestigning',),
'tindebestigninger': ('tindebestigning',),
'tindved': ('tindved',),
'tindveden': ('tindved',),
'tindvedene': ('tindved',),
'tindveder': ('tindved',),
'tina': ('tine',),
'tine': ('tine',),
'tinen': ('tine',),
'tinene': ('tine',),
'tiner': ('tine',),
'ting': ('ting',),
'tinga': ('ting',),
'tingen': ('ting',),
'tingene': ('ting',),
'ting': ('ting',),
'tinga': ('ting',),
'tingene': ('ting',),
'tinget': ('ting',),
'tingeltangel': ('tingeltangel',),
'tingeltangelet': ('tingeltangel',),
'tingeltangla': ('tingeltangel',),
'tingeltanglene': ('tingeltangel',),
'tingeltangler': ('tingeltangel',),
'tingeltanglet': ('tingeltangel',),
'tinger': ('tinger',),
'tingere': ('tinger',),
'tingeren': ('tinger',),
'tingerer': ('tinger',),
'tingerne': ('tinger',),
'tingest': ('tingest',),
'tingesten': ('tingest',),
'tingestene': ('tingest',),
'tingester': ('tingest',),
'tinghus': ('tinghus',),
'tinghusa': ('tinghus',),
'tinghusene': ('tinghus',),
'tinghuset': ('tinghus',),
'tinglag': ('tinglag',),
'tinglaga': ('tinglag',),
'tinglagene': ('tinglag',),
'tinglaget': ('tinglag',),
'tinglysing': ('tinglysing',),
'tinglysinga': ('tinglysing',),
'tinglysingen': ('tinglysing',),
'tinglysingene': ('tinglysing',),
'tinglysinger': ('tinglysing',),
'tingmann': ('tingmann',),
'tingmannen': ('tingmann',),
'tingmenn': ('tingmann',),
'tingmennene': ('tingmann',),
'tingsrett': ('tingsrett',),
'tingsretten': ('tingsrett',),
'tingsrettene': ('tingsrett',),
'tingsretter': ('tingsrett',),
'tingsvitna': ('tingsvitne',),
'tingsvitne': ('tingsvitne',),
'tingsvitnene': ('tingsvitne',),
'tingsvitner': ('tingsvitne',),
'tingsvitnet': ('tingsvitne',),
'tinktur': ('tinktur',),
'tinkturen': ('tinktur',),
'tinkturene': ('tinktur',),
'tinkturer': ('tinktur',),
'tinn': ('tinn',),
'tinna': ('tinn',),
'tinnene': ('tinn',),
'tinnet': ('tinn',),
'tinnfolie': ('tinnfolie',),
'tinnfolien': ('tinnfolie',),
'tinnfoliene': ('tinnfolie',),
'tinnfolier': ('tinnfolie',),
'tinning': ('tinning',),
'tinninga': ('tinning',),
'tinningen': ('tinning',),
'tinningene': ('tinning',),
'tinninger': ('tinning',),
'tinningbein': ('tinningbein',),
'tinningbeina': ('tinningbein',),
'tinningbeinene': ('tinningbein',),
'tinningbeinet': ('tinningbein',),
'tinningben': ('tinningben',),
'tinningbena': ('tinningben',),
'tinningbenene': ('tinningben',),
'tinningbenet': ('tinningben',),
'tinnsoldat': ('tinnsoldat',),
'tinnsoldaten': ('tinnsoldat',),
'tinnsoldatene': ('tinnsoldat',),
'tinnsoldater': ('tinnsoldat',),
'tinntallerken': ('tinntallerken',),
'tinntallerkenen': ('tinntallerken',),
'tinntallerkenene': ('tinntallerken',),
'tinntallerkener': ('tinntallerken',),
'tint': ('tint',),
'tinten': ('tint',),
'tintene': ('tint',),
'tinter': ('tint',),
'tinte': ('tinte',),
'tinten': ('tinte',),
'tintene': ('tinte',),
'tinter': ('tinte',),
'tipakning': ('tipakning',),
'tipakninga': ('tipakning',),
'tipakningen': ('tipakning',),
'tipakningene': ('tipakning',),
'tipakninger': ('tipakning',),
'tipi': ('tipi',),
'tipien': ('tipi',),
'tipiene': ('tipi',),
'tipier': ('tipi',),
'tipp': ('tipp',),
'tippen': ('tipp',),
'tippene': ('tipp',),
'tipper': ('tipp',),
'tipp': ('tipp',),
'tippen': ('tipp',),
'tippene': ('tipp',),
'tipper': ('tipp',),
'tipp': ('tipp',),
'tippa': ('tipp',),
'tippene': ('tipp',),
'tippet': ('tipp',),
'tippa': ('tippe',),
'tippe': ('tippe',),
'tippen': ('tippe',),
'tippene': ('tippe',),
'tipper': ('tippe',),
'tippegalskap': ('tippegalskap',),
'tippegalskapen': ('tippegalskap',),
'tippegalskapene': ('tippegalskap',),
'tippegalskaper': ('tippegalskap',),
'tippegevinst': ('tippegevinst',),
'tippegevinsten': ('tippegevinst',),
'tippegevinstene': ('tippegevinst',),
'tippegevinster': ('tippegevinst',),
'tippekamp': ('tippekamp',),
'tippekampen': ('tippekamp',),
'tippekampene': ('tippekamp',),
'tippekamper': ('tippekamp',),
'tippekupong': ('tippekupong',),
'tippekupongen': ('tippekupong',),
'tippekupongene': ('tippekupong',),
'tippekuponger': ('tippekupong',),
'tippeliga': ('tippeliga',),
'tippeligaen': ('tippeliga',),
'tippeligaene': ('tippeliga',),
'tippeligaer': ('tippeliga',),
'tippemidler': ('tippemidler',),
'tippemidlere': ('tippemidler',),
'tippemidleren': ('tippemidler',),
'tippemidlerer': ('tippemidler',),
'tippemidlerne': ('tippemidler',),
'tippepremie': ('tippepremie',),
'tippepremien': ('tippepremie',),
'tippepremiene': ('tippepremie',),
'tippepremier': ('tippepremie',),
'tipper': ('tipper',),
'tippere': ('tipper',),
'tipperen': ('tipper',),
'tipperer': ('tipper',),
'tipperne': ('tipper',),
'tipperekka': ('tipperekke',),
'tipperekke': ('tipperekke',),
'tipperekken': ('tipperekke',),
'tipperekkene': ('tipperekke',),
'tipperekker': ('tipperekke',),
'tipperesultat': ('tipperesultat',),
'tipperesultata': ('tipperesultat',),
'tipperesultatene': ('tipperesultat',),
'tipperesultater': ('tipperesultat',),
'tipperesultatet': ('tipperesultat',),
'tippesystem': ('tippesystem',),
'tippesystema': ('tippesystem',),
'tippesystemene': ('tippesystem',),
'tippesystemer': ('tippesystem',),
'tippesystemet': ('tippesystem',),
'tippetegn': ('tippetegn',),
'tippetegna': ('tippetegn',),
'tippetegnene': ('tippetegn',),
'tippetegnet': ('tippetegn',),
'tipping': ('tipping',),
'tippinga': ('tipping',),
'tippingen': ('tipping',),
'tippingene': ('tipping',),
'tippinger': ('tipping',),
'tippoldebarn': ('tippoldebarn',),
'tippoldebarna': ('tippoldebarn',),
'tippoldebarnene': ('tippoldebarn',),
'tippoldebarnet': ('tippoldebarn',),
'tipptippoldefar': ('tipptippoldefar',),
'tipptippoldefaren': ('tipptippoldefar',),
'tipptippoldefedre': ('tipptippoldefar',),
'tipptippoldefedrene': ('tipptippoldefar',),
'tipptippoldemor': ('tipptippoldemor',),
'tipptippoldemora': ('tipptippoldemor',),
'tipptippoldemoren': ('tipptippoldemor',),
'tipptippoldemødre': ('tipptippoldemor',),
'tipptippoldemødrene': ('tipptippoldemor',),
'tipptippoldemødrer': ('tipptippoldemor',),
'tippvogn': ('tippvogn',),
'tippvogna': ('tippvogn',),
'tippvognen': ('tippvogn',),
'tippvognene': ('tippvogn',),
'tippvogner': ('tippvogn',),
'tips': ('tips',),
'tipsa': ('tips',),
'tipsene': ('tips',),
'tipset': ('tips',),
'tirade': ('tirade',),
'tiraden': ('tirade',),
'tiradene': ('tirade',),
'tirader': ('tirade',),
'tiraljør': ('tiraljør',),
'tiraljøren': ('tiraljør',),
'tiraljørene': ('tiraljør',),
'tiraljører': ('tiraljør',),
'tiriltunga': ('tiriltunge',),
'tiriltunge': ('tiriltunge',),
'tiriltungen': ('tiriltunge',),
'tiriltungene': ('tiriltunge',),
'tiriltunger': ('tiriltunge',),
'tirsdag': ('tirsdag',),
'tirsdagen': ('tirsdag',),
'tirsdagene': ('tirsdag',),
'tirsdager': ('tirsdag',),
'tispa': ('tispe',),
'tispe': ('tispe',),
'tispen': ('tispe',),
'tispene': ('tispe',),
'tisper': ('tispe',),
'tiss': ('tiss',),
'tissen': ('tiss',),
'tissene': ('tiss',),
'tisser': ('tiss',),
'tiss': ('tiss',),
'tissa': ('tiss',),
'tissene': ('tiss',),
'tisset': ('tiss',),
'tissemann': ('tissemann',),
'tissemannen': ('tissemann',),
'tissemenn': ('tissemann',),
'tissemennene': ('tissemann',),
'tistel': ('tistel',),
'tistelen': ('tistel',),
'tistlene': ('tistel',),
'tistler': ('tistel',),
'tit': ('tit',),
'titen': ('tit',),
'titene': ('tit',),
'titer': ('tit',),
'tital': ('tital',),
'titala': ('tital',),
'titalene': ('tital',),
'titalet': ('tital',),
'titall': ('titall',),
'titalla': ('titall',),
'titallene': ('titall',),
'titallet': ('titall',),
'titallssystem': ('titallssystem',),
'titallssystema': ('titallssystem',),
'titallssystemene': ('titallssystem',),
'titallssystemer': ('titallssystem',),
'titallssystemet': ('titallssystem',),
'titalssystem': ('titalssystem',),
'titalssystema': ('titalssystem',),
'titalssystemene': ('titalssystem',),
'titalssystemer': ('titalssystem',),
'titalssystemet': ('titalssystem',),
'titalsystem': ('titalsystem',),
'titalsystema': ('titalsystem',),
'titalsystemene': ('titalsystem',),
'titalsystemer': ('titalsystem',),
'titalsystemet': ('titalsystem',),
'titan': ('titan',),
'titanen': ('titan',),
'titanene': ('titan',),
'titaner': ('titan',),
'titan': ('titan',),
'titana': ('titan',),
'titanene': ('titan',),
'titanet': ('titan',),
'titandioksid': ('titandioksid',),
'titandioksida': ('titandioksid',),
'titandioksidene': ('titandioksid',),
'titandioksider': ('titandioksid',),
'titandioksidet': ('titandioksid',),
'titanhvitt': ('titanhvitt',),
'titanjernstein': ('titanjernstein',),
'titanjernsteinen': ('titanjernstein',),
'titanjernsteinene': ('titanjernstein',),
'titanjernsteiner': ('titanjernstein',),
'titankvitt': ('titankvitt',),
'tita': ('tite',),
'tite': ('tite',),
'titen': ('tite',),
'titene': ('tite',),
'titer': ('tite',),
'titid': ('titid',),
'titida': ('titid',),
'titiden': ('titid',),
'titidene': ('titid',),
'titider': ('titid',),
'titoisme': ('titoisme',),
'titoismen': ('titoisme',),
'titoismene': ('titoisme',),
'titoismer': ('titoisme',),
'titoist': ('titoist',),
'titoisten': ('titoist',),
'titoistene': ('titoist',),
'titoister': ('titoist',),
'titreranalysa': ('titreranalyse',),
'titreranalyse': ('titreranalyse',),
'titreranalysen': ('titreranalyse',),
'titreranalysene': ('titreranalyse',),
'titreranalyser': ('titreranalyse',),
'titt': ('titt',),
'titten': ('titt',),
'tittene': ('titt',),
'titter': ('titt',),
'titlene': ('tittel',),
'titler': ('tittel',),
'tittel': ('tittel',),
'tittelen': ('tittel',),
'tittelblad': ('tittelblad',),
'tittelblada': ('tittelblad',),
'tittelbladene': ('tittelblad',),
'tittelblader': ('tittelblad',),
'tittelbladet': ('tittelblad',),
'tittelforsvarer': ('tittelforsvarer',),
'tittelforsvarere': ('tittelforsvarer',),
'tittelforsvareren': ('tittelforsvarer',),
'tittelforsvarerer': ('tittelforsvarer',),
'tittelforsvarerne': ('tittelforsvarer',),
'tittelkamp': ('tittelkamp',),
'tittelkampen': ('tittelkamp',),
'tittelkampene': ('tittelkamp',),
'tittelkamper': ('tittelkamp',),
'tittelkutt': ('tittelkutt',),
'tittelkutta': ('tittelkutt',),
'tittelkuttene': ('tittelkutt',),
'tittelkuttet': ('tittelkutt',),
'tittelnovella': ('tittelnovelle',),
'tittelnovelle': ('tittelnovelle',),
'tittelnovellen': ('tittelnovelle',),
'tittelnovellene': ('tittelnovelle',),
'tittelnoveller': ('tittelnovelle',),
'tittelrolla': ('tittelrolle',),
'tittelrolle': ('tittelrolle',),
'tittelrollen': ('tittelrolle',),
'tittelrollene': ('tittelrolle',),
'tittelroller': ('tittelrolle',),
'titter': ('titter',),
'tittere': ('titter',),
'titteren': ('titter',),
'titterer': ('titter',),
'titterne': ('titter',),
'titteskap': ('titteskap',),
'titteskapa': ('titteskap',),
'titteskapene': ('titteskap',),
'titteskapet': ('titteskap',),
'titulatur': ('titulatur',),
'titulaturen': ('titulatur',),
'titulaturene': ('titulatur',),
'titulaturer': ('titulatur',),
'tiur': ('tiur',),
'tiuren': ('tiur',),
'tiurene': ('tiur',),
'tiurer': ('tiur',),
'tiurleik': ('tiurleik',),
'tiurleiken': ('tiurleik',),
'tiurleikene': ('tiurleik',),
'tiurleiker': ('tiurleik',),
'tivoli': ('tivoli',),
'tivolia': ('tivoli',),
'tivoliene': ('tivoli',),
'tivolier': ('tivoli',),
'tivoliet': ('tivoli',),
'tiår': ('tiår',),
'tiåra': ('tiår',),
'tiårene': ('tiår',),
'tiåret': ('tiår',),
'tiåring': ('tiåring',),
'tiåringen': ('tiåring',),
'tiåringene': ('tiåring',),
'tiåringer': ('tiåring',),
'tiårsalder': ('tiårsalder',),
'tiårsaldere': ('tiårsalder',),
'tiårsalderen': ('tiårsalder',),
'tiårsalderer': ('tiårsalder',),
'tiårsalderne': ('tiårsalder',),
'tiårsaldre': ('tiårsalder',),
'tiårsaldrene': ('tiårsalder',),
'tiårsaldrer': ('tiårsalder',),
'tiøre': ('tiøre',),
'tiøren': ('tiøre',),
'tiørene': ('tiøre',),
'tiører': ('tiøre',),
'tiøring': ('tiøring',),
'tiøringen': ('tiøring',),
'tiøringene': ('tiøring',),
'tiøringer': ('tiøring',),
'tja': ('tja',),
'tjaa': ('tja',),
'tjaene': ('tja',),
'tjaet': ('tja',),
'tjadder': ('tjadder',),
'tjaddera': ('tjadder',),
'tjaddere': ('tjadder',),
'tjadderene': ('tjadder',),
'tjadderet': ('tjadder',),
'tjadderne': ('tjadder',),
'tjafs': ('tjafs',),
'tjafsen': ('tjafs',),
'tjafsene': ('tjafs',),
'tjafser': ('tjafs',),
'tjalk': ('tjalk',),
'tjalken': ('tjalk',),
'tjalkene': ('tjalk',),
'tjalker': ('tjalk',),
'tjatt': ('tjatt',),
'tjatta': ('tjatt',),
'tjattene': ('tjatt',),
'tjattet': ('tjatt',),
'tjau': ('tjau',),
'tjaua': ('tjau',),
'tjauene': ('tjau',),
'tjauet': ('tjau',),
'tjeld': ('tjeld',),
'tjelden': ('tjeld',),
'tjeldene': ('tjeld',),
'tjelder': ('tjeld',),
'tjeld': ('tjeld',),
'tjelda': ('tjeld',),
'tjeldene': ('tjeld',),
'tjeldet': ('tjeld',),
'tjener': ('tjener',),
'tjenere': ('tjener',),
'tjeneren': ('tjener',),
'tjenerer': ('tjener',),
'tjenerne': ('tjener',),
'tjenerbolig': ('tjenerbolig',),
'tjenerboligen': ('tjenerbolig',),
'tjenerboligene': ('tjenerbolig',),
'tjenerboliger': ('tjenerbolig',),
'tjenerfløy': ('tjenerfløy',),
'tjenerfløya': ('tjenerfløy',),
'tjenerfløyen': ('tjenerfløy',),
'tjenerfløyene': ('tjenerfløy',),
'tjenerfløyer': ('tjenerfløy',),
'tjenerinna': ('tjenerinne',),
'tjenerinne': ('tjenerinne',),
'tjenerinnen': ('tjenerinne',),
'tjenerinnene': ('tjenerinne',),
'tjenerinner': ('tjenerinne',),
'tjenerskap': ('tjenerskap',),
'tjenerskapa': ('tjenerskap',),
'tjenerskapene': ('tjenerskap',),
'tjenerskapet': ('tjenerskap',),
'tjenerstab': ('tjenerstab',),
'tjenerstaben': ('tjenerstab',),
'tjenerstabene': ('tjenerstab',),
'tjenerstaber': ('tjenerstab',),
'tjeneste': ('tjeneste',),
'tjenesten': ('tjeneste',),
'tjenestene': ('tjeneste',),
'tjenester': ('tjeneste',),
'tjenesteansiennitet': ('tjenesteansiennitet',),
'tjenesteansienniteten': ('tjenesteansiennitet',),
'tjenesteansiennitetene': ('tjenesteansiennitet',),
'tjenesteansienniteter': ('tjenesteansiennitet',),
'tjenestebevis': ('tjenestebevis',),
'tjenestebevisa': ('tjenestebevis',),
'tjenestebevisene': ('tjenestebevis',),
'tjenestebeviser': ('tjenestebevis',),
'tjenestebeviset': ('tjenestebevis',),
'tjenestebolig': ('tjenestebolig',),
'tjenesteboligen': ('tjenestebolig',),
'tjenesteboligene': ('tjenestebolig',),
'tjenesteboliger': ('tjenestebolig',),
'tjenestefolk': ('tjenestefolk',),
'tjenestefolka': ('tjenestefolk',),
'tjenestefolkene': ('tjenestefolk',),
'tjenestefolket': ('tjenestefolk',),
'tjenestefri': ('tjenestefri',),
'tjenestefrimerka': ('tjenestefrimerke',),
'tjenestefrimerke': ('tjenestefrimerke',),
'tjenestefrimerkene': ('tjenestefrimerke',),
'tjenestefrimerker': ('tjenestefrimerke',),
'tjenestefrimerket': ('tjenestefrimerke',),
'tjenestekvinna': ('tjenestekvinne',),
'tjenestekvinne': ('tjenestekvinne',),
'tjenestekvinnen': ('tjenestekvinne',),
'tjenestekvinnene': ('tjenestekvinne',),
'tjenestekvinner': ('tjenestekvinne',),
'tjenestemann': ('tjenestemann',),
'tjenestemannen': ('tjenestemann',),
'tjenestemenn': ('tjenestemann',),
'tjenestemennene': ('tjenestemann',),
'tjenestemerka': ('tjenestemerke',),
'tjenestemerke': ('tjenestemerke',),
'tjenestemerkene': ('tjenestemerke',),
'tjenestemerker': ('tjenestemerke',),
'tjenestemerket': ('tjenestemerke',),
'tjenestereisa': ('tjenestereise',),
'tjenestereise': ('tjenestereise',),
'tjenestereisen': ('tjenestereise',),
'tjenestereisene': ('tjenestereise',),
'tjenestereiser': ('tjenestereise',),
'tjenestetid': ('tjenestetid',),
'tjenestetida': ('tjenestetid',),
'tjenestetiden': ('tjenestetid',),
'tjenestetidene': ('tjenestetid',),
'tjenestetider': ('tjenestetid',),
'tjenestetillegg': ('tjenestetillegg',),
'tjenestetillegga': ('tjenestetillegg',),
'tjenestetilleggene': ('tjenestetillegg',),
'tjenestetillegget': ('tjenestetillegg',),
'tjenesteveg': ('tjenesteveg',),
'tjenestevegen': ('tjenesteveg',),
'tjenestevegene': ('tjenesteveg',),
'tjenesteveger': ('tjenesteveg',),
'tjenestevei': ('tjenestevei',),
'tjenesteveien': ('tjenestevei',),
'tjenesteveiene': ('tjenestevei',),
'tjenesteveier': ('tjenestevei',),
'tjenesteyrka': ('tjenesteyrke',),
'tjenesteyrke': ('tjenesteyrke',),
'tjenesteyrkene': ('tjenesteyrke',),
'tjenesteyrker': ('tjenesteyrke',),
'tjenesteyrket': ('tjenesteyrke',),
'tjern': ('tjern',),
'tjerna': ('tjern',),
'tjernene': ('tjern',),
'tjernet': ('tjern',),
'tjern': ('tjern',),
'tjerna': ('tjern',),
'tjernene': ('tjern',),
'tjernet': ('tjern',),
'tjernblom': ('tjernblom',),
'tjernblommen': ('tjernblom',),
'tjernblommene': ('tjernblom',),
'tjernblommer': ('tjernblom',),
'tjernblom': ('tjernblom',),
'tjernblommen': ('tjernblom',),
'tjernblommene': ('tjernblom',),
'tjernblommer': ('tjernblom',),
'tjommi': ('tjommi',),
'tjommien': ('tjommi',),
'tjommiene': ('tjommi',),
'tjommier': ('tjommi',),
'tjon': ('tjon',),
'tjona': ('tjon',),
'tjonene': ('tjon',),
'tjonet': ('tjon',),
'tjor': ('tjor',),
'tjora': ('tjor',),
'tjorene': ('tjor',),
'tjoret': ('tjor',),
'tjoring': ('tjoring',),
'tjoringa': ('tjoring',),
'tjoringen': ('tjoring',),
'tjoringene': ('tjoring',),
'tjoringer': ('tjoring',),
'tjuagutt': ('tjuagutt',),
'tjuagutten': ('tjuagutt',),
'tjuaguttene': ('tjuagutt',),
'tjuagutter': ('tjuagutt',),
'tjuedel': ('tjuedel',),
'tjuedelen': ('tjuedel',),
'tjuedelene': ('tjuedel',),
'tjuedeler': ('tjuedel',),
'tjueett': ('tjueett',),
'tjuepakning': ('tjuepakning',),
'tjuepakninga': ('tjuepakning',),
'tjuepakningen': ('tjuepakning',),
'tjuepakningene': ('tjuepakning',),
'tjuepakninger': ('tjuepakning',),
'tjueår': ('tjueår',),
'tjueåra': ('tjueår',),
'tjueårene': ('tjueår',),
'tjueåret': ('tjueår',),
'tjueåring': ('tjueåring',),
'tjueåringen': ('tjueåring',),
'tjueåringene': ('tjueåring',),
'tjueåringer': ('tjueåring',),
'tjueårsdag': ('tjueårsdag',),
'tjueårsdagen': ('tjueårsdag',),
'tjueårsdagene': ('tjueårsdag',),
'tjueårsdager': ('tjueårsdag',),
'tjug': ('tjug',),
'tjuga': ('tjug',),
'tjugene': ('tjug',),
'tjuget': ('tjug',),
'tjukka': ('tjukka',),
'tjukkas': ('tjukkas',),
'tjukkasen': ('tjukkas',),
'tjukkasene': ('tjukkas',),
'tjukkaser': ('tjukkas',),
'tjukka': ('tjukke',),
'tjukke': ('tjukke',),
'tjukken': ('tjukke',),
'tjukkene': ('tjukke',),
'tjukker': ('tjukke',),
'tjukkelse': ('tjukkelse',),
'tjukkelsen': ('tjukkelse',),
'tjukkelsene': ('tjukkelse',),
'tjukkelser': ('tjukkelse',),
'tjukken': ('tjukken',),
'tjukken': ('tjukken',),
'tjukklegg': ('tjukklegg',),
'tjukkleggen': ('tjukklegg',),
'tjukkleggene': ('tjukklegg',),
'tjukklegger': ('tjukklegg',),
'tjukkmelk': ('tjukkmelk',),
'tjukkmelka': ('tjukkmelk',),
'tjukkmelken': ('tjukkmelk',),
'tjukkmelkene': ('tjukkmelk',),
'tjukkmelker': ('tjukkmelk',),
'tjukkmjølk': ('tjukkmjølk',),
'tjukkmjølka': ('tjukkmjølk',),
'tjukkmjølken': ('tjukkmjølk',),
'tjukkmjølkene': ('tjukkmjølk',),
'tjukkmjølker': ('tjukkmjølk',),
'tjukktarm': ('tjukktarm',),
'tjukktarmen': ('tjukktarm',),
'tjukktarmene': ('tjukktarm',),
'tjukktarmer': ('tjukktarm',),
'tjuvegods': ('tjuvegods',),
'tjuvegodsa': ('tjuvegods',),
'tjuvegodsene': ('tjuvegods',),
'tjuvegodset': ('tjuvegods',),
'tjuveradd': ('tjuveradd',),
'tjuveradden': ('tjuveradd',),
'tjuveraddene': ('tjuveradd',),
'tjuveradder': ('tjuveradd',),
'tjuveri': ('tjuveri',),
'tjuveria': ('tjuveri',),
'tjuveriene': ('tjuveri',),
'tjuverier': ('tjuveri',),
'tjuveriet': ('tjuveri',),
'tjuverialarm': ('tjuverialarm',),
'tjuverialarmen': ('tjuverialarm',),
'tjuverialarmene': ('tjuverialarm',),
'tjuverialarmer': ('tjuverialarm',),
'tjuveriforsikring': ('tjuveriforsikring',),
'tjuveriforsikringa': ('tjuveriforsikring',),
'tjuveriforsikringen': ('tjuveriforsikring',),
'tjuveriforsikringene': ('tjuveriforsikring',),
'tjuveriforsikringer': ('tjuveriforsikring',),
'tjuvfiska': ('tjuvfiske',),
'tjuvfiske': ('tjuvfiske',),
'tjuvfiskene': ('tjuvfiske',),
'tjuvfisker': ('tjuvfiske',),
'tjuvfisket': ('tjuvfiske',),
'tjuvfisker': ('tjuvfisker',),
'tjuvfiskere': ('tjuvfisker',),
'tjuvfiskeren': ('tjuvfisker',),
'tjuvfiskerer': ('tjuvfisker',),
'tjuvfiskerne': ('tjuvfisker',),
'tjuvjo': ('tjuvjo',),
'tjuvjoen': ('tjuvjo',),
'tjuvjoene': ('tjuvjo',),
'tjuvjoer': ('tjuvjo',),
'tjuvperm': ('tjuvperm',),
'tjuvpermen': ('tjuvperm',),
'tjuvpermene': ('tjuvperm',),
'tjuvpermer': ('tjuvperm',),
'tjåk': ('tjåk',),
'tjåka': ('tjåk',),
'tjåkene': ('tjåk',),
'tjåket': ('tjåk',),
'tjæra': ('tjære',),
'tjære': ('tjære',),
'tjæren': ('tjære',),
'tjærene': ('tjære',),
'tjærer': ('tjære',),
'tjæreband': ('tjæreband',),
'tjærebanda': ('tjæreband',),
'tjærebandene': ('tjæreband',),
'tjærebandet': ('tjæreband',),
'tjæreblom': ('tjæreblom',),
'tjæreblommen': ('tjæreblom',),
'tjæreblommene': ('tjæreblom',),
'tjæreblommer': ('tjæreblom',),
'tjæreblomst': ('tjæreblomst',),
'tjæreblomsten': ('tjæreblomst',),
'tjæreblomstene': ('tjæreblomst',),
'tjæreblomster': ('tjæreblomst',),
'tjærebrenner': ('tjærebrenner',),
'tjærebrennere': ('tjærebrenner',),
'tjærebrenneren': ('tjærebrenner',),
'tjærebrennerer': ('tjærebrenner',),
'tjærebrennerne': ('tjærebrenner',),
'tjærebånd': ('tjærebånd',),
'tjærebånda': ('tjærebånd',),
'tjærebåndene': ('tjærebånd',),
'tjærebåndet': ('tjærebånd',),
'tjærekost': ('tjærekost',),
'tjærekosten': ('tjærekost',),
'tjærekostene': ('tjærekost',),
'tjærekoster': ('tjærekost',),
'tjærepapp': ('tjærepapp',),
'tjærepappen': ('tjærepapp',),
'tjærepappene': ('tjærepapp',),
'tjærepapper': ('tjærepapp',),
'tjæresåpa': ('tjæresåpe',),
'tjæresåpe': ('tjæresåpe',),
'tjæresåpen': ('tjæresåpe',),
'tjæresåpene': ('tjæresåpe',),
'tjæresåper': ('tjæresåpe',),
'tjørnblom': ('tjørnblom',),
'tjørnblommen': ('tjørnblom',),
'tjørnblommene': ('tjørnblom',),
'tjørnblommer': ('tjørnblom',),
'tjørnblom': ('tjørnblom',),
'tjørnblommen': ('tjørnblom',),
'tjørnblommene': ('tjørnblom',),
'tjørnblommer': ('tjørnblom',),
'to': ('to',),
'toa': ('to',),
'toen': ('to',),
'toene': ('to',),
'toer': ('to',),
'toet': ('to',),
'toakter': ('toakter',),
'toaktere': ('toakter',),
'toakteren': ('toakter',),
'toakterer': ('toakter',),
'toakterne': ('toakter',),
'toalett': ('toalett',),
'toaletta': ('toalett',),
'toalettene': ('toalett',),
'toaletter': ('toalett',),
'toalettet': ('toalett',),
'toalettbord': ('toalettbord',),
'toalettborda': ('toalettbord',),
'toalettbordene': ('toalettbord',),
'toalettborder': ('toalettbord',),
'toalettbordet': ('toalettbord',),
'toalettkommode': ('toalettkommode',),
'toalettkommoden': ('toalettkommode',),
'toalettkommodene': ('toalettkommode',),
'toalettkommoder': ('toalettkommode',),
'toalettpapir': ('toalettpapir',),
'toalettpapira': ('toalettpapir',),
'toalettpapirene': ('toalettpapir',),
'toalettpapirer': ('toalettpapir',),
'toalettpapiret': ('toalettpapir',),
'toalettsakene': ('toalettsaker',),
'toalettsaker': ('toalettsaker',),
'toalettsåpa': ('toalettsåpe',),
'toalettsåpe': ('toalettsåpe',),
'toalettsåpen': ('toalettsåpe',),
'toalettsåpene': ('toalettsåpe',),
'toalettsåper': ('toalettsåpe',),
'toast': ('toast',),
'toasten': ('toast',),
'toastene': ('toast',),
'toaster': ('toast',),
'toastmaster': ('toastmaster',),
'toastmastere': ('toastmaster',),
'toastmasteren': ('toastmaster',),
'toastmasterer': ('toastmaster',),
'toastmasterne': ('toastmaster',),
'tobager': ('tobager',),
'tobagere': ('tobager',),
'tobageren': ('tobager',),
'tobagerer': ('tobager',),
'tobagerne': ('tobager',),
'tobakk': ('tobakk',),
'tobakken': ('tobakk',),
'tobakkene': ('tobakk',),
'tobakker': ('tobakk',),
'tobakksfabrikk': ('tobakksfabrikk',),
'tobakksfabrikken': ('tobakksfabrikk',),
'tobakksfabrikkene': ('tobakksfabrikk',),
'tobakksfabrikker': ('tobakksfabrikk',),
'tobakkshandler': ('tobakkshandler',),
'tobakkshandlere': ('tobakkshandler',),
'tobakkshandleren': ('tobakkshandler',),
'tobakkshandlerer': ('tobakkshandler',),
'tobakkshandlerne': ('tobakkshandler',),
'tobakksplanta': ('tobakksplante',),
'tobakksplante': ('tobakksplante',),
'tobakksplanten': ('tobakksplante',),
'tobakksplantene': ('tobakksplante',),
'tobakksplanter': ('tobakksplante',),
'tobakkspung': ('tobakkspung',),
'tobakkspungen': ('tobakkspung',),
'tobakkspungene': ('tobakkspung',),
'tobakkspunger': ('tobakkspung',),
'tobarnsfamilie': ('tobarnsfamilie',),
'tobarnsfamilien': ('tobarnsfamilie',),
'tobarnsfamiliene': ('tobarnsfamilie',),
'tobarnsfamilier': ('tobarnsfamilie',),
'tobarnssystem': ('tobarnssystem',),
'tobarnssystema': ('tobarnssystem',),
'tobarnssystemene': ('tobarnssystem',),
'tobarnssystemer': ('tobarnssystem',),
'tobarnssystemet': ('tobarnssystem',),
'tobb': ('tobb',),
'tobben': ('tobb',),
'tobbene': ('tobb',),
'tobber': ('tobb',),
'tobbe': ('tobbe',),
'tobben': ('tobbe',),
'tobbene': ('tobbe',),
'tobber': ('tobbe',),
'tobis': ('tobis',),
'tobisen': ('tobis',),
'tobisene': ('tobis',),
'tobiser': ('tobis',),
'toboggan': ('toboggan',),
'tobogganen': ('toboggan',),
'tobogganene': ('toboggan',),
'tobogganer': ('toboggan',),
'toccata': ('toccata',),
'toccataen': ('toccata',),
'toccataene': ('toccata',),
'toccataer': ('toccata',),
'todagersritt': ('todagersritt',),
'todagersritta': ('todagersritt',),
'todagersrittene': ('todagersritt',),
'todagersrittet': ('todagersritt',),
'toddi': ('toddi',),
'toddien': ('toddi',),
'toddiene': ('toddi',),
'toddier': ('toddi',),
'toer': ('toer',),
'toere': ('toer',),
'toeren': ('toer',),
'toerer': ('toer',),
'toerne': ('toer',),
'tofeltsveg': ('tofeltsveg',),
'tofeltsvegen': ('tofeltsveg',),
'tofeltsvegene': ('tofeltsveg',),
'tofeltsveger': ('tofeltsveg',),
'tofeltsvei': ('tofeltsvei',),
'tofeltsveien': ('tofeltsvei',),
'tofeltsveiene': ('tofeltsvei',),
'tofeltsveier': ('tofeltsvei',),
'tofoting': ('tofoting',),
'tofotingen': ('tofoting',),
'tofotingene': ('tofoting',),
'tofotinger': ('tofoting',),
'tofta': ('tofte',),
'tofte': ('tofte',),
'toften': ('tofte',),
'toftene': ('tofte',),
'tofter': ('tofte',),
'toføtting': ('toføtting',),
'toføttingen': ('toføtting',),
'toføttingene': ('toføtting',),
'toføttinger': ('toføtting',),
'tog': ('tog',),
'toga': ('tog',),
'togene': ('tog',),
'toget': ('tog',),
'toga': ('toga',),
'togaen': ('toga',),
'togaene': ('toga',),
'togaer': ('toga',),
'togbrett': ('togbrett',),
'togbretta': ('togbrett',),
'togbrettene': ('togbrett',),
'togbretter': ('togbrett',),
'togbrettet': ('togbrett',),
'togbytta': ('togbytte',),
'togbytte': ('togbytte',),
'togbyttene': ('togbytte',),
'togbytter': ('togbytte',),
'togbyttet': ('togbytte',),
'togenerasjonsbolig': ('togenerasjonsbolig',),
'togenerasjonsboligen': ('togenerasjonsbolig',),
'togenerasjonsboligene': ('togenerasjonsbolig',),
'togenerasjonsboliger': ('togenerasjonsbolig',),
'togforbindelse': ('togforbindelse',),
'togforbindelsen': ('togforbindelse',),
'togforbindelsene': ('togforbindelse',),
'togforbindelser': ('togforbindelse',),
'togfører': ('togfører',),
'togførere': ('togfører',),
'togføreren': ('togfører',),
'togførerer': ('togfører',),
'togførerne': ('togfører',),
'togoleser': ('togoleser',),
'togolesere': ('togoleser',),
'togoleseren': ('togoleser',),
'togoleserer': ('togoleser',),
'togoleserne': ('togoleser',),
'togreisa': ('togreise',),
'togreise': ('togreise',),
'togreisen': ('togreise',),
'togreisene': ('togreise',),
'togreiser': ('togreise',),
'togruta': ('togrute',),
'togrute': ('togrute',),
'togruten': ('togrute',),
'togrutene': ('togrute',),
'togruter': ('togrute',),
'togsett': ('togsett',),
'togsetta': ('togsett',),
'togsettene': ('togsett',),
'togsettet': ('togsett',),
'togskifta': ('togskifte',),
'togskifte': ('togskifte',),
'togskiftene': ('togskifte',),
'togskifter': ('togskifte',),
'togskiftet': ('togskifte',),
'togvertinna': ('togvertinne',),
'togvertinne': ('togvertinne',),
'togvertinnen': ('togvertinne',),
'togvertinnene': ('togvertinne',),
'togvertinner': ('togvertinne',),
'tohjuling': ('tohjuling',),
'tohjulingen': ('tohjuling',),
'tohjulingene': ('tohjuling',),
'tohjulinger': ('tohjuling',),
'tohjulssykkel': ('tohjulssykkel',),
'tohjulssykkelen': ('tohjulssykkel',),
'tohjulssyklene': ('tohjulssykkel',),
'tohjulssykler': ('tohjulssykkel',),
'tokaier': ('tokaier',),
'tokaiere': ('tokaier',),
'tokaieren': ('tokaier',),
'tokaierer': ('tokaier',),
'tokaierne': ('tokaier',),
'tokammersystem': ('tokammersystem',),
'tokammersystema': ('tokammersystem',),
'tokammersystemene': ('tokammersystem',),
'tokammersystemer': ('tokammersystem',),
'tokammersystemet': ('tokammersystem',),
'tokar': ('tokar',),
'tokaren': ('tokar',),
'tokarene': ('tokar',),
'tokarer': ('tokar',),
'tokarisk': ('tokarisk',),
'tokarisken': ('tokarisk',),
'tokariskene': ('tokarisk',),
'tokarisker': ('tokarisk',),
'toksikolog': ('toksikolog',),
'toksikologen': ('toksikolog',),
'toksikologene': ('toksikolog',),
'toksikologer': ('toksikolog',),
'toksikologi': ('toksikologi',),
'toksikologien': ('toksikologi',),
'toksikologiene': ('toksikologi',),
'toksikologier': ('toksikologi',),
'toksikoman': ('toksikoman',),
'toksikomanen': ('toksikoman',),
'toksikomanene': ('toksikoman',),
'toksikomaner': ('toksikoman',),
'toksikomani': ('toksikomani',),
'toksikomanien': ('toksikomani',),
'toksikomaniene': ('toksikomani',),
'toksikomanier': ('toksikomani',),
'toksikose': ('toksikose',),
'toksikosen': ('toksikose',),
'toksikosene': ('toksikose',),
'toksikoser': ('toksikose',),
'toksin': ('toksin',),
'toksina': ('toksin',),
'toksinene': ('toksin',),
'toksiner': ('toksin',),
'toksinet': ('toksin',),
'toksisitet': ('toksisitet',),
'toksisiteten': ('toksisitet',),
'toksisitetene': ('toksisitet',),
'toksisiteter': ('toksisitet',),
'tokt': ('tokt',),
'tokta': ('tokt',),
'toktene': ('tokt',),
'tokter': ('tokt',),
'toktet': ('tokt',),
'tokt': ('tokt',),
'tokta': ('tokt',),
'tokten': ('tokt',),
'toktene': ('tokt',),
'tokter': ('tokt',),
'toleranse': ('toleranse',),
'toleransen': ('toleranse',),
'toleransene': ('toleranse',),
'toleranser': ('toleranse',),
'toleransegrensa': ('toleransegrense',),
'toleransegrense': ('toleransegrense',),
'toleransegrensen': ('toleransegrense',),
'toleransegrensene': ('toleransegrense',),
'toleransegrenser': ('toleransegrense',),
'toliter': ('toliter',),
'tolitere': ('toliter',),
'toliteren': ('toliter',),
'toliterer': ('toliter',),
'toliterne': ('toliter',),
'tolk': ('tolk',),
'tolken': ('tolk',),
'tolkene': ('tolk',),
'tolker': ('tolk',),
'tolking': ('tolking',),
'tolkinga': ('tolking',),
'tolkingen': ('tolking',),
'tolkingene': ('tolking',),
'tolkinger': ('tolking',),
'tolkning': ('tolkning',),
'tolkninga': ('tolkning',),
'tolkningen': ('tolkning',),
'tolkningene': ('tolkning',),
'tolkninger': ('tolkning',),
'tollbu': ('tollbu',),
'tollbua': ('tollbu',),
'tollbuen': ('tollbu',),
'tollbuene': ('tollbu',),
'tollbuer': ('tollbu',),
'tolle': ('tolle',),
'tollen': ('tolle',),
'tollene': ('tolle',),
'toller': ('tolle',),
'tollegang': ('tollegang',),
'tollegangen': ('tollegang',),
'tollegangene': ('tollegang',),
'tolleganger': ('tollegang',),
'tollekniv': ('tollekniv',),
'tollekniven': ('tollekniv',),
'tolleknivene': ('tollekniv',),
'tollekniver': ('tollekniv',),
'tollepinn': ('tollepinn',),
'tollepinnen': ('tollepinn',),
'tollepinnene': ('tollepinn',),
'tollepinner': ('tollepinn',),
'tollepinne': ('tollepinne',),
'tollepinnen': ('tollepinne',),
'tollepinnene': ('tollepinne',),
'tollepinner': ('tollepinne',),
'toller': ('toller',),
'tollere': ('toller',),
'tolleren': ('toller',),
'tollerer': ('toller',),
'tollerne': ('toller',),
'tollkniv': ('tollkniv',),
'tollkniven': ('tollkniv',),
'tollknivene': ('tollkniv',),
'tollkniver': ('tollkniv',),
'tollmur': ('tollmur',),
'tollmuren': ('tollmur',),
'tollmurene': ('tollmur',),
'tollmurer': ('tollmur',),
'tollsats': ('tollsats',),
'tollsatsen': ('tollsats',),
'tollsatsene': ('tollsats',),
'tollsatser': ('tollsats',),
'tollstasjon': ('tollstasjon',),
'tollstasjonen': ('tollstasjon',),
'tollstasjonene': ('tollstasjon',),
'tollstasjoner': ('tollstasjon',),
'tollunion': ('tollunion',),
'tollunionen': ('tollunion',),
'tollunionene': ('tollunion',),
'tollunioner': ('tollunion',),
'tolvdel': ('tolvdel',),
'tolvdelen': ('tolvdel',),
'tolvdelene': ('tolvdel',),
'tolvdeler': ('tolvdel',),
'tolver': ('tolver',),
'tolvere': ('tolver',),
'tolveren': ('tolver',),
'tolverer': ('tolver',),
'tolverne': ('tolver',),
'tolvfingertarm': ('tolvfingertarm',),
'tolvfingertarmen': ('tolvfingertarm',),
'tolvfingertarmene': ('tolvfingertarm',),
'tolvfingertarmer': ('tolvfingertarm',),
'tolvhundretal': ('tolvhundretal',),
'tolvhundretala': ('tolvhundretal',),
'tolvhundretalene': ('tolvhundretal',),
'tolvhundretalet': ('tolvhundretal',),
'tolvhundretall': ('tolvhundretall',),
'tolvhundretalla': ('tolvhundretall',),
'tolvhundretallene': ('tolvhundretall',),
'tolvhundretallet': ('tolvhundretall',),
'tolvtedel': ('tolvtedel',),
'tolvtedelen': ('tolvtedel',),
'tolvtedelene': ('tolvtedel',),
'tolvtedeler': ('tolvtedel',),
'tolvtid': ('tolvtid',),
'tolvtida': ('tolvtid',),
'tolvtiden': ('tolvtid',),
'tolvtidene': ('tolvtid',),
'tolvtider': ('tolvtid',),
'tolvtonemusikk': ('tolvtonemusikk',),
'tolvtonemusikken': ('tolvtonemusikk',),
'tolvtonemusikkene': ('tolvtonemusikk',),
'tolvtonemusikker': ('tolvtonemusikk',),
'tolvåring': ('tolvåring',),
'tolvåringen': ('tolvåring',),
'tolvåringene': ('tolvåring',),
'tolvåringer': ('tolvåring',),
'tolvårsalder': ('tolvårsalder',),
'tolvårsaldere': ('tolvårsalder',),
'tolvårsalderen': ('tolvårsalder',),
'tolvårsalderer': ('tolvårsalder',),
'tolvårsalderne': ('tolvårsalder',),
'tolvårsaldre': ('tolvårsalder',),
'tolvårsaldrene': ('tolvårsalder',),
'tolvårsaldrer': ('tolvårsalder',),
'tom': ('tom',),
'tommen': ('tom',),
'tommene': ('tom',),
'tommer': ('tom',),
'tomahawk': ('tomahawk',),
'tomahawken': ('tomahawk',),
'tomahawkene': ('tomahawk',),
'tomahawker': ('tomahawk',),
'tomannsbolig': ('tomannsbolig',),
'tomannsboligen': ('tomannsbolig',),
'tomannsboligene': ('tomannsbolig',),
'tomannsboliger': ('tomannsbolig',),
'tomannstelt': ('tomannstelt',),
'tomannstelta': ('tomannstelt',),
'tomannsteltene': ('tomannstelt',),
'tomannstelter': ('tomannstelt',),
'tomannsteltet': ('tomannstelt',),
'tomaster': ('tomaster',),
'tomastere': ('tomaster',),
'tomasteren': ('tomaster',),
'tomasterer': ('tomaster',),
'tomasterne': ('tomaster',),
'tomat': ('tomat',),
'tomaten': ('tomat',),
'tomatene': ('tomat',),
'tomater': ('tomat',),
'tomatketchup': ('tomatketchup',),
'tomatketchupen': ('tomatketchup',),
'tomatketchupene': ('tomatketchup',),
'tomatketchuper': ('tomatketchup',),
'tomatkniv': ('tomatkniv',),
'tomatkniven': ('tomatkniv',),
'tomatknivene': ('tomatkniv',),
'tomatkniver': ('tomatkniv',),
'tomatplanta': ('tomatplante',),
'tomatplante': ('tomatplante',),
'tomatplanten': ('tomatplante',),
'tomatplantene': ('tomatplante',),
'tomatplanter': ('tomatplante',),
'tomatsaft': ('tomatsaft',),
'tomatsafta': ('tomatsaft',),
'tomatsaften': ('tomatsaft',),
'tomatsaftene': ('tomatsaft',),
'tomatsafter': ('tomatsaft',),
'tomatsalat': ('tomatsalat',),
'tomatsalaten': ('tomatsalat',),
'tomatsalatene': ('tomatsalat',),
'tomatsalater': ('tomatsalat',),
'tomatsaus': ('tomatsaus',),
'tomatsausen': ('tomatsaus',),
'tomatsausene': ('tomatsaus',),
'tomatsauser': ('tomatsaus',),
'tomatsuppa': ('tomatsuppe',),
'tomatsuppe': ('tomatsuppe',),
'tomatsuppen': ('tomatsuppe',),
'tomatsuppene': ('tomatsuppe',),
'tomatsupper': ('tomatsuppe',),
'tombola': ('tombola',),
'tombolaen': ('tombola',),
'tombolaene': ('tombola',),
'tombolaer': ('tombola',),
'tomflaska': ('tomflaske',),
'tomflaske': ('tomflaske',),
'tomflasken': ('tomflaske',),
'tomflaskene': ('tomflaske',),
'tomflasker': ('tomflaske',),
'tomgang': ('tomgang',),
'tomgangen': ('tomgang',),
'tomgangene': ('tomgang',),
'tomganger': ('tomgang',),
'tomhet': ('tomhet',),
'tomheta': ('tomhet',),
'tomheten': ('tomhet',),
'tomhetene': ('tomhet',),
'tomheter': ('tomhet',),
'tomme': ('tomme',),
'tommen': ('tomme',),
'tommene': ('tomme',),
'tommer': ('tomme',),
'tomlene': ('tommel',),
'tomler': ('tommel',),
'tommel': ('tommel',),
'tommelen': ('tommel',),
'tommelfinger': ('tommelfinger',),
'tommelfingeren': ('tommelfinger',),
'tommelfingre': ('tommelfinger',),
'tommelfingrene': ('tommelfinger',),
'tommelfingrer': ('tommelfinger',),
'tommelfingerregel': ('tommelfingerregel',),
'tommelfingerregelen': ('tommelfingerregel',),
'tommelfingerreglene': ('tommelfingerregel',),
'tommelfingerregler': ('tommelfingerregel',),
'tommeltott': ('tommeltott',),
'tommeltotten': ('tommeltott',),
'tommeltottene': ('tommeltott',),
'tommeltotter': ('tommeltott',),
'tommeskrue': ('tommeskrue',),
'tommeskruen': ('tommeskrue',),
'tommeskruene': ('tommeskrue',),
'tommeskruer': ('tommeskrue',),
'tommestokk': ('tommestokk',),
'tommestokken': ('tommestokk',),
'tommestokkene': ('tommestokk',),
'tommestokker': ('tommestokk',),
'tommygun': ('tommygun',),
'tommygunen': ('tommygun',),
'tommygunene': ('tommygun',),
'tommyguner': ('tommygun',),
'tomrom': ('tomrom',),
'tomromma': ('tomrom',),
'tomrommene': ('tomrom',),
'tomrommet': ('tomrom',),
'tomsing': ('tomsing',),
'tomsingen': ('tomsing',),
'tomsingene': ('tomsing',),
'tomsinger': ('tomsing',),
'tomt': ('tomt',),
'tomta': ('tomt',),
'tomten': ('tomt',),
'tomtene': ('tomt',),
'tomter': ('tomt',),
'tomte': ('tomte',),
'tomten': ('tomte',),
'tomtene': ('tomte',),
'tomter': ('tomte',),
'tomteareal': ('tomteareal',),
'tomteareala': ('tomteareal',),
'tomtearealene': ('tomteareal',),
'tomtearealer': ('tomteareal',),
'tomtearealet': ('tomteareal',),
'tomtegubbe': ('tomtegubbe',),
'tomtegubben': ('tomtegubbe',),
'tomtegubbene': ('tomtegubbe',),
'tomtegubber': ('tomtegubbe',),
'tomtekjøp': ('tomtekjøp',),
'tomtekjøpa': ('tomtekjøp',),
'tomtekjøpene': ('tomtekjøp',),
'tomtekjøpet': ('tomtekjøp',),
'tomtesalg': ('tomtesalg',),
'tomtesalga': ('tomtesalg',),
'tomtesalgene': ('tomtesalg',),
'tomtesalget': ('tomtesalg',),
'tomtespekulasjon': ('tomtespekulasjon',),
'tomtespekulasjonen': ('tomtespekulasjon',),
'tomtespekulasjonene': ('tomtespekulasjon',),
'tomtespekulasjoner': ('tomtespekulasjon',),
'tomteverdi': ('tomteverdi',),
'tomteverdien': ('tomteverdi',),
'tomteverdiene': ('tomteverdi',),
'tomteverdier': ('tomteverdi',),
'tonalitet': ('tonalitet',),
'tonaliteten': ('tonalitet',),
'tonalitetene': ('tonalitet',),
'tonaliteter': ('tonalitet',),
'tone': ('tone',),
'tonen': ('tone',),
'tonene': ('tone',),
'toner': ('tone',),
'toneart': ('toneart',),
'tonearta': ('toneart',),
'tonearten': ('toneart',),
'toneartene': ('toneart',),
'tonearter': ('toneart',),
'tonebad': ('tonebad',),
'tonebada': ('tonebad',),
'tonebadene': ('tonebad',),
'tonebadet': ('tonebad',),
'tonedikter': ('tonedikter',),
'tonediktere': ('tonedikter',),
'tonedikteren': ('tonedikter',),
'tonedikterer': ('tonedikter',),
'tonedikterne': ('tonedikter',),
'tonefall': ('tonefall',),
'tonefalla': ('tonefall',),
'tonefallene': ('tonefall',),
'tonefallet': ('tonefall',),
'tonegang': ('tonegang',),
'tonegangen': ('tonegang',),
'tonegangene': ('tonegang',),
'toneganger': ('tonegang',),
'tonelag': ('tonelag',),
'tonelaga': ('tonelag',),
'tonelagene': ('tonelag',),
'tonelaget': ('tonelag',),
'toneleia': ('toneleie',),
'toneleie': ('toneleie',),
'toneleiene': ('toneleie',),
'toneleier': ('toneleie',),
'toneleiet': ('toneleie',),
'tonem': ('tonem',),
'tonema': ('tonem',),
'tonemene': ('tonem',),
'tonemer': ('tonem',),
'tonemet': ('tonem',),
'tonetreff': ('tonetreff',),
'tonetreffa': ('tonetreff',),
'tonetreffene': ('tonetreff',),
'tonetreffet': ('tonetreff',),
'tonetrinn': ('tonetrinn',),
'tonetrinna': ('tonetrinn',),
'tonetrinnene': ('tonetrinn',),
'tonetrinnet': ('tonetrinn',),
'tonganer': ('tonganer',),
'tonganere': ('tonganer',),
'tonganeren': ('tonganer',),
'tonganerer': ('tonganer',),
'tonganerne': ('tonganer',),
'tonic water': ('tonic water',),
'tonika': ('tonika',),
'tonikaen': ('tonika',),
'tonikaene': ('tonika',),
'tonikaer': ('tonika',),
'toning': ('toning',),
'toninga': ('toning',),
'toningen': ('toning',),
'toningene': ('toning',),
'toninger': ('toning',),
'tonn': ('tonn',),
'tonna': ('tonn',),
'tonnene': ('tonn',),
'tonnet': ('tonn',),
'tonnasje': ('tonnasje',),
'tonnasjen': ('tonnasje',),
'tonnasjene': ('tonnasje',),
'tonnasjer': ('tonnasje',),
'tonnkilometer': ('tonnkilometer',),
'tonnkilometeren': ('tonnkilometer',),
'tonnkilometerne': ('tonnkilometer',),
'tonsill': ('tonsill',),
'tonsillen': ('tonsill',),
'tonsillene': ('tonsill',),
'tonsiller': ('tonsill',),
'tonsillitt': ('tonsillitt',),
'tonsillitten': ('tonsillitt',),
'tonsillittene': ('tonsillitt',),
'tonsillitter': ('tonsillitt',),
'topartisystem': ('topartisystem',),
'topartisystema': ('topartisystem',),
'topartisystemene': ('topartisystem',),
'topartisystemer': ('topartisystem',),
'topartisystemet': ('topartisystem',),
'topas': ('topas',),
'topasen': ('topas',),
'topasene': ('topas',),
'topaser': ('topas',),
'topasfarge': ('topasfarge',),
'topasfargen': ('topasfarge',),
'topasfargene': ('topasfarge',),
'topasfarger': ('topasfarge',),
'topasring': ('topasring',),
'topasringen': ('topasring',),
'topasringene': ('topasring',),
'topasringer': ('topasring',),
'topassmykka': ('topassmykke',),
'topassmykke': ('topassmykke',),
'topassmykkene': ('topassmykke',),
'topassmykker': ('topassmykke',),
'topassmykket': ('topassmykke',),
'toplanskryss': ('toplanskryss',),
'toplanskryssa': ('toplanskryss',),
'toplanskryssene': ('toplanskryss',),
'toplanskrysset': ('toplanskryss',),
'topograf': ('topograf',),
'topografen': ('topograf',),
'topografene': ('topograf',),
'topografer': ('topograf',),
'topografi': ('topografi',),
'topografien': ('topografi',),
'topografiene': ('topografi',),
'topografier': ('topografi',),
'topologi': ('topologi',),
'topologien': ('topologi',),
'topologiene': ('topologi',),
'topologier': ('topologi',),
'topp': ('topp',),
'toppen': ('topp',),
'toppene': ('topp',),
'topper': ('topp',),
'topp-plan': ('topp-plan',),
'topp-plana': ('topp-plan',),
'topp-planene': ('topp-plan',),
'topp-planet': ('topp-plan',),
'topp-punkt': ('topp-punkt',),
'topp-punkta': ('topp-punkt',),
'topp-punktene': ('topp-punkt',),
'topp-punkter': ('topp-punkt',),
'topp-punktet': ('topp-punkt',),
'toppand': ('toppand',),
'toppanda': ('toppand',),
'toppanden': ('toppand',),
'toppendene': ('toppand',),
'toppender': ('toppand',),
'toppbrekk': ('toppbrekk',),
'toppbrekka': ('toppbrekk',),
'toppbrekkene': ('toppbrekk',),
'toppbrekket': ('toppbrekk',),
'toppdykker': ('toppdykker',),
'toppdykkere': ('toppdykker',),
'toppdykkeren': ('toppdykker',),
'toppdykkerer': ('toppdykker',),
'toppdykkerne': ('toppdykker',),
'toppfinansiering': ('toppfinansiering',),
'toppfinansieringa': ('toppfinansiering',),
'toppfinansieringen': ('toppfinansiering',),
'toppfinansieringene': ('toppfinansiering',),
'toppfinansieringer': ('toppfinansiering',),
'toppform': ('toppform',),
'toppforma': ('toppform',),
'toppformen': ('toppform',),
'toppformene': ('toppform',),
'toppformer': ('toppform',),
'topphatt': ('topphatt',),
'topphatten': ('topphatt',),
'topphattene': ('topphatt',),
'topphatter': ('topphatt',),
'topphua': ('topphue',),
'topphue': ('topphue',),
'topphuen': ('topphue',),
'topphuene': ('topphue',),
'topphuer': ('topphue',),
'topphuva': ('topphuve',),
'topphuve': ('topphuve',),
'topphuven': ('topphuve',),
'topphuvene': ('topphuve',),
'topphuver': ('topphuve',),
'toppidrett': ('toppidrett',),
'toppidretten': ('toppidrett',),
'toppidrettene': ('toppidrett',),
'toppidretter': ('toppidrett',),
'topplan': ('topplan',),
'topplana': ('topplan',),
'topplanene': ('topplan',),
'topplanet': ('topplan',),
'topplanterna': ('topplanterne',),
'topplanterne': ('topplanterne',),
'topplanternen': ('topplanterne',),
'topplanternene': ('topplanterne',),
'topplanterner': ('topplanterne',),
'topplokk': ('topplokk',),
'topplokka': ('topplokk',),
'topplokkene': ('topplokk',),
'topplokket': ('topplokk',),
'topplua': ('topplue',),
'topplue': ('topplue',),
'toppluen': ('topplue',),
'toppluene': ('topplue',),
'toppluer': ('topplue',),
'toppluva': ('toppluve',),
'toppluve': ('toppluve',),
'toppluven': ('toppluve',),
'toppluvene': ('toppluve',),
'toppluver': ('toppluve',),
'topplån': ('topplån',),
'topplåna': ('topplån',),
'topplånene': ('topplån',),
'topplånet': ('topplån',),
'topplønn': ('topplønn',),
'topplønna': ('topplønn',),
'topplønnen': ('topplønn',),
'topplønnene': ('topplønn',),
'topplønner': ('topplønn',),
'toppmeis': ('toppmeis',),
'toppmeisa': ('toppmeis',),
'toppmeisen': ('toppmeis',),
'toppmeisene': ('toppmeis',),
'toppmeiser': ('toppmeis',),
'toppmål': ('toppmål',),
'toppmåla': ('toppmål',),
'toppmålene': ('toppmål',),
'toppmålet': ('toppmål',),
'toppmøta': ('toppmøte',),
'toppmøte': ('toppmøte',),
'toppmøtene': ('toppmøte',),
'toppmøter': ('toppmøte',),
'toppmøtet': ('toppmøte',),
'toppunkt': ('toppunkt',),
'toppunkta': ('toppunkt',),
'toppunktene': ('toppunkt',),
'toppunkter': ('toppunkt',),
'toppunktet': ('toppunkt',),
'toppventil': ('toppventil',),
'toppventilen': ('toppventil',),
'toppventilene': ('toppventil',),
'toppventiler': ('toppventil',),
'toppvinkel': ('toppvinkel',),
'toppvinkelen': ('toppvinkel',),
'toppvinklene': ('toppvinkel',),
'toppvinkler': ('toppvinkel',),
'topunktsbelta': ('topunktsbelte',),
'topunktsbelte': ('topunktsbelte',),
'topunktsbeltene': ('topunktsbelte',),
'topunktsbelter': ('topunktsbelte',),
'topunktsbeltet': ('topunktsbelte',),
'tora': ('tora',),
'toraen': ('tora',),
'toraene': ('tora',),
'toraer': ('tora',),
'torader': ('torader',),
'toradere': ('torader',),
'toraderen': ('torader',),
'toraderer': ('torader',),
'toraderne': ('torader',),
'toradsbygg': ('toradsbygg',),
'toradsbygga': ('toradsbygg',),
'toradsbyggen': ('toradsbygg',),
'toradsbyggene': ('toradsbygg',),
'toradsbygger': ('toradsbygg',),
'toradsbygget': ('toradsbygg',),
'torden': ('torden',),
'tordenen': ('torden',),
'tordenene': ('torden',),
'tordener': ('torden',),
'tordenbrak': ('tordenbrak',),
'tordenbraka': ('tordenbrak',),
'tordenbrakene': ('tordenbrak',),
'tordenbraket': ('tordenbrak',),
'tordenrøst': ('tordenrøst',),
'tordenrøsta': ('tordenrøst',),
'tordenrøsten': ('tordenrøst',),
'tordenrøstene': ('tordenrøst',),
'tordenrøster': ('tordenrøst',),
'tordentale': ('tordentale',),
'tordentalen': ('tordentale',),
'tordentalene': ('tordentale',),
'tordentaler': ('tordentale',),
'tordenvær': ('tordenvær',),
'tordenværa': ('tordenvær',),
'tordenværene': ('tordenvær',),
'tordenværet': ('tordenvær',),
'tordivel': ('tordivel',),
'tordivelen': ('tordivel',),
'tordivlene': ('tordivel',),
'tordivler': ('tordivel',),
'tora': ('tore',),
'tore': ('tore',),
'toren': ('tore',),
'torene': ('tore',),
'torer': ('tore',),
'toreador': ('toreador',),
'toreadoren': ('toreador',),
'toreadorene': ('toreador',),
'toreadorer': ('toreador',),
'torero': ('torero',),
'toreroen': ('torero',),
'toreroene': ('torero',),
'toreroer': ('torero',),
'torevær': ('torevær',),
'toreværa': ('torevær',),
'toreværene': ('torevær',),
'toreværet': ('torevær',),
'torevær': ('torevær',),
'toreværa': ('torevær',),
'toreværene': ('torevær',),
'toreværet': ('torevær',),
'torg': ('torg',),
'torga': ('torg',),
'torgene': ('torg',),
'torget': ('torg',),
'torgbu': ('torgbu',),
'torgbua': ('torgbu',),
'torgbuen': ('torgbu',),
'torgbuene': ('torgbu',),
'torgbuer': ('torgbu',),
'torgdag': ('torgdag',),
'torgdagen': ('torgdag',),
'torgdagene': ('torgdag',),
'torgdager': ('torgdag',),
'torgkona': ('torgkone',),
'torgkone': ('torgkone',),
'torgkonen': ('torgkone',),
'torgkonene': ('torgkone',),
'torgkoner': ('torgkone',),
'torgpris': ('torgpris',),
'torgprisen': ('torgpris',),
'torgprisene': ('torgpris',),
'torgpriser': ('torgpris',),
'torn': ('torn',),
'tornen': ('torn',),
'tornene': ('torn',),
'torner': ('torn',),
'tornado': ('tornado',),
'tornadoen': ('tornado',),
'tornadoene': ('tornado',),
'tornadoer': ('tornado',),
'tornebusk': ('tornebusk',),
'tornebusken': ('tornebusk',),
'tornebuskene': ('tornebusk',),
'tornebusker': ('tornebusk',),
'tornekratt': ('tornekratt',),
'tornekratta': ('tornekratt',),
'tornekrattene': ('tornekratt',),
'tornekrattet': ('tornekratt',),
'tornekrona': ('tornekrone',),
'tornekrone': ('tornekrone',),
'tornekronen': ('tornekrone',),
'tornekronene': ('tornekrone',),
'tornekroner': ('tornekrone',),
'tornerosesøvn': ('tornerosesøvn',),
'tornerosesøvnen': ('tornerosesøvn',),
'tornerosesøvnene': ('tornerosesøvn',),
'tornerosesøvner': ('tornerosesøvn',),
'tornirisk': ('tornirisk',),
'tornirisken': ('tornirisk',),
'torniriskene': ('tornirisk',),
'tornirisker': ('tornirisk',),
'tornister': ('tornister',),
'tornisteret': ('tornister',),
'tornistra': ('tornister',),
'tornistre': ('tornister',),
'tornistrene': ('tornister',),
'tornistret': ('tornister',),
'torommer': ('torommer',),
'torommere': ('torommer',),
'torommeren': ('torommer',),
'torommerer': ('torommer',),
'torommerne': ('torommer',),
'torp': ('torp',),
'torpa': ('torp',),
'torpene': ('torp',),
'torpet': ('torp',),
'torpedo': ('torpedo',),
'torpedoen': ('torpedo',),
'torpedoene': ('torpedo',),
'torpedoer': ('torpedo',),
'torpedobåt': ('torpedobåt',),
'torpedobåten': ('torpedobåt',),
'torpedobåtene': ('torpedobåt',),
'torpedobåter': ('torpedobåt',),
'torpedojager': ('torpedojager',),
'torpedojagere': ('torpedojager',),
'torpedojageren': ('torpedojager',),
'torpedojagerer': ('torpedojager',),
'torpedojagerne': ('torpedojager',),
'torsdag': ('torsdag',),
'torsdagen': ('torsdag',),
'torsdagene': ('torsdag',),
'torsdager': ('torsdag',),
'torsjon': ('torsjon',),
'torsjonen': ('torsjon',),
'torsjonene': ('torsjon',),
'torsjoner': ('torsjon',),
'torsjonsfjæring': ('torsjonsfjæring',),
'torsjonsfjæringa': ('torsjonsfjæring',),
'torsjonsfjæringen': ('torsjonsfjæring',),
'torsjonsfjæringene': ('torsjonsfjæring',),
'torsjonsfjæringer': ('torsjonsfjæring',),
'torsjonsfjøring': ('torsjonsfjøring',),
'torsjonsfjøringa': ('torsjonsfjøring',),
'torsjonsfjøringen': ('torsjonsfjøring',),
'torsjonsfjøringene': ('torsjonsfjøring',),
'torsjonsfjøringer': ('torsjonsfjøring',),
'torsjonsmoment': ('torsjonsmoment',),
'torsjonsmomenta': ('torsjonsmoment',),
'torsjonsmomentene': ('torsjonsmoment',),
'torsjonsmomenter': ('torsjonsmoment',),
'torsjonsmomentet': ('torsjonsmoment',),
'torsjonsvekt': ('torsjonsvekt',),
'torsjonsvekta': ('torsjonsvekt',),
'torsjonsvekten': ('torsjonsvekt',),
'torsjonsvektene': ('torsjonsvekt',),
'torsjonsvekter': ('torsjonsvekt',),
'torsk': ('torsk',),
'torsken': ('torsk',),
'torskene': ('torsk',),
'torsker': ('torsk',),
'torskeaften': ('torskeaften',),
'torskeaftenen': ('torskeaften',),
'torskeaftenene': ('torskeaften',),
'torskeaftener': ('torskeaften',),
'torskefangst': ('torskefangst',),
'torskefangsten': ('torskefangst',),
'torskefangstene': ('torskefangst',),
'torskefangster': ('torskefangst',),
'torskefilet': ('torskefilet',),
'torskefileten': ('torskefilet',),
'torskefiletene': ('torskefilet',),
'torskefileter': ('torskefilet',),
'torskefiska': ('torskefiske',),
'torskefiske': ('torskefiske',),
'torskefiskene': ('torskefiske',),
'torskefisker': ('torskefiske',),
'torskefisket': ('torskefiske',),
'torskefiskeri': ('torskefiskeri',),
'torskefiskeria': ('torskefiskeri',),
'torskefiskeriene': ('torskefiskeri',),
'torskefiskerier': ('torskefiskeri',),
'torskefiskeriet': ('torskefiskeri',),
'torskelever': ('torskelever',),
'torskelevere': ('torskelever',),
'torskeleveren': ('torskelever',),
'torskeleverer': ('torskelever',),
'torskeleverne': ('torskelever',),
'torskelevra': ('torskelever',),
'torskelevre': ('torskelever',),
'torskelevrene': ('torskelever',),
'torskelevrer': ('torskelever',),
'torskemunn': ('torskemunn',),
'torskemunnen': ('torskemunn',),
'torskemunnene': ('torskemunn',),
'torskemunner': ('torskemunn',),
'torskerogn': ('torskerogn',),
'torskerogna': ('torskerogn',),
'torskerognen': ('torskerogn',),
'torskerognene': ('torskerogn',),
'torskerogner': ('torskerogn',),
'torso': ('torso',),
'torsoen': ('torso',),
'torsoene': ('torso',),
'torsoer': ('torso',),
'tort': ('tort',),
'tortur': ('tortur',),
'torturen': ('tortur',),
'torturene': ('tortur',),
'torturer': ('tortur',),
'torturist': ('torturist',),
'torturisten': ('torturist',),
'torturistene': ('torturist',),
'torturister': ('torturist',),
'torturkammer': ('torturkammer',),
'torturkammeret': ('torturkammer',),
'torturkamra': ('torturkammer',),
'torturkamre': ('torturkammer',),
'torturkamrene': ('torturkammer',),
'torturredskap': ('torturredskap',),
'torturredskapa': ('torturredskap',),
'torturredskapen': ('torturredskap',),
'torturredskapene': ('torturredskap',),
'torturredskaper': ('torturredskap',),
'torturredskapet': ('torturredskap',),
'torv': ('torv',),
'torva': ('torv',),
'torven': ('torv',),
'torvene': ('torv',),
'torver': ('torv',),
'torvet': ('torv',),
'torva': ('torve',),
'torve': ('torve',),
'torven': ('torve',),
'torvene': ('torve',),
'torver': ('torve',),
'torvjord': ('torvjord',),
'torvjorda': ('torvjord',),
'torvjorden': ('torvjord',),
'torvjordene': ('torvjord',),
'torvjorder': ('torvjord',),
'torvmyr': ('torvmyr',),
'torvmyra': ('torvmyr',),
'torvmyren': ('torvmyr',),
'torvmyrene': ('torvmyr',),
'torvmyrer': ('torvmyr',),
'torvstrø': ('torvstrø',),
'torvstrøa': ('torvstrø',),
'torvstrøene': ('torvstrø',),
'torvstrøet': ('torvstrø',),
'torvtak': ('torvtak',),
'torvtaka': ('torvtak',),
'torvtakene': ('torvtak',),
'torvtaket': ('torvtak',),
'torvtak': ('torvtak',),
'torvtaka': ('torvtak',),
'torvtakene': ('torvtak',),
'torvtaket': ('torvtak',),
'tory': ('tory',),
'toryen': ('tory',),
'toryene': ('tory',),
'toryer': ('tory',),
'toseter': ('toseter',),
'tosetere': ('toseter',),
'toseteren': ('toseter',),
'toseterer': ('toseter',),
'toseterne': ('toseter',),
'tosk': ('tosk',),
'tosken': ('tosk',),
'toskene': ('tosk',),
'tosker': ('tosk',),
'toskaftsbinding': ('toskaftsbinding',),
'toskaftsbindinga': ('toskaftsbinding',),
'toskaftsbindingen': ('toskaftsbinding',),
'toskaftsbindingene': ('toskaftsbinding',),
'toskaftsbindinger': ('toskaftsbinding',),
'toskaftsvev': ('toskaftsvev',),
'toskaftsveven': ('toskaftsvev',),
'toskaftsvevene': ('toskaftsvev',),
'toskaftsvever': ('toskaftsvev',),
'toskaner': ('toskaner',),
'toskanere': ('toskaner',),
'toskaneren': ('toskaner',),
'toskanerer': ('toskaner',),
'toskanerne': ('toskaner',),
'toskeskap': ('toskeskap',),
'toskeskapen': ('toskeskap',),
'toskeskapene': ('toskeskap',),
'toskeskaper': ('toskeskap',),
'tosomhet': ('tosomhet',),
'tosomheta': ('tosomhet',),
'tosomheten': ('tosomhet',),
'tosomhetene': ('tosomhet',),
'tosomheter': ('tosomhet',),
'tossa': ('tosse',),
'tosse': ('tosse',),
'tossen': ('tosse',),
'tossene': ('tosse',),
'tosser': ('tosse',),
'tostavelsesord': ('tostavelsesord',),
'tostavelsesorda': ('tostavelsesord',),
'tostavelsesordene': ('tostavelsesord',),
'tostavelsesordet': ('tostavelsesord',),
'tostavingsord': ('tostavingsord',),
'tostavingsorda': ('tostavingsord',),
'tostavingsordene': ('tostavingsord',),
'tostavingsordet': ('tostavingsord',),
'totakter': ('totakter',),
'totaktere': ('totakter',),
'totakteren': ('totakter',),
'totakterer': ('totakter',),
'totakterne': ('totakter',),
'totaktsmotor': ('totaktsmotor',),
'totaktsmotoren': ('totaktsmotor',),
'totaktsmotorene': ('totaktsmotor',),
'totaktsmotorer': ('totaktsmotor',),
'total': ('total',),
'totalen': ('total',),
'totalene': ('total',),
'totaler': ('total',),
'total': ('total',),
'totala': ('total',),
'totalene': ('total',),
'totalet': ('total',),
'totalavhold': ('totalavhold',),
'totalavholda': ('totalavhold',),
'totalavholdene': ('totalavhold',),
'totalavholdet': ('totalavhold',),
'totalavholdsmann': ('totalavholdsmann',),
'totalavholdsmannen': ('totalavholdsmann',),
'totalavholdsmenn': ('totalavholdsmann',),
'totalavholdsmennene': ('totalavholdsmann',),
'totalentreprise': ('totalentreprise',),
'totalentreprisen': ('totalentreprise',),
'totalentreprisene': ('totalentreprise',),
'totalentrepriser': ('totalentreprise',),
'totalforlis': ('totalforlis',),
'totalforlisa': ('totalforlis',),
'totalforlisene': ('totalforlis',),
'totalforliset': ('totalforlis',),
'totalforsvar': ('totalforsvar',),
'totalforsvara': ('totalforsvar',),
'totalforsvarene': ('totalforsvar',),
'totalforsvaret': ('totalforsvar',),
'totalhavari': ('totalhavari',),
'totalhavaria': ('totalhavari',),
'totalhavariene': ('totalhavari',),
'totalhavarier': ('totalhavari',),
'totalhavariet': ('totalhavari',),
'totalinntrykk': ('totalinntrykk',),
'totalinntrykka': ('totalinntrykk',),
'totalinntrykkene': ('totalinntrykk',),
'totalinntrykket': ('totalinntrykk',),
'totalisator': ('totalisator',),
'totalisatoren': ('totalisator',),
'totalisatorene': ('totalisator',),
'totalisatorer': ('totalisator',),
'totalisatorspell': ('totalisatorspell',),
'totalisatorspella': ('totalisatorspell',),
'totalisatorspellene': ('totalisatorspell',),
'totalisatorspellet': ('totalisatorspell',),
'totalisatorspill': ('totalisatorspill',),
'totalisatorspilla': ('totalisatorspill',),
'totalisatorspillene': ('totalisatorspill',),
'totalisatorspillet': ('totalisatorspill',),
'totalisme': ('totalisme',),
'totalismen': ('totalisme',),
'totalismene': ('totalisme',),
'totalismer': ('totalisme',),
'totalist': ('totalist',),
'totalisten': ('totalist',),
'totalistene': ('totalist',),
'totalister': ('totalist',),
'totalitarisme': ('totalitarisme',),
'totalitarismen': ('totalitarisme',),
'totalitarismene': ('totalitarisme',),
'totalitarismer': ('totalitarisme',),
'totalitet': ('totalitet',),
'totaliteten': ('totalitet',),
'totalitetene': ('totalitet',),
'totaliteter': ('totalitet',),
'totall': ('totall',),
'totalla': ('totall',),
'totallene': ('totall',),
'totallet': ('totall',),
'totallssystem': ('totallssystem',),
'totallssystema': ('totallssystem',),
'totallssystemene': ('totallssystem',),
'totallssystemer': ('totallssystem',),
'totallssystemet': ('totallssystem',),
'totalomsetning': ('totalomsetning',),
'totalomsetninga': ('totalomsetning',),
'totalomsetningen': ('totalomsetning',),
'totalomsetningene': ('totalomsetning',),
'totalomsetninger': ('totalomsetning',),
'totalskade': ('totalskade',),
'totalskaden': ('totalskade',),
'totalskadene': ('totalskade',),
'totalskader': ('totalskade',),
'totalssystem': ('totalssystem',),
'totalssystema': ('totalssystem',),
'totalssystemene': ('totalssystem',),
'totalssystemer': ('totalssystem',),
'totalssystemet': ('totalssystem',),
'totalsum': ('totalsum',),
'totalsummen': ('totalsum',),
'totalsummene': ('totalsum',),
'totalsummer': ('totalsum',),
'totem': ('totem',),
'totema': ('totem',),
'totemene': ('totem',),
'totemer': ('totem',),
'totemet': ('totem',),
'totemdyr': ('totemdyr',),
'totemdyra': ('totemdyr',),
'totemdyrene': ('totemdyr',),
'totemdyret': ('totemdyr',),
'totemisme': ('totemisme',),
'totemismen': ('totemisme',),
'totemismene': ('totemisme',),
'totemismer': ('totemisme',),
'totempåle': ('totempåle',),
'totempålen': ('totempåle',),
'totempålene': ('totempåle',),
'totempåler': ('totempåle',),
'totenschläger': ('totenschläger',),
'totenschlägere': ('totenschläger',),
'totenschlägeren': ('totenschläger',),
'totenschlägerer': ('totenschläger',),
'totenschlägerne': ('totenschläger',),
'totenschläger': ('totenschläger',),
'totenschlägere': ('totenschläger',),
'totenschlägeren': ('totenschläger',),
'totenschlägerer': ('totenschläger',),
'totenschlägerne': ('totenschläger',),
'totid': ('totid',),
'totida': ('totid',),
'totiden': ('totid',),
'totidene': ('totid',),
'totider': ('totid',),
'totning': ('totning',),
'totninga': ('totning',),
'totningen': ('totning',),
'totningene': ('totning',),
'totninger': ('totning',),
'toto': ('toto',),
'totoen': ('toto',),
'totoene': ('toto',),
'totoer': ('toto',),
'totospell': ('totospell',),
'totospella': ('totospell',),
'totospellene': ('totospell',),
'totospellet': ('totospell',),
'totospill': ('totospill',),
'totospilla': ('totospill',),
'totospillene': ('totospill',),
'totospillet': ('totospill',),
'totrinnsrakett': ('totrinnsrakett',),
'totrinnsraketten': ('totrinnsrakett',),
'totrinnsrakettene': ('totrinnsrakett',),
'totrinnsraketter': ('totrinnsrakett',),
'totschläger': ('totschläger',),
'totschlägere': ('totschläger',),
'totschlägeren': ('totschläger',),
'totschlägerer': ('totschläger',),
'totschlägerne': ('totschläger',),
'totschläger': ('totschläger',),
'totschlägere': ('totschläger',),
'totschlägeren': ('totschläger',),
'totschlägerer': ('totschläger',),
'totschlägerne': ('totschläger',),
'tott': ('tott',),
'totten': ('tott',),
'tottene': ('tott',),
'totter': ('tott',),
'tott': ('tott',),
'totten': ('tott',),
'tottene': ('tott',),
'totter': ('tott',),
'touch': ('touch',),
'touchen': ('touch',),
'touchene': ('touch',),
'toucher': ('touch',),
'touch-system': ('touch-system',),
'touch-systema': ('touch-system',),
'touch-systemene': ('touch-system',),
'touch-systemer': ('touch-system',),
'touch-systemet': ('touch-system',),
'touche': ('touche',),
'touchen': ('touche',),
'touchene': ('touche',),
'toucher': ('touche',),
'tournedos': ('tournedos',),
'tournedosen': ('tournedos',),
'tournedosene': ('tournedos',),
'tournedoser': ('tournedos',),
'tov': ('tov',),
'tova': ('tov',),
'tovene': ('tov',),
'tovet': ('tov',),
'tove': ('tove',),
'toven': ('tove',),
'tovene': ('tove',),
'tover': ('tove',),
'tovegsforbindelse': ('tovegsforbindelse',),
'tovegsforbindelsen': ('tovegsforbindelse',),
'tovegsforbindelsene': ('tovegsforbindelse',),
'tovegsforbindelser': ('tovegsforbindelse',),
'tovegskommunikasjon': ('tovegskommunikasjon',),
'tovegskommunikasjonen': ('tovegskommunikasjon',),
'tovegskommunikasjonene': ('tovegskommunikasjon',),
'tovegskommunikasjoner': ('tovegskommunikasjon',),
'tovegssamband': ('tovegssamband',),
'tovegssambanda': ('tovegssamband',),
'tovegssambandene': ('tovegssamband',),
'tovegssambandet': ('tovegssamband',),
'toveisforbindelse': ('toveisforbindelse',),
'toveisforbindelsen': ('toveisforbindelse',),
'toveisforbindelsene': ('toveisforbindelse',),
'toveisforbindelser': ('toveisforbindelse',),
'toveiskommunikasjon': ('toveiskommunikasjon',),
'toveiskommunikasjonen': ('toveiskommunikasjon',),
'toveiskommunikasjonene': ('toveiskommunikasjon',),
'toveiskommunikasjoner': ('toveiskommunikasjon',),
'toveissamband': ('toveissamband',),
'toveissambanda': ('toveissamband',),
'toveissambandene': ('toveissamband',),
'toveissambandet': ('toveissamband',),
'toveng': ('toveng',),
'tovengen': ('toveng',),
'tovengene': ('toveng',),
'tovenger': ('toveng',),
'toving': ('toving',),
'tovinga': ('toving',),
'tovingen': ('toving',),
'tovingene': ('toving',),
'tovinger': ('toving',),
'tovinge': ('tovinge',),
'tovingen': ('tovinge',),
'tovingene': ('tovinge',),
'tovinger': ('tovinge',),
'toåring': ('toåring',),
'toåringen': ('toåring',),
'toåringene': ('toåring',),
'toåringer': ('toåring',),
'toårsalder': ('toårsalder',),
'toårsaldere': ('toårsalder',),
'toårsalderen': ('toårsalder',),
'toårsalderer': ('toårsalder',),
'toårsalderne': ('toårsalder',),
'toårsaldre': ('toårsalder',),
'toårsaldrene': ('toårsalder',),
'toårsaldrer': ('toårsalder',),
'toøre': ('toøre',),
'toøren': ('toøre',),
'toørene': ('toøre',),
'toører': ('toøre',),
'toøring': ('toøring',),
'toøringen': ('toøring',),
'toøringene': ('toøring',),
'toøringer': ('toøring',),
'tracer': ('tracer',),
'tracere': ('tracer',),
'traceren': ('tracer',),
'tracerer': ('tracer',),
'tracerne': ('tracer',),
'tracerteknikk': ('tracerteknikk',),
'tracerteknikken': ('tracerteknikk',),
'tracerteknikkene': ('tracerteknikk',),
'tracerteknikker': ('tracerteknikk',),
'tracing': ('tracing',),
'tracinga': ('tracing',),
'tracingen': ('tracing',),
'tracingene': ('tracing',),
'tracinger': ('tracing',),
'tracingpapir': ('tracingpapir',),
'tracingpapira': ('tracingpapir',),
'tracingpapirene': ('tracingpapir',),
'tracingpapirer': ('tracingpapir',),
'tracingpapiret': ('tracingpapir',),
'tradband': ('tradband',),
'tradbanda': ('tradband',),
'tradbandene': ('tradband',),
'tradbandet': ('tradband',),
'trade': ('trade',),
'traden': ('trade',),
'tradene': ('trade',),
'trader': ('trade',),
'tradisjon': ('tradisjon',),
'tradisjonen': ('tradisjon',),
'tradisjonene': ('tradisjon',),
'tradisjoner': ('tradisjon',),
'tradisjonalisme': ('tradisjonalisme',),
'tradisjonalismen': ('tradisjonalisme',),
'tradisjonalismene': ('tradisjonalisme',),
'tradisjonalismer': ('tradisjonalisme',),
'tradisjonalist': ('tradisjonalist',),
'tradisjonalisten': ('tradisjonalist',),
'tradisjonalistene': ('tradisjonalist',),
'tradisjonalister': ('tradisjonalist',),
'tradisjonsstoff': ('tradisjonsstoff',),
'tradisjonsstoffa': ('tradisjonsstoff',),
'tradisjonsstoffene': ('tradisjonsstoff',),
'tradisjonsstoffet': ('tradisjonsstoff',),
'tradjass': ('tradjass',),
'tradjassen': ('tradjass',),
'tradjassene': ('tradjass',),
'tradjasser': ('tradjass',),
'tradjazz': ('tradjazz',),
'tradjazzen': ('tradjazz',),
'tradjazzene': ('tradjazz',),
'tradjazzer': ('tradjazz',),
'trafikant': ('trafikant',),
'trafikanten': ('trafikant',),
'trafikantene': ('trafikant',),
'trafikanter': ('trafikant',),
'trafikk': ('trafikk',),
'trafikken': ('trafikk',),
'trafikkene': ('trafikk',),
'trafikker': ('trafikk',),
'trafikk-kaos': ('trafikk-kaos',),
'trafikk-kaosa': ('trafikk-kaos',),
'trafikk-kaosene': ('trafikk-kaos',),
'trafikk-kaoser': ('trafikk-kaos',),
'trafikk-kaoset': ('trafikk-kaos',),
'trafikk-kontroll': ('trafikk-kontroll',),
'trafikk-kontrollen': ('trafikk-kontroll',),
'trafikk-kontrollene': ('trafikk-kontroll',),
'trafikk-kontroller': ('trafikk-kontroll',),
'trafikk-kork': ('trafikk-kork',),
'trafikk-korken': ('trafikk-kork',),
'trafikk-korkene': ('trafikk-kork',),
'trafikk-korker': ('trafikk-kork',),
'trafikk-kultur': ('trafikk-kultur',),
'trafikk-kulturen': ('trafikk-kultur',),
'trafikk-kulturene': ('trafikk-kultur',),
'trafikk-kulturer': ('trafikk-kultur',),
'trafikkaos': ('trafikkaos',),
'trafikkaosa': ('trafikkaos',),
'trafikkaosene': ('trafikkaos',),
'trafikkaoser': ('trafikkaos',),
'trafikkaoset': ('trafikkaos',),
'trafikkareal': ('trafikkareal',),
'trafikkareala': ('trafikkareal',),
'trafikkarealene': ('trafikkareal',),
'trafikkarealer': ('trafikkareal',),
'trafikkarealet': ('trafikkareal',),
'trafikkbølla': ('trafikkbølle',),
'trafikkbølle': ('trafikkbølle',),
'trafikkbøllen': ('trafikkbølle',),
'trafikkbøllene': ('trafikkbølle',),
'trafikkbøller': ('trafikkbølle',),
'trafikkdød': ('trafikkdød',),
'trafikkdøden': ('trafikkdød',),
'trafikkdødene': ('trafikkdød',),
'trafikkdøder': ('trafikkdød',),
'trafikkfella': ('trafikkfelle',),
'trafikkfelle': ('trafikkfelle',),
'trafikkfellen': ('trafikkfelle',),
'trafikkfellene': ('trafikkfelle',),
'trafikkfeller': ('trafikkfelle',),
'trafikkfly': ('trafikkfly',),
'trafikkflya': ('trafikkfly',),
'trafikkflyene': ('trafikkfly',),
'trafikkflyet': ('trafikkfly',),
'trafikkflyger': ('trafikkflyger',),
'trafikkflygere': ('trafikkflyger',),
'trafikkflygeren': ('trafikkflyger',),
'trafikkflygerer': ('trafikkflyger',),
'trafikkflygerne': ('trafikkflyger',),
'trafikkforsikring': ('trafikkforsikring',),
'trafikkforsikringa': ('trafikkforsikring',),
'trafikkforsikringen': ('trafikkforsikring',),
'trafikkforsikringene': ('trafikkforsikring',),
'trafikkforsikringer': ('trafikkforsikring',),
'trafikkfyr': ('trafikkfyr',),
'trafikkfyra': ('trafikkfyr',),
'trafikkfyrene': ('trafikkfyr',),
'trafikkfyret': ('trafikkfyr',),
'trafikkgrunnlag': ('trafikkgrunnlag',),
'trafikkgrunnlaga': ('trafikkgrunnlag',),
'trafikkgrunnlagene': ('trafikkgrunnlag',),
'trafikkgrunnlaget': ('trafikkgrunnlag',),
'trafikklys': ('trafikklys',),
'trafikklysa': ('trafikklys',),
'trafikklysene': ('trafikklys',),
'trafikklyset': ('trafikklys',),
'trafikkmaskin': ('trafikkmaskin',),
'trafikkmaskina': ('trafikkmaskin',),
'trafikkmaskinen': ('trafikkmaskin',),
'trafikkmaskinene': ('trafikkmaskin',),
'trafikkmaskiner': ('trafikkmaskin',),
'trafikkontroll': ('trafikkontroll',),
'trafikkontrollen': ('trafikkontroll',),
'trafikkontrollene': ('trafikkontroll',),
'trafikkontroller': ('trafikkontroll',),
'trafikkork': ('trafikkork',),
'trafikkorken': ('trafikkork',),
'trafikkorkene': ('trafikkork',),
'trafikkorker': ('trafikkork',),
'trafikkpoliti': ('trafikkpoliti',),
'trafikkpolitia': ('trafikkpoliti',),
'trafikkpolitiene': ('trafikkpoliti',),
'trafikkpolitier': ('trafikkpoliti',),
'trafikkpolitiet': ('trafikkpoliti',),
'trafikkregel': ('trafikkregel',),
'trafikkregelen': ('trafikkregel',),
'trafikkreglene': ('trafikkregel',),
'trafikkregler': ('trafikkregel',),
'trafikksanering': ('trafikksanering',),
'trafikksaneringa': ('trafikksanering',),
'trafikksaneringen': ('trafikksanering',),
'trafikksaneringene': ('trafikksanering',),
'trafikksaneringer': ('trafikksanering',),
'trafikksignal': ('trafikksignal',),
'trafikksignala': ('trafikksignal',),
'trafikksignalene': ('trafikksignal',),
'trafikksignaler': ('trafikksignal',),
'trafikksignalet': ('trafikksignal',),
'trafikksikkerhet': ('trafikksikkerhet',),
'trafikksikkerheta': ('trafikksikkerhet',),
'trafikksikkerheten': ('trafikksikkerhet',),
'trafikksikkerhetene': ('trafikksikkerhet',),
'trafikksikkerheter': ('trafikksikkerhet',),
'trafikkskilt': ('trafikkskilt',),
'trafikkskilta': ('trafikkskilt',),
'trafikkskiltene': ('trafikkskilt',),
'trafikkskilter': ('trafikkskilt',),
'trafikkskiltet': ('trafikkskilt',),
'trafikksynder': ('trafikksynder',),
'trafikksyndere': ('trafikksynder',),
'trafikksynderen': ('trafikksynder',),
'trafikksynderer': ('trafikksynder',),
'trafikksynderne': ('trafikksynder',),
'trafikktelling': ('trafikktelling',),
'trafikktellinga': ('trafikktelling',),
'trafikktellingen': ('trafikktelling',),
'trafikktellingene': ('trafikktelling',),
'trafikktellinger': ('trafikktelling',),
'trafikkultur': ('trafikkultur',),
'trafikkulturen': ('trafikkultur',),
'trafikkulturene': ('trafikkultur',),
'trafikkulturer': ('trafikkultur',),
'trafikkulykka': ('trafikkulykke',),
'trafikkulykke': ('trafikkulykke',),
'trafikkulykken': ('trafikkulykke',),
'trafikkulykkene': ('trafikkulykke',),
'trafikkulykker': ('trafikkulykke',),
'trafikkåra': ('trafikkåre',),
'trafikkåre': ('trafikkåre',),
'trafikkåren': ('trafikkåre',),
'trafikkårene': ('trafikkåre',),
'trafikkårer': ('trafikkåre',),
'trafikkøy': ('trafikkøy',),
'trafikkøya': ('trafikkøy',),
'trafikkøyen': ('trafikkøy',),
'trafikkøyene': ('trafikkøy',),
'trafikkøyer': ('trafikkøy',),
'trafo': ('trafo',),
'trafoen': ('trafo',),
'trafoene': ('trafo',),
'trafoer': ('trafo',),
'trafokiosk': ('trafokiosk',),
'trafokiosken': ('trafokiosk',),
'trafokioskene': ('trafokiosk',),
'trafokiosker': ('trafokiosk',),
'trafostasjon': ('trafostasjon',),
'trafostasjonen': ('trafostasjon',),
'trafostasjonene': ('trafostasjon',),
'trafostasjoner': ('trafostasjon',),
'tragedie': ('tragedie',),
'tragedien': ('tragedie',),
'tragediene': ('tragedie',),
'tragedier': ('tragedie',),
'tragedienna': ('tragedienne',),
'tragedienne': ('tragedienne',),
'tragediennen': ('tragedienne',),
'tragediennene': ('tragedienne',),
'tragedienner': ('tragedienne',),
'tragiker': ('tragiker',),
'tragikere': ('tragiker',),
'tragikeren': ('tragiker',),
'tragikerer': ('tragiker',),
'tragikerne': ('tragiker',),
'tragikk': ('tragikk',),
'tragikken': ('tragikk',),
'tragikkene': ('tragikk',),
'tragikker': ('tragikk',),
'tragikomedie': ('tragikomedie',),
'tragikomedien': ('tragikomedie',),
'tragikomediene': ('tragikomedie',),
'tragikomedier': ('tragikomedie',),
'trailer': ('trailer',),
'trailere': ('trailer',),
'traileren': ('trailer',),
'trailerer': ('trailer',),
'trailerne': ('trailer',),
'trailersjåfør': ('trailersjåfør',),
'trailersjåføren': ('trailersjåfør',),
'trailersjåførene': ('trailersjåfør',),
'trailersjåfører': ('trailersjåfør',),
'trakeen': ('traké',),
'trakeene': ('traké',),
'trakeer': ('traké',),
'traké': ('traké',),
'trakéen': ('traké',),
'trakéene': ('traké',),
'trakéer': ('traké',),
'trakasseri': ('trakasseri',),
'trakasseria': ('trakasseri',),
'trakasseriene': ('trakasseri',),
'trakasserier': ('trakasseri',),
'trakasseriet': ('trakasseri',),
'trakassering': ('trakassering',),
'trakasseringa': ('trakassering',),
'trakasseringen': ('trakassering',),
'trakasseringene': ('trakassering',),
'trakasseringer': ('trakassering',),
'trakk': ('trakk',),
'trakka': ('trakk',),
'trakkene': ('trakk',),
'trakket': ('trakk',),
'trakker': ('trakker',),
'trakkere': ('trakker',),
'trakkeren': ('trakker',),
'trakkerer': ('trakker',),
'trakkerne': ('trakker',),
'trakom': ('trakom',),
'trakoma': ('trakom',),
'trakomene': ('trakom',),
'trakomer': ('trakom',),
'trakomet': ('trakom',),
'trakt': ('trakt',),
'trakta': ('trakt',),
'trakten': ('trakt',),
'traktene': ('trakt',),
'trakter': ('trakt',),
'trakt': ('trakt',),
'trakta': ('trakt',),
'trakten': ('trakt',),
'traktene': ('trakt',),
'trakter': ('trakt',),
'trakt': ('trakt',),
'trakta': ('trakt',),
'trakten': ('trakt',),
'traktene': ('trakt',),
'trakter': ('trakt',),
'traktat': ('traktat',),
'traktaten': ('traktat',),
'traktatene': ('traktat',),
'traktater': ('traktat',),
'traktatbrott': ('traktatbrott',),
'traktatbrotta': ('traktatbrott',),
'traktatbrottene': ('traktatbrott',),
'traktatbrottet': ('traktatbrott',),
'traktatbrudd': ('traktatbrudd',),
'traktatbrudda': ('traktatbrudd',),
'traktatbruddene': ('traktatbrudd',),
'traktatbruddet': ('traktatbrudd',),
'traktatland': ('traktatland',),
'traktatlanda': ('traktatland',),
'traktatlandene': ('traktatland',),
'traktatlandet': ('traktatland',),
'traktekaffe': ('traktekaffe',),
'traktekaffen': ('traktekaffe',),
'traktekaffene': ('traktekaffe',),
'traktekaffer': ('traktekaffe',),
'traktekanna': ('traktekanne',),
'traktekanne': ('traktekanne',),
'traktekannen': ('traktekanne',),
'traktekannene': ('traktekanne',),
'traktekanner': ('traktekanne',),
'traktement': ('traktement',),
'traktementa': ('traktement',),
'traktementene': ('traktement',),
'traktementer': ('traktement',),
'traktementet': ('traktement',),
'trakter': ('trakter',),
'traktere': ('trakter',),
'trakteren': ('trakter',),
'trakterer': ('trakter',),
'trakterne': ('trakter',),
'traktering': ('traktering',),
'trakteringa': ('traktering',),
'trakteringen': ('traktering',),
'trakteringene': ('traktering',),
'trakteringer': ('traktering',),
'traktor': ('traktor',),
'traktoren': ('traktor',),
'traktorene': ('traktor',),
'traktorer': ('traktor',),
'traktorbensin': ('traktorbensin',),
'traktorbensinen': ('traktorbensin',),
'traktorbensinene': ('traktorbensin',),
'traktorbensiner': ('traktorbensin',),
'traktorveg': ('traktorveg',),
'traktorvegen': ('traktorveg',),
'traktorvegene': ('traktorveg',),
'traktorveger': ('traktorveg',),
'traktorvei': ('traktorvei',),
'traktorveien': ('traktorvei',),
'traktorveiene': ('traktorvei',),
'traktorveier': ('traktorvei',),
'traktsopp': ('traktsopp',),
'traktsoppen': ('traktsopp',),
'traktsoppene': ('traktsopp',),
'traktsopper': ('traktsopp',),
'traktsopp': ('traktsopp',),
'traktsoppen': ('traktsopp',),
'traktsoppene': ('traktsopp',),
'traktsopper': ('traktsopp',),
'traktør': ('traktør',),
'traktøren': ('traktør',),
'traktørene': ('traktør',),
'traktører': ('traktør',),
'traktørsted': ('traktørsted',),
'traktørstedene': ('traktørsted',),
'traktørsteder': ('traktørsted',),
'traktørstedet': ('traktørsted',),
'tral': ('tral',),
'trala': ('tral',),
'tralene': ('tral',),
'tralet': ('tral',),
'trall': ('trall',),
'trallen': ('trall',),
'trallene': ('trall',),
'traller': ('trall',),
'tralla': ('tralle',),
'tralle': ('tralle',),
'trallen': ('tralle',),
'trallene': ('tralle',),
'traller': ('tralle',),
'tralt': ('tralt',),
'tralten': ('tralt',),
'traltene': ('tralt',),
'tralter': ('tralt',),
'tram': ('tram',),
'trammen': ('tram',),
'trammene': ('tram',),
'trammer': ('tram',),
'tramp': ('tramp',),
'trampen': ('tramp',),
'trampene': ('tramp',),
'tramper': ('tramp',),
'tramp': ('tramp',),
'trampa': ('tramp',),
'trampene': ('tramp',),
'trampet': ('tramp',),
'trampbåt': ('trampbåt',),
'trampbåten': ('trampbåt',),
'trampbåtene': ('trampbåt',),
'trampbåter': ('trampbåt',),
'trampa': ('trampe',),
'trampe': ('trampe',),
'trampen': ('trampe',),
'trampene': ('trampe',),
'tramper': ('trampe',),
'trampeklapp': ('trampeklapp',),
'trampeklappa': ('trampeklapp',),
'trampeklappen': ('trampeklapp',),
'trampeklappene': ('trampeklapp',),
'trampeklapper': ('trampeklapp',),
'trampeklappet': ('trampeklapp',),
'trampfart': ('trampfart',),
'trampfarten': ('trampfart',),
'trampfartene': ('trampfart',),
'trampfarter': ('trampfart',),
'trampoline': ('trampoline',),
'trampolinen': ('trampoline',),
'trampolinene': ('trampoline',),
'trampoliner': ('trampoline',),
'tran': ('tran',),
'trana': ('tran',),
'tranen': ('tran',),
'tranene': ('tran',),
'traner': ('tran',),
'trana': ('trane',),
'trane': ('trane',),
'tranen': ('trane',),
'tranene': ('trane',),
'traner': ('trane',),
'tranebær': ('tranebær',),
'tranebæra': ('tranebær',),
'tranebærene': ('tranebær',),
'tranebæret': ('tranebær',),
'tranedans': ('tranedans',),
'tranedansen': ('tranedans',),
'tranedansene': ('tranedans',),
'tranedanser': ('tranedans',),
'tranefugl': ('tranefugl',),
'tranefuglen': ('tranefugl',),
'tranefuglene': ('tranefugl',),
'tranefugler': ('tranefugl',),
'tranehals': ('tranehals',),
'tranehalsen': ('tranehals',),
'tranehalsene': ('tranehals',),
'tranehalser': ('tranehals',),
'trang': ('trang',),
'trangen': ('trang',),
'trangene': ('trang',),
'tranger': ('trang',),
'trangsyn': ('trangsyn',),
'trangsyna': ('trangsyn',),
'trangsynene': ('trangsyn',),
'trangsynet': ('trangsyn',),
'tranlampa': ('tranlampe',),
'tranlampe': ('tranlampe',),
'tranlampen': ('tranlampe',),
'tranlampene': ('tranlampe',),
'tranlamper': ('tranlampe',),
'transaksjon': ('transaksjon',),
'transaksjonen': ('transaksjon',),
'transaksjonene': ('transaksjon',),
'transaksjoner': ('transaksjon',),
'transalva': ('transalve',),
'transalve': ('transalve',),
'transalven': ('transalve',),
'transalvene': ('transalve',),
'transalver': ('transalve',),
'transcendens': ('transcendens',),
'transcendensen': ('transcendens',),
'transcendensene': ('transcendens',),
'transcendenser': ('transcendens',),
'transduser': ('transduser',),
'transdusere': ('transduser',),
'transduseren': ('transduser',),
'transduserer': ('transduser',),
'transduserne': ('transduser',),
'transe': ('transe',),
'transen': ('transe',),
'transene': ('transe',),
'transer': ('transe',),
'transetilstand': ('transetilstand',),
'transetilstanden': ('transetilstand',),
'transetilstandene': ('transetilstand',),
'transetilstander': ('transetilstand',),
'transfer': ('transfer',),
'transferen': ('transfer',),
'transferene': ('transfer',),
'transferer': ('transfer',),
'transfigurasjon': ('transfigurasjon',),
'transfigurasjonen': ('transfigurasjon',),
'transfigurasjonene': ('transfigurasjon',),
'transfigurasjoner': ('transfigurasjon',),
'transformasjon': ('transformasjon',),
'transformasjonen': ('transformasjon',),
'transformasjonene': ('transformasjon',),
'transformasjoner': ('transformasjon',),
'transformasjonsgrammatikk': ('transformasjonsgrammatikk',),
'transformasjonsgrammatikken': ('transformasjonsgrammatikk',),
'transformasjonsgrammatikkene': ('transformasjonsgrammatikk',),
'transformasjonsgrammatikker': ('transformasjonsgrammatikk',),
'transformator': ('transformator',),
'transformatoren': ('transformator',),
'transformatorene': ('transformator',),
'transformatorer': ('transformator',),
'transformatorkiosk': ('transformatorkiosk',),
'transformatorkiosken': ('transformatorkiosk',),
'transformatorkioskene': ('transformatorkiosk',),
'transformatorkiosker': ('transformatorkiosk',),
'transformatorstasjon': ('transformatorstasjon',),
'transformatorstasjonen': ('transformatorstasjon',),
'transformatorstasjonene': ('transformatorstasjon',),
'transformatorstasjoner': ('transformatorstasjon',),
'transfusjon': ('transfusjon',),
'transfusjonen': ('transfusjon',),
'transfusjonene': ('transfusjon',),
'transfusjoner': ('transfusjon',),
'transistor': ('transistor',),
'transistoren': ('transistor',),
'transistorene': ('transistor',),
'transistorer': ('transistor',),
'transistorradio': ('transistorradio',),
'transistorradioen': ('transistorradio',),
'transistorradioene': ('transistorradio',),
'transistorradioer': ('transistorradio',),
'transitiv': ('transitiv',),
'transitiva': ('transitiv',),
'transitivene': ('transitiv',),
'transitiver': ('transitiv',),
'transitivet': ('transitiv',),
'transitivitet': ('transitivitet',),
'transitiviteten': ('transitivitet',),
'transitivitetene': ('transitivitet',),
'transitiviteter': ('transitivitet',),
'transitt': ('transitt',),
'transitten': ('transitt',),
'transittene': ('transitt',),
'transitter': ('transitt',),
'transitt-toll': ('transitt-toll',),
'transitt-tollen': ('transitt-toll',),
'transitt-tollene': ('transitt-toll',),
'transitt-toller': ('transitt-toll',),
'transittgods': ('transittgods',),
'transittgodsa': ('transittgods',),
'transittgodsene': ('transittgods',),
'transittgodset': ('transittgods',),
'transitthall': ('transitthall',),
'transitthallen': ('transitthall',),
'transitthallene': ('transitthall',),
'transitthaller': ('transitthall',),
'transitthamn': ('transitthamn',),
'transitthamna': ('transitthamn',),
'transitthamnen': ('transitthamn',),
'transitthamnene': ('transitthamn',),
'transitthamner': ('transitthamn',),
'transitthamn': ('transitthamn',),
'transitthamna': ('transitthamn',),
'transitthamnen': ('transitthamn',),
'transitthamnene': ('transitthamn',),
'transitthamner': ('transitthamn',),
'transitthandel': ('transitthandel',),
'transitthandelen': ('transitthandel',),
'transitthandlene': ('transitthandel',),
'transitthandler': ('transitthandel',),
'transitthavn': ('transitthavn',),
'transitthavna': ('transitthavn',),
'transitthavnen': ('transitthavn',),
'transitthavnene': ('transitthavn',),
'transitthavner': ('transitthavn',),
'transitthavn': ('transitthavn',),
'transitthavna': ('transitthavn',),
'transitthavnen': ('transitthavn',),
'transitthavnene': ('transitthavn',),
'transitthavner': ('transitthavn',),
'transittland': ('transittland',),
'transittlanda': ('transittland',),
'transittlandene': ('transittland',),
'transittlandet': ('transittland',),
'transittoll': ('transittoll',),
'transittollen': ('transittoll',),
'transittollene': ('transittoll',),
'transittoller': ('transittoll',),
'transittvara': ('transittvare',),
'transittvare': ('transittvare',),
'transittvaren': ('transittvare',),
'transittvarene': ('transittvare',),
'transittvarer': ('transittvare',),
'transittveksel': ('transittveksel',),
'transittvekselen': ('transittveksel',),
'transittvekslene': ('transittveksel',),
'transittveksler': ('transittveksel',),
'transittvisa': ('transittvisum',),
'transittvisaene': ('transittvisum',),
'transittvisum': ('transittvisum',),
'transittvisuma': ('transittvisum',),
'transittvisumene': ('transittvisum',),
'transittvisumer': ('transittvisum',),
'transittvisumet': ('transittvisum',),
'transjerkniv': ('transjerkniv',),
'transjerkniven': ('transjerkniv',),
'transjerknivene': ('transjerkniv',),
'transjerkniver': ('transjerkniv',),
'transkripsjon': ('transkripsjon',),
'transkripsjonen': ('transkripsjon',),
'transkripsjonene': ('transkripsjon',),
'transkripsjoner': ('transkripsjon',),
'transkripsjon': ('transkripsjon',),
'transkripsjonen': ('transkripsjon',),
'transkripsjonene': ('transkripsjon',),
'transkripsjoner': ('transkripsjon',),
'translatør': ('translatør',),
'translatøren': ('translatør',),
'translatørene': ('translatør',),
'translatører': ('translatør',),
'translatøreksamen': ('translatøreksamen',),
'translatøreksamenen': ('translatøreksamen',),
'translatøreksamenene': ('translatøreksamen',),
'translatøreksamener': ('translatøreksamen',),
'translitterasjon': ('translitterasjon',),
'translitterasjonen': ('translitterasjon',),
'translitterasjonene': ('translitterasjon',),
'translitterasjoner': ('translitterasjon',),
'transmisjon': ('transmisjon',),
'transmisjonen': ('transmisjon',),
'transmisjonene': ('transmisjon',),
'transmisjoner': ('transmisjon',),
'transmitter': ('transmitter',),
'transmittere': ('transmitter',),
'transmitteren': ('transmitter',),
'transmitterer': ('transmitter',),
'transmitterne': ('transmitter',),
'transparent': ('transparent',),
'transparenten': ('transparent',),
'transparentene': ('transparent',),
'transparenter': ('transparent',),
'transparent': ('transparent',),
'transparenta': ('transparent',),
'transparenten': ('transparent',),
'transparentene': ('transparent',),
'transparenter': ('transparent',),
'transparentet': ('transparent',),
'transpirasjon': ('transpirasjon',),
'transpirasjonen': ('transpirasjon',),
'transpirasjonene': ('transpirasjon',),
'transpirasjoner': ('transpirasjon',),
'transpirasjonslukt': ('transpirasjonslukt',),
'transpirasjonslukta': ('transpirasjonslukt',),
'transpirasjonslukten': ('transpirasjonslukt',),
'transpirasjonsluktene': ('transpirasjonslukt',),
'transpirasjonslukter': ('transpirasjonslukt',),
'transpirasjonsmiddel': ('transpirasjonsmiddel',),
'transpirasjonsmiddelet': ('transpirasjonsmiddel',),
'transpirasjonsmidla': ('transpirasjonsmiddel',),
'transpirasjonsmidlene': ('transpirasjonsmiddel',),
'transpirasjonsmidler': ('transpirasjonsmiddel',),
'transpirasjonsmidlet': ('transpirasjonsmiddel',),
'transplantasjon': ('transplantasjon',),
'transplantasjonen': ('transplantasjon',),
'transplantasjonene': ('transplantasjon',),
'transplantasjoner': ('transplantasjon',),
'transplantat': ('transplantat',),
'transplantata': ('transplantat',),
'transplantatene': ('transplantat',),
'transplantater': ('transplantat',),
'transplantatet': ('transplantat',),
'transport': ('transport',),
'transporten': ('transport',),
'transportene': ('transport',),
'transporter': ('transport',),
'transportband': ('transportband',),
'transportbanda': ('transportband',),
'transportbandene': ('transportband',),
'transportbandet': ('transportband',),
'transportbånd': ('transportbånd',),
'transportbånda': ('transportbånd',),
'transportbåndene': ('transportbånd',),
'transportbåndet': ('transportbånd',),
'transporter': ('transporter',),
'transportere': ('transporter',),
'transporteren': ('transporter',),
'transporterer': ('transporter',),
'transporterne': ('transporter',),
'transportfirma': ('transportfirma',),
'transportfirmaene': ('transportfirma',),
'transportfirmaer': ('transportfirma',),
'transportfirmaet': ('transportfirma',),
'transportkostnad': ('transportkostnad',),
'transportkostnaden': ('transportkostnad',),
'transportkostnadene': ('transportkostnad',),
'transportkostnader': ('transportkostnad',),
'transportmiddel': ('transportmiddel',),
'transportmiddelet': ('transportmiddel',),
'transportmidla': ('transportmiddel',),
'transportmidlene': ('transportmiddel',),
'transportmidler': ('transportmiddel',),
'transportmidlet': ('transportmiddel',),
'transportør': ('transportør',),
'transportøren': ('transportør',),
'transportørene': ('transportør',),
'transportører': ('transportør',),
'transskripsjon': ('transskripsjon',),
'transskripsjonen': ('transskripsjon',),
'transskripsjonene': ('transskripsjon',),
'transskripsjoner': ('transskripsjon',),
'transskripsjon': ('transskripsjon',),
'transskripsjonen': ('transskripsjon',),
'transskripsjonene': ('transskripsjon',),
'transskripsjoner': ('transskripsjon',),
'transsubstansiasjon': ('transsubstansiasjon',),
'transsubstansiasjonen': ('transsubstansiasjon',),
'transsubstansiasjonene': ('transsubstansiasjon',),
'transsubstansiasjoner': ('transsubstansiasjon',),
'transubstansiasjon': ('transubstansiasjon',),
'transubstansiasjonen': ('transubstansiasjon',),
'transubstansiasjonene': ('transubstansiasjon',),
'transubstansiasjoner': ('transubstansiasjon',),
'transuran': ('transuran',),
'transurana': ('transuran',),
'transuranene': ('transuran',),
'transuranet': ('transuran',),
'transvers': ('transvers',),
'transversen': ('transvers',),
'transversene': ('transvers',),
'transverser': ('transvers',),
'transversal': ('transversal',),
'transversalen': ('transversal',),
'transversalene': ('transversal',),
'transversaler': ('transversal',),
'transvestitt': ('transvestitt',),
'transvestitten': ('transvestitt',),
'transvestittene': ('transvestitt',),
'transvestitter': ('transvestitt',),
'transvestittisme': ('transvestittisme',),
'transvestittismen': ('transvestittisme',),
'transvestittismene': ('transvestittisme',),
'transvestittismer': ('transvestittisme',),
'trant': ('trant',),
'tranten': ('trant',),
'trantene': ('trant',),
'tranter': ('trant',),
'trapes': ('trapes',),
'trapesen': ('trapes',),
'trapesene': ('trapes',),
'trapeser': ('trapes',),
'trapes': ('trapes',),
'trapesa': ('trapes',),
'trapesene': ('trapes',),
'trapeser': ('trapes',),
'trapeset': ('trapes',),
'trapeskunstner': ('trapeskunstner',),
'trapeskunstnere': ('trapeskunstner',),
'trapeskunstneren': ('trapeskunstner',),
'trapeskunstnerer': ('trapeskunstner',),
'trapeskunstnerne': ('trapeskunstner',),
'trapp': ('trapp',),
'trappa': ('trapp',),
'trappen': ('trapp',),
'trappene': ('trapp',),
'trapper': ('trapp',),
'trappeavsats': ('trappeavsats',),
'trappeavsatsen': ('trappeavsats',),
'trappeavsatsene': ('trappeavsats',),
'trappeavsatser': ('trappeavsats',),
'trappehus': ('trappehus',),
'trappehusa': ('trappehus',),
'trappehusene': ('trappehus',),
'trappehuset': ('trappehus',),
'trappeoppgang': ('trappeoppgang',),
'trappeoppgangen': ('trappeoppgang',),
'trappeoppgangene': ('trappeoppgang',),
'trappeoppganger': ('trappeoppgang',),
'trapper': ('trapper',),
'trappere': ('trapper',),
'trapperen': ('trapper',),
'trapperer': ('trapper',),
'trapperne': ('trapper',),
'trappetrinn': ('trappetrinn',),
'trappetrinna': ('trappetrinn',),
'trappetrinnene': ('trappetrinn',),
'trappetrinnet': ('trappetrinn',),
'trappevask': ('trappevask',),
'trappevasken': ('trappevask',),
'trappevaskene': ('trappevask',),
'trappevasker': ('trappevask',),
'trappist': ('trappist',),
'trappisten': ('trappist',),
'trappistene': ('trappist',),
'trappister': ('trappist',),
'trapskyting': ('trapskyting',),
'trapskytinga': ('trapskyting',),
'trapskytingen': ('trapskyting',),
'trapskytingene': ('trapskyting',),
'trapskytinger': ('trapskyting',),
'traseen': ('trasé',),
'traseene': ('trasé',),
'traseer': ('trasé',),
'trasé': ('trasé',),
'traséen': ('trasé',),
'traséene': ('trasé',),
'traséer': ('trasé',),
'trase': ('trase',),
'trasen': ('trase',),
'trasene': ('trase',),
'traser': ('trase',),
'trase': ('trase',),
'trasen': ('trase',),
'trasene': ('trase',),
'traser': ('trase',),
'trass': ('trass',),
'trassa': ('trass',),
'trassen': ('trass',),
'trassene': ('trass',),
'trasser': ('trass',),
'trasset': ('trass',),
'trassalder': ('trassalder',),
'trassaldere': ('trassalder',),
'trassalderen': ('trassalder',),
'trassalderer': ('trassalder',),
'trassalderne': ('trassalder',),
'trassaldre': ('trassalder',),
'trassaldrene': ('trassalder',),
'trassaldrer': ('trassalder',),
'trassat': ('trassat',),
'trassaten': ('trassat',),
'trassatene': ('trassat',),
'trassater': ('trassat',),
'trassent': ('trassent',),
'trassenten': ('trassent',),
'trassentene': ('trassent',),
'trassenter': ('trassent',),
'trast': ('trast',),
'trasten': ('trast',),
'trastene': ('trast',),
'traster': ('trast',),
'trast': ('trast',),
'trasten': ('trast',),
'trastene': ('trast',),
'traster': ('trast',),
'trastefugl': ('trastefugl',),
'trastefuglen': ('trastefugl',),
'trastefuglene': ('trastefugl',),
'trastefugler': ('trastefugl',),
'trastefugl': ('trastefugl',),
'trastefuglen': ('trastefugl',),
'trastefuglene': ('trastefugl',),
'trastefugler': ('trastefugl',),
'trastegg': ('trastegg',),
'trastegga': ('trastegg',),
'trasteggene': ('trastegg',),
'trastegget': ('trastegg',),
'trastegg': ('trastegg',),
'trastegga': ('trastegg',),
'trasteggene': ('trastegg',),
'trastegget': ('trastegg',),
'trastereda': ('trasterede',),
'trasterede': ('trasterede',),
'trasteredene': ('trasterede',),
'trastereder': ('trasterede',),
'trasteredet': ('trasterede',),
'trastereda': ('trasterede',),
'trasterede': ('trasterede',),
'trasteredene': ('trasterede',),
'trastereder': ('trasterede',),
'trasteredet': ('trasterede',),
'trastereir': ('trastereir',),
'trastereira': ('trastereir',),
'trastereirene': ('trastereir',),
'trastereiret': ('trastereir',),
'trastereir': ('trastereir',),
'trastereira': ('trastereir',),
'trastereirene': ('trastereir',),
'trastereiret': ('trastereir',),
'trastunge': ('trastunge',),
'trastungen': ('trastunge',),
'trastungene': ('trastunge',),
'trastunger': ('trastunge',),
'trastunge': ('trastunge',),
'trastungen': ('trastunge',),
'trastungene': ('trastunge',),
'trastunger': ('trastunge',),
'tratte': ('tratte',),
'tratten': ('tratte',),
'trattene': ('tratte',),
'tratter': ('tratte',),
'trau': ('trau',),
'traua': ('trau',),
'trauene': ('trau',),
'trauet': ('trau',),
'trauma': ('trauma',),
'traumaene': ('trauma',),
'traumaer': ('trauma',),
'traumaet': ('trauma',),
'trauma': ('traume',),
'traume': ('traume',),
'traumene': ('traume',),
'traumer': ('traume',),
'traumet': ('traume',),
'trav': ('trav',),
'trava': ('trav',),
'travene': ('trav',),
'travet': ('trav',),
'travbane': ('travbane',),
'travbanen': ('travbane',),
'travbanene': ('travbane',),
'travbaner': ('travbane',),
'trave': ('trave',),
'traven': ('trave',),
'travene': ('trave',),
'traver': ('trave',),
'traver': ('traver',),
'travere': ('traver',),
'traveren': ('traver',),
'traverer': ('traver',),
'traverne': ('traver',),
'travers': ('travers',),
'traversen': ('travers',),
'traversene': ('travers',),
'traverser': ('travers',),
'travesti': ('travesti',),
'travestien': ('travesti',),
'travestiene': ('travesti',),
'travestier': ('travesti',),
'travhest': ('travhest',),
'travhesten': ('travhest',),
'travhestene': ('travhest',),
'travhester': ('travhest',),
'travløp': ('travløp',),
'travløpa': ('travløp',),
'travløpene': ('travløp',),
'travløpet': ('travløp',),
'travsport': ('travsport',),
'travsporten': ('travsport',),
'travsportene': ('travsport',),
'travsporter': ('travsport',),
'tre': ('tre',),
'trea': ('tre',),
'treet': ('tre',),
'trær': ('tre',),
'trærne': ('tre',),
'treak': ('treak',),
'treaken': ('treak',),
'treakene': ('treak',),
'treaker': ('treak',),
'treakel': ('treakel',),
'treakelen': ('treakel',),
'treakelet': ('treakel',),
'treakla': ('treakel',),
'treaklene': ('treakel',),
'treakler': ('treakel',),
'treaklet': ('treakel',),
'treakter': ('treakter',),
'treaktere': ('treakter',),
'treakteren': ('treakter',),
'treakterer': ('treakter',),
'treakterne': ('treakter',),
'trealkohol': ('trealkohol',),
'trealkoholen': ('trealkohol',),
'trealkoholene': ('trealkohol',),
'trealkoholer': ('trealkohol',),
'trebarnsfamilie': ('trebarnsfamilie',),
'trebarnsfamilien': ('trebarnsfamilie',),
'trebarnsfamiliene': ('trebarnsfamilie',),
'trebarnsfamilier': ('trebarnsfamilie',),
'trebein': ('trebein',),
'trebeina': ('trebein',),
'trebeinene': ('trebein',),
'trebeinet': ('trebein',),
'treben': ('treben',),
'trebena': ('treben',),
'trebenene': ('treben',),
'trebenet': ('treben',),
'trebjørn': ('trebjørn',),
'trebjørnen': ('trebjørn',),
'trebjørnene': ('trebjørn',),
'trebjørner': ('trebjørn',),
'treblåseinstrument': ('treblåseinstrument',),
'treblåseinstrumenta': ('treblåseinstrument',),
'treblåseinstrumentene': ('treblåseinstrument',),
'treblåseinstrumenter': ('treblåseinstrument',),
'treblåseinstrumentet': ('treblåseinstrument',),
'treblåser': ('treblåser',),
'treblåsere': ('treblåser',),
'treblåseren': ('treblåser',),
'treblåserer': ('treblåser',),
'treblåserne': ('treblåser',),
'trebonnene': ('trebonner',),
'trebonner': ('trebonner',),
'trebukk': ('trebukk',),
'trebukken': ('trebukk',),
'trebukkene': ('trebukk',),
'trebukker': ('trebukk',),
'tredagersritt': ('tredagersritt',),
'tredagersritta': ('tredagersritt',),
'tredagersrittene': ('tredagersritt',),
'tredagersrittet': ('tredagersritt',),
'tredel': ('tredel',),
'tredelen': ('tredel',),
'tredelene': ('tredel',),
'tredeler': ('tredel',),
'tredemølla': ('tredemølle',),
'tredemølle': ('tredemølle',),
'tredemøllen': ('tredemølle',),
'tredemøllene': ('tredemølle',),
'tredemøller': ('tredemølle',),
'tredjedag': ('tredjedag',),
'tredjedagen': ('tredjedag',),
'tredjedagene': ('tredjedag',),
'tredjedager': ('tredjedag',),
'tredjedel': ('tredjedel',),
'tredjedelen': ('tredjedel',),
'tredjedelene': ('tredjedel',),
'tredjedeler': ('tredjedel',),
'tredjegir': ('tredjegir',),
'tredjegira': ('tredjegir',),
'tredjegirene': ('tredjegir',),
'tredjegiret': ('tredjegir',),
'tredjegradsforbrenning': ('tredjegradsforbrenning',),
'tredjegradsforbrenninga': ('tredjegradsforbrenning',),
'tredjegradsforbrenningen': ('tredjegradsforbrenning',),
'tredjegradsforbrenningene': ('tredjegradsforbrenning',),
'tredjegradsforbrenninger': ('tredjegradsforbrenning',),
'tredjegradsforhør': ('tredjegradsforhør',),
'tredjegradsforhøra': ('tredjegradsforhør',),
'tredjegradsforhørene': ('tredjegradsforhør',),
'tredjegradsforhøret': ('tredjegradsforhør',),
'tredjegradsligning': ('tredjegradsligning',),
'tredjegradsligninga': ('tredjegradsligning',),
'tredjegradsligningen': ('tredjegradsligning',),
'tredjegradsligningene': ('tredjegradsligning',),
'tredjegradsligninger': ('tredjegradsligning',),
'tredjegradslikning': ('tredjegradslikning',),
'tredjegradslikninga': ('tredjegradslikning',),
'tredjegradslikningen': ('tredjegradslikning',),
'tredjegradslikningene': ('tredjegradslikning',),
'tredjegradslikninger': ('tredjegradslikning',),
'tredjeland': ('tredjeland',),
'tredjelanda': ('tredjeland',),
'tredjelandene': ('tredjeland',),
'tredjelandet': ('tredjeland',),
'tredjemann': ('tredjemann',),
'tredjemannen': ('tredjemann',),
'tredjemenn': ('tredjemann',),
'tredjemennene': ('tredjemann',),
'tredjepart': ('tredjepart',),
'tredjeparten': ('tredjepart',),
'tredjepartene': ('tredjepart',),
'tredjeparter': ('tredjepart',),
'tredjeplass': ('tredjeplass',),
'tredjeplassen': ('tredjeplass',),
'tredjeplassene': ('tredjeplass',),
'tredjeplasser': ('tredjeplass',),
'tredjeprioritet': ('tredjeprioritet',),
'tredjeprioriteten': ('tredjeprioritet',),
'tredjeprioritetene': ('tredjeprioritet',),
'tredjeprioriteter': ('tredjeprioritet',),
'tredjeprioritetslån': ('tredjeprioritetslån',),
'tredjeprioritetslåna': ('tredjeprioritetslån',),
'tredjeprioritetslånene': ('tredjeprioritetslån',),
'tredjeprioritetslånet': ('tredjeprioritetslån',),
'tredjestand': ('tredjestand',),
'tredjestanden': ('tredjestand',),
'tredjestandene': ('tredjestand',),
'tredjestander': ('tredjestand',),
'tredreper': ('tredreper',),
'tredrepere': ('tredreper',),
'tredreperen': ('tredreper',),
'tredreperer': ('tredreper',),
'tredreperne': ('tredreper',),
'treenighet': ('treenighet',),
'treenigheta': ('treenighet',),
'treenigheten': ('treenighet',),
'treenighetene': ('treenighet',),
'treenigheter': ('treenighet',),
'treenighetssøndag': ('treenighetssøndag',),
'treenighetssøndagen': ('treenighetssøndag',),
'treenighetssøndagene': ('treenighetssøndag',),
'treenighetssøndager': ('treenighetssøndag',),
'treer': ('treer',),
'treere': ('treer',),
'treeren': ('treer',),
'treerer': ('treer',),
'treerne': ('treer',),
'treff': ('treff',),
'treffa': ('treff',),
'treffene': ('treff',),
'treffet': ('treff',),
'treffer': ('treffer',),
'treffere': ('treffer',),
'trefferen': ('treffer',),
'trefferer': ('treffer',),
'trefferne': ('treffer',),
'treffetid': ('treffetid',),
'treffetida': ('treffetid',),
'treffetiden': ('treffetid',),
'treffetidene': ('treffetid',),
'treffetider': ('treffetid',),
'treffpunkt': ('treffpunkt',),
'treffpunkta': ('treffpunkt',),
'treffpunktene': ('treffpunkt',),
'treffpunkter': ('treffpunkt',),
'treffpunktet': ('treffpunkt',),
'treffsikkerhet': ('treffsikkerhet',),
'treffsikkerheta': ('treffsikkerhet',),
'treffsikkerheten': ('treffsikkerhet',),
'treffsikkerhetene': ('treffsikkerhet',),
'treffsikkerheter': ('treffsikkerhet',),
'trefiberplata': ('trefiberplate',),
'trefiberplate': ('trefiberplate',),
'trefiberplaten': ('trefiberplate',),
'trefiberplatene': ('trefiberplate',),
'trefiberplater': ('trefiberplate',),
'trefiredelstakt': ('trefiredelstakt',),
'trefiredelstakta': ('trefiredelstakt',),
'trefiredelstakten': ('trefiredelstakt',),
'trefiredelstaktene': ('trefiredelstakt',),
'trefiredelstakter': ('trefiredelstakt',),
'trefjerdedelstakt': ('trefjerdedelstakt',),
'trefjerdedelstakta': ('trefjerdedelstakt',),
'trefjerdedelstakten': ('trefjerdedelstakt',),
'trefjerdedelstaktene': ('trefjerdedelstakt',),
'trefjerdedelstakter': ('trefjerdedelstakt',),
'trefning': ('trefning',),
'trefninga': ('trefning',),
'trefningen': ('trefning',),
'trefningene': ('trefning',),
'trefninger': ('trefning',),
'trefoldighet': ('trefoldighet',),
'trefoldigheta': ('trefoldighet',),
'trefoldigheten': ('trefoldighet',),
'trefoldighetene': ('trefoldighet',),
'trefoldigheter': ('trefoldighet',),
'trefoldighetsfest': ('trefoldighetsfest',),
'trefoldighetsfesten': ('trefoldighetsfest',),
'trefoldighetsfestene': ('trefoldighetsfest',),
'trefoldighetsfester': ('trefoldighetsfest',),
'trefoldighetssøndag': ('trefoldighetssøndag',),
'trefoldighetssøndagen': ('trefoldighetssøndag',),
'trefoldighetssøndagene': ('trefoldighetssøndag',),
'trefoldighetssøndager': ('trefoldighetssøndag',),
'treforedling': ('treforedling',),
'treforedlinga': ('treforedling',),
'treforedlingen': ('treforedling',),
'treforedlingene': ('treforedling',),
'treforedlinger': ('treforedling',),
'trefot': ('trefot',),
'trefoten': ('trefot',),
'treføttene': ('trefot',),
'treføtter': ('trefot',),
'trefot': ('trefot',),
'trefoten': ('trefot',),
'treføttene': ('trefot',),
'treføtter': ('trefot',),
'treghet': ('treghet',),
'tregheta': ('treghet',),
'tregheten': ('treghet',),
'treghetene': ('treghet',),
'tregheter': ('treghet',),
'tregrensa': ('tregrense',),
'tregrense': ('tregrense',),
'tregrensen': ('tregrense',),
'tregrensene': ('tregrense',),
'tregrenser': ('tregrense',),
'trehest': ('trehest',),
'trehesten': ('trehest',),
'trehestene': ('trehest',),
'trehester': ('trehest',),
'trehjulssykkel': ('trehjulssykkel',),
'trehjulssykkelen': ('trehjulssykkel',),
'trehjulssyklene': ('trehjulssykkel',),
'trehjulssykler': ('trehjulssykkel',),
'trehus': ('trehus',),
'trehusa': ('trehus',),
'trehusene': ('trehus',),
'trehuset': ('trehus',),
'trekamp': ('trekamp',),
'trekampen': ('trekamp',),
'trekampene': ('trekamp',),
'trekamper': ('trekamp',),
'trekant': ('trekant',),
'trekanten': ('trekant',),
'trekantene': ('trekant',),
'trekanter': ('trekant',),
'trekantbytta': ('trekantbytte',),
'trekantbytte': ('trekantbytte',),
'trekantbyttene': ('trekantbytte',),
'trekantbytter': ('trekantbytte',),
'trekantbyttet': ('trekantbytte',),
'trekantdrama': ('trekantdrama',),
'trekantdramaene': ('trekantdrama',),
'trekantdramaer': ('trekantdrama',),
'trekantdramaet': ('trekantdrama',),
'trekk': ('trekk',),
'trekken': ('trekk',),
'trekkene': ('trekk',),
'trekker': ('trekk',),
'trekk': ('trekk',),
'trekka': ('trekk',),
'trekkene': ('trekk',),
'trekket': ('trekk',),
'trekk-kraft': ('trekk-kraft',),
'trekk-krafta': ('trekk-kraft',),
'trekk-kraften': ('trekk-kraft',),
'trekk-kreftene': ('trekk-kraft',),
'trekk-krefter': ('trekk-kraft',),
'trekkbasun': ('trekkbasun',),
'trekkbasunen': ('trekkbasun',),
'trekkbasunene': ('trekkbasun',),
'trekkbasuner': ('trekkbasun',),
'trekkdyr': ('trekkdyr',),
'trekkdyra': ('trekkdyr',),
'trekkdyrene': ('trekkdyr',),
'trekkdyret': ('trekkdyr',),
'trekker': ('trekker',),
'trekkere': ('trekker',),
'trekkeren': ('trekker',),
'trekkerer': ('trekker',),
'trekkerne': ('trekker',),
'trekkfugl': ('trekkfugl',),
'trekkfuglen': ('trekkfugl',),
'trekkfuglene': ('trekkfugl',),
'trekkfugler': ('trekkfugl',),
'trekkhund': ('trekkhund',),
'trekkhunden': ('trekkhund',),
'trekkhundene': ('trekkhund',),
'trekkhunder': ('trekkhund',),
'trekkoppgava': ('trekkoppgave',),
'trekkoppgave': ('trekkoppgave',),
'trekkoppgaven': ('trekkoppgave',),
'trekkoppgavene': ('trekkoppgave',),
'trekkoppgaver': ('trekkoppgave',),
'trekkpapir': ('trekkpapir',),
'trekkpapira': ('trekkpapir',),
'trekkpapirene': ('trekkpapir',),
'trekkpapirer': ('trekkpapir',),
'trekkpapiret': ('trekkpapir',),
'trekkplaster': ('trekkplaster',),
'trekkplasteret': ('trekkplaster',),
'trekkplastra': ('trekkplaster',),
'trekkplastre': ('trekkplaster',),
'trekkplastrene': ('trekkplaster',),
'trekkplastret': ('trekkplaster',),
'trekkprosent': ('trekkprosent',),
'trekkprosenten': ('trekkprosent',),
'trekkprosentene': ('trekkprosent',),
'trekkprosenter': ('trekkprosent',),
'trekkraft': ('trekkraft',),
'trekkrafta': ('trekkraft',),
'trekkraften': ('trekkraft',),
'trekkreftene': ('trekkraft',),
'trekkrefter': ('trekkraft',),
'trekkspell': ('trekkspell',),
'trekkspella': ('trekkspell',),
'trekkspellene': ('trekkspell',),
'trekkspellet': ('trekkspell',),
'trekkspeller': ('trekkspeller',),
'trekkspellere': ('trekkspeller',),
'trekkspelleren': ('trekkspeller',),
'trekkspellerer': ('trekkspeller',),
'trekkspellerne': ('trekkspeller',),
'trekkspill': ('trekkspill',),
'trekkspilla': ('trekkspill',),
'trekkspillene': ('trekkspill',),
'trekkspillet': ('trekkspill',),
'trekkspiller': ('trekkspiller',),
'trekkspillere': ('trekkspiller',),
'trekkspilleren': ('trekkspiller',),
'trekkspillerer': ('trekkspiller',),
'trekkspillerne': ('trekkspiller',),
'trekkvogn': ('trekkvogn',),
'trekkvogna': ('trekkvogn',),
'trekkvognen': ('trekkvogn',),
'trekkvognene': ('trekkvogn',),
'trekkvogner': ('trekkvogn',),
'treklang': ('treklang',),
'treklangen': ('treklang',),
'treklangene': ('treklang',),
'treklanger': ('treklang',),
'trekløver': ('trekløver',),
'trekløvere': ('trekløver',),
'trekløveren': ('trekløver',),
'trekløverer': ('trekløver',),
'trekløverne': ('trekløver',),
'trekløver': ('trekløver',),
'trekløvera': ('trekløver',),
'trekløverene': ('trekløver',),
'trekløverer': ('trekløver',),
'trekløveret': ('trekløver',),
'trekning': ('trekning',),
'trekninga': ('trekning',),
'trekningen': ('trekning',),
'trekningene': ('trekning',),
'trekninger': ('trekning',),
'trekol': ('trekol',),
'trekola': ('trekol',),
'trekolet': ('trekol',),
'trekombinasjon': ('trekombinasjon',),
'trekombinasjonen': ('trekombinasjon',),
'trekombinasjonene': ('trekombinasjon',),
'trekombinasjoner': ('trekombinasjon',),
'trekombinasjonslås': ('trekombinasjonslås',),
'trekombinasjonslåsa': ('trekombinasjonslås',),
'trekombinasjonslåsen': ('trekombinasjonslås',),
'trekombinasjonslåsene': ('trekombinasjonslås',),
'trekombinasjonslåser': ('trekombinasjonslås',),
'trekombinasjonslåset': ('trekombinasjonslås',),
'trekrona': ('trekrone',),
'trekrone': ('trekrone',),
'trekronen': ('trekrone',),
'trekronene': ('trekrone',),
'trekroner': ('trekrone',),
'trekryper': ('trekryper',),
'trekrypere': ('trekryper',),
'trekryperen': ('trekryper',),
'trekryperer': ('trekryper',),
'trekryperne': ('trekryper',),
'trektekaffe': ('trektekaffe',),
'trektekaffen': ('trektekaffe',),
'trektekaffene': ('trektekaffe',),
'trektekaffer': ('trektekaffe',),
'trektekanna': ('trektekanne',),
'trektekanne': ('trektekanne',),
'trektekannen': ('trektekanne',),
'trektekannene': ('trektekanne',),
'trektekanner': ('trektekanne',),
'trektsopp': ('trektsopp',),
'trektsoppen': ('trektsopp',),
'trektsoppene': ('trektsopp',),
'trektsopper': ('trektsopp',),
'trektsopp': ('trektsopp',),
'trektsoppen': ('trektsopp',),
'trektsoppene': ('trektsopp',),
'trektsopper': ('trektsopp',),
'trekull': ('trekull',),
'trekulla': ('trekull',),
'trekullene': ('trekull',),
'trekullet': ('trekull',),
'trelast': ('trelast',),
'trelasta': ('trelast',),
'trelasten': ('trelast',),
'trelastene': ('trelast',),
'trelaster': ('trelast',),
'trelerka': ('trelerke',),
'trelerke': ('trelerke',),
'trelerken': ('trelerke',),
'trelerkene': ('trelerke',),
'trelerker': ('trelerke',),
'trell': ('trell',),
'trellen': ('trell',),
'trellene': ('trell',),
'treller': ('trell',),
'trell': ('trell',),
'trellen': ('trell',),
'trellene': ('trell',),
'treller': ('trell',),
'trell': ('trell',),
'trella': ('trell',),
'trellene': ('trell',),
'trellet': ('trell',),
'trelldom': ('trelldom',),
'trelldommen': ('trelldom',),
'trelldommene': ('trelldom',),
'trelldommer': ('trelldom',),
'trellekår': ('trellekår',),
'trellekåra': ('trellekår',),
'trellekårene': ('trellekår',),
'trellekåret': ('trellekår',),
'trellesinn': ('trellesinn',),
'trellesinna': ('trellesinn',),
'trellesinnene': ('trellesinn',),
'trellesinnet': ('trellesinn',),
'trellkvinna': ('trellkvinne',),
'trellkvinne': ('trellkvinne',),
'trellkvinnen': ('trellkvinne',),
'trellkvinnene': ('trellkvinne',),
'trellkvinner': ('trellkvinne',),
'trema': ('trema',),
'tremaene': ('trema',),
'tremaer': ('trema',),
'tremaet': ('trema',),
'tremasse': ('tremasse',),
'tremassen': ('tremasse',),
'tremassene': ('tremasse',),
'tremasser': ('tremasse',),
'tremaster': ('tremaster',),
'tremastere': ('tremaster',),
'tremasteren': ('tremaster',),
'tremasterer': ('tremaster',),
'tremasterne': ('tremaster',),
'tremenning': ('tremenning',),
'tremenningen': ('tremenning',),
'tremenningene': ('tremenning',),
'tremenninger': ('tremenning',),
'tremilsgrensa': ('tremilsgrense',),
'tremilsgrense': ('tremilsgrense',),
'tremilsgrensen': ('tremilsgrense',),
'tremilsgrensene': ('tremilsgrense',),
'tremilsgrenser': ('tremilsgrense',),
'tremme': ('tremme',),
'tremmen': ('tremme',),
'tremmene': ('tremme',),
'tremmer': ('tremme',),
'tremolo': ('tremolo',),
'tremoloen': ('tremolo',),
'tremoloene': ('tremolo',),
'tremoloer': ('tremolo',),
'tremor': ('tremor',),
'tremoren': ('tremor',),
'tremorene': ('tremor',),
'tremorer': ('tremor',),
'tremulant': ('tremulant',),
'tremulanten': ('tremulant',),
'tremulantene': ('tremulant',),
'tremulanter': ('tremulant',),
'tren': ('tren',),
'trena': ('tren',),
'trenene': ('tren',),
'trenet': ('tren',),
'trench-coat': ('trench-coat',),
'trench-coaten': ('trench-coat',),
'trench-coatene': ('trench-coat',),
'trench-coater': ('trench-coat',),
'trend': ('trend',),
'trenden': ('trend',),
'trendene': ('trend',),
'trender': ('trend',),
'trendsetter': ('trendsetter',),
'trendsettere': ('trendsetter',),
'trendsetteren': ('trendsetter',),
'trendsetterer': ('trendsetter',),
'trendsetterne': ('trendsetter',),
'trener': ('trener',),
'trenere': ('trener',),
'treneren': ('trener',),
'trenerer': ('trener',),
'trenerne': ('trener',),
'trenerchampion': ('trenerchampion',),
'trenerchampionen': ('trenerchampion',),
'trenerchampionene': ('trenerchampion',),
'trenerchampioner': ('trenerchampion',),
'trengsel': ('trengsel',),
'trengselen': ('trengsel',),
'trengsla': ('trengsel',),
'trengslene': ('trengsel',),
'trengsler': ('trengsel',),
'trengsla': ('trengsle',),
'trengsle': ('trengsle',),
'trengslen': ('trengsle',),
'trengslene': ('trengsle',),
'trengsler': ('trengsle',),
'trengslet': ('trengsle',),
'trengsmål': ('trengsmål',),
'trengsmåla': ('trengsmål',),
'trengsmålene': ('trengsmål',),
'trengsmålet': ('trengsmål',),
'trening': ('trening',),
'treninga': ('trening',),
'treningen': ('trening',),
'treningene': ('trening',),
'treninger': ('trening',),
'treningsdrakt': ('treningsdrakt',),
'treningsdrakta': ('treningsdrakt',),
'treningsdrakten': ('treningsdrakt',),
'treningsdraktene': ('treningsdrakt',),
'treningsdrakter': ('treningsdrakt',),
'treningsnarkoman': ('treningsnarkoman',),
'treningsnarkomanen': ('treningsnarkoman',),
'treningsnarkomanene': ('treningsnarkoman',),
'treningsnarkomaner': ('treningsnarkoman',),
'trepan': ('trepan',),
'trepanen': ('trepan',),
'trepanene': ('trepan',),
'trepaner': ('trepan',),
'trepanasjon': ('trepanasjon',),
'trepanasjonen': ('trepanasjon',),
'trepanasjonene': ('trepanasjon',),
'trepanasjoner': ('trepanasjon',),
'trepart': ('trepart',),
'treparten': ('trepart',),
'trepartene': ('trepart',),
'treparter': ('trepart',),
'treplanskryss': ('treplanskryss',),
'treplanskryssa': ('treplanskryss',),
'treplanskryssene': ('treplanskryss',),
'treplanskrysset': ('treplanskryss',),
'trepropp': ('trepropp',),
'treproppen': ('trepropp',),
'treproppene': ('trepropp',),
'trepropper': ('trepropp',),
'treseter': ('treseter',),
'tresetere': ('treseter',),
'treseteren': ('treseter',),
'treseterer': ('treseter',),
'treseterne': ('treseter',),
'treskegolv': ('treskegolv',),
'treskegolva': ('treskegolv',),
'treskegolvene': ('treskegolv',),
'treskegolvet': ('treskegolv',),
'treskegulv': ('treskegulv',),
'treskegulva': ('treskegulv',),
'treskegulvene': ('treskegulv',),
'treskegulvet': ('treskegulv',),
'treskel': ('treskel',),
'treskelen': ('treskel',),
'tresklene': ('treskel',),
'treskler': ('treskel',),
'treskemaskin': ('treskemaskin',),
'treskemaskina': ('treskemaskin',),
'treskemaskinen': ('treskemaskin',),
'treskemaskinene': ('treskemaskin',),
'treskemaskiner': ('treskemaskin',),
'tresker': ('tresker',),
'treskere': ('tresker',),
'treskeren': ('tresker',),
'treskerer': ('tresker',),
'treskerne': ('tresker',),
'treskeverk': ('treskeverk',),
'treskeverka': ('treskeverk',),
'treskeverkene': ('treskeverk',),
'treskeverker': ('treskeverk',),
'treskeverket': ('treskeverk',),
'treskjærer': ('treskjærer',),
'treskjærere': ('treskjærer',),
'treskjæreren': ('treskjærer',),
'treskjærerer': ('treskjærer',),
'treskjærerne': ('treskjærer',),
'treskrue': ('treskrue',),
'treskruen': ('treskrue',),
'treskruene': ('treskrue',),
'treskruer': ('treskrue',),
'treskruve': ('treskruve',),
'treskruven': ('treskruve',),
'treskruvene': ('treskruve',),
'treskruver': ('treskruve',),
'treskurd': ('treskurd',),
'treskurden': ('treskurd',),
'treskurdene': ('treskurd',),
'treskurder': ('treskurd',),
'tresliperi': ('tresliperi',),
'tresliperia': ('tresliperi',),
'tresliperiene': ('tresliperi',),
'tresliperier': ('tresliperi',),
'tresliperiet': ('tresliperi',),
'tresløyd': ('tresløyd',),
'tresløyden': ('tresløyd',),
'tresløydene': ('tresløyd',),
'tresløyder': ('tresløyd',),
'tresmak': ('tresmak',),
'tresmaken': ('tresmak',),
'tresmakene': ('tresmak',),
'tresmaker': ('tresmak',),
'tresnitt': ('tresnitt',),
'tresnitta': ('tresnitt',),
'tresnittene': ('tresnitt',),
'tresnittet': ('tresnitt',),
'trespon': ('trespon',),
'tresponen': ('trespon',),
'tresponene': ('trespon',),
'tresponer': ('trespon',),
'tresprit': ('tresprit',),
'trespriten': ('tresprit',),
'trespritene': ('tresprit',),
'trespriter': ('tresprit',),
'tress': ('tress',),
'tressen': ('tress',),
'tressene': ('tress',),
'tresser': ('tress',),
'tressa': ('tresse',),
'tresse': ('tresse',),
'tressen': ('tresse',),
'tressene': ('tresse',),
'tresser': ('tresse',),
'trestamme': ('trestamme',),
'trestammen': ('trestamme',),
'trestammene': ('trestamme',),
'trestammer': ('trestamme',),
'tresteg': ('tresteg',),
'trestega': ('tresteg',),
'trestegene': ('tresteg',),
'tresteget': ('tresteg',),
'tretal': ('tretal',),
'tretala': ('tretal',),
'tretalene': ('tretal',),
'tretalet': ('tretal',),
'tretall': ('tretall',),
'tretalla': ('tretall',),
'tretallene': ('tretall',),
'tretallet': ('tretall',),
'tretid': ('tretid',),
'tretida': ('tretid',),
'tretiden': ('tretid',),
'tretidene': ('tretid',),
'tretider': ('tretid',),
'tretjæra': ('tretjære',),
'tretjære': ('tretjære',),
'tretjæren': ('tretjære',),
'tretjærene': ('tretjære',),
'tretjærer': ('tretjære',),
'tretopp': ('tretopp',),
'tretoppen': ('tretopp',),
'tretoppene': ('tretopp',),
'tretopper': ('tretopp',),
'tretta': ('trette',),
'trette': ('trette',),
'tretten': ('trette',),
'trettene': ('trette',),
'tretter': ('trette',),
'trettendedag': ('trettendedag',),
'trettendedagen': ('trettendedag',),
'trettendedagene': ('trettendedag',),
'trettendedager': ('trettendedag',),
'trettendel': ('trettendel',),
'trettendelen': ('trettendel',),
'trettendelene': ('trettendel',),
'trettendeler': ('trettendel',),
'trettenhundretal': ('trettenhundretal',),
'trettenhundretala': ('trettenhundretal',),
'trettenhundretalene': ('trettenhundretal',),
'trettenhundretalet': ('trettenhundretal',),
'trettenhundretall': ('trettenhundretall',),
'trettenhundretalla': ('trettenhundretall',),
'trettenhundretallene': ('trettenhundretall',),
'trettenhundretallet': ('trettenhundretall',),
'trettenåring': ('trettenåring',),
'trettenåringen': ('trettenåring',),
'trettenåringene': ('trettenåring',),
'trettenåringer': ('trettenåring',),
'trettenårsalder': ('trettenårsalder',),
'trettenårsaldere': ('trettenårsalder',),
'trettenårsalderen': ('trettenårsalder',),
'trettenårsalderer': ('trettenårsalder',),
'trettenårsalderne': ('trettenårsalder',),
'trettenårsaldre': ('trettenårsalder',),
'trettenårsaldrene': ('trettenårsalder',),
'trettenårsaldrer': ('trettenårsalder',),
'tretthet': ('tretthet',),
'trettheta': ('tretthet',),
'trettheten': ('tretthet',),
'tretthetene': ('tretthet',),
'trettheter': ('tretthet',),
'tretthetsbrott': ('tretthetsbrott',),
'tretthetsbrotta': ('tretthetsbrott',),
'tretthetsbrottene': ('tretthetsbrott',),
'tretthetsbrottet': ('tretthetsbrott',),
'tretthetsbrudd': ('tretthetsbrudd',),
'tretthetsbrudda': ('tretthetsbrudd',),
'tretthetsbruddene': ('tretthetsbrudd',),
'tretthetsbruddet': ('tretthetsbrudd',),
'trettidel': ('trettidel',),
'trettidelen': ('trettidel',),
'trettidelene': ('trettidel',),
'trettideler': ('trettidel',),
'trettiår': ('trettiår',),
'trettiåra': ('trettiår',),
'trettiårene': ('trettiår',),
'trettiåret': ('trettiår',),
'trettiåring': ('trettiåring',),
'trettiåringen': ('trettiåring',),
'trettiåringene': ('trettiåring',),
'trettiåringer': ('trettiåring',),
'trettiårsdag': ('trettiårsdag',),
'trettiårsdagen': ('trettiårsdag',),
'trettiårsdagene': ('trettiårsdag',),
'trettiårsdager': ('trettiårsdag',),
'trettiårskrig': ('trettiårskrig',),
'trettiårskrigen': ('trettiårskrig',),
'trettiårskrigene': ('trettiårskrig',),
'trettiårskriger': ('trettiårskrig',),
'treull': ('treull',),
'treulla': ('treull',),
'treullen': ('treull',),
'treullene': ('treull',),
'treuller': ('treull',),
'trev': ('trev',),
'treva': ('trev',),
'trevene': ('trev',),
'trevet': ('trev',),
'trevara': ('trevare',),
'trevare': ('trevare',),
'trevaren': ('trevare',),
'trevarene': ('trevare',),
'trevarer': ('trevare',),
'treveps': ('treveps',),
'trevepsen': ('treveps',),
'trevepsene': ('treveps',),
'trevepser': ('treveps',),
'treverk': ('treverk',),
'treverka': ('treverk',),
'treverkene': ('treverk',),
'treverker': ('treverk',),
'treverket': ('treverk',),
'trevirka': ('trevirke',),
'trevirke': ('trevirke',),
'trevirkene': ('trevirke',),
'trevirker': ('trevirke',),
'trevirket': ('trevirke',),
'trevl': ('trevl',),
'trevlen': ('trevl',),
'trevlene': ('trevl',),
'trevler': ('trevl',),
'treåring': ('treåring',),
'treåringen': ('treåring',),
'treåringene': ('treåring',),
'treåringer': ('treåring',),
'treårsalder': ('treårsalder',),
'treårsaldere': ('treårsalder',),
'treårsalderen': ('treårsalder',),
'treårsalderer': ('treårsalder',),
'treårsalderne': ('treårsalder',),
'treårsaldre': ('treårsalder',),
'treårsaldrene': ('treårsalder',),
'treårsaldrer': ('treårsalder',),
'triade': ('triade',),
'triaden': ('triade',),
'triadene': ('triade',),
'triader': ('triade',),
'trial': ('trial',),
'triala': ('trial',),
'trialene': ('trial',),
'trialet': ('trial',),
'triangel': ('triangel',),
'triangelen': ('triangel',),
'trianglene': ('triangel',),
'triangler': ('triangel',),
'triangel': ('triangel',),
'triangelen': ('triangel',),
'triangelet': ('triangel',),
'triangla': ('triangel',),
'trianglene': ('triangel',),
'triangler': ('triangel',),
'trianglet': ('triangel',),
'trias': ('trias',),
'triasformasjon': ('triasformasjon',),
'triasformasjonen': ('triasformasjon',),
'triasformasjonene': ('triasformasjon',),
'triasformasjoner': ('triasformasjon',),
'triasperiode': ('triasperiode',),
'triasperioden': ('triasperiode',),
'triasperiodene': ('triasperiode',),
'triasperioder': ('triasperiode',),
'triassystem': ('triassystem',),
'triassystema': ('triassystem',),
'triassystemene': ('triassystem',),
'triassystemer': ('triassystem',),
'triassystemet': ('triassystem',),
'triatlon': ('triatlon',),
'triatlonen': ('triatlon',),
'triatlonene': ('triatlon',),
'triatloner': ('triatlon',),
'tribalisme': ('tribalisme',),
'tribalismen': ('tribalisme',),
'tribalismene': ('tribalisme',),
'tribalismer': ('tribalisme',),
'tribologi': ('tribologi',),
'tribologien': ('tribologi',),
'tribologiene': ('tribologi',),
'tribologier': ('tribologi',),
'tribometer': ('tribometer',),
'tribometeret': ('tribometer',),
'tribometra': ('tribometer',),
'tribometre': ('tribometer',),
'tribometrene': ('tribometer',),
'tribometret': ('tribometer',),
'tribun': ('tribun',),
'tribunen': ('tribun',),
'tribunene': ('tribun',),
'tribuner': ('tribun',),
'tribunal': ('tribunal',),
'tribunala': ('tribunal',),
'tribunalene': ('tribunal',),
'tribunaler': ('tribunal',),
'tribunalet': ('tribunal',),
'tribune': ('tribune',),
'tribunen': ('tribune',),
'tribunene': ('tribune',),
'tribuner': ('tribune',),
'tribunesliter': ('tribunesliter',),
'tribuneslitere': ('tribunesliter',),
'tribunesliteren': ('tribunesliter',),
'tribunesliterer': ('tribunesliter',),
'tribunesliterne': ('tribunesliter',),
'tributt': ('tributt',),
'tributten': ('tributt',),
'tributtene': ('tributt',),
'tributter': ('tributt',),
'triceps': ('triceps',),
'tricepsen': ('triceps',),
'tricepsene': ('triceps',),
'tricepser': ('triceps',),
'triennale': ('triennale',),
'triennalen': ('triennale',),
'triennalene': ('triennale',),
'triennaler': ('triennale',),
'triforia': ('triforium',),
'triforiene': ('triforium',),
'triforier': ('triforium',),
'triforiet': ('triforium',),
'triforium': ('triforium',),
'trigger': ('trigger',),
'triggere': ('trigger',),
'triggeren': ('trigger',),
'triggerer': ('trigger',),
'triggerne': ('trigger',),
'trigonometri': ('trigonometri',),
'trigonometrien': ('trigonometri',),
'trigonometriene': ('trigonometri',),
'trigonometrier': ('trigonometri',),
'trikin': ('trikin',),
'trikinen': ('trikin',),
'trikinene': ('trikin',),
'trikiner': ('trikin',),
'trikinose': ('trikinose',),
'trikinosen': ('trikinose',),
'trikinosene': ('trikinose',),
'trikinoser': ('trikinose',),
'trikk': ('trikk',),
'trikken': ('trikk',),
'trikkene': ('trikk',),
'trikker': ('trikk',),
'trikk': ('trikk',),
'trikka': ('trikk',),
'trikkene': ('trikk',),
'trikket': ('trikk',),
'trikkekonduktør': ('trikkekonduktør',),
'trikkekonduktøren': ('trikkekonduktør',),
'trikkekonduktørene': ('trikkekonduktør',),
'trikkekonduktører': ('trikkekonduktør',),
'trikkeskinna': ('trikkeskinne',),
'trikkeskinne': ('trikkeskinne',),
'trikkeskinnen': ('trikkeskinne',),
'trikkeskinnene': ('trikkeskinne',),
'trikkeskinner': ('trikkeskinne',),
'trikkestall': ('trikkestall',),
'trikkestallen': ('trikkestall',),
'trikkestallene': ('trikkestall',),
'trikkestaller': ('trikkestall',),
'trikolor': ('trikolor',),
'trikoloren': ('trikolor',),
'trikolorene': ('trikolor',),
'trikolorer': ('trikolor',),
'trikot': ('trikot',),
'trikoten': ('trikot',),
'trikotene': ('trikot',),
'trikoter': ('trikot',),
'trikotasje': ('trikotasje',),
'trikotasjen': ('trikotasje',),
'trikotasjene': ('trikotasje',),
'trikotasjer': ('trikotasje',),
'triks': ('triks',),
'triksa': ('triks',),
'triksene': ('triks',),
'trikset': ('triks',),
'trilla': ('trille',),
'trille': ('trille',),
'trillen': ('trille',),
'trillene': ('trille',),
'triller': ('trille',),
'trilla': ('trille',),
'trille': ('trille',),
'trillen': ('trille',),
'trillene': ('trille',),
'triller': ('trille',),
'trillebag': ('trillebag',),
'trillebagen': ('trillebag',),
'trillebagene': ('trillebag',),
'trillebager': ('trillebag',),
'trillebord': ('trillebord',),
'trilleborda': ('trillebord',),
'trillebordene': ('trillebord',),
'trilleborder': ('trillebord',),
'trillebordet': ('trillebord',),
'trillebår': ('trillebår',),
'trillebåra': ('trillebår',),
'trillebåren': ('trillebår',),
'trillebårene': ('trillebår',),
'trillebårer': ('trillebår',),
'trillebør': ('trillebør',),
'trillebøra': ('trillebør',),
'trillebøren': ('trillebør',),
'trillebørene': ('trillebør',),
'trillebører': ('trillebør',),
'trillepika': ('trillepike',),
'trillepike': ('trillepike',),
'trillepiken': ('trillepike',),
'trillepikene': ('trillepike',),
'trillepiker': ('trillepike',),
'trilling': ('trilling',),
'trillingen': ('trilling',),
'trillingene': ('trilling',),
'trillinger': ('trilling',),
'trillion': ('trillion',),
'trillionen': ('trillion',),
'trillionene': ('trillion',),
'trillioner': ('trillion',),
'trilobitt': ('trilobitt',),
'trilobitten': ('trilobitt',),
'trilobittene': ('trilobitt',),
'trilobitter': ('trilobitt',),
'trilogi': ('trilogi',),
'trilogien': ('trilogi',),
'trilogiene': ('trilogi',),
'trilogier': ('trilogi',),
'trim': ('trim',),
'trimmen': ('trim',),
'trimmene': ('trim',),
'trimmer': ('trim',),
'trimaran': ('trimaran',),
'trimaranen': ('trimaran',),
'trimaranene': ('trimaran',),
'trimaraner': ('trimaran',),
'trimmer': ('trimmer',),
'trimmere': ('trimmer',),
'trimmeren': ('trimmer',),
'trimmerer': ('trimmer',),
'trimmerne': ('trimmer',),
'trimrom': ('trimrom',),
'trimromma': ('trimrom',),
'trimrommene': ('trimrom',),
'trimrommet': ('trimrom',),
'trinidader': ('trinidader',),
'trinidadere': ('trinidader',),
'trinidaderen': ('trinidader',),
'trinidaderer': ('trinidader',),
'trinidaderne': ('trinidader',),
'trinitatis': ('trinitatis',),
'trinitatisfest': ('trinitatisfest',),
'trinitatisfesten': ('trinitatisfest',),
'trinitatisfestene': ('trinitatisfest',),
'trinitatisfester': ('trinitatisfest',),
'trinitrotoluen': ('trinitrotoluen',),
'trinitrotoluena': ('trinitrotoluen',),
'trinitrotoluenene': ('trinitrotoluen',),
'trinitrotoluenet': ('trinitrotoluen',),
'trinn': ('trinn',),
'trinna': ('trinn',),
'trinnene': ('trinn',),
'trinnet': ('trinn',),
'trinnrakett': ('trinnrakett',),
'trinnraketten': ('trinnrakett',),
'trinnrakettene': ('trinnrakett',),
'trinnraketter': ('trinnrakett',),
'trinsa': ('trinse',),
'trinse': ('trinse',),
'trinsen': ('trinse',),
'trinsene': ('trinse',),
'trinser': ('trinse',),
'trio': ('trio',),
'trioen': ('trio',),
'trioene': ('trio',),
'trioer': ('trio',),
'triol': ('triol',),
'triolen': ('triol',),
'triolene': ('triol',),
'trioler': ('triol',),
'tripod': ('tripod',),
'tripoden': ('tripod',),
'tripodene': ('tripod',),
'tripoder': ('tripod',),
'tripp': ('tripp',),
'trippen': ('tripp',),
'trippene': ('tripp',),
'tripper': ('tripp',),
'triplene': ('trippel',),
'tripler': ('trippel',),
'trippel': ('trippel',),
'trippelen': ('trippel',),
'tripla': ('trippel',),
'triplene': ('trippel',),
'tripler': ('trippel',),
'trippel': ('trippel',),
'trippelet': ('trippel',),
'trippelallianse': ('trippelallianse',),
'trippelalliansen': ('trippelallianse',),
'trippelalliansene': ('trippelallianse',),
'trippelallianser': ('trippelallianse',),
'trippelkollisjon': ('trippelkollisjon',),
'trippelkollisjonen': ('trippelkollisjon',),
'trippelkollisjonene': ('trippelkollisjon',),
'trippelkollisjoner': ('trippelkollisjon',),
'trippelkonsert': ('trippelkonsert',),
'trippelkonserten': ('trippelkonsert',),
'trippelkonsertene': ('trippelkonsert',),
'trippelkonserter': ('trippelkonsert',),
'trippelmester': ('trippelmester',),
'trippelmestere': ('trippelmester',),
'trippelmesteren': ('trippelmester',),
'trippelmesterer': ('trippelmester',),
'trippelmesterne': ('trippelmester',),
'trippelmestre': ('trippelmester',),
'trippelmestrene': ('trippelmester',),
'trippelmestrer': ('trippelmester',),
'trippelpunkt': ('trippelpunkt',),
'trippelpunkta': ('trippelpunkt',),
'trippelpunktene': ('trippelpunkt',),
'trippelpunkter': ('trippelpunkt',),
'trippelpunktet': ('trippelpunkt',),
'trippeltakt': ('trippeltakt',),
'trippeltakta': ('trippeltakt',),
'trippeltakten': ('trippeltakt',),
'trippeltaktene': ('trippeltakt',),
'trippeltakter': ('trippeltakt',),
'trippelvaksina': ('trippelvaksine',),
'trippelvaksine': ('trippelvaksine',),
'trippelvaksinen': ('trippelvaksine',),
'trippelvaksinene': ('trippelvaksine',),
'trippelvaksiner': ('trippelvaksine',),
'trippteller': ('trippteller',),
'tripptellere': ('trippteller',),
'tripptelleren': ('trippteller',),
'tripptellerer': ('trippteller',),
'tripptellerne': ('trippteller',),
'trips': ('trips',),
'tripsen': ('trips',),
'tripsene': ('trips',),
'tripser': ('trips',),
'trisa': ('trise',),
'trise': ('trise',),
'trisen': ('trise',),
'trisene': ('trise',),
'triser': ('trise',),
'trismus': ('trismus',),
'trismusen': ('trismus',),
'trismusene': ('trismus',),
'trismuser': ('trismus',),
'trissa': ('trisse',),
'trisse': ('trisse',),
'trissen': ('trisse',),
'trissene': ('trisse',),
'trisser': ('trisse',),
'tristesse': ('tristesse',),
'tristessen': ('tristesse',),
'tristessene': ('tristesse',),
'tristesser': ('tristesse',),
'tristhet': ('tristhet',),
'tristheta': ('tristhet',),
'tristheten': ('tristhet',),
'tristhetene': ('tristhet',),
'tristheter': ('tristhet',),
'tritium': ('tritium',),
'tritiuma': ('tritium',),
'tritiumene': ('tritium',),
'tritiumet': ('tritium',),
'tritt': ('tritt',),
'tritta': ('tritt',),
'trittene': ('tritt',),
'trittet': ('tritt',),
'triumf': ('triumf',),
'triumfen': ('triumf',),
'triumfene': ('triumf',),
'triumfer': ('triumf',),
'triumfator': ('triumfator',),
'triumfatoren': ('triumfator',),
'triumfatorene': ('triumfator',),
'triumfatorer': ('triumfator',),
'triumfboge': ('triumfboge',),
'triumfbogen': ('triumfboge',),
'triumfbogene': ('triumfboge',),
'triumfboger': ('triumfboge',),
'triumfbue': ('triumfbue',),
'triumfbuen': ('triumfbue',),
'triumfbuene': ('triumfbue',),
'triumfbuer': ('triumfbue',),
'triumftog': ('triumftog',),
'triumftoga': ('triumftog',),
'triumftogene': ('triumftog',),
'triumftoget': ('triumftog',),
'triumvirat': ('triumvirat',),
'triumvirata': ('triumvirat',),
'triumviratene': ('triumvirat',),
'triumvirater': ('triumvirat',),
'triumviratet': ('triumvirat',),
'trivialitet': ('trivialitet',),
'trivialiteten': ('trivialitet',),
'trivialitetene': ('trivialitet',),
'trivialiteter': ('trivialitet',),
'triviallitteratur': ('triviallitteratur',),
'triviallitteraturen': ('triviallitteratur',),
'triviallitteraturene': ('triviallitteratur',),
'triviallitteraturer': ('triviallitteratur',),
'trivialnavn': ('trivialnavn',),
'trivialnavna': ('trivialnavn',),
'trivialnavnene': ('trivialnavn',),
'trivialnavnet': ('trivialnavn',),
'trivnad': ('trivnad',),
'trivnaden': ('trivnad',),
'trivnadene': ('trivnad',),
'trivnader': ('trivnad',),
'trivsel': ('trivsel',),
'trivselen': ('trivsel',),
'trivslene': ('trivsel',),
'trivsler': ('trivsel',),
'tro': ('tro',),
'troa': ('tro',),
'troen': ('tro',),
'troene': ('tro',),
'troer': ('tro',),
'tro': ('tro',),
'troa': ('tro',),
'troen': ('tro',),
'troene': ('tro',),
'troer': ('tro',),
'troa': ('troe',),
'troe': ('troe',),
'troen': ('troe',),
'troene': ('troe',),
'troer': ('troe',),
'troende': ('troende',),
'trofea': ('trofé',),
'trofeen': ('trofé',),
'trofeene': ('trofé',),
'trofeer': ('trofé',),
'trofeet': ('trofé',),
'trofé': ('trofé',),
'troféa': ('trofé',),
'troféen': ('trofé',),
'troféene': ('trofé',),
'troféer': ('trofé',),
'troféet': ('trofé',),
'troika': ('troika',),
'troikaen': ('troika',),
'troikaene': ('troika',),
'troikaer': ('troika',),
'trojaner': ('trojaner',),
'trojanere': ('trojaner',),
'trojaneren': ('trojaner',),
'trojanerer': ('trojaner',),
'trojanerne': ('trojaner',),
'trokeen': ('troké',),
'trokeene': ('troké',),
'trokeer': ('troké',),
'troké': ('troké',),
'trokéen': ('troké',),
'trokéene': ('troké',),
'trokéer': ('troké',),
'troll': ('troll',),
'trolla': ('troll',),
'trollene': ('troll',),
'trollet': ('troll',),
'trollbær': ('trollbær',),
'trollbæra': ('trollbær',),
'trollbærene': ('trollbær',),
'trollbæret': ('trollbær',),
'trolldom': ('trolldom',),
'trolldommen': ('trolldom',),
'trolldommene': ('trolldom',),
'trolldommer': ('trolldom',),
'trolldomskunst': ('trolldomskunst',),
'trolldomskunsten': ('trolldomskunst',),
'trolldomskunstene': ('trolldomskunst',),
'trolldomskunster': ('trolldomskunst',),
'trolldomsmakt': ('trolldomsmakt',),
'trolldomsmakta': ('trolldomsmakt',),
'trolldomsmakten': ('trolldomsmakt',),
'trolldomsmaktene': ('trolldomsmakt',),
'trolldomsmakter': ('trolldomsmakt',),
'trolleybuss': ('trolleybuss',),
'trolleybussen': ('trolleybuss',),
'trolleybussene': ('trolleybuss',),
'trolleybusser': ('trolleybuss',),
'trollgarn': ('trollgarn',),
'trollgarna': ('trollgarn',),
'trollgarnene': ('trollgarn',),
'trollgarnet': ('trollgarn',),
'trollhegg': ('trollhegg',),
'trollheggen': ('trollhegg',),
'trollheggene': ('trollhegg',),
'trollhegger': ('trollhegg',),
'trollhummer': ('trollhummer',),
'trollhummere': ('trollhummer',),
'trollhummeren': ('trollhummer',),
'trollhummerer': ('trollhummer',),
'trollhummerne': ('trollhummer',),
'trollkatt': ('trollkatt',),
'trollkatten': ('trollkatt',),
'trollkattene': ('trollkatt',),
'trollkatter': ('trollkatt',),
'trollkattspy': ('trollkattspy',),
'trollkattspya': ('trollkattspy',),
'trollkattspyene': ('trollkattspy',),
'trollkattspyet': ('trollkattspy',),
'trollkjerring': ('trollkjerring',),
'trollkjerringa': ('trollkjerring',),
'trollkjerringen': ('trollkjerring',),
'trollkjerringene': ('trollkjerring',),
'trollkjerringer': ('trollkjerring',),
'trollkjerringspytt': ('trollkjerringspytt',),
'trollkjerringspytta': ('trollkjerringspytt',),
'trollkjerringspyttene': ('trollkjerringspytt',),
'trollkjerringspyttet': ('trollkjerringspytt',),
'trollkrabba': ('trollkrabbe',),
'trollkrabbe': ('trollkrabbe',),
'trollkrabben': ('trollkrabbe',),
'trollkrabbene': ('trollkrabbe',),
'trollkrabber': ('trollkrabbe',),
'trollkrem': ('trollkrem',),
'trollkremen': ('trollkrem',),
'trollkremene': ('trollkrem',),
'trollkremer': ('trollkrem',),
'trollmann': ('trollmann',),
'trollmannen': ('trollmann',),
'trollmenn': ('trollmann',),
'trollmennene': ('trollmann',),
'trollmjøl': ('trollmjøl',),
'trollmjøla': ('trollmjøl',),
'trollmjølene': ('trollmjøl',),
'trollmjølet': ('trollmjøl',),
'trollpakk': ('trollpakk',),
'trollpakka': ('trollpakk',),
'trollpakkene': ('trollpakk',),
'trollpakket': ('trollpakk',),
'trollring': ('trollring',),
'trollringen': ('trollring',),
'trollringene': ('trollring',),
'trollringer': ('trollring',),
'trollskap': ('trollskap',),
'trollskapa': ('trollskap',),
'trollskapen': ('trollskap',),
'trollskapene': ('trollskap',),
'trollskaper': ('trollskap',),
'trollskapet': ('trollskap',),
'trollsmør': ('trollsmør',),
'trollsmøra': ('trollsmør',),
'trollsmørene': ('trollsmør',),
'trollsmøret': ('trollsmør',),
'trollspeil': ('trollspeil',),
'trollspeila': ('trollspeil',),
'trollspeilene': ('trollspeil',),
'trollspeilet': ('trollspeil',),
'trollspy': ('trollspy',),
'trollspya': ('trollspy',),
'trollspyene': ('trollspy',),
'trollspyet': ('trollspy',),
'trollunge': ('trollunge',),
'trollungen': ('trollunge',),
'trollungene': ('trollunge',),
'trollunger': ('trollunge',),
'trollurt': ('trollurt',),
'trollurta': ('trollurt',),
'trollurten': ('trollurt',),
'trollurtene': ('trollurt',),
'trollurter': ('trollurt',),
'trollvisa': ('trollvise',),
'trollvise': ('trollvise',),
'trollvisen': ('trollvise',),
'trollvisene': ('trollvise',),
'trollviser': ('trollvise',),
'trolløya': ('trolløye',),
'trolløye': ('trolløye',),
'trolløyene': ('trolløye',),
'trolløyer': ('trolløye',),
'trolløyet': ('trolløye',),
'trolløyne': ('trolløye',),
'trolløynene': ('trolløye',),
'trolovelse': ('trolovelse',),
'trolovelsen': ('trolovelse',),
'trolovelsene': ('trolovelse',),
'trolovelser': ('trolovelse',),
'trom': ('trom',),
'tromma': ('trom',),
'trommene': ('trom',),
'trommet': ('trom',),
'trombe': ('trombe',),
'tromben': ('trombe',),
'trombene': ('trombe',),
'tromber': ('trombe',),
'trombin': ('trombin',),
'trombina': ('trombin',),
'trombinene': ('trombin',),
'trombinet': ('trombin',),
'trombocytt': ('trombocytt',),
'trombocytten': ('trombocytt',),
'trombocyttene': ('trombocytt',),
'trombocytter': ('trombocytt',),
'trombone': ('trombone',),
'trombonen': ('trombone',),
'trombonene': ('trombone',),
'tromboner': ('trombone',),
'trombonist': ('trombonist',),
'trombonisten': ('trombonist',),
'trombonistene': ('trombonist',),
'trombonister': ('trombonist',),
'trombose': ('trombose',),
'trombosen': ('trombose',),
'trombosene': ('trombose',),
'tromboser': ('trombose',),
'tromla': ('tromle',),
'tromle': ('tromle',),
'tromlen': ('tromle',),
'tromlene': ('tromle',),
'tromler': ('tromle',),
'tromma': ('tromme',),
'tromme': ('tromme',),
'trommen': ('tromme',),
'trommene': ('tromme',),
'trommer': ('tromme',),
'trommeeld': ('trommeeld',),
'trommeelden': ('trommeeld',),
'trommeeldene': ('trommeeld',),
'trommeelder': ('trommeeld',),
'trommeeld': ('trommeeld',),
'trommeelden': ('trommeeld',),
'trommeeldene': ('trommeeld',),
'trommeelder': ('trommeeld',),
'trommefisk': ('trommefisk',),
'trommefisken': ('trommefisk',),
'trommefiskene': ('trommefisk',),
'trommefisker': ('trommefisk',),
'trommehinna': ('trommehinne',),
'trommehinne': ('trommehinne',),
'trommehinnen': ('trommehinne',),
'trommehinnene': ('trommehinne',),
'trommehinner': ('trommehinne',),
'trommehola': ('trommehole',),
'trommehole': ('trommehole',),
'trommeholen': ('trommehole',),
'trommeholene': ('trommehole',),
'trommeholer': ('trommehole',),
'trommehula': ('trommehule',),
'trommehule': ('trommehule',),
'trommehulen': ('trommehule',),
'trommehulene': ('trommehule',),
'trommehuler': ('trommehule',),
'trommeild': ('trommeild',),
'trommeilden': ('trommeild',),
'trommeildene': ('trommeild',),
'trommeilder': ('trommeild',),
'trommeild': ('trommeild',),
'trommeilden': ('trommeild',),
'trommeildene': ('trommeild',),
'trommeilder': ('trommeild',),
'trommekjel': ('trommekjel',),
'trommekjelen': ('trommekjel',),
'trommekjelene': ('trommekjel',),
'trommekjeler': ('trommekjel',),
'trommekjele': ('trommekjele',),
'trommekjelen': ('trommekjele',),
'trommekjelene': ('trommekjele',),
'trommekjeler': ('trommekjele',),
'trommekorps': ('trommekorps',),
'trommekorpsa': ('trommekorps',),
'trommekorpsene': ('trommekorps',),
'trommekorpset': ('trommekorps',),
'tromlene': ('trommel',),
'tromler': ('trommel',),
'trommel': ('trommel',),
'trommelen': ('trommel',),
'trommelbrems': ('trommelbrems',),
'trommelbremsen': ('trommelbrems',),
'trommelbremsene': ('trommelbrems',),
'trommelbremser': ('trommelbrems',),
'trommelbremsa': ('trommelbremse',),
'trommelbremse': ('trommelbremse',),
'trommelbremsen': ('trommelbremse',),
'trommelbremsene': ('trommelbremse',),
'trommelbremser': ('trommelbremse',),
'trommesjuka': ('trommesjuke',),
'trommesjuke': ('trommesjuke',),
'trommesjuken': ('trommesjuke',),
'trommesjukene': ('trommesjuke',),
'trommesjuker': ('trommesjuke',),
'trommeskinn': ('trommeskinn',),
'trommeskinna': ('trommeskinn',),
'trommeskinnene': ('trommeskinn',),
'trommeskinnet': ('trommeskinn',),
'trommeslag': ('trommeslag',),
'trommeslaga': ('trommeslag',),
'trommeslagene': ('trommeslag',),
'trommeslaget': ('trommeslag',),
'trommeslager': ('trommeslager',),
'trommeslagere': ('trommeslager',),
'trommeslageren': ('trommeslager',),
'trommeslagerer': ('trommeslager',),
'trommeslagerne': ('trommeslager',),
'trommestikka': ('trommestikke',),
'trommestikke': ('trommestikke',),
'trommestikken': ('trommestikke',),
'trommestikkene': ('trommestikke',),
'trommestikker': ('trommestikke',),
'trommesyka': ('trommesyke',),
'trommesyke': ('trommesyke',),
'trommesyken': ('trommesyke',),
'trommesykene': ('trommesyke',),
'trommesyker': ('trommesyke',),
'trommevirvel': ('trommevirvel',),
'trommevirvelen': ('trommevirvel',),
'trommevirvlene': ('trommevirvel',),
'trommevirvler': ('trommevirvel',),
'trompet': ('trompet',),
'trompeten': ('trompet',),
'trompetene': ('trompet',),
'trompeter': ('trompet',),
'trompetblomst': ('trompetblomst',),
'trompetblomsten': ('trompetblomst',),
'trompetblomstene': ('trompetblomst',),
'trompetblomster': ('trompetblomst',),
'trompetdyr': ('trompetdyr',),
'trompetdyra': ('trompetdyr',),
'trompetdyrene': ('trompetdyr',),
'trompetdyret': ('trompetdyr',),
'trompeter': ('trompeter',),
'trompetere': ('trompeter',),
'trompeteren': ('trompeter',),
'trompeterer': ('trompeter',),
'trompeterne': ('trompeter',),
'trompetfanfare': ('trompetfanfare',),
'trompetfanfaren': ('trompetfanfare',),
'trompetfanfarene': ('trompetfanfare',),
'trompetfanfarer': ('trompetfanfare',),
'trompetfisk': ('trompetfisk',),
'trompetfisken': ('trompetfisk',),
'trompetfiskene': ('trompetfisk',),
'trompetfisker': ('trompetfisk',),
'trompetfugl': ('trompetfugl',),
'trompetfuglen': ('trompetfugl',),
'trompetfuglene': ('trompetfugl',),
'trompetfugler': ('trompetfugl',),
'trompetist': ('trompetist',),
'trompetisten': ('trompetist',),
'trompetistene': ('trompetist',),
'trompetister': ('trompetist',),
'trompetlilja': ('trompetlilje',),
'trompetlilje': ('trompetlilje',),
'trompetliljen': ('trompetlilje',),
'trompetliljene': ('trompetlilje',),
'trompetliljer': ('trompetlilje',),
'trompetsnegl': ('trompetsnegl',),
'trompetsneglen': ('trompetsnegl',),
'trompetsneglene': ('trompetsnegl',),
'trompetsnegler': ('trompetsnegl',),
'trompetsnile': ('trompetsnile',),
'trompetsnilen': ('trompetsnile',),
'trompetsnilene': ('trompetsnile',),
'trompetsniler': ('trompetsnile',),
'trompetsopp': ('trompetsopp',),
'trompetsoppen': ('trompetsopp',),
'trompetsoppene': ('trompetsopp',),
'trompetsopper': ('trompetsopp',),
'trompetstikk': ('trompetstikk',),
'trompetstikka': ('trompetstikk',),
'trompetstikkene': ('trompetstikk',),
'trompetstikket': ('trompetstikk',),
'trompetstøt': ('trompetstøt',),
'trompetstøta': ('trompetstøt',),
'trompetstøtene': ('trompetstøt',),
'trompetstøtet': ('trompetstøt',),
'tromsværing': ('tromsværing',),
'tromsværingen': ('tromsværing',),
'tromsværingene': ('tromsværing',),
'tromsværinger': ('tromsværing',),
'tromsøbjørnekjeks': ('tromsøbjørnekjeks',),
'tromsøbjørnekjeksen': ('tromsøbjørnekjeks',),
'tromsøbjørnekjeksene': ('tromsøbjørnekjeks',),
'tromsøbjørnekjekser': ('tromsøbjørnekjeks',),
'tromsøpalme': ('tromsøpalme',),
'tromsøpalmen': ('tromsøpalme',),
'tromsøpalmene': ('tromsøpalme',),
'tromsøpalmer': ('tromsøpalme',),
'tronarving': ('tronarving',),
'tronarvingen': ('tronarving',),
'tronarvingene': ('tronarving',),
'tronarvinger': ('tronarving',),
'trondheimer': ('trondheimer',),
'trondheimere': ('trondheimer',),
'trondheimeren': ('trondheimer',),
'trondheimerer': ('trondheimer',),
'trondheimerne': ('trondheimer',),
'trondheimitt': ('trondheimitt',),
'trondheimitten': ('trondheimitt',),
'trondheimittene': ('trondheimitt',),
'trondheimitter': ('trondheimitt',),
'trondhjemssuppa': ('trondhjemssuppe',),
'trondhjemssuppe': ('trondhjemssuppe',),
'trondhjemssuppen': ('trondhjemssuppe',),
'trondhjemssuppene': ('trondhjemssuppe',),
'trondhjemssupper': ('trondhjemssuppe',),
'trona': ('trone',),
'trone': ('trone',),
'tronen': ('trone',),
'tronene': ('trone',),
'troner': ('trone',),
'tronfølga': ('tronfølge',),
'tronfølge': ('tronfølge',),
'tronfølgen': ('tronfølge',),
'tronfølgene': ('tronfølge',),
'tronfølger': ('tronfølge',),
'tronfølger': ('tronfølger',),
'tronfølgere': ('tronfølger',),
'tronfølgeren': ('tronfølger',),
'tronfølgerer': ('tronfølger',),
'tronfølgerne': ('tronfølger',),
'tronhimlene': ('tronhimmel',),
'tronhimler': ('tronhimmel',),
'tronhimmel': ('tronhimmel',),
'tronhimmelen': ('tronhimmel',),
'tronsal': ('tronsal',),
'tronsalen': ('tronsal',),
'tronsalene': ('tronsal',),
'tronsaler': ('tronsal',),
'trontale': ('trontale',),
'trontalen': ('trontale',),
'trontalene': ('trontale',),
'trontaler': ('trontale',),
'trontaledebatt': ('trontaledebatt',),
'trontaledebatten': ('trontaledebatt',),
'trontaledebattene': ('trontaledebatt',),
'trontaledebatter': ('trontaledebatt',),
'trope': ('trope',),
'tropen': ('trope',),
'tropene': ('trope',),
'troper': ('trope',),
'trope': ('trope',),
'tropen': ('trope',),
'tropene': ('trope',),
'troper': ('trope',),
'tropefeber': ('tropefeber',),
'tropefebere': ('tropefeber',),
'tropefeberen': ('tropefeber',),
'tropefeberer': ('tropefeber',),
'tropefeberne': ('tropefeber',),
'tropefebre': ('tropefeber',),
'tropefebrene': ('tropefeber',),
'tropefebrer': ('tropefeber',),
'tropehjelm': ('tropehjelm',),
'tropehjelmen': ('tropehjelm',),
'tropehjelmene': ('tropehjelm',),
'tropehjelmer': ('tropehjelm',),
'tropeluft': ('tropeluft',),
'tropelufta': ('tropeluft',),
'tropeluften': ('tropeluft',),
'tropeluftene': ('tropeluft',),
'tropelufter': ('tropeluft',),
'tropenatt': ('tropenatt',),
'tropenatta': ('tropenatt',),
'tropenatten': ('tropenatt',),
'tropenettene': ('tropenatt',),
'tropenetter': ('tropenatt',),
'tropenattstemperatur': ('tropenattstemperatur',),
'tropenattstemperaturen': ('tropenattstemperatur',),
'tropenattstemperaturene': ('tropenattstemperatur',),
'tropenattstemperaturer': ('tropenattstemperatur',),
'tropesjukdom': ('tropesjukdom',),
'tropesjukdommen': ('tropesjukdom',),
'tropesjukdommene': ('tropesjukdom',),
'tropesjukdommer': ('tropesjukdom',),
'tropesykdom': ('tropesykdom',),
'tropesykdommen': ('tropesykdom',),
'tropesykdommene': ('tropesykdom',),
'tropesykdommer': ('tropesykdom',),
'tropevarme': ('tropevarme',),
'tropevarmen': ('tropevarme',),
'tropevarmene': ('tropevarme',),
'tropevarmer': ('tropevarme',),
'tropikfront': ('tropikfront',),
'tropikfronten': ('tropikfront',),
'tropikfrontene': ('tropikfront',),
'tropikfronter': ('tropikfront',),
'tropikfugl': ('tropikfugl',),
'tropikfuglen': ('tropikfugl',),
'tropikfuglene': ('tropikfugl',),
'tropikfugler': ('tropikfugl',),
'tropisme': ('tropisme',),
'tropismen': ('tropisme',),
'tropismene': ('tropisme',),
'tropismer': ('tropisme',),
'troposfære': ('troposfære',),
'troposfæren': ('troposfære',),
'troposfærene': ('troposfære',),
'troposfærer': ('troposfære',),
'tropp': ('tropp',),
'troppen': ('tropp',),
'troppene': ('tropp',),
'tropper': ('tropp',),
'troppebevegelse': ('troppebevegelse',),
'troppebevegelsen': ('troppebevegelse',),
'troppebevegelsene': ('troppebevegelse',),
'troppebevegelser': ('troppebevegelse',),
'troppekonsentrasjon': ('troppekonsentrasjon',),
'troppekonsentrasjonen': ('troppekonsentrasjon',),
'troppekonsentrasjonene': ('troppekonsentrasjon',),
'troppekonsentrasjoner': ('troppekonsentrasjon',),
'troppestyrke': ('troppestyrke',),
'troppestyrken': ('troppestyrke',),
'troppestyrkene': ('troppestyrke',),
'troppestyrker': ('troppestyrke',),
'troppetransport': ('troppetransport',),
'troppetransporten': ('troppetransport',),
'troppetransportene': ('troppetransport',),
'troppetransporter': ('troppetransport',),
'troppsbefal': ('troppsbefal',),
'troppsbefala': ('troppsbefal',),
'troppsbefalene': ('troppsbefal',),
'troppsbefalet': ('troppsbefal',),
'troppsfører': ('troppsfører',),
'troppsførere': ('troppsfører',),
'troppsføreren': ('troppsfører',),
'troppsførerer': ('troppsfører',),
'troppsførerne': ('troppsfører',),
'troppsmøta': ('troppsmøte',),
'troppsmøte': ('troppsmøte',),
'troppsmøtene': ('troppsmøte',),
'troppsmøter': ('troppsmøte',),
'troppsmøtet': ('troppsmøte',),
'troppssjef': ('troppssjef',),
'troppssjefen': ('troppssjef',),
'troppssjefene': ('troppssjef',),
'troppssjefer': ('troppssjef',),
'trosartikkel': ('trosartikkel',),
'trosartikkelen': ('trosartikkel',),
'trosartiklene': ('trosartikkel',),
'trosartikler': ('trosartikkel',),
'trosbekjennelse': ('trosbekjennelse',),
'trosbekjennelsen': ('trosbekjennelse',),
'trosbekjennelsene': ('trosbekjennelse',),
'trosbekjennelser': ('trosbekjennelse',),
'trosbror': ('trosbror',),
'trosbroren': ('trosbror',),
'trosbrødre': ('trosbror',),
'trosbrødrene': ('trosbror',),
'trosfelle': ('trosfelle',),
'trosfellen': ('trosfelle',),
'trosfellene': ('trosfelle',),
'trosfeller': ('trosfelle',),
'trosfrihet': ('trosfrihet',),
'trosfriheta': ('trosfrihet',),
'trosfriheten': ('trosfrihet',),
'trosfrihetene': ('trosfrihet',),
'trosfriheter': ('trosfrihet',),
'troskap': ('troskap',),
'troskapen': ('troskap',),
'troskapene': ('troskap',),
'troskaper': ('troskap',),
'troskapsbrott': ('troskapsbrott',),
'troskapsbrotta': ('troskapsbrott',),
'troskapsbrottene': ('troskapsbrott',),
'troskapsbrottet': ('troskapsbrott',),
'troskapsbrudd': ('troskapsbrudd',),
'troskapsbrudda': ('troskapsbrudd',),
'troskapsbruddene': ('troskapsbrudd',),
'troskapsbruddet': ('troskapsbrudd',),
'troskapsed': ('troskapsed',),
'troskapseden': ('troskapsed',),
'troskapsedene': ('troskapsed',),
'troskapseder': ('troskapsed',),
'troskapsløfta': ('troskapsløfte',),
'troskapsløfte': ('troskapsløfte',),
'troskapsløftene': ('troskapsløfte',),
'troskapsløfter': ('troskapsløfte',),
'troskapsløftet': ('troskapsløfte',),
'troskyldighet': ('troskyldighet',),
'troskyldigheta': ('troskyldighet',),
'troskyldigheten': ('troskyldighet',),
'troskyldighetene': ('troskyldighet',),
'troskyldigheter': ('troskyldighet',),
'trosretning': ('trosretning',),
'trosretninga': ('trosretning',),
'trosretningen': ('trosretning',),
'trosretningene': ('trosretning',),
'trosretninger': ('trosretning',),
'tross': ('tross',),
'trossen': ('tross',),
'trossene': ('tross',),
'trosser': ('tross',),
'tross': ('tross',),
'trossa': ('tross',),
'trossene': ('tross',),
'trosset': ('tross',),
'trossak': ('trossak',),
'trossaka': ('trossak',),
'trossaken': ('trossak',),
'trossakene': ('trossak',),
'trossaker': ('trossak',),
'trossamfunn': ('trossamfunn',),
'trossamfunna': ('trossamfunn',),
'trossamfunnene': ('trossamfunn',),
'trossamfunnet': ('trossamfunn',),
'trossa': ('trosse',),
'trosse': ('trosse',),
'trossen': ('trosse',),
'trossene': ('trosse',),
'trosser': ('trosse',),
'trossetning': ('trossetning',),
'trossetninga': ('trossetning',),
'trossetningen': ('trossetning',),
'trossetningene': ('trossetning',),
'trossetninger': ('trossetning',),
'trost': ('trost',),
'trosten': ('trost',),
'trostene': ('trost',),
'troster': ('trost',),
'trost': ('trost',),
'trosten': ('trost',),
'trostene': ('trost',),
'troster': ('trost',),
'trosteegg': ('trosteegg',),
'trosteegga': ('trosteegg',),
'trosteeggene': ('trosteegg',),
'trosteegget': ('trosteegg',),
'trosteegg': ('trosteegg',),
'trosteegga': ('trosteegg',),
'trosteeggene': ('trosteegg',),
'trosteegget': ('trosteegg',),
'trostefugl': ('trostefugl',),
'trostefuglen': ('trostefugl',),
'trostefuglene': ('trostefugl',),
'trostefugler': ('trostefugl',),
'trostefugl': ('trostefugl',),
'trostefuglen': ('trostefugl',),
'trostefuglene': ('trostefugl',),
'trostefugler': ('trostefugl',),
'trostegg': ('trostegg',),
'trostegga': ('trostegg',),
'trosteggene': ('trostegg',),
'trostegget': ('trostegg',),
'trostegg': ('trostegg',),
'trostegga': ('trostegg',),
'trosteggene': ('trostegg',),
'trostegget': ('trostegg',),
'trostereda': ('trosterede',),
'trosterede': ('trosterede',),
'trosteredene': ('trosterede',),
'trostereder': ('trosterede',),
'trosteredet': ('trosterede',),
'trostereda': ('trosterede',),
'trosterede': ('trosterede',),
'trosteredene': ('trosterede',),
'trostereder': ('trosterede',),
'trosteredet': ('trosterede',),
'trostereir': ('trostereir',),
'trostereira': ('trostereir',),
'trostereirene': ('trostereir',),
'trostereiret': ('trostereir',),
'trostereir': ('trostereir',),
'trostereira': ('trostereir',),
'trostereirene': ('trostereir',),
'trostereiret': ('trostereir',),
'trosteunge': ('trosteunge',),
'trosteungen': ('trosteunge',),
'trosteungene': ('trosteunge',),
'trosteunger': ('trosteunge',),
'trosteunge': ('trosteunge',),
'trosteungen': ('trosteunge',),
'trosteungene': ('trosteunge',),
'trosteunger': ('trosteunge',),
'trostunge': ('trostunge',),
'trostungen': ('trostunge',),
'trostungene': ('trostunge',),
'trostunger': ('trostunge',),
'trostunge': ('trostunge',),
'trostungen': ('trostunge',),
'trostungene': ('trostunge',),
'trostunger': ('trostunge',),
'trosvitna': ('trosvitne',),
'trosvitne': ('trosvitne',),
'trosvitnene': ('trosvitne',),
'trosvitner': ('trosvitne',),
'trosvitnet': ('trosvitne',),
'trotskisme': ('trotskisme',),
'trotskismen': ('trotskisme',),
'trotskismene': ('trotskisme',),
'trotskismer': ('trotskisme',),
'trotskist': ('trotskist',),
'trotskisten': ('trotskist',),
'trotskistene': ('trotskist',),
'trotskister': ('trotskist',),
'tru': ('tru',),
'trua': ('tru',),
'truen': ('tru',),
'truene': ('tru',),
'truer': ('tru',),
'trubadur': ('trubadur',),
'trubaduren': ('trubadur',),
'trubadurene': ('trubadur',),
'trubadurer': ('trubadur',),
'trubadurdikting': ('trubadurdikting',),
'trubadurdiktinga': ('trubadurdikting',),
'trubadurdiktingen': ('trubadurdikting',),
'trubadurdiktingene': ('trubadurdikting',),
'trubadurdiktinger': ('trubadurdikting',),
'trubadurdiktning': ('trubadurdiktning',),
'trubadurdiktninga': ('trubadurdiktning',),
'trubadurdiktningen': ('trubadurdiktning',),
'trubadurdiktningene': ('trubadurdiktning',),
'trubadurdiktninger': ('trubadurdiktning',),
'truck': ('truck',),
'trucken': ('truck',),
'truckene': ('truck',),
'trucker': ('truck',),
'trucksystem': ('trucksystem',),
'trucksystema': ('trucksystem',),
'trucksystemene': ('trucksystem',),
'trucksystemer': ('trucksystem',),
'trucksystemet': ('trucksystem',),
'trudelutt': ('trudelutt',),
'trudelutten': ('trudelutt',),
'trudeluttene': ('trudelutt',),
'trudelutter': ('trudelutt',),
'truga': ('truge',),
'truge': ('truge',),
'trugen': ('truge',),
'trugene': ('truge',),
'truger': ('truge',),
'trugsmål': ('trugsmål',),
'trugsmåla': ('trugsmål',),
'trugsmålene': ('trugsmål',),
'trugsmålet': ('trugsmål',),
'truisme': ('truisme',),
'truismen': ('truisme',),
'truismene': ('truisme',),
'truismer': ('truisme',),
'trulovelse': ('trulovelse',),
'trulovelsen': ('trulovelse',),
'trulovelsene': ('trulovelse',),
'trulovelser': ('trulovelse',),
'truloving': ('truloving',),
'trulovinga': ('truloving',),
'trulovingen': ('truloving',),
'trulovingene': ('truloving',),
'trulovinger': ('truloving',),
'trulta': ('trulte',),
'trulte': ('trulte',),
'trulten': ('trulte',),
'trultene': ('trulte',),
'trulter': ('trulte',),
'trumf': ('trumf',),
'trumfen': ('trumf',),
'trumfene': ('trumf',),
'trumfer': ('trumf',),
'trumfess': ('trumfess',),
'trumfessa': ('trumfess',),
'trumfessene': ('trumfess',),
'trumfesset': ('trumfess',),
'trumfkort': ('trumfkort',),
'trumfkorta': ('trumfkort',),
'trumfkortene': ('trumfkort',),
'trumfkortet': ('trumfkort',),
'trunk': ('trunk',),
'trunken': ('trunk',),
'trunkene': ('trunk',),
'trunker': ('trunk',),
'trupp': ('trupp',),
'truppen': ('trupp',),
'truppene': ('trupp',),
'trupper': ('trupp',),
'trusartikkel': ('trusartikkel',),
'trusartikkelen': ('trusartikkel',),
'trusartiklene': ('trusartikkel',),
'trusartikler': ('trusartikkel',),
'trusbekjennelse': ('trusbekjennelse',),
'trusbekjennelsen': ('trusbekjennelse',),
'trusbekjennelsene': ('trusbekjennelse',),
'trusbekjennelser': ('trusbekjennelse',),
'trusbror': ('trusbror',),
'trusbroren': ('trusbror',),
'trusbrødre': ('trusbror',),
'trusbrødrene': ('trusbror',),
'trusa': ('truse',),
'truse': ('truse',),
'trusen': ('truse',),
'trusene': ('truse',),
'truser': ('truse',),
'trusfelle': ('trusfelle',),
'trusfellen': ('trusfelle',),
'trusfellene': ('trusfelle',),
'trusfeller': ('trusfelle',),
'trusfrihet': ('trusfrihet',),
'trusfriheta': ('trusfrihet',),
'trusfriheten': ('trusfrihet',),
'trusfrihetene': ('trusfrihet',),
'trusfriheter': ('trusfrihet',),
'truskap': ('truskap',),
'truskapen': ('truskap',),
'truskapene': ('truskap',),
'truskaper': ('truskap',),
'truskapsbrott': ('truskapsbrott',),
'truskapsbrotta': ('truskapsbrott',),
'truskapsbrottene': ('truskapsbrott',),
'truskapsbrottet': ('truskapsbrott',),
'truskapsbrudd': ('truskapsbrudd',),
'truskapsbrudda': ('truskapsbrudd',),
'truskapsbruddene': ('truskapsbrudd',),
'truskapsbruddet': ('truskapsbrudd',),
'truskapsed': ('truskapsed',),
'truskapseden': ('truskapsed',),
'truskapsedene': ('truskapsed',),
'truskapseder': ('truskapsed',),
'truskapsløfta': ('truskapsløfte',),
'truskapsløfte': ('truskapsløfte',),
'truskapsløftene': ('truskapsløfte',),
'truskapsløfter': ('truskapsløfte',),
'truskapsløftet': ('truskapsløfte',),
'truskyldighet': ('truskyldighet',),
'truskyldigheta': ('truskyldighet',),
'truskyldigheten': ('truskyldighet',),
'truskyldighetene': ('truskyldighet',),
'truskyldigheter': ('truskyldighet',),
'trusretning': ('trusretning',),
'trusretninga': ('trusretning',),
'trusretningen': ('trusretning',),
'trusretningene': ('trusretning',),
'trusretninger': ('trusretning',),
'trussak': ('trussak',),
'trussaka': ('trussak',),
'trussaken': ('trussak',),
'trussakene': ('trussak',),
'trussaker': ('trussak',),
'trussamfunn': ('trussamfunn',),
'trussamfunna': ('trussamfunn',),
'trussamfunnene': ('trussamfunn',),
'trussamfunnet': ('trussamfunn',),
'truslene': ('trussel',),
'trusler': ('trussel',),
'trussel': ('trussel',),
'trusselen': ('trussel',),
'trussetning': ('trussetning',),
'trussetninga': ('trussetning',),
'trussetningen': ('trussetning',),
'trussetningene': ('trussetning',),
'trussetninger': ('trussetning',),
'trust': ('trust',),
'trusten': ('trust',),
'trustene': ('trust',),
'truster': ('trust',),
'trusvitna': ('trusvitne',),
'trusvitne': ('trusvitne',),
'trusvitnene': ('trusvitne',),
'trusvitner': ('trusvitne',),
'trusvitnet': ('trusvitne',),
'trut': ('trut',),
'truten': ('trut',),
'trutene': ('trut',),
'truter': ('trut',),
'trutmunn': ('trutmunn',),
'trutmunnen': ('trutmunn',),
'trutmunnene': ('trutmunn',),
'trutmunner': ('trutmunn',),
'trygd': ('trygd',),
'trygda': ('trygd',),
'trygden': ('trygd',),
'trygdene': ('trygd',),
'trygder': ('trygd',),
'trygdebolig': ('trygdebolig',),
'trygdeboligen': ('trygdebolig',),
'trygdeboligene': ('trygdebolig',),
'trygdeboliger': ('trygdebolig',),
'trygdekassa': ('trygdekasse',),
'trygdekasse': ('trygdekasse',),
'trygdekassen': ('trygdekasse',),
'trygdekassene': ('trygdekasse',),
'trygdekasser': ('trygdekasse',),
'trygdekontor': ('trygdekontor',),
'trygdekontora': ('trygdekontor',),
'trygdekontorene': ('trygdekontor',),
'trygdekontorer': ('trygdekontor',),
'trygdekontoret': ('trygdekontor',),
'trygdemisbruk': ('trygdemisbruk',),
'trygdemisbruka': ('trygdemisbruk',),
'trygdemisbruken': ('trygdemisbruk',),
'trygdemisbrukene': ('trygdemisbruk',),
'trygdemisbruker': ('trygdemisbruk',),
'trygdemisbruket': ('trygdemisbruk',),
'trygdepremie': ('trygdepremie',),
'trygdepremien': ('trygdepremie',),
'trygdepremiene': ('trygdepremie',),
'trygdepremier': ('trygdepremie',),
'trygderett': ('trygderett',),
'trygderetten': ('trygderett',),
'trygderettene': ('trygderett',),
'trygderetter': ('trygderett',),
'trygghet': ('trygghet',),
'tryggheta': ('trygghet',),
'tryggheten': ('trygghet',),
'trygghetene': ('trygghet',),
'tryggheter': ('trygghet',),
'trykk': ('trykk',),
'trykken': ('trykk',),
'trykkene': ('trykk',),
'trykker': ('trykk',),
'trykk': ('trykk',),
'trykken': ('trykk',),
'trykkene': ('trykk',),
'trykker': ('trykk',),
'trykk': ('trykk',),
'trykka': ('trykk',),
'trykkene': ('trykk',),
'trykket': ('trykk',),
'trykk': ('trykk',),
'trykka': ('trykk',),
'trykken': ('trykk',),
'trykkene': ('trykk',),
'trykker': ('trykk',),
'trykket': ('trykk',),
'trykk-kabin': ('trykk-kabin',),
'trykk-kabinen': ('trykk-kabin',),
'trykk-kabinene': ('trykk-kabin',),
'trykk-kabiner': ('trykk-kabin',),
'trykk-knapp': ('trykk-knapp',),
'trykk-knappen': ('trykk-knapp',),
'trykk-knappene': ('trykk-knapp',),
'trykk-knapper': ('trykk-knapp',),
'trykk-koker': ('trykk-koker',),
'trykk-kokere': ('trykk-koker',),
'trykk-kokeren': ('trykk-koker',),
'trykk-kokerer': ('trykk-koker',),
'trykk-kokerne': ('trykk-koker',),
'trykkabin': ('trykkabin',),
'trykkabinen': ('trykkabin',),
'trykkabinene': ('trykkabin',),
'trykkabiner': ('trykkabin',),
'trykkaksent': ('trykkaksent',),
'trykkaksenten': ('trykkaksent',),
'trykkaksentene': ('trykkaksent',),
'trykkaksenter': ('trykkaksent',),
'trykkbokstav': ('trykkbokstav',),
'trykkbokstaven': ('trykkbokstav',),
'trykkbokstavene': ('trykkbokstav',),
'trykkbokstaver': ('trykkbokstav',),
'trykkefrihet': ('trykkefrihet',),
'trykkefriheta': ('trykkefrihet',),
'trykkefriheten': ('trykkefrihet',),
'trykkefrihetene': ('trykkefrihet',),
'trykkefriheter': ('trykkefrihet',),
'trykker': ('trykker',),
'trykkere': ('trykker',),
'trykkeren': ('trykker',),
'trykkerer': ('trykker',),
'trykkerne': ('trykker',),
'trykkeri': ('trykkeri',),
'trykkeria': ('trykkeri',),
'trykkeriene': ('trykkeri',),
'trykkerier': ('trykkeri',),
'trykkeriet': ('trykkeri',),
'trykkested': ('trykkested',),
'trykkestedene': ('trykkested',),
'trykkesteder': ('trykkested',),
'trykkestedet': ('trykkested',),
'trykkeår': ('trykkeår',),
'trykkeåra': ('trykkeår',),
'trykkeårene': ('trykkeår',),
'trykkeåret': ('trykkeår',),
'trykkfall': ('trykkfall',),
'trykkfalla': ('trykkfall',),
'trykkfallene': ('trykkfall',),
'trykkfallet': ('trykkfall',),
'trykkfallssjuka': ('trykkfallssjuke',),
'trykkfallssjuke': ('trykkfallssjuke',),
'trykkfallssjuken': ('trykkfallssjuke',),
'trykkfallssjukene': ('trykkfallssjuke',),
'trykkfallssjuker': ('trykkfallssjuke',),
'trykkfallssyka': ('trykkfallssyke',),
'trykkfallssyke': ('trykkfallssyke',),
'trykkfallssyken': ('trykkfallssyke',),
'trykkfallssykene': ('trykkfallssyke',),
'trykkfallssyker': ('trykkfallssyke',),
'trykkfarge': ('trykkfarge',),
'trykkfargen': ('trykkfarge',),
'trykkfargene': ('trykkfarge',),
'trykkfarger': ('trykkfarge',),
'trykkfasthet': ('trykkfasthet',),
'trykkfastheta': ('trykkfasthet',),
'trykkfastheten': ('trykkfasthet',),
'trykkfasthetene': ('trykkfasthet',),
'trykkfastheter': ('trykkfasthet',),
'trykkfeil': ('trykkfeil',),
'trykkfeilen': ('trykkfeil',),
'trykkfeilene': ('trykkfeil',),
'trykkfeilsdjevel': ('trykkfeilsdjevel',),
'trykkfeilsdjevelen': ('trykkfeilsdjevel',),
'trykkfeilsdjevlene': ('trykkfeilsdjevel',),
'trykkfeilsdjevler': ('trykkfeilsdjevel',),
'trykkforsterker': ('trykkforsterker',),
'trykkforsterkere': ('trykkforsterker',),
'trykkforsterkeren': ('trykkforsterker',),
'trykkforsterkerer': ('trykkforsterker',),
'trykkforsterkerne': ('trykkforsterker',),
'trykking': ('trykking',),
'trykkinga': ('trykking',),
'trykkingen': ('trykking',),
'trykkingene': ('trykking',),
'trykkinger': ('trykking',),
'trykkingsår': ('trykkingsår',),
'trykkingsåra': ('trykkingsår',),
'trykkingsårene': ('trykkingsår',),
'trykkingsåret': ('trykkingsår',),
'trykkluft': ('trykkluft',),
'trykklufta': ('trykkluft',),
'trykkluften': ('trykkluft',),
'trykkluftene': ('trykkluft',),
'trykklufter': ('trykkluft',),
'trykkluftbrems': ('trykkluftbrems',),
'trykkluftbremsen': ('trykkluftbrems',),
'trykkluftbremsene': ('trykkluftbrems',),
'trykkluftbremser': ('trykkluftbrems',),
'trykkluftsbremsa': ('trykkluftsbremse',),
'trykkluftsbremse': ('trykkluftsbremse',),
'trykkluftsbremsen': ('trykkluftsbremse',),
'trykkluftsbremsene': ('trykkluftsbremse',),
'trykkluftsbremser': ('trykkluftsbremse',),
'trykkluftsverktøy': ('trykkluftsverktøy',),
'trykkluftsverktøya': ('trykkluftsverktøy',),
'trykkluftsverktøyene': ('trykkluftsverktøy',),
'trykkluftsverktøyer': ('trykkluftsverktøy',),
'trykkluftsverktøyet': ('trykkluftsverktøy',),
'trykkluftverktøy': ('trykkluftverktøy',),
'trykkluftverktøya': ('trykkluftverktøy',),
'trykkluftverktøyene': ('trykkluftverktøy',),
'trykkluftverktøyer': ('trykkluftverktøy',),
'trykkluftverktøyet': ('trykkluftverktøy',),
'trykkmåler': ('trykkmåler',),
'trykkmålere': ('trykkmåler',),
'trykkmåleren': ('trykkmåler',),
'trykkmålerer': ('trykkmåler',),
'trykkmålerne': ('trykkmåler',),
'trykknapp': ('trykknapp',),
'trykknappen': ('trykknapp',),
'trykknappene': ('trykknapp',),
'trykknapper': ('trykknapp',),
'trykkoker': ('trykkoker',),
'trykkokere': ('trykkoker',),
'trykkokeren': ('trykkoker',),
'trykkokerer': ('trykkoker',),
'trykkokerne': ('trykkoker',),
'trykkpakning': ('trykkpakning',),
'trykkpakninga': ('trykkpakning',),
'trykkpakningen': ('trykkpakning',),
'trykkpakningene': ('trykkpakning',),
'trykkpakninger': ('trykkpakning',),
'trykksak': ('trykksak',),
'trykksaka': ('trykksak',),
'trykksaken': ('trykksak',),
'trykksakene': ('trykksak',),
'trykksaker': ('trykksak',),
'trykksakkonvolutt': ('trykksakkonvolutt',),
'trykksakkonvolutten': ('trykksakkonvolutt',),
'trykksakkonvoluttene': ('trykksakkonvolutt',),
'trykksakkonvolutter': ('trykksakkonvolutt',),
'trykksakreklame': ('trykksakreklame',),
'trykksakreklamen': ('trykksakreklame',),
'trykksakreklamene': ('trykksakreklame',),
'trykksakreklamer': ('trykksakreklame',),
'trykkstavelse': ('trykkstavelse',),
'trykkstavelsen': ('trykkstavelse',),
'trykkstavelsene': ('trykkstavelse',),
'trykkstavelser': ('trykkstavelse',),
'trykkstaving': ('trykkstaving',),
'trykkstavinga': ('trykkstaving',),
'trykkstavingen': ('trykkstaving',),
'trykkstavingene': ('trykkstaving',),
'trykkstavinger': ('trykkstaving',),
'trykksverta': ('trykksverte',),
'trykksverte': ('trykksverte',),
'trykksverten': ('trykksverte',),
'trykksvertene': ('trykksverte',),
'trykksverter': ('trykksverte',),
'trykktank': ('trykktank',),
'trykktanken': ('trykktank',),
'trykktankene': ('trykktank',),
'trykktanker': ('trykktank',),
'trykktap': ('trykktap',),
'trykktapa': ('trykktap',),
'trykktapene': ('trykktap',),
'trykktapet': ('trykktap',),
'trykkvann': ('trykkvann',),
'trykkvanna': ('trykkvann',),
'trykkvannene': ('trykkvann',),
'trykkvannet': ('trykkvann',),
'trykkvannsreaktor': ('trykkvannsreaktor',),
'trykkvannsreaktoren': ('trykkvannsreaktor',),
'trykkvannsreaktorene': ('trykkvannsreaktor',),
'trykkvannsreaktorer': ('trykkvannsreaktor',),
'trykkvassreaktor': ('trykkvassreaktor',),
'trykkvassreaktoren': ('trykkvassreaktor',),
'trykkvassreaktorene': ('trykkvassreaktor',),
'trykkvassreaktorer': ('trykkvassreaktor',),
'trykkvatn': ('trykkvatn',),
'trykkvatna': ('trykkvatn',),
'trykkvatnene': ('trykkvatn',),
'trykkvatnet': ('trykkvatn',),
'trykning': ('trykning',),
'trykninga': ('trykning',),
'trykningen': ('trykning',),
'trykningene': ('trykning',),
'trykninger': ('trykning',),
'trykningsår': ('trykningsår',),
'trykningsåra': ('trykningsår',),
'trykningsårene': ('trykningsår',),
'trykningsåret': ('trykningsår',),
'trylledrikk': ('trylledrikk',),
'trylledrikken': ('trylledrikk',),
'trylledrikkene': ('trylledrikk',),
'trylledrikker': ('trylledrikk',),
'trylleformular': ('trylleformular',),
'trylleformulara': ('trylleformular',),
'trylleformularen': ('trylleformular',),
'trylleformularene': ('trylleformular',),
'trylleformularer': ('trylleformular',),
'trylleformularet': ('trylleformular',),
'tryllekunst': ('tryllekunst',),
'tryllekunsten': ('tryllekunst',),
'tryllekunstene': ('tryllekunst',),
'tryllekunster': ('tryllekunst',),
'tryllekunstner': ('tryllekunstner',),
'tryllekunstnere': ('tryllekunstner',),
'tryllekunstneren': ('tryllekunstner',),
'tryllekunstnerer': ('tryllekunstner',),
'tryllekunstnerne': ('tryllekunstner',),
'tryllemiddel': ('tryllemiddel',),
'tryllemiddelet': ('tryllemiddel',),
'tryllemidla': ('tryllemiddel',),
'tryllemidlene': ('tryllemiddel',),
'tryllemidler': ('tryllemiddel',),
'tryllemidlet': ('tryllemiddel',),
'trylleri': ('trylleri',),
'trylleria': ('trylleri',),
'trylleriene': ('trylleri',),
'tryllerier': ('trylleri',),
'trylleriet': ('trylleri',),
'tryllering': ('tryllering',),
'trylleringen': ('tryllering',),
'trylleringene': ('tryllering',),
'trylleringer': ('tryllering',),
'trylleslag': ('trylleslag',),
'trylleslaga': ('trylleslag',),
'trylleslagene': ('trylleslag',),
'trylleslaget': ('trylleslag',),
'tryllestav': ('tryllestav',),
'tryllestaven': ('tryllestav',),
'tryllestavene': ('tryllestav',),
'tryllestaver': ('tryllestav',),
'tryna': ('tryne',),
'tryne': ('tryne',),
'trynene': ('tryne',),
'tryner': ('tryne',),
'trynet': ('tryne',),
'trynefaktor': ('trynefaktor',),
'trynefaktoren': ('trynefaktor',),
'trynefaktorene': ('trynefaktor',),
'trynefaktorer': ('trynefaktor',),
'trysling': ('trysling',),
'tryslingen': ('trysling',),
'tryslingene': ('trysling',),
'tryslinger': ('trysling',),
'tryta': ('tryte',),
'tryte': ('tryte',),
'tryten': ('tryte',),
'trytene': ('tryte',),
'tryter': ('tryte',),
'tryta': ('tryte',),
'tryte': ('tryte',),
'tryten': ('tryte',),
'trytene': ('tryte',),
'tryter': ('tryte',),
'trå': ('trå',),
'tråa': ('trå',),
'tråen': ('trå',),
'tråene': ('trå',),
'tråer': ('trå',),
'trå': ('trå',),
'tråa': ('trå',),
'tråen': ('trå',),
'tråene': ('trå',),
'tråer': ('trå',),
'tråbil': ('tråbil',),
'tråbilen': ('tråbil',),
'tråbilene': ('tråbil',),
'tråbiler': ('tråbil',),
'tråbrett': ('tråbrett',),
'tråbretta': ('tråbrett',),
'tråbrettene': ('tråbrett',),
'tråbretter': ('tråbrett',),
'tråbrettet': ('tråbrett',),
'tråd': ('tråd',),
'tråden': ('tråd',),
'trådene': ('tråd',),
'tråder': ('tråd',),
'trådgjerda': ('trådgjerde',),
'trådgjerde': ('trådgjerde',),
'trådgjerdene': ('trådgjerde',),
'trådgjerder': ('trådgjerde',),
'trådgjerdet': ('trådgjerde',),
'trådglas': ('trådglas',),
'trådglasa': ('trådglas',),
'trådglasene': ('trådglas',),
'trådglaset': ('trådglas',),
'trådglass': ('trådglass',),
'trådglassa': ('trådglass',),
'trådglassene': ('trådglass',),
'trådglasset': ('trådglass',),
'trådsnella': ('trådsnelle',),
'trådsnelle': ('trådsnelle',),
'trådsnellen': ('trådsnelle',),
'trådsnellene': ('trådsnelle',),
'trådsneller': ('trådsnelle',),
'trådtrekker': ('trådtrekker',),
'trådtrekkere': ('trådtrekker',),
'trådtrekkeren': ('trådtrekker',),
'trådtrekkerer': ('trådtrekker',),
'trådtrekkerne': ('trådtrekker',),
'tråkk': ('tråkk',),
'tråkka': ('tråkk',),
'tråkkene': ('tråkk',),
'tråkket': ('tråkk',),
'tråkk': ('tråkk',),
'tråkka': ('tråkk',),
'tråkken': ('tråkk',),
'tråkkene': ('tråkk',),
'tråkker': ('tråkk',),
'tråkkemaskin': ('tråkkemaskin',),
'tråkkemaskina': ('tråkkemaskin',),
'tråkkemaskinen': ('tråkkemaskin',),
'tråkkemaskinene': ('tråkkemaskin',),
'tråkkemaskiner': ('tråkkemaskin',),
'tråkker': ('tråkker',),
'tråkkere': ('tråkker',),
'tråkkeren': ('tråkker',),
'tråkkerer': ('tråkker',),
'tråkkerne': ('tråkker',),
'tråklesting': ('tråklesting',),
'tråklestinga': ('tråklesting',),
'tråklestingene': ('tråklesting',),
'tråklestinget': ('tråklesting',),
'tråkletråd': ('tråkletråd',),
'tråkletråden': ('tråkletråd',),
'tråkletrådene': ('tråkletråd',),
'tråkletråder': ('tråkletråd',),
'trål': ('trål',),
'trålen': ('trål',),
'trålene': ('trål',),
'tråler': ('trål',),
'trål': ('trål',),
'tråla': ('trål',),
'trålene': ('trål',),
'trålet': ('trål',),
'tråler': ('tråler',),
'trålere': ('tråler',),
'tråleren': ('tråler',),
'trålerer': ('tråler',),
'trålerne': ('tråler',),
'trålerflåte': ('trålerflåte',),
'trålerflåten': ('trålerflåte',),
'trålerflåtene': ('trålerflåte',),
'trålerflåter': ('trålerflåte',),
'trålerskipper': ('trålerskipper',),
'trålerskippere': ('trålerskipper',),
'trålerskipperen': ('trålerskipper',),
'trålerskipperer': ('trålerskipper',),
'trålerskipperne': ('trålerskipper',),
'trålfiska': ('trålfiske',),
'trålfiske': ('trålfiske',),
'trålfiskene': ('trålfiske',),
'trålfisker': ('trålfiske',),
'trålfisket': ('trålfiske',),
'trålpose': ('trålpose',),
'trålposen': ('trålpose',),
'trålposene': ('trålpose',),
'trålposer': ('trålpose',),
'trålsekk': ('trålsekk',),
'trålsekken': ('trålsekk',),
'trålsekkene': ('trålsekk',),
'trålsekker': ('trålsekk',),
'tråltrekk': ('tråltrekk',),
'tråltrekka': ('tråltrekk',),
'tråltrekkene': ('tråltrekk',),
'tråltrekket': ('tråltrekk',),
'tråmaskin': ('tråmaskin',),
'tråmaskina': ('tråmaskin',),
'tråmaskinen': ('tråmaskin',),
'tråmaskinene': ('tråmaskin',),
'tråmaskiner': ('tråmaskin',),
'tråsykkel': ('tråsykkel',),
'tråsykkelen': ('tråsykkel',),
'tråsyklene': ('tråsykkel',),
'tråsykler': ('tråsykkel',),
'tråv': ('tråv',),
'tråva': ('tråv',),
'tråvene': ('tråv',),
'tråvet': ('tråv',),
'tråvbane': ('tråvbane',),
'tråvbanen': ('tråvbane',),
'tråvbanene': ('tråvbane',),
'tråvbaner': ('tråvbane',),
'tråver': ('tråver',),
'tråvere': ('tråver',),
'tråveren': ('tråver',),
'tråverer': ('tråver',),
'tråverne': ('tråver',),
'tråvhest': ('tråvhest',),
'tråvhesten': ('tråvhest',),
'tråvhestene': ('tråvhest',),
'tråvhester': ('tråvhest',),
'tråvløp': ('tråvløp',),
'tråvløpa': ('tråvløp',),
'tråvløpene': ('tråvløp',),
'tråvløpet': ('tråvløp',),
'tråvsport': ('tråvsport',),
'tråvsporten': ('tråvsport',),
'tråvsportene': ('tråvsport',),
'tråvsporter': ('tråvsport',),
'træl': ('træl',),
'træla': ('træl',),
'trælene': ('træl',),
'trælet': ('træl',),
'trø': ('trø',),
'trøa': ('trø',),
'trøene': ('trø',),
'trøet': ('trø',),
'trø': ('trø',),
'trøa': ('trø',),
'trøen': ('trø',),
'trøene': ('trø',),
'trøer': ('trø',),
'trøet': ('trø',),
'trøbbel': ('trøbbel',),
'trøbbelet': ('trøbbel',),
'trøbla': ('trøbbel',),
'trøblene': ('trøbbel',),
'trøbler': ('trøbbel',),
'trøblet': ('trøbbel',),
'trøa': ('trøe',),
'trøe': ('trøe',),
'trøene': ('trøe',),
'trøer': ('trøe',),
'trøet': ('trøe',),
'trøa': ('trøe',),
'trøe': ('trøe',),
'trøen': ('trøe',),
'trøene': ('trøe',),
'trøer': ('trøe',),
'trøa': ('trøe',),
'trøe': ('trøe',),
'trøen': ('trøe',),
'trøene': ('trøe',),
'trøer': ('trøe',),
'trøffel': ('trøffel',),
'trøffelen': ('trøffel',),
'trøflene': ('trøffel',),
'trøfler': ('trøffel',),
'trønder': ('trønder',),
'trøndere': ('trønder',),
'trønderen': ('trønder',),
'trønderer': ('trønder',),
'trønderne': ('trønder',),
'trønderfe': ('trønderfe',),
'trønderfea': ('trønderfe',),
'trønderfeene': ('trønderfe',),
'trønderfeet': ('trønderfe',),
'trønderhumor': ('trønderhumor',),
'trønderhumoren': ('trønderhumor',),
'trønderhumorene': ('trønderhumor',),
'trønderhumorer': ('trønderhumor',),
'trøndersk': ('trøndersk',),
'trøndersken': ('trøndersk',),
'trønderskene': ('trøndersk',),
'trøndersker': ('trøndersk',),
'trøndsk': ('trøndsk',),
'trøndsken': ('trøndsk',),
'trøndskene': ('trøndsk',),
'trøndsker': ('trøndsk',),
'trøsk': ('trøsk',),
'trøsken': ('trøsk',),
'trøskene': ('trøsk',),
'trøsker': ('trøsk',),
'trøske': ('trøske',),
'trøsken': ('trøske',),
'trøskene': ('trøske',),
'trøsker': ('trøske',),
'trøske': ('trøske',),
'trøsken': ('trøske',),
'trøskene': ('trøske',),
'trøsker': ('trøske',),
'trøskesaft': ('trøskesaft',),
'trøskesafta': ('trøskesaft',),
'trøskesaften': ('trøskesaft',),
'trøskesaftene': ('trøskesaft',),
'trøskesafter': ('trøskesaft',),
'trøskesopp': ('trøskesopp',),
'trøskesoppen': ('trøskesopp',),
'trøskesoppene': ('trøskesopp',),
'trøskesopper': ('trøskesopp',),
'trøst': ('trøst',),
'trøsta': ('trøst',),
'trøsten': ('trøst',),
'trøstene': ('trøst',),
'trøster': ('trøst',),
'trøstepremie': ('trøstepremie',),
'trøstepremien': ('trøstepremie',),
'trøstepremiene': ('trøstepremie',),
'trøstepremier': ('trøstepremie',),
'trøster': ('trøster',),
'trøstere': ('trøster',),
'trøsteren': ('trøster',),
'trøsterer': ('trøster',),
'trøsterne': ('trøster',),
'trøstesløshet': ('trøstesløshet',),
'trøstesløsheta': ('trøstesløshet',),
'trøstesløsheten': ('trøstesløshet',),
'trøstesløshetene': ('trøstesløshet',),
'trøstesløsheter': ('trøstesløshet',),
'trøstesløysa': ('trøstesløyse',),
'trøstesløyse': ('trøstesløyse',),
'trøstesløysen': ('trøstesløyse',),
'trøstesløysene': ('trøstesløyse',),
'trøstesløyser': ('trøstesløyse',),
'trøstespiser': ('trøstespiser',),
'trøstespisere': ('trøstespiser',),
'trøstespiseren': ('trøstespiser',),
'trøstespiserer': ('trøstespiser',),
'trøstespiserne': ('trøstespiser',),
'trøtthet': ('trøtthet',),
'trøttheta': ('trøtthet',),
'trøttheten': ('trøtthet',),
'trøtthetene': ('trøtthet',),
'trøttheter': ('trøtthet',),
'trøtthetsbrott': ('trøtthetsbrott',),
'trøtthetsbrotta': ('trøtthetsbrott',),
'trøtthetsbrottene': ('trøtthetsbrott',),
'trøtthetsbrottet': ('trøtthetsbrott',),
'trøtthetsbrudd': ('trøtthetsbrudd',),
'trøtthetsbrudda': ('trøtthetsbrudd',),
'trøtthetsbruddene': ('trøtthetsbrudd',),
'trøtthetsbruddet': ('trøtthetsbrudd',),
'trøya': ('trøye',),
'trøye': ('trøye',),
'trøyen': ('trøye',),
'trøyene': ('trøye',),
'trøyer': ('trøye',),
'tsar': ('tsar',),
'tsaren': ('tsar',),
'tsarene': ('tsar',),
'tsarer': ('tsar',),
'tsardømma': ('tsardømme',),
'tsardømme': ('tsardømme',),
'tsardømmene': ('tsardømme',),
'tsardømmer': ('tsardømme',),
'tsardømmet': ('tsardømme',),
'tsarevitsj': ('tsarevitsj',),
'tsarevitsjen': ('tsarevitsj',),
'tsarevitsjene': ('tsarevitsj',),
'tsarevitsjer': ('tsarevitsj',),
'tsarevna': ('tsarevna',),
'tsarevnaen': ('tsarevna',),
'tsarevnaene': ('tsarevna',),
'tsarevnaer': ('tsarevna',),
'tsarina': ('tsarina',),
'tsarinaen': ('tsarina',),
'tsarinaene': ('tsarina',),
'tsarinaer': ('tsarina',),
'tsaritsa': ('tsaritsa',),
'tsaritsaen': ('tsaritsa',),
'tsaritsaene': ('tsaritsa',),
'tsaritsaer': ('tsaritsa',),
'tsarstyra': ('tsarstyre',),
'tsarstyre': ('tsarstyre',),
'tsarstyrene': ('tsarstyre',),
'tsarstyrer': ('tsarstyre',),
'tsarstyret': ('tsarstyre',),
'tsarvelda': ('tsarvelde',),
'tsarvelde': ('tsarvelde',),
'tsarveldene': ('tsarvelde',),
'tsarvelder': ('tsarvelde',),
'tsarveldet': ('tsarvelde',),
'tsetseflua': ('tsetseflue',),
'tsetseflue': ('tsetseflue',),
'tsetsefluen': ('tsetseflue',),
'tsetsefluene': ('tsetseflue',),
'tsetsefluer': ('tsetseflue',),
'tsjekker': ('tsjekker',),
'tsjekkere': ('tsjekker',),
'tsjekkeren': ('tsjekker',),
'tsjekkerer': ('tsjekker',),
'tsjekkerne': ('tsjekker',),
'tsjekkisk': ('tsjekkisk',),
'tsjekkisken': ('tsjekkisk',),
'tsjekkiskene': ('tsjekkisk',),
'tsjekkisker': ('tsjekkisk',),
'tsjekkoslovak': ('tsjekkoslovak',),
'tsjekkoslovaken': ('tsjekkoslovak',),
'tsjekkoslovakene': ('tsjekkoslovak',),
'tsjekkoslovaker': ('tsjekkoslovak',),
'tsjetnik': ('tsjetnik',),
'tsjetniken': ('tsjetnik',),
'tsjetnikene': ('tsjetnik',),
'tsjetniker': ('tsjetnik',),
'tsjuvasj': ('tsjuvasj',),
'tsjuvasjen': ('tsjuvasj',),
'tsjuvasjene': ('tsjuvasj',),
'tsjuvasjer': ('tsjuvasj',),
'tsjuvasjer': ('tsjuvasjer',),
'tsjuvasjere': ('tsjuvasjer',),
'tsjuvasjeren': ('tsjuvasjer',),
'tsjuvasjerer': ('tsjuvasjer',),
'tsjuvasjerne': ('tsjuvasjer',),
'tu': ('tu',),
'tuareg': ('tuareg',),
'tuaregen': ('tuareg',),
'tuaregene': ('tuareg',),
'tuareger': ('tuareg',),
'tub': ('tub',),
'tuben': ('tub',),
'tubene': ('tub',),
'tuber': ('tub',),
'tuba': ('tuba',),
'tubaen': ('tuba',),
'tubaene': ('tuba',),
'tubaer': ('tuba',),
'tubaist': ('tubaist',),
'tubaisten': ('tubaist',),
'tubaistene': ('tubaist',),
'tubaister': ('tubaist',),
'tube': ('tube',),
'tuben': ('tube',),
'tubene': ('tube',),
'tuber': ('tube',),
'tuberkel': ('tuberkel',),
'tuberkelen': ('tuberkel',),
'tuberklene': ('tuberkel',),
'tuberkler': ('tuberkel',),
'tuberkelbasill': ('tuberkelbasill',),
'tuberkelbasillen': ('tuberkelbasill',),
'tuberkelbasillene': ('tuberkelbasill',),
'tuberkelbasiller': ('tuberkelbasill',),
'tuberkulin': ('tuberkulin',),
'tuberkulina': ('tuberkulin',),
'tuberkulinene': ('tuberkulin',),
'tuberkulinet': ('tuberkulin',),
'tuberkulinprøva': ('tuberkulinprøve',),
'tuberkulinprøve': ('tuberkulinprøve',),
'tuberkulinprøven': ('tuberkulinprøve',),
'tuberkulinprøvene': ('tuberkulinprøve',),
'tuberkulinprøver': ('tuberkulinprøve',),
'tuberkulose': ('tuberkulose',),
'tuberkulosen': ('tuberkulose',),
'tuberkulosene': ('tuberkulose',),
'tuberkuloser': ('tuberkulose',),
'tua': ('tue',),
'tue': ('tue',),
'tuen': ('tue',),
'tuene': ('tue',),
'tuer': ('tue',),
'tua': ('tue',),
'tue': ('tue',),
'tuen': ('tue',),
'tuene': ('tue',),
'tuer': ('tue',),
'tuff': ('tuff',),
'tuffen': ('tuff',),
'tuffene': ('tuff',),
'tuffer': ('tuff',),
'tufs': ('tufs',),
'tufsen': ('tufs',),
'tufsene': ('tufs',),
'tufser': ('tufs',),
'tufs': ('tufs',),
'tufsa': ('tufs',),
'tufsene': ('tufs',),
'tufset': ('tufs',),
'tufsa': ('tufse',),
'tufse': ('tufse',),
'tufsen': ('tufse',),
'tufsene': ('tufse',),
'tufser': ('tufse',),
'tufsing': ('tufsing',),
'tufsingen': ('tufsing',),
'tufsingene': ('tufsing',),
'tufsinger': ('tufsing',),
'tuft': ('tuft',),
'tuften': ('tuft',),
'tuftene': ('tuft',),
'tufter': ('tuft',),
'tuft': ('tuft',),
'tufta': ('tuft',),
'tuften': ('tuft',),
'tuftene': ('tuft',),
'tufter': ('tuft',),
'tufte': ('tufte',),
'tuften': ('tufte',),
'tuftene': ('tufte',),
'tufter': ('tufte',),
'tuftefolk': ('tuftefolk',),
'tuftefolka': ('tuftefolk',),
'tuftefolkene': ('tuftefolk',),
'tuftefolket': ('tuftefolk',),
'tuftekall': ('tuftekall',),
'tuftekallen': ('tuftekall',),
'tuftekallene': ('tuftekall',),
'tuftekaller': ('tuftekall',),
'tugga': ('tugge',),
'tugge': ('tugge',),
'tuggen': ('tugge',),
'tuggene': ('tugge',),
'tugger': ('tugge',),
'tukan': ('tukan',),
'tukanen': ('tukan',),
'tukanene': ('tukan',),
'tukaner': ('tukan',),
'tukkel': ('tukkel',),
'tukkelen': ('tukkel',),
'tuklene': ('tukkel',),
'tukler': ('tukkel',),
'tukkel': ('tukkel',),
'tukkelet': ('tukkel',),
'tukla': ('tukkel',),
'tuklene': ('tukkel',),
'tuklet': ('tukkel',),
'tukl': ('tukl',),
'tukla': ('tukl',),
'tuklene': ('tukl',),
'tuklet': ('tukl',),
'tukling': ('tukling',),
'tuklingen': ('tukling',),
'tuklingene': ('tukling',),
'tuklinger': ('tukling',),
'tukt': ('tukt',),
'tukta': ('tukt',),
'tukten': ('tukt',),
'tuktene': ('tukt',),
'tukter': ('tukt',),
'tuktemester': ('tuktemester',),
'tuktemestere': ('tuktemester',),
'tuktemesteren': ('tuktemester',),
'tuktemesterer': ('tuktemester',),
'tuktemesterne': ('tuktemester',),
'tuktemestre': ('tuktemester',),
'tuktemestrene': ('tuktemester',),
'tuktemestrer': ('tuktemester',),
'tukter': ('tukter',),
'tuktere': ('tukter',),
'tukteren': ('tukter',),
'tukterer': ('tukter',),
'tukterne': ('tukter',),
'tukthus': ('tukthus',),
'tukthusa': ('tukthus',),
'tukthusene': ('tukthus',),
'tukthuset': ('tukthus',),
'tukthuskandidat': ('tukthuskandidat',),
'tukthuskandidaten': ('tukthuskandidat',),
'tukthuskandidatene': ('tukthuskandidat',),
'tukthuskandidater': ('tukthuskandidat',),
'tularemi': ('tularemi',),
'tularemien': ('tularemi',),
'tularemiene': ('tularemi',),
'tularemier': ('tularemi',),
'tulipan': ('tulipan',),
'tulipanen': ('tulipan',),
'tulipanene': ('tulipan',),
'tulipaner': ('tulipan',),
'tull': ('tull',),
'tullen': ('tull',),
'tullene': ('tull',),
'tuller': ('tull',),
'tull': ('tull',),
'tullen': ('tull',),
'tullene': ('tull',),
'tuller': ('tull',),
'tull': ('tull',),
'tulla': ('tull',),
'tullene': ('tull',),
'tullet': ('tull',),
'tullball': ('tullball',),
'tullballa': ('tullball',),
'tullballene': ('tullball',),
'tullballet': ('tullball',),
'tulla': ('tulle',),
'tulle': ('tulle',),
'tullen': ('tulle',),
'tullene': ('tulle',),
'tuller': ('tulle',),
'tullebukk': ('tullebukk',),
'tullebukken': ('tullebukk',),
'tullebukkene': ('tullebukk',),
'tullebukker': ('tullebukk',),
'tullekopp': ('tullekopp',),
'tullekoppen': ('tullekopp',),
'tullekoppene': ('tullekopp',),
'tullekopper': ('tullekopp',),
'tulleskap': ('tulleskap',),
'tulleskapa': ('tulleskap',),
'tulleskapen': ('tulleskap',),
'tulleskapene': ('tulleskap',),
'tulleskaper': ('tulleskap',),
'tulleskapet': ('tulleskap',),
'tulling': ('tulling',),
'tullingen': ('tulling',),
'tullingene': ('tulling',),
'tullinger': ('tulling',),
'tulling': ('tulling',),
'tullinga': ('tulling',),
'tullingen': ('tulling',),
'tullingene': ('tulling',),
'tullinger': ('tulling',),
'tullprat': ('tullprat',),
'tullprata': ('tullprat',),
'tullpraten': ('tullprat',),
'tullpratene': ('tullprat',),
'tullprater': ('tullprat',),
'tullpratet': ('tullprat',),
'tulupp': ('tulupp',),
'tuluppen': ('tulupp',),
'tuluppene': ('tulupp',),
'tulupper': ('tulupp',),
'tumleplass': ('tumleplass',),
'tumleplassen': ('tumleplass',),
'tumleplassene': ('tumleplass',),
'tumleplasser': ('tumleplass',),
'tumlene': ('tummel',),
'tumler': ('tummel',),
'tummel': ('tummel',),
'tummelen': ('tummel',),
'tumor': ('tumor',),
'tumoren': ('tumor',),
'tumorene': ('tumor',),
'tumorer': ('tumor',),
'tumult': ('tumult',),
'tumulten': ('tumult',),
'tumultene': ('tumult',),
'tumulter': ('tumult',),
'tumultuant': ('tumultuant',),
'tumultuanten': ('tumultuant',),
'tumultuantene': ('tumultuant',),
'tumultuanter': ('tumultuant',),
'tun': ('tun',),
'tuna': ('tun',),
'tunene': ('tun',),
'tunet': ('tun',),
'tundra': ('tundra',),
'tundraen': ('tundra',),
'tundraene': ('tundra',),
'tundraer': ('tundra',),
'tuneflua': ('tuneflue',),
'tuneflue': ('tuneflue',),
'tunefluen': ('tuneflue',),
'tunefluene': ('tuneflue',),
'tunefluer': ('tuneflue',),
'tuner': ('tuner',),
'tunere': ('tuner',),
'tuneren': ('tuner',),
'tunerer': ('tuner',),
'tunerne': ('tuner',),
'tunfisk': ('tunfisk',),
'tunfisken': ('tunfisk',),
'tunfiskene': ('tunfisk',),
'tunfisker': ('tunfisk',),
'tungarbeid': ('tungarbeid',),
'tungarbeida': ('tungarbeid',),
'tungarbeidene': ('tungarbeid',),
'tungarbeider': ('tungarbeid',),
'tungarbeidet': ('tungarbeid',),
'tungarbeider': ('tungarbeider',),
'tungarbeidere': ('tungarbeider',),
'tungarbeideren': ('tungarbeider',),
'tungarbeiderer': ('tungarbeider',),
'tungarbeiderne': ('tungarbeider',),
'tunga': ('tunge',),
'tunge': ('tunge',),
'tungen': ('tunge',),
'tungene': ('tunge',),
'tunger': ('tunge',),
'tunga': ('tunge',),
'tunge': ('tunge',),
'tungen': ('tunge',),
'tungene': ('tunge',),
'tunger': ('tunge',),
'tungeband': ('tungeband',),
'tungebanda': ('tungeband',),
'tungebandene': ('tungeband',),
'tungebandet': ('tungeband',),
'tungebånd': ('tungebånd',),
'tungebånda': ('tungebånd',),
'tungebåndene': ('tungebånd',),
'tungebåndet': ('tungebånd',),
'tungeflyndra': ('tungeflyndre',),
'tungeflyndre': ('tungeflyndre',),
'tungeflyndren': ('tungeflyndre',),
'tungeflyndrene': ('tungeflyndre',),
'tungeflyndrer': ('tungeflyndre',),
'tungemål': ('tungemål',),
'tungemåla': ('tungemål',),
'tungemålene': ('tungemål',),
'tungemålet': ('tungemål',),
'tungerot': ('tungerot',),
'tungerota': ('tungerot',),
'tungeroten': ('tungerot',),
'tungerøttene': ('tungerot',),
'tungerøtter': ('tungerot',),
'tungerygg': ('tungerygg',),
'tungeryggen': ('tungerygg',),
'tungeryggene': ('tungerygg',),
'tungerygger': ('tungerygg',),
'tungespiss': ('tungespiss',),
'tungespissen': ('tungespiss',),
'tungespissene': ('tungespiss',),
'tungespisser': ('tungespiss',),
'tungespiss-r': ('tungespiss-r',),
'tungespiss-r-en': ('tungespiss-r',),
'tungespiss-r-ene': ('tungespiss-r',),
'tungespiss-r-er': ('tungespiss-r',),
'tungetale': ('tungetale',),
'tungetalen': ('tungetale',),
'tungetalene': ('tungetale',),
'tungetaler': ('tungetale',),
'tungetaler': ('tungetaler',),
'tungetalere': ('tungetaler',),
'tungetaleren': ('tungetaler',),
'tungetalerer': ('tungetaler',),
'tungetalerne': ('tungetaler',),
'tungindustri': ('tungindustri',),
'tungindustrien': ('tungindustri',),
'tungindustriene': ('tungindustri',),
'tungindustrier': ('tungindustri',),
'tungmetall': ('tungmetall',),
'tungmetalla': ('tungmetall',),
'tungmetallene': ('tungmetall',),
'tungmetaller': ('tungmetall',),
'tungmetallet': ('tungmetall',),
'tungolja': ('tungolje',),
'tungolje': ('tungolje',),
'tungoljen': ('tungolje',),
'tungoljene': ('tungolje',),
'tungoljer': ('tungolje',),
'tungras': ('tungras',),
'tungrasa': ('tungras',),
'tungrasene': ('tungras',),
'tungraset': ('tungras',),
'tungress': ('tungress',),
'tungressa': ('tungress',),
'tungressene': ('tungress',),
'tungresset': ('tungress',),
'tungsinn': ('tungsinn',),
'tungsinna': ('tungsinn',),
'tungsinnene': ('tungsinn',),
'tungsinnet': ('tungsinn',),
'tungspat': ('tungspat',),
'tungspaten': ('tungspat',),
'tungspatene': ('tungspat',),
'tungspater': ('tungspat',),
'tungtrafikk': ('tungtrafikk',),
'tungtrafikken': ('tungtrafikk',),
'tungtrafikkene': ('tungtrafikk',),
'tungtrafikker': ('tungtrafikk',),
'tungtransport': ('tungtransport',),
'tungtransporten': ('tungtransport',),
'tungtransportene': ('tungtransport',),
'tungtransporter': ('tungtransport',),
'tungtvann': ('tungtvann',),
'tungtvanna': ('tungtvann',),
'tungtvannene': ('tungtvann',),
'tungtvannet': ('tungtvann',),
'tungtvatn': ('tungtvatn',),
'tungtvatna': ('tungtvatn',),
'tungtvatnene': ('tungtvatn',),
'tungtvatnet': ('tungtvatn',),
'tunguser': ('tunguser',),
'tungusere': ('tunguser',),
'tunguseren': ('tunguser',),
'tunguserer': ('tunguser',),
'tunguserne': ('tunguser',),
'tungusisk': ('tungusisk',),
'tungusisken': ('tungusisk',),
'tungusiskene': ('tungusisk',),
'tungusisker': ('tungusisk',),
'tungvekt': ('tungvekt',),
'tungvekta': ('tungvekt',),
'tungvekten': ('tungvekt',),
'tungvektene': ('tungvekt',),
'tungvekter': ('tungvekt',),
'tungvektbokser': ('tungvektbokser',),
'tungvektboksere': ('tungvektbokser',),
'tungvektbokseren': ('tungvektbokser',),
'tungvektbokserer': ('tungvektbokser',),
'tungvektbokserne': ('tungvektbokser',),
'tungvekter': ('tungvekter',),
'tungvektere': ('tungvekter',),
'tungvekteren': ('tungvekter',),
'tungvekterer': ('tungvekter',),
'tungvekterne': ('tungvekter',),
'tungvektklassa': ('tungvektklasse',),
'tungvektklasse': ('tungvektklasse',),
'tungvektklassen': ('tungvektklasse',),
'tungvektklassene': ('tungvektklasse',),
'tungvektklasser': ('tungvektklasse',),
'tungvektsbokser': ('tungvektsbokser',),
'tungvektsboksere': ('tungvektsbokser',),
'tungvektsbokseren': ('tungvektsbokser',),
'tungvektsbokserer': ('tungvektsbokser',),
'tungvektsbokserne': ('tungvektsbokser',),
'tungvektsklassa': ('tungvektsklasse',),
'tungvektsklasse': ('tungvektsklasse',),
'tungvektsklassen': ('tungvektsklasse',),
'tungvektsklassene': ('tungvektsklasse',),
'tungvektsklasser': ('tungvektsklasse',),
'tungvinthet': ('tungvinthet',),
'tungvintheta': ('tungvinthet',),
'tungvintheten': ('tungvinthet',),
'tungvinthetene': ('tungvinthet',),
'tungvintheter': ('tungvinthet',),
'tunika': ('tunika',),
'tunikaen': ('tunika',),
'tunikaene': ('tunika',),
'tunikaer': ('tunika',),
'tunisier': ('tunisier',),
'tunisiere': ('tunisier',),
'tunisieren': ('tunisier',),
'tunisierer': ('tunisier',),
'tunisierne': ('tunisier',),
'tunkall': ('tunkall',),
'tunkallen': ('tunkall',),
'tunkallene': ('tunkall',),
'tunkaller': ('tunkall',),
'tunnel': ('tunnel',),
'tunnelen': ('tunnel',),
'tunnelene': ('tunnel',),
'tunneler': ('tunnel',),
'tunnelbane': ('tunnelbane',),
'tunnelbanen': ('tunnelbane',),
'tunnelbanene': ('tunnelbane',),
'tunnelbaner': ('tunnelbane',),
'tuntre': ('tuntre',),
'tuntrea': ('tuntre',),
'tuntreet': ('tuntre',),
'tuntrær': ('tuntre',),
'tuntrærne': ('tuntre',),
'tupeen': ('tupé',),
'tupeene': ('tupé',),
'tupeer': ('tupé',),
'tupé': ('tupé',),
'tupéen': ('tupé',),
'tupéene': ('tupé',),
'tupéer': ('tupé',),
'tupp': ('tupp',),
'tuppen': ('tupp',),
'tuppene': ('tupp',),
'tupper': ('tupp',),
'tupp': ('tupp',),
'tuppa': ('tupp',),
'tuppene': ('tupp',),
'tuppet': ('tupp',),
'tuppa': ('tuppe',),
'tuppe': ('tuppe',),
'tuppen': ('tuppe',),
'tuppene': ('tuppe',),
'tupper': ('tuppe',),
'tur-retur': ('tur-retur',),
'tur-returen': ('tur-retur',),
'tur-returene': ('tur-retur',),
'tur-returer': ('tur-retur',),
'tur-retur-billett': ('tur-retur-billett',),
'tur-retur-billetten': ('tur-retur-billett',),
'tur-retur-billettene': ('tur-retur-billett',),
'tur-retur-billetter': ('tur-retur-billett',),
'turban': ('turban',),
'turbanen': ('turban',),
'turbanene': ('turban',),
'turbaner': ('turban',),
'turbin': ('turbin',),
'turbinen': ('turbin',),
'turbinene': ('turbin',),
'turbiner': ('turbin',),
'turbinskip': ('turbinskip',),
'turbinskipa': ('turbinskip',),
'turbinskipene': ('turbinskip',),
'turbinskipet': ('turbinskip',),
'turbo': ('turbo',),
'turboen': ('turbo',),
'turboene': ('turbo',),
'turboer': ('turbo',),
'turboladning': ('turboladning',),
'turboladninga': ('turboladning',),
'turboladningen': ('turboladning',),
'turboladningene': ('turboladning',),
'turboladninger': ('turboladning',),
'turboprop': ('turboprop',),
'turbopropen': ('turboprop',),
'turbopropene': ('turboprop',),
'turboproper': ('turboprop',),
'turbopropfly': ('turbopropfly',),
'turbopropflya': ('turbopropfly',),
'turbopropflyene': ('turbopropfly',),
'turbopropflyet': ('turbopropfly',),
'turbopropmotor': ('turbopropmotor',),
'turbopropmotoren': ('turbopropmotor',),
'turbopropmotorene': ('turbopropmotor',),
'turbopropmotorer': ('turbopropmotor',),
'turbulens': ('turbulens',),
'turbulensen': ('turbulens',),
'turbulensene': ('turbulens',),
'turbulenser': ('turbulens',),
'turbuss': ('turbuss',),
'turbussen': ('turbuss',),
'turbussene': ('turbuss',),
'turbusser': ('turbuss',),
'turdans': ('turdans',),
'turdansen': ('turdans',),
'turdansene': ('turdans',),
'turdanser': ('turdans',),
'ture': ('ture',),
'turen': ('ture',),
'turene': ('ture',),
'turer': ('ture',),
'turgjenger': ('turgjenger',),
'turgjengere': ('turgjenger',),
'turgjengeren': ('turgjenger',),
'turgjengerer': ('turgjenger',),
'turgjengerne': ('turgjenger',),
'turgåer': ('turgåer',),
'turgåere': ('turgåer',),
'turgåeren': ('turgåer',),
'turgåerer': ('turgåer',),
'turgåerne': ('turgåer',),
'turgåing': ('turgåing',),
'turgåinga': ('turgåing',),
'turgåingen': ('turgåing',),
'turgåingene': ('turgåing',),
'turgåinger': ('turgåing',),
'turisme': ('turisme',),
'turismen': ('turisme',),
'turismene': ('turisme',),
'turismer': ('turisme',),
'turist': ('turist',),
'turisten': ('turist',),
'turistene': ('turist',),
'turister': ('turist',),
'turistattraksjon': ('turistattraksjon',),
'turistattraksjonen': ('turistattraksjon',),
'turistattraksjonene': ('turistattraksjon',),
'turistattraksjoner': ('turistattraksjon',),
'turistforening': ('turistforening',),
'turistforeninga': ('turistforening',),
'turistforeningen': ('turistforening',),
'turistforeningene': ('turistforening',),
'turistforeninger': ('turistforening',),
'turisthotell': ('turisthotell',),
'turisthotella': ('turisthotell',),
'turisthotellene': ('turisthotell',),
'turisthoteller': ('turisthotell',),
'turisthotellet': ('turisthotell',),
'turisthytta': ('turisthytte',),
'turisthytte': ('turisthytte',),
'turisthytten': ('turisthytte',),
'turisthyttene': ('turisthytte',),
'turisthytter': ('turisthytte',),
'turistklassa': ('turistklasse',),
'turistklasse': ('turistklasse',),
'turistklassen': ('turistklasse',),
'turistklassene': ('turistklasse',),
'turistklasser': ('turistklasse',),
'turistkontor': ('turistkontor',),
'turistkontora': ('turistkontor',),
'turistkontorene': ('turistkontor',),
'turistkontorer': ('turistkontor',),
'turistkontoret': ('turistkontor',),
'turistland': ('turistland',),
'turistlanda': ('turistland',),
'turistlandene': ('turistland',),
'turistlandet': ('turistland',),
'turistnæring': ('turistnæring',),
'turistnæringa': ('turistnæring',),
'turistnæringen': ('turistnæring',),
'turistnæringene': ('turistnæring',),
'turistnæringer': ('turistnæring',),
'turistsesong': ('turistsesong',),
'turistsesongen': ('turistsesong',),
'turistsesongene': ('turistsesong',),
'turistsesonger': ('turistsesong',),
'turisttrafikk': ('turisttrafikk',),
'turisttrafikken': ('turisttrafikk',),
'turisttrafikkene': ('turisttrafikk',),
'turisttrafikker': ('turisttrafikk',),
'turistvaluta': ('turistvaluta',),
'turistvalutaen': ('turistvaluta',),
'turistvalutaene': ('turistvaluta',),
'turistvalutaer': ('turistvaluta',),
'turistvogn': ('turistvogn',),
'turistvogna': ('turistvogn',),
'turistvognen': ('turistvogn',),
'turistvognene': ('turistvogn',),
'turistvogner': ('turistvogn',),
'turkis': ('turkis',),
'turkisen': ('turkis',),
'turkisene': ('turkis',),
'turkiser': ('turkis',),
'turklassa': ('turklasse',),
'turklasse': ('turklasse',),
'turklassen': ('turklasse',),
'turklassene': ('turklasse',),
'turklasser': ('turklasse',),
'turkmener': ('turkmener',),
'turkmenere': ('turkmener',),
'turkmeneren': ('turkmener',),
'turkmenerer': ('turkmener',),
'turkmenerne': ('turkmener',),
'turlangrennsski': ('turlangrennsski',),
'turlangrennsskia': ('turlangrennsski',),
'turlangrennsskien': ('turlangrennsski',),
'turlangrennsskiene': ('turlangrennsski',),
'turlangrennsskier': ('turlangrennsski',),
'turløper': ('turløper',),
'turløpere': ('turløper',),
'turløperen': ('turløper',),
'turløperer': ('turløper',),
'turløperne': ('turløper',),
'turmalin': ('turmalin',),
'turmalina': ('turmalin',),
'turmalinen': ('turmalin',),
'turmalinene': ('turmalin',),
'turmaliner': ('turmalin',),
'turmalinet': ('turmalin',),
'turn': ('turn',),
'turneen': ('turné',),
'turneene': ('turné',),
'turneer': ('turné',),
'turné': ('turné',),
'turnéen': ('turné',),
'turnéene': ('turné',),
'turnéer': ('turné',),
'turnapparat': ('turnapparat',),
'turnapparata': ('turnapparat',),
'turnapparatene': ('turnapparat',),
'turnapparater': ('turnapparat',),
'turnapparatet': ('turnapparat',),
'turndrakt': ('turndrakt',),
'turndrakta': ('turndrakt',),
'turndrakten': ('turndrakt',),
'turndraktene': ('turndrakt',),
'turndrakter': ('turndrakt',),
'turner': ('turner',),
'turnere': ('turner',),
'turneren': ('turner',),
'turnerer': ('turner',),
'turnerne': ('turner',),
'turnering': ('turnering',),
'turneringa': ('turnering',),
'turneringen': ('turnering',),
'turneringene': ('turnering',),
'turneringer': ('turnering',),
'turnikea': ('turniké',),
'turnikeene': ('turniké',),
'turnikeer': ('turniké',),
'turnikeet': ('turniké',),
'turniké': ('turniké',),
'turnikéa': ('turniké',),
'turnikéene': ('turniké',),
'turnikéer': ('turniké',),
'turnikéet': ('turniké',),
'turning': ('turning',),
'turninga': ('turning',),
'turningen': ('turning',),
'turningene': ('turning',),
'turninger': ('turning',),
'turnips': ('turnips',),
'turnipsen': ('turnips',),
'turnipsene': ('turnips',),
'turnipser': ('turnips',),
'turnparti': ('turnparti',),
'turnpartia': ('turnparti',),
'turnpartiene': ('turnparti',),
'turnpartier': ('turnparti',),
'turnpartiet': ('turnparti',),
'turnus': ('turnus',),
'turnusen': ('turnus',),
'turnusene': ('turnus',),
'turnuser': ('turnus',),
'turnuskandidat': ('turnuskandidat',),
'turnuskandidaten': ('turnuskandidat',),
'turnuskandidatene': ('turnuskandidat',),
'turnuskandidater': ('turnuskandidat',),
'turnustjeneste': ('turnustjeneste',),
'turnustjenesten': ('turnustjeneste',),
'turnustjenestene': ('turnustjeneste',),
'turnustjenester': ('turnustjeneste',),
'turoperatør': ('turoperatør',),
'turoperatøren': ('turoperatør',),
'turoperatørene': ('turoperatør',),
'turoperatører': ('turoperatør',),
'turrenn': ('turrenn',),
'turrenna': ('turrenn',),
'turrennene': ('turrenn',),
'turrennet': ('turrenn',),
'turt': ('turt',),
'turta': ('turt',),
'turten': ('turt',),
'turtene': ('turt',),
'turter': ('turt',),
'turtal': ('turtal',),
'turtala': ('turtal',),
'turtalene': ('turtal',),
'turtalet': ('turtal',),
'turtall': ('turtall',),
'turtalla': ('turtall',),
'turtallene': ('turtall',),
'turtallet': ('turtall',),
'turteldua': ('turteldue',),
'turteldue': ('turteldue',),
'turtelduen': ('turteldue',),
'turtelduene': ('turteldue',),
'turtelduer': ('turteldue',),
'turteller': ('turteller',),
'turtellere': ('turteller',),
'turtelleren': ('turteller',),
'turtellerer': ('turteller',),
'turtellerne': ('turteller',),
'turveg': ('turveg',),
'turvegen': ('turveg',),
'turvegene': ('turveg',),
'turveger': ('turveg',),
'turvei': ('turvei',),
'turveien': ('turvei',),
'turveiene': ('turvei',),
'turveier': ('turvei',),
'tusen': ('tusen',),
'tusena': ('tusen',),
'tusenene': ('tusen',),
'tusener': ('tusen',),
'tusenet': ('tusen',),
'tusenbein': ('tusenbein',),
'tusenbeina': ('tusenbein',),
'tusenbeinene': ('tusenbein',),
'tusenbeinet': ('tusenbein',),
'tusenben': ('tusenben',),
'tusenbena': ('tusenben',),
'tusenbenene': ('tusenben',),
'tusenbenet': ('tusenben',),
'tusenblad': ('tusenblad',),
'tusenblada': ('tusenblad',),
'tusenbladene': ('tusenblad',),
'tusenblader': ('tusenblad',),
'tusenbladet': ('tusenblad',),
'tusendel': ('tusendel',),
'tusendelen': ('tusendel',),
'tusendelene': ('tusendel',),
'tusendeler': ('tusendel',),
'tusener': ('tusener',),
'tusenere': ('tusener',),
'tuseneren': ('tusener',),
'tusenerer': ('tusener',),
'tusenerne': ('tusener',),
'tusenfryd': ('tusenfryd',),
'tusenfryden': ('tusenfryd',),
'tusenfrydene': ('tusenfryd',),
'tusenfryder': ('tusenfryd',),
'tusengyllen': ('tusengyllen',),
'tusengyllenen': ('tusengyllen',),
'tusengyllenene': ('tusengyllen',),
'tusengyllener': ('tusengyllen',),
'tusenkrona': ('tusenkrone',),
'tusenkrone': ('tusenkrone',),
'tusenkronen': ('tusenkrone',),
'tusenkronene': ('tusenkrone',),
'tusenkroner': ('tusenkrone',),
'tusenkroneseddel': ('tusenkroneseddel',),
'tusenkroneseddelen': ('tusenkroneseddel',),
'tusenkronesedlene': ('tusenkroneseddel',),
'tusenkronesedler': ('tusenkroneseddel',),
'tusenkroning': ('tusenkroning',),
'tusenkroningen': ('tusenkroning',),
'tusenkroningene': ('tusenkroning',),
'tusenkroninger': ('tusenkroning',),
'tusenkunstner': ('tusenkunstner',),
'tusenkunstnere': ('tusenkunstner',),
'tusenkunstneren': ('tusenkunstner',),
'tusenkunstnerer': ('tusenkunstner',),
'tusenkunstnerne': ('tusenkunstner',),
'tusenlapp': ('tusenlapp',),
'tusenlappen': ('tusenlapp',),
'tusenlappene': ('tusenlapp',),
'tusenlapper': ('tusenlapp',),
'tusental': ('tusental',),
'tusentala': ('tusental',),
'tusentalene': ('tusental',),
'tusentalet': ('tusental',),
'tusentall': ('tusentall',),
'tusentalla': ('tusentall',),
'tusentallene': ('tusentall',),
'tusentallet': ('tusentall',),
'tusenår': ('tusenår',),
'tusenåra': ('tusenår',),
'tusenårene': ('tusenår',),
'tusenåret': ('tusenår',),
'tusenårsrika': ('tusenårsrike',),
'tusenårsrike': ('tusenårsrike',),
'tusenårsrikene': ('tusenårsrike',),
'tusenårsriker': ('tusenårsrike',),
'tusenårsriket': ('tusenårsrike',),
'tusj': ('tusj',),
'tusjen': ('tusj',),
'tusjene': ('tusj',),
'tusjer': ('tusj',),
'tusjpenn': ('tusjpenn',),
'tusjpennen': ('tusjpenn',),
'tusjpennene': ('tusjpenn',),
'tusjpenner': ('tusjpenn',),
'tusjtegning': ('tusjtegning',),
'tusjtegninga': ('tusjtegning',),
'tusjtegningen': ('tusjtegning',),
'tusjtegningene': ('tusjtegning',),
'tusjtegninger': ('tusjtegning',),
'tuskhandel': ('tuskhandel',),
'tuskhandelen': ('tuskhandel',),
'tuskhandlene': ('tuskhandel',),
'tuskhandler': ('tuskhandel',),
'tusling': ('tusling',),
'tuslingen': ('tusling',),
'tuslingene': ('tusling',),
'tuslinger': ('tusling',),
'tuss': ('tuss',),
'tussen': ('tuss',),
'tussene': ('tuss',),
'tusser': ('tuss',),
'tussebitt': ('tussebitt',),
'tussebitta': ('tussebitt',),
'tussebittene': ('tussebitt',),
'tussebittet': ('tussebitt',),
'tussefletta': ('tusseflette',),
'tusseflette': ('tusseflette',),
'tussefletten': ('tusseflette',),
'tusseflettene': ('tusseflette',),
'tussefletter': ('tusseflette',),
'tussefløyta': ('tussefløyte',),
'tussefløyte': ('tussefløyte',),
'tussefløyten': ('tussefløyte',),
'tussefløytene': ('tussefløyte',),
'tussefløyter': ('tussefløyte',),
'tussefolk': ('tussefolk',),
'tussefolka': ('tussefolk',),
'tussefolkene': ('tussefolk',),
'tussefolket': ('tussefolk',),
'tusseladd': ('tusseladd',),
'tusseladden': ('tusseladd',),
'tusseladdene': ('tusseladd',),
'tusseladder': ('tusseladd',),
'tusseskap': ('tusseskap',),
'tusseskapa': ('tusseskap',),
'tusseskapen': ('tusseskap',),
'tusseskapene': ('tusseskap',),
'tusseskaper': ('tusseskap',),
'tusseskapet': ('tusseskap',),
'tussing': ('tussing',),
'tussingen': ('tussing',),
'tussingene': ('tussing',),
'tussinger': ('tussing',),
'tussmørka': ('tussmørke',),
'tussmørke': ('tussmørke',),
'tussmørkene': ('tussmørke',),
'tussmørker': ('tussmørke',),
'tussmørket': ('tussmørke',),
'tust': ('tust',),
'tusten': ('tust',),
'tustene': ('tust',),
'tuster': ('tust',),
'tust': ('tust',),
'tusta': ('tust',),
'tusten': ('tust',),
'tustene': ('tust',),
'tuster': ('tust',),
'tut': ('tut',),
'tuten': ('tut',),
'tutene': ('tut',),
'tuter': ('tut',),
'tut': ('tut',),
'tuta': ('tut',),
'tutene': ('tut',),
'tutet': ('tut',),
'tutekanna': ('tutekanne',),
'tutekanne': ('tutekanne',),
'tutekannen': ('tutekanne',),
'tutekannene': ('tutekanne',),
'tutekanner': ('tutekanne',),
'tutekar': ('tutekar',),
'tutekara': ('tutekar',),
'tutekarene': ('tutekar',),
'tutekaret': ('tutekar',),
'tutel': ('tutel',),
'tutela': ('tutel',),
'tutelene': ('tutel',),
'tuteler': ('tutel',),
'tutelet': ('tutel',),
'tutkanna': ('tutkanne',),
'tutkanne': ('tutkanne',),
'tutkannen': ('tutkanne',),
'tutkannene': ('tutkanne',),
'tutkanner': ('tutkanne',),
'tutkar': ('tutkar',),
'tutkara': ('tutkar',),
'tutkarene': ('tutkar',),
'tutkaret': ('tutkar',),
'tutor': ('tutor',),
'tutoren': ('tutor',),
'tutorene': ('tutor',),
'tutorer': ('tutor',),
'tutsi': ('tutsi',),
'tutsien': ('tutsi',),
'tutsiene': ('tutsi',),
'tutsier': ('tutsi',),
'tutt': ('tutt',),
'tutten': ('tutt',),
'tuttene': ('tutt',),
'tutter': ('tutt',),
'tutti': ('tutti',),
'tuttifrutti': ('tuttifrutti',),
'tuttifruttien': ('tuttifrutti',),
'tuttifruttiene': ('tuttifrutti',),
'tuttifruttier': ('tuttifrutti',),
'tutu': ('tutu',),
'tutuen': ('tutu',),
'tutuene': ('tutu',),
'tutuer': ('tutu',),
'tuvaler': ('tuvaler',),
'tuvalere': ('tuvaler',),
'tuvaleren': ('tuvaler',),
'tuvalerer': ('tuvaler',),
'tuvalerne': ('tuvaler',),
'tuva': ('tuve',),
'tuve': ('tuve',),
'tuven': ('tuve',),
'tuvene': ('tuve',),
'tuver': ('tuve',),
'tuva': ('tuve',),
'tuve': ('tuve',),
'tuven': ('tuve',),
'tuvene': ('tuve',),
'tuver': ('tuve',),
'tv': ('tv',),
'tv-en': ('tv',),
'tv-ene': ('tv',),
'tv-er': ('tv',),
'tv-antenna': ('tv-antenne',),
'tv-antenne': ('tv-antenne',),
'tv-antennen': ('tv-antenne',),
'tv-antennene': ('tv-antenne',),
'tv-antenner': ('tv-antenne',),
'tv-apparat': ('tv-apparat',),
'tv-apparata': ('tv-apparat',),
'tv-apparatene': ('tv-apparat',),
'tv-apparater': ('tv-apparat',),
'tv-apparatet': ('tv-apparat',),
'tv-film': ('tv-film',),
'tv-filmen': ('tv-film',),
'tv-filmene': ('tv-film',),
'tv-filmer': ('tv-film',),
'tv-kanna': ('tv-kanne',),
'tv-kanne': ('tv-kanne',),
'tv-kannen': ('tv-kanne',),
'tv-kannene': ('tv-kanne',),
'tv-kanner': ('tv-kanne',),
'tv-kjendis': ('tv-kjendis',),
'tv-kjendisen': ('tv-kjendis',),
'tv-kjendisene': ('tv-kjendis',),
'tv-kjendiser': ('tv-kjendis',),
'tv-overføring': ('tv-overføring',),
'tv-overføringa': ('tv-overføring',),
'tv-overføringen': ('tv-overføring',),
'tv-overføringene': ('tv-overføring',),
'tv-overføringer': ('tv-overføring',),
'tv-overvåking': ('tv-overvåking',),
'tv-overvåkinga': ('tv-overvåking',),
'tv-overvåkingen': ('tv-overvåking',),
'tv-overvåkingene': ('tv-overvåking',),
'tv-overvåkinger': ('tv-overvåking',),
'tv-overvåkning': ('tv-overvåkning',),
'tv-overvåkninga': ('tv-overvåkning',),
'tv-overvåkningen': ('tv-overvåkning',),
'tv-overvåkningene': ('tv-overvåkning',),
'tv-overvåkninger': ('tv-overvåkning',),
'tv-program': ('tv-program',),
'tv-programma': ('tv-program',),
'tv-programmene': ('tv-program',),
'tv-programmer': ('tv-program',),
'tv-programmet': ('tv-program',),
'tv-skjerm': ('tv-skjerm',),
'tv-skjermen': ('tv-skjerm',),
'tv-skjermene': ('tv-skjerm',),
'tv-skjermer': ('tv-skjerm',),
'tv-vert': ('tv-vert',),
'tv-verten': ('tv-vert',),
'tv-vertene': ('tv-vert',),
'tv-verter': ('tv-vert',),
'tv-vertinna': ('tv-vertinne',),
'tv-vertinne': ('tv-vertinne',),
'tv-vertinnen': ('tv-vertinne',),
'tv-vertinnene': ('tv-vertinne',),
'tv-vertinner': ('tv-vertinne',),
'tvang': ('tvang',),
'tvangen': ('tvang',),
'tvangene': ('tvang',),
'tvanger': ('tvang',),
'tvangsakkord': ('tvangsakkord',),
'tvangsakkorden': ('tvangsakkord',),
'tvangsakkordene': ('tvangsakkord',),
'tvangsakkorder': ('tvangsakkord',),
'tvangsarbeid': ('tvangsarbeid',),
'tvangsarbeida': ('tvangsarbeid',),
'tvangsarbeidene': ('tvangsarbeid',),
'tvangsarbeider': ('tvangsarbeid',),
'tvangsarbeidet': ('tvangsarbeid',),
'tvangsauksjon': ('tvangsauksjon',),
'tvangsauksjonen': ('tvangsauksjon',),
'tvangsauksjonene': ('tvangsauksjon',),
'tvangsauksjoner': ('tvangsauksjon',),
'tvangsforestilling': ('tvangsforestilling',),
'tvangsforestillinga': ('tvangsforestilling',),
'tvangsforestillingen': ('tvangsforestilling',),
'tvangsforestillingene': ('tvangsforestilling',),
'tvangsforestillinger': ('tvangsforestilling',),
'tvangsfullbyrdelse': ('tvangsfullbyrdelse',),
'tvangsfullbyrdelsen': ('tvangsfullbyrdelse',),
'tvangsfullbyrdelsene': ('tvangsfullbyrdelse',),
'tvangsfullbyrdelser': ('tvangsfullbyrdelse',),
'tvangsfullbyrding': ('tvangsfullbyrding',),
'tvangsfullbyrdinga': ('tvangsfullbyrding',),
'tvangsfullbyrdingen': ('tvangsfullbyrding',),
'tvangsfullbyrdingene': ('tvangsfullbyrding',),
'tvangsfullbyrdinger': ('tvangsfullbyrding',),
'tvangshandling': ('tvangshandling',),
'tvangshandlinga': ('tvangshandling',),
'tvangshandlingen': ('tvangshandling',),
'tvangshandlingene': ('tvangshandling',),
'tvangshandlinger': ('tvangshandling',),
'tvangsinnleggelse': ('tvangsinnleggelse',),
'tvangsinnleggelsen': ('tvangsinnleggelse',),
'tvangsinnleggelsene': ('tvangsinnleggelse',),
'tvangsinnleggelser': ('tvangsinnleggelse',),
'tvangskartell': ('tvangskartell',),
'tvangskartella': ('tvangskartell',),
'tvangskartellene': ('tvangskartell',),
'tvangskarteller': ('tvangskartell',),
'tvangskartellet': ('tvangskartell',),
'tvangslån': ('tvangslån',),
'tvangslåna': ('tvangslån',),
'tvangslånene': ('tvangslån',),
'tvangslånet': ('tvangslån',),
'tvangsmulkt': ('tvangsmulkt',),
'tvangsmulkta': ('tvangsmulkt',),
'tvangsmulkten': ('tvangsmulkt',),
'tvangsmulktene': ('tvangsmulkt',),
'tvangsmulkter': ('tvangsmulkt',),
'tvangsneurose': ('tvangsneurose',),
'tvangsneurosen': ('tvangsneurose',),
'tvangsneurosene': ('tvangsneurose',),
'tvangsneuroser': ('tvangsneurose',),
'tvangsnevrose': ('tvangsnevrose',),
'tvangsnevrosen': ('tvangsnevrose',),
'tvangsnevrosene': ('tvangsnevrose',),
'tvangsnevroser': ('tvangsnevrose',),
'tvangssparing': ('tvangssparing',),
'tvangssparinga': ('tvangssparing',),
'tvangssparingen': ('tvangssparing',),
'tvangssparingene': ('tvangssparing',),
'tvangssparinger': ('tvangssparing',),
'tvangstanke': ('tvangstanke',),
'tvangstanken': ('tvangstanke',),
'tvangstankene': ('tvangstanke',),
'tvangstanker': ('tvangstanke',),
'tvangstrøya': ('tvangstrøye',),
'tvangstrøye': ('tvangstrøye',),
'tvangstrøyen': ('tvangstrøye',),
'tvangstrøyene': ('tvangstrøye',),
'tvangstrøyer': ('tvangstrøye',),
'tvara': ('tvare',),
'tvare': ('tvare',),
'tvaren': ('tvare',),
'tvarene': ('tvare',),
'tvarer': ('tvare',),
'tvebitt': ('tvebitt',),
'tvebitta': ('tvebitt',),
'tvebittene': ('tvebitt',),
'tvebittet': ('tvebitt',),
'tveblad': ('tveblad',),
'tveblada': ('tveblad',),
'tvebladene': ('tveblad',),
'tveblader': ('tveblad',),
'tvebladet': ('tveblad',),
'tvedrakt': ('tvedrakt',),
'tvedrakten': ('tvedrakt',),
'tvedraktene': ('tvedrakt',),
'tvedrakter': ('tvedrakt',),
'tvekamp': ('tvekamp',),
'tvekampen': ('tvekamp',),
'tvekampene': ('tvekamp',),
'tvekamper': ('tvekamp',),
'tvelyd': ('tvelyd',),
'tvelyden': ('tvelyd',),
'tvelydene': ('tvelyd',),
'tvelyder': ('tvelyd',),
'tverke': ('tverke',),
'tverrbjelke': ('tverrbjelke',),
'tverrbjelken': ('tverrbjelke',),
'tverrbjelkene': ('tverrbjelke',),
'tverrbjelker': ('tverrbjelke',),
'tverrdal': ('tverrdal',),
'tverrdalen': ('tverrdal',),
'tverrdalene': ('tverrdal',),
'tverrdaler': ('tverrdal',),
'tverrdriver': ('tverrdriver',),
'tverrdrivere': ('tverrdriver',),
'tverrdriveren': ('tverrdriver',),
'tverrdriverer': ('tverrdriver',),
'tverrdriverne': ('tverrdriver',),
'tverra': ('tverre',),
'tverre': ('tverre',),
'tverren': ('tverre',),
'tverrene': ('tverre',),
'tverrer': ('tverre',),
'tverrfløyta': ('tverrfløyte',),
'tverrfløyte': ('tverrfløyte',),
'tverrfløyten': ('tverrfløyte',),
'tverrfløytene': ('tverrfløyte',),
'tverrfløyter': ('tverrfløyte',),
'tverrgata': ('tverrgate',),
'tverrgate': ('tverrgate',),
'tverrgaten': ('tverrgate',),
'tverrgatene': ('tverrgate',),
'tverrgater': ('tverrgate',),
'tverrkast': ('tverrkast',),
'tverrkasta': ('tverrkast',),
'tverrkastene': ('tverrkast',),
'tverrkastet': ('tverrkast',),
'tverrligger': ('tverrligger',),
'tverrliggere': ('tverrligger',),
'tverrliggeren': ('tverrligger',),
'tverrliggerer': ('tverrligger',),
'tverrliggerne': ('tverrligger',),
'tverrmål': ('tverrmål',),
'tverrmåla': ('tverrmål',),
'tverrmålene': ('tverrmål',),
'tverrmålet': ('tverrmål',),
'tverrpomp': ('tverrpomp',),
'tverrpompen': ('tverrpomp',),
'tverrpompene': ('tverrpomp',),
'tverrpomper': ('tverrpomp',),
'tverrskip': ('tverrskip',),
'tverrskipa': ('tverrskip',),
'tverrskipene': ('tverrskip',),
'tverrskipet': ('tverrskip',),
'tverrsnitt': ('tverrsnitt',),
'tverrsnitta': ('tverrsnitt',),
'tverrsnittene': ('tverrsnitt',),
'tverrsnittet': ('tverrsnitt',),
'tverrsum': ('tverrsum',),
'tverrsummen': ('tverrsum',),
'tverrsummene': ('tverrsum',),
'tverrsummer': ('tverrsum',),
'tverrved': ('tverrved',),
'tverrveden': ('tverrved',),
'tverrvedene': ('tverrved',),
'tverrveder': ('tverrved',),
'tversoversløyfa': ('tversoversløyfe',),
'tversoversløyfe': ('tversoversløyfe',),
'tversoversløyfen': ('tversoversløyfe',),
'tversoversløyfene': ('tversoversløyfe',),
'tversoversløyfer': ('tversoversløyfe',),
'tvetann': ('tvetann',),
'tvetanna': ('tvetann',),
'tvetannen': ('tvetann',),
'tvetannene': ('tvetann',),
'tvetanner': ('tvetann',),
'tvett': ('tvett',),
'tvetten': ('tvett',),
'tvettene': ('tvett',),
'tvetter': ('tvett',),
'tvibrent': ('tvibrent',),
'tvil': ('tvil',),
'tvilen': ('tvil',),
'tvilene': ('tvil',),
'tviler': ('tviler',),
'tvilere': ('tviler',),
'tvileren': ('tviler',),
'tvilerer': ('tviler',),
'tvilerne': ('tviler',),
'tvill': ('tvill',),
'tvillen': ('tvill',),
'tvillene': ('tvill',),
'tviller': ('tvill',),
'tvilling': ('tvilling',),
'tvillingen': ('tvilling',),
'tvillingene': ('tvilling',),
'tvillinger': ('tvilling',),
'tvillingbror': ('tvillingbror',),
'tvillingbroren': ('tvillingbror',),
'tvillingbrødre': ('tvillingbror',),
'tvillingbrødrene': ('tvillingbror',),
'tvillinghjul': ('tvillinghjul',),
'tvillinghjula': ('tvillinghjul',),
'tvillinghjulene': ('tvillinghjul',),
'tvillinghjulet': ('tvillinghjul',),
'tvillingpar': ('tvillingpar',),
'tvillingpara': ('tvillingpar',),
'tvillingparene': ('tvillingpar',),
'tvillingparet': ('tvillingpar',),
'tvillingrika': ('tvillingrike',),
'tvillingrike': ('tvillingrike',),
'tvillingrikene': ('tvillingrike',),
'tvillingriker': ('tvillingrike',),
'tvillingriket': ('tvillingrike',),
'tvillingsøster': ('tvillingsøster',),
'tvillingsøstera': ('tvillingsøster',),
'tvillingsøsteren': ('tvillingsøster',),
'tvillingsøstre': ('tvillingsøster',),
'tvillingsøstrene': ('tvillingsøster',),
'tvillingsøstrer': ('tvillingsøster',),
'tvilstilfella': ('tvilstilfelle',),
'tvilstilfelle': ('tvilstilfelle',),
'tvilstilfellene': ('tvilstilfelle',),
'tvilstilfeller': ('tvilstilfelle',),
'tvilstilfellet': ('tvilstilfelle',),
'tvinga': ('tvinge',),
'tvinge': ('tvinge',),
'tvingen': ('tvinge',),
'tvingene': ('tvinge',),
'tvinger': ('tvinge',),
'tvinn': ('tvinn',),
'tvinna': ('tvinn',),
'tvinnene': ('tvinn',),
'tvinnet': ('tvinn',),
'tvinning': ('tvinning',),
'tvinninga': ('tvinning',),
'tvinningen': ('tvinning',),
'tvinningene': ('tvinning',),
'tvinninger': ('tvinning',),
'tvistemål': ('tvistemål',),
'tvistemåla': ('tvistemål',),
'tvistemålene': ('tvistemål',),
'tvistemålet': ('tvistemål',),
'tvistepunkt': ('tvistepunkt',),
'tvistepunkta': ('tvistepunkt',),
'tvistepunktene': ('tvistepunkt',),
'tvistepunkter': ('tvistepunkt',),
'tvistepunktet': ('tvistepunkt',),
'tvistighet': ('tvistighet',),
'tvistigheta': ('tvistighet',),
'tvistigheten': ('tvistighet',),
'tvistighetene': ('tvistighet',),
'tvistigheter': ('tvistighet',),
'tvisyn': ('tvisyn',),
'tvisyna': ('tvisyn',),
'tvisynene': ('tvisyn',),
'tvisynet': ('tvisyn',),
'tvitann': ('tvitann',),
'tvitanna': ('tvitann',),
'tvitannen': ('tvitann',),
'tvitannene': ('tvitann',),
'tvitanner': ('tvitann',),
'tweed': ('tweed',),
'tweeden': ('tweed',),
'tweedene': ('tweed',),
'tweeder': ('tweed',),
'tweeddress': ('tweeddress',),
'tweeddressen': ('tweeddress',),
'tweeddressene': ('tweeddress',),
'tweeddresser': ('tweeddress',),
'tweedjakka': ('tweedjakke',),
'tweedjakke': ('tweedjakke',),
'tweedjakken': ('tweedjakke',),
'tweedjakkene': ('tweedjakke',),
'tweedjakker': ('tweedjakke',),
'twinsett': ('twinsett',),
'twinsetta': ('twinsett',),
'twinsettene': ('twinsett',),
'twinsettet': ('twinsett',),
'twist': ('twist',),
'twisten': ('twist',),
'twistene': ('twist',),
'twister': ('twist',),
'twister': ('twister',),
'twistere': ('twister',),
'twisteren': ('twister',),
'twisterer': ('twister',),
'twisterne': ('twister',),
'twostep': ('twostep',),
'twostepen': ('twostep',),
'twostepene': ('twostep',),
'twosteper': ('twostep',),
'tyder': ('tyder',),
'tydere': ('tyder',),
'tyderen': ('tyder',),
'tyderer': ('tyder',),
'tyderne': ('tyder',),
'tydning': ('tydning',),
'tydninga': ('tydning',),
'tydningen': ('tydning',),
'tydningene': ('tydning',),
'tydninger': ('tydning',),
'tyenda': ('tyende',),
'tyende': ('tyende',),
'tyendene': ('tyende',),
'tyender': ('tyende',),
'tyendet': ('tyende',),
'tyfoidfeber': ('tyfoidfeber',),
'tyfoidfebere': ('tyfoidfeber',),
'tyfoidfeberen': ('tyfoidfeber',),
'tyfoidfeberne': ('tyfoidfeber',),
'tyfoidfebre': ('tyfoidfeber',),
'tyfoidfebrene': ('tyfoidfeber',),
'tyfoidfebrer': ('tyfoidfeber',),
'tyfon': ('tyfon',),
'tyfonen': ('tyfon',),
'tyfonene': ('tyfon',),
'tyfoner': ('tyfon',),
'tyfus': ('tyfus',),
'tyfusen': ('tyfus',),
'tyfusene': ('tyfus',),
'tyfuser': ('tyfus',),
'tygga': ('tygge',),
'tygge': ('tygge',),
'tyggen': ('tygge',),
'tyggene': ('tygge',),
'tygger': ('tygge',),
'tyggebevegelse': ('tyggebevegelse',),
'tyggebevegelsen': ('tyggebevegelse',),
'tyggebevegelsene': ('tyggebevegelse',),
'tyggebevegelser': ('tyggebevegelse',),
'tyggeflata': ('tyggeflate',),
'tyggeflate': ('tyggeflate',),
'tyggeflaten': ('tyggeflate',),
'tyggeflatene': ('tyggeflate',),
'tyggeflater': ('tyggeflate',),
'tyggegummi': ('tyggegummi',),
'tyggegummien': ('tyggegummi',),
'tyggegummiene': ('tyggegummi',),
'tyggegummier': ('tyggegummi',),
'tyggemuskel': ('tyggemuskel',),
'tyggemuskelen': ('tyggemuskel',),
'tyggemusklene': ('tyggemuskel',),
'tyggemuskler': ('tyggemuskel',),
'tykkas': ('tykkas',),
'tykkasen': ('tykkas',),
'tykkasene': ('tykkas',),
'tykkaser': ('tykkas',),
'tykka': ('tykke',),
'tykke': ('tykke',),
'tykken': ('tykke',),
'tykkene': ('tykke',),
'tykker': ('tykke',),
'tykket': ('tykke',),
'tykka': ('tykke',),
'tykke': ('tykke',),
'tykkene': ('tykke',),
'tykker': ('tykke',),
'tykket': ('tykke',),
'tykkelse': ('tykkelse',),
'tykkelsen': ('tykkelse',),
'tykkelsene': ('tykkelse',),
'tykkelser': ('tykkelse',),
'tykklegg': ('tykklegg',),
'tykkleggen': ('tykklegg',),
'tykkleggene': ('tykklegg',),
'tykklegger': ('tykklegg',),
'tykkmelk': ('tykkmelk',),
'tykkmelka': ('tykkmelk',),
'tykkmelken': ('tykkmelk',),
'tykkmelkene': ('tykkmelk',),
'tykkmelker': ('tykkmelk',),
'tykkmjølk': ('tykkmjølk',),
'tykkmjølka': ('tykkmjølk',),
'tykkmjølken': ('tykkmjølk',),
'tykkmjølkene': ('tykkmjølk',),
'tykkmjølker': ('tykkmjølk',),
'tykksak': ('tykksak',),
'tykksaken': ('tykksak',),
'tykksakene': ('tykksak',),
'tykksaker': ('tykksak',),
'tykktarm': ('tykktarm',),
'tykktarmen': ('tykktarm',),
'tykktarmene': ('tykktarm',),
'tykktarmer': ('tykktarm',),
'tykning': ('tykning',),
'tykninga': ('tykning',),
'tykningen': ('tykning',),
'tykningene': ('tykning',),
'tykninger': ('tykning',),
'tylft': ('tylft',),
'tylfta': ('tylft',),
'tylften': ('tylft',),
'tylftene': ('tylft',),
'tylfter': ('tylft',),
'tyll': ('tyll',),
'tylla': ('tyll',),
'tyllen': ('tyll',),
'tyllene': ('tyll',),
'tyller': ('tyll',),
'tyllet': ('tyll',),
'tyllgardin': ('tyllgardin',),
'tyllgardina': ('tyllgardin',),
'tyllgardinen': ('tyllgardin',),
'tyllgardinene': ('tyllgardin',),
'tyllgardiner': ('tyllgardin',),
'tyllgardinet': ('tyllgardin',),
'tyllkjole': ('tyllkjole',),
'tyllkjolen': ('tyllkjole',),
'tyllkjolene': ('tyllkjole',),
'tyllkjoler': ('tyllkjole',),
'tyngd': ('tyngd',),
'tyngda': ('tyngd',),
'tyngden': ('tyngd',),
'tyngdene': ('tyngd',),
'tyngder': ('tyngd',),
'tyngde': ('tyngde',),
'tyngden': ('tyngde',),
'tyngdene': ('tyngde',),
'tyngder': ('tyngde',),
'tyngdeakselerasjon': ('tyngdeakselerasjon',),
'tyngdeakselerasjonen': ('tyngdeakselerasjon',),
'tyngdeakselerasjonene': ('tyngdeakselerasjon',),
'tyngdeakselerasjoner': ('tyngdeakselerasjon',),
'tyngdekraft': ('tyngdekraft',),
'tyngdekrafta': ('tyngdekraft',),
'tyngdekraften': ('tyngdekraft',),
'tyngdekreftene': ('tyngdekraft',),
'tyngdekrefter': ('tyngdekraft',),
'tyngdelov': ('tyngdelov',),
'tyngdeloven': ('tyngdelov',),
'tyngdelovene': ('tyngdelov',),
'tyngdelover': ('tyngdelov',),
'tyngdepunkt': ('tyngdepunkt',),
'tyngdepunkta': ('tyngdepunkt',),
'tyngdepunktene': ('tyngdepunkt',),
'tyngdepunkter': ('tyngdepunkt',),
'tyngdepunktet': ('tyngdepunkt',),
'tyngsel': ('tyngsel',),
'tyngselen': ('tyngsel',),
'tyngsla': ('tyngsel',),
'tyngslene': ('tyngsel',),
'tyngsler': ('tyngsel',),
'tyngsla': ('tyngsle',),
'tyngsle': ('tyngsle',),
'tyngslen': ('tyngsle',),
'tyngslene': ('tyngsle',),
'tyngsler': ('tyngsle',),
'tynna': ('tynne',),
'tynne': ('tynne',),
'tynnen': ('tynne',),
'tynnene': ('tynne',),
'tynner': ('tynne',),
'tynna': ('tynne',),
'tynne': ('tynne',),
'tynnen': ('tynne',),
'tynnene': ('tynne',),
'tynner': ('tynne',),
'tynneband': ('tynneband',),
'tynnebanda': ('tynneband',),
'tynnebandene': ('tynneband',),
'tynnebandet': ('tynneband',),
'tynneband': ('tynneband',),
'tynnebanda': ('tynneband',),
'tynnebandene': ('tynneband',),
'tynnebandet': ('tynneband',),
'tynnehvelv': ('tynnehvelv',),
'tynnehvelva': ('tynnehvelv',),
'tynnehvelvene': ('tynnehvelv',),
'tynnehvelvet': ('tynnehvelv',),
'tynnehvelv': ('tynnehvelv',),
'tynnehvelva': ('tynnehvelv',),
'tynnehvelvene': ('tynnehvelv',),
'tynnehvelvet': ('tynnehvelv',),
'tynnehvelving': ('tynnehvelving',),
'tynnehvelvingen': ('tynnehvelving',),
'tynnehvelvingene': ('tynnehvelving',),
'tynnehvelvinger': ('tynnehvelving',),
'tynnehvelving': ('tynnehvelving',),
'tynnehvelvingen': ('tynnehvelving',),
'tynnehvelvingene': ('tynnehvelving',),
'tynnehvelvinger': ('tynnehvelving',),
'tynnekvelv': ('tynnekvelv',),
'tynnekvelva': ('tynnekvelv',),
'tynnekvelven': ('tynnekvelv',),
'tynnekvelvene': ('tynnekvelv',),
'tynnekvelver': ('tynnekvelv',),
'tynnekvelvet': ('tynnekvelv',),
'tynnekvelv': ('tynnekvelv',),
'tynnekvelva': ('tynnekvelv',),
'tynnekvelven': ('tynnekvelv',),
'tynnekvelvene': ('tynnekvelv',),
'tynnekvelver': ('tynnekvelv',),
'tynnekvelvet': ('tynnekvelv',),
'tynnekvelving': ('tynnekvelving',),
'tynnekvelvingen': ('tynnekvelving',),
'tynnekvelvingene': ('tynnekvelving',),
'tynnekvelvinger': ('tynnekvelving',),
'tynnekvelving': ('tynnekvelving',),
'tynnekvelvingen': ('tynnekvelving',),
'tynnekvelvingene': ('tynnekvelving',),
'tynnekvelvinger': ('tynnekvelving',),
'tynnemål': ('tynnemål',),
'tynnemåla': ('tynnemål',),
'tynnemålene': ('tynnemål',),
'tynnemålet': ('tynnemål',),
'tynnemål': ('tynnemål',),
'tynnemåla': ('tynnemål',),
'tynnemålene': ('tynnemål',),
'tynnemålet': ('tynnemål',),
'tynner': ('tynner',),
'tynnere': ('tynner',),
'tynneren': ('tynner',),
'tynnerer': ('tynner',),
'tynnerne': ('tynner',),
'tynnestav': ('tynnestav',),
'tynnestaven': ('tynnestav',),
'tynnestavene': ('tynnestav',),
'tynnestaver': ('tynnestav',),
'tynnestav': ('tynnestav',),
'tynnestaven': ('tynnestav',),
'tynnestavene': ('tynnestav',),
'tynnestaver': ('tynnestav',),
'tynnetapp': ('tynnetapp',),
'tynnetappen': ('tynnetapp',),
'tynnetappene': ('tynnetapp',),
'tynnetapper': ('tynnetapp',),
'tynnetapp': ('tynnetapp',),
'tynnetappen': ('tynnetapp',),
'tynnetappene': ('tynnetapp',),
'tynnetapper': ('tynnetapp',),
'tynning': ('tynning',),
'tynninga': ('tynning',),
'tynningen': ('tynning',),
'tynningene': ('tynning',),
'tynninger': ('tynning',),
'tynningshogst': ('tynningshogst',),
'tynningshogsten': ('tynningshogst',),
'tynningshogstene': ('tynningshogst',),
'tynningshogster': ('tynningshogst',),
'tynningshugst': ('tynningshugst',),
'tynningshugsten': ('tynningshugst',),
'tynningshugstene': ('tynningshugst',),
'tynningshugster': ('tynningshugst',),
'tynningsmiddel': ('tynningsmiddel',),
'tynningsmiddelet': ('tynningsmiddel',),
'tynningsmidla': ('tynningsmiddel',),
'tynningsmidlene': ('tynningsmiddel',),
'tynningsmidler': ('tynningsmiddel',),
'tynningsmidlet': ('tynningsmiddel',),
'tynntarm': ('tynntarm',),
'tynntarmen': ('tynntarm',),
'tynntarmene': ('tynntarm',),
'tynntarmer': ('tynntarm',),
'type': ('type',),
'typen': ('type',),
'typene': ('type',),
'typer': ('type',),
'typehus': ('typehus',),
'typehusa': ('typehus',),
'typehusene': ('typehus',),
'typehuset': ('typehus',),
'typetegning': ('typetegning',),
'typetegninga': ('typetegning',),
'typetegningen': ('typetegning',),
'typetegningene': ('typetegning',),
'typetegninger': ('typetegning',),
'typograf': ('typograf',),
'typografen': ('typograf',),
'typografene': ('typograf',),
'typografer': ('typograf',),
'typografi': ('typografi',),
'typografien': ('typografi',),
'typografiene': ('typografi',),
'typografier': ('typografi',),
'typolog': ('typolog',),
'typologen': ('typolog',),
'typologene': ('typolog',),
'typologer': ('typolog',),
'typologi': ('typologi',),
'typologien': ('typologi',),
'typologiene': ('typologi',),
'typologier': ('typologi',),
'typene': ('typus',),
'typer': ('typus',),
'typus': ('typus',),
'typusen': ('typus',),
'tyr': ('tyr',),
'tyren': ('tyr',),
'tyrene': ('tyr',),
'tyrer': ('tyr',),
'tyrann': ('tyrann',),
'tyrannen': ('tyrann',),
'tyrannene': ('tyrann',),
'tyranner': ('tyrann',),
'tyranni': ('tyranni',),
'tyrannia': ('tyranni',),
'tyranniene': ('tyranni',),
'tyrannier': ('tyranni',),
'tyranniet': ('tyranni',),
'tyrannosaur': ('tyrannosaur',),
'tyrannosauren': ('tyrannosaur',),
'tyrannosaurene': ('tyrannosaur',),
'tyrannosaurer': ('tyrannosaur',),
'tyrannosaurene': ('tyrannosaurus',),
'tyrannosaurer': ('tyrannosaurus',),
'tyrannosauriene': ('tyrannosaurus',),
'tyrannosaurier': ('tyrannosaurus',),
'tyrannosaurus': ('tyrannosaurus',),
'tyrannosaurusen': ('tyrannosaurus',),
'tyrefekter': ('tyrefekter',),
'tyrefektere': ('tyrefekter',),
'tyrefekteren': ('tyrefekter',),
'tyrefekterer': ('tyrefekter',),
'tyrefekterne': ('tyrefekter',),
'tyrefekting': ('tyrefekting',),
'tyrefektinga': ('tyrefekting',),
'tyrefektingen': ('tyrefekting',),
'tyrefektingene': ('tyrefekting',),
'tyrefektinger': ('tyrefekting',),
'tyrefektning': ('tyrefektning',),
'tyrefektninga': ('tyrefektning',),
'tyrefektningen': ('tyrefektning',),
'tyrefektningene': ('tyrefektning',),
'tyrefektninger': ('tyrefektning',),
'tyrenakke': ('tyrenakke',),
'tyrenakken': ('tyrenakke',),
'tyrenakkene': ('tyrenakke',),
'tyrenakker': ('tyrenakke',),
'tyrhjelm': ('tyrhjelm',),
'tyrhjelmen': ('tyrhjelm',),
'tyrhjelmene': ('tyrhjelm',),
'tyrhjelmer': ('tyrhjelm',),
'tyri': ('tyri',),
'tyrien': ('tyri',),
'tyriene': ('tyri',),
'tyrier': ('tyri',),
'tyriflis': ('tyriflis',),
'tyriflisa': ('tyriflis',),
'tyriflisen': ('tyriflis',),
'tyriflisene': ('tyriflis',),
'tyrifliser': ('tyriflis',),
'tyrihjelm': ('tyrihjelm',),
'tyrihjelmen': ('tyrihjelm',),
'tyrihjelmene': ('tyrihjelm',),
'tyrihjelmer': ('tyrihjelm',),
'tyrirot': ('tyrirot',),
'tyrirota': ('tyrirot',),
'tyriroten': ('tyrirot',),
'tyrirøttene': ('tyrirot',),
'tyrirøtter': ('tyrirot',),
'tyrispik': ('tyrispik',),
'tyrispika': ('tyrispik',),
'tyrispiken': ('tyrispik',),
'tyrispikene': ('tyrispik',),
'tyrispiker': ('tyrispik',),
'tyristikka': ('tyristikke',),
'tyristikke': ('tyristikke',),
'tyristikken': ('tyristikke',),
'tyristikkene': ('tyristikke',),
'tyristikker': ('tyristikke',),
'tyrk': ('tyrk',),
'tyrken': ('tyrk',),
'tyrkene': ('tyrk',),
'tyrker': ('tyrk',),
'tyrker': ('tyrker',),
'tyrkere': ('tyrker',),
'tyrkeren': ('tyrker',),
'tyrkerer': ('tyrker',),
'tyrkerne': ('tyrker',),
'tyrkerdua': ('tyrkerdue',),
'tyrkerdue': ('tyrkerdue',),
'tyrkerduen': ('tyrkerdue',),
'tyrkerduene': ('tyrkerdue',),
'tyrkerduer': ('tyrkerdue',),
'tyrkerlua': ('tyrkerlue',),
'tyrkerlue': ('tyrkerlue',),
'tyrkerluen': ('tyrkerlue',),
'tyrkerluene': ('tyrkerlue',),
'tyrkerluer': ('tyrkerlue',),
'tyrkerluva': ('tyrkerluve',),
'tyrkerluve': ('tyrkerluve',),
'tyrkerluven': ('tyrkerluve',),
'tyrkerluvene': ('tyrkerluve',),
'tyrkerluver': ('tyrkerluve',),
'tyrkertro': ('tyrkertro',),
'tyrkertroa': ('tyrkertro',),
'tyrkertroen': ('tyrkertro',),
'tyrkertroene': ('tyrkertro',),
'tyrkertroer': ('tyrkertro',),
'tyrkertru': ('tyrkertru',),
'tyrkertrua': ('tyrkertru',),
'tyrkertruen': ('tyrkertru',),
'tyrkertruene': ('tyrkertru',),
'tyrkertruer': ('tyrkertru',),
'tyrkisk': ('tyrkisk',),
'tyrkisken': ('tyrkisk',),
'tyrkiskene': ('tyrkisk',),
'tyrkisker': ('tyrkisk',),
'tyroksin': ('tyroksin',),
'tyroksina': ('tyroksin',),
'tyroksinene': ('tyroksin',),
'tyroksinet': ('tyroksin',),
'tyroler': ('tyroler',),
'tyrolere': ('tyroler',),
'tyroleren': ('tyroler',),
'tyrolerer': ('tyroler',),
'tyrolerne': ('tyroler',),
'tyrolerhatt': ('tyrolerhatt',),
'tyrolerhatten': ('tyrolerhatt',),
'tyrolerhattene': ('tyrolerhatt',),
'tyrolerhatter': ('tyrolerhatt',),
'tysbast': ('tysbast',),
'tysbasten': ('tysbast',),
'tysbastene': ('tysbast',),
'tysbaster': ('tysbast',),
'tysk': ('tysk',),
'tysken': ('tysk',),
'tyskene': ('tysk',),
'tysker': ('tysk',),
'tysker': ('tysker',),
'tyskere': ('tysker',),
'tyskeren': ('tysker',),
'tyskerer': ('tysker',),
'tyskerne': ('tysker',),
'tyskerbrakka': ('tyskerbrakke',),
'tyskerbrakke': ('tyskerbrakke',),
'tyskerbrakken': ('tyskerbrakke',),
'tyskerbrakkene': ('tyskerbrakke',),
'tyskerbrakker': ('tyskerbrakke',),
'tyskertøs': ('tyskertøs',),
'tyskertøsa': ('tyskertøs',),
'tyskertøsen': ('tyskertøs',),
'tyskertøsene': ('tyskertøs',),
'tyskertøser': ('tyskertøs',),
'tyskhet': ('tyskhet',),
'tyskheta': ('tyskhet',),
'tyskheten': ('tyskhet',),
'tyskhetene': ('tyskhet',),
'tyskheter': ('tyskhet',),
'tyster': ('tyster',),
'tystere': ('tyster',),
'tysteren': ('tyster',),
'tysterer': ('tyster',),
'tysterne': ('tyster',),
'tyta': ('tyte',),
'tyte': ('tyte',),
'tyten': ('tyte',),
'tytene': ('tyte',),
'tyter': ('tyte',),
'tyttebær': ('tyttebær',),
'tyttebæra': ('tyttebær',),
'tyttebærene': ('tyttebær',),
'tyttebæret': ('tyttebær',),
'tyttebær': ('tyttebær',),
'tyttebæra': ('tyttebær',),
'tyttebærene': ('tyttebær',),
'tyttebæret': ('tyttebær',),
'tyv': ('tyv',),
'tyven': ('tyv',),
'tyvene': ('tyv',),
'tyver': ('tyv',),
'tyved': ('tyved',),
'tyveden': ('tyved',),
'tyvedene': ('tyved',),
'tyveder': ('tyved',),
'tyvegods': ('tyvegods',),
'tyvegodsa': ('tyvegods',),
'tyvegodsene': ('tyvegods',),
'tyvegodset': ('tyvegods',),
'tyveradd': ('tyveradd',),
'tyveradden': ('tyveradd',),
'tyveraddene': ('tyveradd',),
'tyveradder': ('tyveradd',),
'tyveri': ('tyveri',),
'tyveria': ('tyveri',),
'tyveriene': ('tyveri',),
'tyverier': ('tyveri',),
'tyveriet': ('tyveri',),
'tyverialarm': ('tyverialarm',),
'tyverialarmen': ('tyverialarm',),
'tyverialarmene': ('tyverialarm',),
'tyverialarmer': ('tyverialarm',),
'tyveriforsikring': ('tyveriforsikring',),
'tyveriforsikringa': ('tyveriforsikring',),
'tyveriforsikringen': ('tyveriforsikring',),
'tyveriforsikringene': ('tyveriforsikring',),
'tyveriforsikringer': ('tyveriforsikring',),
'tyvfiska': ('tyvfiske',),
'tyvfiske': ('tyvfiske',),
'tyvfiskene': ('tyvfiske',),
'tyvfisker': ('tyvfiske',),
'tyvfisket': ('tyvfiske',),
'tyvfisker': ('tyvfisker',),
'tyvfiskere': ('tyvfisker',),
'tyvfiskeren': ('tyvfisker',),
'tyvfiskerer': ('tyvfisker',),
'tyvfiskerne': ('tyvfisker',),
'tyvjo': ('tyvjo',),
'tyvjoen': ('tyvjo',),
'tyvjoene': ('tyvjo',),
'tyvjoer': ('tyvjo',),
'tyvperm': ('tyvperm',),
'tyvpermen': ('tyvperm',),
'tyvpermene': ('tyvperm',),
'tyvpermer': ('tyvperm',),
'tå': ('tå',),
'tåa': ('tå',),
'tåen': ('tå',),
'tær': ('tå',),
'tærne': ('tå',),
'tåballe': ('tåballe',),
'tåballen': ('tåballe',),
'tåballene': ('tåballe',),
'tåballer': ('tåballe',),
'tåbinding': ('tåbinding',),
'tåbindinga': ('tåbinding',),
'tåbindingen': ('tåbinding',),
'tåbindingene': ('tåbinding',),
'tåbindinger': ('tåbinding',),
'tåg': ('tåg',),
'tåga': ('tåg',),
'tågen': ('tåg',),
'tægene': ('tåg',),
'tæger': ('tåg',),
'tågang': ('tågang',),
'tågangen': ('tågang',),
'tågangene': ('tågang',),
'tåganger': ('tågang',),
'tågarbeid': ('tågarbeid',),
'tågarbeida': ('tågarbeid',),
'tågarbeidene': ('tågarbeid',),
'tågarbeider': ('tågarbeid',),
'tågarbeidet': ('tågarbeid',),
'tågebær': ('tågebær',),
'tågebæra': ('tågebær',),
'tågebærene': ('tågebær',),
'tågebæret': ('tågebær',),
'tågebær': ('tågebær',),
'tågebæra': ('tågebær',),
'tågebærene': ('tågebær',),
'tågebæret': ('tågebær',),
'tågjenger': ('tågjenger',),
'tågjengere': ('tågjenger',),
'tågjengeren': ('tågjenger',),
'tågjengerer': ('tågjenger',),
'tågjengerne': ('tågjenger',),
'tåhetta': ('tåhette',),
'tåhette': ('tåhette',),
'tåhetten': ('tåhette',),
'tåhettene': ('tåhette',),
'tåhetter': ('tåhette',),
'tåheving': ('tåheving',),
'tåhevinga': ('tåheving',),
'tåhevingen': ('tåheving',),
'tåhevingene': ('tåheving',),
'tåhevinger': ('tåheving',),
'tåhevning': ('tåhevning',),
'tåhevninga': ('tåhevning',),
'tåhevningen': ('tåhevning',),
'tåhevningene': ('tåhevning',),
'tåhevninger': ('tåhevning',),
'tåjern': ('tåjern',),
'tåjerna': ('tåjern',),
'tåjernene': ('tåjern',),
'tåjernet': ('tåjern',),
'tåkappa': ('tåkappe',),
'tåkappe': ('tåkappe',),
'tåkappen': ('tåkappe',),
'tåkappene': ('tåkappe',),
'tåkapper': ('tåkappe',),
'tåka': ('tåke',),
'tåke': ('tåke',),
'tåken': ('tåke',),
'tåkene': ('tåke',),
'tåker': ('tåke',),
'tåkebanke': ('tåkebanke',),
'tåkebanken': ('tåkebanke',),
'tåkebankene': ('tåkebanke',),
'tåkebanker': ('tåkebanke',),
'tåkedis': ('tåkedis',),
'tåkedisen': ('tåkedis',),
'tåkedisene': ('tåkedis',),
'tåkediser': ('tåkedis',),
'tåkedott': ('tåkedott',),
'tåkedotten': ('tåkedott',),
'tåkedottene': ('tåkedott',),
'tåkedotter': ('tåkedott',),
'tåkefelling': ('tåkefelling',),
'tåkefellinga': ('tåkefelling',),
'tåkefellingen': ('tåkefelling',),
'tåkefellingene': ('tåkefelling',),
'tåkefellinger': ('tåkefelling',),
'tåkefyrste': ('tåkefyrste',),
'tåkefyrsten': ('tåkefyrste',),
'tåkefyrstene': ('tåkefyrste',),
'tåkefyrster': ('tåkefyrste',),
'tåkelur': ('tåkelur',),
'tåkeluren': ('tåkelur',),
'tåkelurene': ('tåkelur',),
'tåkelurer': ('tåkelur',),
'tåkelykt': ('tåkelykt',),
'tåkelykta': ('tåkelykt',),
'tåkelykten': ('tåkelykt',),
'tåkelyktene': ('tåkelykt',),
'tåkelykter': ('tåkelykt',),
'tåkelys': ('tåkelys',),
'tåkelysa': ('tåkelys',),
'tåkelysene': ('tåkelys',),
'tåkelyset': ('tåkelys',),
'tåkeprat': ('tåkeprat',),
'tåkeprata': ('tåkeprat',),
'tåkepraten': ('tåkeprat',),
'tåkepratene': ('tåkeprat',),
'tåkeprater': ('tåkeprat',),
'tåkepratet': ('tåkeprat',),
'tåkerim': ('tåkerim',),
'tåkerima': ('tåkerim',),
'tåkerimen': ('tåkerim',),
'tåkerimene': ('tåkerim',),
'tåkerimer': ('tåkerim',),
'tåkerimet': ('tåkerim',),
'tåkesignal': ('tåkesignal',),
'tåkesignala': ('tåkesignal',),
'tåkesignalene': ('tåkesignal',),
'tåkesignaler': ('tåkesignal',),
'tåkesignalet': ('tåkesignal',),
'tåkesignalapparat': ('tåkesignalapparat',),
'tåkesignalapparata': ('tåkesignalapparat',),
'tåkesignalapparatene': ('tåkesignalapparat',),
'tåkesignalapparater': ('tåkesignalapparat',),
'tåkesignalapparatet': ('tåkesignalapparat',),
'tåkesky': ('tåkesky',),
'tåkeskya': ('tåkesky',),
'tåkeskyen': ('tåkesky',),
'tåkeskyene': ('tåkesky',),
'tåkeskyer': ('tåkesky',),
'tåkeslokking': ('tåkeslokking',),
'tåkeslokkinga': ('tåkeslokking',),
'tåkeslokkingen': ('tåkeslokking',),
'tåkeslokkingene': ('tåkeslokking',),
'tåkeslokkinger': ('tåkeslokking',),
'tåkeslukking': ('tåkeslukking',),
'tåkeslukkinga': ('tåkeslukking',),
'tåkeslukkingen': ('tåkeslukking',),
'tåkeslukkingene': ('tåkeslukking',),
'tåkeslukkinger': ('tåkeslukking',),
'tåkesløkking': ('tåkesløkking',),
'tåkesløkkinga': ('tåkesløkking',),
'tåkesløkkingen': ('tåkesløkking',),
'tåkesløkkingene': ('tåkesløkking',),
'tåkesløkkinger': ('tåkesløkking',),
'tåkeslør': ('tåkeslør',),
'tåkesløra': ('tåkeslør',),
'tåkeslørene': ('tåkeslør',),
'tåkesløret': ('tåkeslør',),
'tåkesprøyta': ('tåkesprøyte',),
'tåkesprøyte': ('tåkesprøyte',),
'tåkesprøyten': ('tåkesprøyte',),
'tåkesprøytene': ('tåkesprøyte',),
'tåkesprøyter': ('tåkesprøyte',),
'tåketale': ('tåketale',),
'tåketalen': ('tåketale',),
'tåketalene': ('tåketale',),
'tåketaler': ('tåketale',),
'tåketeppa': ('tåketeppe',),
'tåketeppe': ('tåketeppe',),
'tåketeppene': ('tåketeppe',),
'tåketepper': ('tåketeppe',),
'tåketeppet': ('tåketeppe',),
'tål': ('tål',),
'tålegrensa': ('tålegrense',),
'tålegrense': ('tålegrense',),
'tålegrensen': ('tålegrense',),
'tålegrensene': ('tålegrense',),
'tålegrenser': ('tålegrense',),
'tålmod': ('tålmod',),
'tålmoda': ('tålmod',),
'tålmodene': ('tålmod',),
'tålmodet': ('tålmod',),
'tålmodighet': ('tålmodighet',),
'tålmodigheta': ('tålmodighet',),
'tålmodigheten': ('tålmodighet',),
'tålmodighetene': ('tålmodighet',),
'tålmodigheter': ('tålmodighet',),
'tålmodighetsprøva': ('tålmodighetsprøve',),
'tålmodighetsprøve': ('tålmodighetsprøve',),
'tålmodighetsprøven': ('tålmodighetsprøve',),
'tålmodighetsprøvene': ('tålmodighetsprøve',),
'tålmodighetsprøver': ('tålmodighetsprøve',),
'tånegl': ('tånegl',),
'tåneglen': ('tånegl',),
'tåneglene': ('tånegl',),
'tånegler': ('tånegl',),
'tåpe': ('tåpe',),
'tåpen': ('tåpe',),
'tåpene': ('tåpe',),
'tåper': ('tåpe',),
'tåpelighet': ('tåpelighet',),
'tåpeligheta': ('tåpelighet',),
'tåpeligheten': ('tåpelighet',),
'tåpelighetene': ('tåpelighet',),
'tåpeligheter': ('tåpelighet',),
'tår': ('tår',),
'tåren': ('tår',),
'tårene': ('tår',),
'tårer': ('tår',),
'tår': ('tår',),
'tåra': ('tår',),
'tåren': ('tår',),
'tårene': ('tår',),
'tårer': ('tår',),
'tåra': ('tåre',),
'tåre': ('tåre',),
'tåren': ('tåre',),
'tårene': ('tåre',),
'tårer': ('tåre',),
'tåreflom': ('tåreflom',),
'tåreflommen': ('tåreflom',),
'tåreflommene': ('tåreflom',),
'tåreflommer': ('tåreflom',),
'tåregass': ('tåregass',),
'tåregassen': ('tåregass',),
'tåregassene': ('tåregass',),
'tåregasser': ('tåregass',),
'tåregras': ('tåregras',),
'tåregrasa': ('tåregras',),
'tåregrasene': ('tåregras',),
'tåregraset': ('tåregras',),
'tåregress': ('tåregress',),
'tåregressa': ('tåregress',),
'tåregressene': ('tåregress',),
'tåregresset': ('tåregress',),
'tårekanal': ('tårekanal',),
'tårekanalen': ('tårekanal',),
'tårekanalene': ('tårekanal',),
'tårekanaler': ('tårekanal',),
'tårekjertel': ('tårekjertel',),
'tårekjertelen': ('tårekjertel',),
'tårekjertlene': ('tårekjertel',),
'tårekjertler': ('tårekjertel',),
'tårepersa': ('tåreperse',),
'tåreperse': ('tåreperse',),
'tårepersen': ('tåreperse',),
'tårepersene': ('tåreperse',),
'tåreperser': ('tåreperse',),
'tåresekk': ('tåresekk',),
'tåresekken': ('tåresekk',),
'tåresekkene': ('tåresekk',),
'tåresekker': ('tåresekk',),
'tårevæska': ('tårevæske',),
'tårevæske': ('tårevæske',),
'tårevæsken': ('tårevæske',),
'tårevæskene': ('tårevæske',),
'tårevæsker': ('tårevæske',),
'tårn': ('tårn',),
'tårna': ('tårn',),
'tårnene': ('tårn',),
'tårnet': ('tårn',),
'tårnfalk': ('tårnfalk',),
'tårnfalken': ('tårnfalk',),
'tårnfalkene': ('tårnfalk',),
'tårnfalker': ('tårnfalk',),
'tårnglugg': ('tårnglugg',),
'tårngluggen': ('tårnglugg',),
'tårngluggene': ('tårnglugg',),
'tårnglugger': ('tårnglugg',),
'tårnglugge': ('tårnglugge',),
'tårngluggen': ('tårnglugge',),
'tårngluggene': ('tårnglugge',),
'tårnglugger': ('tårnglugge',),
'tårnsegler': ('tårnsegler',),
'tårnseglere': ('tårnsegler',),
'tårnsegleren': ('tårnsegler',),
'tårnseglerer': ('tårnsegler',),
'tårnseglerne': ('tårnsegler',),
'tårnseiler': ('tårnseiler',),
'tårnseilere': ('tårnseiler',),
'tårnseileren': ('tårnseiler',),
'tårnseilerer': ('tårnseiler',),
'tårnseilerne': ('tårnseiler',),
'tårnsnegl': ('tårnsnegl',),
'tårnsneglen': ('tårnsnegl',),
'tårnsneglene': ('tårnsnegl',),
'tårnsnegler': ('tårnsnegl',),
'tårnsnile': ('tårnsnile',),
'tårnsnilen': ('tårnsnile',),
'tårnsnilene': ('tårnsnile',),
'tårnsniler': ('tårnsnile',),
'tårnsvala': ('tårnsvale',),
'tårnsvale': ('tårnsvale',),
'tårnsvalen': ('tårnsvale',),
'tårnsvalene': ('tårnsvale',),
'tårnsvaler': ('tårnsvale',),
'tårnteleskop': ('tårnteleskop',),
'tårnteleskopa': ('tårnteleskop',),
'tårnteleskopene': ('tårnteleskop',),
'tårnteleskoper': ('tårnteleskop',),
'tårnteleskopet': ('tårnteleskop',),
'tårnugla': ('tårnugle',),
'tårnugle': ('tårnugle',),
'tårnuglen': ('tårnugle',),
'tårnuglene': ('tårnugle',),
'tårnugler': ('tårnugle',),
'tårnur': ('tårnur',),
'tårnura': ('tårnur',),
'tårnurene': ('tårnur',),
'tårnuret': ('tårnur',),
'tårnurt': ('tårnurt',),
'tårnurta': ('tårnurt',),
'tårnurten': ('tårnurt',),
'tårnurtene': ('tårnurt',),
'tårnurter': ('tårnurt',),
'tåspiss': ('tåspiss',),
'tåspissen': ('tåspiss',),
'tåspissene': ('tåspiss',),
'tåspisser': ('tåspiss',),
'tåspissdans': ('tåspissdans',),
'tåspissdansen': ('tåspissdans',),
'tåspissdansene': ('tåspissdans',),
'tåspissdanser': ('tåspissdans',),
'tåta': ('tåte',),
'tåte': ('tåte',),
'tåten': ('tåte',),
'tåtene': ('tåte',),
'tåter': ('tåte',),
'tåteflaska': ('tåteflaske',),
'tåteflaske': ('tåteflaske',),
'tåteflasken': ('tåteflaske',),
'tåteflaskene': ('tåteflaske',),
'tåteflasker': ('tåteflaske',),
'tåtesmokk': ('tåtesmokk',),
'tåtesmokken': ('tåtesmokk',),
'tåtesmokkene': ('tåtesmokk',),
'tåtesmokker': ('tåtesmokk',),
'tått': ('tått',),
'tåtten': ('tått',),
'tåttene': ('tått',),
'tåtter': ('tått',),
'tættene': ('tått',),
'tætter': ('tått',),
'tæl': ('tæl',),
'tælen': ('tæl',),
'tælene': ('tæl',),
'tæler': ('tæl',),
'tæring': ('tæring',),
'tæringa': ('tæring',),
'tæringen': ('tæring',),
'tæringene': ('tæring',),
'tæringer': ('tæring',),
'tæring': ('tæring',),
'tæringa': ('tæring',),
'tæringen': ('tæring',),
'tæringene': ('tæring',),
'tæringer': ('tæring',),
'tøddel': ('tøddel',),
'tøddelen': ('tøddel',),
'tødlene': ('tøddel',),
'tødler': ('tøddel',),
'tøa': ('tøe',),
'tøe': ('tøe',),
'tøen': ('tøe',),
'tøene': ('tøe',),
'tøer': ('tøe',),
'tøff': ('tøff',),
'tøffa': ('tøff',),
'tøffene': ('tøff',),
'tøffet': ('tøff',),
'tøffel': ('tøffel',),
'tøffelen': ('tøffel',),
'tøflene': ('tøffel',),
'tøfler': ('tøffel',),
'tøffelblomst': ('tøffelblomst',),
'tøffelblomsten': ('tøffelblomst',),
'tøffelblomstene': ('tøffelblomst',),
'tøffelblomster': ('tøffelblomst',),
'tøffelhelt': ('tøffelhelt',),
'tøffelhelten': ('tøffelhelt',),
'tøffelheltene': ('tøffelhelt',),
'tøffelhelter': ('tøffelhelt',),
'tøffing': ('tøffing',),
'tøffingen': ('tøffing',),
'tøffingene': ('tøffing',),
'tøffinger': ('tøffing',),
'tølene': ('tøler',),
'tøler': ('tøler',),
'tølper': ('tølper',),
'tølpere': ('tølper',),
'tølperen': ('tølper',),
'tølperer': ('tølper',),
'tølperne': ('tølper',),
'tøm': ('tøm',),
'tømmen': ('tøm',),
'tømmene': ('tøm',),
'tømmer': ('tøm',),
'tømme': ('tømme',),
'tømmen': ('tømme',),
'tømmene': ('tømme',),
'tømmer': ('tømme',),
'tømmer': ('tømmer',),
'tømmera': ('tømmer',),
'tømmerene': ('tømmer',),
'tømmeret': ('tømmer',),
'tømra': ('tømmer',),
'tømre': ('tømmer',),
'tømrene': ('tømmer',),
'tømmeravvirkning': ('tømmeravvirkning',),
'tømmeravvirkninga': ('tømmeravvirkning',),
'tømmeravvirkningen': ('tømmeravvirkning',),
'tømmeravvirkningene': ('tømmeravvirkning',),
'tømmeravvirkninger': ('tømmeravvirkning',),
'tømmerblink': ('tømmerblink',),
'tømmerblinken': ('tømmerblink',),
'tømmerblinkene': ('tømmerblink',),
'tømmerblinker': ('tømmerblink',),
'tømmerblinking': ('tømmerblinking',),
'tømmerblinkinga': ('tømmerblinking',),
'tømmerblinkingen': ('tømmerblinking',),
'tømmerblinkingene': ('tømmerblinking',),
'tømmerblinkinger': ('tømmerblinking',),
'tømmerdrift': ('tømmerdrift',),
'tømmerdrifta': ('tømmerdrift',),
'tømmerdriften': ('tømmerdrift',),
'tømmerdriftene': ('tømmerdrift',),
'tømmerdrifter': ('tømmerdrift',),
'tømmerflåte': ('tømmerflåte',),
'tømmerflåten': ('tømmerflåte',),
'tømmerflåtene': ('tømmerflåte',),
'tømmerflåter': ('tømmerflåte',),
'tømmerfløter': ('tømmerfløter',),
'tømmerfløtere': ('tømmerfløter',),
'tømmerfløteren': ('tømmerfløter',),
'tømmerfløterer': ('tømmerfløter',),
'tømmerfløterne': ('tømmerfløter',),
'tømmerfløtning': ('tømmerfløtning',),
'tømmerfløtninga': ('tømmerfløtning',),
'tømmerfløtningen': ('tømmerfløtning',),
'tømmerfløtningene': ('tømmerfløtning',),
'tømmerfløtninger': ('tømmerfløtning',),
'tømmerfløyter': ('tømmerfløyter',),
'tømmerfløytere': ('tømmerfløyter',),
'tømmerfløyteren': ('tømmerfløyter',),
'tømmerfløyterer': ('tømmerfløyter',),
'tømmerfløyterne': ('tømmerfløyter',),
'tømmerfløyting': ('tømmerfløyting',),
'tømmerfløytinga': ('tømmerfløyting',),
'tømmerfløytingen': ('tømmerfløyting',),
'tømmerfløytingene': ('tømmerfløyting',),
'tømmerfløytinger': ('tømmerfløyting',),
'tømmerhake': ('tømmerhake',),
'tømmerhaken': ('tømmerhake',),
'tømmerhakene': ('tømmerhake',),
'tømmerhaker': ('tømmerhake',),
'tømmerhogger': ('tømmerhogger',),
'tømmerhoggere': ('tømmerhogger',),
'tømmerhoggeren': ('tømmerhogger',),
'tømmerhoggerer': ('tømmerhogger',),
'tømmerhoggerne': ('tømmerhogger',),
'tømmerhogst': ('tømmerhogst',),
'tømmerhogsten': ('tømmerhogst',),
'tømmerhogstene': ('tømmerhogst',),
'tømmerhogster': ('tømmerhogst',),
'tømmerhugger': ('tømmerhugger',),
'tømmerhuggere': ('tømmerhugger',),
'tømmerhuggeren': ('tømmerhugger',),
'tømmerhuggerer': ('tømmerhugger',),
'tømmerhuggerne': ('tømmerhugger',),
'tømmerhugst': ('tømmerhugst',),
'tømmerhugsten': ('tømmerhugst',),
'tømmerhugstene': ('tømmerhugst',),
'tømmerhugster': ('tømmerhugst',),
'tømmerklave': ('tømmerklave',),
'tømmerklaven': ('tømmerklave',),
'tømmerklavene': ('tømmerklave',),
'tømmerklaver': ('tømmerklave',),
'tømmerkoia': ('tømmerkoie',),
'tømmerkoie': ('tømmerkoie',),
'tømmerkoien': ('tømmerkoie',),
'tømmerkoiene': ('tømmerkoie',),
'tømmerkoier': ('tømmerkoie',),
'tømmerlensa': ('tømmerlense',),
'tømmerlense': ('tømmerlense',),
'tømmerlensen': ('tømmerlense',),
'tømmerlensene': ('tømmerlense',),
'tømmerlenser': ('tømmerlense',),
'tømmerlunna': ('tømmerlunne',),
'tømmerlunne': ('tømmerlunne',),
'tømmerlunnen': ('tømmerlunne',),
'tømmerlunnene': ('tømmerlunne',),
'tømmerlunner': ('tømmerlunne',),
'tømmermann': ('tømmermann',),
'tømmermannen': ('tømmermann',),
'tømmermenn': ('tømmermann',),
'tømmermennene': ('tømmermann',),
'tømmermannsblyant': ('tømmermannsblyant',),
'tømmermannsblyanten': ('tømmermannsblyant',),
'tømmermannsblyantene': ('tømmermannsblyant',),
'tømmermannsblyanter': ('tømmermannsblyant',),
'tømmermerka': ('tømmermerke',),
'tømmermerke': ('tømmermerke',),
'tømmermerkene': ('tømmermerke',),
'tømmermerker': ('tømmermerke',),
'tømmermerket': ('tømmermerke',),
'tømmermerking': ('tømmermerking',),
'tømmermerkinga': ('tømmermerking',),
'tømmermerkingen': ('tømmermerking',),
'tømmermerkingene': ('tømmermerking',),
'tømmermerkinger': ('tømmermerking',),
'tømmermester': ('tømmermester',),
'tømmermestere': ('tømmermester',),
'tømmermesteren': ('tømmermester',),
'tømmermesterer': ('tømmermester',),
'tømmermesterne': ('tømmermester',),
'tømmermestre': ('tømmermester',),
'tømmermestrene': ('tømmermester',),
'tømmermestrer': ('tømmermester',),
'tømmermåling': ('tømmermåling',),
'tømmermålinga': ('tømmermåling',),
'tømmermålingen': ('tømmermåling',),
'tømmermålingene': ('tømmermåling',),
'tømmermålinger': ('tømmermåling',),
'tømmerstokk': ('tømmerstokk',),
'tømmerstokken': ('tømmerstokk',),
'tømmerstokkene': ('tømmerstokk',),
'tømmerstokker': ('tømmerstokk',),
'tømmerveg': ('tømmerveg',),
'tømmervegen': ('tømmerveg',),
'tømmervegene': ('tømmerveg',),
'tømmerveger': ('tømmerveg',),
'tømmervei': ('tømmervei',),
'tømmerveien': ('tømmervei',),
'tømmerveiene': ('tømmervei',),
'tømmerveier': ('tømmervei',),
'tømmervelta': ('tømmervelte',),
'tømmervelte': ('tømmervelte',),
'tømmervelten': ('tømmervelte',),
'tømmerveltene': ('tømmervelte',),
'tømmervelter': ('tømmervelte',),
'tømmetid': ('tømmetid',),
'tømmetida': ('tømmetid',),
'tømmetiden': ('tømmetid',),
'tømmetidene': ('tømmetid',),
'tømmetider': ('tømmetid',),
'tømmingstid': ('tømmingstid',),
'tømmingstida': ('tømmingstid',),
'tømmingstiden': ('tømmingstid',),
'tømmingstidene': ('tømmingstid',),
'tømmingstider': ('tømmingstid',),
'tømrer': ('tømrer',),
'tømrere': ('tømrer',),
'tømreren': ('tømrer',),
'tømrerer': ('tømrer',),
'tømrerne': ('tømrer',),
'tømrerarbeid': ('tømrerarbeid',),
'tømrerarbeida': ('tømrerarbeid',),
'tømrerarbeidene': ('tømrerarbeid',),
'tømrerarbeider': ('tømrerarbeid',),
'tømrerarbeidet': ('tømrerarbeid',),
'tømrermester': ('tømrermester',),
'tømrermestere': ('tømrermester',),
'tømrermesteren': ('tømrermester',),
'tømrermesterer': ('tømrermester',),
'tømrermesterne': ('tømrermester',),
'tømrermestre': ('tømrermester',),
'tømrermestrene': ('tømrermester',),
'tømrermestrer': ('tømrermester',),
'tømring': ('tømring',),
'tømringen': ('tømring',),
'tømringene': ('tømring',),
'tømringer': ('tømring',),
'tømring': ('tømring',),
'tømringa': ('tømring',),
'tømringen': ('tømring',),
'tømringene': ('tømring',),
'tømringer': ('tømring',),
'tønna': ('tønne',),
'tønne': ('tønne',),
'tønnen': ('tønne',),
'tønnene': ('tønne',),
'tønner': ('tønne',),
'tønna': ('tønne',),
'tønne': ('tønne',),
'tønnen': ('tønne',),
'tønnene': ('tønne',),
'tønner': ('tønne',),
'tønneband': ('tønneband',),
'tønnebanda': ('tønneband',),
'tønnebandene': ('tønneband',),
'tønnebandet': ('tønneband',),
'tønneband': ('tønneband',),
'tønnebanda': ('tønneband',),
'tønnebandene': ('tønneband',),
'tønnebandet': ('tønneband',),
'tønnehvelv': ('tønnehvelv',),
'tønnehvelva': ('tønnehvelv',),
'tønnehvelvene': ('tønnehvelv',),
'tønnehvelvet': ('tønnehvelv',),
'tønnehvelv': ('tønnehvelv',),
'tønnehvelva': ('tønnehvelv',),
'tønnehvelvene': ('tønnehvelv',),
'tønnehvelvet': ('tønnehvelv',),
'tønnehvelving': ('tønnehvelving',),
'tønnehvelvingen': ('tønnehvelving',),
'tønnehvelvingene': ('tønnehvelving',),
'tønnehvelvinger': ('tønnehvelving',),
'tønnehvelving': ('tønnehvelving',),
'tønnehvelvingen': ('tønnehvelving',),
'tønnehvelvingene': ('tønnehvelving',),
'tønnehvelvinger': ('tønnehvelving',),
'tønnekvelv': ('tønnekvelv',),
'tønnekvelva': ('tønnekvelv',),
'tønnekvelven': ('tønnekvelv',),
'tønnekvelvene': ('tønnekvelv',),
'tønnekvelver': ('tønnekvelv',),
'tønnekvelvet': ('tønnekvelv',),
'tønnekvelv': ('tønnekvelv',),
'tønnekvelva': ('tønnekvelv',),
'tønnekvelven': ('tønnekvelv',),
'tønnekvelvene': ('tønnekvelv',),
'tønnekvelver': ('tønnekvelv',),
'tønnekvelvet': ('tønnekvelv',),
'tønnekvelving': ('tønnekvelving',),
'tønnekvelvingen': ('tønnekvelving',),
'tønnekvelvingene': ('tønnekvelving',),
'tønnekvelvinger': ('tønnekvelving',),
'tønnekvelving': ('tønnekvelving',),
'tønnekvelvingen': ('tønnekvelving',),
'tønnekvelvingene': ('tønnekvelving',),
'tønnekvelvinger': ('tønnekvelving',),
'tønnemål': ('tønnemål',),
'tønnemåla': ('tønnemål',),
'tønnemålene': ('tønnemål',),
'tønnemålet': ('tønnemål',),
'tønnemål': ('tønnemål',),
'tønnemåla': ('tønnemål',),
'tønnemålene': ('tønnemål',),
'tønnemålet': ('tønnemål',),
'tønnestav': ('tønnestav',),
'tønnestaven': ('tønnestav',),
'tønnestavene': ('tønnestav',),
'tønnestaver': ('tønnestav',),
'tønnestav': ('tønnestav',),
'tønnestaven': ('tønnestav',),
'tønnestavene': ('tønnestav',),
'tønnestaver': ('tønnestav',),
'tønnetapp': ('tønnetapp',),
'tønnetappen': ('tønnetapp',),
'tønnetappene': ('tønnetapp',),
'tønnetapper': ('tønnetapp',),
'tønnetapp': ('tønnetapp',),
'tønnetappen': ('tønnetapp',),
'tønnetappene': ('tønnetapp',),
'tønnetapper': ('tønnetapp',),
'tørk': ('tørk',),
'tørken': ('tørk',),
'tørkene': ('tørk',),
'tørker': ('tørk',),
'tørk': ('tørk',),
'tørka': ('tørk',),
'tørkene': ('tørk',),
'tørket': ('tørk',),
'tørka': ('tørke',),
'tørke': ('tørke',),
'tørken': ('tørke',),
'tørkene': ('tørke',),
'tørker': ('tørke',),
'tørkeloft': ('tørkeloft',),
'tørkelofta': ('tørkeloft',),
'tørkeloftene': ('tørkeloft',),
'tørkeloftet': ('tørkeloft',),
'tørker': ('tørker',),
'tørkere': ('tørker',),
'tørkeren': ('tørker',),
'tørkerer': ('tørker',),
'tørkerne': ('tørker',),
'tørkeri': ('tørkeri',),
'tørkeria': ('tørkeri',),
'tørkeriene': ('tørkeri',),
'tørkerier': ('tørkeri',),
'tørkeriet': ('tørkeri',),
'tørkerom': ('tørkerom',),
'tørkeromma': ('tørkerom',),
'tørkerommene': ('tørkerom',),
'tørkerommet': ('tørkerom',),
'tørkeskap': ('tørkeskap',),
'tørkeskapa': ('tørkeskap',),
'tørkeskapene': ('tørkeskap',),
'tørkeskapet': ('tørkeskap',),
'tørkesnor': ('tørkesnor',),
'tørkesnora': ('tørkesnor',),
'tørkesnoren': ('tørkesnor',),
'tørkesnorene': ('tørkesnor',),
'tørkesnorer': ('tørkesnor',),
'tørkesommer': ('tørkesommer',),
'tørkesommere': ('tørkesommer',),
'tørkesommeren': ('tørkesommer',),
'tørkesommerne': ('tørkesommer',),
'tørkesomre': ('tørkesommer',),
'tørkesomrene': ('tørkesommer',),
'tørkesomrer': ('tørkesommer',),
'tørkestativ': ('tørkestativ',),
'tørkestativa': ('tørkestativ',),
'tørkestativene': ('tørkestativ',),
'tørkestativer': ('tørkestativ',),
'tørkestativet': ('tørkestativ',),
'tørketid': ('tørketid',),
'tørketida': ('tørketid',),
'tørketiden': ('tørketid',),
'tørketidene': ('tørketid',),
'tørketider': ('tørketid',),
'tørketromlene': ('tørketrommel',),
'tørketromler': ('tørketrommel',),
'tørketrommel': ('tørketrommel',),
'tørketrommelen': ('tørketrommel',),
'tørkle': ('tørkle',),
'tørkleet': ('tørkle',),
'tørklær': ('tørkle',),
'tørklærne': ('tørkle',),
'tørn': ('tørn',),
'tørnen': ('tørn',),
'tørnene': ('tørn',),
'tørner': ('tørn',),
'tørn': ('tørn',),
'tørna': ('tørn',),
'tørnene': ('tørn',),
'tørnet': ('tørn',),
'tørr-råte': ('tørr-råte',),
'tørr-råten': ('tørr-råte',),
'tørr-råtene': ('tørr-råte',),
'tørr-råter': ('tørr-råte',),
'tørrblekk': ('tørrblekk',),
'tørrblekka': ('tørrblekk',),
'tørrblekkene': ('tørrblekk',),
'tørrblekket': ('tørrblekk',),
'tørrblekkpenn': ('tørrblekkpenn',),
'tørrblekkpennen': ('tørrblekkpenn',),
'tørrblekkpennene': ('tørrblekkpenn',),
'tørrblekkpenner': ('tørrblekkpenn',),
'tørrdokk': ('tørrdokk',),
'tørrdokka': ('tørrdokk',),
'tørrdokken': ('tørrdokk',),
'tørrdokkene': ('tørrdokk',),
'tørrdokker': ('tørrdokk',),
'tørrdrakt': ('tørrdrakt',),
'tørrdrakta': ('tørrdrakt',),
'tørrdrakten': ('tørrdrakt',),
'tørrdraktene': ('tørrdrakt',),
'tørrdrakter': ('tørrdrakt',),
'tørrehjelm': ('tørrehjelm',),
'tørrehjelmen': ('tørrehjelm',),
'tørrehjelmene': ('tørrehjelm',),
'tørrehjelmer': ('tørrehjelm',),
'tørrelement': ('tørrelement',),
'tørrelementa': ('tørrelement',),
'tørrelementene': ('tørrelement',),
'tørrelementer': ('tørrelement',),
'tørrelementet': ('tørrelement',),
'tørrer': ('tørrer',),
'tørrere': ('tørrer',),
'tørreren': ('tørrer',),
'tørrerer': ('tørrer',),
'tørrerne': ('tørrer',),
'tørrfisk': ('tørrfisk',),
'tørrfisken': ('tørrfisk',),
'tørrfiskene': ('tørrfisk',),
'tørrfisker': ('tørrfisk',),
'tørrflua': ('tørrflue',),
'tørrflue': ('tørrflue',),
'tørrfluen': ('tørrflue',),
'tørrfluene': ('tørrflue',),
'tørrfluer': ('tørrflue',),
'tørrfuru': ('tørrfuru',),
'tørrfurua': ('tørrfuru',),
'tørrfuruen': ('tørrfuru',),
'tørrfuruene': ('tørrfuru',),
'tørrfuruer': ('tørrfuru',),
'tørrgjær': ('tørrgjær',),
'tørrgjæren': ('tørrgjær',),
'tørrgjærene': ('tørrgjær',),
'tørrgjærer': ('tørrgjær',),
'tørrgran': ('tørrgran',),
'tørrgrana': ('tørrgran',),
'tørrgranen': ('tørrgran',),
'tørrgranene': ('tørrgran',),
'tørrgraner': ('tørrgran',),
'tørrhoste': ('tørrhoste',),
'tørrhosten': ('tørrhoste',),
'tørrhostene': ('tørrhoste',),
'tørrhoster': ('tørrhoste',),
'tørring': ('tørring',),
'tørringa': ('tørring',),
'tørringen': ('tørring',),
'tørringene': ('tørring',),
'tørringer': ('tørring',),
'tørris': ('tørris',),
'tørrisen': ('tørris',),
'tørrisene': ('tørris',),
'tørriser': ('tørris',),
'tørrklosett': ('tørrklosett',),
'tørrklosetta': ('tørrklosett',),
'tørrklosettene': ('tørrklosett',),
'tørrklosetter': ('tørrklosett',),
'tørrklosettet': ('tørrklosett',),
'tørrkompas': ('tørrkompas',),
'tørrkompasa': ('tørrkompas',),
'tørrkompasen': ('tørrkompas',),
'tørrkompasene': ('tørrkompas',),
'tørrkompaser': ('tørrkompas',),
'tørrkompaset': ('tørrkompas',),
'tørrkompass': ('tørrkompass',),
'tørrkompassa': ('tørrkompass',),
'tørrkompassen': ('tørrkompass',),
'tørrkompassene': ('tørrkompass',),
'tørrkompasser': ('tørrkompass',),
'tørrkompasset': ('tørrkompass',),
'tørrkopi': ('tørrkopi',),
'tørrkopien': ('tørrkopi',),
'tørrkopiene': ('tørrkopi',),
'tørrkopier': ('tørrkopi',),
'tørrkopiering': ('tørrkopiering',),
'tørrkopieringa': ('tørrkopiering',),
'tørrkopieringen': ('tørrkopiering',),
'tørrkopieringene': ('tørrkopiering',),
'tørrkopieringer': ('tørrkopiering',),
'tørrlast': ('tørrlast',),
'tørrlasta': ('tørrlast',),
'tørrlasten': ('tørrlast',),
'tørrlastene': ('tørrlast',),
'tørrlaster': ('tørrlast',),
'tørrlastskip': ('tørrlastskip',),
'tørrlastskipa': ('tørrlastskip',),
'tørrlastskipene': ('tørrlastskip',),
'tørrlastskipet': ('tørrlastskip',),
'tørrmat': ('tørrmat',),
'tørrmaten': ('tørrmat',),
'tørrmatene': ('tørrmat',),
'tørrmater': ('tørrmat',),
'tørrmelk': ('tørrmelk',),
'tørrmelka': ('tørrmelk',),
'tørrmelken': ('tørrmelk',),
'tørrmelkene': ('tørrmelk',),
'tørrmelker': ('tørrmelk',),
'tørrmjølk': ('tørrmjølk',),
'tørrmjølka': ('tørrmjølk',),
'tørrmjølken': ('tørrmjølk',),
'tørrmjølkene': ('tørrmjølk',),
'tørrmjølker': ('tørrmjølk',),
'tørrpinn': ('tørrpinn',),
'tørrpinnen': ('tørrpinn',),
'tørrpinnene': ('tørrpinn',),
'tørrpinner': ('tørrpinn',),
'tørrpinne': ('tørrpinne',),
'tørrpinnen': ('tørrpinne',),
'tørrpinnene': ('tørrpinne',),
'tørrpinner': ('tørrpinne',),
'tørrsjampo': ('tørrsjampo',),
'tørrsjampoen': ('tørrsjampo',),
'tørrsjampoene': ('tørrsjampo',),
'tørrsjampoer': ('tørrsjampo',),
'tørrsprit': ('tørrsprit',),
'tørrspriten': ('tørrsprit',),
'tørrspritene': ('tørrsprit',),
'tørrspriter': ('tørrsprit',),
'tørrstoff': ('tørrstoff',),
'tørrstoffa': ('tørrstoff',),
'tørrstoffene': ('tørrstoff',),
'tørrstoffer': ('tørrstoff',),
'tørrstoffet': ('tørrstoff',),
'tørråte': ('tørråte',),
'tørråten': ('tørråte',),
'tørråtene': ('tørråte',),
'tørråter': ('tørråte',),
'tørst': ('tørst',),
'tørsten': ('tørst',),
'tørstene': ('tørst',),
'tørster': ('tørst',),
'tørste': ('tørste',),
'tørsten': ('tørste',),
'tørstene': ('tørste',),
'tørster': ('tørste',),
'tørstedrikk': ('tørstedrikk',),
'tørstedrikken': ('tørstedrikk',),
'tørstedrikkene': ('tørstedrikk',),
'tørstedrikker': ('tørstedrikk',),
'tøs': ('tøs',),
'tøsa': ('tøs',),
'tøsen': ('tøs',),
'tøsene': ('tøs',),
'tøser': ('tøs',),
'tøtsj': ('tøtsj',),
'tøtsjen': ('tøtsj',),
'tøtsjene': ('tøtsj',),
'tøtsjer': ('tøtsj',),
'tøv': ('tøv',),
'tøva': ('tøv',),
'tøvene': ('tøv',),
'tøvet': ('tøv',),
'tøvekopp': ('tøvekopp',),
'tøvekoppen': ('tøvekopp',),
'tøvekoppene': ('tøvekopp',),
'tøvekopper': ('tøvekopp',),
'tøvær': ('tøvær',),
'tøværa': ('tøvær',),
'tøværene': ('tøvær',),
'tøværet': ('tøvær',),
'tøvær': ('tøvær',),
'tøværa': ('tøvær',),
'tøværene': ('tøvær',),
'tøværet': ('tøvær',),
'tøy': ('tøy',),
'tøyen': ('tøy',),
'tøyene': ('tøy',),
'tøyer': ('tøy',),
'tøy': ('tøy',),
'tøya': ('tøy',),
'tøyene': ('tøy',),
'tøyer': ('tøy',),
'tøyet': ('tøy',),
'tøyle': ('tøyle',),
'tøylen': ('tøyle',),
'tøylene': ('tøyle',),
'tøyler': ('tøyle',),
'tøymester': ('tøymester',),
'tøymestere': ('tøymester',),
'tøymesteren': ('tøymester',),
'tøymesterer': ('tøymester',),
'tøymesterne': ('tøymester',),
'tøymestre': ('tøymester',),
'tøymestrene': ('tøymester',),
'tøymestrer': ('tøymester',),
'tøyning': ('tøyning',),
'tøyninga': ('tøyning',),
'tøyningen': ('tøyning',),
'tøyningene': ('tøyning',),
'tøyninger': ('tøyning',),
'tøyningsøvelse': ('tøyningsøvelse',),
'tøyningsøvelsen': ('tøyningsøvelse',),
'tøyningsøvelsene': ('tøyningsøvelse',),
'tøyningsøvelser': ('tøyningsøvelse',),
'tøyningsøving': ('tøyningsøving',),
'tøyningsøvinga': ('tøyningsøving',),
'tøyningsøvingen': ('tøyningsøving',),
'tøyningsøvingene': ('tøyningsøving',),
'tøyningsøvinger': ('tøyningsøving',),
'tøys': ('tøys',),
'tøysa': ('tøys',),
'tøysene': ('tøys',),
'tøyset': ('tøys',),
'tøysa': ('tøyse',),
'tøyse': ('tøyse',),
'tøysen': ('tøyse',),
'tøysene': ('tøyse',),
'tøyser': ('tøyse',),
'tøysebukk': ('tøysebukk',),
'tøysebukken': ('tøysebukk',),
'tøysebukkene': ('tøysebukk',),
'tøysebukker': ('tøysebukk',),
'tøysekopp': ('tøysekopp',),
'tøysekoppen': ('tøysekopp',),
'tøysekoppene': ('tøysekopp',),
'tøysekopper': ('tøysekopp',),
'tøyseri': ('tøyseri',),
'tøyseria': ('tøyseri',),
'tøyseriene': ('tøyseri',),
'tøyserier': ('tøyseri',),
'tøyseriet': ('tøyseri',),
'tøyta': ('tøyte',),
'tøyte': ('tøyte',),
'tøyten': ('tøyte',),
'tøytene': ('tøyte',),
'tøyter': ('tøyte',),
'u': ('u',),
'u\'en': ('u',),
'u-en': ('u',),
'u-ene': ('u',),
'u-er': ('u',),
'u-hjelp': ('u-hjelp',),
'u-hjelpa': ('u-hjelp',),
'u-hjelpen': ('u-hjelp',),
'u-hjelpene': ('u-hjelp',),
'u-hjelper': ('u-hjelp',),
'u-hjelper': ('u-hjelper',),
'u-hjelpere': ('u-hjelper',),
'u-hjelperen': ('u-hjelper',),
'u-hjelperer': ('u-hjelper',),
'u-hjelperne': ('u-hjelper',),
'u-hjelpsarbeid': ('u-hjelpsarbeid',),
'u-hjelpsarbeida': ('u-hjelpsarbeid',),
'u-hjelpsarbeidene': ('u-hjelpsarbeid',),
'u-hjelpsarbeidet': ('u-hjelpsarbeid',),
'u-kort': ('u-kort',),
'u-korta': ('u-kort',),
'u-kortene': ('u-kort',),
'u-kortet': ('u-kort',),
'u-land': ('u-land',),
'u-landa': ('u-land',),
'u-landene': ('u-land',),
'u-landet': ('u-land',),
'u-landshjelp': ('u-landshjelp',),
'u-landshjelpa': ('u-landshjelp',),
'u-landshjelpen': ('u-landshjelp',),
'u-landshjelpene': ('u-landshjelp',),
'u-landshjelper': ('u-landshjelp',),
'u-landstjeneste': ('u-landstjeneste',),
'u-landstjenesten': ('u-landstjeneste',),
'u-landstjenestene': ('u-landstjeneste',),
'u-landstjenester': ('u-landstjeneste',),
'u-omlyd': ('u-omlyd',),
'u-omlyden': ('u-omlyd',),
'u-omlydene': ('u-omlyd',),
'u-omlyder': ('u-omlyd',),
'uaktsomhet': ('uaktsomhet',),
'uaktsomheta': ('uaktsomhet',),
'uaktsomheten': ('uaktsomhet',),
'uaktsomhetene': ('uaktsomhet',),
'uaktsomheter': ('uaktsomhet',),
'uanstendighet': ('uanstendighet',),
'uanstendigheta': ('uanstendighet',),
'uanstendigheten': ('uanstendighet',),
'uanstendighetene': ('uanstendighet',),
'uanstendigheter': ('uanstendighet',),
'uansvarlighet': ('uansvarlighet',),
'uansvarligheta': ('uansvarlighet',),
'uansvarligheten': ('uansvarlighet',),
'uansvarlighetene': ('uansvarlighet',),
'uansvarligheter': ('uansvarlighet',),
'uartighet': ('uartighet',),
'uartigheta': ('uartighet',),
'uartigheten': ('uartighet',),
'uartighetene': ('uartighet',),
'uartigheter': ('uartighet',),
'uavhengighet': ('uavhengighet',),
'uavhengigheta': ('uavhengighet',),
'uavhengigheten': ('uavhengighet',),
'uavhengighetene': ('uavhengighet',),
'uavhengigheter': ('uavhengighet',),
'uavhengighetserklæring': ('uavhengighetserklæring',),
'uavhengighetserklæringa': ('uavhengighetserklæring',),
'uavhengighetserklæringen': ('uavhengighetserklæring',),
'uavhengighetserklæringene': ('uavhengighetserklæring',),
'uavhengighetserklæringer': ('uavhengighetserklæring',),
'uavhengighetskamp': ('uavhengighetskamp',),
'uavhengighetskampen': ('uavhengighetskamp',),
'uavhengighetskampene': ('uavhengighetskamp',),
'uavhengighetskamper': ('uavhengighetskamp',),
'ubalanse': ('ubalanse',),
'ubalansen': ('ubalanse',),
'ubalansene': ('ubalanse',),
'ubalanser': ('ubalanse',),
'ubehag': ('ubehag',),
'ubehaga': ('ubehag',),
'ubehagene': ('ubehag',),
'ubehaget': ('ubehag',),
'ubehagelighet': ('ubehagelighet',),
'ubehageligheta': ('ubehagelighet',),
'ubehageligheten': ('ubehagelighet',),
'ubehagelighetene': ('ubehagelighet',),
'ubehageligheter': ('ubehagelighet',),
'ubehjelpelighet': ('ubehjelpelighet',),
'ubehjelpeligheta': ('ubehjelpelighet',),
'ubehjelpeligheten': ('ubehjelpelighet',),
'ubehjelpelighetene': ('ubehjelpelighet',),
'ubehjelpeligheter': ('ubehjelpelighet',),
'ubeist': ('ubeist',),
'ubeista': ('ubeist',),
'ubeistene': ('ubeist',),
'ubeistet': ('ubeist',),
'uberegnelighet': ('uberegnelighet',),
'uberegneligheta': ('uberegnelighet',),
'uberegneligheten': ('uberegnelighet',),
'uberegnelighetene': ('uberegnelighet',),
'uberegneligheter': ('uberegnelighet',),
'ubereknelighet': ('ubereknelighet',),
'uberekneligheta': ('ubereknelighet',),
'uberekneligheten': ('ubereknelighet',),
'ubereknelighetene': ('ubereknelighet',),
'uberekneligheter': ('ubereknelighet',),
'uberørthet': ('uberørthet',),
'uberørtheta': ('uberørthet',),
'uberørtheten': ('uberørthet',),
'uberørthetene': ('uberørthet',),
'uberørtheter': ('uberørthet',),
'ubesindighet': ('ubesindighet',),
'ubesindigheta': ('ubesindighet',),
'ubesindigheten': ('ubesindighet',),
'ubesindighetene': ('ubesindighet',),
'ubesindigheter': ('ubesindighet',),
'ubesluttsomhet': ('ubesluttsomhet',),
'ubesluttsomheta': ('ubesluttsomhet',),
'ubesluttsomheten': ('ubesluttsomhet',),
'ubesluttsomhetene': ('ubesluttsomhet',),
'ubesluttsomheter': ('ubesluttsomhet',),
'ubest': ('ubest',),
'ubesta': ('ubest',),
'ubestene': ('ubest',),
'ubestet': ('ubest',),
'ubestemthet': ('ubestemthet',),
'ubestemtheta': ('ubestemthet',),
'ubestemtheten': ('ubestemthet',),
'ubestemthetene': ('ubestemthet',),
'ubestemtheter': ('ubestemthet',),
'ubestridelighet': ('ubestridelighet',),
'ubestrideligheta': ('ubestridelighet',),
'ubestrideligheten': ('ubestridelighet',),
'ubestridelighetene': ('ubestridelighet',),
'ubestrideligheter': ('ubestridelighet',),
'ubetenksomhet': ('ubetenksomhet',),
'ubetenksomheta': ('ubetenksomhet',),
'ubetenksomheten': ('ubetenksomhet',),
'ubetenksomhetene': ('ubetenksomhet',),
'ubetenksomheter': ('ubetenksomhet',),
'ubetydlelighet': ('ubetydlelighet',),
'ubetydleligheta': ('ubetydlelighet',),
'ubetydleligheten': ('ubetydlelighet',),
'ubetydlelighetene': ('ubetydlelighet',),
'ubetydleligheter': ('ubetydlelighet',),
'ubåt': ('ubåt',),
'ubåten': ('ubåt',),
'ubåtene': ('ubåt',),
'ubåter': ('ubåt',),
'ubåtbunker': ('ubåtbunker',),
'ubåtbunkere': ('ubåtbunker',),
'ubåtbunkeren': ('ubåtbunker',),
'ubåtbunkerer': ('ubåtbunker',),
'ubåtbunkerne': ('ubåtbunker',),
'ubåtklokka': ('ubåtklokke',),
'ubåtklokke': ('ubåtklokke',),
'ubåtklokken': ('ubåtklokke',),
'ubåtklokkene': ('ubåtklokke',),
'ubåtklokker': ('ubåtklokke',),
'ubåtkrig': ('ubåtkrig',),
'ubåtkrigen': ('ubåtkrig',),
'ubåtkrigene': ('ubåtkrig',),
'ubåtkriger': ('ubåtkrig',),
'udugelihet': ('udugelihet',),
'udugeliheta': ('udugelihet',),
'udugeliheten': ('udugelihet',),
'udugelihetene': ('udugelihet',),
'udugeliheter': ('udugelihet',),
'udyd': ('udyd',),
'udyden': ('udyd',),
'udydene': ('udyd',),
'udyder': ('udyd',),
'udyr': ('udyr',),
'udyra': ('udyr',),
'udyrene': ('udyr',),
'udyret': ('udyr',),
'udåd': ('udåd',),
'udåden': ('udåd',),
'udådene': ('udåd',),
'udåder': ('udåd',),
'udådsmann': ('udådsmann',),
'udådsmannen': ('udådsmann',),
'udådsmenn': ('udådsmann',),
'udådsmennene': ('udådsmann',),
'udødelighet': ('udødelighet',),
'udødeligheta': ('udødelighet',),
'udødeligheten': ('udødelighet',),
'udødelighetene': ('udødelighet',),
'udødeligheter': ('udødelighet',),
'uendelighet': ('uendelighet',),
'uendeligheta': ('uendelighet',),
'uendeligheten': ('uendelighet',),
'uendelighetene': ('uendelighet',),
'uendeligheter': ('uendelighet',),
'uenighet': ('uenighet',),
'uenigheta': ('uenighet',),
'uenigheten': ('uenighet',),
'uenighetene': ('uenighet',),
'uenigheter': ('uenighet',),
'uer': ('uer',),
'uere': ('uer',),
'ueren': ('uer',),
'uerer': ('uer',),
'uerne': ('uer',),
'uetterrettelighet': ('uetterrettelighet',),
'uetterretteligheta': ('uetterrettelighet',),
'uetterretteligheten': ('uetterrettelighet',),
'uetterrettelighetene': ('uetterrettelighet',),
'uetterretteligheter': ('uetterrettelighet',),
'ufasong': ('ufasong',),
'ufasongen': ('ufasong',),
'ufasongene': ('ufasong',),
'ufasonger': ('ufasong',),
'ufeilbarhet': ('ufeilbarhet',),
'ufeilbarheta': ('ufeilbarhet',),
'ufeilbarheten': ('ufeilbarhet',),
'ufeilbarhetene': ('ufeilbarhet',),
'ufeilbarheter': ('ufeilbarhet',),
'ufeilbarlighet': ('ufeilbarlighet',),
'ufeilbarligheta': ('ufeilbarlighet',),
'ufeilbarligheten': ('ufeilbarlighet',),
'ufeilbarlighetene': ('ufeilbarlighet',),
'ufeilbarligheter': ('ufeilbarlighet',),
'ufinhet': ('ufinhet',),
'ufinheta': ('ufinhet',),
'ufinheten': ('ufinhet',),
'ufinhetene': ('ufinhet',),
'ufinheter': ('ufinhet',),
'ufisk': ('ufisk',),
'ufisken': ('ufisk',),
'ufiskene': ('ufisk',),
'ufisker': ('ufisk',),
'uflaks': ('uflaks',),
'uflaksen': ('uflaks',),
'uflaksene': ('uflaks',),
'uflakser': ('uflaks',),
'ufo': ('ufo',),
'ufoen': ('ufo',),
'ufoene': ('ufo',),
'ufoer': ('ufo',),
'ufolog': ('ufolog',),
'ufologen': ('ufolog',),
'ufologene': ('ufolog',),
'ufologer': ('ufolog',),
'ufologi': ('ufologi',),
'ufologien': ('ufologi',),
'ufologiene': ('ufologi',),
'ufologier': ('ufologi',),
'uformuenhet': ('uformuenhet',),
'uformuenheta': ('uformuenhet',),
'uformuenheten': ('uformuenhet',),
'uformuenhetene': ('uformuenhet',),
'uformuenheter': ('uformuenhet',),
'ufornuft': ('ufornuft',),
'ufornuften': ('ufornuft',),
'ufornuftene': ('ufornuft',),
'ufornufter': ('ufornuft',),
'uforsiktighet': ('uforsiktighet',),
'uforsiktigheta': ('uforsiktighet',),
'uforsiktigheten': ('uforsiktighet',),
'uforsiktighetene': ('uforsiktighet',),
'uforsiktigheter': ('uforsiktighet',),
'uforskammethet': ('uforskammethet',),
'uforskammetheta': ('uforskammethet',),
'uforskammetheten': ('uforskammethet',),
'uforskammethetene': ('uforskammethet',),
'uforskammetheter': ('uforskammethet',),
'uforstand': ('uforstand',),
'uforstanden': ('uforstand',),
'uforstandene': ('uforstand',),
'uforstander': ('uforstand',),
'ufred': ('ufred',),
'ufreden': ('ufred',),
'ufredene': ('ufred',),
'ufreder': ('ufred',),
'ufrihet': ('ufrihet',),
'ufriheta': ('ufrihet',),
'ufriheten': ('ufrihet',),
'ufrihetene': ('ufrihet',),
'ufriheter': ('ufrihet',),
'ufs': ('ufs',),
'ufsen': ('ufs',),
'ufsene': ('ufs',),
'ufser': ('ufs',),
'ufs': ('ufs',),
'ufsen': ('ufs',),
'ufsene': ('ufs',),
'ufser': ('ufs',),
'ufs': ('ufs',),
'ufsa': ('ufs',),
'ufsen': ('ufs',),
'ufsene': ('ufs',),
'ufser': ('ufs',),
'ufysa': ('ufyse',),
'ufyse': ('ufyse',),
'ufysen': ('ufyse',),
'ufysene': ('ufyse',),
'ufyser': ('ufyse',),
'uføra': ('uføre',),
'uføre': ('uføre',),
'uførene': ('uføre',),
'ufører': ('uføre',),
'uføret': ('uføre',),
'uføregrad': ('uføregrad',),
'uføregraden': ('uføregrad',),
'uføregradene': ('uføregrad',),
'uføregrader': ('uføregrad',),
'uførepensjon': ('uførepensjon',),
'uførepensjonen': ('uførepensjon',),
'uførepensjonene': ('uførepensjon',),
'uførepensjoner': ('uførepensjon',),
'uføretrygd': ('uføretrygd',),
'uføretrygda': ('uføretrygd',),
'uføretrygden': ('uføretrygd',),
'uføretrygdene': ('uføretrygd',),
'uføretrygder': ('uføretrygd',),
'uførhet': ('uførhet',),
'uførheta': ('uførhet',),
'uførheten': ('uførhet',),
'uførhetene': ('uførhet',),
'uførheter': ('uførhet',),
'ugagn': ('ugagn',),
'ugagna': ('ugagn',),
'ugagnene': ('ugagn',),
'ugagnet': ('ugagn',),
'ugagnskråka': ('ugagnskråke',),
'ugagnskråke': ('ugagnskråke',),
'ugagnskråken': ('ugagnskråke',),
'ugagnskråkene': ('ugagnskråke',),
'ugagnskråker': ('ugagnskråke',),
'ugander': ('ugander',),
'ugandere': ('ugander',),
'uganderen': ('ugander',),
'uganderer': ('ugander',),
'uganderne': ('ugander',),
'ugg': ('ugg',),
'uggen': ('ugg',),
'uggene': ('ugg',),
'ugger': ('ugg',),
'ugg': ('ugg',),
'ugga': ('ugg',),
'uggene': ('ugg',),
'ugget': ('ugg',),
'ugge': ('ugge',),
'uggen': ('ugge',),
'uggene': ('ugge',),
'ugger': ('ugge',),
'ugildhet': ('ugildhet',),
'ugildheta': ('ugildhet',),
'ugildheten': ('ugildhet',),
'ugildhetene': ('ugildhet',),
'ugildheter': ('ugildhet',),
'ugjenkjennelighet': ('ugjenkjennelighet',),
'ugjenkjenneligheta': ('ugjenkjennelighet',),
'ugjenkjenneligheten': ('ugjenkjennelighet',),
'ugjenkjennelighetene': ('ugjenkjennelighet',),
'ugjenkjenneligheter': ('ugjenkjennelighet',),
'ugjerning': ('ugjerning',),
'ugjerninga': ('ugjerning',),
'ugjerningen': ('ugjerning',),
'ugjerningene': ('ugjerning',),
'ugjerninger': ('ugjerning',),
'ugjerningsmann': ('ugjerningsmann',),
'ugjerningsmannen': ('ugjerningsmann',),
'ugjerningsmenn': ('ugjerningsmann',),
'ugjerningsmennene': ('ugjerningsmann',),
'ugla': ('ugle',),
'ugle': ('ugle',),
'uglen': ('ugle',),
'uglene': ('ugle',),
'ugler': ('ugle',),
'ugras': ('ugras',),
'ugrasa': ('ugras',),
'ugrasene': ('ugras',),
'ugraset': ('ugras',),
'ugrasdreper': ('ugrasdreper',),
'ugrasdrepere': ('ugrasdreper',),
'ugrasdreperen': ('ugrasdreper',),
'ugrasdreperer': ('ugrasdreper',),
'ugrasdreperne': ('ugrasdreper',),
'ugrasfisk': ('ugrasfisk',),
'ugrasfisken': ('ugrasfisk',),
'ugrasfiskene': ('ugrasfisk',),
'ugrasfisker': ('ugrasfisk',),
'ugrasmiddel': ('ugrasmiddel',),
'ugrasmiddelet': ('ugrasmiddel',),
'ugrasmidla': ('ugrasmiddel',),
'ugrasmidlene': ('ugrasmiddel',),
'ugrasmidler': ('ugrasmiddel',),
'ugrasmidlet': ('ugrasmiddel',),
'ugrasplanta': ('ugrasplante',),
'ugrasplante': ('ugrasplante',),
'ugrasplanten': ('ugrasplante',),
'ugrasplantene': ('ugrasplante',),
'ugrasplanter': ('ugrasplante',),
'ugrer': ('ugrer',),
'ugrere': ('ugrer',),
'ugreren': ('ugrer',),
'ugrerer': ('ugrer',),
'ugrerne': ('ugrer',),
'ugress': ('ugress',),
'ugressa': ('ugress',),
'ugressene': ('ugress',),
'ugresset': ('ugress',),
'ugressdreper': ('ugressdreper',),
'ugressdrepere': ('ugressdreper',),
'ugressdreperen': ('ugressdreper',),
'ugressdreperer': ('ugressdreper',),
'ugressdreperne': ('ugressdreper',),
'ugressfisk': ('ugressfisk',),
'ugressfisken': ('ugressfisk',),
'ugressfiskene': ('ugressfisk',),
'ugressfisker': ('ugressfisk',),
'ugressmiddel': ('ugressmiddel',),
'ugressmiddelet': ('ugressmiddel',),
'ugressmidla': ('ugressmiddel',),
'ugressmidlene': ('ugressmiddel',),
'ugressmidler': ('ugressmiddel',),
'ugressmidlet': ('ugressmiddel',),
'ugressplanta': ('ugressplante',),
'ugressplante': ('ugressplante',),
'ugressplanten': ('ugressplante',),
'ugressplantene': ('ugressplante',),
'ugressplanter': ('ugressplante',),
'ugudelighet': ('ugudelighet',),
'ugudeligheta': ('ugudelighet',),
'ugudeligheten': ('ugudelighet',),
'ugudelighetene': ('ugudelighet',),
'ugudeligheter': ('ugudelighet',),
'ugunst': ('ugunst',),
'ugunsten': ('ugunst',),
'ugunstene': ('ugunst',),
'ugunster': ('ugunst',),
'ugyldighetserklæring': ('ugyldighetserklæring',),
'ugyldighetserklæringa': ('ugyldighetserklæring',),
'ugyldighetserklæringen': ('ugyldighetserklæring',),
'ugyldighetserklæringene': ('ugyldighetserklæring',),
'ugyldighetserklæringer': ('ugyldighetserklæring',),
'uhell': ('uhell',),
'uhella': ('uhell',),
'uhellene': ('uhell',),
'uhellet': ('uhell',),
'uhumskhet': ('uhumskhet',),
'uhumskheta': ('uhumskhet',),
'uhumskheten': ('uhumskhet',),
'uhumskhetene': ('uhumskhet',),
'uhumskheter': ('uhumskhet',),
'uhygga': ('uhygge',),
'uhygge': ('uhygge',),
'uhyggen': ('uhygge',),
'uhyggene': ('uhygge',),
'uhygger': ('uhygge',),
'uhyggefølelse': ('uhyggefølelse',),
'uhyggefølelsen': ('uhyggefølelse',),
'uhyggefølelsene': ('uhyggefølelse',),
'uhyggefølelser': ('uhyggefølelse',),
'uhyggekjensla': ('uhyggekjensle',),
'uhyggekjensle': ('uhyggekjensle',),
'uhyggekjenslen': ('uhyggekjensle',),
'uhyggekjenslene': ('uhyggekjensle',),
'uhyggekjensler': ('uhyggekjensle',),
'uhyggeskjensla': ('uhyggeskjensle',),
'uhyggeskjensle': ('uhyggeskjensle',),
'uhyggeskjenslen': ('uhyggeskjensle',),
'uhyggeskjenslene': ('uhyggeskjensle',),
'uhyggeskjensler': ('uhyggeskjensle',),
'uhyra': ('uhyre',),
'uhyre': ('uhyre',),
'uhyrene': ('uhyre',),
'uhyrer': ('uhyre',),
'uhyret': ('uhyre',),
'uhyrlighet': ('uhyrlighet',),
'uhyrligheta': ('uhyrlighet',),
'uhyrligheten': ('uhyrlighet',),
'uhyrlighetene': ('uhyrlighet',),
'uhyrligheter': ('uhyrlighet',),
'uhøflighet': ('uhøflighet',),
'uhøfligheta': ('uhøflighet',),
'uhøfligheten': ('uhøflighet',),
'uhøflighetene': ('uhøflighet',),
'uhøfligheter': ('uhøflighet',),
'ujamnhet': ('ujamnhet',),
'ujamnheta': ('ujamnhet',),
'ujamnheten': ('ujamnhet',),
'ujamnhetene': ('ujamnhet',),
'ujamnheter': ('ujamnhet',),
'ujevnhet': ('ujevnhet',),
'ujevnheta': ('ujevnhet',),
'ujevnheten': ('ujevnhet',),
'ujevnhetene': ('ujevnhet',),
'ujevnheter': ('ujevnhet',),
'ukas': ('ukas',),
'ukasen': ('ukas',),
'ukasene': ('ukas',),
'ukaser': ('ukas',),
'uka': ('uke',),
'uke': ('uke',),
'uken': ('uke',),
'ukene': ('uke',),
'uker': ('uke',),
'uka': ('uke',),
'uke': ('uke',),
'uken': ('uke',),
'ukene': ('uke',),
'uker': ('uke',),
'ukeavis': ('ukeavis',),
'ukeavisa': ('ukeavis',),
'ukeavisen': ('ukeavis',),
'ukeavisene': ('ukeavis',),
'ukeaviser': ('ukeavis',),
'ukeavis': ('ukeavis',),
'ukeavisa': ('ukeavis',),
'ukeavisen': ('ukeavis',),
'ukeavisene': ('ukeavis',),
'ukeaviser': ('ukeavis',),
'ukeblad': ('ukeblad',),
'ukeblada': ('ukeblad',),
'ukebladene': ('ukeblad',),
'ukeblader': ('ukeblad',),
'ukebladet': ('ukeblad',),
'ukeblad': ('ukeblad',),
'ukeblada': ('ukeblad',),
'ukebladene': ('ukeblad',),
'ukeblader': ('ukeblad',),
'ukebladet': ('ukeblad',),
'ukebladnovella': ('ukebladnovelle',),
'ukebladnovelle': ('ukebladnovelle',),
'ukebladnovellen': ('ukebladnovelle',),
'ukebladnovellene': ('ukebladnovelle',),
'ukebladnoveller': ('ukebladnovelle',),
'ukebladnovella': ('ukebladnovelle',),
'ukebladnovelle': ('ukebladnovelle',),
'ukebladnovellen': ('ukebladnovelle',),
'ukebladnovellene': ('ukebladnovelle',),
'ukebladnoveller': ('ukebladnovelle',),
'ukebladsnovella': ('ukebladsnovelle',),
'ukebladsnovelle': ('ukebladsnovelle',),
'ukebladsnovellen': ('ukebladsnovelle',),
'ukebladsnovellene': ('ukebladsnovelle',),
'ukebladsnoveller': ('ukebladsnovelle',),
'ukebladsnovella': ('ukebladsnovelle',),
'ukebladsnovelle': ('ukebladsnovelle',),
'ukebladsnovellen': ('ukebladsnovelle',),
'ukebladsnovellene': ('ukebladsnovelle',),
'ukebladsnoveller': ('ukebladsnovelle',),
'ukedag': ('ukedag',),
'ukedagen': ('ukedag',),
'ukedagene': ('ukedag',),
'ukedager': ('ukedag',),
'ukedag': ('ukedag',),
'ukedagen': ('ukedag',),
'ukedagene': ('ukedag',),
'ukedager': ('ukedag',),
'ukekort': ('ukekort',),
'ukekorta': ('ukekort',),
'ukekortene': ('ukekort',),
'ukekortet': ('ukekort',),
'ukekort': ('ukekort',),
'ukekorta': ('ukekort',),
'ukekortene': ('ukekort',),
'ukekortet': ('ukekort',),
'ukelønn': ('ukelønn',),
'ukelønna': ('ukelønn',),
'ukelønnen': ('ukelønn',),
'ukelønnene': ('ukelønn',),
'ukelønner': ('ukelønn',),
'ukelønn': ('ukelønn',),
'ukelønna': ('ukelønn',),
'ukelønnen': ('ukelønn',),
'ukelønnene': ('ukelønn',),
'ukelønner': ('ukelønn',),
'ukependler': ('ukependler',),
'ukependlere': ('ukependler',),
'ukependleren': ('ukependler',),
'ukependlerer': ('ukependler',),
'ukependlerne': ('ukependler',),
'ukependler': ('ukependler',),
'ukependlere': ('ukependler',),
'ukependleren': ('ukependler',),
'ukependlerer': ('ukependler',),
'ukependlerne': ('ukependler',),
'ukependling': ('ukependling',),
'ukependlinga': ('ukependling',),
'ukependlingen': ('ukependling',),
'ukependlingene': ('ukependling',),
'ukependlinger': ('ukependling',),
'ukependling': ('ukependling',),
'ukependlinga': ('ukependling',),
'ukependlingen': ('ukependling',),
'ukependlingene': ('ukependling',),
'ukependlinger': ('ukependling',),
'ukepengene': ('ukepenger',),
'ukepenger': ('ukepenger',),
'ukepengene': ('ukepenger',),
'ukepenger': ('ukepenger',),
'ukepressa': ('ukepresse',),
'ukepresse': ('ukepresse',),
'ukepressen': ('ukepresse',),
'ukepressene': ('ukepresse',),
'ukepresser': ('ukepresse',),
'ukepressa': ('ukepresse',),
'ukepresse': ('ukepresse',),
'ukepressen': ('ukepresse',),
'ukepressene': ('ukepresse',),
'ukepresser': ('ukepresse',),
'ukeslutt': ('ukeslutt',),
'ukeslutten': ('ukeslutt',),
'ukesluttene': ('ukeslutt',),
'ukeslutter': ('ukeslutt',),
'ukeslutt': ('ukeslutt',),
'ukeslutten': ('ukeslutt',),
'ukesluttene': ('ukeslutt',),
'ukeslutter': ('ukeslutt',),
'ukjennelighet': ('ukjennelighet',),
'ukjenneligheta': ('ukjennelighet',),
'ukjenneligheten': ('ukjennelighet',),
'ukjennelighetene': ('ukjennelighet',),
'ukjenneligheter': ('ukjennelighet',),
'ukjura': ('ukjure',),
'ukjure': ('ukjure',),
'ukjuren': ('ukjure',),
'ukjurene': ('ukjure',),
'ukjurer': ('ukjure',),
'uklarhet': ('uklarhet',),
'uklarheta': ('uklarhet',),
'uklarheten': ('uklarhet',),
'uklarhetene': ('uklarhet',),
'uklarheter': ('uklarhet',),
'ukrainer': ('ukrainer',),
'ukrainere': ('ukrainer',),
'ukraineren': ('ukrainer',),
'ukrainerer': ('ukrainer',),
'ukrainerne': ('ukrainer',),
'ukrutt': ('ukrutt',),
'ukrutta': ('ukrutt',),
'ukruttene': ('ukrutt',),
'ukruttet': ('ukrutt',),
'ukulele': ('ukulele',),
'ukulelen': ('ukulele',),
'ukulelene': ('ukulele',),
'ukuleler': ('ukulele',),
'ukultur': ('ukultur',),
'ukulturen': ('ukultur',),
'ukulturene': ('ukultur',),
'ukulturer': ('ukultur',),
'ukunst': ('ukunst',),
'ukunsten': ('ukunst',),
'ukunstene': ('ukunst',),
'ukunster': ('ukunst',),
'ukvemsord': ('ukvemsord',),
'ukvemsorda': ('ukvemsord',),
'ukvemsordene': ('ukvemsord',),
'ukvemsordet': ('ukvemsord',),
'ul': ('ul',),
'ula': ('ul',),
'ulene': ('ul',),
'ulet': ('ul',),
'ulag': ('ulag',),
'ulage': ('ulage',),
'uleilighet': ('uleilighet',),
'uleiligheta': ('uleilighet',),
'uleiligheten': ('uleilighet',),
'uleilighetene': ('uleilighet',),
'uleiligheter': ('uleilighet',),
'ulempa': ('ulempe',),
'ulempe': ('ulempe',),
'ulempen': ('ulempe',),
'ulempene': ('ulempe',),
'ulemper': ('ulempe',),
'ulempeerstatning': ('ulempeerstatning',),
'ulempeerstatninga': ('ulempeerstatning',),
'ulempeerstatningen': ('ulempeerstatning',),
'ulempeerstatningene': ('ulempeerstatning',),
'ulempeerstatninger': ('ulempeerstatning',),
'ulenda': ('ulende',),
'ulende': ('ulende',),
'ulendene': ('ulende',),
'ulendet': ('ulende',),
'ulikhet': ('ulikhet',),
'ulikheta': ('ulikhet',),
'ulikheten': ('ulikhet',),
'ulikhetene': ('ulikhet',),
'ulikheter': ('ulikhet',),
'ulivssår': ('ulivssår',),
'ulivssåra': ('ulivssår',),
'ulivssårene': ('ulivssår',),
'ulivssåret': ('ulivssår',),
'ulk': ('ulk',),
'ulken': ('ulk',),
'ulkene': ('ulk',),
'ulker': ('ulk',),
'ulka': ('ulke',),
'ulke': ('ulke',),
'ulken': ('ulke',),
'ulkene': ('ulke',),
'ulker': ('ulke',),
'ulkefisk': ('ulkefisk',),
'ulkefisken': ('ulkefisk',),
'ulkefiskene': ('ulkefisk',),
'ulkefisker': ('ulkefisk',),
'ull': ('ull',),
'ulla': ('ull',),
'ullen': ('ull',),
'ullene': ('ull',),
'uller': ('ull',),
'ull-longs': ('ull-longs',),
'ull-longsen': ('ull-longs',),
'ull-longsene': ('ull-longs',),
'ull-lus': ('ull-lus',),
'ull-lusa': ('ull-lus',),
'ull-lusen': ('ull-lus',),
'ull-lusene': ('ull-lus',),
'ullapa': ('ullape',),
'ullape': ('ullape',),
'ullapen': ('ullape',),
'ullapene': ('ullape',),
'ullaper': ('ullape',),
'ullfett': ('ullfett',),
'ullfetta': ('ullfett',),
'ullfettene': ('ullfett',),
'ullfettet': ('ullfett',),
'ullgenser': ('ullgenser',),
'ullgensere': ('ullgenser',),
'ullgenseren': ('ullgenser',),
'ullgenserer': ('ullgenser',),
'ullgenserne': ('ullgenser',),
'ullhår': ('ullhår',),
'ullhåra': ('ullhår',),
'ullhårene': ('ullhår',),
'ullhåret': ('ullhår',),
'ullmus': ('ullmus',),
'ullmusa': ('ullmus',),
'ullmusen': ('ullmus',),
'ullmusene': ('ullmus',),
'ullongs': ('ullongs',),
'ullongsen': ('ullongs',),
'ullongsene': ('ullongs',),
'ullrotta': ('ullrotte',),
'ullrotte': ('ullrotte',),
'ullrotten': ('ullrotte',),
'ullrottene': ('ullrotte',),
'ullrotter': ('ullrotte',),
'ullstrømpa': ('ullstrømpe',),
'ullstrømpe': ('ullstrømpe',),
'ullstrømpen': ('ullstrømpe',),
'ullstrømpene': ('ullstrømpe',),
'ullstrømper': ('ullstrømpe',),
'ullteppa': ('ullteppe',),
'ullteppe': ('ullteppe',),
'ullteppene': ('ullteppe',),
'ulltepper': ('ullteppe',),
'ullteppet': ('ullteppe',),
'ullurt': ('ullurt',),
'ullurta': ('ullurt',),
'ullurten': ('ullurt',),
'ullurtene': ('ullurt',),
'ullurter': ('ullurt',),
'ullus': ('ullus',),
'ullusa': ('ullus',),
'ullusen': ('ullus',),
'ullusene': ('ullus',),
'ullvara': ('ullvare',),
'ullvare': ('ullvare',),
'ullvaren': ('ullvare',),
'ullvarene': ('ullvare',),
'ullvarer': ('ullvare',),
'ullvarefabrikk': ('ullvarefabrikk',),
'ullvarefabrikken': ('ullvarefabrikk',),
'ullvarefabrikkene': ('ullvarefabrikk',),
'ullvarefabrikker': ('ullvarefabrikk',),
'ullvoks': ('ullvoks',),
'ullvoksa': ('ullvoks',),
'ullvoksen': ('ullvoks',),
'ullvoksene': ('ullvoks',),
'ullvokser': ('ullvoks',),
'ullvokset': ('ullvoks',),
'ulov': ('ulov',),
'ulovlighet': ('ulovlighet',),
'ulovligheta': ('ulovlighet',),
'ulovligheten': ('ulovlighet',),
'ulovlighetene': ('ulovlighet',),
'ulovligheter': ('ulovlighet',),
'ulster': ('ulster',),
'ulstere': ('ulster',),
'ulsteren': ('ulster',),
'ulsterne': ('ulster',),
'ulstre': ('ulster',),
'ulstrene': ('ulster',),
'ulstrer': ('ulster',),
'ultimata': ('ultimatum',),
'ultimataene': ('ultimatum',),
'ultimatum': ('ultimatum',),
'ultimatuma': ('ultimatum',),
'ultimatumene': ('ultimatum',),
'ultimatumer': ('ultimatum',),
'ultimatumet': ('ultimatum',),
'ultralyd': ('ultralyd',),
'ultralyden': ('ultralyd',),
'ultralydene': ('ultralyd',),
'ultralyder': ('ultralyd',),
'ultramarin': ('ultramarin',),
'ultramarina': ('ultramarin',),
'ultramarinen': ('ultramarin',),
'ultramarinene': ('ultramarin',),
'ultramariner': ('ultramarin',),
'ultramarinet': ('ultramarin',),
'ulv': ('ulv',),
'ulven': ('ulv',),
'ulvene': ('ulv',),
'ulver': ('ulv',),
'ulvebinna': ('ulvebinne',),
'ulvebinne': ('ulvebinne',),
'ulvebinnen': ('ulvebinne',),
'ulvebinnene': ('ulvebinne',),
'ulvebinner': ('ulvebinne',),
'ulveedderkopp': ('ulveedderkopp',),
'ulveedderkoppen': ('ulveedderkopp',),
'ulveedderkoppene': ('ulveedderkopp',),
'ulveedderkopper': ('ulveedderkopp',),
'ulvegrav': ('ulvegrav',),
'ulvegrava': ('ulvegrav',),
'ulvegraven': ('ulvegrav',),
'ulvegravene': ('ulvegrav',),
'ulvegraver': ('ulvegrav',),
'ulvehi': ('ulvehi',),
'ulvehia': ('ulvehi',),
'ulvehiene': ('ulvehi',),
'ulvehiet': ('ulvehi',),
'ulvehund': ('ulvehund',),
'ulvehunden': ('ulvehund',),
'ulvehundene': ('ulvehund',),
'ulvehunder': ('ulvehund',),
'ulvemelk': ('ulvemelk',),
'ulvemelka': ('ulvemelk',),
'ulvemelken': ('ulvemelk',),
'ulvemelkene': ('ulvemelk',),
'ulvemelker': ('ulvemelk',),
'ulvemjølk': ('ulvemjølk',),
'ulvemjølka': ('ulvemjølk',),
'ulvemjølken': ('ulvemjølk',),
'ulvemjølkene': ('ulvemjølk',),
'ulvemjølker': ('ulvemjølk',),
'ulvestova': ('ulvestove',),
'ulvestove': ('ulvestove',),
'ulvestoven': ('ulvestove',),
'ulvestovene': ('ulvestove',),
'ulvestover': ('ulvestove',),
'ulvestua': ('ulvestue',),
'ulvestue': ('ulvestue',),
'ulvestuen': ('ulvestue',),
'ulvestuene': ('ulvestue',),
'ulvestuer': ('ulvestue',),
'ulvetid': ('ulvetid',),
'ulvetida': ('ulvetid',),
'ulvetiden': ('ulvetid',),
'ulvetidene': ('ulvetid',),
'ulvetider': ('ulvetid',),
'ulveunge': ('ulveunge',),
'ulveungen': ('ulveunge',),
'ulveungene': ('ulveunge',),
'ulveunger': ('ulveunge',),
'ulvinna': ('ulvinne',),
'ulvinne': ('ulvinne',),
'ulvinnen': ('ulvinne',),
'ulvinnene': ('ulvinne',),
'ulvinner': ('ulvinne',),
'ulvunge': ('ulvunge',),
'ulvungen': ('ulvunge',),
'ulvungene': ('ulvunge',),
'ulvunger': ('ulvunge',),
'ulvunge': ('ulvunge',),
'ulvungen': ('ulvunge',),
'ulvungene': ('ulvunge',),
'ulvunger': ('ulvunge',),
'ulvunge': ('ulvunge',),
'ulvungen': ('ulvunge',),
'ulvungene': ('ulvunge',),
'ulvunger': ('ulvunge',),
'ulyd': ('ulyd',),
'ulyden': ('ulyd',),
'ulydene': ('ulyd',),
'ulyder': ('ulyd',),
'ulydighet': ('ulydighet',),
'ulydigheta': ('ulydighet',),
'ulydigheten': ('ulydighet',),
'ulydighetene': ('ulydighet',),
'ulydigheter': ('ulydighet',),
'ulykka': ('ulykke',),
'ulykke': ('ulykke',),
'ulykken': ('ulykke',),
'ulykkene': ('ulykke',),
'ulykker': ('ulykke',),
'ulykkesassuranse': ('ulykkesassuranse',),
'ulykkesassuransen': ('ulykkesassuranse',),
'ulykkesassuransene': ('ulykkesassuranse',),
'ulykkesassuranser': ('ulykkesassuranse',),
'ulykkesbil': ('ulykkesbil',),
'ulykkesbilen': ('ulykkesbil',),
'ulykkesbilene': ('ulykkesbil',),
'ulykkesbiler': ('ulykkesbil',),
'ulykkesbud': ('ulykkesbud',),
'ulykkesbuda': ('ulykkesbud',),
'ulykkesbudene': ('ulykkesbud',),
'ulykkesbudet': ('ulykkesbud',),
'ulykkesbudskap': ('ulykkesbudskap',),
'ulykkesbudskapa': ('ulykkesbudskap',),
'ulykkesbudskapene': ('ulykkesbudskap',),
'ulykkesbudskaper': ('ulykkesbudskap',),
'ulykkesbudskapet': ('ulykkesbudskap',),
'ulykkesforsikring': ('ulykkesforsikring',),
'ulykkesforsikringa': ('ulykkesforsikring',),
'ulykkesforsikringen': ('ulykkesforsikring',),
'ulykkesforsikringene': ('ulykkesforsikring',),
'ulykkesforsikringer': ('ulykkesforsikring',),
'ulykkesfugl': ('ulykkesfugl',),
'ulykkesfuglen': ('ulykkesfugl',),
'ulykkesfuglene': ('ulykkesfugl',),
'ulykkesfugler': ('ulykkesfugl',),
'ulykkeshendelse': ('ulykkeshendelse',),
'ulykkeshendelsen': ('ulykkeshendelse',),
'ulykkeshendelsene': ('ulykkeshendelse',),
'ulykkeshendelser': ('ulykkeshendelse',),
'ulykkeshending': ('ulykkeshending',),
'ulykkeshendinga': ('ulykkeshending',),
'ulykkeshendingen': ('ulykkeshending',),
'ulykkeshendingene': ('ulykkeshending',),
'ulykkeshendinger': ('ulykkeshending',),
'ulykkesrisiko': ('ulykkesrisiko',),
'ulykkesrisikoen': ('ulykkesrisiko',),
'ulykkesrisikoene': ('ulykkesrisiko',),
'ulykkesrisikoer': ('ulykkesrisiko',),
'ulykkesstatistikk': ('ulykkesstatistikk',),
'ulykkesstatistikken': ('ulykkesstatistikk',),
'ulykkesstatistikkene': ('ulykkesstatistikk',),
'ulykkesstatistikker': ('ulykkesstatistikk',),
'ulykkestilfella': ('ulykkestilfelle',),
'ulykkestilfelle': ('ulykkestilfelle',),
'ulykkestilfellene': ('ulykkestilfelle',),
'ulykkestilfeller': ('ulykkestilfelle',),
'ulykkestilfellet': ('ulykkestilfelle',),
'ulyst': ('ulyst',),
'ulysta': ('ulyst',),
'ulysten': ('ulyst',),
'ulystene': ('ulyst',),
'ulyster': ('ulyst',),
'ulystfølelse': ('ulystfølelse',),
'ulystfølelsen': ('ulystfølelse',),
'ulystfølelsene': ('ulystfølelse',),
'ulystfølelser': ('ulystfølelse',),
'ulåt': ('ulåt',),
'ulåten': ('ulåt',),
'ulåtene': ('ulåt',),
'ulåter': ('ulåt',),
'umak': ('umak',),
'umaken': ('umak',),
'umakene': ('umak',),
'umaker': ('umak',),
'umake': ('umake',),
'umaken': ('umake',),
'umakene': ('umake',),
'umaker': ('umake',),
'umbrer': ('umbrer',),
'umbrere': ('umbrer',),
'umbreren': ('umbrer',),
'umbrerer': ('umbrer',),
'umbrerne': ('umbrer',),
'umenneska': ('umenneske',),
'umenneske': ('umenneske',),
'umenneskene': ('umenneske',),
'umennesker': ('umenneske',),
'umennesket': ('umenneske',),
'umiak': ('umiak',),
'umiaken': ('umiak',),
'umiakene': ('umiak',),
'umiaker': ('umiak',),
'umoral': ('umoral',),
'umoralen': ('umoral',),
'umoralene': ('umoral',),
'umoraler': ('umoral',),
'umulighet': ('umulighet',),
'umuligheta': ('umulighet',),
'umuligheten': ('umulighet',),
'umulighetene': ('umulighet',),
'umuligheter': ('umulighet',),
'umulius': ('umulius',),
'umuliusen': ('umulius',),
'umuliusene': ('umulius',),
'umuliuser': ('umulius',),
'umyndighetserklæring': ('umyndighetserklæring',),
'umyndighetserklæringa': ('umyndighetserklæring',),
'umyndighetserklæringen': ('umyndighetserklæring',),
'umyndighetserklæringene': ('umyndighetserklæring',),
'umyndighetserklæringer': ('umyndighetserklæring',),
'unatur': ('unatur',),
'unaturen': ('unatur',),
'unaturene': ('unatur',),
'unaturer': ('unatur',),
'unavn': ('unavn',),
'unavna': ('unavn',),
'unavnene': ('unavn',),
'unavnet': ('unavn',),
'unbrakonøkkel': ('unbrakonøkkel',),
'unbrakonøkkelen': ('unbrakonøkkel',),
'unbrakonøklene': ('unbrakonøkkel',),
'unbrakonøkler': ('unbrakonøkkel',),
'under': ('under',),
'undera': ('under',),
'undere': ('under',),
'underet': ('under',),
'underne': ('under',),
'undra': ('under',),
'undre': ('under',),
'undrene': ('under',),
'undret': ('under',),
'underarm': ('underarm',),
'underarmen': ('underarm',),
'underarmene': ('underarm',),
'underarmer': ('underarm',),
'underart': ('underart',),
'underarta': ('underart',),
'underarten': ('underart',),
'underartene': ('underart',),
'underarter': ('underart',),
'underavdeling': ('underavdeling',),
'underavdelinga': ('underavdeling',),
'underavdelingen': ('underavdeling',),
'underavdelingene': ('underavdeling',),
'underavdelinger': ('underavdeling',),
'underbalanse': ('underbalanse',),
'underbalansen': ('underbalanse',),
'underbalansene': ('underbalanse',),
'underbalanser': ('underbalanse',),
'underbefal': ('underbefal',),
'underbefala': ('underbefal',),
'underbefalene': ('underbefal',),
'underbefalet': ('underbefal',),
'underbemanning': ('underbemanning',),
'underbemanninga': ('underbemanning',),
'underbemanningen': ('underbemanning',),
'underbemanningene': ('underbemanning',),
'underbemanninger': ('underbemanning',),
'underbeskjeftigelse': ('underbeskjeftigelse',),
'underbeskjeftigelsen': ('underbeskjeftigelse',),
'underbeskjeftigelsene': ('underbeskjeftigelse',),
'underbeskjeftigelser': ('underbeskjeftigelse',),
'underbevissthet': ('underbevissthet',),
'underbevisstheta': ('underbevissthet',),
'underbevisstheten': ('underbevissthet',),
'underbevissthetene': ('underbevissthet',),
'underbevisstheter': ('underbevissthet',),
'underbitt': ('underbitt',),
'underbitta': ('underbitt',),
'underbittene': ('underbitt',),
'underbittet': ('underbitt',),
'underbredsel': ('underbredsel',),
'underbredselet': ('underbredsel',),
'underbredsla': ('underbredsel',),
'underbredslene': ('underbredsel',),
'underbredsler': ('underbredsel',),
'underbredslet': ('underbredsel',),
'underbruk': ('underbruk',),
'underbruka': ('underbruk',),
'underbrukene': ('underbruk',),
'underbruket': ('underbruk',),
'underbud': ('underbud',),
'underbuda': ('underbud',),
'underbudene': ('underbud',),
'underbudet': ('underbud',),
'underbuksa': ('underbukse',),
'underbukse': ('underbukse',),
'underbuksen': ('underbukse',),
'underbuksene': ('underbukse',),
'underbukser': ('underbukse',),
'underbuksehumor': ('underbuksehumor',),
'underbuksehumoren': ('underbuksehumor',),
'underbuksehumorene': ('underbuksehumor',),
'underbuksehumorer': ('underbuksehumor',),
'underdekk': ('underdekk',),
'underdekka': ('underdekk',),
'underdekkene': ('underdekk',),
'underdekket': ('underdekk',),
'underdel': ('underdel',),
'underdelen': ('underdel',),
'underdelene': ('underdel',),
'underdeler': ('underdel',),
'underdirektør': ('underdirektør',),
'underdirektøren': ('underdirektør',),
'underdirektørene': ('underdirektør',),
'underdirektører': ('underdirektør',),
'underdog': ('underdog',),
'underdogen': ('underdog',),
'underdogene': ('underdog',),
'underdoger': ('underdog',),
'underdommer': ('underdommer',),
'underdommere': ('underdommer',),
'underdommeren': ('underdommer',),
'underdommerer': ('underdommer',),
'underdommerne': ('underdommer',),
'underdrivelse': ('underdrivelse',),
'underdrivelsen': ('underdrivelse',),
'underdrivelsene': ('underdrivelse',),
'underdrivelser': ('underdrivelse',),
'underdønning': ('underdønning',),
'underdønninga': ('underdønning',),
'underdønningen': ('underdønning',),
'underdønningene': ('underdønning',),
'underdønninger': ('underdønning',),
'underekstremitet': ('underekstremitet',),
'underekstremiteten': ('underekstremitet',),
'underekstremitetene': ('underekstremitet',),
'underekstremiteter': ('underekstremitet',),
'underentreprenør': ('underentreprenør',),
'underentreprenøren': ('underentreprenør',),
'underentreprenørene': ('underentreprenør',),
'underentreprenører': ('underentreprenør',),
'underernæring': ('underernæring',),
'underernæringa': ('underernæring',),
'underernæringen': ('underernæring',),
'underernæringene': ('underernæring',),
'underernæringer': ('underernæring',),
'underetasje': ('underetasje',),
'underetasjen': ('underetasje',),
'underetasjene': ('underetasje',),
'underetasjer': ('underetasje',),
'underfamilie': ('underfamilie',),
'underfamilien': ('underfamilie',),
'underfamiliene': ('underfamilie',),
'underfamilier': ('underfamilie',),
'underfundighet': ('underfundighet',),
'underfundigheta': ('underfundighet',),
'underfundigheten': ('underfundighet',),
'underfundighetene': ('underfundighet',),
'underfundigheter': ('underfundighet',),
'undergang': ('undergang',),
'undergangen': ('undergang',),
'undergangene': ('undergang',),
'underganger': ('undergang',),
'undergjær': ('undergjær',),
'undergjæren': ('undergjær',),
'undergjærene': ('undergjær',),
'undergjærer': ('undergjær',),
'undergravingsarbeid': ('undergravingsarbeid',),
'undergravingsarbeida': ('undergravingsarbeid',),
'undergravingsarbeidene': ('undergravingsarbeid',),
'undergravingsarbeidet': ('undergravingsarbeid',),
'undergravningsarbeid': ('undergravningsarbeid',),
'undergravningsarbeida': ('undergravningsarbeid',),
'undergravningsarbeidene': ('undergravningsarbeid',),
'undergravningsarbeider': ('undergravningsarbeid',),
'undergravningsarbeidet': ('undergravningsarbeid',),
'undergrunn': ('undergrunn',),
'undergrunnen': ('undergrunn',),
'undergrunnene': ('undergrunn',),
'undergrunner': ('undergrunn',),
'undergrunnsbane': ('undergrunnsbane',),
'undergrunnsbanen': ('undergrunnsbane',),
'undergrunnsbanene': ('undergrunnsbane',),
'undergrunnsbaner': ('undergrunnsbane',),
'undergrunnsbevegelse': ('undergrunnsbevegelse',),
'undergrunnsbevegelsen': ('undergrunnsbevegelse',),
'undergrunnsbevegelsene': ('undergrunnsbevegelse',),
'undergrunnsbevegelser': ('undergrunnsbevegelse',),
'underhandssalg': ('underhandssalg',),
'underhandssalga': ('underhandssalg',),
'underhandssalgene': ('underhandssalg',),
'underhandssalget': ('underhandssalg',),
'underhold': ('underhold',),
'underholda': ('underhold',),
'underholdene': ('underhold',),
'underholdet': ('underhold',),
'underholder': ('underholder',),
'underholdere': ('underholder',),
'underholderen': ('underholder',),
'underholderer': ('underholder',),
'underholderne': ('underholder',),
'underholdning': ('underholdning',),
'underholdninga': ('underholdning',),
'underholdningen': ('underholdning',),
'underholdningene': ('underholdning',),
'underholdninger': ('underholdning',),
'underholdningsartist': ('underholdningsartist',),
'underholdningsartisten': ('underholdningsartist',),
'underholdningsartistene': ('underholdningsartist',),
'underholdningsartister': ('underholdningsartist',),
'underholdningsavdeling': ('underholdningsavdeling',),
'underholdningsavdelinga': ('underholdningsavdeling',),
'underholdningsavdelingen': ('underholdningsavdeling',),
'underholdningsavdelingene': ('underholdningsavdeling',),
'underholdningsavdelinger': ('underholdningsavdeling',),
'underholdningsbidrag': ('underholdningsbidrag',),
'underholdningsbidraga': ('underholdningsbidrag',),
'underholdningsbidragene': ('underholdningsbidrag',),
'underholdningsbidraget': ('underholdningsbidrag',),
'underholdningslitteratur': ('underholdningslitteratur',),
'underholdningslitteraturen': ('underholdningslitteratur',),
'underholdningslitteraturene': ('underholdningslitteratur',),
'underholdningslitteraturer': ('underholdningslitteratur',),
'underholdningsmusikk': ('underholdningsmusikk',),
'underholdningsmusikken': ('underholdningsmusikk',),
'underholdningsmusikkene': ('underholdningsmusikk',),
'underholdningsmusikker': ('underholdningsmusikk',),
'underholdningsplikt': ('underholdningsplikt',),
'underholdningsplikta': ('underholdningsplikt',),
'underholdningsplikten': ('underholdningsplikt',),
'underholdningspliktene': ('underholdningsplikt',),
'underholdningsplikter': ('underholdningsplikt',),
'underholdningsprogram': ('underholdningsprogram',),
'underholdningsprogramma': ('underholdningsprogram',),
'underholdningsprogrammene': ('underholdningsprogram',),
'underholdningsprogrammer': ('underholdningsprogram',),
'underholdningsprogrammet': ('underholdningsprogram',),
'underholdsbidrag': ('underholdsbidrag',),
'underholdsbidraga': ('underholdsbidrag',),
'underholdsbidragene': ('underholdsbidrag',),
'underholdsbidraget': ('underholdsbidrag',),
'underholdsplikt': ('underholdsplikt',),
'underholdsplikta': ('underholdsplikt',),
'underholdsplikten': ('underholdsplikt',),
'underholdspliktene': ('underholdsplikt',),
'underholdsplikter': ('underholdsplikt',),
'underhud': ('underhud',),
'underhuda': ('underhud',),
'underhuden': ('underhud',),
'underhudene': ('underhud',),
'underhuder': ('underhud',),
'underhus': ('underhus',),
'underhusa': ('underhus',),
'underhusene': ('underhus',),
'underhuset': ('underhus',),
'underhåndssalg': ('underhåndssalg',),
'underhåndssalga': ('underhåndssalg',),
'underhåndssalgene': ('underhåndssalg',),
'underhåndssalget': ('underhåndssalg',),
'underkant': ('underkant',),
'underkanten': ('underkant',),
'underkantene': ('underkant',),
'underkanter': ('underkant',),
'underkastelse': ('underkastelse',),
'underkastelsen': ('underkastelse',),
'underkastelsene': ('underkastelse',),
'underkastelser': ('underkastelse',),
'underkjeve': ('underkjeve',),
'underkjeven': ('underkjeve',),
'underkjevene': ('underkjeve',),
'underkjever': ('underkjeve',),
'underkjole': ('underkjole',),
'underkjolen': ('underkjole',),
'underkjolene': ('underkjole',),
'underkjoler': ('underkjole',),
'underklassa': ('underklasse',),
'underklasse': ('underklasse',),
'underklassen': ('underklasse',),
'underklassene': ('underklasse',),
'underklasser': ('underklasse',),
'underklær': ('underklær',),
'underklærne': ('underklær',),
'underkonge': ('underkonge',),
'underkongen': ('underkonge',),
'underkongene': ('underkonge',),
'underkonger': ('underkonge',),
'underkropp': ('underkropp',),
'underkroppen': ('underkropp',),
'underkroppene': ('underkropp',),
'underkropper': ('underkropp',),
'underkultur': ('underkultur',),
'underkulturen': ('underkultur',),
'underkulturene': ('underkultur',),
'underkulturer': ('underkultur',),
'underkurs': ('underkurs',),
'underkursen': ('underkurs',),
'underkursene': ('underkurs',),
'underkurser': ('underkurs',),
'underkøya': ('underkøye',),
'underkøye': ('underkøye',),
'underkøyen': ('underkøye',),
'underkøyene': ('underkøye',),
'underkøyer': ('underkøye',),
'underlag': ('underlag',),
'underlaga': ('underlag',),
'underlagene': ('underlag',),
'underlaget': ('underlag',),
'underlagsmateriala': ('underlagsmateriale',),
'underlagsmateriale': ('underlagsmateriale',),
'underlagsmaterialene': ('underlagsmateriale',),
'underlagsmaterialer': ('underlagsmateriale',),
'underlagsmaterialet': ('underlagsmateriale',),
'underledd': ('underledd',),
'underledda': ('underledd',),
'underleddene': ('underledd',),
'underleddet': ('underledd',),
'underleppa': ('underleppe',),
'underleppe': ('underleppe',),
'underleppen': ('underleppe',),
'underleppene': ('underleppe',),
'underlepper': ('underleppe',),
'underleverandør': ('underleverandør',),
'underleverandøren': ('underleverandør',),
'underleverandørene': ('underleverandør',),
'underleverandører': ('underleverandør',),
'underligger': ('underligger',),
'underliggere': ('underligger',),
'underliggeren': ('underligger',),
'underliggerer': ('underligger',),
'underliggerne': ('underligger',),
'underliv': ('underliv',),
'underliva': ('underliv',),
'underlivene': ('underliv',),
'underlivet': ('underliv',),
'underlivssjukdom': ('underlivssjukdom',),
'underlivssjukdommen': ('underlivssjukdom',),
'underlivssjukdommene': ('underlivssjukdom',),
'underlivssjukdommer': ('underlivssjukdom',),
'underlivssykdom': ('underlivssykdom',),
'underlivssykdommen': ('underlivssykdom',),
'underlivssykdommene': ('underlivssykdom',),
'underlivssykdommer': ('underlivssykdom',),
'underlivsundersøkelse': ('underlivsundersøkelse',),
'underlivsundersøkelsen': ('underlivsundersøkelse',),
'underlivsundersøkelsene': ('underlivsundersøkelse',),
'underlivsundersøkelser': ('underlivsundersøkelse',),
'underlær': ('underlær',),
'underlæra': ('underlær',),
'underlærene': ('underlær',),
'underlæret': ('underlær',),
'undermenneska': ('undermenneske',),
'undermenneske': ('undermenneske',),
'undermenneskene': ('undermenneske',),
'undermennesker': ('undermenneske',),
'undermennesket': ('undermenneske',),
'undermunn': ('undermunn',),
'undermunnen': ('undermunn',),
'undermunnene': ('undermunn',),
'undermunner': ('undermunn',),
'undermål': ('undermål',),
'undermåla': ('undermål',),
'undermålene': ('undermål',),
'undermålet': ('undermål',),
'undermåler': ('undermåler',),
'undermålere': ('undermåler',),
'undermåleren': ('undermåler',),
'undermålerer': ('undermåler',),
'undermålerne': ('undermåler',),
'underoffiser': ('underoffiser',),
'underoffiseren': ('underoffiser',),
'underoffiserene': ('underoffiser',),
'underoffiserer': ('underoffiser',),
'underoffisersskole': ('underoffisersskole',),
'underoffisersskolen': ('underoffisersskole',),
'underoffisersskolene': ('underoffisersskole',),
'underoffisersskoler': ('underoffisersskole',),
'underordning': ('underordning',),
'underordninga': ('underordning',),
'underordningen': ('underordning',),
'underordningene': ('underordning',),
'underordninger': ('underordning',),
'underpris': ('underpris',),
'underprisen': ('underpris',),
'underprisene': ('underpris',),
'underpriser': ('underpris',),
'underretning': ('underretning',),
'underretninga': ('underretning',),
'underretningen': ('underretning',),
'underretningene': ('underretning',),
'underretninger': ('underretning',),
'underrett': ('underrett',),
'underretten': ('underrett',),
'underrettene': ('underrett',),
'underretter': ('underrett',),
'undersegl': ('undersegl',),
'undersegla': ('undersegl',),
'underseglene': ('undersegl',),
'underseglet': ('undersegl',),
'underseil': ('underseil',),
'underseila': ('underseil',),
'underseilene': ('underseil',),
'underseilet': ('underseil',),
'undersetning': ('undersetning',),
'undersetninga': ('undersetning',),
'undersetningen': ('undersetning',),
'undersetningene': ('undersetning',),
'undersetninger': ('undersetning',),
'undersida': ('underside',),
'underside': ('underside',),
'undersiden': ('underside',),
'undersidene': ('underside',),
'undersider': ('underside',),
'underskjønn': ('underskjønn',),
'underskjønna': ('underskjønn',),
'underskjønnene': ('underskjønn',),
'underskjønnet': ('underskjønn',),
'underskjørt': ('underskjørt',),
'underskjørta': ('underskjørt',),
'underskjørtene': ('underskjørt',),
'underskjørter': ('underskjørt',),
'underskjørtet': ('underskjørt',),
'underskog': ('underskog',),
'underskogen': ('underskog',),
'underskogene': ('underskog',),
'underskoger': ('underskog',),
'underskott': ('underskott',),
'underskotta': ('underskott',),
'underskottene': ('underskott',),
'underskottet': ('underskott',),
'underskottsforetagende': ('underskottsforetagende',),
'underskottsforetagendene': ('underskottsforetagende',),
'underskottsforetagender': ('underskottsforetagende',),
'underskottsforetagendet': ('underskottsforetagende',),
'underskottsforetak': ('underskottsforetak',),
'underskottsforetaka': ('underskottsforetak',),
'underskottsforetakene': ('underskottsforetak',),
'underskottsforetaket': ('underskottsforetak',),
'underskottsforetakende': ('underskottsforetakende',),
'underskottsforetakendene': ('underskottsforetakende',),
'underskottsforetakender': ('underskottsforetakende',),
'underskottsforetakendet': ('underskottsforetakende',),
'underskrift': ('underskrift',),
'underskrifta': ('underskrift',),
'underskriften': ('underskrift',),
'underskriftene': ('underskrift',),
'underskrifter': ('underskrift',),
'underskriftskampanje': ('underskriftskampanje',),
'underskriftskampanjen': ('underskriftskampanje',),
'underskriftskampanjene': ('underskriftskampanje',),
'underskriftskampanjer': ('underskriftskampanje',),
'underskriver': ('underskriver',),
'underskrivere': ('underskriver',),
'underskriveren': ('underskriver',),
'underskriverer': ('underskriver',),
'underskriverne': ('underskriver',),
'underskudd': ('underskudd',),
'underskudda': ('underskudd',),
'underskuddene': ('underskudd',),
'underskuddet': ('underskudd',),
'underskuddsforetagende': ('underskuddsforetagende',),
'underskuddsforetagendene': ('underskuddsforetagende',),
'underskuddsforetagender': ('underskuddsforetagende',),
'underskuddsforetagendet': ('underskuddsforetagende',),
'underskuddsforetak': ('underskuddsforetak',),
'underskuddsforetaka': ('underskuddsforetak',),
'underskuddsforetakene': ('underskuddsforetak',),
'underskuddsforetaket': ('underskuddsforetak',),
'underskuddsforetakende': ('underskuddsforetakende',),
'underskuddsforetakendene': ('underskuddsforetakende',),
'underskuddsforetakender': ('underskuddsforetakende',),
'underskuddsforetakendet': ('underskuddsforetakende',),
'underslag': ('underslag',),
'underslaga': ('underslag',),
'underslagene': ('underslag',),
'underslaget': ('underslag',),
'underslager': ('underslager',),
'underslagere': ('underslager',),
'underslageren': ('underslager',),
'underslagerer': ('underslager',),
'underslagerne': ('underslager',),
'understatement': ('understatement',),
'understatementa': ('understatement',),
'understatementene': ('understatement',),
'understatementet': ('understatement',),
'understell': ('understell',),
'understella': ('understell',),
'understellene': ('understell',),
'understellet': ('understell',),
'understellsbehandling': ('understellsbehandling',),
'understellsbehandlinga': ('understellsbehandling',),
'understellsbehandlingen': ('understellsbehandling',),
'understellsbehandlingene': ('understellsbehandling',),
'understellsbehandlinger': ('understellsbehandling',),
'understemme': ('understemme',),
'understemmen': ('understemme',),
'understemmene': ('understemme',),
'understemmer': ('understemme',),
'understikk': ('understikk',),
'understikka': ('understikk',),
'understikkene': ('understikk',),
'understikket': ('understikk',),
'understreking': ('understreking',),
'understrekinga': ('understreking',),
'understrekingen': ('understreking',),
'understrekingene': ('understreking',),
'understrekinger': ('understreking',),
'understrekning': ('understrekning',),
'understrekninga': ('understrekning',),
'understrekningen': ('understrekning',),
'understrekningene': ('understrekning',),
'understrekninger': ('understrekning',),
'understreng': ('understreng',),
'understrengen': ('understreng',),
'understrengene': ('understreng',),
'understrenger': ('understreng',),
'understryking': ('understryking',),
'understrykinga': ('understryking',),
'understrykingen': ('understryking',),
'understrykingene': ('understryking',),
'understrykinger': ('understryking',),
'understrykning': ('understrykning',),
'understrykninga': ('understrykning',),
'understrykningen': ('understrykning',),
'understrykningene': ('understrykning',),
'understrykninger': ('understrykning',),
'understrøm': ('understrøm',),
'understrømmen': ('understrøm',),
'understrømmene': ('understrøm',),
'understrømmer': ('understrøm',),
'understøttelse': ('understøttelse',),
'understøttelsen': ('understøttelse',),
'understøttelsene': ('understøttelse',),
'understøttelser': ('understøttelse',),
'understøtting': ('understøtting',),
'understøttinga': ('understøtting',),
'understøttingen': ('understøtting',),
'understøttingene': ('understøtting',),
'understøttinger': ('understøtting',),
'undersått': ('undersått',),
'undersåtten': ('undersått',),
'undersåttene': ('undersått',),
'undersåtter': ('undersått',),
'undersøkelse': ('undersøkelse',),
'undersøkelsen': ('undersøkelse',),
'undersøkelsene': ('undersøkelse',),
'undersøkelser': ('undersøkelse',),
'undersøkelseskommisjon': ('undersøkelseskommisjon',),
'undersøkelseskommisjonen': ('undersøkelseskommisjon',),
'undersøkelseskommisjonene': ('undersøkelseskommisjon',),
'undersøkelseskommisjoner': ('undersøkelseskommisjon',),
'undersøking': ('undersøking',),
'undersøkinga': ('undersøking',),
'undersøkingen': ('undersøking',),
'undersøkingene': ('undersøking',),
'undersøkinger': ('undersøking',),
'undertak': ('undertak',),
'undertaka': ('undertak',),
'undertakene': ('undertak',),
'undertaket': ('undertak',),
'undertann': ('undertann',),
'undertanna': ('undertann',),
'undertannen': ('undertann',),
'undertennene': ('undertann',),
'undertenner': ('undertann',),
'undertegner': ('undertegner',),
'undertegnere': ('undertegner',),
'undertegneren': ('undertegner',),
'undertegnerer': ('undertegner',),
'undertegnerne': ('undertegner',),
'undertitlene': ('undertittel',),
'undertitler': ('undertittel',),
'undertittel': ('undertittel',),
'undertittelen': ('undertittel',),
'undertone': ('undertone',),
'undertonen': ('undertone',),
'undertonene': ('undertone',),
'undertoner': ('undertone',),
'undertrykk': ('undertrykk',),
'undertrykka': ('undertrykk',),
'undertrykkene': ('undertrykk',),
'undertrykket': ('undertrykk',),
'undertrykkelse': ('undertrykkelse',),
'undertrykkelsen': ('undertrykkelse',),
'undertrykkelsene': ('undertrykkelse',),
'undertrykkelser': ('undertrykkelse',),
'undertrykkelsesmekanisme': ('undertrykkelsesmekanisme',),
'undertrykkelsesmekanismen': ('undertrykkelsesmekanisme',),
'undertrykkelsesmekanismene': ('undertrykkelsesmekanisme',),
'undertrykkelsesmekanismer': ('undertrykkelsesmekanisme',),
'undertrykker': ('undertrykker',),
'undertrykkere': ('undertrykker',),
'undertrykkeren': ('undertrykker',),
'undertrykkerer': ('undertrykker',),
'undertrykkerne': ('undertrykker',),
'undertrykking': ('undertrykking',),
'undertrykkinga': ('undertrykking',),
'undertrykkingen': ('undertrykking',),
'undertrykkingene': ('undertrykking',),
'undertrykkinger': ('undertrykking',),
'undertrykkingsmekanisme': ('undertrykkingsmekanisme',),
'undertrykkingsmekanismen': ('undertrykkingsmekanisme',),
'undertrykkingsmekanismene': ('undertrykkingsmekanisme',),
'undertrykkingsmekanismer': ('undertrykkingsmekanisme',),
'undertråd': ('undertråd',),
'undertråden': ('undertråd',),
'undertrådene': ('undertråd',),
'undertråder': ('undertråd',),
'undertrøya': ('undertrøye',),
'undertrøye': ('undertrøye',),
'undertrøyen': ('undertrøye',),
'undertrøyene': ('undertrøye',),
'undertrøyer': ('undertrøye',),
'undertøy': ('undertøy',),
'undertøya': ('undertøy',),
'undertøyene': ('undertøy',),
'undertøyer': ('undertøy',),
'undertøyet': ('undertøy',),
'undertøyforretning': ('undertøyforretning',),
'undertøyforretninga': ('undertøyforretning',),
'undertøyforretningen': ('undertøyforretning',),
'undertøyforretningene': ('undertøyforretning',),
'undertøyforretninger': ('undertøyforretning',),
'undertøysforretning': ('undertøysforretning',),
'undertøysforretninga': ('undertøysforretning',),
'undertøysforretningen': ('undertøysforretning',),
'undertøysforretningene': ('undertøysforretning',),
'undertøysforretninger': ('undertøysforretning',),
'undervannsbåt': ('undervannsbåt',),
'undervannsbåten': ('undervannsbåt',),
'undervannsbåtene': ('undervannsbåt',),
'undervannsbåter': ('undervannsbåt',),
'undervannsskjær': ('undervannsskjær',),
'undervannsskjæra': ('undervannsskjær',),
'undervannsskjærene': ('undervannsskjær',),
'undervannsskjæret': ('undervannsskjær',),
'undervannssport': ('undervannssport',),
'undervannssporten': ('undervannssport',),
'undervannssportene': ('undervannssport',),
'undervannssporter': ('undervannssport',),
'undervarme': ('undervarme',),
'undervarmen': ('undervarme',),
'undervarmene': ('undervarme',),
'undervarmer': ('undervarme',),
'undervassbåt': ('undervassbåt',),
'undervassbåten': ('undervassbåt',),
'undervassbåtene': ('undervassbåt',),
'undervassbåter': ('undervassbåt',),
'undervekt': ('undervekt',),
'undervekta': ('undervekt',),
'undervekten': ('undervekt',),
'undervektene': ('undervekt',),
'undervekter': ('undervekt',),
'underverden': ('underverden',),
'underverdenen': ('underverden',),
'underverdenene': ('underverden',),
'underverdener': ('underverden',),
'underverk': ('underverk',),
'underverka': ('underverk',),
'underverkene': ('underverk',),
'underverker': ('underverk',),
'underverket': ('underverk',),
'underviser': ('underviser',),
'undervisere': ('underviser',),
'underviseren': ('underviser',),
'underviserer': ('underviser',),
'underviserne': ('underviser',),
'undervisning': ('undervisning',),
'undervisninga': ('undervisning',),
'undervisningen': ('undervisning',),
'undervisningene': ('undervisning',),
'undervisninger': ('undervisning',),
'undervisningsdepartement': ('undervisningsdepartement',),
'undervisningsdepartementa': ('undervisningsdepartement',),
'undervisningsdepartementene': ('undervisningsdepartement',),
'undervisningsdepartementer': ('undervisningsdepartement',),
'undervisningsdepartementet': ('undervisningsdepartement',),
'undervisningsfag': ('undervisningsfag',),
'undervisningsfaga': ('undervisningsfag',),
'undervisningsfagene': ('undervisningsfag',),
'undervisningsfaget': ('undervisningsfag',),
'undervisningsinspektør': ('undervisningsinspektør',),
'undervisningsinspektøren': ('undervisningsinspektør',),
'undervisningsinspektørene': ('undervisningsinspektør',),
'undervisningsinspektører': ('undervisningsinspektør',),
'undervisningsmateriell': ('undervisningsmateriell',),
'undervisningsmateriella': ('undervisningsmateriell',),
'undervisningsmateriellene': ('undervisningsmateriell',),
'undervisningsmateriellet': ('undervisningsmateriell',),
'undervisningsplikt': ('undervisningsplikt',),
'undervisningsplikta': ('undervisningsplikt',),
'undervisningsplikten': ('undervisningsplikt',),
'undervisningspliktene': ('undervisningsplikt',),
'undervisningsplikter': ('undervisningsplikt',),
'undervisningstilbud': ('undervisningstilbud',),
'undervisningstilbuda': ('undervisningstilbud',),
'undervisningstilbudene': ('undervisningstilbud',),
'undervisningstilbudet': ('undervisningstilbud',),
'underåring': ('underåring',),
'underåringen': ('underåring',),
'underåringene': ('underåring',),
'underåringer': ('underåring',),
'undina': ('undine',),
'undine': ('undine',),
'undinen': ('undine',),
'undinene': ('undine',),
'undiner': ('undine',),
'undring': ('undring',),
'undringa': ('undring',),
'undringen': ('undring',),
'undringene': ('undring',),
'undringer': ('undring',),
'undulansfeber': ('undulansfeber',),
'undulansfebere': ('undulansfeber',),
'undulansfeberen': ('undulansfeber',),
'undulansfeberne': ('undulansfeber',),
'undulansfebre': ('undulansfeber',),
'undulansfebrene': ('undulansfeber',),
'undulansfebrer': ('undulansfeber',),
'undulasjon': ('undulasjon',),
'undulasjonen': ('undulasjon',),
'undulasjonene': ('undulasjon',),
'undulasjoner': ('undulasjon',),
'undulat': ('undulat',),
'undulaten': ('undulat',),
'undulatene': ('undulat',),
'undulater': ('undulat',),
'ungarer': ('ungarer',),
'ungarere': ('ungarer',),
'ungareren': ('ungarer',),
'ungarerer': ('ungarer',),
'ungarerne': ('ungarer',),
'ungarsk': ('ungarsk',),
'ungarsken': ('ungarsk',),
'ungarskene': ('ungarsk',),
'ungarsker': ('ungarsk',),
'ungdom': ('ungdom',),
'ungdommen': ('ungdom',),
'ungdommene': ('ungdom',),
'ungdommer': ('ungdom',),
'ungdomsalder': ('ungdomsalder',),
'ungdomsaldere': ('ungdomsalder',),
'ungdomsalderen': ('ungdomsalder',),
'ungdomsalderer': ('ungdomsalder',),
'ungdomsalderne': ('ungdomsalder',),
'ungdomsaldre': ('ungdomsalder',),
'ungdomsaldrene': ('ungdomsalder',),
'ungdomsaldrer': ('ungdomsalder',),
'ungdomsarrest': ('ungdomsarrest',),
'ungdomsarresten': ('ungdomsarrest',),
'ungdomsarrestene': ('ungdomsarrest',),
'ungdomsarrester': ('ungdomsarrest',),
'ungdomsavdeling': ('ungdomsavdeling',),
'ungdomsavdelinga': ('ungdomsavdeling',),
'ungdomsavdelingen': ('ungdomsavdeling',),
'ungdomsavdelingene': ('ungdomsavdeling',),
'ungdomsavdelinger': ('ungdomsavdeling',),
'ungdomsbande': ('ungdomsbande',),
'ungdomsbanden': ('ungdomsbande',),
'ungdomsbandene': ('ungdomsbande',),
'ungdomsbander': ('ungdomsbande',),
'ungdomsdagene': ('ungdomsdager',),
'ungdomsdager': ('ungdomsdager',),
'ungdomsdrøm': ('ungdomsdrøm',),
'ungdomsdrømmen': ('ungdomsdrøm',),
'ungdomsdrømmene': ('ungdomsdrøm',),
'ungdomsdrømmer': ('ungdomsdrøm',),
'ungdomsfengsel': ('ungdomsfengsel',),
'ungdomsfengselet': ('ungdomsfengsel',),
'ungdomsfengsla': ('ungdomsfengsel',),
'ungdomsfengslene': ('ungdomsfengsel',),
'ungdomsfengsler': ('ungdomsfengsel',),
'ungdomsfengslet': ('ungdomsfengsel',),
'ungdomsforbrytelse': ('ungdomsforbrytelse',),
'ungdomsforbrytelsen': ('ungdomsforbrytelse',),
'ungdomsforbrytelsene': ('ungdomsforbrytelse',),
'ungdomsforbrytelser': ('ungdomsforbrytelse',),
'ungdomsforbryter': ('ungdomsforbryter',),
'ungdomsforbrytere': ('ungdomsforbryter',),
'ungdomsforbryteren': ('ungdomsforbryter',),
'ungdomsforbryterer': ('ungdomsforbryter',),
'ungdomsforbryterne': ('ungdomsforbryter',),
'ungdomsherberga': ('ungdomsherberge',),
'ungdomsherberge': ('ungdomsherberge',),
'ungdomsherbergene': ('ungdomsherberge',),
'ungdomsherberger': ('ungdomsherberge',),
'ungdomsherberget': ('ungdomsherberge',),
'ungdomshus': ('ungdomshus',),
'ungdomshusa': ('ungdomshus',),
'ungdomshusene': ('ungdomshus',),
'ungdomshuset': ('ungdomshus',),
'ungdomsideal': ('ungdomsideal',),
'ungdomsideala': ('ungdomsideal',),
'ungdomsidealene': ('ungdomsideal',),
'ungdomsidealer': ('ungdomsideal',),
'ungdomsidealet': ('ungdomsideal',),
'ungdomskjæreste': ('ungdomskjæreste',),
'ungdomskjæresten': ('ungdomskjæreste',),
'ungdomskjærestene': ('ungdomskjæreste',),
'ungdomskjærester': ('ungdomskjæreste',),
'ungdomskjærlighet': ('ungdomskjærlighet',),
'ungdomskjærligheta': ('ungdomskjærlighet',),
'ungdomskjærligheten': ('ungdomskjærlighet',),
'ungdomskjærlighetene': ('ungdomskjærlighet',),
'ungdomskjærligheter': ('ungdomskjærlighet',),
'ungdomsklubb': ('ungdomsklubb',),
'ungdomsklubben': ('ungdomsklubb',),
'ungdomsklubbene': ('ungdomsklubb',),
'ungdomsklubber': ('ungdomsklubb',),
'ungdomskriminalitet': ('ungdomskriminalitet',),
'ungdomskriminaliteten': ('ungdomskriminalitet',),
'ungdomskriminalitetene': ('ungdomskriminalitet',),
'ungdomskriminaliteter': ('ungdomskriminalitet',),
'ungdomskultur': ('ungdomskultur',),
'ungdomskulturen': ('ungdomskultur',),
'ungdomskulturene': ('ungdomskultur',),
'ungdomskulturer': ('ungdomskultur',),
'ungdomslag': ('ungdomslag',),
'ungdomslaga': ('ungdomslag',),
'ungdomslagene': ('ungdomslag',),
'ungdomslaget': ('ungdomslag',),
'ungdomslandskamp': ('ungdomslandskamp',),
'ungdomslandskampen': ('ungdomslandskamp',),
'ungdomslandskampene': ('ungdomslandskamp',),
'ungdomslandskamper': ('ungdomslandskamp',),
'ungdomslandslag': ('ungdomslandslag',),
'ungdomslandslaga': ('ungdomslandslag',),
'ungdomslandslagene': ('ungdomslandslag',),
'ungdomslandslaget': ('ungdomslandslag',),
'ungdomsleder': ('ungdomsleder',),
'ungdomsledere': ('ungdomsleder',),
'ungdomslederen': ('ungdomsleder',),
'ungdomslederer': ('ungdomsleder',),
'ungdomslederne': ('ungdomsleder',),
'ungdomsminna': ('ungdomsminne',),
'ungdomsminne': ('ungdomsminne',),
'ungdomsminnene': ('ungdomsminne',),
'ungdomsminner': ('ungdomsminne',),
'ungdomsminnet': ('ungdomsminne',),
'ungdomsopprør': ('ungdomsopprør',),
'ungdomsopprøra': ('ungdomsopprør',),
'ungdomsopprørene': ('ungdomsopprør',),
'ungdomsopprøret': ('ungdomsopprør',),
'ungdomsskole': ('ungdomsskole',),
'ungdomsskolen': ('ungdomsskole',),
'ungdomsskolene': ('ungdomsskole',),
'ungdomsskoler': ('ungdomsskole',),
'ungdomssløvsinn': ('ungdomssløvsinn',),
'ungdomssløvsinna': ('ungdomssløvsinn',),
'ungdomssløvsinnene': ('ungdomssløvsinn',),
'ungdomssløvsinnet': ('ungdomssløvsinn',),
'ungdomssynd': ('ungdomssynd',),
'ungdomssynda': ('ungdomssynd',),
'ungdomssynden': ('ungdomssynd',),
'ungdomssyndene': ('ungdomssynd',),
'ungdomssynder': ('ungdomssynd',),
'ungdomstid': ('ungdomstid',),
'ungdomstida': ('ungdomstid',),
'ungdomstiden': ('ungdomstid',),
'ungdomstidene': ('ungdomstid',),
'ungdomstider': ('ungdomstid',),
'ungdomstrinn': ('ungdomstrinn',),
'ungdomstrinna': ('ungdomstrinn',),
'ungdomstrinnene': ('ungdomstrinn',),
'ungdomstrinnet': ('ungdomstrinn',),
'ungdomsår': ('ungdomsår',),
'ungdomsåra': ('ungdomsår',),
'ungdomsårene': ('ungdomsår',),
'ungdomsåret': ('ungdomsår',),
'ungdyr': ('ungdyr',),
'ungdyra': ('ungdyr',),
'ungdyrene': ('ungdyr',),
'ungdyret': ('ungdyr',),
'unge': ('unge',),
'ungen': ('unge',),
'ungene': ('unge',),
'unger': ('unge',),
'ungeflokk': ('ungeflokk',),
'ungeflokken': ('ungeflokk',),
'ungeflokkene': ('ungeflokk',),
'ungeflokker': ('ungeflokk',),
'ungemas': ('ungemas',),
'ungemasa': ('ungemas',),
'ungemasene': ('ungemas',),
'ungemaset': ('ungemas',),
'ungersvenn': ('ungersvenn',),
'ungersvennen': ('ungersvenn',),
'ungersvennene': ('ungersvenn',),
'ungersvenner': ('ungersvenn',),
'ungfolk': ('ungfolk',),
'ungfolka': ('ungfolk',),
'ungfolkene': ('ungfolk',),
'ungfolket': ('ungfolk',),
'unggutt': ('unggutt',),
'unggutten': ('unggutt',),
'ungguttene': ('unggutt',),
'unggutter': ('unggutt',),
'unghest': ('unghest',),
'unghesten': ('unghest',),
'unghestene': ('unghest',),
'unghester': ('unghest',),
'ungjenta': ('ungjente',),
'ungjente': ('ungjente',),
'ungjenten': ('ungjente',),
'ungjentene': ('ungjente',),
'ungjenter': ('ungjente',),
'ungkar': ('ungkar',),
'ungkaren': ('ungkar',),
'ungkarene': ('ungkar',),
'ungkarer': ('ungkar',),
'ungkarskvinna': ('ungkarskvinne',),
'ungkarskvinne': ('ungkarskvinne',),
'ungkarskvinnen': ('ungkarskvinne',),
'ungkarskvinnene': ('ungkarskvinne',),
'ungkarskvinner': ('ungkarskvinne',),
'ungkarsstand': ('ungkarsstand',),
'ungkarsstanden': ('ungkarsstand',),
'ungkarsstandene': ('ungkarsstand',),
'ungkarsstander': ('ungkarsstand',),
'ungpika': ('ungpike',),
'ungpike': ('ungpike',),
'ungpiken': ('ungpike',),
'ungpikene': ('ungpike',),
'ungpiker': ('ungpike',),
'ungsau': ('ungsau',),
'ungsauen': ('ungsau',),
'ungsauene': ('ungsau',),
'ungsauer': ('ungsau',),
'ungskog': ('ungskog',),
'ungskogen': ('ungskog',),
'ungskogene': ('ungskog',),
'ungskoger': ('ungskog',),
'uniform': ('uniform',),
'uniforma': ('uniform',),
'uniformen': ('uniform',),
'uniformene': ('uniform',),
'uniformer': ('uniform',),
'uniformisme': ('uniformisme',),
'uniformismen': ('uniformisme',),
'uniformismene': ('uniformisme',),
'uniformismer': ('uniformisme',),
'uniformitet': ('uniformitet',),
'uniformiteten': ('uniformitet',),
'uniformitetene': ('uniformitet',),
'uniformiteter': ('uniformitet',),
'uniformsgodtgjørelse': ('uniformsgodtgjørelse',),
'uniformsgodtgjørelsen': ('uniformsgodtgjørelse',),
'uniformsgodtgjørelsene': ('uniformsgodtgjørelse',),
'uniformsgodtgjørelser': ('uniformsgodtgjørelse',),
'uniformsgodtgjøring': ('uniformsgodtgjøring',),
'uniformsgodtgjøringa': ('uniformsgodtgjøring',),
'uniformsgodtgjøringen': ('uniformsgodtgjøring',),
'uniformsgodtgjøringene': ('uniformsgodtgjøring',),
'uniformsgodtgjøringer': ('uniformsgodtgjøring',),
'uniformsjakka': ('uniformsjakke',),
'uniformsjakke': ('uniformsjakke',),
'uniformsjakken': ('uniformsjakke',),
'uniformsjakkene': ('uniformsjakke',),
'uniformsjakker': ('uniformsjakke',),
'uniformslua': ('uniformslue',),
'uniformslue': ('uniformslue',),
'uniformsluen': ('uniformslue',),
'uniformsluene': ('uniformslue',),
'uniformsluer': ('uniformslue',),
'uniformsluva': ('uniformsluve',),
'uniformsluve': ('uniformsluve',),
'uniformsluven': ('uniformsluve',),
'uniformsluvene': ('uniformsluve',),
'uniformsluver': ('uniformsluve',),
'unikum': ('unikum',),
'unikuma': ('unikum',),
'unikumene': ('unikum',),
'unikumer': ('unikum',),
'unikumet': ('unikum',),
'union': ('union',),
'unionen': ('union',),
'unionene': ('union',),
'unioner': ('union',),
'unionist': ('unionist',),
'unionisten': ('unionist',),
'unionistene': ('unionist',),
'unionister': ('unionist',),
'unionsflagg': ('unionsflagg',),
'unionsflagga': ('unionsflagg',),
'unionsflaggene': ('unionsflagg',),
'unionsflagget': ('unionsflagg',),
'unionskonge': ('unionskonge',),
'unionskongen': ('unionskonge',),
'unionskongene': ('unionskonge',),
'unionskonger': ('unionskonge',),
'unionsmerka': ('unionsmerke',),
'unionsmerke': ('unionsmerke',),
'unionsmerkene': ('unionsmerke',),
'unionsmerker': ('unionsmerke',),
'unionsmerket': ('unionsmerke',),
'unionsoppløsning': ('unionsoppløsning',),
'unionsoppløsninga': ('unionsoppløsning',),
'unionsoppløsningen': ('unionsoppløsning',),
'unionsoppløsningene': ('unionsoppløsning',),
'unionsoppløsninger': ('unionsoppløsning',),
'unionstid': ('unionstid',),
'unionstida': ('unionstid',),
'unionstiden': ('unionstid',),
'unionstidene': ('unionstid',),
'unionstider': ('unionstid',),
'unisex': ('unisex',),
'unisexmote': ('unisexmote',),
'unisexmoten': ('unisexmote',),
'unisexmotene': ('unisexmote',),
'unisexmoter': ('unisexmote',),
'unitar': ('unitar',),
'unitaren': ('unitar',),
'unitarene': ('unitar',),
'unitarer': ('unitar',),
'unitarier': ('unitarier',),
'unitariere': ('unitarier',),
'unitarieren': ('unitarier',),
'unitarierer': ('unitarier',),
'unitarierne': ('unitarier',),
'unitarisme': ('unitarisme',),
'unitarismen': ('unitarisme',),
'unitarismene': ('unitarisme',),
'unitarismer': ('unitarisme',),
'univers': ('univers',),
'universa': ('univers',),
'universene': ('univers',),
'universer': ('univers',),
'universet': ('univers',),
'universalarving': ('universalarving',),
'universalarvingen': ('universalarving',),
'universalarvingene': ('universalarving',),
'universalarvinger': ('universalarving',),
'universalgeni': ('universalgeni',),
'universalgenia': ('universalgeni',),
'universalgeniene': ('universalgeni',),
'universalgenier': ('universalgeni',),
'universalgeniet': ('universalgeni',),
'universalia': ('universalia',),
'universaliene': ('universalia',),
'universaliene': ('universalier',),
'universalier': ('universalier',),
'universalisme': ('universalisme',),
'universalismen': ('universalisme',),
'universalismene': ('universalisme',),
'universalismer': ('universalisme',),
'universalist': ('universalist',),
'universalisten': ('universalist',),
'universalistene': ('universalist',),
'universalister': ('universalist',),
'universalitet': ('universalitet',),
'universaliteten': ('universalitet',),
'universalitetene': ('universalitet',),
'universaliteter': ('universalitet',),
'universalkobling': ('universalkobling',),
'universalkoblinga': ('universalkobling',),
'universalkoblingen': ('universalkobling',),
'universalkoblingene': ('universalkobling',),
'universalkoblinger': ('universalkobling',),
'universalkopling': ('universalkopling',),
'universalkoplinga': ('universalkopling',),
'universalkoplingen': ('universalkopling',),
'universalkoplingene': ('universalkopling',),
'universalkoplinger': ('universalkopling',),
'universalkort': ('universalkort',),
'universalkorta': ('universalkort',),
'universalkortene': ('universalkort',),
'universalkortet': ('universalkort',),
'universalledd': ('universalledd',),
'universalledda': ('universalledd',),
'universalleddene': ('universalledd',),
'universalleddet': ('universalledd',),
'universalmiddel': ('universalmiddel',),
'universalmiddelet': ('universalmiddel',),
'universalmidla': ('universalmiddel',),
'universalmidlene': ('universalmiddel',),
'universalmidler': ('universalmiddel',),
'universalmidlet': ('universalmiddel',),
'universalmotor': ('universalmotor',),
'universalmotoren': ('universalmotor',),
'universalmotorene': ('universalmotor',),
'universalmotorer': ('universalmotor',),
'universalnøkkel': ('universalnøkkel',),
'universalnøkkelen': ('universalnøkkel',),
'universalnøklene': ('universalnøkkel',),
'universalnøkler': ('universalnøkkel',),
'universalsmurning': ('universalsmurning',),
'universalsmurninga': ('universalsmurning',),
'universalsmurningen': ('universalsmurning',),
'universalsmurningene': ('universalsmurning',),
'universalsmurninger': ('universalsmurning',),
'universalsmøring': ('universalsmøring',),
'universalsmøringa': ('universalsmøring',),
'universalsmøringen': ('universalsmøring',),
'universalsmøringene': ('universalsmøring',),
'universalsmøringer': ('universalsmøring',),
'universalstat': ('universalstat',),
'universalstaten': ('universalstat',),
'universalstatene': ('universalstat',),
'universalstater': ('universalstat',),
'universitet': ('universitet',),
'universiteta': ('universitet',),
'universitetene': ('universitet',),
'universiteter': ('universitet',),
'universitetet': ('universitet',),
'universitetsbibliotek': ('universitetsbibliotek',),
'universitetsbiblioteka': ('universitetsbibliotek',),
'universitetsbibliotekene': ('universitetsbibliotek',),
'universitetsbiblioteker': ('universitetsbibliotek',),
'universitetsbiblioteket': ('universitetsbibliotek',),
'universitetsby': ('universitetsby',),
'universitetsbyen': ('universitetsby',),
'universitetsbyene': ('universitetsby',),
'universitetsbyer': ('universitetsby',),
'universitetsdemokrati': ('universitetsdemokrati',),
'universitetsdemokratia': ('universitetsdemokrati',),
'universitetsdemokratiene': ('universitetsdemokrati',),
'universitetsdemokratier': ('universitetsdemokrati',),
'universitetsdemokratiet': ('universitetsdemokrati',),
'universitetsdirektør': ('universitetsdirektør',),
'universitetsdirektøren': ('universitetsdirektør',),
'universitetsdirektørene': ('universitetsdirektør',),
'universitetsdirektører': ('universitetsdirektør',),
'universitetslektor': ('universitetslektor',),
'universitetslektoren': ('universitetslektor',),
'universitetslektorene': ('universitetslektor',),
'universitetslektorer': ('universitetslektor',),
'universitetslektorat': ('universitetslektorat',),
'universitetslektorata': ('universitetslektorat',),
'universitetslektoratene': ('universitetslektorat',),
'universitetslektorater': ('universitetslektorat',),
'universitetslektoratet': ('universitetslektorat',),
'universitetssirkel': ('universitetssirkel',),
'universitetssirkelen': ('universitetssirkel',),
'universitetssirklene': ('universitetssirkel',),
'universitetssirkler': ('universitetssirkel',),
'universitetsstipend': ('universitetsstipend',),
'universitetsstipenda': ('universitetsstipend',),
'universitetsstipendene': ('universitetsstipend',),
'universitetsstipender': ('universitetsstipend',),
'universitetsstipendet': ('universitetsstipend',),
'universitetsstipendiat': ('universitetsstipendiat',),
'universitetsstipendiaten': ('universitetsstipendiat',),
'universitetsstipendiatene': ('universitetsstipendiat',),
'universitetsstipendiater': ('universitetsstipendiat',),
'universitetsstipendia': ('universitetsstipendium',),
'universitetsstipendiene': ('universitetsstipendium',),
'universitetsstipendier': ('universitetsstipendium',),
'universitetsstipendiet': ('universitetsstipendium',),
'universitetsstipendium': ('universitetsstipendium',),
'universum': ('universum',),
'universuma': ('universum',),
'universumene': ('universum',),
'universumet': ('universum',),
'unnabakke': ('unnabakke',),
'unnabakken': ('unnabakke',),
'unnabakkene': ('unnabakke',),
'unnabakker': ('unnabakke',),
'unnarenn': ('unnarenn',),
'unnarenna': ('unnarenn',),
'unnarennene': ('unnarenn',),
'unnarennet': ('unnarenn',),
'unnatak': ('unnatak',),
'unnataka': ('unnatak',),
'unnatakene': ('unnatak',),
'unnataket': ('unnatak',),
'unndragelse': ('unndragelse',),
'unndragelsen': ('unndragelse',),
'unndragelsene': ('unndragelse',),
'unndragelser': ('unndragelse',),
'unndragning': ('unndragning',),
'unndragninga': ('unndragning',),
'unndragningen': ('unndragning',),
'unndragningene': ('unndragning',),
'unndragninger': ('unndragning',),
'unnfallenhet': ('unnfallenhet',),
'unnfallenheta': ('unnfallenhet',),
'unnfallenheten': ('unnfallenhet',),
'unnfallenhetene': ('unnfallenhet',),
'unnfallenheter': ('unnfallenhet',),
'unnfangelse': ('unnfangelse',),
'unnfangelsen': ('unnfangelse',),
'unnfangelsene': ('unnfangelse',),
'unnfangelser': ('unnfangelse',),
'unnlatelse': ('unnlatelse',),
'unnlatelsen': ('unnlatelse',),
'unnlatelsene': ('unnlatelse',),
'unnlatelser': ('unnlatelse',),
'unnlatelsessynd': ('unnlatelsessynd',),
'unnlatelsessynda': ('unnlatelsessynd',),
'unnlatelsessynden': ('unnlatelsessynd',),
'unnlatelsessyndene': ('unnlatelsessynd',),
'unnlatelsessynder': ('unnlatelsessynd',),
'unnseelse': ('unnseelse',),
'unnseelsen': ('unnseelse',),
'unnseelsene': ('unnseelse',),
'unnseelser': ('unnseelse',),
'unnselighet': ('unnselighet',),
'unnseligheta': ('unnselighet',),
'unnseligheten': ('unnselighet',),
'unnselighetene': ('unnselighet',),
'unnseligheter': ('unnselighet',),
'unnsetning': ('unnsetning',),
'unnsetninga': ('unnsetning',),
'unnsetningen': ('unnsetning',),
'unnsetningene': ('unnsetning',),
'unnsetninger': ('unnsetning',),
'unnsetningsekspedisjon': ('unnsetningsekspedisjon',),
'unnsetningsekspedisjonen': ('unnsetningsekspedisjon',),
'unnsetningsekspedisjonene': ('unnsetningsekspedisjon',),
'unnsetningsekspedisjoner': ('unnsetningsekspedisjon',),
'unnsigelse': ('unnsigelse',),
'unnsigelsen': ('unnsigelse',),
'unnsigelsene': ('unnsigelse',),
'unnsigelser': ('unnsigelse',),
'unnskyldning': ('unnskyldning',),
'unnskyldninga': ('unnskyldning',),
'unnskyldningen': ('unnskyldning',),
'unnskyldningene': ('unnskyldning',),
'unnskyldninger': ('unnskyldning',),
'unnslipningshastighet': ('unnslipningshastighet',),
'unnslipningshastigheta': ('unnslipningshastighet',),
'unnslipningshastigheten': ('unnslipningshastighet',),
'unnslipningshastighetene': ('unnslipningshastighet',),
'unnslipningshastigheter': ('unnslipningshastighet',),
'unnslippingshastighet': ('unnslippingshastighet',),
'unnslippingshastigheta': ('unnslippingshastighet',),
'unnslippingshastigheten': ('unnslippingshastighet',),
'unnslippingshastighetene': ('unnslippingshastighet',),
'unnslippingshastigheter': ('unnslippingshastighet',),
'unnslippshastighet': ('unnslippshastighet',),
'unnslippshastigheta': ('unnslippshastighet',),
'unnslippshastigheten': ('unnslippshastighet',),
'unnslippshastighetene': ('unnslippshastighet',),
'unnslippshastigheter': ('unnslippshastighet',),
'unntak': ('unntak',),
'unntaka': ('unntak',),
'unntakene': ('unntak',),
'unntaket': ('unntak',),
'unntakelse': ('unntakelse',),
'unntakelsen': ('unntakelse',),
'unntakelsene': ('unntakelse',),
'unntakelser': ('unntakelse',),
'unntakelseslov': ('unntakelseslov',),
'unntakelsesloven': ('unntakelseslov',),
'unntakelseslovene': ('unntakelseslov',),
'unntakelseslover': ('unntakelseslov',),
'unntakelsestilfella': ('unntakelsestilfelle',),
'unntakelsestilfelle': ('unntakelsestilfelle',),
'unntakelsestilfellene': ('unntakelsestilfelle',),
'unntakelsestilfeller': ('unntakelsestilfelle',),
'unntakelsestilfellet': ('unntakelsestilfelle',),
'unntakelsestilstand': ('unntakelsestilstand',),
'unntakelsestilstanden': ('unntakelsestilstand',),
'unntakelsestilstandene': ('unntakelsestilstand',),
'unntakelsestilstander': ('unntakelsestilstand',),
'unntakslov': ('unntakslov',),
'unntaksloven': ('unntakslov',),
'unntakslovene': ('unntakslov',),
'unntakslover': ('unntakslov',),
'unntakstilfella': ('unntakstilfelle',),
'unntakstilfelle': ('unntakstilfelle',),
'unntakstilfellene': ('unntakstilfelle',),
'unntakstilfeller': ('unntakstilfelle',),
'unntakstilfellet': ('unntakstilfelle',),
'unntakstilstand': ('unntakstilstand',),
'unntakstilstanden': ('unntakstilstand',),
'unntakstilstandene': ('unntakstilstand',),
'unntakstilstander': ('unntakstilstand',),
'unote': ('unote',),
'unoten': ('unote',),
'unotene': ('unote',),
'unoter': ('unote',),
'unse': ('unse',),
'unsen': ('unse',),
'unsene': ('unse',),
'unser': ('unse',),
'unytta': ('unytte',),
'unytte': ('unytte',),
'unytten': ('unytte',),
'unyttene': ('unytte',),
'unytter': ('unytte',),
'unåde': ('unåde',),
'unåden': ('unåde',),
'unådene': ('unåde',),
'unåder': ('unåde',),
'unøyaktighet': ('unøyaktighet',),
'unøyaktigheta': ('unøyaktighet',),
'unøyaktigheten': ('unøyaktighet',),
'unøyaktighetene': ('unøyaktighet',),
'unøyaktigheter': ('unøyaktighet',),
'uord': ('uord',),
'uorda': ('uord',),
'uordene': ('uord',),
'uordet': ('uord',),
'uorden': ('uorden',),
'uordenen': ('uorden',),
'uordenene': ('uorden',),
'uordener': ('uorden',),
'uoverensstemmelse': ('uoverensstemmelse',),
'uoverensstemmelsen': ('uoverensstemmelse',),
'uoverensstemmelsene': ('uoverensstemmelse',),
'uoverensstemmelser': ('uoverensstemmelse',),
'uppercut': ('uppercut',),
'uppercuten': ('uppercut',),
'uppercutene': ('uppercut',),
'uppercuter': ('uppercut',),
'upris': ('upris',),
'uprisen': ('upris',),
'uprisene': ('upris',),
'upriser': ('upris',),
'ur': ('ur',),
'ura': ('ur',),
'urene': ('ur',),
'uret': ('ur',),
'ur': ('ur',),
'ura': ('ur',),
'uren': ('ur',),
'urene': ('ur',),
'urer': ('ur',),
'uradel': ('uradel',),
'uradelen': ('uradel',),
'uradelene': ('uradel',),
'uradeler': ('uradel',),
'uran': ('uran',),
'urana': ('uran',),
'uranene': ('uran',),
'uranet': ('uran',),
'urandioksid': ('urandioksid',),
'urandioksida': ('urandioksid',),
'urandioksidene': ('urandioksid',),
'urandioksider': ('urandioksid',),
'urandioksidet': ('urandioksid',),
'uraninitt': ('uraninitt',),
'uraninitten': ('uraninitt',),
'uraninittene': ('uraninitt',),
'uraninitter': ('uraninitt',),
'uranmila': ('uranmile',),
'uranmile': ('uranmile',),
'uranmilen': ('uranmile',),
'uranmilene': ('uranmile',),
'uranmiler': ('uranmile',),
'uranografi': ('uranografi',),
'uranografien': ('uranografi',),
'uranografiene': ('uranografi',),
'uranografier': ('uranografi',),
'uranolatri': ('uranolatri',),
'uranolatrien': ('uranolatri',),
'uranolatriene': ('uranolatri',),
'uranolatrier': ('uranolatri',),
'uranreaktor': ('uranreaktor',),
'uranreaktoren': ('uranreaktor',),
'uranreaktorene': ('uranreaktor',),
'uranreaktorer': ('uranreaktor',),
'uravstemning': ('uravstemning',),
'uravstemninga': ('uravstemning',),
'uravstemningen': ('uravstemning',),
'uravstemningene': ('uravstemning',),
'uravstemninger': ('uravstemning',),
'urbanisasjon': ('urbanisasjon',),
'urbanisasjonen': ('urbanisasjon',),
'urbanisasjonene': ('urbanisasjon',),
'urbanisasjoner': ('urbanisasjon',),
'urbaniseringsprosess': ('urbaniseringsprosess',),
'urbaniseringsprosessen': ('urbaniseringsprosess',),
'urbaniseringsprosessene': ('urbaniseringsprosess',),
'urbaniseringsprosesser': ('urbaniseringsprosess',),
'urbanisme': ('urbanisme',),
'urbanismen': ('urbanisme',),
'urbanismene': ('urbanisme',),
'urbanismer': ('urbanisme',),
'urbanitet': ('urbanitet',),
'urbaniteten': ('urbanitet',),
'urbanitetene': ('urbanitet',),
'urbaniteter': ('urbanitet',),
'urbefolkning': ('urbefolkning',),
'urbefolkninga': ('urbefolkning',),
'urbefolkningen': ('urbefolkning',),
'urbefolkningene': ('urbefolkning',),
'urbefolkninger': ('urbefolkning',),
'urbilda': ('urbilde',),
'urbilde': ('urbilde',),
'urbildene': ('urbilde',),
'urbilder': ('urbilde',),
'urbildet': ('urbilde',),
'urcella': ('urcelle',),
'urcelle': ('urcelle',),
'urcellen': ('urcelle',),
'urcellene': ('urcelle',),
'urceller': ('urcelle',),
'urdu': ('urdu',),
'urduen': ('urdu',),
'urduene': ('urdu',),
'urduer': ('urdu',),
'urea': ('urea',),
'urede': ('urede',),
'uregelmessighet': ('uregelmessighet',),
'uregelmessigheta': ('uregelmessighet',),
'uregelmessigheten': ('uregelmessighet',),
'uregelmessighetene': ('uregelmessighet',),
'uregelmessigheter': ('uregelmessighet',),
'ureinslighet': ('ureinslighet',),
'ureinsligheta': ('ureinslighet',),
'ureinsligheten': ('ureinslighet',),
'ureinslighetene': ('ureinslighet',),
'ureinsligheter': ('ureinslighet',),
'uremi': ('uremi',),
'uremien': ('uremi',),
'uremiene': ('uremi',),
'uremier': ('uremi',),
'urenhet': ('urenhet',),
'urenheta': ('urenhet',),
'urenheten': ('urenhet',),
'urenhetene': ('urenhet',),
'urenheter': ('urenhet',),
'urenslighet': ('urenslighet',),
'urensligheta': ('urenslighet',),
'urensligheten': ('urenslighet',),
'urenslighetene': ('urenslighet',),
'urensligheter': ('urenslighet',),
'uretan': ('uretan',),
'uretana': ('uretan',),
'uretanene': ('uretan',),
'uretanet': ('uretan',),
'uretangummi': ('uretangummi',),
'uretangummien': ('uretangummi',),
'uretangummiene': ('uretangummi',),
'uretangummier': ('uretangummi',),
'uretanharpiks': ('uretanharpiks',),
'uretanharpiksen': ('uretanharpiks',),
'uretanharpiksene': ('uretanharpiks',),
'uretanharpikser': ('uretanharpiks',),
'uretanplast': ('uretanplast',),
'uretanplasten': ('uretanplast',),
'uretanplastene': ('uretanplast',),
'uretanplaster': ('uretanplast',),
'urett': ('urett',),
'uretten': ('urett',),
'urettene': ('urett',),
'uretter': ('urett',),
'urett': ('urett',),
'uretten': ('urett',),
'urettene': ('urett',),
'uretter': ('urett',),
'urfisk': ('urfisk',),
'urfisken': ('urfisk',),
'urfiskene': ('urfisk',),
'urfisker': ('urfisk',),
'urfjær': ('urfjær',),
'urfjæra': ('urfjær',),
'urfjæren': ('urfjær',),
'urfjærene': ('urfjær',),
'urfjærer': ('urfjær',),
'urfjør': ('urfjør',),
'urfjøra': ('urfjør',),
'urfjøren': ('urfjør',),
'urfjørene': ('urfjør',),
'urfjører': ('urfjør',),
'urframførelse': ('urframførelse',),
'urframførelsen': ('urframførelse',),
'urframførelsene': ('urframførelse',),
'urframførelser': ('urframførelse',),
'urframføring': ('urframføring',),
'urframføringa': ('urframføring',),
'urframføringen': ('urframføring',),
'urframføringene': ('urframføring',),
'urframføringer': ('urframføring',),
'urfremførelse': ('urfremførelse',),
'urfremførelsen': ('urfremførelse',),
'urfremførelsene': ('urfremførelse',),
'urfremførelser': ('urfremførelse',),
'urfremføring': ('urfremføring',),
'urfremføringa': ('urfremføring',),
'urfremføringen': ('urfremføring',),
'urfremføringene': ('urfremføring',),
'urfremføringer': ('urfremføring',),
'urfugl': ('urfugl',),
'urfuglen': ('urfugl',),
'urfuglene': ('urfugl',),
'urfugler': ('urfugl',),
'uriaspost': ('uriaspost',),
'uriasposten': ('uriaspost',),
'uriaspostene': ('uriaspost',),
'uriasposter': ('uriaspost',),
'urin': ('urin',),
'urinen': ('urin',),
'urinene': ('urin',),
'uriner': ('urin',),
'urinal': ('urinal',),
'urinala': ('urinal',),
'urinalene': ('urinal',),
'urinaler': ('urinal',),
'urinalet': ('urinal',),
'urinblæra': ('urinblære',),
'urinblære': ('urinblære',),
'urinblæren': ('urinblære',),
'urinblærene': ('urinblære',),
'urinblærer': ('urinblære',),
'urinforgiftning': ('urinforgiftning',),
'urinforgiftninga': ('urinforgiftning',),
'urinforgiftningen': ('urinforgiftning',),
'urinforgiftningene': ('urinforgiftning',),
'urinforgiftninger': ('urinforgiftning',),
'urinleder': ('urinleder',),
'urinledere': ('urinleder',),
'urinlederen': ('urinleder',),
'urinlederer': ('urinleder',),
'urinlederne': ('urinleder',),
'urinnbygger': ('urinnbygger',),
'urinnbyggere': ('urinnbygger',),
'urinnbyggeren': ('urinnbygger',),
'urinnbyggerer': ('urinnbygger',),
'urinnbyggerne': ('urinnbygger',),
'urinnvåner': ('urinnvåner',),
'urinnvånere': ('urinnvåner',),
'urinnvåneren': ('urinnvåner',),
'urinnvånerer': ('urinnvåner',),
'urinnvånerne': ('urinnvåner',),
'urinorgan': ('urinorgan',),
'urinorgana': ('urinorgan',),
'urinorganene': ('urinorgan',),
'urinorganer': ('urinorgan',),
'urinorganet': ('urinorgan',),
'urinprøva': ('urinprøve',),
'urinprøve': ('urinprøve',),
'urinprøven': ('urinprøve',),
'urinprøvene': ('urinprøve',),
'urinprøver': ('urinprøve',),
'urinrør': ('urinrør',),
'urinrøra': ('urinrør',),
'urinrørene': ('urinrør',),
'urinrøret': ('urinrør',),
'urinstinkt': ('urinstinkt',),
'urinstinkta': ('urinstinkt',),
'urinstinktene': ('urinstinkt',),
'urinstinkter': ('urinstinkt',),
'urinstinktet': ('urinstinkt',),
'urinstoff': ('urinstoff',),
'urinstoffa': ('urinstoff',),
'urinstoffene': ('urinstoff',),
'urinstoffer': ('urinstoff',),
'urinstoffet': ('urinstoff',),
'urinsyra': ('urinsyre',),
'urinsyre': ('urinsyre',),
'urinsyren': ('urinsyre',),
'urinsyrene': ('urinsyre',),
'urinsyrer': ('urinsyre',),
'urinveg': ('urinveg',),
'urinvegen': ('urinveg',),
'urinvegene': ('urinveg',),
'urinveger': ('urinveg',),
'urinvegsinfeksjon': ('urinvegsinfeksjon',),
'urinvegsinfeksjonen': ('urinvegsinfeksjon',),
'urinvegsinfeksjonene': ('urinvegsinfeksjon',),
'urinvegsinfeksjoner': ('urinvegsinfeksjon',),
'urinvegssjukdom': ('urinvegssjukdom',),
'urinvegssjukdommen': ('urinvegssjukdom',),
'urinvegssjukdommene': ('urinvegssjukdom',),
'urinvegssjukdommer': ('urinvegssjukdom',),
'urinvegssykdom': ('urinvegssykdom',),
'urinvegssykdommen': ('urinvegssykdom',),
'urinvegssykdommene': ('urinvegssykdom',),
'urinvegssykdommer': ('urinvegssykdom',),
'urinvei': ('urinvei',),
'urinveien': ('urinvei',),
'urinveiene': ('urinvei',),
'urinveier': ('urinvei',),
'urinveissjukdom': ('urinveissjukdom',),
'urinveissjukdommen': ('urinveissjukdom',),
'urinveissjukdommene': ('urinveissjukdom',),
'urinveissjukdommer': ('urinveissjukdom',),
'urinveissykdom': ('urinveissykdom',),
'urinveissykdommen': ('urinveissykdom',),
'urinveissykdommene': ('urinveissykdom',),
'urinveissykdommer': ('urinveissykdom',),
'urkassa': ('urkasse',),
'urkasse': ('urkasse',),
'urkassen': ('urkasse',),
'urkassene': ('urkasse',),
'urkasser': ('urkasse',),
'urkjeda': ('urkjede',),
'urkjede': ('urkjede',),
'urkjeden': ('urkjede',),
'urkjedene': ('urkjede',),
'urkjeder': ('urkjede',),
'urkjedet': ('urkjede',),
'urkraft': ('urkraft',),
'urkrafta': ('urkraft',),
'urkraften': ('urkraft',),
'urkreftene': ('urkraft',),
'urkrefter': ('urkraft',),
'urkristendom': ('urkristendom',),
'urkristendommen': ('urkristendom',),
'urkristendommene': ('urkristendom',),
'urkristendommer': ('urkristendom',),
'urlodd': ('urlodd',),
'urlodda': ('urlodd',),
'urloddene': ('urlodd',),
'urlodder': ('urlodd',),
'urloddet': ('urlodd',),
'urlomma': ('urlomme',),
'urlomme': ('urlomme',),
'urlommen': ('urlomme',),
'urlommene': ('urlomme',),
'urlommer': ('urlomme',),
'urmaker': ('urmaker',),
'urmakere': ('urmaker',),
'urmakeren': ('urmaker',),
'urmakerer': ('urmaker',),
'urmakerne': ('urmaker',),
'urmenneska': ('urmenneske',),
'urmenneske': ('urmenneske',),
'urmenneskene': ('urmenneske',),
'urmennesker': ('urmenneske',),
'urmennesket': ('urmenneske',),
'urna': ('urne',),
'urne': ('urne',),
'urnen': ('urne',),
'urnene': ('urne',),
'urner': ('urne',),
'urnebisettelse': ('urnebisettelse',),
'urnebisettelsen': ('urnebisettelse',),
'urnebisettelsene': ('urnebisettelse',),
'urnebisettelser': ('urnebisettelse',),
'urnegrav': ('urnegrav',),
'urnegrava': ('urnegrav',),
'urnegraven': ('urnegrav',),
'urnegravene': ('urnegrav',),
'urnegraver': ('urnegrav',),
'urnehall': ('urnehall',),
'urnehallen': ('urnehall',),
'urnehallene': ('urnehall',),
'urnehaller': ('urnehall',),
'urnenedsettelse': ('urnenedsettelse',),
'urnenedsettelsen': ('urnenedsettelse',),
'urnenedsettelsene': ('urnenedsettelse',),
'urnenedsettelser': ('urnenedsettelse',),
'urnenedsetting': ('urnenedsetting',),
'urnenedsettinga': ('urnenedsetting',),
'urnenedsettingen': ('urnenedsetting',),
'urnenedsettingene': ('urnenedsetting',),
'urnenedsettinger': ('urnenedsetting',),
'urnevalg': ('urnevalg',),
'urnevalga': ('urnevalg',),
'urnevalgene': ('urnevalg',),
'urnevalget': ('urnevalg',),
'uro': ('uro',),
'uroa': ('uro',),
'uroen': ('uro',),
'uroene': ('uro',),
'uroer': ('uro',),
'uroelement': ('uroelement',),
'uroelementa': ('uroelement',),
'uroelementene': ('uroelement',),
'uroelementer': ('uroelement',),
'uroelementet': ('uroelement',),
'urokråka': ('urokråke',),
'urokråke': ('urokråke',),
'urokråken': ('urokråke',),
'urokråkene': ('urokråke',),
'urokråker': ('urokråke',),
'urokse': ('urokse',),
'uroksen': ('urokse',),
'uroksene': ('urokse',),
'urokser': ('urokse',),
'urolighet': ('urolighet',),
'uroligheta': ('urolighet',),
'uroligheten': ('urolighet',),
'urolighetene': ('urolighet',),
'uroligheter': ('urolighet',),
'urolog': ('urolog',),
'urologen': ('urolog',),
'urologene': ('urolog',),
'urologer': ('urolog',),
'urologi': ('urologi',),
'urologien': ('urologi',),
'urologiene': ('urologi',),
'urologier': ('urologi',),
'uroppførelse': ('uroppførelse',),
'uroppførelsen': ('uroppførelse',),
'uroppførelsene': ('uroppførelse',),
'uroppførelser': ('uroppførelse',),
'uroppføring': ('uroppføring',),
'uroppføringa': ('uroppføring',),
'uroppføringen': ('uroppføring',),
'uroppføringene': ('uroppføring',),
'uroppføringer': ('uroppføring',),
'urosentra': ('urosentrum',),
'urosentraene': ('urosentrum',),
'urosentre': ('urosentrum',),
'urosentrene': ('urosentrum',),
'urosentret': ('urosentrum',),
'urosentrum': ('urosentrum',),
'urosentrumet': ('urosentrum',),
'uroskråka': ('uroskråke',),
'uroskråke': ('uroskråke',),
'uroskråken': ('uroskråke',),
'uroskråkene': ('uroskråke',),
'uroskråker': ('uroskråke',),
'urostifter': ('urostifter',),
'urostiftere': ('urostifter',),
'urostifteren': ('urostifter',),
'urostifterer': ('urostifter',),
'urostifterne': ('urostifter',),
'urpremiere': ('urpremiere',),
'urpremieren': ('urpremiere',),
'urpremierene': ('urpremiere',),
'urpremierer': ('urpremiere',),
'urskiva': ('urskive',),
'urskive': ('urskive',),
'urskiven': ('urskive',),
'urskivene': ('urskive',),
'urskiver': ('urskive',),
'urskog': ('urskog',),
'urskogen': ('urskog',),
'urskogene': ('urskog',),
'urskoger': ('urskog',),
'urspråk': ('urspråk',),
'urspråka': ('urspråk',),
'urspråkene': ('urspråk',),
'urspråket': ('urspråk',),
'urstoff': ('urstoff',),
'urstoffa': ('urstoff',),
'urstoffene': ('urstoff',),
'urstoffer': ('urstoff',),
'urstoffet': ('urstoff',),
'urt': ('urt',),
'urta': ('urt',),
'urten': ('urt',),
'urtene': ('urt',),
'urter': ('urt',),
'urtehage': ('urtehage',),
'urtehagen': ('urtehage',),
'urtehagene': ('urtehage',),
'urtehager': ('urtehage',),
'urtete': ('urtete',),
'urteteen': ('urtete',),
'urteteene': ('urtete',),
'urteteer': ('urtete',),
'urtid': ('urtid',),
'urtida': ('urtid',),
'urtiden': ('urtid',),
'urtidene': ('urtid',),
'urtider': ('urtid',),
'uruguayaner': ('uruguayaner',),
'uruguayanere': ('uruguayaner',),
'uruguayaneren': ('uruguayaner',),
'uruguayanerer': ('uruguayaner',),
'uruguayanerne': ('uruguayaner',),
'urverk': ('urverk',),
'urverka': ('urverk',),
'urverkene': ('urverk',),
'urverker': ('urverk',),
'urverket': ('urverk',),
'urviser': ('urviser',),
'urvisere': ('urviser',),
'urviseren': ('urviser',),
'urviserer': ('urviser',),
'urviserne': ('urviser',),
'uråd': ('uråd',),
'urådighetserklæring': ('urådighetserklæring',),
'urådighetserklæringa': ('urådighetserklæring',),
'urådighetserklæringen': ('urådighetserklæring',),
'urådighetserklæringene': ('urådighetserklæring',),
'urådighetserklæringer': ('urådighetserklæring',),
'usaklighet': ('usaklighet',),
'usakligheta': ('usaklighet',),
'usakligheten': ('usaklighet',),
'usaklighetene': ('usaklighet',),
'usakligheter': ('usaklighet',),
'usannhet': ('usannhet',),
'usannheta': ('usannhet',),
'usannheten': ('usannhet',),
'usannhetene': ('usannhet',),
'usannheter': ('usannhet',),
'usbek': ('usbek',),
'usbeken': ('usbek',),
'usbekene': ('usbek',),
'usbeker': ('usbek',),
'usbeker': ('usbeker',),
'usbekere': ('usbeker',),
'usbekeren': ('usbeker',),
'usbekerer': ('usbeker',),
'usbekerne': ('usbeker',),
'usedelighet': ('usedelighet',),
'usedeligheta': ('usedelighet',),
'usedeligheten': ('usedelighet',),
'usedelighetene': ('usedelighet',),
'usedeligheter': ('usedelighet',),
'uselviskhet': ('uselviskhet',),
'uselviskheta': ('uselviskhet',),
'uselviskheten': ('uselviskhet',),
'uselviskhetene': ('uselviskhet',),
'uselviskheter': ('uselviskhet',),
'usikkerhet': ('usikkerhet',),
'usikkerheta': ('usikkerhet',),
'usikkerheten': ('usikkerhet',),
'usikkerhetene': ('usikkerhet',),
'usikkerheter': ('usikkerhet',),
'usikkerhetsmoment': ('usikkerhetsmoment',),
'usikkerhetsmomenta': ('usikkerhetsmoment',),
'usikkerhetsmomentene': ('usikkerhetsmoment',),
'usikkerhetsmomenter': ('usikkerhetsmoment',),
'usikkerhetsmomentet': ('usikkerhetsmoment',),
'uskap': ('uskap',),
'uskapa': ('uskap',),
'uskapene': ('uskap',),
'uskapet': ('uskap',),
'uskifta': ('uskifte',),
'uskifte': ('uskifte',),
'uskiftene': ('uskifte',),
'uskifter': ('uskifte',),
'uskiftet': ('uskifte',),
'uskikk': ('uskikk',),
'uskikken': ('uskikk',),
'uskikkene': ('uskikk',),
'uskikker': ('uskikk',),
'uskyld': ('uskyld',),
'uskylda': ('uskyld',),
'uskylden': ('uskyld',),
'uskyldene': ('uskyld',),
'uskylder': ('uskyld',),
'uskyldighet': ('uskyldighet',),
'uskyldigheta': ('uskyldighet',),
'uskyldigheten': ('uskyldighet',),
'uskyldighetene': ('uskyldighet',),
'uskyldigheter': ('uskyldighet',),
'uskyldighetstilstand': ('uskyldighetstilstand',),
'uskyldighetstilstanden': ('uskyldighetstilstand',),
'uskyldighetstilstandene': ('uskyldighetstilstand',),
'uskyldighetstilstander': ('uskyldighetstilstand',),
'usling': ('usling',),
'uslingen': ('usling',),
'uslingene': ('usling',),
'uslinger': ('usling',),
'usmak': ('usmak',),
'usmaken': ('usmak',),
'usmakene': ('usmak',),
'usmaker': ('usmak',),
'usseldom': ('usseldom',),
'usseldommen': ('usseldom',),
'usseldommene': ('usseldom',),
'usseldommer': ('usseldom',),
'usselhet': ('usselhet',),
'usselheta': ('usselhet',),
'usselheten': ('usselhet',),
'usselhetene': ('usselhet',),
'usselheter': ('usselhet',),
'ustand': ('ustand',),
'ustanden': ('ustand',),
'ustandene': ('ustand',),
'ustander': ('ustand',),
'ustand': ('ustand',),
'ustell': ('ustell',),
'ustella': ('ustell',),
'ustellene': ('ustell',),
'ustellet': ('ustell',),
'usurpasjon': ('usurpasjon',),
'usurpasjonen': ('usurpasjon',),
'usurpasjonene': ('usurpasjon',),
'usurpasjoner': ('usurpasjon',),
'usurpator': ('usurpator',),
'usurpatoren': ('usurpator',),
'usurpatorene': ('usurpator',),
'usurpatorer': ('usurpator',),
'usus': ('usus',),
'ususen': ('usus',),
'ususene': ('usus',),
'ususer': ('usus',),
'usynlighetshatt': ('usynlighetshatt',),
'usynlighetshatten': ('usynlighetshatt',),
'usynlighetshattene': ('usynlighetshatt',),
'usynlighetshatter': ('usynlighetshatt',),
'ut-enhet': ('ut-enhet',),
'ut-enheta': ('ut-enhet',),
'ut-enheten': ('ut-enhet',),
'ut-enhetene': ('ut-enhet',),
'ut-enheter': ('ut-enhet',),
'utabordsmotor': ('utabordsmotor',),
'utabordsmotoren': ('utabordsmotor',),
'utabordsmotorene': ('utabordsmotor',),
'utabordsmotorer': ('utabordsmotor',),
'utakk': ('utakk',),
'utakka': ('utakk',),
'utakken': ('utakk',),
'utakkene': ('utakk',),
'utakker': ('utakk',),
'utakknemlighet': ('utakknemlighet',),
'utakknemligheta': ('utakknemlighet',),
'utakknemligheten': ('utakknemlighet',),
'utakknemlighetene': ('utakknemlighet',),
'utakknemligheter': ('utakknemlighet',),
'utakt': ('utakt',),
'utakta': ('utakt',),
'utakten': ('utakt',),
'utaktene': ('utakt',),
'utakter': ('utakt',),
'utal': ('utal',),
'utala': ('utal',),
'utalene': ('utal',),
'utalet': ('utal',),
'utal': ('utal',),
'utala': ('utal',),
'utalene': ('utal',),
'utalet': ('utal',),
'utalandsgjeld': ('utalandsgjeld',),
'utalandsgjelda': ('utalandsgjeld',),
'utalandsgjelden': ('utalandsgjeld',),
'utalandsgjeldene': ('utalandsgjeld',),
'utalandsgjelder': ('utalandsgjeld',),
'utalandsopphold': ('utalandsopphold',),
'utalandsoppholda': ('utalandsopphold',),
'utalandsoppholdene': ('utalandsopphold',),
'utalandsoppholdet': ('utalandsopphold',),
'utalandsprefiks': ('utalandsprefiks',),
'utalandsprefiksa': ('utalandsprefiks',),
'utalandsprefiksene': ('utalandsprefiks',),
'utalandsprefikser': ('utalandsprefiks',),
'utalandsprefikset': ('utalandsprefiks',),
'utalandsreisa': ('utalandsreise',),
'utalandsreise': ('utalandsreise',),
'utalandsreisen': ('utalandsreise',),
'utalandsreisene': ('utalandsreise',),
'utalandsreiser': ('utalandsreise',),
'utalandsstudent': ('utalandsstudent',),
'utalandsstudenten': ('utalandsstudent',),
'utalandsstudentene': ('utalandsstudent',),
'utalandsstudenter': ('utalandsstudent',),
'utall': ('utall',),
'utalla': ('utall',),
'utallene': ('utall',),
'utallet': ('utall',),
'utall': ('utall',),
'utalla': ('utall',),
'utallene': ('utall',),
'utallet': ('utall',),
'utapålomma': ('utapålomme',),
'utapålomme': ('utapålomme',),
'utapålommen': ('utapålomme',),
'utapålommene': ('utapålomme',),
'utapålommer': ('utapålomme',),
'utapåskrift': ('utapåskrift',),
'utapåskrifta': ('utapåskrift',),
'utapåskriften': ('utapåskrift',),
'utapåskriftene': ('utapåskrift',),
'utapåskrifter': ('utapåskrift',),
'utapåtøy': ('utapåtøy',),
'utapåtøya': ('utapåtøy',),
'utapåtøyene': ('utapåtøy',),
'utapåtøyer': ('utapåtøy',),
'utapåtøyet': ('utapåtøy',),
'utarbeidelse': ('utarbeidelse',),
'utarbeidelsen': ('utarbeidelse',),
'utarbeidelsene': ('utarbeidelse',),
'utarbeidelser': ('utarbeidelse',),
'utarbeiding': ('utarbeiding',),
'utarbeidinga': ('utarbeiding',),
'utarbeidingen': ('utarbeiding',),
'utarbeidingene': ('utarbeiding',),
'utarbeidinger': ('utarbeiding',),
'utariksdepartement': ('utariksdepartement',),
'utariksdepartementa': ('utariksdepartement',),
'utariksdepartementene': ('utariksdepartement',),
'utariksdepartementer': ('utariksdepartement',),
'utariksdepartementet': ('utariksdepartement',),
'utariksfart': ('utariksfart',),
'utariksfarten': ('utariksfart',),
'utariksfartene': ('utariksfart',),
'utariksfarter': ('utariksfart',),
'utariksflåte': ('utariksflåte',),
'utariksflåten': ('utariksflåte',),
'utariksflåtene': ('utariksflåte',),
'utariksflåter': ('utariksflåte',),
'utarikshandel': ('utarikshandel',),
'utarikshandelen': ('utarikshandel',),
'utarikshandlene': ('utarikshandel',),
'utarikshandler': ('utarikshandel',),
'utarikskorrespondent': ('utarikskorrespondent',),
'utarikskorrespondenten': ('utarikskorrespondent',),
'utarikskorrespondentene': ('utarikskorrespondent',),
'utarikskorrespondenter': ('utarikskorrespondent',),
'utarikskronikk': ('utarikskronikk',),
'utarikskronikken': ('utarikskronikk',),
'utarikskronikkene': ('utarikskronikk',),
'utarikskronikker': ('utarikskronikk',),
'utariksminister': ('utariksminister',),
'utariksministere': ('utariksminister',),
'utariksministeren': ('utariksminister',),
'utariksministerer': ('utariksminister',),
'utariksministerne': ('utariksminister',),
'utariksministre': ('utariksminister',),
'utariksministrene': ('utariksminister',),
'utariksministrer': ('utariksminister',),
'utarikspolitikk': ('utarikspolitikk',),
'utarikspolitikken': ('utarikspolitikk',),
'utarikspolitikkene': ('utarikspolitikk',),
'utarikspolitikker': ('utarikspolitikk',),
'utariksredaktør': ('utariksredaktør',),
'utariksredaktøren': ('utariksredaktør',),
'utariksredaktørene': ('utariksredaktør',),
'utariksredaktører': ('utariksredaktør',),
'utarikstjeneste': ('utarikstjeneste',),
'utarikstjenesten': ('utarikstjeneste',),
'utarikstjenestene': ('utarikstjeneste',),
'utarikstjenester': ('utarikstjeneste',),
'utarv': ('utarv',),
'utarven': ('utarv',),
'utarvene': ('utarv',),
'utarver': ('utarv',),
'utarving': ('utarving',),
'utarvingen': ('utarving',),
'utarvingene': ('utarving',),
'utarvinger': ('utarving',),
'utaskjærsvirksomhet': ('utaskjærsvirksomhet',),
'utaskjærsvirksomheta': ('utaskjærsvirksomhet',),
'utaskjærsvirksomheten': ('utaskjærsvirksomhet',),
'utaskjærsvirksomhetene': ('utaskjærsvirksomhet',),
'utaskjærsvirksomheter': ('utaskjærsvirksomhet',),
'utaverden': ('utaverden',),
'utaverdenen': ('utaverden',),
'utaverdenene': ('utaverden',),
'utaverdener': ('utaverden',),
'utbedring': ('utbedring',),
'utbedringa': ('utbedring',),
'utbedringen': ('utbedring',),
'utbedringene': ('utbedring',),
'utbedringer': ('utbedring',),
'utbedringsarbeid': ('utbedringsarbeid',),
'utbedringsarbeida': ('utbedringsarbeid',),
'utbedringsarbeidene': ('utbedringsarbeid',),
'utbedringsarbeider': ('utbedringsarbeid',),
'utbedringsarbeidet': ('utbedringsarbeid',),
'utbetaling': ('utbetaling',),
'utbetalinga': ('utbetaling',),
'utbetalingen': ('utbetaling',),
'utbetalingene': ('utbetaling',),
'utbetalinger': ('utbetaling',),
'utbetalingskort': ('utbetalingskort',),
'utbetalingskorta': ('utbetalingskort',),
'utbetalingskortene': ('utbetalingskort',),
'utbetalingskortet': ('utbetalingskort',),
'utblinking': ('utblinking',),
'utblinkinga': ('utblinking',),
'utblinkingen': ('utblinking',),
'utblinkingene': ('utblinking',),
'utblinkinger': ('utblinking',),
'utblokking': ('utblokking',),
'utblokkinga': ('utblokking',),
'utblokkingen': ('utblokking',),
'utblokkingene': ('utblokking',),
'utblokkinger': ('utblokking',),
'utblåsing': ('utblåsing',),
'utblåsinga': ('utblåsing',),
'utblåsingen': ('utblåsing',),
'utblåsingene': ('utblåsing',),
'utblåsinger': ('utblåsing',),
'utboring': ('utboring',),
'utboringa': ('utboring',),
'utboringen': ('utboring',),
'utboringene': ('utboring',),
'utboringer': ('utboring',),
'utboringsverktøy': ('utboringsverktøy',),
'utboringsverktøya': ('utboringsverktøy',),
'utboringsverktøyene': ('utboringsverktøy',),
'utboringsverktøyer': ('utboringsverktøy',),
'utboringsverktøyet': ('utboringsverktøy',),
'utbredelse': ('utbredelse',),
'utbredelsen': ('utbredelse',),
'utbredelsene': ('utbredelse',),
'utbredelser': ('utbredelse',),
'utbrettbilda': ('utbrettbilde',),
'utbrettbilde': ('utbrettbilde',),
'utbrettbildene': ('utbrettbilde',),
'utbrettbilder': ('utbrettbilde',),
'utbrettbildet': ('utbrettbilde',),
'utbrettgutt': ('utbrettgutt',),
'utbrettgutten': ('utbrettgutt',),
'utbrettguttene': ('utbrettgutt',),
'utbrettgutter': ('utbrettgutt',),
'utbrettjenta': ('utbrettjente',),
'utbrettjente': ('utbrettjente',),
'utbrettjenten': ('utbrettjente',),
'utbrettjentene': ('utbrettjente',),
'utbrettjenter': ('utbrettjente',),
'utbrodering': ('utbrodering',),
'utbroderinga': ('utbrodering',),
'utbroderingen': ('utbrodering',),
'utbroderingene': ('utbrodering',),
'utbroderinger': ('utbrodering',),
'utbrott': ('utbrott',),
'utbrotta': ('utbrott',),
'utbrottene': ('utbrott',),
'utbrottet': ('utbrott',),
'utbrudd': ('utbrudd',),
'utbrudda': ('utbrudd',),
'utbruddene': ('utbrudd',),
'utbruddet': ('utbrudd',),
'utbryter': ('utbryter',),
'utbrytere': ('utbryter',),
'utbryteren': ('utbryter',),
'utbryterer': ('utbryter',),
'utbryterne': ('utbryter',),
'utbryterkonge': ('utbryterkonge',),
'utbryterkongen': ('utbryterkonge',),
'utbryterkongene': ('utbryterkonge',),
'utbryterkonger': ('utbryterkonge',),
'utbud': ('utbud',),
'utbuda': ('utbud',),
'utbudene': ('utbud',),
'utbudet': ('utbud',),
'utbukting': ('utbukting',),
'utbuktinga': ('utbukting',),
'utbuktingen': ('utbukting',),
'utbuktingene': ('utbukting',),
'utbuktinger': ('utbukting',),
'utbuktning': ('utbuktning',),
'utbuktninga': ('utbuktning',),
'utbuktningen': ('utbuktning',),
'utbuktningene': ('utbuktning',),
'utbuktninger': ('utbuktning',),
'utbuling': ('utbuling',),
'utbulinga': ('utbuling',),
'utbulingen': ('utbuling',),
'utbulingene': ('utbuling',),
'utbulinger': ('utbuling',),
'utburd': ('utburd',),
'utburden': ('utburd',),
'utburdene': ('utburd',),
'utburder': ('utburd',),
'utbyder': ('utbyder',),
'utbydere': ('utbyder',),
'utbyderen': ('utbyder',),
'utbyderer': ('utbyder',),
'utbyderne': ('utbyder',),
'utbygd': ('utbygd',),
'utbygda': ('utbygd',),
'utbygden': ('utbygd',),
'utbygdene': ('utbygd',),
'utbygder': ('utbygd',),
'utbygding': ('utbygding',),
'utbygdingen': ('utbygding',),
'utbygdingene': ('utbygding',),
'utbygdinger': ('utbygding',),
'utbygg': ('utbygg',),
'utbygga': ('utbygg',),
'utbyggene': ('utbygg',),
'utbygget': ('utbygg',),
'utbygging': ('utbygging',),
'utbygginga': ('utbygging',),
'utbyggingen': ('utbygging',),
'utbyggingene': ('utbygging',),
'utbygginger': ('utbygging',),
'utbyggingskommune': ('utbyggingskommune',),
'utbyggingskommunen': ('utbyggingskommune',),
'utbyggingskommunene': ('utbyggingskommune',),
'utbyggingskommuner': ('utbyggingskommune',),
'utbyggingsområda': ('utbyggingsområde',),
'utbyggingsområde': ('utbyggingsområde',),
'utbyggingsområdene': ('utbyggingsområde',),
'utbyggingsområder': ('utbyggingsområde',),
'utbyggingsområdet': ('utbyggingsområde',),
'utbytta': ('utbytte',),
'utbytte': ('utbytte',),
'utbyttene': ('utbytte',),
'utbytter': ('utbytte',),
'utbyttet': ('utbytte',),
'utbytter': ('utbytter',),
'utbyttere': ('utbytter',),
'utbytteren': ('utbytter',),
'utbytterer': ('utbytter',),
'utbytterne': ('utbytter',),
'utbyttersamfunn': ('utbyttersamfunn',),
'utbyttersamfunna': ('utbyttersamfunn',),
'utbyttersamfunnene': ('utbyttersamfunn',),
'utbyttersamfunnet': ('utbyttersamfunn',),
'utbytting': ('utbytting',),
'utbyttinga': ('utbytting',),
'utbyttingen': ('utbytting',),
'utbyttingene': ('utbytting',),
'utbyttinger': ('utbytting',),
'utdannelse': ('utdannelse',),
'utdannelsen': ('utdannelse',),
'utdannelsene': ('utdannelse',),
'utdannelser': ('utdannelse',),
'utdannelsesflukt': ('utdannelsesflukt',),
'utdannelsesflukta': ('utdannelsesflukt',),
'utdannelsesflukten': ('utdannelsesflukt',),
'utdannelsesfluktene': ('utdannelsesflukt',),
'utdannelsesflukter': ('utdannelsesflukt',),
'utdannelseskløft': ('utdannelseskløft',),
'utdannelseskløfta': ('utdannelseskløft',),
'utdannelseskløften': ('utdannelseskløft',),
'utdannelseskløftene': ('utdannelseskløft',),
'utdannelseskløfter': ('utdannelseskløft',),
'utdannelseskø': ('utdannelseskø',),
'utdannelseskøen': ('utdannelseskø',),
'utdannelseskøene': ('utdannelseskø',),
'utdannelseskøer': ('utdannelseskø',),
'utdannelsesnivå': ('utdannelsesnivå',),
'utdannelsesnivåa': ('utdannelsesnivå',),
'utdannelsesnivåene': ('utdannelsesnivå',),
'utdannelsesnivåer': ('utdannelsesnivå',),
'utdannelsesnivået': ('utdannelsesnivå',),
'utdannelsessamfunn': ('utdannelsessamfunn',),
'utdannelsessamfunna': ('utdannelsessamfunn',),
'utdannelsessamfunnene': ('utdannelsessamfunn',),
'utdannelsessamfunnet': ('utdannelsessamfunn',),
'utdanning': ('utdanning',),
'utdanninga': ('utdanning',),
'utdanningen': ('utdanning',),
'utdanningene': ('utdanning',),
'utdanninger': ('utdanning',),
'utdanningskløft': ('utdanningskløft',),
'utdanningskløfta': ('utdanningskløft',),
'utdanningskløften': ('utdanningskløft',),
'utdanningskløftene': ('utdanningskløft',),
'utdanningskløfter': ('utdanningskløft',),
'utdanningskø': ('utdanningskø',),
'utdanningskøen': ('utdanningskø',),
'utdanningskøene': ('utdanningskø',),
'utdanningskøer': ('utdanningskø',),
'utdanningsnivå': ('utdanningsnivå',),
'utdanningsnivåa': ('utdanningsnivå',),
'utdanningsnivåene': ('utdanningsnivå',),
'utdanningsnivåer': ('utdanningsnivå',),
'utdanningsnivået': ('utdanningsnivå',),
'utdanningssamfunn': ('utdanningssamfunn',),
'utdanningssamfunna': ('utdanningssamfunn',),
'utdanningssamfunnene': ('utdanningssamfunn',),
'utdanningssamfunnet': ('utdanningssamfunn',),
'utdata': ('utdata',),
'utdataen': ('utdata',),
'utdataene': ('utdata',),
'utdataet': ('utdata',),
'utdjuping': ('utdjuping',),
'utdjupinga': ('utdjuping',),
'utdjupingen': ('utdjuping',),
'utdjupingene': ('utdjuping',),
'utdjupinger': ('utdjuping',),
'utdjupning': ('utdjupning',),
'utdjupninga': ('utdjupning',),
'utdjupningen': ('utdjupning',),
'utdjupningene': ('utdjupning',),
'utdjupninger': ('utdjupning',),
'utdrag': ('utdrag',),
'utdraga': ('utdrag',),
'utdragene': ('utdrag',),
'utdraget': ('utdrag',),
'utdrikkingslag': ('utdrikkingslag',),
'utdrikkingslaga': ('utdrikkingslag',),
'utdrikkingslagene': ('utdrikkingslag',),
'utdrikkingslaget': ('utdrikkingslag',),
'utdrivelse': ('utdrivelse',),
'utdrivelsen': ('utdrivelse',),
'utdrivelsene': ('utdrivelse',),
'utdrivelser': ('utdrivelse',),
'utdriving': ('utdriving',),
'utdrivinga': ('utdriving',),
'utdrivingen': ('utdriving',),
'utdrivingene': ('utdriving',),
'utdrivinger': ('utdriving',),
'utdrivning': ('utdrivning',),
'utdrivninga': ('utdrivning',),
'utdrivningen': ('utdrivning',),
'utdrivningene': ('utdrivning',),
'utdrivninger': ('utdrivning',),
'utdunsting': ('utdunsting',),
'utdunstinga': ('utdunsting',),
'utdunstingen': ('utdunsting',),
'utdunstingene': ('utdunsting',),
'utdunstinger': ('utdunsting',),
'utdunstning': ('utdunstning',),
'utdunstninga': ('utdunstning',),
'utdunstningen': ('utdunstning',),
'utdunstningene': ('utdunstning',),
'utdunstninger': ('utdunstning',),
'utdyping': ('utdyping',),
'utdypinga': ('utdyping',),
'utdypingen': ('utdyping',),
'utdypingene': ('utdyping',),
'utdypinger': ('utdyping',),
'utdypning': ('utdypning',),
'utdypninga': ('utdypning',),
'utdypningen': ('utdypning',),
'utdypningene': ('utdypning',),
'utdypninger': ('utdypning',),
'utdør': ('utdør',),
'utdøra': ('utdør',),
'utdøren': ('utdør',),
'utdørene': ('utdør',),
'utdører': ('utdør',),
'uteaktivitet': ('uteaktivitet',),
'uteaktiviteten': ('uteaktivitet',),
'uteaktivitetene': ('uteaktivitet',),
'uteaktiviteter': ('uteaktivitet',),
'utearbeid': ('utearbeid',),
'utearbeida': ('utearbeid',),
'utearbeidene': ('utearbeid',),
'utearbeider': ('utearbeid',),
'utearbeidet': ('utearbeid',),
'utebliing': ('utebliing',),
'utebliinga': ('utebliing',),
'utebliingen': ('utebliing',),
'utebliingene': ('utebliing',),
'utebliinger': ('utebliing',),
'uteblivelse': ('uteblivelse',),
'uteblivelsen': ('uteblivelse',),
'uteblivelsene': ('uteblivelse',),
'uteblivelser': ('uteblivelse',),
'uteblivelsesdom': ('uteblivelsesdom',),
'uteblivelsesdommen': ('uteblivelsesdom',),
'uteblivelsesdommene': ('uteblivelsesdom',),
'uteblivelsesdommer': ('uteblivelsesdom',),
'utebliving': ('utebliving',),
'uteblivinga': ('utebliving',),
'uteblivingen': ('utebliving',),
'uteblivingene': ('utebliving',),
'uteblivinger': ('utebliving',),
'utedo': ('utedo',),
'utedoa': ('utedo',),
'utedoen': ('utedo',),
'utedoene': ('utedo',),
'utedoer': ('utedo',),
'utedoet': ('utedo',),
'uteganger': ('uteganger',),
'utegangere': ('uteganger',),
'utegangeren': ('uteganger',),
'utegangerer': ('uteganger',),
'utegangerne': ('uteganger',),
'utegangersau': ('utegangersau',),
'utegangersauen': ('utegangersau',),
'utegangersauene': ('utegangersau',),
'utegangersauer': ('utegangersau',),
'utegangssau': ('utegangssau',),
'utegangssauen': ('utegangssau',),
'utegangssauene': ('utegangssau',),
'utegangssauer': ('utegangssau',),
'uteklær': ('uteklær',),
'uteklærne': ('uteklær',),
'utekontakt': ('utekontakt',),
'utekontakten': ('utekontakt',),
'utekontaktene': ('utekontakt',),
'utekontakter': ('utekontakt',),
'utelampa': ('utelampe',),
'utelampe': ('utelampe',),
'utelampen': ('utelampe',),
'utelampene': ('utelampe',),
'utelamper': ('utelampe',),
'utelatelse': ('utelatelse',),
'utelatelsen': ('utelatelse',),
'utelatelsene': ('utelatelse',),
'utelatelser': ('utelatelse',),
'utelating': ('utelating',),
'utelatinga': ('utelating',),
'utelatingen': ('utelating',),
'utelatingene': ('utelating',),
'utelatinger': ('utelating',),
'uteligger': ('uteligger',),
'uteliggere': ('uteligger',),
'uteliggeren': ('uteligger',),
'uteliggerer': ('uteligger',),
'uteliggerne': ('uteligger',),
'uteliv': ('uteliv',),
'uteliva': ('uteliv',),
'utelivene': ('uteliv',),
'utelivet': ('uteliv',),
'utelukkelse': ('utelukkelse',),
'utelukkelsen': ('utelukkelse',),
'utelukkelsene': ('utelukkelse',),
'utelukkelser': ('utelukkelse',),
'utenatleksa': ('utenatlekse',),
'utenatlekse': ('utenatlekse',),
'utenatleksen': ('utenatlekse',),
'utenatleksene': ('utenatlekse',),
'utenatlekser': ('utenatlekse',),
'utenatlæring': ('utenatlæring',),
'utenatlæringa': ('utenatlæring',),
'utenatlæringen': ('utenatlæring',),
'utenatlæringene': ('utenatlæring',),
'utenatlæringer': ('utenatlæring',),
'utenbordsmotor': ('utenbordsmotor',),
'utenbordsmotoren': ('utenbordsmotor',),
'utenbordsmotorene': ('utenbordsmotor',),
'utenbordsmotorer': ('utenbordsmotor',),
'utenlandsgjeld': ('utenlandsgjeld',),
'utenlandsgjelda': ('utenlandsgjeld',),
'utenlandsgjelden': ('utenlandsgjeld',),
'utenlandsgjeldene': ('utenlandsgjeld',),
'utenlandsgjelder': ('utenlandsgjeld',),
'utenlandsopphold': ('utenlandsopphold',),
'utenlandsoppholda': ('utenlandsopphold',),
'utenlandsoppholdene': ('utenlandsopphold',),
'utenlandsoppholdet': ('utenlandsopphold',),
'utenlandsprefiks': ('utenlandsprefiks',),
'utenlandsprefiksa': ('utenlandsprefiks',),
'utenlandsprefiksene': ('utenlandsprefiks',),
'utenlandsprefikser': ('utenlandsprefiks',),
'utenlandsprefikset': ('utenlandsprefiks',),
'utenlandsreisa': ('utenlandsreise',),
'utenlandsreise': ('utenlandsreise',),
'utenlandsreisen': ('utenlandsreise',),
'utenlandsreisene': ('utenlandsreise',),
'utenlandsreiser': ('utenlandsreise',),
'utenlandsstudent': ('utenlandsstudent',),
'utenlandsstudenten': ('utenlandsstudent',),
'utenlandsstudentene': ('utenlandsstudent',),
'utenlandsstudenter': ('utenlandsstudent',),
'utenomsnakk': ('utenomsnakk',),
'utenomsnakka': ('utenomsnakk',),
'utenomsnakken': ('utenomsnakk',),
'utenomsnakkene': ('utenomsnakk',),
'utenomsnakker': ('utenomsnakk',),
'utenomsnakket': ('utenomsnakk',),
'utenpålomma': ('utenpålomme',),
'utenpålomme': ('utenpålomme',),
'utenpålommen': ('utenpålomme',),
'utenpålommene': ('utenpålomme',),
'utenpålommer': ('utenpålomme',),
'utenpåskrift': ('utenpåskrift',),
'utenpåskrifta': ('utenpåskrift',),
'utenpåskriften': ('utenpåskrift',),
'utenpåskriftene': ('utenpåskrift',),
'utenpåskrifter': ('utenpåskrift',),
'utenpåtøy': ('utenpåtøy',),
'utenpåtøya': ('utenpåtøy',),
'utenpåtøyene': ('utenpåtøy',),
'utenpåtøyer': ('utenpåtøy',),
'utenpåtøyet': ('utenpåtøy',),
'utenriksdepartement': ('utenriksdepartement',),
'utenriksdepartementa': ('utenriksdepartement',),
'utenriksdepartementene': ('utenriksdepartement',),
'utenriksdepartementer': ('utenriksdepartement',),
'utenriksdepartementet': ('utenriksdepartement',),
'utenriksfart': ('utenriksfart',),
'utenriksfarten': ('utenriksfart',),
'utenriksfartene': ('utenriksfart',),
'utenriksfarter': ('utenriksfart',),
'utenriksflåte': ('utenriksflåte',),
'utenriksflåten': ('utenriksflåte',),
'utenriksflåtene': ('utenriksflåte',),
'utenriksflåter': ('utenriksflåte',),
'utenrikshandel': ('utenrikshandel',),
'utenrikshandelen': ('utenrikshandel',),
'utenrikshandlene': ('utenrikshandel',),
'utenrikshandler': ('utenrikshandel',),
'utenrikskorrespondent': ('utenrikskorrespondent',),
'utenrikskorrespondenten': ('utenrikskorrespondent',),
'utenrikskorrespondentene': ('utenrikskorrespondent',),
'utenrikskorrespondenter': ('utenrikskorrespondent',),
'utenrikskronikk': ('utenrikskronikk',),
'utenrikskronikken': ('utenrikskronikk',),
'utenrikskronikkene': ('utenrikskronikk',),
'utenrikskronikker': ('utenrikskronikk',),
'utenriksminister': ('utenriksminister',),
'utenriksministere': ('utenriksminister',),
'utenriksministeren': ('utenriksminister',),
'utenriksministerer': ('utenriksminister',),
'utenriksministerne': ('utenriksminister',),
'utenriksministre': ('utenriksminister',),
'utenriksministrene': ('utenriksminister',),
'utenriksministrer': ('utenriksminister',),
'utenrikspolitikk': ('utenrikspolitikk',),
'utenrikspolitikken': ('utenrikspolitikk',),
'utenrikspolitikkene': ('utenrikspolitikk',),
'utenrikspolitikker': ('utenrikspolitikk',),
'utenriksredaktør': ('utenriksredaktør',),
'utenriksredaktøren': ('utenriksredaktør',),
'utenriksredaktørene': ('utenriksredaktør',),
'utenriksredaktører': ('utenriksredaktør',),
'utenrikstjeneste': ('utenrikstjeneste',),
'utenrikstjenesten': ('utenrikstjeneste',),
'utenrikstjenestene': ('utenrikstjeneste',),
'utenrikstjenester': ('utenrikstjeneste',),
'utenskjærsvirksomhet': ('utenskjærsvirksomhet',),
'utenskjærsvirksomheta': ('utenskjærsvirksomhet',),
'utenskjærsvirksomheten': ('utenskjærsvirksomhet',),
'utenskjærsvirksomhetene': ('utenskjærsvirksomhet',),
'utenskjærsvirksomheter': ('utenskjærsvirksomhet',),
'utenverden': ('utenverden',),
'utenverdenen': ('utenverden',),
'utenverdenene': ('utenverden',),
'utenverdener': ('utenverden',),
'uterus': ('uterus',),
'uterusen': ('uterus',),
'uterusene': ('uterus',),
'uteruser': ('uterus',),
'utesegler': ('utesegler',),
'uteseglere': ('utesegler',),
'utesegleren': ('utesegler',),
'uteseglerer': ('utesegler',),
'uteseglerne': ('utesegler',),
'uteseiler': ('uteseiler',),
'uteseilere': ('uteseiler',),
'uteseileren': ('uteseiler',),
'uteseilerer': ('uteseiler',),
'uteseilerne': ('uteseiler',),
'uteseksjon': ('uteseksjon',),
'uteseksjonen': ('uteseksjon',),
'uteseksjonene': ('uteseksjon',),
'uteseksjoner': ('uteseksjon',),
'utespeller': ('utespeller',),
'utespellere': ('utespeller',),
'utespelleren': ('utespeller',),
'utespellerer': ('utespeller',),
'utespellerne': ('utespeller',),
'utespiller': ('utespiller',),
'utespillere': ('utespiller',),
'utespilleren': ('utespiller',),
'utespillerer': ('utespiller',),
'utespillerne': ('utespiller',),
'utested': ('utested',),
'utestedene': ('utested',),
'utesteder': ('utested',),
'utestedet': ('utested',),
'uteståenda': ('utestående',),
'utestående': ('utestående',),
'uteståendene': ('utestående',),
'uteståender': ('utestående',),
'uteståendet': ('utestående',),
'utfôring': ('utfôring',),
'utfôringa': ('utfôring',),
'utfôringen': ('utfôring',),
'utfôringene': ('utfôring',),
'utfôringer': ('utfôring',),
'utfall': ('utfall',),
'utfalla': ('utfall',),
'utfallene': ('utfall',),
'utfallet': ('utfall',),
'utfallsport': ('utfallsport',),
'utfallsporten': ('utfallsport',),
'utfallsportene': ('utfallsport',),
'utfallsporter': ('utfallsport',),
'utfallsvinkel': ('utfallsvinkel',),
'utfallsvinkelen': ('utfallsvinkel',),
'utfallsvinklene': ('utfallsvinkel',),
'utfallsvinkler': ('utfallsvinkel',),
'utfart': ('utfart',),
'utfarten': ('utfart',),
'utfartene': ('utfart',),
'utfarter': ('utfart',),
'utfartsdag': ('utfartsdag',),
'utfartsdagen': ('utfartsdag',),
'utfartsdagene': ('utfartsdag',),
'utfartsdager': ('utfartsdag',),
'utfartssted': ('utfartssted',),
'utfartsstedene': ('utfartssted',),
'utfartssteder': ('utfartssted',),
'utfartsstedet': ('utfartssted',),
'utfartsveg': ('utfartsveg',),
'utfartsvegen': ('utfartsveg',),
'utfartsvegene': ('utfartsveg',),
'utfartsveger': ('utfartsveg',),
'utfartsvei': ('utfartsvei',),
'utfartsveien': ('utfartsvei',),
'utfartsveiene': ('utfartsvei',),
'utfartsveier': ('utfartsvei',),
'utfelling': ('utfelling',),
'utfellinga': ('utfelling',),
'utfellingen': ('utfelling',),
'utfellingene': ('utfelling',),
'utfellinger': ('utfelling',),
'utferd': ('utferd',),
'utferda': ('utferd',),
'utferden': ('utferd',),
'utferdene': ('utferd',),
'utferder': ('utferd',),
'utferdigelse': ('utferdigelse',),
'utferdigelsen': ('utferdigelse',),
'utferdigelsene': ('utferdigelse',),
'utferdigelser': ('utferdigelse',),
'utferdigelsesdag': ('utferdigelsesdag',),
'utferdigelsesdagen': ('utferdigelsesdag',),
'utferdigelsesdagene': ('utferdigelsesdag',),
'utferdigelsesdager': ('utferdigelsesdag',),
'utferdslengsel': ('utferdslengsel',),
'utferdslengselen': ('utferdslengsel',),
'utferdslengslene': ('utferdslengsel',),
'utferdslengsler': ('utferdslengsel',),
'utferdstrang': ('utferdstrang',),
'utferdstrangen': ('utferdstrang',),
'utferdstrangene': ('utferdstrang',),
'utferdstranger': ('utferdstrang',),
'utfjording': ('utfjording',),
'utfjordingen': ('utfjording',),
'utfjordingene': ('utfjording',),
'utfjordinger': ('utfjording',),
'utflagging': ('utflagging',),
'utflagginga': ('utflagging',),
'utflaggingen': ('utflagging',),
'utflaggingene': ('utflagging',),
'utflagginger': ('utflagging',),
'utflod': ('utflod',),
'utfloden': ('utflod',),
'utflodene': ('utflod',),
'utfloder': ('utflod',),
'utflukt': ('utflukt',),
'utflukta': ('utflukt',),
'utflukten': ('utflukt',),
'utfluktene': ('utflukt',),
'utflukter': ('utflukt',),
'utfluktssted': ('utfluktssted',),
'utfluktsstedene': ('utfluktssted',),
'utfluktssteder': ('utfluktssted',),
'utfluktsstedet': ('utfluktssted',),
'utflytning': ('utflytning',),
'utflytninga': ('utflytning',),
'utflytningen': ('utflytning',),
'utflytningene': ('utflytning',),
'utflytninger': ('utflytning',),
'utflytter': ('utflytter',),
'utflyttere': ('utflytter',),
'utflytteren': ('utflytter',),
'utflytterer': ('utflytter',),
'utflytterne': ('utflytter',),
'utflytting': ('utflytting',),
'utflyttinga': ('utflytting',),
'utflyttingen': ('utflytting',),
'utflyttingene': ('utflytting',),
'utflyttinger': ('utflytting',),
'utfoldelse': ('utfoldelse',),
'utfoldelsen': ('utfoldelse',),
'utfoldelsene': ('utfoldelse',),
'utfoldelser': ('utfoldelse',),
'utfolding': ('utfolding',),
'utfoldinga': ('utfolding',),
'utfoldingen': ('utfolding',),
'utfoldingene': ('utfolding',),
'utfoldinger': ('utfolding',),
'utfor': ('utfor',),
'utforen': ('utfor',),
'utforene': ('utfor',),
'utforer': ('utfor',),
'utforbakke': ('utforbakke',),
'utforbakken': ('utforbakke',),
'utforbakkene': ('utforbakke',),
'utforbakker': ('utforbakke',),
'utfordrer': ('utfordrer',),
'utfordrere': ('utfordrer',),
'utfordreren': ('utfordrer',),
'utfordrerer': ('utfordrer',),
'utfordrerne': ('utfordrer',),
'utfordring': ('utfordring',),
'utfordringa': ('utfordring',),
'utfordringen': ('utfordring',),
'utfordringene': ('utfordring',),
'utfordringer': ('utfordring',),
'utforkjører': ('utforkjører',),
'utforkjørere': ('utforkjører',),
'utforkjøreren': ('utforkjører',),
'utforkjørerer': ('utforkjører',),
'utforkjørerne': ('utforkjører',),
'utforkjøring': ('utforkjøring',),
'utforkjøringa': ('utforkjøring',),
'utforkjøringen': ('utforkjøring',),
'utforkjøringene': ('utforkjøring',),
'utforkjøringer': ('utforkjøring',),
'utforløypa': ('utforløype',),
'utforløype': ('utforløype',),
'utforløypen': ('utforløype',),
'utforløypene': ('utforløype',),
'utforløyper': ('utforløype',),
'utforming': ('utforming',),
'utforminga': ('utforming',),
'utformingen': ('utforming',),
'utformingene': ('utforming',),
'utforminger': ('utforming',),
'utforrenn': ('utforrenn',),
'utforrenna': ('utforrenn',),
'utforrennene': ('utforrenn',),
'utforrennet': ('utforrenn',),
'utforsking': ('utforsking',),
'utforskinga': ('utforsking',),
'utforskingen': ('utforsking',),
'utforskingene': ('utforsking',),
'utforskinger': ('utforsking',),
'utforskning': ('utforskning',),
'utforskninga': ('utforskning',),
'utforskningen': ('utforskning',),
'utforskningene': ('utforskning',),
'utforskninger': ('utforskning',),
'utfylling': ('utfylling',),
'utfyllinga': ('utfylling',),
'utfyllingen': ('utfylling',),
'utfyllingene': ('utfylling',),
'utfyllinger': ('utfylling',),
'utførelse': ('utførelse',),
'utførelsen': ('utførelse',),
'utførelsene': ('utførelse',),
'utførelser': ('utførelse',),
'utføring': ('utføring',),
'utføringa': ('utføring',),
'utføringen': ('utføring',),
'utføringene': ('utføring',),
'utføringer': ('utføring',),
'utførsel': ('utførsel',),
'utførselen': ('utførsel',),
'utførslene': ('utførsel',),
'utførsler': ('utførsel',),
'utførselstoll': ('utførselstoll',),
'utførselstollen': ('utførselstoll',),
'utførselstollene': ('utførselstoll',),
'utførselstoller': ('utførselstoll',),
'utførselsvara': ('utførselsvare',),
'utførselsvare': ('utførselsvare',),
'utførselsvaren': ('utførselsvare',),
'utførselsvarene': ('utførselsvare',),
'utførselsvarer': ('utførselsvare',),
'utgang': ('utgang',),
'utgangen': ('utgang',),
'utgangene': ('utgang',),
'utganger': ('utgang',),
'utganger': ('utganger',),
'utgangere': ('utganger',),
'utgangeren': ('utganger',),
'utgangerer': ('utganger',),
'utgangerne': ('utganger',),
'utgangersau': ('utgangersau',),
'utgangersauen': ('utgangersau',),
'utgangersauene': ('utgangersau',),
'utgangersauer': ('utgangersau',),
'utgangsbillett': ('utgangsbillett',),
'utgangsbilletten': ('utgangsbillett',),
'utgangsbillettene': ('utgangsbillett',),
'utgangsbilletter': ('utgangsbillett',),
'utgangsbønn': ('utgangsbønn',),
'utgangsbønna': ('utgangsbønn',),
'utgangsbønnen': ('utgangsbønn',),
'utgangsbønnene': ('utgangsbønn',),
'utgangsbønner': ('utgangsbønn',),
'utgangsdør': ('utgangsdør',),
'utgangsdøra': ('utgangsdør',),
'utgangsdøren': ('utgangsdør',),
'utgangsdørene': ('utgangsdør',),
'utgangsdører': ('utgangsdør',),
'utgangshastighet': ('utgangshastighet',),
'utgangshastigheta': ('utgangshastighet',),
'utgangshastigheten': ('utgangshastighet',),
'utgangshastighetene': ('utgangshastighet',),
'utgangshastigheter': ('utgangshastighet',),
'utgangsport': ('utgangsport',),
'utgangsporten': ('utgangsport',),
'utgangsportene': ('utgangsport',),
'utgangsporter': ('utgangsport',),
'utgangsposisjon': ('utgangsposisjon',),
'utgangsposisjonen': ('utgangsposisjon',),
'utgangsposisjonene': ('utgangsposisjon',),
'utgangsposisjoner': ('utgangsposisjon',),
'utgangspunkt': ('utgangspunkt',),
'utgangspunkta': ('utgangspunkt',),
'utgangspunktene': ('utgangspunkt',),
'utgangspunkter': ('utgangspunkt',),
'utgangspunktet': ('utgangspunkt',),
'utgangsrekka': ('utgangsrekke',),
'utgangsrekke': ('utgangsrekke',),
'utgangsrekken': ('utgangsrekke',),
'utgangsrekkene': ('utgangsrekke',),
'utgangsrekker': ('utgangsrekke',),
'utgangsstilling': ('utgangsstilling',),
'utgangsstillinga': ('utgangsstilling',),
'utgangsstillingen': ('utgangsstilling',),
'utgangsstillingene': ('utgangsstilling',),
'utgangsstillinger': ('utgangsstilling',),
'utgava': ('utgave',),
'utgave': ('utgave',),
'utgaven': ('utgave',),
'utgavene': ('utgave',),
'utgaver': ('utgave',),
'utgift': ('utgift',),
'utgifta': ('utgift',),
'utgiften': ('utgift',),
'utgiftene': ('utgift',),
'utgifter': ('utgift',),
'utgiftspost': ('utgiftspost',),
'utgiftsposten': ('utgiftspost',),
'utgiftspostene': ('utgiftspost',),
'utgiftsposter': ('utgiftspost',),
'utgiing': ('utgiing',),
'utgiinga': ('utgiing',),
'utgiingen': ('utgiing',),
'utgiingene': ('utgiing',),
'utgiinger': ('utgiing',),
'utgivelse': ('utgivelse',),
'utgivelsen': ('utgivelse',),
'utgivelsene': ('utgivelse',),
'utgivelser': ('utgivelse',),
'utgiver': ('utgiver',),
'utgivere': ('utgiver',),
'utgiveren': ('utgiver',),
'utgiverer': ('utgiver',),
'utgiverne': ('utgiver',),
'utgiving': ('utgiving',),
'utgivinga': ('utgiving',),
'utgivingen': ('utgiving',),
'utgivingene': ('utgiving',),
'utgivinger': ('utgiving',),
'utgliding': ('utgliding',),
'utglidinga': ('utgliding',),
'utglidingen': ('utgliding',),
'utglidingene': ('utgliding',),
'utglidinger': ('utgliding',),
'utglidning': ('utglidning',),
'utglidninga': ('utglidning',),
'utglidningen': ('utglidning',),
'utglidningene': ('utglidning',),
'utglidninger': ('utglidning',),
'utgliing': ('utgliing',),
'utgliinga': ('utgliing',),
'utgliingen': ('utgliing',),
'utgliingene': ('utgliing',),
'utgliinger': ('utgliing',),
'utgraver': ('utgraver',),
'utgravere': ('utgraver',),
'utgraveren': ('utgraver',),
'utgraverer': ('utgraver',),
'utgraverne': ('utgraver',),
'utgraving': ('utgraving',),
'utgravinga': ('utgraving',),
'utgravingen': ('utgraving',),
'utgravingene': ('utgraving',),
'utgravinger': ('utgraving',),
'utgravning': ('utgravning',),
'utgravninga': ('utgravning',),
'utgravningen': ('utgravning',),
'utgravningene': ('utgravning',),
'utgravninger': ('utgravning',),
'utgreiing': ('utgreiing',),
'utgreiinga': ('utgreiing',),
'utgreiingen': ('utgreiing',),
'utgreiingene': ('utgreiing',),
'utgreiinger': ('utgreiing',),
'utgruppa': ('utgruppe',),
'utgruppe': ('utgruppe',),
'utgruppen': ('utgruppe',),
'utgruppene': ('utgruppe',),
'utgrupper': ('utgruppe',),
'utgytelse': ('utgytelse',),
'utgytelsen': ('utgytelse',),
'utgytelsene': ('utgytelse',),
'utgytelser': ('utgytelse',),
'uthaler': ('uthaler',),
'uthalere': ('uthaler',),
'uthaleren': ('uthaler',),
'uthalerer': ('uthaler',),
'uthalerne': ('uthaler',),
'uthamn': ('uthamn',),
'uthamna': ('uthamn',),
'uthamnen': ('uthamn',),
'uthamnene': ('uthamn',),
'uthamner': ('uthamn',),
'uthavn': ('uthavn',),
'uthavna': ('uthavn',),
'uthavnen': ('uthavn',),
'uthavnene': ('uthavn',),
'uthavner': ('uthavn',),
'utheng': ('utheng',),
'uthenga': ('utheng',),
'uthengene': ('utheng',),
'uthenget': ('utheng',),
'uthenging': ('uthenging',),
'uthenginga': ('uthenging',),
'uthengingen': ('uthenging',),
'uthengingene': ('uthenging',),
'uthenginger': ('uthenging',),
'uthengning': ('uthengning',),
'uthengninga': ('uthengning',),
'uthengningen': ('uthengning',),
'uthengningene': ('uthengning',),
'uthengninger': ('uthengning',),
'uthengskassa': ('uthengskasse',),
'uthengskasse': ('uthengskasse',),
'uthengskassen': ('uthengskasse',),
'uthengskassene': ('uthengskasse',),
'uthengskasser': ('uthengskasse',),
'uthengsskap': ('uthengsskap',),
'uthengsskapa': ('uthengsskap',),
'uthengsskapene': ('uthengsskap',),
'uthengsskapet': ('uthengsskap',),
'uthengsskilt': ('uthengsskilt',),
'uthengsskilta': ('uthengsskilt',),
'uthengsskiltene': ('uthengsskilt',),
'uthengsskilter': ('uthengsskilt',),
'uthengsskiltet': ('uthengsskilt',),
'uthevelse': ('uthevelse',),
'uthevelsen': ('uthevelse',),
'uthevelsene': ('uthevelse',),
'uthevelser': ('uthevelse',),
'utheving': ('utheving',),
'uthevinga': ('utheving',),
'uthevingen': ('utheving',),
'uthevingene': ('utheving',),
'uthevinger': ('utheving',),
'uthogg': ('uthogg',),
'uthogga': ('uthogg',),
'uthoggene': ('uthogg',),
'uthogget': ('uthogg',),
'uthogst': ('uthogst',),
'uthogsten': ('uthogst',),
'uthogstene': ('uthogst',),
'uthogster': ('uthogst',),
'utholdenhet': ('utholdenhet',),
'utholdenheta': ('utholdenhet',),
'utholdenheten': ('utholdenhet',),
'utholdenhetene': ('utholdenhet',),
'utholdenheter': ('utholdenhet',),
'utholing': ('utholing',),
'utholinga': ('utholing',),
'utholingen': ('utholing',),
'utholingene': ('utholing',),
'utholinger': ('utholing',),
'uthugg': ('uthugg',),
'uthugga': ('uthugg',),
'uthuggene': ('uthugg',),
'uthugget': ('uthugg',),
'uthugst': ('uthugst',),
'uthugsten': ('uthugst',),
'uthugstene': ('uthugst',),
'uthugster': ('uthugst',),
'uthuling': ('uthuling',),
'uthulinga': ('uthuling',),
'uthulingen': ('uthuling',),
'uthulingene': ('uthuling',),
'uthulinger': ('uthuling',),
'uthus': ('uthus',),
'uthusa': ('uthus',),
'uthusene': ('uthus',),
'uthuset': ('uthus',),
'utid': ('utid',),
'utidighet': ('utidighet',),
'utidigheta': ('utidighet',),
'utidigheten': ('utidighet',),
'utidighetene': ('utidighet',),
'utidigheter': ('utidighet',),
'utilfredshet': ('utilfredshet',),
'utilfredsheta': ('utilfredshet',),
'utilfredsheten': ('utilfredshet',),
'utilfredshetene': ('utilfredshet',),
'utilfredsheter': ('utilfredshet',),
'utilisme': ('utilisme',),
'utilismen': ('utilisme',),
'utilismene': ('utilisme',),
'utilismer': ('utilisme',),
'utilist': ('utilist',),
'utilisten': ('utilist',),
'utilistene': ('utilist',),
'utilister': ('utilist',),
'utilitarier': ('utilitarier',),
'utilitariere': ('utilitarier',),
'utilitarieren': ('utilitarier',),
'utilitarierer': ('utilitarier',),
'utilitarierne': ('utilitarier',),
'utilitarisme': ('utilitarisme',),
'utilitarismen': ('utilitarisme',),
'utilitarismene': ('utilitarisme',),
'utilitarismer': ('utilitarisme',),
'uting': ('uting',),
'utinga': ('uting',),
'utingen': ('uting',),
'utingene': ('uting',),
'utjamning': ('utjamning',),
'utjamninga': ('utjamning',),
'utjamningen': ('utjamning',),
'utjamningene': ('utjamning',),
'utjamninger': ('utjamning',),
'utjamningsmandat': ('utjamningsmandat',),
'utjamningsmandata': ('utjamningsmandat',),
'utjamningsmandatene': ('utjamningsmandat',),
'utjamningsmandater': ('utjamningsmandat',),
'utjamningsmandatet': ('utjamningsmandat',),
'utjevning': ('utjevning',),
'utjevninga': ('utjevning',),
'utjevningen': ('utjevning',),
'utjevningene': ('utjevning',),
'utjevninger': ('utjevning',),
'utjevningsmandat': ('utjevningsmandat',),
'utjevningsmandata': ('utjevningsmandat',),
'utjevningsmandatene': ('utjevningsmandat',),
'utjevningsmandater': ('utjevningsmandat',),
'utjevningsmandatet': ('utjevningsmandat',),
'utkallelse': ('utkallelse',),
'utkallelsen': ('utkallelse',),
'utkallelsene': ('utkallelse',),
'utkallelser': ('utkallelse',),
'utkalling': ('utkalling',),
'utkallinga': ('utkalling',),
'utkallingen': ('utkalling',),
'utkallingene': ('utkalling',),
'utkallinger': ('utkalling',),
'utkant': ('utkant',),
'utkanten': ('utkant',),
'utkantene': ('utkant',),
'utkanter': ('utkant',),
'utkantstrøk': ('utkantstrøk',),
'utkantstrøka': ('utkantstrøk',),
'utkantstrøkene': ('utkantstrøk',),
'utkantstrøket': ('utkantstrøk',),
'utkast': ('utkast',),
'utkasta': ('utkast',),
'utkastene': ('utkast',),
'utkastet': ('utkast',),
'utkastelse': ('utkastelse',),
'utkastelsen': ('utkastelse',),
'utkastelsene': ('utkastelse',),
'utkastelser': ('utkastelse',),
'utkaster': ('utkaster',),
'utkastere': ('utkaster',),
'utkasteren': ('utkaster',),
'utkasterer': ('utkaster',),
'utkasterne': ('utkaster',),
'utkasting': ('utkasting',),
'utkastinga': ('utkasting',),
'utkastingen': ('utkasting',),
'utkastingene': ('utkasting',),
'utkastinger': ('utkasting',),
'utkiker': ('utkiker',),
'utkikere': ('utkiker',),
'utkikeren': ('utkiker',),
'utkikerer': ('utkiker',),
'utkikerne': ('utkiker',),
'utkikker': ('utkikker',),
'utkikkere': ('utkikker',),
'utkikkeren': ('utkikker',),
'utkikkerer': ('utkikker',),
'utkikkerne': ('utkikker',),
'utkikkspost': ('utkikkspost',),
'utkikksposten': ('utkikkspost',),
'utkikkspostene': ('utkikkspost',),
'utkikksposter': ('utkikkspost',),
'utkikkssted': ('utkikkssted',),
'utkikksstedene': ('utkikkssted',),
'utkikkssteder': ('utkikkssted',),
'utkikksstedet': ('utkikkssted',),
'utkikkstynna': ('utkikkstynne',),
'utkikkstynne': ('utkikkstynne',),
'utkikkstynnen': ('utkikkstynne',),
'utkikkstynnene': ('utkikkstynne',),
'utkikkstynner': ('utkikkstynne',),
'utkikkstårn': ('utkikkstårn',),
'utkikkstårna': ('utkikkstårn',),
'utkikkstårnene': ('utkikkstårn',),
'utkikkstårnet': ('utkikkstårn',),
'utkikkstønna': ('utkikkstønne',),
'utkikkstønne': ('utkikkstønne',),
'utkikkstønnen': ('utkikkstønne',),
'utkikkstønnene': ('utkikkstønne',),
'utkikkstønner': ('utkikkstønne',),
'utkikspost': ('utkikspost',),
'utkiksposten': ('utkikspost',),
'utkikspostene': ('utkikspost',),
'utkiksposter': ('utkikspost',),
'utkikssted': ('utkikssted',),
'utkiksstedene': ('utkikssted',),
'utkikssteder': ('utkikssted',),
'utkiksstedet': ('utkikssted',),
'utkikstynna': ('utkikstynne',),
'utkikstynne': ('utkikstynne',),
'utkikstynnen': ('utkikstynne',),
'utkikstynnene': ('utkikstynne',),
'utkikstynner': ('utkikstynne',),
'utkikstårn': ('utkikstårn',),
'utkikstårna': ('utkikstårn',),
'utkikstårnene': ('utkikstårn',),
'utkikstårnet': ('utkikstårn',),
'utkikstønna': ('utkikstønne',),
'utkikstønne': ('utkikstønne',),
'utkikstønnen': ('utkikstønne',),
'utkikstønnene': ('utkikstønne',),
'utkikstønner': ('utkikstønne',),
'utkjør': ('utkjør',),
'utkjøra': ('utkjør',),
'utkjørene': ('utkjør',),
'utkjøret': ('utkjør',),
'utkjøring': ('utkjøring',),
'utkjøringa': ('utkjøring',),
'utkjøringen': ('utkjøring',),
'utkjøringene': ('utkjøring',),
'utkjøringer': ('utkjøring',),
'utkjørsel': ('utkjørsel',),
'utkjørselen': ('utkjørsel',),
'utkjørsla': ('utkjørsel',),
'utkjørslene': ('utkjørsel',),
'utkjørsler': ('utkjørsel',),
'utklassing': ('utklassing',),
'utklassinga': ('utklassing',),
'utklassingen': ('utklassing',),
'utklassingene': ('utklassing',),
'utklassinger': ('utklassing',),
'utkleding': ('utkleding',),
'utkledinga': ('utkleding',),
'utkledingen': ('utkleding',),
'utkledingene': ('utkleding',),
'utkledinger': ('utkleding',),
'utkledning': ('utkledning',),
'utkledninga': ('utkledning',),
'utkledningen': ('utkledning',),
'utkledningene': ('utkledning',),
'utkledninger': ('utkledning',),
'utklekking': ('utklekking',),
'utklekkinga': ('utklekking',),
'utklekkingen': ('utklekking',),
'utklekkingene': ('utklekking',),
'utklekkinger': ('utklekking',),
'utklekkingsanstalt': ('utklekkingsanstalt',),
'utklekkingsanstalten': ('utklekkingsanstalt',),
'utklekkingsanstaltene': ('utklekkingsanstalt',),
'utklekkingsanstalter': ('utklekkingsanstalt',),
'utklekkingsfisk': ('utklekkingsfisk',),
'utklekkingsfisken': ('utklekkingsfisk',),
'utklekkingsfiskene': ('utklekkingsfisk',),
'utklekkingsfisker': ('utklekkingsfisk',),
'utklekning': ('utklekning',),
'utklekninga': ('utklekning',),
'utklekningen': ('utklekning',),
'utklekningene': ('utklekning',),
'utklekninger': ('utklekning',),
'utklekningsanstalt': ('utklekningsanstalt',),
'utklekningsanstalten': ('utklekningsanstalt',),
'utklekningsanstaltene': ('utklekningsanstalt',),
'utklekningsanstalter': ('utklekningsanstalt',),
'utklekningsfisk': ('utklekningsfisk',),
'utklekningsfisken': ('utklekningsfisk',),
'utklekningsfiskene': ('utklekningsfisk',),
'utklekningsfisker': ('utklekningsfisk',),
'utklipning': ('utklipning',),
'utklipninga': ('utklipning',),
'utklipningen': ('utklipning',),
'utklipningene': ('utklipning',),
'utklipninger': ('utklipning',),
'utklipningsbyrå': ('utklipningsbyrå',),
'utklipningsbyråa': ('utklipningsbyrå',),
'utklipningsbyråene': ('utklipningsbyrå',),
'utklipningsbyråer': ('utklipningsbyrå',),
'utklipningsbyrået': ('utklipningsbyrå',),
'utklipp': ('utklipp',),
'utklippa': ('utklipp',),
'utklippene': ('utklipp',),
'utklippet': ('utklipp',),
'utklipping': ('utklipping',),
'utklippinga': ('utklipping',),
'utklippingen': ('utklipping',),
'utklippingene': ('utklipping',),
'utklippinger': ('utklipping',),
'utklippingsbyrå': ('utklippingsbyrå',),
'utklippingsbyråa': ('utklippingsbyrå',),
'utklippingsbyråene': ('utklippingsbyrå',),
'utklippingsbyråer': ('utklippingsbyrå',),
'utklippingsbyrået': ('utklippingsbyrå',),
'utklippsalbum': ('utklippsalbum',),
'utklippsalbuma': ('utklippsalbum',),
'utklippsalbumene': ('utklippsalbum',),
'utklippsalbumer': ('utklippsalbum',),
'utklippsalbumet': ('utklippsalbum',),
'utklippsbyrå': ('utklippsbyrå',),
'utklippsbyråa': ('utklippsbyrå',),
'utklippsbyråene': ('utklippsbyrå',),
'utklippsbyråer': ('utklippsbyrå',),
'utklippsbyrået': ('utklippsbyrå',),
'utkobling': ('utkobling',),
'utkoblinga': ('utkobling',),
'utkoblingen': ('utkobling',),
'utkoblingene': ('utkobling',),
'utkoblinger': ('utkobling',),
'utkok': ('utkok',),
'utkoka': ('utkok',),
'utkokene': ('utkok',),
'utkoket': ('utkok',),
'utkoking': ('utkoking',),
'utkokinga': ('utkoking',),
'utkokingen': ('utkoking',),
'utkokingene': ('utkoking',),
'utkokinger': ('utkoking',),
'utkomma': ('utkomme',),
'utkomme': ('utkomme',),
'utkommene': ('utkomme',),
'utkommer': ('utkomme',),
'utkommet': ('utkomme',),
'utkomst': ('utkomst',),
'utkomsten': ('utkomst',),
'utkomstene': ('utkomst',),
'utkomster': ('utkomst',),
'utkopling': ('utkopling',),
'utkoplinga': ('utkopling',),
'utkoplingen': ('utkopling',),
'utkoplingene': ('utkopling',),
'utkoplinger': ('utkopling',),
'utkragning': ('utkragning',),
'utkragninga': ('utkragning',),
'utkragningen': ('utkragning',),
'utkragningene': ('utkragning',),
'utkragninger': ('utkragning',),
'utkroting': ('utkroting',),
'utkrotinga': ('utkroting',),
'utkrotingen': ('utkroting',),
'utkrotingene': ('utkroting',),
'utkrotinger': ('utkroting',),
'utlader': ('utlader',),
'utladere': ('utlader',),
'utladeren': ('utlader',),
'utladerer': ('utlader',),
'utladerne': ('utlader',),
'utladning': ('utladning',),
'utladninga': ('utladning',),
'utladningen': ('utladning',),
'utladningene': ('utladning',),
'utladninger': ('utladning',),
'utland': ('utland',),
'utlanda': ('utland',),
'utlandene': ('utland',),
'utlandet': ('utland',),
'utlegd': ('utlegd',),
'utlegda': ('utlegd',),
'utlegden': ('utlegd',),
'utlegdene': ('utlegd',),
'utlegder': ('utlegd',),
'utlegg': ('utlegg',),
'utlegga': ('utlegg',),
'utleggene': ('utlegg',),
'utlegget': ('utlegg',),
'utleggspant': ('utleggspant',),
'utleggspanta': ('utleggspant',),
'utleggspantene': ('utleggspant',),
'utleggspantet': ('utleggspant',),
'utlegning': ('utlegning',),
'utlegninga': ('utlegning',),
'utlegningen': ('utlegning',),
'utlegningene': ('utlegning',),
'utlegninger': ('utlegning',),
'utleiebil': ('utleiebil',),
'utleiebilen': ('utleiebil',),
'utleiebilene': ('utleiebil',),
'utleiebiler': ('utleiebil',),
'utleier': ('utleier',),
'utleiere': ('utleier',),
'utleieren': ('utleier',),
'utleierer': ('utleier',),
'utleierne': ('utleier',),
'utlendighet': ('utlendighet',),
'utlendigheta': ('utlendighet',),
'utlendigheten': ('utlendighet',),
'utlendighetene': ('utlendighet',),
'utlendigheter': ('utlendighet',),
'utlending': ('utlending',),
'utlendingen': ('utlending',),
'utlendingene': ('utlending',),
'utlendinger': ('utlending',),
'utlengsel': ('utlengsel',),
'utlengselen': ('utlengsel',),
'utlengslene': ('utlengsel',),
'utlengsler': ('utlengsel',),
'utlevering': ('utlevering',),
'utleveringa': ('utlevering',),
'utleveringen': ('utlevering',),
'utleveringene': ('utlevering',),
'utleveringer': ('utlevering',),
'utligger': ('utligger',),
'utliggere': ('utligger',),
'utliggeren': ('utligger',),
'utliggerer': ('utligger',),
'utliggerne': ('utligger',),
'utliggerbåt': ('utliggerbåt',),
'utliggerbåten': ('utliggerbåt',),
'utliggerbåtene': ('utliggerbåt',),
'utliggerbåter': ('utliggerbåt',),
'utligning': ('utligning',),
'utligninga': ('utligning',),
'utligningen': ('utligning',),
'utligningene': ('utligning',),
'utligninger': ('utligning',),
'utlikning': ('utlikning',),
'utlikninga': ('utlikning',),
'utlikningen': ('utlikning',),
'utlikningene': ('utlikning',),
'utlikninger': ('utlikning',),
'utlodding': ('utlodding',),
'utloddinga': ('utlodding',),
'utloddingen': ('utlodding',),
'utloddingene': ('utlodding',),
'utloddinger': ('utlodding',),
'utlodning': ('utlodning',),
'utlodninga': ('utlodning',),
'utlodningen': ('utlodning',),
'utlodningene': ('utlodning',),
'utlodninger': ('utlodning',),
'utlufting': ('utlufting',),
'utluftinga': ('utlufting',),
'utluftingen': ('utlufting',),
'utluftingene': ('utlufting',),
'utluftinger': ('utlufting',),
'utluftning': ('utluftning',),
'utluftninga': ('utluftning',),
'utluftningen': ('utluftning',),
'utluftningene': ('utluftning',),
'utluftninger': ('utluftning',),
'utluting': ('utluting',),
'utlutinga': ('utluting',),
'utlutingen': ('utluting',),
'utlutingene': ('utluting',),
'utlutinger': ('utluting',),
'utlyd': ('utlyd',),
'utlyden': ('utlyd',),
'utlydene': ('utlyd',),
'utlyder': ('utlyd',),
'utlydsvokal': ('utlydsvokal',),
'utlydsvokalen': ('utlydsvokal',),
'utlydsvokalene': ('utlydsvokal',),
'utlydsvokaler': ('utlydsvokal',),
'utlysing': ('utlysing',),
'utlysinga': ('utlysing',),
'utlysingen': ('utlysing',),
'utlysingene': ('utlysing',),
'utlysinger': ('utlysing',),
'utlån': ('utlån',),
'utlåna': ('utlån',),
'utlånene': ('utlån',),
'utlånet': ('utlån',),
'utlåner': ('utlåner',),
'utlånere': ('utlåner',),
'utlåneren': ('utlåner',),
'utlånerer': ('utlåner',),
'utlånerne': ('utlåner',),
'utlånsavdeling': ('utlånsavdeling',),
'utlånsavdelinga': ('utlånsavdeling',),
'utlånsavdelingen': ('utlånsavdeling',),
'utlånsavdelingene': ('utlånsavdeling',),
'utlånsavdelinger': ('utlånsavdeling',),
'utlånskonti': ('utlånskonto',),
'utlånskontiene': ('utlånskonto',),
'utlånskonto': ('utlånskonto',),
'utlånskontoen': ('utlånskonto',),
'utlånskontoene': ('utlånskonto',),
'utlånskontoer': ('utlånskonto',),
'utlånsramma': ('utlånsramme',),
'utlånsramme': ('utlånsramme',),
'utlånsrammen': ('utlånsramme',),
'utlånsrammene': ('utlånsramme',),
'utlånsrammer': ('utlånsramme',),
'utlånsrenta': ('utlånsrente',),
'utlånsrente': ('utlånsrente',),
'utlånsrenten': ('utlånsrente',),
'utlånsrentene': ('utlånsrente',),
'utlånsrenter': ('utlånsrente',),
'utlånsstopp': ('utlånsstopp',),
'utlånsstoppa': ('utlånsstopp',),
'utlånsstoppen': ('utlånsstopp',),
'utlånsstoppene': ('utlånsstopp',),
'utlånsstoppet': ('utlånsstopp',),
'utlånsvirksomhet': ('utlånsvirksomhet',),
'utlånsvirksomheta': ('utlånsvirksomhet',),
'utlånsvirksomheten': ('utlånsvirksomhet',),
'utlånsvirksomhetene': ('utlånsvirksomhet',),
'utlånsvirksomheter': ('utlånsvirksomhet',),
'utløa': ('utløe',),
'utløe': ('utløe',),
'utløen': ('utløe',),
'utløene': ('utløe',),
'utløer': ('utløe',),
'utløp': ('utløp',),
'utløpa': ('utløp',),
'utløpene': ('utløp',),
'utløpet': ('utløp',),
'utløper': ('utløper',),
'utløpere': ('utløper',),
'utløperen': ('utløper',),
'utløperer': ('utløper',),
'utløperne': ('utløper',),
'utløpsgrøft': ('utløpsgrøft',),
'utløpsgrøfta': ('utløpsgrøft',),
'utløpsgrøften': ('utløpsgrøft',),
'utløpsgrøftene': ('utløpsgrøft',),
'utløpsgrøfter': ('utløpsgrøft',),
'utløser': ('utløser',),
'utløsere': ('utløser',),
'utløseren': ('utløser',),
'utløserer': ('utløser',),
'utløserne': ('utløser',),
'utløsing': ('utløsing',),
'utløsinga': ('utløsing',),
'utløsingen': ('utløsing',),
'utløsingene': ('utløsing',),
'utløsinger': ('utløsing',),
'utløsingsmekanisme': ('utløsingsmekanisme',),
'utløsingsmekanismen': ('utløsingsmekanisme',),
'utløsingsmekanismene': ('utløsingsmekanisme',),
'utløsingsmekanismer': ('utløsingsmekanisme',),
'utløsning': ('utløsning',),
'utløsninga': ('utløsning',),
'utløsningen': ('utløsning',),
'utløsningene': ('utløsning',),
'utløsninger': ('utløsning',),
'utløsningsmekanisme': ('utløsningsmekanisme',),
'utløsningsmekanismen': ('utløsningsmekanisme',),
'utløsningsmekanismene': ('utløsningsmekanisme',),
'utløsningsmekanismer': ('utløsningsmekanisme',),
'utløyser': ('utløyser',),
'utløysere': ('utløyser',),
'utløyseren': ('utløyser',),
'utløyserer': ('utløyser',),
'utløyserne': ('utløyser',),
'utløysing': ('utløysing',),
'utløysinga': ('utløysing',),
'utløysingen': ('utløysing',),
'utløysingene': ('utløysing',),
'utløysinger': ('utløysing',),
'utløysingsmekanisme': ('utløysingsmekanisme',),
'utløysingsmekanismen': ('utløysingsmekanisme',),
'utløysingsmekanismene': ('utløysingsmekanisme',),
'utløysingsmekanismer': ('utløysingsmekanisme',),
'utmaling': ('utmaling',),
'utmalinga': ('utmaling',),
'utmalingen': ('utmaling',),
'utmalingene': ('utmaling',),
'utmalinger': ('utmaling',),
'utmalingsgrad': ('utmalingsgrad',),
'utmalingsgraden': ('utmalingsgrad',),
'utmalingsgradene': ('utmalingsgrad',),
'utmalingsgrader': ('utmalingsgrad',),
'utmark': ('utmark',),
'utmarka': ('utmark',),
'utmarken': ('utmark',),
'utmarkene': ('utmark',),
'utmarker': ('utmark',),
'utmarkslæra': ('utmarkslære',),
'utmarkslære': ('utmarkslære',),
'utmarkslæren': ('utmarkslære',),
'utmarkslærene': ('utmarkslære',),
'utmarkslærer': ('utmarkslære',),
'utmarksnæring': ('utmarksnæring',),
'utmarksnæringa': ('utmarksnæring',),
'utmarksnæringen': ('utmarksnæring',),
'utmarksnæringene': ('utmarksnæring',),
'utmarksnæringer': ('utmarksnæring',),
'utmarkstekniker': ('utmarkstekniker',),
'utmarksteknikere': ('utmarkstekniker',),
'utmarksteknikeren': ('utmarkstekniker',),
'utmarksteknikerer': ('utmarkstekniker',),
'utmarksteknikerne': ('utmarkstekniker',),
'utmarsj': ('utmarsj',),
'utmarsjen': ('utmarsj',),
'utmarsjene': ('utmarsj',),
'utmarsjer': ('utmarsj',),
'utmating': ('utmating',),
'utmatinga': ('utmating',),
'utmatingen': ('utmating',),
'utmatingene': ('utmating',),
'utmatinger': ('utmating',),
'utmattelse': ('utmattelse',),
'utmattelsen': ('utmattelse',),
'utmattelsene': ('utmattelse',),
'utmattelser': ('utmattelse',),
'utmattelseskrig': ('utmattelseskrig',),
'utmattelseskrigen': ('utmattelseskrig',),
'utmattelseskrigene': ('utmattelseskrig',),
'utmattelseskriger': ('utmattelseskrig',),
'utmatting': ('utmatting',),
'utmattinga': ('utmatting',),
'utmattingen': ('utmatting',),
'utmattingene': ('utmatting',),
'utmattinger': ('utmatting',),
'utmattingsbrott': ('utmattingsbrott',),
'utmattingsbrotta': ('utmattingsbrott',),
'utmattingsbrottene': ('utmattingsbrott',),
'utmattingsbrottet': ('utmattingsbrott',),
'utmattingsbrudd': ('utmattingsbrudd',),
'utmattingsbrudda': ('utmattingsbrudd',),
'utmattingsbruddene': ('utmattingsbrudd',),
'utmattingsbruddet': ('utmattingsbrudd',),
'utmeldelse': ('utmeldelse',),
'utmeldelsen': ('utmeldelse',),
'utmeldelsene': ('utmeldelse',),
'utmeldelser': ('utmeldelse',),
'utmelding': ('utmelding',),
'utmeldinga': ('utmelding',),
'utmeldingen': ('utmelding',),
'utmeldingene': ('utmelding',),
'utmeldinger': ('utmelding',),
'utmerkelse': ('utmerkelse',),
'utmerkelsen': ('utmerkelse',),
'utmerkelsene': ('utmerkelse',),
'utmerkelser': ('utmerkelse',),
'utmål': ('utmål',),
'utmåla': ('utmål',),
'utmålene': ('utmål',),
'utmålet': ('utmål',),
'utnavn': ('utnavn',),
'utnavna': ('utnavn',),
'utnavnene': ('utnavn',),
'utnavnet': ('utnavn',),
'utnevnelse': ('utnevnelse',),
'utnevnelsen': ('utnevnelse',),
'utnevnelsene': ('utnevnelse',),
'utnevnelser': ('utnevnelse',),
'utnevning': ('utnevning',),
'utnevninga': ('utnevning',),
'utnevningen': ('utnevning',),
'utnevningene': ('utnevning',),
'utnevninger': ('utnevning',),
'utnisting': ('utnisting',),
'utnistinga': ('utnisting',),
'utnistingen': ('utnisting',),
'utnistingene': ('utnisting',),
'utnistinger': ('utnisting',),
'utnyttelse': ('utnyttelse',),
'utnyttelsen': ('utnyttelse',),
'utnyttelsene': ('utnyttelse',),
'utnyttelser': ('utnyttelse',),
'utnyttelsesgrad': ('utnyttelsesgrad',),
'utnyttelsesgraden': ('utnyttelsesgrad',),
'utnyttelsesgradene': ('utnyttelsesgrad',),
'utnyttelsesgrader': ('utnyttelsesgrad',),
'utnytter': ('utnytter',),
'utnyttere': ('utnytter',),
'utnytteren': ('utnytter',),
'utnytterer': ('utnytter',),
'utnytterne': ('utnytter',),
'utnytting': ('utnytting',),
'utnyttinga': ('utnytting',),
'utnyttingen': ('utnytting',),
'utnyttingene': ('utnytting',),
'utnyttinger': ('utnytting',),
'utnyttingsgrad': ('utnyttingsgrad',),
'utnyttingsgraden': ('utnyttingsgrad',),
'utnyttingsgradene': ('utnyttingsgrad',),
'utnyttingsgrader': ('utnyttingsgrad',),
'utopi': ('utopi',),
'utopien': ('utopi',),
'utopiene': ('utopi',),
'utopier': ('utopi',),
'utopist': ('utopist',),
'utopisten': ('utopist',),
'utopistene': ('utopist',),
'utopister': ('utopist',),
'utpanter': ('utpanter',),
'utpantere': ('utpanter',),
'utpanteren': ('utpanter',),
'utpanterer': ('utpanter',),
'utpanterne': ('utpanter',),
'utpanting': ('utpanting',),
'utpantinga': ('utpanting',),
'utpantingen': ('utpanting',),
'utpantingene': ('utpanting',),
'utpantinger': ('utpanting',),
'utpantingsforretning': ('utpantingsforretning',),
'utpantingsforretninga': ('utpantingsforretning',),
'utpantingsforretningen': ('utpantingsforretning',),
'utpantingsforretningene': ('utpantingsforretning',),
'utpantingsforretninger': ('utpantingsforretning',),
'utpantingskjennelse': ('utpantingskjennelse',),
'utpantingskjennelsen': ('utpantingskjennelse',),
'utpantingskjennelsene': ('utpantingskjennelse',),
'utpantingskjennelser': ('utpantingskjennelse',),
'utpantning': ('utpantning',),
'utpantninga': ('utpantning',),
'utpantningen': ('utpantning',),
'utpantningene': ('utpantning',),
'utpantninger': ('utpantning',),
'utpining': ('utpining',),
'utpininga': ('utpining',),
'utpiningen': ('utpining',),
'utpiningene': ('utpining',),
'utpininger': ('utpining',),
'utplanting': ('utplanting',),
'utplantinga': ('utplanting',),
'utplantingen': ('utplanting',),
'utplantingene': ('utplanting',),
'utplantinger': ('utplanting',),
'utplantning': ('utplantning',),
'utplantninga': ('utplantning',),
'utplantningen': ('utplantning',),
'utplantningene': ('utplantning',),
'utplantninger': ('utplantning',),
'utplassering': ('utplassering',),
'utplasseringa': ('utplassering',),
'utplasseringen': ('utplassering',),
'utplasseringene': ('utplassering',),
'utplasseringer': ('utplassering',),
'utplukk': ('utplukk',),
'utplukka': ('utplukk',),
'utplukkene': ('utplukk',),
'utplukket': ('utplukk',),
'utplukking': ('utplukking',),
'utplukkinga': ('utplukking',),
'utplukkingen': ('utplukking',),
'utplukkingene': ('utplukking',),
'utplukkinger': ('utplukking',),
'utplyndrer': ('utplyndrer',),
'utplyndrere': ('utplyndrer',),
'utplyndreren': ('utplyndrer',),
'utplyndrerer': ('utplyndrer',),
'utplyndrerne': ('utplyndrer',),
'utposing': ('utposing',),
'utposinga': ('utposing',),
'utposingen': ('utposing',),
'utposingene': ('utposing',),
'utposinger': ('utposing',),
'utposning': ('utposning',),
'utposninga': ('utposning',),
'utposningen': ('utposning',),
'utposningene': ('utposning',),
'utposninger': ('utposning',),
'utpost': ('utpost',),
'utposten': ('utpost',),
'utpostene': ('utpost',),
'utposter': ('utpost',),
'utpresning': ('utpresning',),
'utpresninga': ('utpresning',),
'utpresningen': ('utpresning',),
'utpresningene': ('utpresning',),
'utpresninger': ('utpresning',),
'utpresser': ('utpresser',),
'utpressere': ('utpresser',),
'utpresseren': ('utpresser',),
'utpresserer': ('utpresser',),
'utpresserne': ('utpresser',),
'utpressing': ('utpressing',),
'utpressinga': ('utpressing',),
'utpressingen': ('utpressing',),
'utpressingene': ('utpressing',),
'utpressinger': ('utpressing',),
'utprogram': ('utprogram',),
'utprogramma': ('utprogram',),
'utprogrammene': ('utprogram',),
'utprogrammer': ('utprogram',),
'utprogrammet': ('utprogram',),
'utprøving': ('utprøving',),
'utprøvinga': ('utprøving',),
'utprøvingen': ('utprøving',),
'utprøvingene': ('utprøving',),
'utprøvinger': ('utprøving',),
'utprøvning': ('utprøvning',),
'utprøvninga': ('utprøvning',),
'utprøvningen': ('utprøvning',),
'utprøvningene': ('utprøvning',),
'utprøvninger': ('utprøvning',),
'utpusting': ('utpusting',),
'utpustinga': ('utpusting',),
'utpustingen': ('utpusting',),
'utpustingene': ('utpusting',),
'utpustinger': ('utpusting',),
'utpynting': ('utpynting',),
'utpyntinga': ('utpynting',),
'utpyntingen': ('utpynting',),
'utpyntingene': ('utpynting',),
'utpyntinger': ('utpynting',),
'utreder': ('utreder',),
'utredere': ('utreder',),
'utrederen': ('utreder',),
'utrederer': ('utreder',),
'utrederne': ('utreder',),
'utredning': ('utredning',),
'utredninga': ('utredning',),
'utredningen': ('utredning',),
'utredningene': ('utredning',),
'utredninger': ('utredning',),
'utredsel': ('utredsel',),
'utredselen': ('utredsel',),
'utredsla': ('utredsel',),
'utredslene': ('utredsel',),
'utredsler': ('utredsel',),
'utregning': ('utregning',),
'utregninga': ('utregning',),
'utregningen': ('utregning',),
'utregningene': ('utregning',),
'utregninger': ('utregning',),
'utregning': ('utregning',),
'utregninga': ('utregning',),
'utregningen': ('utregning',),
'utregningene': ('utregning',),
'utregninger': ('utregning',),
'utreisa': ('utreise',),
'utreise': ('utreise',),
'utreisen': ('utreise',),
'utreisene': ('utreise',),
'utreiser': ('utreise',),
'utreisetillatelse': ('utreisetillatelse',),
'utreisetillatelsen': ('utreisetillatelse',),
'utreisetillatelsene': ('utreisetillatelse',),
'utreisetillatelser': ('utreisetillatelse',),
'utrekning': ('utrekning',),
'utrekninga': ('utrekning',),
'utrekningen': ('utrekning',),
'utrekningene': ('utrekning',),
'utrekninger': ('utrekning',),
'utrekning': ('utrekning',),
'utrekninga': ('utrekning',),
'utrekningen': ('utrekning',),
'utrekningene': ('utrekning',),
'utrekninger': ('utrekning',),
'utrengsmål': ('utrengsmål',),
'utrengsmåla': ('utrengsmål',),
'utrengsmålene': ('utrengsmål',),
'utrengsmålet': ('utrengsmål',),
'utrensing': ('utrensing',),
'utrensinga': ('utrensing',),
'utrensingen': ('utrensing',),
'utrensingene': ('utrensing',),
'utrensinger': ('utrensing',),
'utrensingsaksjon': ('utrensingsaksjon',),
'utrensingsaksjonen': ('utrensingsaksjon',),
'utrensingsaksjonene': ('utrensingsaksjon',),
'utrensingsaksjoner': ('utrensingsaksjon',),
'utrensking': ('utrensking',),
'utrenskinga': ('utrensking',),
'utrenskingen': ('utrensking',),
'utrenskingene': ('utrensking',),
'utrenskinger': ('utrensking',),
'utrenskingsaksjon': ('utrenskingsaksjon',),
'utrenskingsaksjonen': ('utrenskingsaksjon',),
'utrenskingsaksjonene': ('utrenskingsaksjon',),
'utrenskingsaksjoner': ('utrenskingsaksjon',),
'utrenskning': ('utrenskning',),
'utrenskninga': ('utrenskning',),
'utrenskningen': ('utrenskning',),
'utrenskningene': ('utrenskning',),
'utrenskninger': ('utrenskning',),
'utrenskningsaksjon': ('utrenskningsaksjon',),
'utrenskningsaksjonen': ('utrenskningsaksjon',),
'utrenskningsaksjonene': ('utrenskningsaksjon',),
'utrenskningsaksjoner': ('utrenskningsaksjon',),
'utrensning': ('utrensning',),
'utrensninga': ('utrensning',),
'utrensningen': ('utrensning',),
'utrensningene': ('utrensning',),
'utrensninger': ('utrensning',),
'utrensningsaksjon': ('utrensningsaksjon',),
'utrensningsaksjonen': ('utrensningsaksjon',),
'utrensningsaksjonene': ('utrensningsaksjon',),
'utrensningsaksjoner': ('utrensningsaksjon',),
'utrigger': ('utrigger',),
'utriggere': ('utrigger',),
'utriggeren': ('utrigger',),
'utriggerer': ('utrigger',),
'utriggerne': ('utrigger',),
'utringing': ('utringing',),
'utringinga': ('utringing',),
'utringingen': ('utringing',),
'utringingene': ('utringing',),
'utringinger': ('utringing',),
'utringning': ('utringning',),
'utringninga': ('utringning',),
'utringningen': ('utringning',),
'utringningene': ('utringning',),
'utringninger': ('utringning',),
'utrivsel': ('utrivsel',),
'utrivselen': ('utrivsel',),
'utrivslene': ('utrivsel',),
'utrivsler': ('utrivsel',),
'utrogn': ('utrogn',),
'utrogna': ('utrogn',),
'utrognen': ('utrogn',),
'utrognene': ('utrogn',),
'utrogner': ('utrogn',),
'utrop': ('utrop',),
'utropa': ('utrop',),
'utropene': ('utrop',),
'utropet': ('utrop',),
'utroper': ('utroper',),
'utropere': ('utroper',),
'utroperen': ('utroper',),
'utroperer': ('utroper',),
'utroperne': ('utroper',),
'utropsord': ('utropsord',),
'utropsorda': ('utropsord',),
'utropsordene': ('utropsord',),
'utropsordet': ('utropsord',),
'utropstegn': ('utropstegn',),
'utropstegna': ('utropstegn',),
'utropstegnene': ('utropstegn',),
'utropstegnet': ('utropstegn',),
'utror': ('utror',),
'utroren': ('utror',),
'utrorene': ('utror',),
'utrorer': ('utror',),
'utroskap': ('utroskap',),
'utroskapen': ('utroskap',),
'utroskapene': ('utroskap',),
'utroskaper': ('utroskap',),
'utruging': ('utruging',),
'utruginga': ('utruging',),
'utrugingen': ('utruging',),
'utrugingene': ('utruging',),
'utruginger': ('utruging',),
'utrugingsmaskin': ('utrugingsmaskin',),
'utrugingsmaskina': ('utrugingsmaskin',),
'utrugingsmaskinen': ('utrugingsmaskin',),
'utrugingsmaskinene': ('utrugingsmaskin',),
'utrugingsmaskiner': ('utrugingsmaskin',),
'utrugning': ('utrugning',),
'utrugninga': ('utrugning',),
'utrugningen': ('utrugning',),
'utrugningene': ('utrugning',),
'utrugninger': ('utrugning',),
'utrugningsmaskin': ('utrugningsmaskin',),
'utrugningsmaskina': ('utrugningsmaskin',),
'utrugningsmaskinen': ('utrugningsmaskin',),
'utrugningsmaskinene': ('utrugningsmaskin',),
'utrugningsmaskiner': ('utrugningsmaskin',),
'utruskap': ('utruskap',),
'utruskapen': ('utruskap',),
'utruskapene': ('utruskap',),
'utruskaper': ('utruskap',),
'utrusting': ('utrusting',),
'utrustinga': ('utrusting',),
'utrustingen': ('utrusting',),
'utrustingene': ('utrusting',),
'utrustinger': ('utrusting',),
'utryddelse': ('utryddelse',),
'utryddelsen': ('utryddelse',),
'utryddelsene': ('utryddelse',),
'utryddelser': ('utryddelse',),
'utryddelseskrig': ('utryddelseskrig',),
'utryddelseskrigen': ('utryddelseskrig',),
'utryddelseskrigene': ('utryddelseskrig',),
'utryddelseskriger': ('utryddelseskrig',),
'utrydding': ('utrydding',),
'utryddinga': ('utrydding',),
'utryddingen': ('utrydding',),
'utryddingene': ('utrydding',),
'utryddinger': ('utrydding',),
'utrygghet': ('utrygghet',),
'utryggheta': ('utrygghet',),
'utryggheten': ('utrygghet',),
'utrygghetene': ('utrygghet',),
'utryggheter': ('utrygghet',),
'utrygghetsfølelse': ('utrygghetsfølelse',),
'utrygghetsfølelsen': ('utrygghetsfølelse',),
'utrygghetsfølelsene': ('utrygghetsfølelse',),
'utrygghetsfølelser': ('utrygghetsfølelse',),
'utrykk': ('utrykk',),
'utrykka': ('utrykk',),
'utrykken': ('utrykk',),
'utrykkene': ('utrykk',),
'utrykket': ('utrykk',),
'utrykking': ('utrykking',),
'utrykkinga': ('utrykking',),
'utrykkingen': ('utrykking',),
'utrykkingene': ('utrykking',),
'utrykkinger': ('utrykking',),
'utrykning': ('utrykning',),
'utrykninga': ('utrykning',),
'utrykningen': ('utrykning',),
'utrykningene': ('utrykning',),
'utrykninger': ('utrykning',),
'utrykningskjøretøy': ('utrykningskjøretøy',),
'utrykningskjøretøya': ('utrykningskjøretøy',),
'utrykningskjøretøyene': ('utrykningskjøretøy',),
'utrykningskjøretøyer': ('utrykningskjøretøy',),
'utrykningskjøretøyet': ('utrykningskjøretøy',),
'utrykningsordre': ('utrykningsordre',),
'utrykningsordren': ('utrykningsordre',),
'utrykningsordrene': ('utrykningsordre',),
'utrykningsordrer': ('utrykningsordre',),
'utrykningspoliti': ('utrykningspoliti',),
'utrykningspolitia': ('utrykningspoliti',),
'utrykningspolitiene': ('utrykningspoliti',),
'utrykningspolitier': ('utrykningspoliti',),
'utrykningspolitiet': ('utrykningspoliti',),
'utrykningssjef': ('utrykningssjef',),
'utrykningssjefen': ('utrykningssjef',),
'utrykningssjefene': ('utrykningssjef',),
'utrykningssjefer': ('utrykningssjef',),
'utsagn': ('utsagn',),
'utsagna': ('utsagn',),
'utsagnene': ('utsagn',),
'utsagnet': ('utsagn',),
'utsagnssetning': ('utsagnssetning',),
'utsagnssetninga': ('utsagnssetning',),
'utsagnssetningen': ('utsagnssetning',),
'utsagnssetningene': ('utsagnssetning',),
'utsagnssetninger': ('utsagnssetning',),
'utsalg': ('utsalg',),
'utsalga': ('utsalg',),
'utsalgene': ('utsalg',),
'utsalget': ('utsalg',),
'utsalgspris': ('utsalgspris',),
'utsalgsprisen': ('utsalgspris',),
'utsalgsprisene': ('utsalgspris',),
'utsalgspriser': ('utsalgspris',),
'utsalgsvara': ('utsalgsvare',),
'utsalgsvare': ('utsalgsvare',),
'utsalgsvaren': ('utsalgsvare',),
'utsalgsvarene': ('utsalgsvare',),
'utsalgsvarer': ('utsalgsvare',),
'utseende': ('utseende',),
'utseendene': ('utseende',),
'utseender': ('utseende',),
'utseendet': ('utseende',),
'utsegling': ('utsegling',),
'utseglinga': ('utsegling',),
'utseglingen': ('utsegling',),
'utseglingene': ('utsegling',),
'utseglinger': ('utsegling',),
'utseiling': ('utseiling',),
'utseilinga': ('utseiling',),
'utseilingen': ('utseiling',),
'utseilingene': ('utseiling',),
'utseilinger': ('utseiling',),
'utsendelse': ('utsendelse',),
'utsendelsen': ('utsendelse',),
'utsendelsene': ('utsendelse',),
'utsendelser': ('utsendelse',),
'utsending': ('utsending',),
'utsendingen': ('utsending',),
'utsendingene': ('utsending',),
'utsendinger': ('utsending',),
'utsending': ('utsending',),
'utsendinga': ('utsending',),
'utsendingen': ('utsending',),
'utsendingene': ('utsending',),
'utsendinger': ('utsending',),
'utsetning': ('utsetning',),
'utsetninga': ('utsetning',),
'utsetningen': ('utsetning',),
'utsetningene': ('utsetning',),
'utsetninger': ('utsetning',),
'utsettelse': ('utsettelse',),
'utsettelsen': ('utsettelse',),
'utsettelsene': ('utsettelse',),
'utsettelser': ('utsettelse',),
'utsettelsespolitikk': ('utsettelsespolitikk',),
'utsettelsespolitikken': ('utsettelsespolitikk',),
'utsettelsespolitikkene': ('utsettelsespolitikk',),
'utsettelsespolitikker': ('utsettelsespolitikk',),
'utsetting': ('utsetting',),
'utsettinga': ('utsetting',),
'utsettingen': ('utsetting',),
'utsettingene': ('utsetting',),
'utsettinger': ('utsetting',),
'utsetting': ('utsetting',),
'utsettinga': ('utsetting',),
'utsettingen': ('utsetting',),
'utsettingene': ('utsetting',),
'utsettinger': ('utsetting',),
'utsida': ('utside',),
'utside': ('utside',),
'utsiden': ('utside',),
'utsidene': ('utside',),
'utsider': ('utside',),
'utsig': ('utsig',),
'utsiga': ('utsig',),
'utsigene': ('utsig',),
'utsiget': ('utsig',),
'utsikt': ('utsikt',),
'utsikta': ('utsikt',),
'utsikten': ('utsikt',),
'utsiktene': ('utsikt',),
'utsikter': ('utsikt',),
'utsiktstårn': ('utsiktstårn',),
'utsiktstårna': ('utsiktstårn',),
'utsiktstårnene': ('utsiktstårn',),
'utsiktstårnet': ('utsiktstårn',),
'utsjalting': ('utsjalting',),
'utsjaltinga': ('utsjalting',),
'utsjaltingen': ('utsjalting',),
'utsjaltingene': ('utsjalting',),
'utsjaltinger': ('utsjalting',),
'utsjekking': ('utsjekking',),
'utsjekkinga': ('utsjekking',),
'utsjekkingen': ('utsjekking',),
'utsjekkingene': ('utsjekking',),
'utsjekkinger': ('utsjekking',),
'utskei': ('utskei',),
'utskeia': ('utskei',),
'utskeien': ('utskei',),
'utskeiene': ('utskei',),
'utskeier': ('utskei',),
'utskeiet': ('utskei',),
'utskeielse': ('utskeielse',),
'utskeielsen': ('utskeielse',),
'utskeielsene': ('utskeielse',),
'utskeielser': ('utskeielse',),
'utskeiing': ('utskeiing',),
'utskeiinga': ('utskeiing',),
'utskeiingen': ('utskeiing',),
'utskeiingene': ('utskeiing',),
'utskeiinger': ('utskeiing',),
'utskifting': ('utskifting',),
'utskiftinga': ('utskifting',),
'utskiftingen': ('utskifting',),
'utskiftingene': ('utskifting',),
'utskiftinger': ('utskifting',),
'utskiftning': ('utskiftning',),
'utskiftninga': ('utskiftning',),
'utskiftningen': ('utskiftning',),
'utskiftningene': ('utskiftning',),
'utskiftninger': ('utskiftning',),
'utskilling': ('utskilling',),
'utskillinga': ('utskilling',),
'utskillingen': ('utskilling',),
'utskillingene': ('utskilling',),
'utskillinger': ('utskilling',),
'utskillingsprosess': ('utskillingsprosess',),
'utskillingsprosessen': ('utskillingsprosess',),
'utskillingsprosessene': ('utskillingsprosess',),
'utskillingsprosesser': ('utskillingsprosess',),
'utskiper': ('utskiper',),
'utskipere': ('utskiper',),
'utskiperen': ('utskiper',),
'utskiperer': ('utskiper',),
'utskiperne': ('utskiper',),
'utskiping': ('utskiping',),
'utskipinga': ('utskiping',),
'utskipingen': ('utskiping',),
'utskipingene': ('utskiping',),
'utskipinger': ('utskiping',),
'utskipingssted': ('utskipingssted',),
'utskipingsstedene': ('utskipingssted',),
'utskipingssteder': ('utskipingssted',),
'utskipingsstedet': ('utskipingssted',),
'utskipning': ('utskipning',),
'utskipninga': ('utskipning',),
'utskipningen': ('utskipning',),
'utskipningene': ('utskipning',),
'utskipninger': ('utskipning',),
'utskipningssted': ('utskipningssted',),
'utskipningsstedene': ('utskipningssted',),
'utskipningssteder': ('utskipningssted',),
'utskipningsstedet': ('utskipningssted',),
'utskjelling': ('utskjelling',),
'utskjellinga': ('utskjelling',),
'utskjellingen': ('utskjelling',),
'utskjellingene': ('utskjelling',),
'utskjellinger': ('utskjelling',),
'utskjemming': ('utskjemming',),
'utskjemminga': ('utskjemming',),
'utskjemmingen': ('utskjemming',),
'utskjemmingene': ('utskjemming',),
'utskjemminger': ('utskjemming',),
'utskjenking': ('utskjenking',),
'utskjenkinga': ('utskjenking',),
'utskjenkingen': ('utskjenking',),
'utskjenkingene': ('utskjenking',),
'utskjenkinger': ('utskjenking',),
'utskjenkingssted': ('utskjenkingssted',),
'utskjenkingsstedene': ('utskjenkingssted',),
'utskjenkingssteder': ('utskjenkingssted',),
'utskjenkingsstedet': ('utskjenkingssted',),
'utskjenkning': ('utskjenkning',),
'utskjenkninga': ('utskjenkning',),
'utskjenkningen': ('utskjenkning',),
'utskjenkningene': ('utskjenkning',),
'utskjenkninger': ('utskjenkning',),
'utskjenkningssted': ('utskjenkningssted',),
'utskjenkningsstedene': ('utskjenkningssted',),
'utskjenkningssteder': ('utskjenkningssted',),
'utskjenkningsstedet': ('utskjenkningssted',),
'utskjær': ('utskjær',),
'utskjæra': ('utskjær',),
'utskjærene': ('utskjær',),
'utskjæret': ('utskjær',),
'utskjær': ('utskjær',),
'utskjæra': ('utskjær',),
'utskjærene': ('utskjær',),
'utskjæret': ('utskjær',),
'utskjær': ('utskjær',),
'utskjæra': ('utskjær',),
'utskjærene': ('utskjær',),
'utskjæret': ('utskjær',),
'utskjærer': ('utskjærer',),
'utskjærere': ('utskjærer',),
'utskjæreren': ('utskjærer',),
'utskjærerer': ('utskjærer',),
'utskjærerne': ('utskjærer',),
'utskjæring': ('utskjæring',),
'utskjæringa': ('utskjæring',),
'utskjæringen': ('utskjæring',),
'utskjæringene': ('utskjæring',),
'utskjæringer': ('utskjæring',),
'utskott': ('utskott',),
'utskotta': ('utskott',),
'utskottene': ('utskott',),
'utskottet': ('utskott',),
'utskott': ('utskott',),
'utskotta': ('utskott',),
'utskottene': ('utskott',),
'utskottet': ('utskott',),
'utskottsvara': ('utskottsvare',),
'utskottsvare': ('utskottsvare',),
'utskottsvaren': ('utskottsvare',),
'utskottsvarene': ('utskottsvare',),
'utskottsvarer': ('utskottsvare',),
'utskraping': ('utskraping',),
'utskrapinga': ('utskraping',),
'utskrapingen': ('utskraping',),
'utskrapingene': ('utskraping',),
'utskrapinger': ('utskraping',),
'utskrapning': ('utskrapning',),
'utskrapninga': ('utskrapning',),
'utskrapningen': ('utskrapning',),
'utskrapningene': ('utskrapning',),
'utskrapninger': ('utskrapning',),
'utskrift': ('utskrift',),
'utskrifta': ('utskrift',),
'utskriften': ('utskrift',),
'utskriftene': ('utskrift',),
'utskrifter': ('utskrift',),
'utskriving': ('utskriving',),
'utskrivinga': ('utskriving',),
'utskrivingen': ('utskriving',),
'utskrivingene': ('utskriving',),
'utskrivinger': ('utskriving',),
'utskrivning': ('utskrivning',),
'utskrivninga': ('utskrivning',),
'utskrivningen': ('utskrivning',),
'utskrivningene': ('utskrivning',),
'utskrivninger': ('utskrivning',),
'utskudd': ('utskudd',),
'utskudda': ('utskudd',),
'utskuddene': ('utskudd',),
'utskuddet': ('utskudd',),
'utskudd': ('utskudd',),
'utskudda': ('utskudd',),
'utskuddene': ('utskudd',),
'utskuddet': ('utskudd',),
'utskuddsvara': ('utskuddsvare',),
'utskuddsvare': ('utskuddsvare',),
'utskuddsvaren': ('utskuddsvare',),
'utskuddsvarene': ('utskuddsvare',),
'utskuddsvarer': ('utskuddsvare',),
'utskurd': ('utskurd',),
'utskurden': ('utskurd',),
'utskurdene': ('utskurd',),
'utskurder': ('utskurd',),
'utskylling': ('utskylling',),
'utskyllinga': ('utskylling',),
'utskyllingen': ('utskylling',),
'utskyllingene': ('utskylling',),
'utskyllinger': ('utskylling',),
'utskyting': ('utskyting',),
'utskytinga': ('utskyting',),
'utskytingen': ('utskyting',),
'utskytingene': ('utskyting',),
'utskytinger': ('utskyting',),
'utskytingsbase': ('utskytingsbase',),
'utskytingsbasen': ('utskytingsbase',),
'utskytingsbasene': ('utskytingsbase',),
'utskytingsbaser': ('utskytingsbase',),
'utskytingsrampa': ('utskytingsrampe',),
'utskytingsrampe': ('utskytingsrampe',),
'utskytingsrampen': ('utskytingsrampe',),
'utskytingsrampene': ('utskytingsrampe',),
'utskytingsramper': ('utskytingsrampe',),
'utskytning': ('utskytning',),
'utskytninga': ('utskytning',),
'utskytningen': ('utskytning',),
'utskytningene': ('utskytning',),
'utskytninger': ('utskytning',),
'utskytningsbase': ('utskytningsbase',),
'utskytningsbasen': ('utskytningsbase',),
'utskytningsbasene': ('utskytningsbase',),
'utskytningsbaser': ('utskytningsbase',),
'utskytningsrampa': ('utskytningsrampe',),
'utskytningsrampe': ('utskytningsrampe',),
'utskytningsrampen': ('utskytningsrampe',),
'utskytningsrampene': ('utskytningsrampe',),
'utskytningsramper': ('utskytningsrampe',),
'utslag': ('utslag',),
'utslaga': ('utslag',),
'utslagene': ('utslag',),
'utslaget': ('utslag',),
'utslagsmetode': ('utslagsmetode',),
'utslagsmetoden': ('utslagsmetode',),
'utslagsmetodene': ('utslagsmetode',),
'utslagsmetoder': ('utslagsmetode',),
'utslagsvask': ('utslagsvask',),
'utslagsvasken': ('utslagsvask',),
'utslagsvaskene': ('utslagsvask',),
'utslagsvasker': ('utslagsvask',),
'utslagsvinkel': ('utslagsvinkel',),
'utslagsvinkelen': ('utslagsvinkel',),
'utslagsvinklene': ('utslagsvinkel',),
'utslagsvinkler': ('utslagsvinkel',),
'utslepp': ('utslepp',),
'utsleppa': ('utslepp',),
'utsleppene': ('utslepp',),
'utsleppet': ('utslepp',),
'utslepping': ('utslepping',),
'utsleppinga': ('utslepping',),
'utsleppingen': ('utslepping',),
'utsleppingene': ('utslepping',),
'utsleppinger': ('utslepping',),
'utsleppstillatelse': ('utsleppstillatelse',),
'utsleppstillatelsen': ('utsleppstillatelse',),
'utsleppstillatelsene': ('utsleppstillatelse',),
'utsleppstillatelser': ('utsleppstillatelse',),
'utslett': ('utslett',),
'utsletta': ('utslett',),
'utslettene': ('utslett',),
'utslettet': ('utslett',),
'utslettelse': ('utslettelse',),
'utslettelsen': ('utslettelse',),
'utslettelsene': ('utslettelse',),
'utslettelser': ('utslettelse',),
'utsletting': ('utsletting',),
'utslettinga': ('utsletting',),
'utslettingen': ('utsletting',),
'utslettingene': ('utsletting',),
'utslettinger': ('utsletting',),
'utslipp': ('utslipp',),
'utslippa': ('utslipp',),
'utslippene': ('utslipp',),
'utslippet': ('utslipp',),
'utslipping': ('utslipping',),
'utslippinga': ('utslipping',),
'utslippingen': ('utslipping',),
'utslippingene': ('utslipping',),
'utslippinger': ('utslipping',),
'utslippstillatelse': ('utslippstillatelse',),
'utslippstillatelsen': ('utslippstillatelse',),
'utslippstillatelsene': ('utslippstillatelse',),
'utslippstillatelser': ('utslippstillatelse',),
'utslått': ('utslått',),
'utslåtten': ('utslått',),
'utslåttene': ('utslått',),
'utslåtter': ('utslått',),
'utsmykking': ('utsmykking',),
'utsmykkinga': ('utsmykking',),
'utsmykkingen': ('utsmykking',),
'utsmykkingene': ('utsmykking',),
'utsmykkinger': ('utsmykking',),
'utsmykning': ('utsmykning',),
'utsmykninga': ('utsmykning',),
'utsmykningen': ('utsmykning',),
'utsmykningene': ('utsmykning',),
'utsmykninger': ('utsmykning',),
'utsnitt': ('utsnitt',),
'utsnitta': ('utsnitt',),
'utsnittene': ('utsnitt',),
'utsnittet': ('utsnitt',),
'utsparing': ('utsparing',),
'utsparinga': ('utsparing',),
'utsparingen': ('utsparing',),
'utsparingene': ('utsparing',),
'utsparinger': ('utsparing',),
'utspark': ('utspark',),
'utsparka': ('utspark',),
'utsparkene': ('utspark',),
'utsparket': ('utspark',),
'utspenning': ('utspenning',),
'utspenninga': ('utspenning',),
'utspenningen': ('utspenning',),
'utspenningene': ('utspenning',),
'utspenninger': ('utspenning',),
'utspiling': ('utspiling',),
'utspilinga': ('utspiling',),
'utspilingen': ('utspiling',),
'utspilingene': ('utspiling',),
'utspilinger': ('utspiling',),
'utspill': ('utspill',),
'utspilla': ('utspill',),
'utspillene': ('utspill',),
'utspillet': ('utspill',),
'utspiller': ('utspiller',),
'utspillere': ('utspiller',),
'utspilleren': ('utspiller',),
'utspillerer': ('utspiller',),
'utspillerne': ('utspiller',),
'utspjåking': ('utspjåking',),
'utspjåkinga': ('utspjåking',),
'utspjåkingen': ('utspjåking',),
'utspjåkingene': ('utspjåking',),
'utspjåkinger': ('utspjåking',),
'utsprang': ('utsprang',),
'utspranga': ('utsprang',),
'utsprangene': ('utsprang',),
'utspranget': ('utsprang',),
'utsprenging': ('utsprenging',),
'utsprenginga': ('utsprenging',),
'utsprengingen': ('utsprenging',),
'utsprengingene': ('utsprenging',),
'utsprenginger': ('utsprenging',),
'utsprengning': ('utsprengning',),
'utsprengninga': ('utsprengning',),
'utsprengningen': ('utsprengning',),
'utsprengningene': ('utsprengning',),
'utsprengninger': ('utsprengning',),
'utspring': ('utspring',),
'utspringa': ('utspring',),
'utspringene': ('utspring',),
'utspringet': ('utspring',),
'utspørring': ('utspørring',),
'utspørringa': ('utspørring',),
'utspørringen': ('utspørring',),
'utspørringene': ('utspørring',),
'utspørringer': ('utspørring',),
'utstedelse': ('utstedelse',),
'utstedelsen': ('utstedelse',),
'utstedelsene': ('utstedelse',),
'utstedelser': ('utstedelse',),
'utstedelsesdag': ('utstedelsesdag',),
'utstedelsesdagen': ('utstedelsesdag',),
'utstedelsesdagene': ('utstedelsesdag',),
'utstedelsesdager': ('utstedelsesdag',),
'utstedelsessted': ('utstedelsessted',),
'utstedelsesstedene': ('utstedelsessted',),
'utstedelsessteder': ('utstedelsessted',),
'utstedelsesstedet': ('utstedelsessted',),
'utsteder': ('utsteder',),
'utstedere': ('utsteder',),
'utstederen': ('utsteder',),
'utstederer': ('utsteder',),
'utstederne': ('utsteder',),
'utstikker': ('utstikker',),
'utstikkere': ('utstikker',),
'utstikkeren': ('utstikker',),
'utstikkerer': ('utstikker',),
'utstikkerne': ('utstikker',),
'utstikkerbrygga': ('utstikkerbrygge',),
'utstikkerbrygge': ('utstikkerbrygge',),
'utstikkerbryggen': ('utstikkerbrygge',),
'utstikkerbryggene': ('utstikkerbrygge',),
'utstikkerbrygger': ('utstikkerbrygge',),
'utstikking': ('utstikking',),
'utstikkinga': ('utstikking',),
'utstikkingen': ('utstikking',),
'utstikkingene': ('utstikking',),
'utstikkinger': ('utstikking',),
'utstikning': ('utstikning',),
'utstikninga': ('utstikning',),
'utstikningen': ('utstikning',),
'utstikningene': ('utstikning',),
'utstikninger': ('utstikning',),
'utstiller': ('utstiller',),
'utstillere': ('utstiller',),
'utstilleren': ('utstiller',),
'utstillerer': ('utstiller',),
'utstillerne': ('utstiller',),
'utstilling': ('utstilling',),
'utstillinga': ('utstilling',),
'utstillingen': ('utstilling',),
'utstillingene': ('utstilling',),
'utstillinger': ('utstilling',),
'utstillingsdokka': ('utstillingsdokke',),
'utstillingsdokke': ('utstillingsdokke',),
'utstillingsdokken': ('utstillingsdokke',),
'utstillingsdokkene': ('utstillingsdokke',),
'utstillingsdokker': ('utstillingsdokke',),
'utstillingsdukka': ('utstillingsdukke',),
'utstillingsdukke': ('utstillingsdukke',),
'utstillingsdukken': ('utstillingsdukke',),
'utstillingsdukkene': ('utstillingsdukke',),
'utstillingsdukker': ('utstillingsdukke',),
'utstillingskassa': ('utstillingskasse',),
'utstillingskasse': ('utstillingskasse',),
'utstillingskassen': ('utstillingskasse',),
'utstillingskassene': ('utstillingskasse',),
'utstillingskasser': ('utstillingskasse',),
'utstillingslokala': ('utstillingslokale',),
'utstillingslokale': ('utstillingslokale',),
'utstillingslokalene': ('utstillingslokale',),
'utstillingslokaler': ('utstillingslokale',),
'utstillingslokalet': ('utstillingslokale',),
'utstillingsmonter': ('utstillingsmonter',),
'utstillingsmontere': ('utstillingsmonter',),
'utstillingsmonteren': ('utstillingsmonter',),
'utstillingsmonterne': ('utstillingsmonter',),
'utstillingsmontre': ('utstillingsmonter',),
'utstillingsmontrene': ('utstillingsmonter',),
'utstillingsmontrer': ('utstillingsmonter',),
'utstillingsmontre': ('utstillingsmontre',),
'utstillingsmontren': ('utstillingsmontre',),
'utstillingsmontrene': ('utstillingsmontre',),
'utstillingsmontrer': ('utstillingsmontre',),
'utstillingsvara': ('utstillingsvare',),
'utstillingsvare': ('utstillingsvare',),
'utstillingsvaren': ('utstillingsvare',),
'utstillingsvarene': ('utstillingsvare',),
'utstillingsvarer': ('utstillingsvare',),
'utstillingsvindu': ('utstillingsvindu',),
'utstillingsvindua': ('utstillingsvindu',),
'utstillingsvinduene': ('utstillingsvindu',),
'utstillingsvinduer': ('utstillingsvindu',),
'utstillingsvinduet': ('utstillingsvindu',),
'utstopper': ('utstopper',),
'utstoppere': ('utstopper',),
'utstopperen': ('utstopper',),
'utstopperer': ('utstopper',),
'utstopperne': ('utstopper',),
'utstrekking': ('utstrekking',),
'utstrekkinga': ('utstrekking',),
'utstrekkingen': ('utstrekking',),
'utstrekkingene': ('utstrekking',),
'utstrekkinger': ('utstrekking',),
'utstrekning': ('utstrekning',),
'utstrekninga': ('utstrekning',),
'utstrekningen': ('utstrekning',),
'utstrekningene': ('utstrekning',),
'utstrekninger': ('utstrekning',),
'utstryking': ('utstryking',),
'utstrykinga': ('utstryking',),
'utstrykingen': ('utstryking',),
'utstrykingene': ('utstryking',),
'utstrykinger': ('utstryking',),
'utstrykning': ('utstrykning',),
'utstrykninga': ('utstrykning',),
'utstrykningen': ('utstrykning',),
'utstrykningene': ('utstrykning',),
'utstrykninger': ('utstrykning',),
'utstråling': ('utstråling',),
'utstrålinga': ('utstråling',),
'utstrålingen': ('utstråling',),
'utstrålingene': ('utstråling',),
'utstrålinger': ('utstråling',),
'utstrømming': ('utstrømming',),
'utstrømminga': ('utstrømming',),
'utstrømmingen': ('utstrømming',),
'utstrømmingene': ('utstrømming',),
'utstrømminger': ('utstrømming',),
'utstrømmingsventil': ('utstrømmingsventil',),
'utstrømmingsventilen': ('utstrømmingsventil',),
'utstrømmingsventilene': ('utstrømmingsventil',),
'utstrømmingsventiler': ('utstrømmingsventil',),
'utstrømning': ('utstrømning',),
'utstrømninga': ('utstrømning',),
'utstrømningen': ('utstrømning',),
'utstrømningene': ('utstrømning',),
'utstrømninger': ('utstrømning',),
'utstrømningsventil': ('utstrømningsventil',),
'utstrømningsventilen': ('utstrømningsventil',),
'utstrømningsventilene': ('utstrømningsventil',),
'utstrømningsventiler': ('utstrømningsventil',),
'utstyr': ('utstyr',),
'utstyra': ('utstyr',),
'utstyrene': ('utstyr',),
'utstyret': ('utstyr',),
'utstyrsfilm': ('utstyrsfilm',),
'utstyrsfilmen': ('utstyrsfilm',),
'utstyrsfilmene': ('utstyrsfilm',),
'utstyrsfilmer': ('utstyrsfilm',),
'utstyrsforretning': ('utstyrsforretning',),
'utstyrsforretninga': ('utstyrsforretning',),
'utstyrsforretningen': ('utstyrsforretning',),
'utstyrsforretningene': ('utstyrsforretning',),
'utstyrsforretninger': ('utstyrsforretning',),
'utstyrsmagasin': ('utstyrsmagasin',),
'utstyrsmagasina': ('utstyrsmagasin',),
'utstyrsmagasinene': ('utstyrsmagasin',),
'utstyrsmagasiner': ('utstyrsmagasin',),
'utstyrsmagasinet': ('utstyrsmagasin',),
'utsuger': ('utsuger',),
'utsugere': ('utsuger',),
'utsugeren': ('utsuger',),
'utsugerer': ('utsuger',),
'utsugerne': ('utsuger',),
'utsuging': ('utsuging',),
'utsuginga': ('utsuging',),
'utsugingen': ('utsuging',),
'utsugingene': ('utsuging',),
'utsuginger': ('utsuging',),
'utsultingsblokade': ('utsultingsblokade',),
'utsultingsblokaden': ('utsultingsblokade',),
'utsultingsblokadene': ('utsultingsblokade',),
'utsultingsblokader': ('utsultingsblokade',),
'utsvevelse': ('utsvevelse',),
'utsvevelsen': ('utsvevelse',),
'utsvevelsene': ('utsvevelse',),
'utsvevelser': ('utsvevelse',),
'utsving': ('utsving',),
'utsvinga': ('utsving',),
'utsvingen': ('utsving',),
'utsvingene': ('utsving',),
'utsvinger': ('utsving',),
'utsvinget': ('utsving',),
'utsvinging': ('utsvinging',),
'utsvinginga': ('utsvinging',),
'utsvingingen': ('utsvinging',),
'utsvingingene': ('utsvinging',),
'utsvinginger': ('utsvinging',),
'utsvingning': ('utsvingning',),
'utsvingninga': ('utsvingning',),
'utsvingningen': ('utsvingning',),
'utsvingningene': ('utsvingning',),
'utsvingninger': ('utsvingning',),
'utsyn': ('utsyn',),
'utsyna': ('utsyn',),
'utsynene': ('utsyn',),
'utsynet': ('utsyn',),
'utsynspunkt': ('utsynspunkt',),
'utsynspunkta': ('utsynspunkt',),
'utsynspunktene': ('utsynspunkt',),
'utsynspunkter': ('utsynspunkt',),
'utsynspunktet': ('utsynspunkt',),
'utsæd': ('utsæd',),
'utsæden': ('utsæd',),
'utsædene': ('utsæd',),
'utsæder': ('utsæd',),
'uttaing': ('uttaing',),
'uttainga': ('uttaing',),
'uttaingen': ('uttaing',),
'uttaingene': ('uttaing',),
'uttainger': ('uttaing',),
'uttaing': ('uttaing',),
'uttainga': ('uttaing',),
'uttaingen': ('uttaing',),
'uttaingene': ('uttaing',),
'uttainger': ('uttaing',),
'uttaingsrenn': ('uttaingsrenn',),
'uttaingsrenna': ('uttaingsrenn',),
'uttaingsrennene': ('uttaingsrenn',),
'uttaingsrennet': ('uttaingsrenn',),
'uttak': ('uttak',),
'uttaka': ('uttak',),
'uttakene': ('uttak',),
'uttaket': ('uttak',),
'uttakelse': ('uttakelse',),
'uttakelsen': ('uttakelse',),
'uttakelsene': ('uttakelse',),
'uttakelser': ('uttakelse',),
'uttakelse': ('uttakelse',),
'uttakelsen': ('uttakelse',),
'uttakelsene': ('uttakelse',),
'uttakelser': ('uttakelse',),
'uttaking': ('uttaking',),
'uttakinga': ('uttaking',),
'uttakingen': ('uttaking',),
'uttakingene': ('uttaking',),
'uttakinger': ('uttaking',),
'uttaking': ('uttaking',),
'uttakinga': ('uttaking',),
'uttakingen': ('uttaking',),
'uttakingene': ('uttaking',),
'uttakinger': ('uttaking',),
'uttakingsrenn': ('uttakingsrenn',),
'uttakingsrenna': ('uttakingsrenn',),
'uttakingsrennene': ('uttakingsrenn',),
'uttakingsrennet': ('uttakingsrenn',),
'uttale': ('uttale',),
'uttalen': ('uttale',),
'uttalene': ('uttale',),
'uttaler': ('uttale',),
'uttalefeil': ('uttalefeil',),
'uttalefeilen': ('uttalefeil',),
'uttalefeilene': ('uttalefeil',),
'uttalelse': ('uttalelse',),
'uttalelsen': ('uttalelse',),
'uttalelsene': ('uttalelse',),
'uttalelser': ('uttalelse',),
'uttegner': ('uttegner',),
'uttegnere': ('uttegner',),
'uttegneren': ('uttegner',),
'uttegnerer': ('uttegner',),
'uttegnerne': ('uttegner',),
'uttegning': ('uttegning',),
'uttegninga': ('uttegning',),
'uttegningen': ('uttegning',),
'uttegningene': ('uttegning',),
'uttegninger': ('uttegning',),
'uttelling': ('uttelling',),
'uttellinga': ('uttelling',),
'uttellingen': ('uttelling',),
'uttellingene': ('uttelling',),
'uttellinger': ('uttelling',),
'uttog': ('uttog',),
'uttoga': ('uttog',),
'uttogene': ('uttog',),
'uttoget': ('uttog',),
'uttredelse': ('uttredelse',),
'uttredelsen': ('uttredelse',),
'uttredelsene': ('uttredelse',),
'uttredelser': ('uttredelse',),
'uttreden': ('uttreden',),
'uttredenen': ('uttreden',),
'uttredenene': ('uttreden',),
'uttredener': ('uttreden',),
'uttrekk': ('uttrekk',),
'uttrekka': ('uttrekk',),
'uttrekkene': ('uttrekk',),
'uttrekket': ('uttrekk',),
'uttrekking': ('uttrekking',),
'uttrekkinga': ('uttrekking',),
'uttrekkingen': ('uttrekking',),
'uttrekkingene': ('uttrekking',),
'uttrekkinger': ('uttrekking',),
'uttrekksbord': ('uttrekksbord',),
'uttrekksborda': ('uttrekksbord',),
'uttrekksbordene': ('uttrekksbord',),
'uttrekksborder': ('uttrekksbord',),
'uttrekksbordet': ('uttrekksbord',),
'uttrekksseng': ('uttrekksseng',),
'uttrekkssenga': ('uttrekksseng',),
'uttrekkssengen': ('uttrekksseng',),
'uttrekkssengene': ('uttrekksseng',),
'uttrekkssenger': ('uttrekksseng',),
'uttrekning': ('uttrekning',),
'uttrekninga': ('uttrekning',),
'uttrekningen': ('uttrekning',),
'uttrekningene': ('uttrekning',),
'uttrekninger': ('uttrekning',),
'uttrykk': ('uttrykk',),
'uttrykka': ('uttrykk',),
'uttrykkene': ('uttrykk',),
'uttrykket': ('uttrykk',),
'uttrykksevna': ('uttrykksevne',),
'uttrykksevne': ('uttrykksevne',),
'uttrykksevnen': ('uttrykksevne',),
'uttrykksevnene': ('uttrykksevne',),
'uttrykksevner': ('uttrykksevne',),
'uttrykksform': ('uttrykksform',),
'uttrykksforma': ('uttrykksform',),
'uttrykksformen': ('uttrykksform',),
'uttrykksformene': ('uttrykksform',),
'uttrykksformer': ('uttrykksform',),
'uttrykksmiddel': ('uttrykksmiddel',),
'uttrykksmiddelet': ('uttrykksmiddel',),
'uttrykksmidla': ('uttrykksmiddel',),
'uttrykksmidlene': ('uttrykksmiddel',),
'uttrykksmidler': ('uttrykksmiddel',),
'uttrykksmidlet': ('uttrykksmiddel',),
'uttrykksmåte': ('uttrykksmåte',),
'uttrykksmåten': ('uttrykksmåte',),
'uttrykksmåtene': ('uttrykksmåte',),
'uttrykksmåter': ('uttrykksmåte',),
'uttur': ('uttur',),
'utturen': ('uttur',),
'utturene': ('uttur',),
'utturer': ('uttur',),
'uttydning': ('uttydning',),
'uttydninga': ('uttydning',),
'uttydningen': ('uttydning',),
'uttydningene': ('uttydning',),
'uttydninger': ('uttydning',),
'uttynning': ('uttynning',),
'uttynninga': ('uttynning',),
'uttynningen': ('uttynning',),
'uttynningene': ('uttynning',),
'uttynninger': ('uttynning',),
'uttømming': ('uttømming',),
'uttømminga': ('uttømming',),
'uttømmingen': ('uttømming',),
'uttømmingene': ('uttømming',),
'uttømminger': ('uttømming',),
'uttørking': ('uttørking',),
'uttørkinga': ('uttørking',),
'uttørkingen': ('uttørking',),
'uttørkingene': ('uttørking',),
'uttørkinger': ('uttørking',),
'uttørring': ('uttørring',),
'uttørringa': ('uttørring',),
'uttørringen': ('uttørring',),
'uttørringene': ('uttørring',),
'uttørringer': ('uttørring',),
'utukt': ('utukt',),
'utukta': ('utukt',),
'utukten': ('utukt',),
'utuktene': ('utukt',),
'utukter': ('utukt',),
'utur': ('utur',),
'uturen': ('utur',),
'uturene': ('utur',),
'uturer': ('utur',),
'utvalg': ('utvalg',),
'utvalga': ('utvalg',),
'utvalgene': ('utvalg',),
'utvalget': ('utvalg',),
'utvalgsmedlem': ('utvalgsmedlem',),
'utvalgsmedlemma': ('utvalgsmedlem',),
'utvalgsmedlemmene': ('utvalgsmedlem',),
'utvalgsmedlemmer': ('utvalgsmedlem',),
'utvalgsmedlemmet': ('utvalgsmedlem',),
'utvalsing': ('utvalsing',),
'utvalsinga': ('utvalsing',),
'utvalsingen': ('utvalsing',),
'utvalsingene': ('utvalsing',),
'utvalsinger': ('utvalsing',),
'utvandrer': ('utvandrer',),
'utvandrere': ('utvandrer',),
'utvandreren': ('utvandrer',),
'utvandrerer': ('utvandrer',),
'utvandrerne': ('utvandrer',),
'utvandrerskip': ('utvandrerskip',),
'utvandrerskipa': ('utvandrerskip',),
'utvandrerskipene': ('utvandrerskip',),
'utvandrerskipet': ('utvandrerskip',),
'utvandring': ('utvandring',),
'utvandringa': ('utvandring',),
'utvandringen': ('utvandring',),
'utvandringene': ('utvandring',),
'utvandringer': ('utvandring',),
'utvandringskontor': ('utvandringskontor',),
'utvandringskontora': ('utvandringskontor',),
'utvandringskontorene': ('utvandringskontor',),
'utvandringskontorer': ('utvandringskontor',),
'utvandringskontoret': ('utvandringskontor',),
'utvanning': ('utvanning',),
'utvanninga': ('utvanning',),
'utvanningen': ('utvanning',),
'utvanningene': ('utvanning',),
'utvanninger': ('utvanning',),
'utvasking': ('utvasking',),
'utvaskinga': ('utvasking',),
'utvaskingen': ('utvasking',),
'utvaskingene': ('utvasking',),
'utvaskinger': ('utvasking',),
'utvatning': ('utvatning',),
'utvatninga': ('utvatning',),
'utvatningen': ('utvatning',),
'utvatningene': ('utvatning',),
'utvatninger': ('utvatning',),
'utve': ('utve',),
'utveen': ('utve',),
'utveene': ('utve',),
'utveer': ('utve',),
'utveg': ('utveg',),
'utvegen': ('utveg',),
'utvegene': ('utveg',),
'utveger': ('utveg',),
'utvei': ('utvei',),
'utveien': ('utvei',),
'utveiene': ('utvei',),
'utveier': ('utvei',),
'utveksling': ('utveksling',),
'utvekslinga': ('utveksling',),
'utvekslingen': ('utveksling',),
'utvekslingene': ('utveksling',),
'utvekslinger': ('utveksling',),
'utvekslingsforhold': ('utvekslingsforhold',),
'utvekslingsforholda': ('utvekslingsforhold',),
'utvekslingsforholdene': ('utvekslingsforhold',),
'utvekslingsforholdet': ('utvekslingsforhold',),
'utvekst': ('utvekst',),
'utveksten': ('utvekst',),
'utvekstene': ('utvekst',),
'utvekster': ('utvekst',),
'utvelgelse': ('utvelgelse',),
'utvelgelsen': ('utvelgelse',),
'utvelgelsene': ('utvelgelse',),
'utvelgelser': ('utvelgelse',),
'utvelging': ('utvelging',),
'utvelginga': ('utvelging',),
'utvelgingen': ('utvelging',),
'utvelgingene': ('utvelging',),
'utvelginger': ('utvelging',),
'utvendighet': ('utvendighet',),
'utvendigheta': ('utvendighet',),
'utvendigheten': ('utvendighet',),
'utvendighetene': ('utvendighet',),
'utvendigheter': ('utvendighet',),
'utvidelse': ('utvidelse',),
'utvidelsen': ('utvidelse',),
'utvidelsene': ('utvidelse',),
'utvidelser': ('utvidelse',),
'utvidelsesmulighet': ('utvidelsesmulighet',),
'utvidelsesmuligheta': ('utvidelsesmulighet',),
'utvidelsesmuligheten': ('utvidelsesmulighet',),
'utvidelsesmulighetene': ('utvidelsesmulighet',),
'utvidelsesmuligheter': ('utvidelsesmulighet',),
'utviding': ('utviding',),
'utvidinga': ('utviding',),
'utvidingen': ('utviding',),
'utvidingene': ('utviding',),
'utvidinger': ('utviding',),
'utvikling': ('utvikling',),
'utviklinga': ('utvikling',),
'utviklingen': ('utvikling',),
'utviklingene': ('utvikling',),
'utviklinger': ('utvikling',),
'utviklingsalder': ('utviklingsalder',),
'utviklingsaldere': ('utviklingsalder',),
'utviklingsalderen': ('utviklingsalder',),
'utviklingsalderer': ('utviklingsalder',),
'utviklingsalderne': ('utviklingsalder',),
'utviklingsaldre': ('utviklingsalder',),
'utviklingsaldrene': ('utviklingsalder',),
'utviklingsaldrer': ('utviklingsalder',),
'utviklingsgang': ('utviklingsgang',),
'utviklingsgangen': ('utviklingsgang',),
'utviklingsgangene': ('utviklingsgang',),
'utviklingsganger': ('utviklingsgang',),
'utviklingshjelp': ('utviklingshjelp',),
'utviklingshjelpa': ('utviklingshjelp',),
'utviklingshjelpen': ('utviklingshjelp',),
'utviklingshjelpene': ('utviklingshjelp',),
'utviklingshjelper': ('utviklingshjelp',),
'utviklingsland': ('utviklingsland',),
'utviklingslanda': ('utviklingsland',),
'utviklingslandene': ('utviklingsland',),
'utviklingslandet': ('utviklingsland',),
'utviklingslæra': ('utviklingslære',),
'utviklingslære': ('utviklingslære',),
'utviklingslæren': ('utviklingslære',),
'utviklingslærene': ('utviklingslære',),
'utviklingslærer': ('utviklingslære',),
'utviklingsområda': ('utviklingsområde',),
'utviklingsområde': ('utviklingsområde',),
'utviklingsområdene': ('utviklingsområde',),
'utviklingsområder': ('utviklingsområde',),
'utviklingsområdet': ('utviklingsområde',),
'utviklingsoptimisme': ('utviklingsoptimisme',),
'utviklingsoptimismen': ('utviklingsoptimisme',),
'utviklingsoptimismene': ('utviklingsoptimisme',),
'utviklingsoptimismer': ('utviklingsoptimisme',),
'utviklingspsykologi': ('utviklingspsykologi',),
'utviklingspsykologien': ('utviklingspsykologi',),
'utviklingspsykologiene': ('utviklingspsykologi',),
'utviklingspsykologier': ('utviklingspsykologi',),
'utviklingstrinn': ('utviklingstrinn',),
'utviklingstrinna': ('utviklingstrinn',),
'utviklingstrinnene': ('utviklingstrinn',),
'utviklingstrinnet': ('utviklingstrinn',),
'utvinning': ('utvinning',),
'utvinninga': ('utvinning',),
'utvinningen': ('utvinning',),
'utvinningene': ('utvinning',),
'utvinninger': ('utvinning',),
'utvisning': ('utvisning',),
'utvisninga': ('utvisning',),
'utvisningen': ('utvisning',),
'utvisningene': ('utvisning',),
'utvisninger': ('utvisning',),
'utvisningsboks': ('utvisningsboks',),
'utvisningsboksen': ('utvisningsboks',),
'utvisningsboksene': ('utvisningsboks',),
'utvisningsbokser': ('utvisningsboks',),
'utvisningsordre': ('utvisningsordre',),
'utvisningsordren': ('utvisningsordre',),
'utvisningsordrene': ('utvisningsordre',),
'utvisningsordrer': ('utvisningsordre',),
'utvortes': ('utvortes',),
'utvær': ('utvær',),
'utværa': ('utvær',),
'utværene': ('utvær',),
'utværet': ('utvær',),
'utvær': ('utvær',),
'utværa': ('utvær',),
'utværene': ('utvær',),
'utværet': ('utvær',),
'utværing': ('utværing',),
'utværingen': ('utværing',),
'utværingene': ('utværing',),
'utværinger': ('utværing',),
'utyska': ('utyske',),
'utyske': ('utyske',),
'utyskene': ('utyske',),
'utysker': ('utyske',),
'utysket': ('utyske',),
'utånding': ('utånding',),
'utåndinga': ('utånding',),
'utåndingen': ('utånding',),
'utåndingene': ('utånding',),
'utåndinger': ('utånding',),
'utørken': ('utørken',),
'utørkenen': ('utørken',),
'utørkenene': ('utørken',),
'utørkener': ('utørken',),
'utøvelse': ('utøvelse',),
'utøvelsen': ('utøvelse',),
'utøvelsene': ('utøvelse',),
'utøvelser': ('utøvelse',),
'utøver': ('utøver',),
'utøvere': ('utøver',),
'utøveren': ('utøver',),
'utøverer': ('utøver',),
'utøverne': ('utøver',),
'uvane': ('uvane',),
'uvanen': ('uvane',),
'uvanene': ('uvane',),
'uvaner': ('uvane',),
'uvenn': ('uvenn',),
'uvennen': ('uvenn',),
'uvennene': ('uvenn',),
'uvenner': ('uvenn',),
'uvennlighet': ('uvennlighet',),
'uvennligheta': ('uvennlighet',),
'uvennligheten': ('uvennlighet',),
'uvennlighetene': ('uvennlighet',),
'uvennligheter': ('uvennlighet',),
'uvennskap': ('uvennskap',),
'uvennskapa': ('uvennskap',),
'uvennskapen': ('uvennskap',),
'uvennskapene': ('uvennskap',),
'uvennskaper': ('uvennskap',),
'uvennskapet': ('uvennskap',),
'uvesen': ('uvesen',),
'uvesena': ('uvesen',),
'uvesenene': ('uvesen',),
'uvesener': ('uvesen',),
'uvesenet': ('uvesen',),
'uvesentlighet': ('uvesentlighet',),
'uvesentligheta': ('uvesentlighet',),
'uvesentligheten': ('uvesentlighet',),
'uvesentlighetene': ('uvesentlighet',),
'uvesentligheter': ('uvesentlighet',),
'uvett': ('uvett',),
'uvetta': ('uvett',),
'uvettene': ('uvett',),
'uvettet': ('uvett',),
'uvetta': ('uvette',),
'uvette': ('uvette',),
'uvetten': ('uvette',),
'uvettene': ('uvette',),
'uvetter': ('uvette',),
'uvettet': ('uvette',),
'uvetting': ('uvetting',),
'uvettingen': ('uvetting',),
'uvettingene': ('uvetting',),
'uvettinger': ('uvetting',),
'uvilje': ('uvilje',),
'uviljen': ('uvilje',),
'uviljene': ('uvilje',),
'uviljer': ('uvilje',),
'uvillighet': ('uvillighet',),
'uvilligheta': ('uvillighet',),
'uvilligheten': ('uvillighet',),
'uvillighetene': ('uvillighet',),
'uvilligheter': ('uvillighet',),
'uvirkelighet': ('uvirkelighet',),
'uvirkeligheta': ('uvirkelighet',),
'uvirkeligheten': ('uvirkelighet',),
'uvirkelighetene': ('uvirkelighet',),
'uvirkeligheter': ('uvirkelighet',),
'uvirksomhet': ('uvirksomhet',),
'uvirksomheta': ('uvirksomhet',),
'uvirksomheten': ('uvirksomhet',),
'uvirksomhetene': ('uvirksomhet',),
'uvirksomheter': ('uvirksomhet',),
'uvissa': ('uvisse',),
'uvisse': ('uvisse',),
'uvissen': ('uvisse',),
'uvissene': ('uvisse',),
'uvisser': ('uvisse',),
'uvisshet': ('uvisshet',),
'uvissheta': ('uvisshet',),
'uvissheten': ('uvisshet',),
'uvisshetene': ('uvisshet',),
'uvissheter': ('uvisshet',),
'uvitenhet': ('uvitenhet',),
'uvitenheta': ('uvitenhet',),
'uvitenheten': ('uvitenhet',),
'uvitenhetene': ('uvitenhet',),
'uvitenheter': ('uvitenhet',),
'uvular': ('uvular',),
'uvularen': ('uvular',),
'uvularene': ('uvular',),
'uvularer': ('uvular',),
'uvær': ('uvær',),
'uværa': ('uvær',),
'uværene': ('uvær',),
'uværet': ('uvær',),
'uvær': ('uvær',),
'uværa': ('uvær',),
'uværene': ('uvær',),
'uværet': ('uvær',),
'uværsdag': ('uværsdag',),
'uværsdagen': ('uværsdag',),
'uværsdagene': ('uværsdag',),
'uværsdager': ('uværsdag',),
'uværsfugl': ('uværsfugl',),
'uværsfuglen': ('uværsfugl',),
'uværsfuglene': ('uværsfugl',),
'uværsfugler': ('uværsfugl',),
'uværshimlene': ('uværshimmel',),
'uværshimler': ('uværshimmel',),
'uværshimmel': ('uværshimmel',),
'uværshimmelen': ('uværshimmel',),
'uværsnatt': ('uværsnatt',),
'uværsnatta': ('uværsnatt',),
'uværsnatten': ('uværsnatt',),
'uværsnettene': ('uværsnatt',),
'uværsnetter': ('uværsnatt',),
'uværssentra': ('uværssentrum',),
'uværssentraene': ('uværssentrum',),
'uværssentre': ('uværssentrum',),
'uværssentrene': ('uværssentrum',),
'uværssentret': ('uværssentrum',),
'uværssentrum': ('uværssentrum',),
'uværssentrumet': ('uværssentrum',),
'uværssky': ('uværssky',),
'uværsskya': ('uværssky',),
'uværsskyen': ('uværssky',),
'uværsskyene': ('uværssky',),
'uværsskyer': ('uværssky',),
'uvørding': ('uvørding',),
'uvørdingen': ('uvørding',),
'uvørdingene': ('uvørding',),
'uvørdinger': ('uvørding',),
'uvørdnad': ('uvørdnad',),
'uvørdnaden': ('uvørdnad',),
'uvørdnadene': ('uvørdnad',),
'uvørdnader': ('uvørdnad',),
'uvøring': ('uvøring',),
'uvøringen': ('uvøring',),
'uvøringene': ('uvøring',),
'uvøringer': ('uvøring',),
'uvørnad': ('uvørnad',),
'uvørnaden': ('uvørnad',),
'uvørnadene': ('uvørnad',),
'uvørnader': ('uvørnad',),
'uår': ('uår',),
'uåra': ('uår',),
'uårene': ('uår',),
'uåret': ('uår',),
'uærlighet': ('uærlighet',),
'uærligheta': ('uærlighet',),
'uærligheten': ('uærlighet',),
'uærlighetene': ('uærlighet',),
'uærligheter': ('uærlighet',),
'v': ('v',),
'v\'en': ('v',),
'v-en': ('v',),
'v-ene': ('v',),
'v-er': ('v',),
'vable': ('vable',),
'vablen': ('vable',),
'vablene': ('vable',),
'vabler': ('vable',),
'vad': ('vad',),
'vada': ('vad',),
'vadene': ('vad',),
'vadet': ('vad',),
'vad': ('vad',),
'vada': ('vad',),
'vaden': ('vad',),
'vadene': ('vad',),
'vader': ('vad',),
'vadet': ('vad',),
'vadbein': ('vadbein',),
'vadbeina': ('vadbein',),
'vadbeinene': ('vadbein',),
'vadbeinet': ('vadbein',),
'vadderot': ('vadderot',),
'vadderota': ('vadderot',),
'vadderoten': ('vadderot',),
'vadderotene': ('vadderot',),
'vadefot': ('vadefot',),
'vadefoten': ('vadefot',),
'vadeføttene': ('vadefot',),
'vadeføtter': ('vadefot',),
'vadefugl': ('vadefugl',),
'vadefuglen': ('vadefugl',),
'vadefuglene': ('vadefugl',),
'vadefugler': ('vadefugl',),
'vademekum': ('vademekum',),
'vademekuma': ('vademekum',),
'vademekumene': ('vademekum',),
'vademekumet': ('vademekum',),
'vader': ('vader',),
'vadere': ('vader',),
'vaderen': ('vader',),
'vaderer': ('vader',),
'vaderne': ('vader',),
'vadested': ('vadested',),
'vadestedene': ('vadested',),
'vadesteder': ('vadested',),
'vadestedet': ('vadested',),
'vadestøvel': ('vadestøvel',),
'vadestøvelen': ('vadestøvel',),
'vadestøvlene': ('vadestøvel',),
'vadestøvler': ('vadestøvel',),
'vadmel': ('vadmel',),
'vadmela': ('vadmel',),
'vadmelene': ('vadmel',),
'vadmelet': ('vadmel',),
'vadmelsbuksa': ('vadmelsbukse',),
'vadmelsbukse': ('vadmelsbukse',),
'vadmelsbuksen': ('vadmelsbukse',),
'vadmelsbuksene': ('vadmelsbukse',),
'vadmelsbukser': ('vadmelsbukse',),
'vadmelsklær': ('vadmelsklær',),
'vadmelsklærne': ('vadmelsklær',),
'vadmål': ('vadmål',),
'vadmåla': ('vadmål',),
'vadmålene': ('vadmål',),
'vadmålet': ('vadmål',),
'vadmålsbuksa': ('vadmålsbukse',),
'vadmålsbukse': ('vadmålsbukse',),
'vadmålsbuksen': ('vadmålsbukse',),
'vadmålsbuksene': ('vadmålsbukse',),
'vadmålsbukser': ('vadmålsbukse',),
'vadmålsklær': ('vadmålsklær',),
'vadmålsklærne': ('vadmålsklær',),
'vadsekk': ('vadsekk',),
'vadsekken': ('vadsekk',),
'vadsekkene': ('vadsekk',),
'vadsekker': ('vadsekk',),
'vaffel': ('vaffel',),
'vaffelen': ('vaffel',),
'vaflene': ('vaffel',),
'vafler': ('vaffel',),
'vaffel': ('vaffel',),
'vaffelen': ('vaffel',),
'vaflene': ('vaffel',),
'vafler': ('vaffel',),
'vaffelhjerta': ('vaffelhjerte',),
'vaffelhjerte': ('vaffelhjerte',),
'vaffelhjertene': ('vaffelhjerte',),
'vaffelhjerter': ('vaffelhjerte',),
'vaffelhjertet': ('vaffelhjerte',),
'vaffeljern': ('vaffeljern',),
'vaffeljerna': ('vaffeljern',),
'vaffeljernene': ('vaffeljern',),
'vaffeljernet': ('vaffeljern',),
'vaffelmønster': ('vaffelmønster',),
'vaffelmønsteret': ('vaffelmønster',),
'vaffelmønstra': ('vaffelmønster',),
'vaffelmønstre': ('vaffelmønster',),
'vaffelmønstrene': ('vaffelmønster',),
'vaffelmønstret': ('vaffelmønster',),
'vaffelplata': ('vaffelplate',),
'vaffelplate': ('vaffelplate',),
'vaffelplaten': ('vaffelplate',),
'vaffelplatene': ('vaffelplate',),
'vaffelplater': ('vaffelplate',),
'vaffelrøra': ('vaffelrøre',),
'vaffelrøre': ('vaffelrøre',),
'vaffelrøren': ('vaffelrøre',),
'vaffelrørene': ('vaffelrøre',),
'vaffelrører': ('vaffelrøre',),
'vaffelsåle': ('vaffelsåle',),
'vaffelsålen': ('vaffelsåle',),
'vaffelsålene': ('vaffelsåle',),
'vaffelsåler': ('vaffelsåle',),
'vaffelsøm': ('vaffelsøm',),
'vaffelsømmen': ('vaffelsøm',),
'vaffelsømmene': ('vaffelsøm',),
'vaffelsømmer': ('vaffelsøm',),
'vafling': ('vafling',),
'vaflingen': ('vafling',),
'vaflingene': ('vafling',),
'vaflinger': ('vafling',),
'vagabond': ('vagabond',),
'vagabonden': ('vagabond',),
'vagabondene': ('vagabond',),
'vagabonder': ('vagabond',),
'vagabondasj': ('vagabondasj',),
'vagabondasjen': ('vagabondasj',),
'vagabondasjene': ('vagabondasj',),
'vagabondasjer': ('vagabondasj',),
'vagabondasje': ('vagabondasje',),
'vagabondasjen': ('vagabondasje',),
'vagabondasjene': ('vagabondasje',),
'vagabondasjer': ('vagabondasje',),
'vagabondstrøm': ('vagabondstrøm',),
'vagabondstrømmen': ('vagabondstrøm',),
'vagabondstrømmene': ('vagabondstrøm',),
'vagabondstrømmer': ('vagabondstrøm',),
'vagant': ('vagant',),
'vaganten': ('vagant',),
'vagantene': ('vagant',),
'vaganter': ('vagant',),
'vagantvisa': ('vagantvise',),
'vagantvise': ('vagantvise',),
'vagantvisen': ('vagantvise',),
'vagantvisene': ('vagantvise',),
'vagantviser': ('vagantvise',),
'vagg': ('vagg',),
'vaggen': ('vagg',),
'vaggene': ('vagg',),
'vagger': ('vagg',),
'vagga': ('vagge',),
'vagge': ('vagge',),
'vaggen': ('vagge',),
'vaggene': ('vagge',),
'vagger': ('vagge',),
'vagina': ('vagina',),
'vaginaen': ('vagina',),
'vaginaene': ('vagina',),
'vaginaer': ('vagina',),
'vaginisme': ('vaginisme',),
'vaginismen': ('vaginisme',),
'vaginismene': ('vaginisme',),
'vaginismer': ('vaginisme',),
'vaginitt': ('vaginitt',),
'vaginitten': ('vaginitt',),
'vaginittene': ('vaginitt',),
'vaginitter': ('vaginitt',),
'vagl': ('vagl',),
'vagla': ('vagl',),
'vaglen': ('vagl',),
'vaglene': ('vagl',),
'vagler': ('vagl',),
'vaglet': ('vagl',),
'vagla': ('vagle',),
'vagle': ('vagle',),
'vaglen': ('vagle',),
'vaglene': ('vagle',),
'vagler': ('vagle',),
'vaglet': ('vagle',),
'vagn': ('vagn',),
'vagnen': ('vagn',),
'vagnene': ('vagn',),
'vagner': ('vagn',),
'vaid': ('vaid',),
'vaiden': ('vaid',),
'vaidene': ('vaid',),
'vaider': ('vaid',),
'vaier': ('vaier',),
'vaiere': ('vaier',),
'vaieren': ('vaier',),
'vaierer': ('vaier',),
'vaierne': ('vaier',),
'vaire': ('vaier',),
'vairene': ('vaier',),
'vairer': ('vaier',),
'vaisenhus': ('vaisenhus',),
'vaisenhusa': ('vaisenhus',),
'vaisenhusene': ('vaisenhus',),
'vaisenhuset': ('vaisenhus',),
'vak': ('vak',),
'vaka': ('vak',),
'vakene': ('vak',),
'vaket': ('vak',),
'vakanse': ('vakanse',),
'vakansen': ('vakanse',),
'vakansene': ('vakanse',),
'vakanser': ('vakanse',),
'vaka': ('vake',),
'vake': ('vake',),
'vaken': ('vake',),
'vakene': ('vake',),
'vaker': ('vake',),
'vaker': ('vaker',),
'vakere': ('vaker',),
'vakeren': ('vaker',),
'vakerer': ('vaker',),
'vakerne': ('vaker',),
'vakkermannen': ('vakkermannen',),
'vaksinasjon': ('vaksinasjon',),
'vaksinasjonen': ('vaksinasjon',),
'vaksinasjonene': ('vaksinasjon',),
'vaksinasjoner': ('vaksinasjon',),
'vaksinasjonsattest': ('vaksinasjonsattest',),
'vaksinasjonsattesten': ('vaksinasjonsattest',),
'vaksinasjonsattestene': ('vaksinasjonsattest',),
'vaksinasjonsattester': ('vaksinasjonsattest',),
'vaksinatør': ('vaksinatør',),
'vaksinatøren': ('vaksinatør',),
'vaksinatørene': ('vaksinatør',),
'vaksinatører': ('vaksinatør',),
'vaksina': ('vaksine',),
'vaksine': ('vaksine',),
'vaksinen': ('vaksine',),
'vaksinene': ('vaksine',),
'vaksiner': ('vaksine',),
'vakt': ('vakt',),
'vakta': ('vakt',),
'vakten': ('vakt',),
'vaktene': ('vakt',),
'vakter': ('vakt',),
'vaktarrest': ('vaktarrest',),
'vaktarresten': ('vaktarrest',),
'vaktarrestene': ('vaktarrest',),
'vaktarrester': ('vaktarrest',),
'vaktavløsing': ('vaktavløsing',),
'vaktavløsinga': ('vaktavløsing',),
'vaktavløsingen': ('vaktavløsing',),
'vaktavløsingene': ('vaktavløsing',),
'vaktavløsinger': ('vaktavløsing',),
'vaktavløsning': ('vaktavløsning',),
'vaktavløsninga': ('vaktavløsning',),
'vaktavløsningen': ('vaktavløsning',),
'vaktavløsningene': ('vaktavløsning',),
'vaktavløsninger': ('vaktavløsning',),
'vaktavløysing': ('vaktavløysing',),
'vaktavløysinga': ('vaktavløysing',),
'vaktavløysingen': ('vaktavløysing',),
'vaktavløysingene': ('vaktavløysing',),
'vaktavløysinger': ('vaktavløysing',),
'vaktbåt': ('vaktbåt',),
'vaktbåten': ('vaktbåt',),
'vaktbåtene': ('vaktbåt',),
'vaktbåter': ('vaktbåt',),
'vaktel': ('vaktel',),
'vaktelen': ('vaktel',),
'vaktlene': ('vaktel',),
'vaktler': ('vaktel',),
'vakthold': ('vakthold',),
'vaktholda': ('vakthold',),
'vaktholdene': ('vakthold',),
'vaktholdet': ('vakthold',),
'vakthund': ('vakthund',),
'vakthunden': ('vakthund',),
'vakthundene': ('vakthund',),
'vakthunder': ('vakthund',),
'vaktjournal': ('vaktjournal',),
'vaktjournalen': ('vaktjournal',),
'vaktjournalene': ('vaktjournal',),
'vaktjournaler': ('vaktjournal',),
'vaktkommandør': ('vaktkommandør',),
'vaktkommandøren': ('vaktkommandør',),
'vaktkommandørene': ('vaktkommandør',),
'vaktkommandører': ('vaktkommandør',),
'vaktkvarter': ('vaktkvarter',),
'vaktkvartera': ('vaktkvarter',),
'vaktkvarterene': ('vaktkvarter',),
'vaktkvarterer': ('vaktkvarter',),
'vaktkvarteret': ('vaktkvarter',),
'vaktlista': ('vaktliste',),
'vaktliste': ('vaktliste',),
'vaktlisten': ('vaktliste',),
'vaktlistene': ('vaktliste',),
'vaktlister': ('vaktliste',),
'vaktmann': ('vaktmann',),
'vaktmannen': ('vaktmann',),
'vaktmenn': ('vaktmann',),
'vaktmennene': ('vaktmann',),
'vaktmannskap': ('vaktmannskap',),
'vaktmannskapa': ('vaktmannskap',),
'vaktmannskapene': ('vaktmannskap',),
'vaktmannskaper': ('vaktmannskap',),
'vaktmannskapet': ('vaktmannskap',),
'vaktmester': ('vaktmester',),
'vaktmestere': ('vaktmester',),
'vaktmesteren': ('vaktmester',),
'vaktmesterer': ('vaktmester',),
'vaktmesterne': ('vaktmester',),
'vaktmestre': ('vaktmester',),
'vaktmestrene': ('vaktmester',),
'vaktmestrer': ('vaktmester',),
'vaktordning': ('vaktordning',),
'vaktordninga': ('vaktordning',),
'vaktordningen': ('vaktordning',),
'vaktordningene': ('vaktordning',),
'vaktordninger': ('vaktordning',),
'vaktparade': ('vaktparade',),
'vaktparaden': ('vaktparade',),
'vaktparadene': ('vaktparade',),
'vaktparader': ('vaktparade',),
'vaktpost': ('vaktpost',),
'vaktposten': ('vaktpost',),
'vaktpostene': ('vaktpost',),
'vaktposter': ('vaktpost',),
'vaktrom': ('vaktrom',),
'vaktromma': ('vaktrom',),
'vaktrommene': ('vaktrom',),
'vaktrommet': ('vaktrom',),
'vaktselskap': ('vaktselskap',),
'vaktselskapa': ('vaktselskap',),
'vaktselskapene': ('vaktselskap',),
'vaktselskaper': ('vaktselskap',),
'vaktselskapet': ('vaktselskap',),
'vaktskift': ('vaktskift',),
'vaktskifta': ('vaktskift',),
'vaktskiftene': ('vaktskift',),
'vaktskiftet': ('vaktskift',),
'vaktskifta': ('vaktskifte',),
'vaktskifte': ('vaktskifte',),
'vaktskiftene': ('vaktskifte',),
'vaktskifter': ('vaktskifte',),
'vaktskiftet': ('vaktskifte',),
'vaktstova': ('vaktstove',),
'vaktstove': ('vaktstove',),
'vaktstoven': ('vaktstove',),
'vaktstovene': ('vaktstove',),
'vaktstover': ('vaktstove',),
'vaktstua': ('vaktstue',),
'vaktstue': ('vaktstue',),
'vaktstuen': ('vaktstue',),
'vaktstuene': ('vaktstue',),
'vaktstuer': ('vaktstue',),
'vaktstyrke': ('vaktstyrke',),
'vaktstyrken': ('vaktstyrke',),
'vaktstyrkene': ('vaktstyrke',),
'vaktstyrker': ('vaktstyrke',),
'vakttjeneste': ('vakttjeneste',),
'vakttjenesten': ('vakttjeneste',),
'vakttjenestene': ('vakttjeneste',),
'vakttjenester': ('vakttjeneste',),
'vakttårn': ('vakttårn',),
'vakttårna': ('vakttårn',),
'vakttårnene': ('vakttårn',),
'vakttårnet': ('vakttårn',),
'vakttørn': ('vakttørn',),
'vakttørnen': ('vakttørn',),
'vakttørnene': ('vakttørn',),
'vakttørner': ('vakttørn',),
'vakuol': ('vakuol',),
'vakuolen': ('vakuol',),
'vakuolene': ('vakuol',),
'vakuoler': ('vakuol',),
'vakuole': ('vakuole',),
'vakuolen': ('vakuole',),
'vakuolene': ('vakuole',),
'vakuoler': ('vakuole',),
'vakuum': ('vakuum',),
'vakuuma': ('vakuum',),
'vakuumene': ('vakuum',),
'vakuumer': ('vakuum',),
'vakuumet': ('vakuum',),
'vakuumbrems': ('vakuumbrems',),
'vakuumbremsen': ('vakuumbrems',),
'vakuumbremsene': ('vakuumbrems',),
'vakuumbremser': ('vakuumbrems',),
'vakuumbremsa': ('vakuumbremse',),
'vakuumbremse': ('vakuumbremse',),
'vakuumbremsen': ('vakuumbremse',),
'vakuumbremsene': ('vakuumbremse',),
'vakuumbremser': ('vakuumbremse',),
'vakuumisering': ('vakuumisering',),
'vakuumiseringa': ('vakuumisering',),
'vakuumiseringen': ('vakuumisering',),
'vakuumiseringene': ('vakuumisering',),
'vakuumiseringer': ('vakuumisering',),
'vakuummeter': ('vakuummeter',),
'vakuummeteret': ('vakuummeter',),
'vakuummetra': ('vakuummeter',),
'vakuummetre': ('vakuummeter',),
'vakuummetrene': ('vakuummeter',),
'vakuummetret': ('vakuummeter',),
'vakuumpakning': ('vakuumpakning',),
'vakuumpakninga': ('vakuumpakning',),
'vakuumpakningen': ('vakuumpakning',),
'vakuumpakningene': ('vakuumpakning',),
'vakuumpakninger': ('vakuumpakning',),
'vakuumrør': ('vakuumrør',),
'vakuumrøra': ('vakuumrør',),
'vakuumrørene': ('vakuumrør',),
'vakuumrøret': ('vakuumrør',),
'valbjerk': ('valbjerk',),
'valbjerka': ('valbjerk',),
'valbjerken': ('valbjerk',),
'valbjerkene': ('valbjerk',),
'valbjerker': ('valbjerk',),
'valbjørk': ('valbjørk',),
'valbjørka': ('valbjørk',),
'valbjørken': ('valbjørk',),
'valbjørkene': ('valbjørk',),
'valbjørker': ('valbjørk',),
'valborgsdag': ('valborgsdag',),
'valborgsdagen': ('valborgsdag',),
'valborgsdagene': ('valborgsdag',),
'valborgsdager': ('valborgsdag',),
'valborgsnatt': ('valborgsnatt',),
'valborgsnatta': ('valborgsnatt',),
'valborgsnatten': ('valborgsnatt',),
'valborgsnettene': ('valborgsnatt',),
'valborgsnetter': ('valborgsnatt',),
'vald': ('vald',),
'valda': ('vald',),
'valdene': ('vald',),
'valdet': ('vald',),
'valdrapp': ('valdrapp',),
'valdrappa': ('valdrapp',),
'valdrappen': ('valdrapp',),
'valdrappene': ('valdrapp',),
'valdrapper': ('valdrapp',),
'valdrappet': ('valdrapp',),
'valdris': ('valdris',),
'valdrisen': ('valdris',),
'valdrisene': ('valdris',),
'valdriser': ('valdris',),
'valens': ('valens',),
'valensen': ('valens',),
'valensene': ('valens',),
'valenser': ('valens',),
'valentinsdag': ('valentinsdag',),
'valentinsdagen': ('valentinsdag',),
'valentinsdagene': ('valentinsdag',),
'valentinsdager': ('valentinsdag',),
'valerian': ('valerian',),
'valerianen': ('valerian',),
'valerianene': ('valerian',),
'valerianer': ('valerian',),
'valeriana': ('valeriana',),
'valerianaen': ('valeriana',),
'valerianaene': ('valeriana',),
'valerianaer': ('valeriana',),
'valfart': ('valfart',),
'valfarten': ('valfart',),
'valfartene': ('valfart',),
'valfarter': ('valfart',),
'valg': ('valg',),
'valga': ('valg',),
'valgene': ('valg',),
'valget': ('valg',),
'valgagitasjon': ('valgagitasjon',),
'valgagitasjonen': ('valgagitasjon',),
'valgagitasjonene': ('valgagitasjon',),
'valgagitasjoner': ('valgagitasjon',),
'valgagn': ('valgagn',),
'valgagna': ('valgagn',),
'valgagnene': ('valgagn',),
'valgagnet': ('valgagn',),
'valgallianse': ('valgallianse',),
'valgalliansen': ('valgallianse',),
'valgalliansene': ('valgallianse',),
'valgallianser': ('valgallianse',),
'valgapparat': ('valgapparat',),
'valgapparata': ('valgapparat',),
'valgapparatene': ('valgapparat',),
'valgapparater': ('valgapparat',),
'valgapparatet': ('valgapparat',),
'valgavis': ('valgavis',),
'valgavisa': ('valgavis',),
'valgavisen': ('valgavis',),
'valgavisene': ('valgavis',),
'valgaviser': ('valgavis',),
'valgbarhetsalder': ('valgbarhetsalder',),
'valgbarhetsaldere': ('valgbarhetsalder',),
'valgbarhetsalderen': ('valgbarhetsalder',),
'valgbarhetsalderer': ('valgbarhetsalder',),
'valgbarhetsalderne': ('valgbarhetsalder',),
'valgbarhetsaldre': ('valgbarhetsalder',),
'valgbarhetsaldrene': ('valgbarhetsalder',),
'valgbarhetsaldrer': ('valgbarhetsalder',),
'valgdag': ('valgdag',),
'valgdagen': ('valgdag',),
'valgdagene': ('valgdag',),
'valgdager': ('valgdag',),
'valgdistrikt': ('valgdistrikt',),
'valgdistrikta': ('valgdistrikt',),
'valgdistriktene': ('valgdistrikt',),
'valgdistrikter': ('valgdistrikt',),
'valgdistriktet': ('valgdistrikt',),
'valgfag': ('valgfag',),
'valgfaga': ('valgfag',),
'valgfagene': ('valgfag',),
'valgfaget': ('valgfag',),
'valgflesk': ('valgflesk',),
'valgfleska': ('valgflesk',),
'valgfleskene': ('valgflesk',),
'valgflesket': ('valgflesk',),
'valgforbund': ('valgforbund',),
'valgforbunda': ('valgforbund',),
'valgforbundene': ('valgforbund',),
'valgforbundet': ('valgforbund',),
'valgforsking': ('valgforsking',),
'valgforskinga': ('valgforsking',),
'valgforskingen': ('valgforsking',),
'valgforskingene': ('valgforsking',),
'valgforskinger': ('valgforsking',),
'valgforskning': ('valgforskning',),
'valgforskninga': ('valgforskning',),
'valgforskningen': ('valgforskning',),
'valgforskningene': ('valgforskning',),
'valgforskninger': ('valgforskning',),
'valgfusk': ('valgfusk',),
'valgfuska': ('valgfusk',),
'valgfuskene': ('valgfusk',),
'valgfusket': ('valgfusk',),
'valgkamp': ('valgkamp',),
'valgkampen': ('valgkamp',),
'valgkampene': ('valgkamp',),
'valgkamper': ('valgkamp',),
'valgkampanje': ('valgkampanje',),
'valgkampanjen': ('valgkampanje',),
'valgkampanjene': ('valgkampanje',),
'valgkampanjer': ('valgkampanje',),
'valgkrets': ('valgkrets',),
'valgkretsen': ('valgkrets',),
'valgkretsene': ('valgkrets',),
'valgkretser': ('valgkrets',),
'valglista': ('valgliste',),
'valgliste': ('valgliste',),
'valglisten': ('valgliste',),
'valglistene': ('valgliste',),
'valglister': ('valgliste',),
'valglokala': ('valglokale',),
'valglokale': ('valglokale',),
'valglokalene': ('valglokale',),
'valglokaler': ('valglokale',),
'valglokalet': ('valglokale',),
'valgløfta': ('valgløfte',),
'valgløfte': ('valgløfte',),
'valgløftene': ('valgløfte',),
'valgløfter': ('valgløfte',),
'valgløftet': ('valgløfte',),
'valgmann': ('valgmann',),
'valgmannen': ('valgmann',),
'valgmenn': ('valgmann',),
'valgmennene': ('valgmann',),
'valgmanntal': ('valgmanntal',),
'valgmanntala': ('valgmanntal',),
'valgmanntalene': ('valgmanntal',),
'valgmanntalet': ('valgmanntal',),
'valgmanntall': ('valgmanntall',),
'valgmanntalla': ('valgmanntall',),
'valgmanntallene': ('valgmanntall',),
'valgmanntallet': ('valgmanntall',),
'valgmulighet': ('valgmulighet',),
'valgmuligheta': ('valgmulighet',),
'valgmuligheten': ('valgmulighet',),
'valgmulighetene': ('valgmulighet',),
'valgmuligheter': ('valgmulighet',),
'valgmøta': ('valgmøte',),
'valgmøte': ('valgmøte',),
'valgmøtene': ('valgmøte',),
'valgmøter': ('valgmøte',),
'valgmøtet': ('valgmøte',),
'valgnederlag': ('valgnederlag',),
'valgnederlaga': ('valgnederlag',),
'valgnederlagene': ('valgnederlag',),
'valgnederlaget': ('valgnederlag',),
'valgoppgjør': ('valgoppgjør',),
'valgoppgjøra': ('valgoppgjør',),
'valgoppgjørene': ('valgoppgjør',),
'valgoppgjøret': ('valgoppgjør',),
'valgordning': ('valgordning',),
'valgordninga': ('valgordning',),
'valgordningen': ('valgordning',),
'valgordningene': ('valgordning',),
'valgordninger': ('valgordning',),
'valgperiode': ('valgperiode',),
'valgperioden': ('valgperiode',),
'valgperiodene': ('valgperiode',),
'valgperioder': ('valgperiode',),
'valgprogram': ('valgprogram',),
'valgprogramma': ('valgprogram',),
'valgprogrammene': ('valgprogram',),
'valgprogrammer': ('valgprogram',),
'valgprogrammet': ('valgprogram',),
'valgseier': ('valgseier',),
'valgseiere': ('valgseier',),
'valgseieren': ('valgseier',),
'valgseierne': ('valgseier',),
'valgseire': ('valgseier',),
'valgseirene': ('valgseier',),
'valgseirer': ('valgseier',),
'valgskred': ('valgskred',),
'valgskreda': ('valgskred',),
'valgskredene': ('valgskred',),
'valgskredet': ('valgskred',),
'valgsogn': ('valgsogn',),
'valgsogna': ('valgsogn',),
'valgsognene': ('valgsogn',),
'valgsognet': ('valgsogn',),
'valgsokn': ('valgsokn',),
'valgsokna': ('valgsokn',),
'valgsoknen': ('valgsokn',),
'valgsoknene': ('valgsokn',),
'valgsokner': ('valgsokn',),
'valgsoknet': ('valgsokn',),
'valgspråk': ('valgspråk',),
'valgspråka': ('valgspråk',),
'valgspråkene': ('valgspråk',),
'valgspråket': ('valgspråk',),
'valgstyra': ('valgstyre',),
'valgstyre': ('valgstyre',),
'valgstyrene': ('valgstyre',),
'valgstyrer': ('valgstyre',),
'valgstyret': ('valgstyre',),
'valgting': ('valgting',),
'valgtinga': ('valgting',),
'valgtingene': ('valgting',),
'valgtinget': ('valgting',),
'valgurna': ('valgurne',),
'valgurne': ('valgurne',),
'valgurnen': ('valgurne',),
'valgurnene': ('valgurne',),
'valgurner': ('valgurne',),
'valgvaka': ('valgvake',),
'valgvake': ('valgvake',),
'valgvaken': ('valgvake',),
'valgvakene': ('valgvake',),
'valgvaker': ('valgvake',),
'valgvind': ('valgvind',),
'valgvinden': ('valgvind',),
'valgvindene': ('valgvind',),
'valgvinder': ('valgvind',),
'valgår': ('valgår',),
'valgåra': ('valgår',),
'valgårene': ('valgår',),
'valgåret': ('valgår',),
'validitet': ('validitet',),
'validiteten': ('validitet',),
'validitetene': ('validitet',),
'validiteter': ('validitet',),
'valk': ('valk',),
'valken': ('valk',),
'valkene': ('valk',),
'valker': ('valk',),
'valkebrett': ('valkebrett',),
'valkebretta': ('valkebrett',),
'valkebrettene': ('valkebrett',),
'valkebretter': ('valkebrett',),
'valkebrettet': ('valkebrett',),
'valkyrja': ('valkyrje',),
'valkyrje': ('valkyrje',),
'valkyrjen': ('valkyrje',),
'valkyrjene': ('valkyrje',),
'valkyrjer': ('valkyrje',),
'vallak': ('vallak',),
'vallaken': ('vallak',),
'vallakene': ('vallak',),
'vallaker': ('vallak',),
'valle': ('valle',),
'vallen': ('valle',),
'vallene': ('valle',),
'valler': ('valle',),
'valloner': ('valloner',),
'vallonere': ('valloner',),
'valloneren': ('valloner',),
'vallonerer': ('valloner',),
'vallonerne': ('valloner',),
'vallonsk': ('vallonsk',),
'vallonsken': ('vallonsk',),
'vallonskene': ('vallonsk',),
'vallonsker': ('vallonsk',),
'valm': ('valm',),
'valmen': ('valm',),
'valmene': ('valm',),
'valmer': ('valm',),
'valmtak': ('valmtak',),
'valmtaka': ('valmtak',),
'valmtakene': ('valmtak',),
'valmtaket': ('valmtak',),
'valmue': ('valmue',),
'valmuen': ('valmue',),
'valmuene': ('valmue',),
'valmuer': ('valmue',),
'valmuefamilie': ('valmuefamilie',),
'valmuefamilien': ('valmuefamilie',),
'valmuefamiliene': ('valmuefamilie',),
'valmuefamilier': ('valmuefamilie',),
'valmuefrø': ('valmuefrø',),
'valmuefrøa': ('valmuefrø',),
'valmuefrøene': ('valmuefrø',),
'valmuefrøet': ('valmuefrø',),
'valnøtt': ('valnøtt',),
'valnøtta': ('valnøtt',),
'valnøtten': ('valnøtt',),
'valnøttene': ('valnøtt',),
'valnøtter': ('valnøtt',),
'valnøtt-tre': ('valnøtt-tre',),
'valnøtt-trea': ('valnøtt-tre',),
'valnøtt-treet': ('valnøtt-tre',),
'valnøtt-trær': ('valnøtt-tre',),
'valnøtt-trærne': ('valnøtt-tre',),
'valnøttre': ('valnøttre',),
'valnøttrea': ('valnøttre',),
'valnøttreet': ('valnøttre',),
'valnøttrær': ('valnøttre',),
'valnøttrærne': ('valnøttre',),
'valorisasjon': ('valorisasjon',),
'valorisasjonen': ('valorisasjon',),
'valorisasjonene': ('valorisasjon',),
'valorisasjoner': ('valorisasjon',),
'valp': ('valp',),
'valpen': ('valp',),
'valpene': ('valp',),
'valper': ('valp',),
'valpesjuka': ('valpesjuke',),
'valpesjuke': ('valpesjuke',),
'valpesjuken': ('valpesjuke',),
'valpesjukene': ('valpesjuke',),
'valpesjuker': ('valpesjuke',),
'valpesyka': ('valpesyke',),
'valpesyke': ('valpesyke',),
'valpesyken': ('valpesyke',),
'valpesykene': ('valpesyke',),
'valpesyker': ('valpesyke',),
'valplass': ('valplass',),
'valplassen': ('valplass',),
'valplassene': ('valplass',),
'valplasser': ('valplass',),
'vals': ('vals',),
'valsen': ('vals',),
'valsene': ('vals',),
'valser': ('vals',),
'vals': ('vals',),
'valsen': ('vals',),
'valsene': ('vals',),
'valser': ('vals',),
'valse': ('valse',),
'valsen': ('valse',),
'valsene': ('valse',),
'valser': ('valse',),
'valsejern': ('valsejern',),
'valsejerna': ('valsejern',),
'valsejernene': ('valsejern',),
'valsejernet': ('valsejern',),
'valsemaskin': ('valsemaskin',),
'valsemaskina': ('valsemaskin',),
'valsemaskinen': ('valsemaskin',),
'valsemaskinene': ('valsemaskin',),
'valsemaskiner': ('valsemaskin',),
'valsemølla': ('valsemølle',),
'valsemølle': ('valsemølle',),
'valsemøllen': ('valsemølle',),
'valsemøllene': ('valsemølle',),
'valsemøller': ('valsemølle',),
'valsetakt': ('valsetakt',),
'valsetakta': ('valsetakt',),
'valsetakten': ('valsetakt',),
'valsetaktene': ('valsetakt',),
'valsetakter': ('valsetakt',),
'valsetråd': ('valsetråd',),
'valsetråden': ('valsetråd',),
'valsetrådene': ('valsetråd',),
'valsetråder': ('valsetråd',),
'valseverk': ('valseverk',),
'valseverka': ('valseverk',),
'valseverkene': ('valseverk',),
'valseverker': ('valseverk',),
'valseverket': ('valseverk',),
'valthorn': ('valthorn',),
'valthorna': ('valthorn',),
'valthornene': ('valthorn',),
'valthornet': ('valthorn',),
'valthornist': ('valthornist',),
'valthornisten': ('valthornist',),
'valthornistene': ('valthornist',),
'valthornister': ('valthornist',),
'valurt': ('valurt',),
'valurta': ('valurt',),
'valurten': ('valurt',),
'valurtene': ('valurt',),
'valurter': ('valurt',),
'valuta': ('valuta',),
'valutaen': ('valuta',),
'valutaene': ('valuta',),
'valutaer': ('valuta',),
'valutafond': ('valutafond',),
'valutafonda': ('valutafond',),
'valutafondene': ('valutafond',),
'valutafondet': ('valutafond',),
'valutainnsegling': ('valutainnsegling',),
'valutainnseglinga': ('valutainnsegling',),
'valutainnseglingen': ('valutainnsegling',),
'valutainnseglingene': ('valutainnsegling',),
'valutainnseglinger': ('valutainnsegling',),
'valutainnseiling': ('valutainnseiling',),
'valutainnseilinga': ('valutainnseiling',),
'valutainnseilingen': ('valutainnseiling',),
'valutainnseilingene': ('valutainnseiling',),
'valutainnseilinger': ('valutainnseiling',),
'valutaklausul': ('valutaklausul',),
'valutaklausulen': ('valutaklausul',),
'valutaklausulene': ('valutaklausul',),
'valutaklausuler': ('valutaklausul',),
'valutakurs': ('valutakurs',),
'valutakursen': ('valutakurs',),
'valutakursene': ('valutakurs',),
'valutakurser': ('valutakurs',),
'valutanotering': ('valutanotering',),
'valutanoteringa': ('valutanotering',),
'valutanoteringen': ('valutanotering',),
'valutanoteringene': ('valutanotering',),
'valutanoteringer': ('valutanotering',),
'valutaomsetning': ('valutaomsetning',),
'valutaomsetninga': ('valutaomsetning',),
'valutaomsetningen': ('valutaomsetning',),
'valutaomsetningene': ('valutaomsetning',),
'valutaomsetninger': ('valutaomsetning',),
'valutaoverføring': ('valutaoverføring',),
'valutaoverføringa': ('valutaoverføring',),
'valutaoverføringen': ('valutaoverføring',),
'valutaoverføringene': ('valutaoverføring',),
'valutaoverføringer': ('valutaoverføring',),
'valutaoverskott': ('valutaoverskott',),
'valutaoverskotta': ('valutaoverskott',),
'valutaoverskottene': ('valutaoverskott',),
'valutaoverskottet': ('valutaoverskott',),
'valutaoverskudd': ('valutaoverskudd',),
'valutaoverskudda': ('valutaoverskudd',),
'valutaoverskuddene': ('valutaoverskudd',),
'valutaoverskuddet': ('valutaoverskudd',),
'valutapukkel': ('valutapukkel',),
'valutapukkelen': ('valutapukkel',),
'valutapuklene': ('valutapukkel',),
'valutapukler': ('valutapukkel',),
'valutaregulering': ('valutaregulering',),
'valutareguleringa': ('valutaregulering',),
'valutareguleringen': ('valutaregulering',),
'valutareguleringene': ('valutaregulering',),
'valutareguleringer': ('valutaregulering',),
'valutareserve': ('valutareserve',),
'valutareserven': ('valutareserve',),
'valutareservene': ('valutareserve',),
'valutareserver': ('valutareserve',),
'valutasmugling': ('valutasmugling',),
'valutasmuglinga': ('valutasmugling',),
'valutasmuglingen': ('valutasmugling',),
'valutasmuglingene': ('valutasmugling',),
'valutasmuglinger': ('valutasmugling',),
'valutaspekulasjon': ('valutaspekulasjon',),
'valutaspekulasjonen': ('valutaspekulasjon',),
'valutaspekulasjonene': ('valutaspekulasjon',),
'valutaspekulasjoner': ('valutaspekulasjon',),
'valutaunderskott': ('valutaunderskott',),
'valutaunderskotta': ('valutaunderskott',),
'valutaunderskottene': ('valutaunderskott',),
'valutaunderskottet': ('valutaunderskott',),
'valutaunderskudd': ('valutaunderskudd',),
'valutaunderskudda': ('valutaunderskudd',),
'valutaunderskuddene': ('valutaunderskudd',),
'valutaunderskuddet': ('valutaunderskudd',),
'valvasjon': ('valvasjon',),
'valvasjonen': ('valvasjon',),
'valvasjonene': ('valvasjon',),
'valvasjoner': ('valvasjon',),
'valør': ('valør',),
'valøren': ('valør',),
'valørene': ('valør',),
'valører': ('valør',),
'vamp': ('vamp',),
'vampen': ('vamp',),
'vampene': ('vamp',),
'vamper': ('vamp',),
'vamperolla': ('vamperolle',),
'vamperolle': ('vamperolle',),
'vamperollen': ('vamperolle',),
'vamperollene': ('vamperolle',),
'vamperoller': ('vamperolle',),
'vampyr': ('vampyr',),
'vampyren': ('vampyr',),
'vampyrene': ('vampyr',),
'vampyrer': ('vampyr',),
'vams': ('vams',),
'vamsen': ('vams',),
'vamsene': ('vams',),
'vamser': ('vams',),
'van': ('van',),
'vanen': ('van',),
'vanene': ('van',),
'vaner': ('van',),
'van': ('van',),
'vanen': ('van',),
'vanene': ('van',),
'vaner': ('van',),
'vanadium': ('vanadium',),
'vanadiuma': ('vanadium',),
'vanadiumene': ('vanadium',),
'vanadiumet': ('vanadium',),
'vanadiumstål': ('vanadiumstål',),
'vanadiumståla': ('vanadiumstål',),
'vanadiumstålene': ('vanadiumstål',),
'vanadiumstålet': ('vanadiumstål',),
'vanakt': ('vanakt',),
'vanakten': ('vanakt',),
'vanaktene': ('vanakt',),
'vanakter': ('vanakt',),
'vandal': ('vandal',),
'vandalen': ('vandal',),
'vandalene': ('vandal',),
'vandaler': ('vandal',),
'vandalisme': ('vandalisme',),
'vandalismen': ('vandalisme',),
'vandalismene': ('vandalisme',),
'vandalismer': ('vandalisme',),
'vandel': ('vandel',),
'vandelen': ('vandel',),
'vandlene': ('vandel',),
'vandler': ('vandel',),
'vandelsattest': ('vandelsattest',),
'vandelsattesten': ('vandelsattest',),
'vandelsattestene': ('vandelsattest',),
'vandelsattester': ('vandelsattest',),
'vandrebibliotek': ('vandrebibliotek',),
'vandrebiblioteka': ('vandrebibliotek',),
'vandrebibliotekene': ('vandrebibliotek',),
'vandrebiblioteker': ('vandrebibliotek',),
'vandrebiblioteket': ('vandrebibliotek',),
'vandreboksamling': ('vandreboksamling',),
'vandreboksamlinga': ('vandreboksamling',),
'vandreboksamlingen': ('vandreboksamling',),
'vandreboksamlingene': ('vandreboksamling',),
'vandreboksamlinger': ('vandreboksamling',),
'vandrefalk': ('vandrefalk',),
'vandrefalken': ('vandrefalk',),
'vandrefalkene': ('vandrefalk',),
'vandrefalker': ('vandrefalk',),
'vandrefigur': ('vandrefigur',),
'vandrefiguren': ('vandrefigur',),
'vandrefigurene': ('vandrefigur',),
'vandrefigurer': ('vandrefigur',),
'vandrefolk': ('vandrefolk',),
'vandrefolka': ('vandrefolk',),
'vandrefolkene': ('vandrefolk',),
'vandrefolket': ('vandrefolk',),
'vandrehistoria': ('vandrehistorie',),
'vandrehistorie': ('vandrehistorie',),
'vandrehistorien': ('vandrehistorie',),
'vandrehistoriene': ('vandrehistorie',),
'vandrehistorier': ('vandrehistorie',),
'vandremandag': ('vandremandag',),
'vandremandagen': ('vandremandag',),
'vandremandagene': ('vandremandag',),
'vandremandager': ('vandremandag',),
'vandremotiv': ('vandremotiv',),
'vandremotiva': ('vandremotiv',),
'vandremotivene': ('vandremotiv',),
'vandremotiver': ('vandremotiv',),
'vandremotivet': ('vandremotiv',),
'vandrenyra': ('vandrenyre',),
'vandrenyre': ('vandrenyre',),
'vandrenyren': ('vandrenyre',),
'vandrenyrene': ('vandrenyre',),
'vandrenyrer': ('vandrenyre',),
'vandrenyret': ('vandrenyre',),
'vandrepokal': ('vandrepokal',),
'vandrepokalen': ('vandrepokal',),
'vandrepokalene': ('vandrepokal',),
'vandrepokaler': ('vandrepokal',),
'vandrer': ('vandrer',),
'vandrere': ('vandrer',),
'vandreren': ('vandrer',),
'vandrerer': ('vandrer',),
'vandrerne': ('vandrer',),
'vandrerfolk': ('vandrerfolk',),
'vandrerfolka': ('vandrerfolk',),
'vandrerfolkene': ('vandrerfolk',),
'vandrerfolket': ('vandrerfolk',),
'vandrerheim': ('vandrerheim',),
'vandrerheimen': ('vandrerheim',),
'vandrerheimene': ('vandrerheim',),
'vandrerheimer': ('vandrerheim',),
'vandrerhjem': ('vandrerhjem',),
'vandrerhjemma': ('vandrerhjem',),
'vandrerhjemmene': ('vandrerhjem',),
'vandrerhjemmet': ('vandrerhjem',),
'vandresagn': ('vandresagn',),
'vandresagna': ('vandresagn',),
'vandresagnene': ('vandresagn',),
'vandresagnet': ('vandresagn',),
'vandreskjold': ('vandreskjold',),
'vandreskjolda': ('vandreskjold',),
'vandreskjoldene': ('vandreskjold',),
'vandreskjoldet': ('vandreskjold',),
'vandrestjerna': ('vandrestjerne',),
'vandrestjerne': ('vandrestjerne',),
'vandrestjernen': ('vandrestjerne',),
'vandrestjernene': ('vandrestjerne',),
'vandrestjerner': ('vandrestjerne',),
'vandreutstilling': ('vandreutstilling',),
'vandreutstillinga': ('vandreutstilling',),
'vandreutstillingen': ('vandreutstilling',),
'vandreutstillingene': ('vandreutstilling',),
'vandreutstillinger': ('vandreutstilling',),
'vandring': ('vandring',),
'vandringa': ('vandring',),
'vandringen': ('vandring',),
'vandringene': ('vandring',),
'vandringer': ('vandring',),
'vandringsfot': ('vandringsfot',),
'vandringsmann': ('vandringsmann',),
'vandringsmannen': ('vandringsmann',),
'vandringsmenn': ('vandringsmann',),
'vandringsmennene': ('vandringsmann',),
'vandringsstav': ('vandringsstav',),
'vandringsstaven': ('vandringsstav',),
'vandringsstavene': ('vandringsstav',),
'vandringsstaver': ('vandringsstav',),
'vandskjær': ('vandskjær',),
'vandskjæra': ('vandskjær',),
'vandskjæren': ('vandskjær',),
'vandskjærene': ('vandskjær',),
'vandskjærer': ('vandskjær',),
'vandskjæret': ('vandskjær',),
'vane': ('vane',),
'vanen': ('vane',),
'vanene': ('vane',),
'vaner': ('vane',),
'vanedranker': ('vanedranker',),
'vanedrankere': ('vanedranker',),
'vanedrankeren': ('vanedranker',),
'vanedrankerer': ('vanedranker',),
'vanedrankerne': ('vanedranker',),
'vanedyr': ('vanedyr',),
'vanedyra': ('vanedyr',),
'vanedyrene': ('vanedyr',),
'vanedyret': ('vanedyr',),
'vaneforbryter': ('vaneforbryter',),
'vaneforbrytere': ('vaneforbryter',),
'vaneforbryteren': ('vaneforbryter',),
'vaneforbryterer': ('vaneforbryter',),
'vaneforbryterne': ('vaneforbryter',),
'vaneforestilling': ('vaneforestilling',),
'vaneforestillinga': ('vaneforestilling',),
'vaneforestillingen': ('vaneforestilling',),
'vaneforestillingene': ('vaneforestilling',),
'vaneforestillinger': ('vaneforestilling',),
'vanegjengeri': ('vanegjengeri',),
'vanegjengeria': ('vanegjengeri',),
'vanegjengeriene': ('vanegjengeri',),
'vanegjengeriet': ('vanegjengeri',),
'vanekristendom': ('vanekristendom',),
'vanekristendommen': ('vanekristendom',),
'vanekristendommene': ('vanekristendom',),
'vanekristendommer': ('vanekristendom',),
'vanemenneska': ('vanemenneske',),
'vanemenneske': ('vanemenneske',),
'vanemenneskene': ('vanemenneske',),
'vanemennesker': ('vanemenneske',),
'vanemennesket': ('vanemenneske',),
'vanerøyker': ('vanerøyker',),
'vanerøykere': ('vanerøyker',),
'vanerøykeren': ('vanerøyker',),
'vanerøykerer': ('vanerøyker',),
'vanerøykerne': ('vanerøyker',),
'vanesak': ('vanesak',),
'vanesaka': ('vanesak',),
'vanesaken': ('vanesak',),
'vanesakene': ('vanesak',),
'vanesaker': ('vanesak',),
'vanetenking': ('vanetenking',),
'vanetenkinga': ('vanetenking',),
'vanetenkingen': ('vanetenking',),
'vanetenkingene': ('vanetenking',),
'vanetenkinger': ('vanetenking',),
'vanetenkning': ('vanetenkning',),
'vanetenkninga': ('vanetenkning',),
'vanetenkningen': ('vanetenkning',),
'vanetenkningene': ('vanetenkning',),
'vanetenkninger': ('vanetenkning',),
'vanføreheim': ('vanføreheim',),
'vanføreheimen': ('vanføreheim',),
'vanføreheimene': ('vanføreheim',),
'vanføreheimer': ('vanføreheim',),
'vanførehjem': ('vanførehjem',),
'vanførehjemma': ('vanførehjem',),
'vanførehjemmene': ('vanførehjem',),
'vanførehjemmet': ('vanførehjem',),
'vanførelag': ('vanførelag',),
'vanførelaga': ('vanførelag',),
'vanførelagene': ('vanførelag',),
'vanførelaget': ('vanførelag',),
'vanføresak': ('vanføresak',),
'vanføresaka': ('vanføresak',),
'vanføresaken': ('vanføresak',),
'vanføresakene': ('vanføresak',),
'vanføresaker': ('vanføresak',),
'vang': ('vang',),
'vangen': ('vang',),
'vangene': ('vang',),
'vanger': ('vang',),
'vange': ('vange',),
'vangen': ('vange',),
'vangene': ('vange',),
'vanger': ('vange',),
'vanheder': ('vanheder',),
'vanhedere': ('vanheder',),
'vanhederen': ('vanheder',),
'vanhederer': ('vanheder',),
'vanhederne': ('vanheder',),
'vanhedre': ('vanheder',),
'vanhedrene': ('vanheder',),
'vanhedrer': ('vanheder',),
'vanheimel': ('vanheimel',),
'vanheimelen': ('vanheimel',),
'vanheimlene': ('vanheimel',),
'vanheimler': ('vanheimel',),
'vanhell': ('vanhell',),
'vanhella': ('vanhell',),
'vanhellene': ('vanhell',),
'vanhellet': ('vanhell',),
'vanhelsa': ('vanhelse',),
'vanhelse': ('vanhelse',),
'vanhelsen': ('vanhelse',),
'vanhelsene': ('vanhelse',),
'vanhelser': ('vanhelse',),
'vanhevd': ('vanhevd',),
'vanhevden': ('vanhevd',),
'vanhevdene': ('vanhevd',),
'vanhevder': ('vanhevd',),
'vanhjemlene': ('vanhjemmel',),
'vanhjemler': ('vanhjemmel',),
'vanhjemmel': ('vanhjemmel',),
'vanhjemmelen': ('vanhjemmel',),
'vanilje': ('vanilje',),
'vaniljen': ('vanilje',),
'vaniljene': ('vanilje',),
'vaniljer': ('vanilje',),
'vaniljefyll': ('vaniljefyll',),
'vaniljefylla': ('vaniljefyll',),
'vaniljefyllen': ('vaniljefyll',),
'vaniljefyllene': ('vaniljefyll',),
'vaniljefyller': ('vaniljefyll',),
'vaniljefyllet': ('vaniljefyll',),
'vaniljeis': ('vaniljeis',),
'vaniljeisen': ('vaniljeis',),
'vaniljeisene': ('vaniljeis',),
'vaniljeiser': ('vaniljeis',),
'vaniljeplanta': ('vaniljeplante',),
'vaniljeplante': ('vaniljeplante',),
'vaniljeplanten': ('vaniljeplante',),
'vaniljeplantene': ('vaniljeplante',),
'vaniljeplanter': ('vaniljeplante',),
'vaniljerot': ('vaniljerot',),
'vaniljerota': ('vaniljerot',),
'vaniljeroten': ('vaniljerot',),
'vaniljerøttene': ('vaniljerot',),
'vaniljerøtter': ('vaniljerot',),
'vaniljesaus': ('vaniljesaus',),
'vaniljesausen': ('vaniljesaus',),
'vaniljesausene': ('vaniljesaus',),
'vaniljesauser': ('vaniljesaus',),
'vaniljestang': ('vaniljestang',),
'vaniljestanga': ('vaniljestang',),
'vaniljestangen': ('vaniljestang',),
'vaniljestengene': ('vaniljestang',),
'vaniljestenger': ('vaniljestang',),
'vaniljesukker': ('vaniljesukker',),
'vaniljesukkera': ('vaniljesukker',),
'vaniljesukkere': ('vaniljesukker',),
'vaniljesukkerene': ('vaniljesukker',),
'vaniljesukkeret': ('vaniljesukker',),
'vaniljesukkerne': ('vaniljesukker',),
'vanillin': ('vanillin',),
'vanillina': ('vanillin',),
'vanillinene': ('vanillin',),
'vanillinet': ('vanillin',),
'vankant': ('vankant',),
'vankanten': ('vankant',),
'vankantene': ('vankant',),
'vankanter': ('vankant',),
'vankundighet': ('vankundighet',),
'vankundigheta': ('vankundighet',),
'vankundigheten': ('vankundighet',),
'vankundighetene': ('vankundighet',),
'vankundigheter': ('vankundighet',),
'vankunna': ('vankunne',),
'vankunne': ('vankunne',),
'vankunnen': ('vankunne',),
'vankunnene': ('vankunne',),
'vankunner': ('vankunne',),
'vanlagnad': ('vanlagnad',),
'vanlagnaden': ('vanlagnad',),
'vanlagnadene': ('vanlagnad',),
'vanlagnader': ('vanlagnad',),
'vanmakt': ('vanmakt',),
'vanmakta': ('vanmakt',),
'vanmakten': ('vanmakt',),
'vanmaktene': ('vanmakt',),
'vanmakter': ('vanmakt',),
'vann': ('vann',),
'vanna': ('vann',),
'vannene': ('vann',),
'vannet': ('vann',),
'vann-nymfa': ('vann-nymfe',),
'vann-nymfe': ('vann-nymfe',),
'vann-nymfen': ('vann-nymfe',),
'vann-nymfene': ('vann-nymfe',),
'vann-nymfer': ('vann-nymfe',),
'vannavgift': ('vannavgift',),
'vannavgifta': ('vannavgift',),
'vannavgiften': ('vannavgift',),
'vannavgiftene': ('vannavgift',),
'vannavgifter': ('vannavgift',),
'vannbad': ('vannbad',),
'vannbada': ('vannbad',),
'vannbadene': ('vannbad',),
'vannbadet': ('vannbad',),
'vannbakkels': ('vannbakkels',),
'vannbakkelsen': ('vannbakkels',),
'vannbakkelsene': ('vannbakkels',),
'vannbakkelser': ('vannbakkels',),
'vannbakkelse': ('vannbakkelse',),
'vannbakkelsen': ('vannbakkelse',),
'vannbakkelsene': ('vannbakkelse',),
'vannbakkelser': ('vannbakkelse',),
'vannbasseng': ('vannbasseng',),
'vannbassenga': ('vannbasseng',),
'vannbassengene': ('vannbasseng',),
'vannbassenger': ('vannbasseng',),
'vannbassenget': ('vannbasseng',),
'vannbeis': ('vannbeis',),
'vannbeisen': ('vannbeis',),
'vannbeisene': ('vannbeis',),
'vannbeiser': ('vannbeis',),
'vannblemma': ('vannblemme',),
'vannblemme': ('vannblemme',),
'vannblemmen': ('vannblemme',),
'vannblemmene': ('vannblemme',),
'vannblemmer': ('vannblemme',),
'vannblæra': ('vannblære',),
'vannblære': ('vannblære',),
'vannblæren': ('vannblære',),
'vannblærene': ('vannblære',),
'vannblærer': ('vannblære',),
'vannbobla': ('vannboble',),
'vannboble': ('vannboble',),
'vannboblen': ('vannboble',),
'vannboblene': ('vannboble',),
'vannbobler': ('vannboble',),
'vannbord': ('vannbord',),
'vannborda': ('vannbord',),
'vannbordene': ('vannbord',),
'vannborder': ('vannbord',),
'vannbordet': ('vannbord',),
'vannbregna': ('vannbregne',),
'vannbregne': ('vannbregne',),
'vannbregnen': ('vannbregne',),
'vannbregnene': ('vannbregne',),
'vannbregner': ('vannbregne',),
'vannbruk': ('vannbruk',),
'vannbruka': ('vannbruk',),
'vannbrukene': ('vannbruk',),
'vannbruket': ('vannbruk',),
'vannbygging': ('vannbygging',),
'vannbygginga': ('vannbygging',),
'vannbyggingen': ('vannbygging',),
'vannbyggingene': ('vannbygging',),
'vannbygginger': ('vannbygging',),
'vannbygningskunst': ('vannbygningskunst',),
'vannbygningskunsten': ('vannbygningskunst',),
'vannbygningskunstene': ('vannbygningskunst',),
'vannbygningskunster': ('vannbygningskunst',),
'vannbygningsteknikk': ('vannbygningsteknikk',),
'vannbygningsteknikken': ('vannbygningsteknikk',),
'vannbygningsteknikkene': ('vannbygningsteknikk',),
'vannbygningsteknikker': ('vannbygningsteknikk',),
'vannbøffel': ('vannbøffel',),
'vannbøffelen': ('vannbøffel',),
'vannbøflene': ('vannbøffel',),
'vannbøfler': ('vannbøffel',),
'vanndam': ('vanndam',),
'vanndammen': ('vanndam',),
'vanndammene': ('vanndam',),
'vanndammer': ('vanndam',),
'vanndamp': ('vanndamp',),
'vanndampen': ('vanndamp',),
'vanndampene': ('vanndamp',),
'vanndamper': ('vanndamp',),
'vanndråpe': ('vanndråpe',),
'vanndråpen': ('vanndråpe',),
'vanndråpene': ('vanndråpe',),
'vanndråper': ('vanndråpe',),
'vanndyrking': ('vanndyrking',),
'vanndyrkinga': ('vanndyrking',),
'vanndyrkingen': ('vanndyrking',),
'vanndyrkingene': ('vanndyrking',),
'vanndyrkinger': ('vanndyrking',),
'vannfall': ('vannfall',),
'vannfalla': ('vannfall',),
'vannfallene': ('vannfall',),
'vannfallet': ('vannfall',),
'vannfarge': ('vannfarge',),
'vannfargen': ('vannfarge',),
'vannfargene': ('vannfarge',),
'vannfarger': ('vannfarge',),
'vannfiltrering': ('vannfiltrering',),
'vannfiltreringa': ('vannfiltrering',),
'vannfiltreringen': ('vannfiltrering',),
'vannfiltreringene': ('vannfiltrering',),
'vannfiltreringer': ('vannfiltrering',),
'vannflaska': ('vannflaske',),
'vannflaske': ('vannflaske',),
'vannflasken': ('vannflaske',),
'vannflaskene': ('vannflaske',),
'vannflasker': ('vannflaske',),
'vannflata': ('vannflate',),
'vannflate': ('vannflate',),
'vannflaten': ('vannflate',),
'vannflatene': ('vannflate',),
'vannflater': ('vannflate',),
'vannflom': ('vannflom',),
'vannflommen': ('vannflom',),
'vannflommene': ('vannflom',),
'vannflommer': ('vannflom',),
'vannforbruk': ('vannforbruk',),
'vannforbruka': ('vannforbruk',),
'vannforbrukene': ('vannforbruk',),
'vannforbruket': ('vannforbruk',),
'vannfordamper': ('vannfordamper',),
'vannfordampere': ('vannfordamper',),
'vannfordamperen': ('vannfordamper',),
'vannfordamperer': ('vannfordamper',),
'vannfordamperne': ('vannfordamper',),
'vannforsyning': ('vannforsyning',),
'vannforsyninga': ('vannforsyning',),
'vannforsyningen': ('vannforsyning',),
'vannforsyningene': ('vannforsyning',),
'vannforsyninger': ('vannforsyning',),
'vannforurensing': ('vannforurensing',),
'vannforurensinga': ('vannforurensing',),
'vannforurensingen': ('vannforurensing',),
'vannforurensingene': ('vannforurensing',),
'vannforurensinger': ('vannforurensing',),
'vannforurensning': ('vannforurensning',),
'vannforurensninga': ('vannforurensning',),
'vannforurensningen': ('vannforurensning',),
'vannforurensningene': ('vannforurensning',),
'vannforurensninger': ('vannforurensning',),
'vannfugl': ('vannfugl',),
'vannfuglen': ('vannfugl',),
'vannfuglene': ('vannfugl',),
'vannfugler': ('vannfugl',),
'vannføring': ('vannføring',),
'vannføringa': ('vannføring',),
'vannføringen': ('vannføring',),
'vannføringene': ('vannføring',),
'vannføringer': ('vannføring',),
'vanngang': ('vanngang',),
'vanngangen': ('vanngang',),
'vanngangene': ('vanngang',),
'vannganger': ('vanngang',),
'vanngass': ('vanngass',),
'vanngassen': ('vanngass',),
'vanngassene': ('vanngass',),
'vanngasser': ('vanngass',),
'vannglas': ('vannglas',),
'vannglasa': ('vannglas',),
'vannglasene': ('vannglas',),
'vannglaset': ('vannglas',),
'vannglass': ('vannglass',),
'vannglassa': ('vannglass',),
'vannglassene': ('vannglass',),
'vannglasset': ('vannglass',),
'vanngrav': ('vanngrav',),
'vanngrava': ('vanngrav',),
'vanngraven': ('vanngrav',),
'vanngravene': ('vanngrav',),
'vanngraver': ('vanngrav',),
'vanngrøft': ('vanngrøft',),
'vanngrøfta': ('vanngrøft',),
'vanngrøften': ('vanngrøft',),
'vanngrøftene': ('vanngrøft',),
'vanngrøfter': ('vanngrøft',),
'vannhinna': ('vannhinne',),
'vannhinne': ('vannhinne',),
'vannhinnen': ('vannhinne',),
'vannhinnene': ('vannhinne',),
'vannhinner': ('vannhinne',),
'vannhjul': ('vannhjul',),
'vannhjula': ('vannhjul',),
'vannhjulene': ('vannhjul',),
'vannhjulet': ('vannhjul',),
'vanning': ('vanning',),
'vanninga': ('vanning',),
'vanningen': ('vanning',),
'vanningene': ('vanning',),
'vanninger': ('vanning',),
'vanningsanlegg': ('vanningsanlegg',),
'vanningsanlegga': ('vanningsanlegg',),
'vanningsanleggene': ('vanningsanlegg',),
'vanningsanlegget': ('vanningsanlegg',),
'vannkanal': ('vannkanal',),
'vannkanalen': ('vannkanal',),
'vannkanalene': ('vannkanal',),
'vannkanaler': ('vannkanal',),
'vannkanon': ('vannkanon',),
'vannkanonen': ('vannkanon',),
'vannkanonene': ('vannkanon',),
'vannkanoner': ('vannkanon',),
'vannkant': ('vannkant',),
'vannkanten': ('vannkant',),
'vannkantene': ('vannkant',),
'vannkanter': ('vannkant',),
'vannkikkert': ('vannkikkert',),
'vannkikkerten': ('vannkikkert',),
'vannkikkertene': ('vannkikkert',),
'vannkikkerter': ('vannkikkert',),
'vannkjøler': ('vannkjøler',),
'vannkjølere': ('vannkjøler',),
'vannkjøleren': ('vannkjøler',),
'vannkjølerer': ('vannkjøler',),
'vannkjølerne': ('vannkjøler',),
'vannklosett': ('vannklosett',),
'vannklosetta': ('vannklosett',),
'vannklosettene': ('vannklosett',),
'vannklosetter': ('vannklosett',),
'vannklosettet': ('vannklosett',),
'vannkoppene': ('vannkopper',),
'vannkopper': ('vannkopper',),
'vannkraft': ('vannkraft',),
'vannkrafta': ('vannkraft',),
'vannkraften': ('vannkraft',),
'vannkreftene': ('vannkraft',),
'vannkrefter': ('vannkraft',),
'vannkraftmaskin': ('vannkraftmaskin',),
'vannkraftmaskina': ('vannkraftmaskin',),
'vannkraftmaskinen': ('vannkraftmaskin',),
'vannkraftmaskinene': ('vannkraftmaskin',),
'vannkraftmaskiner': ('vannkraftmaskin',),
'vannkraftverk': ('vannkraftverk',),
'vannkraftverka': ('vannkraftverk',),
'vannkraftverkene': ('vannkraftverk',),
'vannkraftverker': ('vannkraftverk',),
'vannkraftverket': ('vannkraftverk',),
'vannkran': ('vannkran',),
'vannkrana': ('vannkran',),
'vannkranen': ('vannkran',),
'vannkranene': ('vannkran',),
'vannkraner': ('vannkran',),
'vannkringla': ('vannkringle',),
'vannkringle': ('vannkringle',),
'vannkringlen': ('vannkringle',),
'vannkringlene': ('vannkringle',),
'vannkringler': ('vannkringle',),
'vannkultur': ('vannkultur',),
'vannkulturen': ('vannkultur',),
'vannkulturene': ('vannkultur',),
'vannkulturer': ('vannkultur',),
'vannkunst': ('vannkunst',),
'vannkunsten': ('vannkunst',),
'vannkunstene': ('vannkunst',),
'vannkunster': ('vannkunst',),
'vannkur': ('vannkur',),
'vannkuren': ('vannkur',),
'vannkurene': ('vannkur',),
'vannkurer': ('vannkur',),
'vannlating': ('vannlating',),
'vannlatinga': ('vannlating',),
'vannlatingen': ('vannlating',),
'vannlatingene': ('vannlating',),
'vannlatinger': ('vannlating',),
'vannledning': ('vannledning',),
'vannledninga': ('vannledning',),
'vannledningen': ('vannledning',),
'vannledningene': ('vannledning',),
'vannledninger': ('vannledning',),
'vannlilja': ('vannlilje',),
'vannlilje': ('vannlilje',),
'vannliljen': ('vannlilje',),
'vannliljene': ('vannlilje',),
'vannliljer': ('vannlilje',),
'vannlinja': ('vannlinje',),
'vannlinje': ('vannlinje',),
'vannlinjen': ('vannlinje',),
'vannlinjene': ('vannlinje',),
'vannlinjer': ('vannlinje',),
'vannloppa': ('vannloppe',),
'vannloppe': ('vannloppe',),
'vannloppen': ('vannloppe',),
'vannloppene': ('vannloppe',),
'vannlopper': ('vannloppe',),
'vannlås': ('vannlås',),
'vannlåsa': ('vannlås',),
'vannlåsen': ('vannlås',),
'vannlåsene': ('vannlås',),
'vannlåser': ('vannlås',),
'vannlåset': ('vannlås',),
'vannløper': ('vannløper',),
'vannløpere': ('vannløper',),
'vannløperen': ('vannløper',),
'vannløperer': ('vannløper',),
'vannløperne': ('vannløper',),
'vannløsning': ('vannløsning',),
'vannløsninga': ('vannløsning',),
'vannløsningen': ('vannløsning',),
'vannløsningene': ('vannløsning',),
'vannløsninger': ('vannløsning',),
'vannmann': ('vannmann',),
'vannmannen': ('vannmann',),
'vannmenn': ('vannmann',),
'vannmennene': ('vannmann',),
'vannmasse': ('vannmasse',),
'vannmassen': ('vannmasse',),
'vannmassene': ('vannmasse',),
'vannmasser': ('vannmasse',),
'vannmelon': ('vannmelon',),
'vannmelonen': ('vannmelon',),
'vannmelonene': ('vannmelon',),
'vannmeloner': ('vannmelon',),
'vannmerka': ('vannmerke',),
'vannmerke': ('vannmerke',),
'vannmerkene': ('vannmerke',),
'vannmerker': ('vannmerke',),
'vannmerket': ('vannmerke',),
'vannmåler': ('vannmåler',),
'vannmålere': ('vannmåler',),
'vannmåleren': ('vannmåler',),
'vannmålerer': ('vannmåler',),
'vannmålerne': ('vannmåler',),
'vannomslag': ('vannomslag',),
'vannomslaga': ('vannomslag',),
'vannomslagene': ('vannomslag',),
'vannomslaget': ('vannomslag',),
'vannorgel': ('vannorgel',),
'vannorgelet': ('vannorgel',),
'vannorgla': ('vannorgel',),
'vannorglene': ('vannorgel',),
'vannorgler': ('vannorgel',),
'vannorglet': ('vannorgel',),
'vannpepper': ('vannpepper',),
'vannpeppere': ('vannpepper',),
'vannpepperen': ('vannpepper',),
'vannpepperer': ('vannpepper',),
'vannpepperne': ('vannpepper',),
'vannpeprene': ('vannpepper',),
'vannpeprer': ('vannpepper',),
'vannpipa': ('vannpipe',),
'vannpipe': ('vannpipe',),
'vannpipen': ('vannpipe',),
'vannpipene': ('vannpipe',),
'vannpiper': ('vannpipe',),
'vannpistol': ('vannpistol',),
'vannpistolen': ('vannpistol',),
'vannpistolene': ('vannpistol',),
'vannpistoler': ('vannpistol',),
'vannplanta': ('vannplante',),
'vannplante': ('vannplante',),
'vannplanten': ('vannplante',),
'vannplantene': ('vannplante',),
'vannplanter': ('vannplante',),
'vannpolo': ('vannpolo',),
'vannpoloen': ('vannpolo',),
'vannpoloene': ('vannpolo',),
'vannpoloer': ('vannpolo',),
'vannpost': ('vannpost',),
'vannposten': ('vannpost',),
'vannpostene': ('vannpost',),
'vannposter': ('vannpost',),
'vannprøva': ('vannprøve',),
'vannprøve': ('vannprøve',),
'vannprøven': ('vannprøve',),
'vannprøvene': ('vannprøve',),
'vannprøver': ('vannprøve',),
'vannpumpa': ('vannpumpe',),
'vannpumpe': ('vannpumpe',),
'vannpumpen': ('vannpumpe',),
'vannpumpene': ('vannpumpe',),
'vannpumper': ('vannpumpe',),
'vannrenna': ('vannrenne',),
'vannrenne': ('vannrenne',),
'vannrennen': ('vannrenne',),
'vannrennene': ('vannrenne',),
'vannrenner': ('vannrenne',),
'vannrensing': ('vannrensing',),
'vannrensinga': ('vannrensing',),
'vannrensingen': ('vannrensing',),
'vannrensingene': ('vannrensing',),
'vannrensinger': ('vannrensing',),
'vannrett': ('vannrett',),
'vannretten': ('vannrett',),
'vannrettene': ('vannrett',),
'vannretter': ('vannrett',),
'vannrotta': ('vannrotte',),
'vannrotte': ('vannrotte',),
'vannrotten': ('vannrotte',),
'vannrottene': ('vannrotte',),
'vannrotter': ('vannrotte',),
'vannrør': ('vannrør',),
'vannrøra': ('vannrør',),
'vannrørene': ('vannrør',),
'vannrøret': ('vannrør',),
'vannsag': ('vannsag',),
'vannsaga': ('vannsag',),
'vannsagen': ('vannsag',),
'vannsagene': ('vannsag',),
'vannsager': ('vannsag',),
'vannsamling': ('vannsamling',),
'vannsamlinga': ('vannsamling',),
'vannsamlingen': ('vannsamling',),
'vannsamlingene': ('vannsamling',),
'vannsamlinger': ('vannsamling',),
'vannseng': ('vannseng',),
'vannsenga': ('vannseng',),
'vannsengen': ('vannseng',),
'vannsengene': ('vannseng',),
'vannsenger': ('vannseng',),
'vannsig': ('vannsig',),
'vannsiga': ('vannsig',),
'vannsigene': ('vannsig',),
'vannsiget': ('vannsig',),
'vannskade': ('vannskade',),
'vannskaden': ('vannskade',),
'vannskadene': ('vannskade',),
'vannskader': ('vannskade',),
'vannskadesalg': ('vannskadesalg',),
'vannskadesalga': ('vannskadesalg',),
'vannskadesalgene': ('vannskadesalg',),
'vannskadesalget': ('vannskadesalg',),
'vannskilla': ('vannskille',),
'vannskille': ('vannskille',),
'vannskillene': ('vannskille',),
'vannskiller': ('vannskille',),
'vannskillet': ('vannskille',),
'vannskisport': ('vannskisport',),
'vannskisporten': ('vannskisport',),
'vannskisportene': ('vannskisport',),
'vannskisporter': ('vannskisport',),
'vannskorpa': ('vannskorpe',),
'vannskorpe': ('vannskorpe',),
'vannskorpen': ('vannskorpe',),
'vannskorpene': ('vannskorpe',),
'vannskorper': ('vannskorpe',),
'vannskrekk': ('vannskrekk',),
'vannskrekken': ('vannskrekk',),
'vannskrekkene': ('vannskrekk',),
'vannskrekker': ('vannskrekk',),
'vannslange': ('vannslange',),
'vannslangen': ('vannslange',),
'vannslangene': ('vannslange',),
'vannslanger': ('vannslange',),
'vannsmak': ('vannsmak',),
'vannsmaken': ('vannsmak',),
'vannsmakene': ('vannsmak',),
'vannsmaker': ('vannsmak',),
'vannspeil': ('vannspeil',),
'vannspeila': ('vannspeil',),
'vannspeilene': ('vannspeil',),
'vannspeilet': ('vannspeil',),
'vannspissmus': ('vannspissmus',),
'vannspissmusa': ('vannspissmus',),
'vannspissmusen': ('vannspissmus',),
'vannspissmusene': ('vannspissmus',),
'vannsport': ('vannsport',),
'vannsporten': ('vannsport',),
'vannsportene': ('vannsport',),
'vannsporter': ('vannsport',),
'vannspreder': ('vannspreder',),
'vannspredere': ('vannspreder',),
'vannsprederen': ('vannspreder',),
'vannsprederer': ('vannspreder',),
'vannsprederne': ('vannspreder',),
'vannspreier': ('vannspreier',),
'vannspreiere': ('vannspreier',),
'vannspreieren': ('vannspreier',),
'vannspreierer': ('vannspreier',),
'vannspreierne': ('vannspreier',),
'vannstand': ('vannstand',),
'vannstanden': ('vannstand',),
'vannstandene': ('vannstand',),
'vannstander': ('vannstand',),
'vannstoff': ('vannstoff',),
'vannstoffa': ('vannstoff',),
'vannstoffene': ('vannstoff',),
'vannstoffer': ('vannstoff',),
'vannstoffet': ('vannstoff',),
'vannstoffperoksid': ('vannstoffperoksid',),
'vannstoffperoksida': ('vannstoffperoksid',),
'vannstoffperoksidene': ('vannstoffperoksid',),
'vannstoffperoksider': ('vannstoffperoksid',),
'vannstoffperoksidet': ('vannstoffperoksid',),
'vanntank': ('vanntank',),
'vanntanken': ('vanntank',),
'vanntankene': ('vanntank',),
'vanntanker': ('vanntank',),
'vanntro': ('vanntro',),
'vanntroa': ('vanntro',),
'vanntroen': ('vanntro',),
'vanntroene': ('vanntro',),
'vanntroer': ('vanntro',),
'vanntrykk': ('vanntrykk',),
'vanntrykka': ('vanntrykk',),
'vanntrykkene': ('vanntrykk',),
'vanntrykket': ('vanntrykk',),
'vanntunnel': ('vanntunnel',),
'vanntunnelen': ('vanntunnel',),
'vanntunnelene': ('vanntunnel',),
'vanntunneler': ('vanntunnel',),
'vannturbin': ('vannturbin',),
'vannturbinen': ('vannturbin',),
'vannturbinene': ('vannturbin',),
'vannturbiner': ('vannturbin',),
'vanntårn': ('vanntårn',),
'vanntårna': ('vanntårn',),
'vanntårnene': ('vanntårn',),
'vanntårnet': ('vanntårn',),
'vannvarmer': ('vannvarmer',),
'vannvarmere': ('vannvarmer',),
'vannvarmeren': ('vannvarmer',),
'vannvarmerer': ('vannvarmer',),
'vannvarmerne': ('vannvarmer',),
'vannveg': ('vannveg',),
'vannvegen': ('vannveg',),
'vannvegene': ('vannveg',),
'vannveger': ('vannveg',),
'vannvei': ('vannvei',),
'vannveien': ('vannvei',),
'vannveiene': ('vannvei',),
'vannveier': ('vannvei',),
'vannverk': ('vannverk',),
'vannverka': ('vannverk',),
'vannverkene': ('vannverk',),
'vannverker': ('vannverk',),
'vannverket': ('vannverk',),
'vannvogn': ('vannvogn',),
'vannvogna': ('vannvogn',),
'vannvognen': ('vannvogn',),
'vannvognene': ('vannvogn',),
'vannvogner': ('vannvogn',),
'vannymfa': ('vannymfe',),
'vannymfe': ('vannymfe',),
'vannymfen': ('vannymfe',),
'vannymfene': ('vannymfe',),
'vannymfer': ('vannymfe',),
'vannåra': ('vannåre',),
'vannåre': ('vannåre',),
'vannåren': ('vannåre',),
'vannårene': ('vannåre',),
'vannårer': ('vannåre',),
'vannøsa': ('vannøse',),
'vannøse': ('vannøse',),
'vannøsen': ('vannøse',),
'vannøsene': ('vannøse',),
'vannøser': ('vannøse',),
'vanry': ('vanry',),
'vanrya': ('vanry',),
'vanryene': ('vanry',),
'vanryet': ('vanry',),
'vanrøkt': ('vanrøkt',),
'vanrøkta': ('vanrøkt',),
'vanrøkten': ('vanrøkt',),
'vanrøktene': ('vanrøkt',),
'vanrøkter': ('vanrøkt',),
'vanskapning': ('vanskapning',),
'vanskapningen': ('vanskapning',),
'vanskapningene': ('vanskapning',),
'vanskapninger': ('vanskapning',),
'vanske': ('vanske',),
'vansken': ('vanske',),
'vanskene': ('vanske',),
'vansker': ('vanske',),
'vanskegrad': ('vanskegrad',),
'vanskegraden': ('vanskegrad',),
'vanskegradene': ('vanskegrad',),
'vanskegrader': ('vanskegrad',),
'vanskelighet': ('vanskelighet',),
'vanskeligheta': ('vanskelighet',),
'vanskeligheten': ('vanskelighet',),
'vanskelighetene': ('vanskelighet',),
'vanskeligheter': ('vanskelighet',),
'vanskelighetsgrad': ('vanskelighetsgrad',),
'vanskelighetsgraden': ('vanskelighetsgrad',),
'vanskelighetsgradene': ('vanskelighetsgrad',),
'vanskelighetsgrader': ('vanskelighetsgrad',),
'vanskjebne': ('vanskjebne',),
'vanskjebnen': ('vanskjebne',),
'vanskjebnene': ('vanskjebne',),
'vanskjebner': ('vanskjebne',),
'vanstell': ('vanstell',),
'vanstella': ('vanstell',),
'vanstellene': ('vanstell',),
'vanstellet': ('vanstell',),
'vanstyra': ('vanstyre',),
'vanstyre': ('vanstyre',),
'vanstyrene': ('vanstyre',),
'vanstyrer': ('vanstyre',),
'vanstyret': ('vanstyre',),
'vant': ('vant',),
'vanta': ('vant',),
'vantene': ('vant',),
'vantet': ('vant',),
'vantakk': ('vantakk',),
'vantakka': ('vantakk',),
'vantakken': ('vantakk',),
'vantakkene': ('vantakk',),
'vantakker': ('vantakk',),
'vante': ('vante',),
'vanten': ('vante',),
'vantene': ('vante',),
'vanter': ('vante',),
'vantrivsel': ('vantrivsel',),
'vantrivselen': ('vantrivsel',),
'vantrivslene': ('vantrivsel',),
'vantrivsler': ('vantrivsel',),
'vantro': ('vantro',),
'vantroa': ('vantro',),
'vantroen': ('vantro',),
'vantroene': ('vantro',),
'vantroer': ('vantro',),
'vantru': ('vantru',),
'vantrua': ('vantru',),
'vantruen': ('vantru',),
'vantruene': ('vantru',),
'vantruer': ('vantru',),
'vanuatuer': ('vanuatuer',),
'vanuatuere': ('vanuatuer',),
'vanuatueren': ('vanuatuer',),
'vanuatuerer': ('vanuatuer',),
'vanuatuerne': ('vanuatuer',),
'vanvare': ('vanvare',),
'vanvett': ('vanvett',),
'vanvetta': ('vanvett',),
'vanvettene': ('vanvett',),
'vanvettet': ('vanvett',),
'vanvidd': ('vanvidd',),
'vanvidda': ('vanvidd',),
'vanviddene': ('vanvidd',),
'vanviddet': ('vanvidd',),
'vanvørding': ('vanvørding',),
'vanvørdingen': ('vanvørding',),
'vanvørdingene': ('vanvørding',),
'vanvørdinger': ('vanvørding',),
'vanvørdnad': ('vanvørdnad',),
'vanvørdnaden': ('vanvørdnad',),
'vanvørdnadene': ('vanvørdnad',),
'vanvørdnader': ('vanvørdnad',),
'vanvøring': ('vanvøring',),
'vanvøringen': ('vanvøring',),
'vanvøringene': ('vanvøring',),
'vanvøringer': ('vanvøring',),
'vanvørnad': ('vanvørnad',),
'vanvørnaden': ('vanvørnad',),
'vanvørnadene': ('vanvørnad',),
'vanvørnader': ('vanvørnad',),
'vanæra': ('vanære',),
'vanære': ('vanære',),
'vanæren': ('vanære',),
'vanærene': ('vanære',),
'vanærer': ('vanære',),
'var': ('var',),
'varen': ('var',),
'varene': ('var',),
'varer': ('var',),
'var': ('var',),
'vara': ('var',),
'varene': ('var',),
'varet': ('var',),
'varafond': ('varafond',),
'varafonda': ('varafond',),
'varafondene': ('varafond',),
'varafondet': ('varafond',),
'varaformann': ('varaformann',),
'varaformannen': ('varaformann',),
'varaformenn': ('varaformann',),
'varaformennene': ('varaformann',),
'varakvinna': ('varakvinne',),
'varakvinne': ('varakvinne',),
'varakvinnen': ('varakvinne',),
'varakvinnene': ('varakvinne',),
'varakvinner': ('varakvinne',),
'varamann': ('varamann',),
'varamannen': ('varamann',),
'varamenn': ('varamann',),
'varamennene': ('varamann',),
'varaordfører': ('varaordfører',),
'varaordførere': ('varaordfører',),
'varaordføreren': ('varaordfører',),
'varaordførerer': ('varaordfører',),
'varaordførerne': ('varaordfører',),
'varaperson': ('varaperson',),
'varapersonen': ('varaperson',),
'varapersonene': ('varaperson',),
'varapersoner': ('varaperson',),
'vararepresentant': ('vararepresentant',),
'vararepresentanten': ('vararepresentant',),
'vararepresentantene': ('vararepresentant',),
'vararepresentanter': ('vararepresentant',),
'varastyra': ('varastyre',),
'varastyre': ('varastyre',),
'varastyrene': ('varastyre',),
'varastyrer': ('varastyre',),
'varastyret': ('varastyre',),
'varde': ('varde',),
'varden': ('varde',),
'vardene': ('varde',),
'varder': ('varde',),
'vardøger': ('vardøger',),
'vardøgeret': ('vardøger',),
'vardøgra': ('vardøger',),
'vardøgre': ('vardøger',),
'vardøgrene': ('vardøger',),
'vardøgrer': ('vardøger',),
'vardøgret': ('vardøger',),
'vare': ('vare',),
'vara': ('vare',),
'vare': ('vare',),
'varen': ('vare',),
'varene': ('vare',),
'varer': ('vare',),
'varebil': ('varebil',),
'varebilen': ('varebil',),
'varebilene': ('varebil',),
'varebiler': ('varebil',),
'varebind': ('varebind',),
'varebinda': ('varebind',),
'varebindene': ('varebind',),
'varebindet': ('varebind',),
'varebytta': ('varebytte',),
'varebytte': ('varebytte',),
'varebyttene': ('varebytte',),
'varebytter': ('varebytte',),
'varebyttet': ('varebytte',),
'varebørs': ('varebørs',),
'varebørsen': ('varebørs',),
'varebørsene': ('varebørs',),
'varebørser': ('varebørs',),
'varedeklarasjon': ('varedeklarasjon',),
'varedeklarasjonen': ('varedeklarasjon',),
'varedeklarasjonene': ('varedeklarasjon',),
'varedeklarasjoner': ('varedeklarasjon',),
'varedrosja': ('varedrosje',),
'varedrosje': ('varedrosje',),
'varedrosjen': ('varedrosje',),
'varedrosjene': ('varedrosje',),
'varedrosjer': ('varedrosje',),
'varefakta': ('varefakta',),
'varefaktaen': ('varefakta',),
'varefaktaene': ('varefakta',),
'varefaktaer': ('varefakta',),
'varehandel': ('varehandel',),
'varehandelen': ('varehandel',),
'varehandlene': ('varehandel',),
'varehandler': ('varehandel',),
'vareheis': ('vareheis',),
'vareheisen': ('vareheis',),
'vareheisene': ('vareheis',),
'vareheiser': ('vareheis',),
'varehus': ('varehus',),
'varehusa': ('varehus',),
'varehusene': ('varehus',),
'varehuset': ('varehus',),
'varekatalog': ('varekatalog',),
'varekatalogen': ('varekatalog',),
'varekatalogene': ('varekatalog',),
'varekataloger': ('varekatalog',),
'varekreditt': ('varekreditt',),
'varekreditten': ('varekreditt',),
'varekredittene': ('varekreditt',),
'varekreditter': ('varekreditt',),
'varekunnskap': ('varekunnskap',),
'varekunnskapen': ('varekunnskap',),
'varekunnskapene': ('varekunnskap',),
'varekunnskaper': ('varekunnskap',),
'varelager': ('varelager',),
'varelageret': ('varelager',),
'varelagra': ('varelager',),
'varelagre': ('varelager',),
'varelagrene': ('varelager',),
'varelista': ('vareliste',),
'vareliste': ('vareliste',),
'varelisten': ('vareliste',),
'varelistene': ('vareliste',),
'varelister': ('vareliste',),
'varemagasin': ('varemagasin',),
'varemagasina': ('varemagasin',),
'varemagasinene': ('varemagasin',),
'varemagasiner': ('varemagasin',),
'varemagasinet': ('varemagasin',),
'varemangel': ('varemangel',),
'varemangelen': ('varemangel',),
'varemanglene': ('varemangel',),
'varemangler': ('varemangel',),
'varemarked': ('varemarked',),
'varemarkeda': ('varemarked',),
'varemarkedene': ('varemarked',),
'varemarkeder': ('varemarked',),
'varemarkedet': ('varemarked',),
'varemarknad': ('varemarknad',),
'varemarknaden': ('varemarknad',),
'varemarknadene': ('varemarknad',),
'varemarknader': ('varemarknad',),
'varemerka': ('varemerke',),
'varemerke': ('varemerke',),
'varemerkene': ('varemerke',),
'varemerker': ('varemerke',),
'varemerket': ('varemerke',),
'varemessa': ('varemesse',),
'varemesse': ('varemesse',),
'varemessen': ('varemesse',),
'varemessene': ('varemesse',),
'varemesser': ('varemesse',),
'vareomsetning': ('vareomsetning',),
'vareomsetninga': ('vareomsetning',),
'vareomsetningen': ('vareomsetning',),
'vareomsetningene': ('vareomsetning',),
'vareomsetninger': ('vareomsetning',),
'vareopptelling': ('vareopptelling',),
'vareopptellinga': ('vareopptelling',),
'vareopptellingen': ('vareopptelling',),
'vareopptellingene': ('vareopptelling',),
'vareopptellinger': ('vareopptelling',),
'vareprøva': ('vareprøve',),
'vareprøve': ('vareprøve',),
'vareprøven': ('vareprøve',),
'vareprøvene': ('vareprøve',),
'vareprøver': ('vareprøve',),
'varesykkel': ('varesykkel',),
'varesykkelen': ('varesykkel',),
'varesyklene': ('varesykkel',),
'varesykler': ('varesykkel',),
'varetaxi': ('varetaxi',),
'varetaxien': ('varetaxi',),
'varetaxiene': ('varetaxi',),
'varetaxier': ('varetaxi',),
'varetekt': ('varetekt',),
'varetekta': ('varetekt',),
'varetekten': ('varetekt',),
'varetektene': ('varetekt',),
'varetekter': ('varetekt',),
'varetektsarrest': ('varetektsarrest',),
'varetektsarresten': ('varetektsarrest',),
'varetektsarrestene': ('varetektsarrest',),
'varetektsarrester': ('varetektsarrest',),
'varetektsfange': ('varetektsfange',),
'varetektsfangen': ('varetektsfange',),
'varetektsfangene': ('varetektsfange',),
'varetektsfanger': ('varetektsfange',),
'varetektsfengsel': ('varetektsfengsel',),
'varetektsfengselet': ('varetektsfengsel',),
'varetektsfengsla': ('varetektsfengsel',),
'varetektsfengslene': ('varetektsfengsel',),
'varetektsfengsler': ('varetektsfengsel',),
'varetektsfengslet': ('varetektsfengsel',),
'varetransport': ('varetransport',),
'varetransporten': ('varetransport',),
'varetransportene': ('varetransport',),
'varetransporter': ('varetransport',),
'varetrekk': ('varetrekk',),
'varetrekka': ('varetrekk',),
'varetrekkene': ('varetrekk',),
'varetrekket': ('varetrekk',),
'vareutstilling': ('vareutstilling',),
'vareutstillinga': ('vareutstilling',),
'vareutstillingen': ('vareutstilling',),
'vareutstillingene': ('vareutstilling',),
'vareutstillinger': ('vareutstilling',),
'varevogn': ('varevogn',),
'varevogna': ('varevogn',),
'varevognen': ('varevogn',),
'varevognene': ('varevogn',),
'varevogner': ('varevogn',),
'varg': ('varg',),
'vargen': ('varg',),
'vargene': ('varg',),
'varger': ('varg',),
'vargehi': ('vargehi',),
'vargehia': ('vargehi',),
'vargehiene': ('vargehi',),
'vargehiet': ('vargehi',),
'vargehyl': ('vargehyl',),
'vargehyla': ('vargehyl',),
'vargehylene': ('vargehyl',),
'vargehylet': ('vargehyl',),
'varghi': ('varghi',),
'varghia': ('varghi',),
'varghiene': ('varghi',),
'varghiet': ('varghi',),
'varghyl': ('varghyl',),
'varghyla': ('varghyl',),
'varghylene': ('varghyl',),
'varghylet': ('varghyl',),
'vargskinn': ('vargskinn',),
'vargskinna': ('vargskinn',),
'vargskinnene': ('vargskinn',),
'vargskinnet': ('vargskinn',),
'vargtid': ('vargtid',),
'vargtida': ('vargtid',),
'vargtiden': ('vargtid',),
'vargtidene': ('vargtid',),
'vargtider': ('vargtid',),
'vargtik': ('vargtik',),
'vargtika': ('vargtik',),
'vargtiken': ('vargtik',),
'vargtikene': ('vargtik',),
'vargtiker': ('vargtik',),
'varia': ('varia',),
'variabel': ('variabel',),
'variabelen': ('variabel',),
'variablene': ('variabel',),
'variabler': ('variabel',),
'variabilitet': ('variabilitet',),
'variabiliteten': ('variabilitet',),
'variabilitetene': ('variabilitet',),
'variabiliteter': ('variabilitet',),
'varians': ('varians',),
'variansen': ('varians',),
'variansene': ('varians',),
'varianser': ('varians',),
'variant': ('variant',),
'varianten': ('variant',),
'variantene': ('variant',),
'varianter': ('variant',),
'variantapparat': ('variantapparat',),
'variantapparata': ('variantapparat',),
'variantapparatene': ('variantapparat',),
'variantapparater': ('variantapparat',),
'variantapparatet': ('variantapparat',),
'variasjon': ('variasjon',),
'variasjonen': ('variasjon',),
'variasjonene': ('variasjon',),
'variasjoner': ('variasjon',),
'variasjonsbredde': ('variasjonsbredde',),
'variasjonsbredden': ('variasjonsbredde',),
'variasjonsbreddene': ('variasjonsbredde',),
'variasjonsbredder': ('variasjonsbredde',),
'variasjonsbreidd': ('variasjonsbreidd',),
'variasjonsbreidda': ('variasjonsbreidd',),
'variasjonsbreidden': ('variasjonsbreidd',),
'variasjonsbreiddene': ('variasjonsbreidd',),
'variasjonsbreidder': ('variasjonsbreidd',),
'variasjonsevna': ('variasjonsevne',),
'variasjonsevne': ('variasjonsevne',),
'variasjonsevnen': ('variasjonsevne',),
'variasjonsevnene': ('variasjonsevne',),
'variasjonsevner': ('variasjonsevne',),
'variasjonsrikdom': ('variasjonsrikdom',),
'variasjonsrikdommen': ('variasjonsrikdom',),
'variasjonsrikdommene': ('variasjonsrikdom',),
'variasjonsrikdommer': ('variasjonsrikdom',),
'varieteen': ('varieté',),
'varieteene': ('varieté',),
'varieteer': ('varieté',),
'varieté': ('varieté',),
'varietéen': ('varieté',),
'varietéene': ('varieté',),
'varietéer': ('varieté',),
'varietésanger': ('varietésanger',),
'varietésangere': ('varietésanger',),
'varietésangeren': ('varietésanger',),
'varietésangerer': ('varietésanger',),
'varietésangerne': ('varietésanger',),
'varietéstjerna': ('varietéstjerne',),
'varietéstjerne': ('varietéstjerne',),
'varietéstjernen': ('varietéstjerne',),
'varietéstjernene': ('varietéstjerne',),
'varietéstjerner': ('varietéstjerne',),
'varietet': ('varietet',),
'varieteten': ('varietet',),
'varietetene': ('varietet',),
'varieteter': ('varietet',),
'varighet': ('varighet',),
'varigheta': ('varighet',),
'varigheten': ('varighet',),
'varighetene': ('varighet',),
'varigheter': ('varighet',),
'varmblodshest': ('varmblodshest',),
'varmblodshesten': ('varmblodshest',),
'varmblodshestene': ('varmblodshest',),
'varmblodshester': ('varmblodshest',),
'varme': ('varme',),
'varmen': ('varme',),
'varmene': ('varme',),
'varmer': ('varme',),
'varmeapparat': ('varmeapparat',),
'varmeapparata': ('varmeapparat',),
'varmeapparatene': ('varmeapparat',),
'varmeapparater': ('varmeapparat',),
'varmeapparatet': ('varmeapparat',),
'varmebehandling': ('varmebehandling',),
'varmebehandlinga': ('varmebehandling',),
'varmebehandlingen': ('varmebehandling',),
'varmebehandlingene': ('varmebehandling',),
'varmebehandlinger': ('varmebehandling',),
'varmebelta': ('varmebelte',),
'varmebelte': ('varmebelte',),
'varmebeltene': ('varmebelte',),
'varmebelter': ('varmebelte',),
'varmebeltet': ('varmebelte',),
'varmebilda': ('varmebilde',),
'varmebilde': ('varmebilde',),
'varmebildene': ('varmebilde',),
'varmebilder': ('varmebilde',),
'varmebildet': ('varmebilde',),
'varmebildekamera': ('varmebildekamera',),
'varmebildekameraene': ('varmebildekamera',),
'varmebildekameraer': ('varmebildekamera',),
'varmebildekameraet': ('varmebildekamera',),
'varmebord': ('varmebord',),
'varmeborda': ('varmebord',),
'varmebordene': ('varmebord',),
'varmeborder': ('varmebord',),
'varmebordet': ('varmebord',),
'varmebølga': ('varmebølge',),
'varmebølge': ('varmebølge',),
'varmebølgen': ('varmebølge',),
'varmebølgene': ('varmebølge',),
'varmebølger': ('varmebølge',),
'varmebølgja': ('varmebølgje',),
'varmebølgje': ('varmebølgje',),
'varmebølgjen': ('varmebølgje',),
'varmebølgjene': ('varmebølgje',),
'varmebølgjer': ('varmebølgje',),
'varmedis': ('varmedis',),
'varmedisen': ('varmedis',),
'varmedisene': ('varmedis',),
'varmediser': ('varmedis',),
'varmeelement': ('varmeelement',),
'varmeelementa': ('varmeelement',),
'varmeelementene': ('varmeelement',),
'varmeelementer': ('varmeelement',),
'varmeelementet': ('varmeelement',),
'varmeenhet': ('varmeenhet',),
'varmeenheta': ('varmeenhet',),
'varmeenheten': ('varmeenhet',),
'varmeenhetene': ('varmeenhet',),
'varmeenheter': ('varmeenhet',),
'varmeflaska': ('varmeflaske',),
'varmeflaske': ('varmeflaske',),
'varmeflasken': ('varmeflaske',),
'varmeflaskene': ('varmeflaske',),
'varmeflasker': ('varmeflaske',),
'varmegjennomgangskoeffisient': ('varmegjennomgangskoeffisient',),
'varmegjennomgangskoeffisienten': ('varmegjennomgangskoeffisient',),
'varmegjennomgangskoeffisientene': ('varmegjennomgangskoeffisient',),
'varmegjennomgangskoeffisienter': ('varmegjennomgangskoeffisient',),
'varmegjennomgangstal': ('varmegjennomgangstal',),
'varmegjennomgangstala': ('varmegjennomgangstal',),
'varmegjennomgangstalene': ('varmegjennomgangstal',),
'varmegjennomgangstalet': ('varmegjennomgangstal',),
'varmegjennomgangstall': ('varmegjennomgangstall',),
'varmegjennomgangstalla': ('varmegjennomgangstall',),
'varmegjennomgangstallene': ('varmegjennomgangstall',),
'varmegjennomgangstallet': ('varmegjennomgangstall',),
'varmegjenvinner': ('varmegjenvinner',),
'varmegjenvinnere': ('varmegjenvinner',),
'varmegjenvinneren': ('varmegjenvinner',),
'varmegjenvinnerer': ('varmegjenvinner',),
'varmegjenvinnerne': ('varmegjenvinner',),
'varmegrad': ('varmegrad',),
'varmegraden': ('varmegrad',),
'varmegradene': ('varmegrad',),
'varmegrader': ('varmegrad',),
'varmeisolasjon': ('varmeisolasjon',),
'varmeisolasjonen': ('varmeisolasjon',),
'varmeisolasjonene': ('varmeisolasjon',),
'varmeisolasjoner': ('varmeisolasjon',),
'varmekabel': ('varmekabel',),
'varmekabelen': ('varmekabel',),
'varmekablene': ('varmekabel',),
'varmekabler': ('varmekabel',),
'varmekapasitet': ('varmekapasitet',),
'varmekapasiteten': ('varmekapasitet',),
'varmekapasitetene': ('varmekapasitet',),
'varmekapasiteter': ('varmekapasitet',),
'varmekilde': ('varmekilde',),
'varmekilden': ('varmekilde',),
'varmekildene': ('varmekilde',),
'varmekilder': ('varmekilde',),
'varmekjelda': ('varmekjelde',),
'varmekjelde': ('varmekjelde',),
'varmekjelden': ('varmekjelde',),
'varmekjeldene': ('varmekjelde',),
'varmekjelder': ('varmekjelde',),
'varmekraft': ('varmekraft',),
'varmekrafta': ('varmekraft',),
'varmekraften': ('varmekraft',),
'varmekreftene': ('varmekraft',),
'varmekrefter': ('varmekraft',),
'varmekraftmaskin': ('varmekraftmaskin',),
'varmekraftmaskina': ('varmekraftmaskin',),
'varmekraftmaskinen': ('varmekraftmaskin',),
'varmekraftmaskinene': ('varmekraftmaskin',),
'varmekraftmaskiner': ('varmekraftmaskin',),
'varmekraftverk': ('varmekraftverk',),
'varmekraftverka': ('varmekraftverk',),
'varmekraftverkene': ('varmekraftverk',),
'varmekraftverker': ('varmekraftverk',),
'varmekraftverket': ('varmekraftverk',),
'varmeleder': ('varmeleder',),
'varmeledere': ('varmeleder',),
'varmelederen': ('varmeleder',),
'varmelederer': ('varmeleder',),
'varmelederne': ('varmeleder',),
'varmelist': ('varmelist',),
'varmelista': ('varmelist',),
'varmelisten': ('varmelist',),
'varmelistene': ('varmelist',),
'varmelister': ('varmelist',),
'varmelæra': ('varmelære',),
'varmelære': ('varmelære',),
'varmelæren': ('varmelære',),
'varmelærene': ('varmelære',),
'varmelærer': ('varmelære',),
'varmemengd': ('varmemengd',),
'varmemengda': ('varmemengd',),
'varmemengden': ('varmemengd',),
'varmemengdene': ('varmemengd',),
'varmemengder': ('varmemengd',),
'varmemengde': ('varmemengde',),
'varmemengden': ('varmemengde',),
'varmemengdene': ('varmemengde',),
'varmemengder': ('varmemengde',),
'varmemåler': ('varmemåler',),
'varmemålere': ('varmemåler',),
'varmemåleren': ('varmemåler',),
'varmemålerer': ('varmemåler',),
'varmemålerne': ('varmemåler',),
'varmeomn': ('varmeomn',),
'varmeomnen': ('varmeomn',),
'varmeomnene': ('varmeomn',),
'varmeomner': ('varmeomn',),
'varmeovn': ('varmeovn',),
'varmeovnen': ('varmeovn',),
'varmeovnene': ('varmeovn',),
'varmeovner': ('varmeovn',),
'varmepose': ('varmepose',),
'varmeposen': ('varmepose',),
'varmeposene': ('varmepose',),
'varmeposer': ('varmepose',),
'varmepunkt': ('varmepunkt',),
'varmepunkta': ('varmepunkt',),
'varmepunktene': ('varmepunkt',),
'varmepunkter': ('varmepunkt',),
'varmepunktet': ('varmepunkt',),
'varmeputa': ('varmepute',),
'varmepute': ('varmepute',),
'varmeputen': ('varmepute',),
'varmeputene': ('varmepute',),
'varmeputer': ('varmepute',),
'varmer': ('varmer',),
'varmere': ('varmer',),
'varmeren': ('varmer',),
'varmerer': ('varmer',),
'varmerne': ('varmer',),
'varmeregulator': ('varmeregulator',),
'varmeregulatoren': ('varmeregulator',),
'varmeregulatorene': ('varmeregulator',),
'varmeregulatorer': ('varmeregulator',),
'varmeregulering': ('varmeregulering',),
'varmereguleringa': ('varmeregulering',),
'varmereguleringen': ('varmeregulering',),
'varmereguleringene': ('varmeregulering',),
'varmereguleringer': ('varmeregulering',),
'varmesans': ('varmesans',),
'varmesansen': ('varmesans',),
'varmesansene': ('varmesans',),
'varmesanser': ('varmesans',),
'varmeskap': ('varmeskap',),
'varmeskapa': ('varmeskap',),
'varmeskapene': ('varmeskap',),
'varmeskapet': ('varmeskap',),
'varmeskjold': ('varmeskjold',),
'varmeskjolda': ('varmeskjold',),
'varmeskjoldene': ('varmeskjold',),
'varmeskjoldet': ('varmeskjold',),
'varmestråle': ('varmestråle',),
'varmestrålen': ('varmestråle',),
'varmestrålene': ('varmestråle',),
'varmestråler': ('varmestråle',),
'varmestua': ('varmestue',),
'varmestue': ('varmestue',),
'varmestuen': ('varmestue',),
'varmestuene': ('varmestue',),
'varmestuer': ('varmestue',),
'varmetap': ('varmetap',),
'varmetapa': ('varmetap',),
'varmetapene': ('varmetap',),
'varmetapet': ('varmetap',),
'varmeutvikling': ('varmeutvikling',),
'varmeutviklinga': ('varmeutvikling',),
'varmeutviklingen': ('varmeutvikling',),
'varmeutviklingene': ('varmeutvikling',),
'varmeutviklinger': ('varmeutvikling',),
'varmeveksler': ('varmeveksler',),
'varmevekslere': ('varmeveksler',),
'varmeveksleren': ('varmeveksler',),
'varmevekslerer': ('varmeveksler',),
'varmevekslerne': ('varmeveksler',),
'varmfront': ('varmfront',),
'varmfronten': ('varmfront',),
'varmfrontene': ('varmfront',),
'varmfronter': ('varmfront',),
'varmgang': ('varmgang',),
'varmgangen': ('varmgang',),
'varmgangene': ('varmgang',),
'varmganger': ('varmgang',),
'varmjomfru': ('varmjomfru',),
'varmjomfrua': ('varmjomfru',),
'varmjomfruen': ('varmjomfru',),
'varmjomfruene': ('varmjomfru',),
'varmjomfruer': ('varmjomfru',),
'varmluft': ('varmluft',),
'varmlufta': ('varmluft',),
'varmluften': ('varmluft',),
'varmluftene': ('varmluft',),
'varmlufter': ('varmluft',),
'varmluftsanlegg': ('varmluftsanlegg',),
'varmluftsanlegga': ('varmluftsanlegg',),
'varmluftsanleggene': ('varmluftsanlegg',),
'varmluftsanlegget': ('varmluftsanlegg',),
'varmluftsmaskin': ('varmluftsmaskin',),
'varmluftsmaskina': ('varmluftsmaskin',),
'varmluftsmaskinen': ('varmluftsmaskin',),
'varmluftsmaskinene': ('varmluftsmaskin',),
'varmluftsmaskiner': ('varmluftsmaskin',),
'varmrett': ('varmrett',),
'varmretten': ('varmrett',),
'varmrettene': ('varmrett',),
'varmretter': ('varmrett',),
'varmtkjøkken': ('varmtkjøkken',),
'varmtkjøkkena': ('varmtkjøkken',),
'varmtkjøkkenene': ('varmtkjøkken',),
'varmtkjøkkener': ('varmtkjøkken',),
'varmtkjøkkenet': ('varmtkjøkken',),
'varmtvann': ('varmtvann',),
'varmtvanna': ('varmtvann',),
'varmtvannene': ('varmtvann',),
'varmtvannet': ('varmtvann',),
'varmtvannsanlegg': ('varmtvannsanlegg',),
'varmtvannsanlegga': ('varmtvannsanlegg',),
'varmtvannsanleggene': ('varmtvannsanlegg',),
'varmtvannsanlegget': ('varmtvannsanlegg',),
'varmtvannsbeholder': ('varmtvannsbeholder',),
'varmtvannsbeholdere': ('varmtvannsbeholder',),
'varmtvannsbeholderen': ('varmtvannsbeholder',),
'varmtvannsbeholderer': ('varmtvannsbeholder',),
'varmtvannsbeholderne': ('varmtvannsbeholder',),
'varmtvannsbereder': ('varmtvannsbereder',),
'varmtvannsberedere': ('varmtvannsbereder',),
'varmtvannsberederen': ('varmtvannsbereder',),
'varmtvannsberederer': ('varmtvannsbereder',),
'varmtvannsberederne': ('varmtvannsbereder',),
'varmtvannsomslag': ('varmtvannsomslag',),
'varmtvannsomslaga': ('varmtvannsomslag',),
'varmtvannsomslagene': ('varmtvannsomslag',),
'varmtvannsomslaget': ('varmtvannsomslag',),
'varmtvassanlegg': ('varmtvassanlegg',),
'varmtvassanlegga': ('varmtvassanlegg',),
'varmtvassanleggene': ('varmtvassanlegg',),
'varmtvassanlegget': ('varmtvassanlegg',),
'varmtvassbeholder': ('varmtvassbeholder',),
'varmtvassbeholdere': ('varmtvassbeholder',),
'varmtvassbeholderen': ('varmtvassbeholder',),
'varmtvassbeholderer': ('varmtvassbeholder',),
'varmtvassbeholderne': ('varmtvassbeholder',),
'varmtvassbereder': ('varmtvassbereder',),
'varmtvassberedere': ('varmtvassbereder',),
'varmtvassberederen': ('varmtvassbereder',),
'varmtvassberederer': ('varmtvassbereder',),
'varmtvassberederne': ('varmtvassbereder',),
'varmtvassomslag': ('varmtvassomslag',),
'varmtvassomslaga': ('varmtvassomslag',),
'varmtvassomslagene': ('varmtvassomslag',),
'varmtvassomslaget': ('varmtvassomslag',),
'varmtvatnanlegg': ('varmtvatnanlegg',),
'varmtvatnanlegga': ('varmtvatnanlegg',),
'varmtvatnanleggene': ('varmtvatnanlegg',),
'varmtvatnanlegget': ('varmtvatnanlegg',),
'varmvatnbeholder': ('varmvatnbeholder',),
'varmvatnbeholdere': ('varmvatnbeholder',),
'varmvatnbeholderen': ('varmvatnbeholder',),
'varmvatnbeholderer': ('varmvatnbeholder',),
'varmvatnbeholderne': ('varmvatnbeholder',),
'varmvatnbereder': ('varmvatnbereder',),
'varmvatnberedere': ('varmvatnbereder',),
'varmvatnberederen': ('varmvatnbereder',),
'varmvatnberederer': ('varmvatnbereder',),
'varmvatnberederne': ('varmvatnbereder',),
'varmvatnomslag': ('varmvatnomslag',),
'varmvatnomslaga': ('varmvatnomslag',),
'varmvatnomslagene': ('varmvatnomslag',),
'varmvatnomslaget': ('varmvatnomslag',),
'varp': ('varp',),
'varpa': ('varp',),
'varpene': ('varp',),
'varpet': ('varp',),
'varpanker': ('varpanker',),
'varpankera': ('varpanker',),
'varpankere': ('varpanker',),
'varpankeret': ('varpanker',),
'varpankra': ('varpanker',),
'varpankre': ('varpanker',),
'varpankrene': ('varpanker',),
'varpankret': ('varpanker',),
'varpebåt': ('varpebåt',),
'varpebåten': ('varpebåt',),
'varpebåtene': ('varpebåt',),
'varpebåter': ('varpebåt',),
'varpespill': ('varpespill',),
'varpespilla': ('varpespill',),
'varpespillene': ('varpespill',),
'varpespillet': ('varpespill',),
'varsel': ('varsel',),
'varselet': ('varsel',),
'varsla': ('varsel',),
'varslene': ('varsel',),
'varsler': ('varsel',),
'varslet': ('varsel',),
'varselbrev': ('varselbrev',),
'varselbreva': ('varselbrev',),
'varselbrevene': ('varselbrev',),
'varselbrever': ('varselbrev',),
'varselbrevet': ('varselbrev',),
'varselfarge': ('varselfarge',),
'varselfargen': ('varselfarge',),
'varselfargene': ('varselfarge',),
'varselfarger': ('varselfarge',),
'varselklokka': ('varselklokke',),
'varselklokke': ('varselklokke',),
'varselklokken': ('varselklokke',),
'varselklokkene': ('varselklokke',),
'varselklokker': ('varselklokke',),
'varsellys': ('varsellys',),
'varsellysa': ('varsellys',),
'varsellysene': ('varsellys',),
'varsellyset': ('varsellys',),
'varselpinne': ('varselpinne',),
'varselpinnen': ('varselpinne',),
'varselpinnene': ('varselpinne',),
'varselpinner': ('varselpinne',),
'varselrop': ('varselrop',),
'varselropa': ('varselrop',),
'varselropene': ('varselrop',),
'varselropet': ('varselrop',),
'varselsbrev': ('varselsbrev',),
'varselsbreva': ('varselsbrev',),
'varselsbrevene': ('varselsbrev',),
'varselsbrever': ('varselsbrev',),
'varselsbrevet': ('varselsbrev',),
'varselsfarge': ('varselsfarge',),
'varselsfargen': ('varselsfarge',),
'varselsfargene': ('varselsfarge',),
'varselsfarger': ('varselsfarge',),
'varselsignal': ('varselsignal',),
'varselsignala': ('varselsignal',),
'varselsignalene': ('varselsignal',),
'varselsignaler': ('varselsignal',),
'varselsignalet': ('varselsignal',),
'varselskilt': ('varselskilt',),
'varselskilta': ('varselskilt',),
'varselskiltene': ('varselskilt',),
'varselskilter': ('varselskilt',),
'varselskiltet': ('varselskilt',),
'varselsklokka': ('varselsklokke',),
'varselsklokke': ('varselsklokke',),
'varselsklokken': ('varselsklokke',),
'varselsklokkene': ('varselsklokke',),
'varselsklokker': ('varselsklokke',),
'varselskott': ('varselskott',),
'varselskotta': ('varselskott',),
'varselskottene': ('varselskott',),
'varselskottet': ('varselskott',),
'varselskudd': ('varselskudd',),
'varselskudda': ('varselskudd',),
'varselskuddene': ('varselskudd',),
'varselskuddet': ('varselskudd',),
'varselslys': ('varselslys',),
'varselslysa': ('varselslys',),
'varselslysene': ('varselslys',),
'varselslyset': ('varselslys',),
'varselspinne': ('varselspinne',),
'varselspinnen': ('varselspinne',),
'varselspinnene': ('varselspinne',),
'varselspinner': ('varselspinne',),
'varselsrop': ('varselsrop',),
'varselsropa': ('varselsrop',),
'varselsropene': ('varselsrop',),
'varselsropet': ('varselsrop',),
'varselssignal': ('varselssignal',),
'varselssignala': ('varselssignal',),
'varselssignalene': ('varselssignal',),
'varselssignaler': ('varselssignal',),
'varselssignalet': ('varselssignal',),
'varselsskilt': ('varselsskilt',),
'varselsskilta': ('varselsskilt',),
'varselsskiltene': ('varselsskilt',),
'varselsskilter': ('varselsskilt',),
'varselsskiltet': ('varselsskilt',),
'varselsskott': ('varselsskott',),
'varselsskotta': ('varselsskott',),
'varselsskottene': ('varselsskott',),
'varselsskottet': ('varselsskott',),
'varselsskudd': ('varselsskudd',),
'varselsskudda': ('varselsskudd',),
'varselsskuddene': ('varselsskudd',),
'varselsskuddet': ('varselsskudd',),
'varselstrekant': ('varselstrekant',),
'varselstrekanten': ('varselstrekant',),
'varselstrekantene': ('varselstrekant',),
'varselstrekanter': ('varselstrekant',),
'varseltrekant': ('varseltrekant',),
'varseltrekanten': ('varseltrekant',),
'varseltrekantene': ('varseltrekant',),
'varseltrekanter': ('varseltrekant',),
'varsemd': ('varsemd',),
'varsemda': ('varsemd',),
'varsemden': ('varsemd',),
'varsemdene': ('varsemd',),
'varsemder': ('varsemd',),
'varsku': ('varsku',),
'varskua': ('varsku',),
'varskuene': ('varsku',),
'varskuet': ('varsku',),
'varsler': ('varsler',),
'varslere': ('varsler',),
'varsleren': ('varsler',),
'varslerer': ('varsler',),
'varslerne': ('varsler',),
'varslingsanlegg': ('varslingsanlegg',),
'varslingsanlegga': ('varslingsanlegg',),
'varslingsanleggene': ('varslingsanlegg',),
'varslingsanlegget': ('varslingsanlegg',),
'varslingssatellitt': ('varslingssatellitt',),
'varslingssatellitten': ('varslingssatellitt',),
'varslingssatellittene': ('varslingssatellitt',),
'varslingssatellitter': ('varslingssatellitt',),
'varsomhet': ('varsomhet',),
'varsomheta': ('varsomhet',),
'varsomheten': ('varsomhet',),
'varsomhetene': ('varsomhet',),
'varsomheter': ('varsomhet',),
'vartpengene': ('vartpenger',),
'vartpenger': ('vartpenger',),
'varulv': ('varulv',),
'varulven': ('varulv',),
'varulvene': ('varulv',),
'varulver': ('varulv',),
'vas': ('vas',),
'vasa': ('vas',),
'vasene': ('vas',),
'vaset': ('vas',),
'vasall': ('vasall',),
'vasallen': ('vasall',),
'vasallene': ('vasall',),
'vasaller': ('vasall',),
'vasallstat': ('vasallstat',),
'vasallstaten': ('vasallstat',),
'vasallstatene': ('vasallstat',),
'vasallstater': ('vasallstat',),
'vase': ('vase',),
'vasen': ('vase',),
'vasene': ('vase',),
'vaser': ('vase',),
'vase': ('vase',),
'vasen': ('vase',),
'vasene': ('vase',),
'vaser': ('vase',),
'vasekopp': ('vasekopp',),
'vasekoppen': ('vasekopp',),
'vasekoppene': ('vasekopp',),
'vasekopper': ('vasekopp',),
'vaselin': ('vaselin',),
'vaselinen': ('vaselin',),
'vaselinene': ('vaselin',),
'vaseliner': ('vaselin',),
'vask': ('vask',),
'vasken': ('vask',),
'vaskene': ('vask',),
'vasker': ('vask',),
'vaskarryss': ('vaskarryss',),
'vaskarryssen': ('vaskarryss',),
'vaskarryssene': ('vaskarryss',),
'vaskarrysser': ('vaskarryss',),
'vaskebalja': ('vaskebalje',),
'vaskebalje': ('vaskebalje',),
'vaskebaljen': ('vaskebalje',),
'vaskebaljene': ('vaskebalje',),
'vaskebaljer': ('vaskebalje',),
'vaskebjørn': ('vaskebjørn',),
'vaskebjørnen': ('vaskebjørn',),
'vaskebjørnene': ('vaskebjørn',),
'vaskebjørner': ('vaskebjørn',),
'vaskebrett': ('vaskebrett',),
'vaskebretta': ('vaskebrett',),
'vaskebrettene': ('vaskebrett',),
'vaskebretter': ('vaskebrett',),
'vaskebrettet': ('vaskebrett',),
'vaskefat': ('vaskefat',),
'vaskefata': ('vaskefat',),
'vaskefatene': ('vaskefat',),
'vaskefater': ('vaskefat',),
'vaskefatet': ('vaskefat',),
'vaskehall': ('vaskehall',),
'vaskehallen': ('vaskehall',),
'vaskehallene': ('vaskehall',),
'vaskehaller': ('vaskehall',),
'vaskehjelp': ('vaskehjelp',),
'vaskehjelpa': ('vaskehjelp',),
'vaskehjelpen': ('vaskehjelp',),
'vaskehjelpene': ('vaskehjelp',),
'vaskehjelper': ('vaskehjelp',),
'vaskekjeller': ('vaskekjeller',),
'vaskekjellere': ('vaskekjeller',),
'vaskekjelleren': ('vaskekjeller',),
'vaskekjellerer': ('vaskekjeller',),
'vaskekjellerne': ('vaskekjeller',),
'vaskeklut': ('vaskeklut',),
'vaskekluten': ('vaskeklut',),
'vaskeklutene': ('vaskeklut',),
'vaskekluter': ('vaskeklut',),
'vaskekona': ('vaskekone',),
'vaskekone': ('vaskekone',),
'vaskekonen': ('vaskekone',),
'vaskekonene': ('vaskekone',),
'vaskekoner': ('vaskekone',),
'vaskekum': ('vaskekum',),
'vaskekummen': ('vaskekum',),
'vaskekummene': ('vaskekum',),
'vaskekummer': ('vaskekum',),
'vaskemaskin': ('vaskemaskin',),
'vaskemaskina': ('vaskemaskin',),
'vaskemaskinen': ('vaskemaskin',),
'vaskemaskinene': ('vaskemaskin',),
'vaskemaskiner': ('vaskemaskin',),
'vaskemiddel': ('vaskemiddel',),
'vaskemiddelet': ('vaskemiddel',),
'vaskemidla': ('vaskemiddel',),
'vaskemidlene': ('vaskemiddel',),
'vaskemidler': ('vaskemiddel',),
'vaskemidlet': ('vaskemiddel',),
'vaskepulver': ('vaskepulver',),
'vaskepulvera': ('vaskepulver',),
'vaskepulvere': ('vaskepulver',),
'vaskepulveret': ('vaskepulver',),
'vaskepulverne': ('vaskepulver',),
'vasker': ('vasker',),
'vaskere': ('vasker',),
'vaskeren': ('vasker',),
'vaskerer': ('vasker',),
'vaskerne': ('vasker',),
'vaskeri': ('vaskeri',),
'vaskeria': ('vaskeri',),
'vaskeriene': ('vaskeri',),
'vaskerier': ('vaskeri',),
'vaskeriet': ('vaskeri',),
'vaskerom': ('vaskerom',),
'vaskeromma': ('vaskerom',),
'vaskerommene': ('vaskerom',),
'vaskerommet': ('vaskerom',),
'vaskeseddel': ('vaskeseddel',),
'vaskeseddelen': ('vaskeseddel',),
'vaskesedlene': ('vaskeseddel',),
'vaskesedler': ('vaskeseddel',),
'vaskeservant': ('vaskeservant',),
'vaskeservanten': ('vaskeservant',),
'vaskeservantene': ('vaskeservant',),
'vaskeservanter': ('vaskeservant',),
'vaskesvamp': ('vaskesvamp',),
'vaskesvampen': ('vaskesvamp',),
'vaskesvampene': ('vaskesvamp',),
'vaskesvamper': ('vaskesvamp',),
'vasketromlene': ('vasketrommel',),
'vasketromler': ('vasketrommel',),
'vasketrommel': ('vasketrommel',),
'vasketrommelen': ('vasketrommel',),
'vasketøy': ('vasketøy',),
'vasketøya': ('vasketøy',),
'vasketøyene': ('vasketøy',),
'vasketøyet': ('vasketøy',),
'vaskevannsfat': ('vaskevannsfat',),
'vaskevannsfata': ('vaskevannsfat',),
'vaskevannsfatene': ('vaskevannsfat',),
'vaskevannsfater': ('vaskevannsfat',),
'vaskevannsfatet': ('vaskevannsfat',),
'vaskevassfat': ('vaskevassfat',),
'vaskevassfata': ('vaskevassfat',),
'vaskevassfatene': ('vaskevassfat',),
'vaskevassfater': ('vaskevassfat',),
'vaskevassfatet': ('vaskevassfat',),
'vasle': ('vasle',),
'vaslen': ('vasle',),
'vaslene': ('vasle',),
'vasler': ('vasle',),
'vasomotor': ('vasomotor',),
'vasomotoren': ('vasomotor',),
'vasomotorene': ('vasomotor',),
'vasomotorer': ('vasomotor',),
'vass-sag': ('vass-sag',),
'vass-saga': ('vass-sag',),
'vass-sagen': ('vass-sag',),
'vass-sagene': ('vass-sag',),
'vass-sager': ('vass-sag',),
'vass-samling': ('vass-samling',),
'vass-samlinga': ('vass-samling',),
'vass-samlingen': ('vass-samling',),
'vass-samlingene': ('vass-samling',),
'vass-samlinger': ('vass-samling',),
'vass-sele': ('vass-sele',),
'vass-selen': ('vass-sele',),
'vass-selene': ('vass-sele',),
'vass-seler': ('vass-sele',),
'vass-seng': ('vass-seng',),
'vass-senga': ('vass-seng',),
'vass-sengen': ('vass-seng',),
'vass-sengene': ('vass-seng',),
'vass-senger': ('vass-seng',),
'vass-sig': ('vass-sig',),
'vass-siga': ('vass-sig',),
'vass-sigene': ('vass-sig',),
'vass-siget': ('vass-sig',),
'vass-skade': ('vass-skade',),
'vass-skaden': ('vass-skade',),
'vass-skadene': ('vass-skade',),
'vass-skader': ('vass-skade',),
'vass-skadesalg': ('vass-skadesalg',),
'vass-skadesalga': ('vass-skadesalg',),
'vass-skadesalgene': ('vass-skadesalg',),
'vass-skadesalget': ('vass-skadesalg',),
'vass-skilla': ('vass-skille',),
'vass-skille': ('vass-skille',),
'vass-skillene': ('vass-skille',),
'vass-skiller': ('vass-skille',),
'vass-skillet': ('vass-skille',),
'vass-skisport': ('vass-skisport',),
'vass-skisporten': ('vass-skisport',),
'vass-skisportene': ('vass-skisport',),
'vass-skisporter': ('vass-skisport',),
'vass-skorpa': ('vass-skorpe',),
'vass-skorpe': ('vass-skorpe',),
'vass-skorpen': ('vass-skorpe',),
'vass-skorpene': ('vass-skorpe',),
'vass-skorper': ('vass-skorpe',),
'vass-skrekk': ('vass-skrekk',),
'vass-skrekken': ('vass-skrekk',),
'vass-skrekkene': ('vass-skrekk',),
'vass-skrekker': ('vass-skrekk',),
'vass-slange': ('vass-slange',),
'vass-slangen': ('vass-slange',),
'vass-slangene': ('vass-slange',),
'vass-slanger': ('vass-slange',),
'vass-smak': ('vass-smak',),
'vass-smaken': ('vass-smak',),
'vass-smakene': ('vass-smak',),
'vass-smaker': ('vass-smak',),
'vass-soleia': ('vass-soleie',),
'vass-soleie': ('vass-soleie',),
'vass-soleien': ('vass-soleie',),
'vass-soleiene': ('vass-soleie',),
'vass-soleier': ('vass-soleie',),
'vass-speil': ('vass-speil',),
'vass-speila': ('vass-speil',),
'vass-speilene': ('vass-speil',),
'vass-speilet': ('vass-speil',),
'vass-spissmus': ('vass-spissmus',),
'vass-spissmusa': ('vass-spissmus',),
'vass-spissmusen': ('vass-spissmus',),
'vass-spissmusene': ('vass-spissmus',),
'vass-sport': ('vass-sport',),
'vass-sporten': ('vass-sport',),
'vass-sportene': ('vass-sport',),
'vass-sporter': ('vass-sport',),
'vass-spreder': ('vass-spreder',),
'vass-spredere': ('vass-spreder',),
'vass-sprederen': ('vass-spreder',),
'vass-sprederer': ('vass-spreder',),
'vass-sprederne': ('vass-spreder',),
'vass-spreier': ('vass-spreier',),
'vass-spreiere': ('vass-spreier',),
'vass-spreieren': ('vass-spreier',),
'vass-spreierer': ('vass-spreier',),
'vass-spreierne': ('vass-spreier',),
'vass-stand': ('vass-stand',),
'vass-standen': ('vass-stand',),
'vass-standene': ('vass-stand',),
'vass-stander': ('vass-stand',),
'vass-stoff': ('vass-stoff',),
'vass-stoffa': ('vass-stoff',),
'vass-stoffene': ('vass-stoff',),
'vass-stoffer': ('vass-stoff',),
'vass-stoffet': ('vass-stoff',),
'vass-stoffperoksid': ('vass-stoffperoksid',),
'vass-stoffperoksida': ('vass-stoffperoksid',),
'vass-stoffperoksidene': ('vass-stoffperoksid',),
'vass-stoffperoksider': ('vass-stoffperoksid',),
'vass-stoffperoksidet': ('vass-stoffperoksid',),
'vassag': ('vassag',),
'vassaga': ('vassag',),
'vassagen': ('vassag',),
'vassagene': ('vassag',),
'vassager': ('vassag',),
'vassamling': ('vassamling',),
'vassamlinga': ('vassamling',),
'vassamlingen': ('vassamling',),
'vassamlingene': ('vassamling',),
'vassamlinger': ('vassamling',),
'vassarv': ('vassarv',),
'vassarven': ('vassarv',),
'vassarvene': ('vassarv',),
'vassarver': ('vassarv',),
'vassarve': ('vassarve',),
'vassarven': ('vassarve',),
'vassarvene': ('vassarve',),
'vassarver': ('vassarve',),
'vassausa': ('vassause',),
'vassause': ('vassause',),
'vassausen': ('vassause',),
'vassausene': ('vassause',),
'vassauser': ('vassause',),
'vassavgift': ('vassavgift',),
'vassavgifta': ('vassavgift',),
'vassavgiften': ('vassavgift',),
'vassavgiftene': ('vassavgift',),
'vassavgifter': ('vassavgift',),
'vassbad': ('vassbad',),
'vassbada': ('vassbad',),
'vassbadene': ('vassbad',),
'vassbadet': ('vassbad',),
'vassbakkels': ('vassbakkels',),
'vassbakkelsen': ('vassbakkels',),
'vassbakkelsene': ('vassbakkels',),
'vassbakkelser': ('vassbakkels',),
'vassbakkelse': ('vassbakkelse',),
'vassbakkelsen': ('vassbakkelse',),
'vassbakkelsene': ('vassbakkelse',),
'vassbakkelser': ('vassbakkelse',),
'vassbasseng': ('vassbasseng',),
'vassbassenga': ('vassbasseng',),
'vassbassengene': ('vassbasseng',),
'vassbassenger': ('vassbasseng',),
'vassbassenget': ('vassbasseng',),
'vassbeis': ('vassbeis',),
'vassbeisen': ('vassbeis',),
'vassbeisene': ('vassbeis',),
'vassbeiser': ('vassbeis',),
'vassblanda': ('vassblande',),
'vassblande': ('vassblande',),
'vassblanden': ('vassblande',),
'vassblandene': ('vassblande',),
'vassblander': ('vassblande',),
'vassblemma': ('vassblemme',),
'vassblemme': ('vassblemme',),
'vassblemmen': ('vassblemme',),
'vassblemmene': ('vassblemme',),
'vassblemmer': ('vassblemme',),
'vassblæra': ('vassblære',),
'vassblære': ('vassblære',),
'vassblæren': ('vassblære',),
'vassblærene': ('vassblære',),
'vassblærer': ('vassblære',),
'vassbløyta': ('vassbløyte',),
'vassbløyte': ('vassbløyte',),
'vassbløyten': ('vassbløyte',),
'vassbløytene': ('vassbløyte',),
'vassbløyter': ('vassbløyte',),
'vassbobla': ('vassboble',),
'vassboble': ('vassboble',),
'vassboblen': ('vassboble',),
'vassboblene': ('vassboble',),
'vassbobler': ('vassboble',),
'vassbord': ('vassbord',),
'vassborda': ('vassbord',),
'vassbordene': ('vassbord',),
'vassborder': ('vassbord',),
'vassbordet': ('vassbord',),
'vassbotn': ('vassbotn',),
'vassbotnen': ('vassbotn',),
'vassbotnene': ('vassbotn',),
'vassbotner': ('vassbotn',),
'vassbregna': ('vassbregne',),
'vassbregne': ('vassbregne',),
'vassbregnen': ('vassbregne',),
'vassbregnene': ('vassbregne',),
'vassbregner': ('vassbregne',),
'vassbruk': ('vassbruk',),
'vassbruka': ('vassbruk',),
'vassbrukene': ('vassbruk',),
'vassbruket': ('vassbruk',),
'vassbygging': ('vassbygging',),
'vassbygginga': ('vassbygging',),
'vassbyggingen': ('vassbygging',),
'vassbyggingene': ('vassbygging',),
'vassbygginger': ('vassbygging',),
'vassbygningskunst': ('vassbygningskunst',),
'vassbygningskunsten': ('vassbygningskunst',),
'vassbygningskunstene': ('vassbygningskunst',),
'vassbygningskunster': ('vassbygningskunst',),
'vassbygningsteknikk': ('vassbygningsteknikk',),
'vassbygningsteknikken': ('vassbygningsteknikk',),
'vassbygningsteknikkene': ('vassbygningsteknikk',),
'vassbygningsteknikker': ('vassbygningsteknikk',),
'vassbøffel': ('vassbøffel',),
'vassbøffelen': ('vassbøffel',),
'vassbøflene': ('vassbøffel',),
'vassbøfler': ('vassbøffel',),
'vassdam': ('vassdam',),
'vassdammen': ('vassdam',),
'vassdammene': ('vassdam',),
'vassdammer': ('vassdam',),
'vassdamp': ('vassdamp',),
'vassdampen': ('vassdamp',),
'vassdampene': ('vassdamp',),
'vassdamper': ('vassdamp',),
'vassdrag': ('vassdrag',),
'vassdraga': ('vassdrag',),
'vassdragene': ('vassdrag',),
'vassdraget': ('vassdrag',),
'vassdragsregulering': ('vassdragsregulering',),
'vassdragsreguleringa': ('vassdragsregulering',),
'vassdragsreguleringen': ('vassdragsregulering',),
'vassdragsreguleringene': ('vassdragsregulering',),
'vassdragsreguleringer': ('vassdragsregulering',),
'vassdragsvesen': ('vassdragsvesen',),
'vassdragsvesena': ('vassdragsvesen',),
'vassdragsvesenene': ('vassdragsvesen',),
'vassdragsvesener': ('vassdragsvesen',),
'vassdragsvesenet': ('vassdragsvesen',),
'vassdråpe': ('vassdråpe',),
'vassdråpen': ('vassdråpe',),
'vassdråpene': ('vassdråpe',),
'vassdråper': ('vassdråpe',),
'vassdyrking': ('vassdyrking',),
'vassdyrkinga': ('vassdyrking',),
'vassdyrkingen': ('vassdyrking',),
'vassdyrkingene': ('vassdyrking',),
'vassdyrkinger': ('vassdyrking',),
'vassende': ('vassende',),
'vassenden': ('vassende',),
'vassendene': ('vassende',),
'vassender': ('vassende',),
'vasseng': ('vasseng',),
'vassenga': ('vasseng',),
'vassengen': ('vasseng',),
'vassengene': ('vasseng',),
'vassenger': ('vasseng',),
'vassfall': ('vassfall',),
'vassfalla': ('vassfall',),
'vassfallene': ('vassfall',),
'vassfallet': ('vassfall',),
'vassfar': ('vassfar',),
'vassfara': ('vassfar',),
'vassfarene': ('vassfar',),
'vassfaret': ('vassfar',),
'vassfarge': ('vassfarge',),
'vassfargen': ('vassfarge',),
'vassfargene': ('vassfarge',),
'vassfarger': ('vassfarge',),
'vassfiltrering': ('vassfiltrering',),
'vassfiltreringa': ('vassfiltrering',),
'vassfiltreringen': ('vassfiltrering',),
'vassfiltreringene': ('vassfiltrering',),
'vassfiltreringer': ('vassfiltrering',),
'vassflaska': ('vassflaske',),
'vassflaske': ('vassflaske',),
'vassflasken': ('vassflaske',),
'vassflaskene': ('vassflaske',),
'vassflasker': ('vassflaske',),
'vassflata': ('vassflate',),
'vassflate': ('vassflate',),
'vassflaten': ('vassflate',),
'vassflatene': ('vassflate',),
'vassflater': ('vassflate',),
'vassflom': ('vassflom',),
'vassflommen': ('vassflom',),
'vassflommene': ('vassflom',),
'vassflommer': ('vassflom',),
'vassforbruk': ('vassforbruk',),
'vassforbruka': ('vassforbruk',),
'vassforbrukene': ('vassforbruk',),
'vassforbruket': ('vassforbruk',),
'vassfordamper': ('vassfordamper',),
'vassfordampere': ('vassfordamper',),
'vassfordamperen': ('vassfordamper',),
'vassfordamperer': ('vassfordamper',),
'vassfordamperne': ('vassfordamper',),
'vassforsyning': ('vassforsyning',),
'vassforsyninga': ('vassforsyning',),
'vassforsyningen': ('vassforsyning',),
'vassforsyningene': ('vassforsyning',),
'vassforsyninger': ('vassforsyning',),
'vassforurensing': ('vassforurensing',),
'vassforurensinga': ('vassforurensing',),
'vassforurensingen': ('vassforurensing',),
'vassforurensingene': ('vassforurensing',),
'vassforurensinger': ('vassforurensing',),
'vassforurensning': ('vassforurensning',),
'vassforurensninga': ('vassforurensning',),
'vassforurensningen': ('vassforurensning',),
'vassforurensningene': ('vassforurensning',),
'vassforurensninger': ('vassforurensning',),
'vassfugl': ('vassfugl',),
'vassfuglen': ('vassfugl',),
'vassfuglene': ('vassfugl',),
'vassfugler': ('vassfugl',),
'vassføring': ('vassføring',),
'vassføringa': ('vassføring',),
'vassføringen': ('vassføring',),
'vassføringene': ('vassføring',),
'vassføringer': ('vassføring',),
'vassgang': ('vassgang',),
'vassgangen': ('vassgang',),
'vassgangene': ('vassgang',),
'vassganger': ('vassgang',),
'vassgass': ('vassgass',),
'vassgassen': ('vassgass',),
'vassgassene': ('vassgass',),
'vassgasser': ('vassgass',),
'vassglas': ('vassglas',),
'vassglasa': ('vassglas',),
'vassglasene': ('vassglas',),
'vassglaset': ('vassglas',),
'vassglass': ('vassglass',),
'vassglassa': ('vassglass',),
'vassglassene': ('vassglass',),
'vassglasset': ('vassglass',),
'vassgras': ('vassgras',),
'vassgrasa': ('vassgras',),
'vassgrasene': ('vassgras',),
'vassgraset': ('vassgras',),
'vassgraut': ('vassgraut',),
'vassgrauten': ('vassgraut',),
'vassgrautene': ('vassgraut',),
'vassgrauter': ('vassgraut',),
'vassgrav': ('vassgrav',),
'vassgrava': ('vassgrav',),
'vassgraven': ('vassgrav',),
'vassgravene': ('vassgrav',),
'vassgraver': ('vassgrav',),
'vassgress': ('vassgress',),
'vassgressa': ('vassgress',),
'vassgressene': ('vassgress',),
'vassgresset': ('vassgress',),
'vassgro': ('vassgro',),
'vassgroen': ('vassgro',),
'vassgroene': ('vassgro',),
'vassgroer': ('vassgro',),
'vassgrøft': ('vassgrøft',),
'vassgrøfta': ('vassgrøft',),
'vassgrøften': ('vassgrøft',),
'vassgrøftene': ('vassgrøft',),
'vassgrøfter': ('vassgrøft',),
'vasshinna': ('vasshinne',),
'vasshinne': ('vasshinne',),
'vasshinnen': ('vasshinne',),
'vasshinnene': ('vasshinne',),
'vasshinner': ('vasshinne',),
'vasshjul': ('vasshjul',),
'vasshjula': ('vasshjul',),
'vasshjulene': ('vasshjul',),
'vasshjulet': ('vasshjul',),
'vassig': ('vassig',),
'vassiga': ('vassig',),
'vassigene': ('vassig',),
'vassiget': ('vassig',),
'vassis': ('vassis',),
'vassisen': ('vassis',),
'vassisene': ('vassis',),
'vassiser': ('vassis',),
'vasskade': ('vasskade',),
'vasskaden': ('vasskade',),
'vasskadene': ('vasskade',),
'vasskader': ('vasskade',),
'vasskadesalg': ('vasskadesalg',),
'vasskadesalga': ('vasskadesalg',),
'vasskadesalgene': ('vasskadesalg',),
'vasskadesalget': ('vasskadesalg',),
'vasskall': ('vasskall',),
'vasskallen': ('vasskall',),
'vasskallene': ('vasskall',),
'vasskaller': ('vasskall',),
'vasskanal': ('vasskanal',),
'vasskanalen': ('vasskanal',),
'vasskanalene': ('vasskanal',),
'vasskanaler': ('vasskanal',),
'vasskanon': ('vasskanon',),
'vasskanonen': ('vasskanon',),
'vasskanonene': ('vasskanon',),
'vasskanoner': ('vasskanon',),
'vasskant': ('vasskant',),
'vasskanten': ('vasskant',),
'vasskantene': ('vasskant',),
'vasskanter': ('vasskant',),
'vasskikkert': ('vasskikkert',),
'vasskikkerten': ('vasskikkert',),
'vasskikkertene': ('vasskikkert',),
'vasskikkerter': ('vasskikkert',),
'vasskilla': ('vasskille',),
'vasskille': ('vasskille',),
'vasskillene': ('vasskille',),
'vasskiller': ('vasskille',),
'vasskillet': ('vasskille',),
'vasskisport': ('vasskisport',),
'vasskisporten': ('vasskisport',),
'vasskisportene': ('vasskisport',),
'vasskisporter': ('vasskisport',),
'vasskjøler': ('vasskjøler',),
'vasskjølere': ('vasskjøler',),
'vasskjøleren': ('vasskjøler',),
'vasskjølerer': ('vasskjøler',),
'vasskjølerne': ('vasskjøler',),
'vassklosett': ('vassklosett',),
'vassklosetta': ('vassklosett',),
'vassklosettene': ('vassklosett',),
'vassklosetter': ('vassklosett',),
'vassklosettet': ('vassklosett',),
'vasskoppene': ('vasskopper',),
'vasskopper': ('vasskopper',),
'vasskorpa': ('vasskorpe',),
'vasskorpe': ('vasskorpe',),
'vasskorpen': ('vasskorpe',),
'vasskorpene': ('vasskorpe',),
'vasskorper': ('vasskorpe',),
'vasskraft': ('vasskraft',),
'vasskrafta': ('vasskraft',),
'vasskraften': ('vasskraft',),
'vasskreftene': ('vasskraft',),
'vasskrefter': ('vasskraft',),
'vasskraftmaskin': ('vasskraftmaskin',),
'vasskraftmaskina': ('vasskraftmaskin',),
'vasskraftmaskinen': ('vasskraftmaskin',),
'vasskraftmaskinene': ('vasskraftmaskin',),
'vasskraftmaskiner': ('vasskraftmaskin',),
'vasskraftverk': ('vasskraftverk',),
'vasskraftverka': ('vasskraftverk',),
'vasskraftverkene': ('vasskraftverk',),
'vasskraftverker': ('vasskraftverk',),
'vasskraftverket': ('vasskraftverk',),
'vasskran': ('vasskran',),
'vasskrana': ('vasskran',),
'vasskranen': ('vasskran',),
'vasskranene': ('vasskran',),
'vasskraner': ('vasskran',),
'vasskrekk': ('vasskrekk',),
'vasskrekken': ('vasskrekk',),
'vasskrekkene': ('vasskrekk',),
'vasskrekker': ('vasskrekk',),
'vasskringla': ('vasskringle',),
'vasskringle': ('vasskringle',),
'vasskringlen': ('vasskringle',),
'vasskringlene': ('vasskringle',),
'vasskringler': ('vasskringle',),
'vasskultur': ('vasskultur',),
'vasskulturen': ('vasskultur',),
'vasskulturene': ('vasskultur',),
'vasskulturer': ('vasskultur',),
'vasskunst': ('vasskunst',),
'vasskunsten': ('vasskunst',),
'vasskunstene': ('vasskunst',),
'vasskunster': ('vasskunst',),
'vasskur': ('vasskur',),
'vasskuren': ('vasskur',),
'vasskurene': ('vasskur',),
'vasskurer': ('vasskur',),
'vasslange': ('vasslange',),
'vasslangen': ('vasslange',),
'vasslangene': ('vasslange',),
'vasslanger': ('vasslange',),
'vasslating': ('vasslating',),
'vasslatinga': ('vasslating',),
'vasslatingen': ('vasslating',),
'vasslatingene': ('vasslating',),
'vasslatinger': ('vasslating',),
'vassledning': ('vassledning',),
'vassledninga': ('vassledning',),
'vassledningen': ('vassledning',),
'vassledningene': ('vassledning',),
'vassledninger': ('vassledning',),
'vasslilja': ('vasslilje',),
'vasslilje': ('vasslilje',),
'vassliljen': ('vasslilje',),
'vassliljene': ('vasslilje',),
'vassliljer': ('vasslilje',),
'vasslinja': ('vasslinje',),
'vasslinje': ('vasslinje',),
'vasslinjen': ('vasslinje',),
'vasslinjene': ('vasslinje',),
'vasslinjer': ('vasslinje',),
'vassloppa': ('vassloppe',),
'vassloppe': ('vassloppe',),
'vassloppen': ('vassloppe',),
'vassloppene': ('vassloppe',),
'vasslopper': ('vassloppe',),
'vasslås': ('vasslås',),
'vasslåsa': ('vasslås',),
'vasslåsen': ('vasslås',),
'vasslåsene': ('vasslås',),
'vasslåser': ('vasslås',),
'vasslåset': ('vasslås',),
'vassløper': ('vassløper',),
'vassløpere': ('vassløper',),
'vassløperen': ('vassløper',),
'vassløperer': ('vassløper',),
'vassløperne': ('vassløper',),
'vassløsning': ('vassløsning',),
'vassløsninga': ('vassløsning',),
'vassløsningen': ('vassløsning',),
'vassløsningene': ('vassløsning',),
'vassløsninger': ('vassløsning',),
'vassmak': ('vassmak',),
'vassmaken': ('vassmak',),
'vassmakene': ('vassmak',),
'vassmaker': ('vassmak',),
'vassmasse': ('vassmasse',),
'vassmassen': ('vassmasse',),
'vassmassene': ('vassmasse',),
'vassmasser': ('vassmasse',),
'vassmelon': ('vassmelon',),
'vassmelonen': ('vassmelon',),
'vassmelonene': ('vassmelon',),
'vassmeloner': ('vassmelon',),
'vassmerka': ('vassmerke',),
'vassmerke': ('vassmerke',),
'vassmerkene': ('vassmerke',),
'vassmerker': ('vassmerke',),
'vassmerket': ('vassmerke',),
'vassmål': ('vassmål',),
'vassmåla': ('vassmål',),
'vassmålene': ('vassmål',),
'vassmålet': ('vassmål',),
'vassmåler': ('vassmåler',),
'vassmålere': ('vassmåler',),
'vassmåleren': ('vassmåler',),
'vassmålerer': ('vassmåler',),
'vassmålerne': ('vassmåler',),
'vassnymfa': ('vassnymfe',),
'vassnymfe': ('vassnymfe',),
'vassnymfen': ('vassnymfe',),
'vassnymfene': ('vassnymfe',),
'vassnymfer': ('vassnymfe',),
'vassoleia': ('vassoleie',),
'vassoleie': ('vassoleie',),
'vassoleien': ('vassoleie',),
'vassoleiene': ('vassoleie',),
'vassoleier': ('vassoleie',),
'vassomslag': ('vassomslag',),
'vassomslaga': ('vassomslag',),
'vassomslagene': ('vassomslag',),
'vassomslaget': ('vassomslag',),
'vassorgel': ('vassorgel',),
'vassorgelet': ('vassorgel',),
'vassorgla': ('vassorgel',),
'vassorglene': ('vassorgel',),
'vassorgler': ('vassorgel',),
'vassorglet': ('vassorgel',),
'vasspeil': ('vasspeil',),
'vasspeila': ('vasspeil',),
'vasspeilene': ('vasspeil',),
'vasspeilet': ('vasspeil',),
'vasspepper': ('vasspepper',),
'vasspeppere': ('vasspepper',),
'vasspepperen': ('vasspepper',),
'vasspepperer': ('vasspepper',),
'vasspepperne': ('vasspepper',),
'vasspeprene': ('vasspepper',),
'vasspeprer': ('vasspepper',),
'vasspest': ('vasspest',),
'vasspesta': ('vasspest',),
'vasspesten': ('vasspest',),
'vasspestene': ('vasspest',),
'vasspester': ('vasspest',),
'vasspipa': ('vasspipe',),
'vasspipe': ('vasspipe',),
'vasspipen': ('vasspipe',),
'vasspipene': ('vasspipe',),
'vasspiper': ('vasspipe',),
'vasspissmus': ('vasspissmus',),
'vasspissmusa': ('vasspissmus',),
'vasspissmusen': ('vasspissmus',),
'vasspissmusene': ('vasspissmus',),
'vasspistol': ('vasspistol',),
'vasspistolen': ('vasspistol',),
'vasspistolene': ('vasspistol',),
'vasspistoler': ('vasspistol',),
'vassplanta': ('vassplante',),
'vassplante': ('vassplante',),
'vassplanten': ('vassplante',),
'vassplantene': ('vassplante',),
'vassplanter': ('vassplante',),
'vasspolo': ('vasspolo',),
'vasspoloen': ('vasspolo',),
'vasspoloene': ('vasspolo',),
'vasspoloer': ('vasspolo',),
'vassport': ('vassport',),
'vassporten': ('vassport',),
'vassportene': ('vassport',),
'vassporter': ('vassport',),
'vasspost': ('vasspost',),
'vassposten': ('vasspost',),
'vasspostene': ('vasspost',),
'vassposter': ('vasspost',),
'vasspreder': ('vasspreder',),
'vasspredere': ('vasspreder',),
'vassprederen': ('vasspreder',),
'vassprederer': ('vasspreder',),
'vassprederne': ('vasspreder',),
'vasspreier': ('vasspreier',),
'vasspreiere': ('vasspreier',),
'vasspreieren': ('vasspreier',),
'vasspreierer': ('vasspreier',),
'vasspreierne': ('vasspreier',),
'vassprøva': ('vassprøve',),
'vassprøve': ('vassprøve',),
'vassprøven': ('vassprøve',),
'vassprøvene': ('vassprøve',),
'vassprøver': ('vassprøve',),
'vasspumpa': ('vasspumpe',),
'vasspumpe': ('vasspumpe',),
'vasspumpen': ('vasspumpe',),
'vasspumpene': ('vasspumpe',),
'vasspumper': ('vasspumpe',),
'vassrenna': ('vassrenne',),
'vassrenne': ('vassrenne',),
'vassrennen': ('vassrenne',),
'vassrennene': ('vassrenne',),
'vassrenner': ('vassrenne',),
'vassrensing': ('vassrensing',),
'vassrensinga': ('vassrensing',),
'vassrensingen': ('vassrensing',),
'vassrensingene': ('vassrensing',),
'vassrensinger': ('vassrensing',),
'vassrett': ('vassrett',),
'vassretten': ('vassrett',),
'vassrettene': ('vassrett',),
'vassretter': ('vassrett',),
'vassrotta': ('vassrotte',),
'vassrotte': ('vassrotte',),
'vassrotten': ('vassrotte',),
'vassrottene': ('vassrotte',),
'vassrotter': ('vassrotte',),
'vassrør': ('vassrør',),
'vassrøra': ('vassrør',),
'vassrørene': ('vassrør',),
'vassrøret': ('vassrør',),
'vasstand': ('vasstand',),
'vasstanden': ('vasstand',),
'vasstandene': ('vasstand',),
'vasstander': ('vasstand',),
'vasstank': ('vasstank',),
'vasstanken': ('vasstank',),
'vasstankene': ('vasstank',),
'vasstanker': ('vasstank',),
'vasstoff': ('vasstoff',),
'vasstoffa': ('vasstoff',),
'vasstoffene': ('vasstoff',),
'vasstoffer': ('vasstoff',),
'vasstoffet': ('vasstoff',),
'vasstoffperoksid': ('vasstoffperoksid',),
'vasstoffperoksida': ('vasstoffperoksid',),
'vasstoffperoksidene': ('vasstoffperoksid',),
'vasstoffperoksider': ('vasstoffperoksid',),
'vasstoffperoksidet': ('vasstoffperoksid',),
'vasstro': ('vasstro',),
'vasstroa': ('vasstro',),
'vasstroen': ('vasstro',),
'vasstroene': ('vasstro',),
'vasstroer': ('vasstro',),
'vasstroll': ('vasstroll',),
'vasstrolla': ('vasstroll',),
'vasstrollene': ('vasstroll',),
'vasstrollet': ('vasstroll',),
'vasstrykk': ('vasstrykk',),
'vasstrykka': ('vasstrykk',),
'vasstrykkene': ('vasstrykk',),
'vasstrykket': ('vasstrykk',),
'vasstunnel': ('vasstunnel',),
'vasstunnelen': ('vasstunnel',),
'vasstunnelene': ('vasstunnel',),
'vasstunneler': ('vasstunnel',),
'vassturbin': ('vassturbin',),
'vassturbinen': ('vassturbin',),
'vassturbinene': ('vassturbin',),
'vassturbiner': ('vassturbin',),
'vasstårn': ('vasstårn',),
'vasstårna': ('vasstårn',),
'vasstårnene': ('vasstårn',),
'vasstårnet': ('vasstårn',),
'vassvarmer': ('vassvarmer',),
'vassvarmere': ('vassvarmer',),
'vassvarmeren': ('vassvarmer',),
'vassvarmerer': ('vassvarmer',),
'vassvarmerne': ('vassvarmer',),
'vassveg': ('vassveg',),
'vassvegen': ('vassveg',),
'vassvegene': ('vassveg',),
'vassveger': ('vassveg',),
'vassvei': ('vassvei',),
'vassveien': ('vassvei',),
'vassveiene': ('vassvei',),
'vassveier': ('vassvei',),
'vassvelling': ('vassvelling',),
'vassvellinga': ('vassvelling',),
'vassvellingen': ('vassvelling',),
'vassvellingene': ('vassvelling',),
'vassvellinger': ('vassvelling',),
'vassverk': ('vassverk',),
'vassverka': ('vassverk',),
'vassverkene': ('vassverk',),
'vassverker': ('vassverk',),
'vassverket': ('vassverk',),
'vassvetta': ('vassvette',),
'vassvette': ('vassvette',),
'vassvetten': ('vassvette',),
'vassvettene': ('vassvette',),
'vassvetter': ('vassvette',),
'vassvettet': ('vassvette',),
'vassvogn': ('vassvogn',),
'vassvogna': ('vassvogn',),
'vassvognen': ('vassvogn',),
'vassvognene': ('vassvogn',),
'vassvogner': ('vassvogn',),
'vassåra': ('vassåre',),
'vassåre': ('vassåre',),
'vassåren': ('vassåre',),
'vassårene': ('vassåre',),
'vassårer': ('vassåre',),
'vater': ('vater',),
'vateret': ('vater',),
'vatra': ('vater',),
'vatre': ('vater',),
'vatrene': ('vater',),
'vatret': ('vater',),
'vaterbord': ('vaterbord',),
'vaterborda': ('vaterbord',),
'vaterbordene': ('vaterbord',),
'vaterborder': ('vaterbord',),
'vaterbordet': ('vaterbord',),
'vaterpass': ('vaterpass',),
'vaterpassa': ('vaterpass',),
'vaterpassene': ('vaterpass',),
'vaterpasset': ('vaterpass',),
'vatersott': ('vatersott',),
'vatersotta': ('vatersott',),
'vatersotten': ('vatersott',),
'vatersottene': ('vatersott',),
'vatersotter': ('vatersott',),
'vatn': ('vatn',),
'vatna': ('vatn',),
'vatnene': ('vatn',),
'vatnet': ('vatn',),
'vatning': ('vatning',),
'vatninga': ('vatning',),
'vatningen': ('vatning',),
'vatningene': ('vatning',),
'vatninger': ('vatning',),
'vatningsanlegg': ('vatningsanlegg',),
'vatningsanlegga': ('vatningsanlegg',),
'vatningsanleggene': ('vatningsanlegg',),
'vatningsanlegget': ('vatningsanlegg',),
'vatt': ('vatt',),
'vatta': ('vatt',),
'vatten': ('vatt',),
'vattene': ('vatt',),
'vatter': ('vatt',),
'vattet': ('vatt',),
'vatt-teppa': ('vatt-teppe',),
'vatt-teppe': ('vatt-teppe',),
'vatt-teppene': ('vatt-teppe',),
'vatt-tepper': ('vatt-teppe',),
'vatt-teppet': ('vatt-teppe',),
'vattdott': ('vattdott',),
'vattdotten': ('vattdott',),
'vattdottene': ('vattdott',),
'vattdotter': ('vattdott',),
'vatteppa': ('vatteppe',),
'vatteppe': ('vatteppe',),
'vatteppene': ('vatteppe',),
'vattepper': ('vatteppe',),
'vatteppet': ('vatteppe',),
'vattering': ('vattering',),
'vatteringa': ('vattering',),
'vatteringen': ('vattering',),
'vatteringene': ('vattering',),
'vatteringer': ('vattering',),
'vattlag': ('vattlag',),
'vattlaga': ('vattlag',),
'vattlagene': ('vattlag',),
'vattlaget': ('vattlag',),
'vaudeville': ('vaudeville',),
'vaudevillen': ('vaudeville',),
'vaudevillene': ('vaudeville',),
'vaudeviller': ('vaudeville',),
've': ('ve',),
'veen': ('ve',),
'veene': ('ve',),
'veer': ('ve',),
'ved': ('ved',),
'veden': ('ved',),
'vedene': ('ved',),
'veder': ('ved',),
'veda': ('veda',),
'vedaen': ('veda',),
'vedaene': ('veda',),
'vedaer': ('veda',),
'vedbend': ('vedbend',),
'vedbenden': ('vedbend',),
'vedbendene': ('vedbend',),
'vedbender': ('vedbend',),
'vedbende': ('vedbende',),
'vedbenden': ('vedbende',),
'vedbendene': ('vedbende',),
'vedbender': ('vedbende',),
'vedbliing': ('vedbliing',),
'vedbliinga': ('vedbliing',),
'vedbliingen': ('vedbliing',),
'vedbliingene': ('vedbliing',),
'vedbliinger': ('vedbliing',),
'vedbliving': ('vedbliving',),
'vedblivinga': ('vedbliving',),
'vedblivingen': ('vedbliving',),
'vedblivingene': ('vedbliving',),
'vedblivinger': ('vedbliving',),
'vedbod': ('vedbod',),
'vedboden': ('vedbod',),
'vedbodene': ('vedbod',),
'vedboder': ('vedbod',),
'vedbu': ('vedbu',),
'vedbua': ('vedbu',),
'vedbuen': ('vedbu',),
'vedbuene': ('vedbu',),
'vedbuer': ('vedbu',),
'vedbærer': ('vedbærer',),
'vedbærere': ('vedbærer',),
'vedbæreren': ('vedbærer',),
'vedbærerer': ('vedbærer',),
'vedbærerne': ('vedbærer',),
'vedcella': ('vedcelle',),
'vedcelle': ('vedcelle',),
'vedcellen': ('vedcelle',),
'vedcellene': ('vedcelle',),
'vedceller': ('vedcelle',),
'veddeløp': ('veddeløp',),
'veddeløpa': ('veddeløp',),
'veddeløpene': ('veddeløp',),
'veddeløpet': ('veddeløp',),
'veddemål': ('veddemål',),
'veddemåla': ('veddemål',),
'veddemålene': ('veddemål',),
'veddemålet': ('veddemål',),
'vederkvegelse': ('vederkvegelse',),
'vederkvegelsen': ('vederkvegelse',),
'vederkvegelsene': ('vederkvegelse',),
'vederkvegelser': ('vederkvegelse',),
'vederlag': ('vederlag',),
'vederlaga': ('vederlag',),
'vederlagene': ('vederlag',),
'vederlaget': ('vederlag',),
'vederstyggelighet': ('vederstyggelighet',),
'vederstyggeligheta': ('vederstyggelighet',),
'vederstyggeligheten': ('vederstyggelighet',),
'vederstyggelighetene': ('vederstyggelighet',),
'vederstyggeligheter': ('vederstyggelighet',),
'vedett': ('vedett',),
'vedetten': ('vedett',),
'vedettene': ('vedett',),
'vedetter': ('vedett',),
'vedettbåt': ('vedettbåt',),
'vedettbåten': ('vedettbåt',),
'vedettbåtene': ('vedettbåt',),
'vedettbåter': ('vedettbåt',),
'vedfamn': ('vedfamn',),
'vedfamnen': ('vedfamn',),
'vedfamnene': ('vedfamn',),
'vedfamner': ('vedfamn',),
'vedfamn': ('vedfamn',),
'vedfamnen': ('vedfamn',),
'vedfamnene': ('vedfamn',),
'vedfamner': ('vedfamn',),
'vedfang': ('vedfang',),
'vedfanga': ('vedfang',),
'vedfangene': ('vedfang',),
'vedfanget': ('vedfang',),
'vedfanga': ('vedfange',),
'vedfange': ('vedfange',),
'vedfangene': ('vedfange',),
'vedfanger': ('vedfange',),
'vedfanget': ('vedfange',),
'vedfavn': ('vedfavn',),
'vedfavnen': ('vedfavn',),
'vedfavnene': ('vedfavn',),
'vedfavner': ('vedfavn',),
'vedfavn': ('vedfavn',),
'vedfavnen': ('vedfavn',),
'vedfavnene': ('vedfavn',),
'vedfavner': ('vedfavn',),
'vedfyring': ('vedfyring',),
'vedfyringa': ('vedfyring',),
'vedfyringen': ('vedfyring',),
'vedfyringene': ('vedfyring',),
'vedfyringer': ('vedfyring',),
'vedgåelse': ('vedgåelse',),
'vedgåelsen': ('vedgåelse',),
'vedgåelsene': ('vedgåelse',),
'vedgåelser': ('vedgåelse',),
'vedgåing': ('vedgåing',),
'vedgåinga': ('vedgåing',),
'vedgåingen': ('vedgåing',),
'vedgåingene': ('vedgåing',),
'vedgåinger': ('vedgåing',),
'vedheng': ('vedheng',),
'vedhenga': ('vedheng',),
'vedhengene': ('vedheng',),
'vedhenget': ('vedheng',),
'vedhogger': ('vedhogger',),
'vedhoggere': ('vedhogger',),
'vedhoggeren': ('vedhogger',),
'vedhoggerer': ('vedhogger',),
'vedhoggerne': ('vedhogger',),
'vedhogst': ('vedhogst',),
'vedhogsten': ('vedhogst',),
'vedhogstene': ('vedhogst',),
'vedhogster': ('vedhogst',),
'vedholdenhet': ('vedholdenhet',),
'vedholdenheta': ('vedholdenhet',),
'vedholdenheten': ('vedholdenhet',),
'vedholdenhetene': ('vedholdenhet',),
'vedholdenheter': ('vedholdenhet',),
'vedhugger': ('vedhugger',),
'vedhuggere': ('vedhugger',),
'vedhuggeren': ('vedhugger',),
'vedhuggerer': ('vedhugger',),
'vedhuggerne': ('vedhugger',),
'vedhugst': ('vedhugst',),
'vedhugsten': ('vedhugst',),
'vedhugstene': ('vedhugst',),
'vedhugster': ('vedhugst',),
'vedhus': ('vedhus',),
'vedhusa': ('vedhus',),
'vedhusene': ('vedhus',),
'vedhuset': ('vedhus',),
'vedkassa': ('vedkasse',),
'vedkasse': ('vedkasse',),
'vedkassen': ('vedkasse',),
'vedkassene': ('vedkasse',),
'vedkasser': ('vedkasse',),
'vedkjennelse': ('vedkjennelse',),
'vedkjennelsen': ('vedkjennelse',),
'vedkjennelsene': ('vedkjennelse',),
'vedkjennelser': ('vedkjennelse',),
'vedkomfyr': ('vedkomfyr',),
'vedkomfyren': ('vedkomfyr',),
'vedkomfyrene': ('vedkomfyr',),
'vedkomfyrer': ('vedkomfyr',),
'vedkommende': ('vedkommende',),
'vedkubbe': ('vedkubbe',),
'vedkubben': ('vedkubbe',),
'vedkubbene': ('vedkubbe',),
'vedkubber': ('vedkubbe',),
'vedlegg': ('vedlegg',),
'vedlegga': ('vedlegg',),
'vedleggene': ('vedlegg',),
'vedlegget': ('vedlegg',),
'vedlikehold': ('vedlikehold',),
'vedlikeholda': ('vedlikehold',),
'vedlikeholdene': ('vedlikehold',),
'vedlikeholdet': ('vedlikehold',),
'vedlikeholdsarbeid': ('vedlikeholdsarbeid',),
'vedlikeholdsarbeida': ('vedlikeholdsarbeid',),
'vedlikeholdsarbeidene': ('vedlikeholdsarbeid',),
'vedlikeholdsarbeider': ('vedlikeholdsarbeid',),
'vedlikeholdsarbeidet': ('vedlikeholdsarbeid',),
'vedpinn': ('vedpinn',),
'vedpinnen': ('vedpinn',),
'vedpinnene': ('vedpinn',),
'vedpinner': ('vedpinn',),
'vedpinne': ('vedpinne',),
'vedpinnen': ('vedpinne',),
'vedpinnene': ('vedpinne',),
'vedpinner': ('vedpinne',),
'vedplanta': ('vedplante',),
'vedplante': ('vedplante',),
'vedplanten': ('vedplante',),
'vedplantene': ('vedplante',),
'vedplanter': ('vedplante',),
'vedski': ('vedski',),
'vedskia': ('vedski',),
'vedskien': ('vedski',),
'vedskiene': ('vedski',),
'vedskier': ('vedski',),
'vedskia': ('vedskie',),
'vedskie': ('vedskie',),
'vedskien': ('vedskie',),
'vedskiene': ('vedskie',),
'vedskier': ('vedskie',),
'vedskjul': ('vedskjul',),
'vedskjula': ('vedskjul',),
'vedskjulene': ('vedskjul',),
'vedskjulet': ('vedskjul',),
'vedstabel': ('vedstabel',),
'vedstabelen': ('vedstabel',),
'vedstablene': ('vedstabel',),
'vedstabler': ('vedstabel',),
'vedstoff': ('vedstoff',),
'vedstoffa': ('vedstoff',),
'vedstoffene': ('vedstoff',),
'vedstoffer': ('vedstoff',),
'vedstoffet': ('vedstoff',),
'vedtak': ('vedtak',),
'vedtaka': ('vedtak',),
'vedtakene': ('vedtak',),
'vedtaket': ('vedtak',),
'vedtakelse': ('vedtakelse',),
'vedtakelsen': ('vedtakelse',),
'vedtakelsene': ('vedtakelse',),
'vedtakelser': ('vedtakelse',),
'vedtekt': ('vedtekt',),
'vedtekta': ('vedtekt',),
'vedtekten': ('vedtekt',),
'vedtektene': ('vedtekt',),
'vedtekter': ('vedtekt',),
'vedtre': ('vedtre',),
'vedtrea': ('vedtre',),
'vedtreet': ('vedtre',),
'vedtrær': ('vedtre',),
'vedtrærne': ('vedtre',),
'vedvendel': ('vedvendel',),
'vedvendelen': ('vedvendel',),
'vedvendlene': ('vedvendel',),
'vedvendler': ('vedvendel',),
'vedøks': ('vedøks',),
'vedøksa': ('vedøks',),
'vedøksen': ('vedøks',),
'vedøksene': ('vedøks',),
'vedøkser': ('vedøks',),
'veft': ('veft',),
'veften': ('veft',),
'veftene': ('veft',),
'vefter': ('veft',),
'vefting': ('vefting',),
'veftinga': ('vefting',),
'veftingen': ('vefting',),
'veftingene': ('vefting',),
'veftinger': ('vefting',),
'veg': ('veg',),
'vegen': ('veg',),
'vegene': ('veg',),
'veger': ('veg',),
'vegavgift': ('vegavgift',),
'vegavgifta': ('vegavgift',),
'vegavgiften': ('vegavgift',),
'vegavgiftene': ('vegavgift',),
'vegavgifter': ('vegavgift',),
'vegbane': ('vegbane',),
'vegbanen': ('vegbane',),
'vegbanene': ('vegbane',),
'vegbaner': ('vegbane',),
'vegbredde': ('vegbredde',),
'vegbredden': ('vegbredde',),
'vegbreddene': ('vegbredde',),
'vegbredder': ('vegbredde',),
'vegbreidd': ('vegbreidd',),
'vegbreidda': ('vegbreidd',),
'vegbreidden': ('vegbreidd',),
'vegbreiddene': ('vegbreidd',),
'vegbreidder': ('vegbreidd',),
'vegdekka': ('vegdekke',),
'vegdekke': ('vegdekke',),
'vegdekkene': ('vegdekke',),
'vegdekker': ('vegdekke',),
'vegdekket': ('vegdekke',),
'vegdirektorat': ('vegdirektorat',),
'vegdirektorata': ('vegdirektorat',),
'vegdirektoratene': ('vegdirektorat',),
'vegdirektorater': ('vegdirektorat',),
'vegdirektoratet': ('vegdirektorat',),
'vegdirektør': ('vegdirektør',),
'vegdirektøren': ('vegdirektør',),
'vegdirektørene': ('vegdirektør',),
'vegdirektører': ('vegdirektør',),
'vegelsinn': ('vegelsinn',),
'vegelsinna': ('vegelsinn',),
'vegelsinnene': ('vegelsinn',),
'vegelsinnet': ('vegelsinn',),
'vegemot': ('vegemot',),
'vegemota': ('vegemot',),
'vegemotene': ('vegemot',),
'vegemotet': ('vegemot',),
'vegetabil': ('vegetabil',),
'vegetabila': ('vegetabil',),
'vegetabilene': ('vegetabil',),
'vegetabiler': ('vegetabil',),
'vegetabilet': ('vegetabil',),
'vegetar': ('vegetar',),
'vegetaren': ('vegetar',),
'vegetarene': ('vegetar',),
'vegetarer': ('vegetar',),
'vegetarianer': ('vegetarianer',),
'vegetarianere': ('vegetarianer',),
'vegetarianeren': ('vegetarianer',),
'vegetarianerer': ('vegetarianer',),
'vegetarianerne': ('vegetarianer',),
'vegetarianisme': ('vegetarianisme',),
'vegetarianismen': ('vegetarianisme',),
'vegetarianismene': ('vegetarianisme',),
'vegetarianismer': ('vegetarianisme',),
'vegetarisme': ('vegetarisme',),
'vegetarismen': ('vegetarisme',),
'vegetarismene': ('vegetarisme',),
'vegetarismer': ('vegetarisme',),
'vegetarkost': ('vegetarkost',),
'vegetarkosten': ('vegetarkost',),
'vegetarkostene': ('vegetarkost',),
'vegetarkoster': ('vegetarkost',),
'vegetarrestaurant': ('vegetarrestaurant',),
'vegetarrestauranten': ('vegetarrestaurant',),
'vegetarrestaurantene': ('vegetarrestaurant',),
'vegetarrestauranter': ('vegetarrestaurant',),
'vegetasjon': ('vegetasjon',),
'vegetasjonen': ('vegetasjon',),
'vegetasjonene': ('vegetasjon',),
'vegetasjoner': ('vegetasjon',),
'vegetasjonsbelta': ('vegetasjonsbelte',),
'vegetasjonsbelte': ('vegetasjonsbelte',),
'vegetasjonsbeltene': ('vegetasjonsbelte',),
'vegetasjonsbelter': ('vegetasjonsbelte',),
'vegetasjonsbeltet': ('vegetasjonsbelte',),
'vegetasjonsperiode': ('vegetasjonsperiode',),
'vegetasjonsperioden': ('vegetasjonsperiode',),
'vegetasjonsperiodene': ('vegetasjonsperiode',),
'vegetasjonsperioder': ('vegetasjonsperiode',),
'vegetoterapi': ('vegetoterapi',),
'vegetoterapien': ('vegetoterapi',),
'vegetoterapiene': ('vegetoterapi',),
'vegetoterapier': ('vegetoterapi',),
'vegforbindelse': ('vegforbindelse',),
'vegforbindelsen': ('vegforbindelse',),
'vegforbindelsene': ('vegforbindelse',),
'vegforbindelser': ('vegforbindelse',),
'vegg': ('vegg',),
'veggen': ('vegg',),
'veggene': ('vegg',),
'vegger': ('vegg',),
'vegg-til-vegg-teppa': ('vegg-til-vegg-teppe',),
'vegg-til-vegg-teppe': ('vegg-til-vegg-teppe',),
'vegg-til-vegg-teppene': ('vegg-til-vegg-teppe',),
'vegg-til-vegg-tepper': ('vegg-til-vegg-teppe',),
'vegg-til-vegg-teppet': ('vegg-til-vegg-teppe',),
'veggavis': ('veggavis',),
'veggavisa': ('veggavis',),
'veggavisen': ('veggavis',),
'veggavisene': ('veggavis',),
'veggaviser': ('veggavis',),
'veggedyr': ('veggedyr',),
'veggedyra': ('veggedyr',),
'veggedyrene': ('veggedyr',),
'veggedyret': ('veggedyr',),
'veggelement': ('veggelement',),
'veggelementa': ('veggelement',),
'veggelementene': ('veggelement',),
'veggelementer': ('veggelement',),
'veggelementet': ('veggelement',),
'veggelus': ('veggelus',),
'veggelusa': ('veggelus',),
'veggelusen': ('veggelus',),
'veggelusene': ('veggelus',),
'veggepryd': ('veggepryd',),
'veggepryden': ('veggepryd',),
'veggeprydene': ('veggepryd',),
'veggepryder': ('veggepryd',),
'veggkart': ('veggkart',),
'veggkarta': ('veggkart',),
'veggkartene': ('veggkart',),
'veggkarter': ('veggkart',),
'veggkartet': ('veggkart',),
'veggmaleri': ('veggmaleri',),
'veggmaleria': ('veggmaleri',),
'veggmaleriene': ('veggmaleri',),
'veggmalerier': ('veggmaleri',),
'veggmaleriet': ('veggmaleri',),
'veggplass': ('veggplass',),
'veggplassen': ('veggplass',),
'veggplassene': ('veggplass',),
'veggplasser': ('veggplass',),
'veggpryd': ('veggpryd',),
'veggpryden': ('veggpryd',),
'veggprydene': ('veggpryd',),
'veggpryder': ('veggpryd',),
'veggrep': ('veggrep',),
'veggrepa': ('veggrep',),
'veggrepene': ('veggrep',),
'veggrepet': ('veggrep',),
'veggrunn': ('veggrunn',),
'veggrunnen': ('veggrunn',),
'veggrunnene': ('veggrunn',),
'veggrunner': ('veggrunn',),
'veggrøft': ('veggrøft',),
'veggrøfta': ('veggrøft',),
'veggrøften': ('veggrøft',),
'veggrøftene': ('veggrøft',),
'veggrøfter': ('veggrøft',),
'veggskap': ('veggskap',),
'veggskapa': ('veggskap',),
'veggskapene': ('veggskap',),
'veggskapet': ('veggskap',),
'veggskrift': ('veggskrift',),
'veggskrifta': ('veggskrift',),
'veggskriften': ('veggskrift',),
'veggskriftene': ('veggskrift',),
'veggskrifter': ('veggskrift',),
'veggspell': ('veggspell',),
'veggspella': ('veggspell',),
'veggspellene': ('veggspell',),
'veggspellet': ('veggspell',),
'veggspill': ('veggspill',),
'veggspilla': ('veggspill',),
'veggspillene': ('veggspill',),
'veggspillet': ('veggspill',),
'veggtavla': ('veggtavle',),
'veggtavle': ('veggtavle',),
'veggtavlen': ('veggtavle',),
'veggtavlene': ('veggtavle',),
'veggtavler': ('veggtavle',),
'veggteppa': ('veggteppe',),
'veggteppe': ('veggteppe',),
'veggteppene': ('veggteppe',),
'veggtepper': ('veggteppe',),
'veggteppet': ('veggteppe',),
'veggur': ('veggur',),
'veggura': ('veggur',),
'veggurene': ('veggur',),
'vegguret': ('veggur',),
'veghøvel': ('veghøvel',),
'veghøvelen': ('veghøvel',),
'veghøvlene': ('veghøvel',),
'veghøvler': ('veghøvel',),
'vegingeniør': ('vegingeniør',),
'vegingeniøren': ('vegingeniør',),
'vegingeniørene': ('vegingeniør',),
'vegingeniører': ('vegingeniør',),
'vegkant': ('vegkant',),
'vegkanten': ('vegkant',),
'vegkantene': ('vegkant',),
'vegkanter': ('vegkant',),
'vegkart': ('vegkart',),
'vegkarta': ('vegkart',),
'vegkartene': ('vegkart',),
'vegkarter': ('vegkart',),
'vegkartet': ('vegkart',),
'vegkontor': ('vegkontor',),
'vegkontora': ('vegkontor',),
'vegkontorene': ('vegkontor',),
'vegkontorer': ('vegkontor',),
'vegkontoret': ('vegkontor',),
'vegkro': ('vegkro',),
'vegkroa': ('vegkro',),
'vegkroen': ('vegkro',),
'vegkroene': ('vegkro',),
'vegkroer': ('vegkro',),
'vegkryss': ('vegkryss',),
'vegkryssa': ('vegkryss',),
'vegkryssene': ('vegkryss',),
'vegkrysset': ('vegkryss',),
'veglegema': ('veglegeme',),
'veglegeme': ('veglegeme',),
'veglegemene': ('veglegeme',),
'veglegemer': ('veglegeme',),
'veglegemet': ('veglegeme',),
'veglov': ('veglov',),
'vegloven': ('veglov',),
'veglovene': ('veglov',),
'veglover': ('veglov',),
'vegmaskin': ('vegmaskin',),
'vegmaskina': ('vegmaskin',),
'vegmaskinen': ('vegmaskin',),
'vegmaskinene': ('vegmaskin',),
'vegmaskiner': ('vegmaskin',),
'vegmasse': ('vegmasse',),
'vegmassen': ('vegmasse',),
'vegmassene': ('vegmasse',),
'vegmasser': ('vegmasse',),
'vegmerka': ('vegmerke',),
'vegmerke': ('vegmerke',),
'vegmerkene': ('vegmerke',),
'vegmerker': ('vegmerke',),
'vegmerket': ('vegmerke',),
'vegmerking': ('vegmerking',),
'vegmerkinga': ('vegmerking',),
'vegmerkingen': ('vegmerking',),
'vegmerkingene': ('vegmerking',),
'vegmerkinger': ('vegmerking',),
'vegmester': ('vegmester',),
'vegmestere': ('vegmester',),
'vegmesteren': ('vegmester',),
'vegmesterer': ('vegmester',),
'vegmesterne': ('vegmester',),
'vegmestre': ('vegmester',),
'vegmestrene': ('vegmester',),
'vegmestrer': ('vegmester',),
'vegn': ('vegn',),
'vegna': ('vegn',),
'vegnen': ('vegn',),
'vegnene': ('vegn',),
'vegner': ('vegn',),
'vegnet': ('vegn',),
'vegnavn': ('vegnavn',),
'vegnavna': ('vegnavn',),
'vegnavnene': ('vegnavn',),
'vegnavnet': ('vegnavn',),
'vegne': ('vegne',),
'vegnemnd': ('vegnemnd',),
'vegnemnda': ('vegnemnd',),
'vegnemnden': ('vegnemnd',),
'vegnemndene': ('vegnemnd',),
'vegnemnder': ('vegnemnd',),
'vegnett': ('vegnett',),
'vegnetta': ('vegnett',),
'vegnettene': ('vegnett',),
'vegnettet': ('vegnett',),
'vegoppsynsmann': ('vegoppsynsmann',),
'vegoppsynsmannen': ('vegoppsynsmann',),
'vegoppsynsmenn': ('vegoppsynsmann',),
'vegoppsynsmennene': ('vegoppsynsmann',),
'vegpatrulje': ('vegpatrulje',),
'vegpatruljen': ('vegpatrulje',),
'vegpatruljene': ('vegpatrulje',),
'vegpatruljer': ('vegpatrulje',),
'vegplan': ('vegplan',),
'vegplanen': ('vegplan',),
'vegplanene': ('vegplan',),
'vegplaner': ('vegplan',),
'vegrapport': ('vegrapport',),
'vegrapporten': ('vegrapport',),
'vegrapportene': ('vegrapport',),
'vegrapporter': ('vegrapport',),
'vegrett': ('vegrett',),
'vegretten': ('vegrett',),
'vegrettene': ('vegrett',),
'vegretter': ('vegrett',),
'vegsjef': ('vegsjef',),
'vegsjefen': ('vegsjef',),
'vegsjefene': ('vegsjef',),
'vegsjefer': ('vegsjef',),
'vegskilla': ('vegskille',),
'vegskille': ('vegskille',),
'vegskillene': ('vegskille',),
'vegskiller': ('vegskille',),
'vegskillet': ('vegskille',),
'vegskilt': ('vegskilt',),
'vegskilta': ('vegskilt',),
'vegskiltene': ('vegskilt',),
'vegskilter': ('vegskilt',),
'vegskiltet': ('vegskilt',),
'vegskrapa': ('vegskrape',),
'vegskrape': ('vegskrape',),
'vegskrapen': ('vegskrape',),
'vegskrapene': ('vegskrape',),
'vegskraper': ('vegskrape',),
'vegskråning': ('vegskråning',),
'vegskråninga': ('vegskråning',),
'vegskråningen': ('vegskråning',),
'vegskråningene': ('vegskråning',),
'vegskråninger': ('vegskråning',),
'vegsperring': ('vegsperring',),
'vegsperringa': ('vegsperring',),
'vegsperringen': ('vegsperring',),
'vegsperringene': ('vegsperring',),
'vegsperringer': ('vegsperring',),
'vegstøv': ('vegstøv',),
'vegstøva': ('vegstøv',),
'vegstøvene': ('vegstøv',),
'vegstøvet': ('vegstøv',),
'vegtavla': ('vegtavle',),
'vegtavle': ('vegtavle',),
'vegtavlen': ('vegtavle',),
'vegtavlene': ('vegtavle',),
'vegtavler': ('vegtavle',),
'vegtistel': ('vegtistel',),
'vegtistelen': ('vegtistel',),
'vegtistlene': ('vegtistel',),
'vegtistler': ('vegtistel',),
'vegtunnel': ('vegtunnel',),
'vegtunnelen': ('vegtunnel',),
'vegtunnelene': ('vegtunnel',),
'vegtunneler': ('vegtunnel',),
'vegutløsing': ('vegutløsing',),
'vegutløsinga': ('vegutløsing',),
'vegutløsingen': ('vegutløsing',),
'vegutløsingene': ('vegutløsing',),
'vegutløsinger': ('vegutløsing',),
'vegutløsning': ('vegutløsning',),
'vegutløsninga': ('vegutløsning',),
'vegutløsningen': ('vegutløsning',),
'vegutløsningene': ('vegutløsning',),
'vegutløsninger': ('vegutløsning',),
'vegutløysing': ('vegutløysing',),
'vegutløysinga': ('vegutløysing',),
'vegutløysingen': ('vegutløysing',),
'vegutløysingene': ('vegutløysing',),
'vegutløysinger': ('vegutløysing',),
'vegvals': ('vegvals',),
'vegvalsen': ('vegvals',),
'vegvalsene': ('vegvals',),
'vegvalser': ('vegvals',),
'vegvalse': ('vegvalse',),
'vegvalsen': ('vegvalse',),
'vegvalsene': ('vegvalse',),
'vegvalser': ('vegvalse',),
'vegvesen': ('vegvesen',),
'vegvesena': ('vegvesen',),
'vegvesenene': ('vegvesen',),
'vegvesener': ('vegvesen',),
'vegvesenet': ('vegvesen',),
'vegviser': ('vegviser',),
'vegvisere': ('vegviser',),
'vegviseren': ('vegviser',),
'vegviserer': ('vegviser',),
'vegviserne': ('vegviser',),
'vegvokter': ('vegvokter',),
'vegvoktere': ('vegvokter',),
'vegvokteren': ('vegvokter',),
'vegvokterer': ('vegvokter',),
'vegvokterne': ('vegvokter',),
'vehikkel': ('vehikkel',),
'vehikkelet': ('vehikkel',),
'vehikla': ('vehikkel',),
'vehiklene': ('vehikkel',),
'vehikler': ('vehikkel',),
'vehiklet': ('vehikkel',),
'vei': ('vei',),
'veien': ('vei',),
'veiene': ('vei',),
'veier': ('vei',),
'veiavgift': ('veiavgift',),
'veiavgifta': ('veiavgift',),
'veiavgiften': ('veiavgift',),
'veiavgiftene': ('veiavgift',),
'veiavgifter': ('veiavgift',),
'veibane': ('veibane',),
'veibanen': ('veibane',),
'veibanene': ('veibane',),
'veibaner': ('veibane',),
'veibredde': ('veibredde',),
'veibredden': ('veibredde',),
'veibreddene': ('veibredde',),
'veibredder': ('veibredde',),
'veibreidd': ('veibreidd',),
'veibreidda': ('veibreidd',),
'veibreidden': ('veibreidd',),
'veibreiddene': ('veibreidd',),
'veibreidder': ('veibreidd',),
'veida': ('veide',),
'veide': ('veide',),
'veidene': ('veide',),
'veider': ('veide',),
'veidet': ('veide',),
'veidefolk': ('veidefolk',),
'veidefolka': ('veidefolk',),
'veidefolkene': ('veidefolk',),
'veidefolket': ('veidefolk',),
'veidehår': ('veidehår',),
'veidehåra': ('veidehår',),
'veidehårene': ('veidehår',),
'veidehåret': ('veidehår',),
'veidekka': ('veidekke',),
'veidekke': ('veidekke',),
'veidekkene': ('veidekke',),
'veidekker': ('veidekke',),
'veidekket': ('veidekke',),
'veidemann': ('veidemann',),
'veidemannen': ('veidemann',),
'veidemenn': ('veidemann',),
'veidemennene': ('veidemann',),
'veideredskap': ('veideredskap',),
'veideredskapa': ('veideredskap',),
'veideredskapen': ('veideredskap',),
'veideredskapene': ('veideredskap',),
'veideredskaper': ('veideredskap',),
'veideredskapet': ('veideredskap',),
'veidirektorat': ('veidirektorat',),
'veidirektorata': ('veidirektorat',),
'veidirektoratene': ('veidirektorat',),
'veidirektorater': ('veidirektorat',),
'veidirektoratet': ('veidirektorat',),
'veidirektør': ('veidirektør',),
'veidirektøren': ('veidirektør',),
'veidirektørene': ('veidirektør',),
'veidirektører': ('veidirektør',),
'veidn': ('veidn',),
'veidna': ('veidn',),
'veidnen': ('veidn',),
'veidnene': ('veidn',),
'veidner': ('veidn',),
'veiforbindelse': ('veiforbindelse',),
'veiforbindelsen': ('veiforbindelse',),
'veiforbindelsene': ('veiforbindelse',),
'veiforbindelser': ('veiforbindelse',),
'veigrep': ('veigrep',),
'veigrepa': ('veigrep',),
'veigrepene': ('veigrep',),
'veigrepet': ('veigrep',),
'veigrunn': ('veigrunn',),
'veigrunnen': ('veigrunn',),
'veigrunnene': ('veigrunn',),
'veigrunner': ('veigrunn',),
'veigrøft': ('veigrøft',),
'veigrøfta': ('veigrøft',),
'veigrøften': ('veigrøft',),
'veigrøftene': ('veigrøft',),
'veigrøfter': ('veigrøft',),
'veihøvel': ('veihøvel',),
'veihøvelen': ('veihøvel',),
'veihøvlene': ('veihøvel',),
'veihøvler': ('veihøvel',),
'veiingeniør': ('veiingeniør',),
'veiingeniøren': ('veiingeniør',),
'veiingeniørene': ('veiingeniør',),
'veiingeniører': ('veiingeniør',),
'veikant': ('veikant',),
'veikanten': ('veikant',),
'veikantene': ('veikant',),
'veikanter': ('veikant',),
'veikart': ('veikart',),
'veikarta': ('veikart',),
'veikartene': ('veikart',),
'veikarter': ('veikart',),
'veikartet': ('veikart',),
'veike': ('veike',),
'veiken': ('veike',),
'veikene': ('veike',),
'veiker': ('veike',),
'veikhet': ('veikhet',),
'veikheta': ('veikhet',),
'veikheten': ('veikhet',),
'veikhetene': ('veikhet',),
'veikheter': ('veikhet',),
'veiking': ('veiking',),
'veikingen': ('veiking',),
'veikingene': ('veiking',),
'veikinger': ('veiking',),
'veikling': ('veikling',),
'veiklingen': ('veikling',),
'veiklingene': ('veikling',),
'veiklinger': ('veikling',),
'veikontor': ('veikontor',),
'veikontora': ('veikontor',),
'veikontorene': ('veikontor',),
'veikontorer': ('veikontor',),
'veikontoret': ('veikontor',),
'veikro': ('veikro',),
'veikroa': ('veikro',),
'veikroen': ('veikro',),
'veikroene': ('veikro',),
'veikroer': ('veikro',),
'veikryss': ('veikryss',),
'veikryssa': ('veikryss',),
'veikryssene': ('veikryss',),
'veikrysset': ('veikryss',),
'veila': ('veile',),
'veile': ('veile',),
'veilen': ('veile',),
'veilene': ('veile',),
'veiler': ('veile',),
'veileder': ('veileder',),
'veiledere': ('veileder',),
'veilederen': ('veileder',),
'veilederer': ('veileder',),
'veilederne': ('veileder',),
'veiledning': ('veiledning',),
'veiledninga': ('veiledning',),
'veiledningen': ('veiledning',),
'veiledningene': ('veiledning',),
'veiledninger': ('veiledning',),
'veiledningskontor': ('veiledningskontor',),
'veiledningskontora': ('veiledningskontor',),
'veiledningskontorene': ('veiledningskontor',),
'veiledningskontorer': ('veiledningskontor',),
'veiledningskontoret': ('veiledningskontor',),
'veiledningstjeneste': ('veiledningstjeneste',),
'veiledningstjenesten': ('veiledningstjeneste',),
'veiledningstjenestene': ('veiledningstjeneste',),
'veiledningstjenester': ('veiledningstjeneste',),
'veilegema': ('veilegeme',),
'veilegeme': ('veilegeme',),
'veilegemene': ('veilegeme',),
'veilegemer': ('veilegeme',),
'veilegemet': ('veilegeme',),
'veilov': ('veilov',),
'veiloven': ('veilov',),
'veilovene': ('veilov',),
'veilover': ('veilov',),
'veimaskin': ('veimaskin',),
'veimaskina': ('veimaskin',),
'veimaskinen': ('veimaskin',),
'veimaskinene': ('veimaskin',),
'veimaskiner': ('veimaskin',),
'veimasse': ('veimasse',),
'veimassen': ('veimasse',),
'veimassene': ('veimasse',),
'veimasser': ('veimasse',),
'veimerka': ('veimerke',),
'veimerke': ('veimerke',),
'veimerkene': ('veimerke',),
'veimerker': ('veimerke',),
'veimerket': ('veimerke',),
'veimerking': ('veimerking',),
'veimerkinga': ('veimerking',),
'veimerkingen': ('veimerking',),
'veimerkingene': ('veimerking',),
'veimerkinger': ('veimerking',),
'veimester': ('veimester',),
'veimestere': ('veimester',),
'veimesteren': ('veimester',),
'veimesterer': ('veimester',),
'veimesterne': ('veimester',),
'veimestre': ('veimester',),
'veimestrene': ('veimester',),
'veimestrer': ('veimester',),
'veinavn': ('veinavn',),
'veinavna': ('veinavn',),
'veinavnene': ('veinavn',),
'veinavnet': ('veinavn',),
'veinemnd': ('veinemnd',),
'veinemnda': ('veinemnd',),
'veinemnden': ('veinemnd',),
'veinemndene': ('veinemnd',),
'veinemnder': ('veinemnd',),
'veinett': ('veinett',),
'veinetta': ('veinett',),
'veinettene': ('veinett',),
'veinettet': ('veinett',),
'veioppsynsmann': ('veioppsynsmann',),
'veioppsynsmannen': ('veioppsynsmann',),
'veioppsynsmenn': ('veioppsynsmann',),
'veioppsynsmennene': ('veioppsynsmann',),
'veipatrulje': ('veipatrulje',),
'veipatruljen': ('veipatrulje',),
'veipatruljene': ('veipatrulje',),
'veipatruljer': ('veipatrulje',),
'veiplan': ('veiplan',),
'veiplanen': ('veiplan',),
'veiplanene': ('veiplan',),
'veiplaner': ('veiplan',),
'veirapport': ('veirapport',),
'veirapporten': ('veirapport',),
'veirapportene': ('veirapport',),
'veirapporter': ('veirapport',),
'veirett': ('veirett',),
'veiretten': ('veirett',),
'veirettene': ('veirett',),
'veiretter': ('veirett',),
'veisjef': ('veisjef',),
'veisjefen': ('veisjef',),
'veisjefene': ('veisjef',),
'veisjefer': ('veisjef',),
'veiskilla': ('veiskille',),
'veiskille': ('veiskille',),
'veiskillene': ('veiskille',),
'veiskiller': ('veiskille',),
'veiskillet': ('veiskille',),
'veiskilt': ('veiskilt',),
'veiskilta': ('veiskilt',),
'veiskiltene': ('veiskilt',),
'veiskilter': ('veiskilt',),
'veiskiltet': ('veiskilt',),
'veiskrapa': ('veiskrape',),
'veiskrape': ('veiskrape',),
'veiskrapen': ('veiskrape',),
'veiskrapene': ('veiskrape',),
'veiskraper': ('veiskrape',),
'veiskråning': ('veiskråning',),
'veiskråninga': ('veiskråning',),
'veiskråningen': ('veiskråning',),
'veiskråningene': ('veiskråning',),
'veiskråninger': ('veiskråning',),
'veisperring': ('veisperring',),
'veisperringa': ('veisperring',),
'veisperringen': ('veisperring',),
'veisperringene': ('veisperring',),
'veisperringer': ('veisperring',),
'veistøv': ('veistøv',),
'veistøva': ('veistøv',),
'veistøvene': ('veistøv',),
'veistøvet': ('veistøv',),
'veit': ('veit',),
'veita': ('veit',),
'veiten': ('veit',),
'veitene': ('veit',),
'veiter': ('veit',),
'veitavla': ('veitavle',),
'veitavle': ('veitavle',),
'veitavlen': ('veitavle',),
'veitavlene': ('veitavle',),
'veitavler': ('veitavle',),
'veitistel': ('veitistel',),
'veitistelen': ('veitistel',),
'veitistlene': ('veitistel',),
'veitistler': ('veitistel',),
'veitsla': ('veitsle',),
'veitsle': ('veitsle',),
'veitslen': ('veitsle',),
'veitslene': ('veitsle',),
'veitsler': ('veitsle',),
'veitunnel': ('veitunnel',),
'veitunnelen': ('veitunnel',),
'veitunnelene': ('veitunnel',),
'veitunneler': ('veitunnel',),
'veiutløsing': ('veiutløsing',),
'veiutløsinga': ('veiutløsing',),
'veiutløsingen': ('veiutløsing',),
'veiutløsingene': ('veiutløsing',),
'veiutløsinger': ('veiutløsing',),
'veiutløsning': ('veiutløsning',),
'veiutløsninga': ('veiutløsning',),
'veiutløsningen': ('veiutløsning',),
'veiutløsningene': ('veiutløsning',),
'veiutløsninger': ('veiutløsning',),
'veiutløysing': ('veiutløysing',),
'veiutløysinga': ('veiutløysing',),
'veiutløysingen': ('veiutløysing',),
'veiutløysingene': ('veiutløysing',),
'veiutløysinger': ('veiutløysing',),
'veiv': ('veiv',),
'veiva': ('veiv',),
'veiven': ('veiv',),
'veivene': ('veiv',),
'veiver': ('veiv',),
'veivaksel': ('veivaksel',),
'veivakselen': ('veivaksel',),
'veivakslene': ('veivaksel',),
'veivaksler': ('veivaksel',),
'veivals': ('veivals',),
'veivalsen': ('veivals',),
'veivalsene': ('veivals',),
'veivalser': ('veivals',),
'veivalse': ('veivalse',),
'veivalsen': ('veivalse',),
'veivalsene': ('veivalse',),
'veivalser': ('veivalse',),
'veivesen': ('veivesen',),
'veivesena': ('veivesen',),
'veivesenene': ('veivesen',),
'veivesener': ('veivesen',),
'veivesenet': ('veivesen',),
'veivhus': ('veivhus',),
'veivhusa': ('veivhus',),
'veivhusene': ('veivhus',),
'veivhuset': ('veivhus',),
'veiviser': ('veiviser',),
'veivisere': ('veiviser',),
'veiviseren': ('veiviser',),
'veiviserer': ('veiviser',),
'veiviserne': ('veiviser',),
'veivokter': ('veivokter',),
'veivoktere': ('veivokter',),
'veivokteren': ('veivokter',),
'veivokterer': ('veivokter',),
'veivokterne': ('veivokter',),
'veivstang': ('veivstang',),
'veivstanga': ('veivstang',),
'veivstangen': ('veivstang',),
'veivstengene': ('veivstang',),
'veivstenger': ('veivstang',),
'veivtapp': ('veivtapp',),
'veivtappen': ('veivtapp',),
'veivtappene': ('veivtapp',),
'veivtapper': ('veivtapp',),
'veke': ('veke',),
'veken': ('veke',),
'vekene': ('veke',),
'veker': ('veke',),
'veka': ('veke',),
'veke': ('veke',),
'veken': ('veke',),
'vekene': ('veke',),
'veker': ('veke',),
'veka': ('veke',),
'veke': ('veke',),
'veken': ('veke',),
'vekene': ('veke',),
'veker': ('veke',),
'vekeavis': ('vekeavis',),
'vekeavisa': ('vekeavis',),
'vekeavisen': ('vekeavis',),
'vekeavisene': ('vekeavis',),
'vekeaviser': ('vekeavis',),
'vekeavis': ('vekeavis',),
'vekeavisa': ('vekeavis',),
'vekeavisen': ('vekeavis',),
'vekeavisene': ('vekeavis',),
'vekeaviser': ('vekeavis',),
'vekeblad': ('vekeblad',),
'vekeblada': ('vekeblad',),
'vekebladene': ('vekeblad',),
'vekeblader': ('vekeblad',),
'vekebladet': ('vekeblad',),
'vekeblad': ('vekeblad',),
'vekeblada': ('vekeblad',),
'vekebladene': ('vekeblad',),
'vekeblader': ('vekeblad',),
'vekebladet': ('vekeblad',),
'vekebladnovella': ('vekebladnovelle',),
'vekebladnovelle': ('vekebladnovelle',),
'vekebladnovellen': ('vekebladnovelle',),
'vekebladnovellene': ('vekebladnovelle',),
'vekebladnoveller': ('vekebladnovelle',),
'vekebladnovella': ('vekebladnovelle',),
'vekebladnovelle': ('vekebladnovelle',),
'vekebladnovellen': ('vekebladnovelle',),
'vekebladnovellene': ('vekebladnovelle',),
'vekebladnoveller': ('vekebladnovelle',),
'vekebladsnovella': ('vekebladsnovelle',),
'vekebladsnovelle': ('vekebladsnovelle',),
'vekebladsnovellen': ('vekebladsnovelle',),
'vekebladsnovellene': ('vekebladsnovelle',),
'vekebladsnoveller': ('vekebladsnovelle',),
'vekebladsnovella': ('vekebladsnovelle',),
'vekebladsnovelle': ('vekebladsnovelle',),
'vekebladsnovellen': ('vekebladsnovelle',),
'vekebladsnovellene': ('vekebladsnovelle',),
'vekebladsnoveller': ('vekebladsnovelle',),
'vekedag': ('vekedag',),
'vekedagen': ('vekedag',),
'vekedagene': ('vekedag',),
'vekedager': ('vekedag',),
'vekedag': ('vekedag',),
'vekedagen': ('vekedag',),
'vekedagene': ('vekedag',),
'vekedager': ('vekedag',),
'vekekort': ('vekekort',),
'vekekorta': ('vekekort',),
'vekekortene': ('vekekort',),
'vekekortet': ('vekekort',),
'vekekort': ('vekekort',),
'vekekorta': ('vekekort',),
'vekekortene': ('vekekort',),
'vekekortet': ('vekekort',),
'vekelønn': ('vekelønn',),
'vekelønna': ('vekelønn',),
'vekelønnen': ('vekelønn',),
'vekelønnene': ('vekelønn',),
'vekelønner': ('vekelønn',),
'vekelønn': ('vekelønn',),
'vekelønna': ('vekelønn',),
'vekelønnen': ('vekelønn',),
'vekelønnene': ('vekelønn',),
'vekelønner': ('vekelønn',),
'vekependler': ('vekependler',),
'vekependlere': ('vekependler',),
'vekependleren': ('vekependler',),
'vekependlerer': ('vekependler',),
'vekependlerne': ('vekependler',),
'vekependling': ('vekependling',),
'vekependlinga': ('vekependling',),
'vekependlingen': ('vekependling',),
'vekependlingene': ('vekependling',),
'vekependlinger': ('vekependling',),
'vekependling': ('vekependling',),
'vekependlinga': ('vekependling',),
'vekependlingen': ('vekependling',),
'vekependlingene': ('vekependling',),
'vekependlinger': ('vekependling',),
'vekepengene': ('vekepenger',),
'vekepenger': ('vekepenger',),
'vekepengene': ('vekepenger',),
'vekepenger': ('vekepenger',),
'vekepressa': ('vekepresse',),
'vekepresse': ('vekepresse',),
'vekepressen': ('vekepresse',),
'vekepressene': ('vekepresse',),
'vekepresser': ('vekepresse',),
'vekepressa': ('vekepresse',),
'vekepresse': ('vekepresse',),
'vekepressen': ('vekepresse',),
'vekepressene': ('vekepresse',),
'vekepresser': ('vekepresse',),
'vekeslutt': ('vekeslutt',),
'vekeslutten': ('vekeslutt',),
'vekesluttene': ('vekeslutt',),
'vekeslutter': ('vekeslutt',),
'vekeslutt': ('vekeslutt',),
'vekeslutten': ('vekeslutt',),
'vekesluttene': ('vekeslutt',),
'vekeslutter': ('vekeslutt',),
'vekhet': ('vekhet',),
'vekheta': ('vekhet',),
'vekheten': ('vekhet',),
'vekhetene': ('vekhet',),
'vekheter': ('vekhet',),
'veking': ('veking',),
'vekingen': ('veking',),
'vekingene': ('veking',),
'vekinger': ('veking',),
'vekka': ('vekke',),
'vekke': ('vekke',),
'vekken': ('vekke',),
'vekkene': ('vekke',),
'vekker': ('vekke',),
'vekkeklokka': ('vekkeklokke',),
'vekkeklokke': ('vekkeklokke',),
'vekkeklokken': ('vekkeklokke',),
'vekkeklokkene': ('vekkeklokke',),
'vekkeklokker': ('vekkeklokke',),
'vekkelse': ('vekkelse',),
'vekkelsen': ('vekkelse',),
'vekkelsene': ('vekkelse',),
'vekkelser': ('vekkelse',),
'vekkelsesbevegelse': ('vekkelsesbevegelse',),
'vekkelsesbevegelsen': ('vekkelsesbevegelse',),
'vekkelsesbevegelsene': ('vekkelsesbevegelse',),
'vekkelsesbevegelser': ('vekkelsesbevegelse',),
'vekkelsesmøta': ('vekkelsesmøte',),
'vekkelsesmøte': ('vekkelsesmøte',),
'vekkelsesmøtene': ('vekkelsesmøte',),
'vekkelsesmøter': ('vekkelsesmøte',),
'vekkelsesmøtet': ('vekkelsesmøte',),
'vekkelsespredikant': ('vekkelsespredikant',),
'vekkelsespredikanten': ('vekkelsespredikant',),
'vekkelsespredikantene': ('vekkelsespredikant',),
'vekkelsespredikanter': ('vekkelsespredikant',),
'vekkelsestid': ('vekkelsestid',),
'vekkelsestida': ('vekkelsestid',),
'vekkelsestiden': ('vekkelsestid',),
'vekkelsestidene': ('vekkelsestid',),
'vekkelsestider': ('vekkelsestid',),
'vekker': ('vekker',),
'vekkere': ('vekker',),
'vekkeren': ('vekker',),
'vekkerer': ('vekker',),
'vekkerne': ('vekker',),
'vekkerklokka': ('vekkerklokke',),
'vekkerklokke': ('vekkerklokke',),
'vekkerklokken': ('vekkerklokke',),
'vekkerklokkene': ('vekkerklokke',),
'vekkerklokker': ('vekkerklokke',),
'vekkerur': ('vekkerur',),
'vekkerura': ('vekkerur',),
'vekkerurene': ('vekkerur',),
'vekkeruret': ('vekkerur',),
'vekkeur': ('vekkeur',),
'vekkeura': ('vekkeur',),
'vekkeurene': ('vekkeur',),
'vekkeuret': ('vekkeur',),
'vekling': ('vekling',),
'veklingen': ('vekling',),
'veklingene': ('vekling',),
'veklinger': ('vekling',),
'veksel': ('veksel',),
'vekselen': ('veksel',),
'vekslene': ('veksel',),
'veksler': ('veksel',),
'vekselaksept': ('vekselaksept',),
'vekselaksepten': ('vekselaksept',),
'vekselakseptene': ('vekselaksept',),
'vekselaksepter': ('vekselaksept',),
'vekselbedrager': ('vekselbedrager',),
'vekselbedragere': ('vekselbedrager',),
'vekselbedrageren': ('vekselbedrager',),
'vekselbedragerer': ('vekselbedrager',),
'vekselbedragerne': ('vekselbedrager',),
'vekselbedrageri': ('vekselbedrageri',),
'vekselbedrageria': ('vekselbedrageri',),
'vekselbedrageriene': ('vekselbedrageri',),
'vekselbedragerier': ('vekselbedrageri',),
'vekselbedrageriet': ('vekselbedrageri',),
'vekselbruk': ('vekselbruk',),
'vekselbruka': ('vekselbruk',),
'vekselbruken': ('vekselbruk',),
'vekselbrukene': ('vekselbruk',),
'vekselbruker': ('vekselbruk',),
'vekselbruket': ('vekselbruk',),
'vekseler': ('vekseler',),
'vekseleren': ('vekseler',),
'vekselerene': ('vekseler',),
'vekselerer': ('vekseler',),
'vekselfalsk': ('vekselfalsk',),
'vekselfalsken': ('vekselfalsk',),
'vekselfalskene': ('vekselfalsk',),
'vekselfalsker': ('vekselfalsk',),
'vekselobligasjon': ('vekselobligasjon',),
'vekselobligasjonen': ('vekselobligasjon',),
'vekselobligasjonene': ('vekselobligasjon',),
'vekselobligasjoner': ('vekselobligasjon',),
'vekselobligasjonslån': ('vekselobligasjonslån',),
'vekselobligasjonslåna': ('vekselobligasjonslån',),
'vekselobligasjonslånene': ('vekselobligasjonslån',),
'vekselobligasjonslånet': ('vekselobligasjonslån',),
'vekselpanel': ('vekselpanel',),
'vekselpanela': ('vekselpanel',),
'vekselpanelene': ('vekselpanel',),
'vekselpaneler': ('vekselpanel',),
'vekselpanelet': ('vekselpanel',),
'vekselrytter': ('vekselrytter',),
'vekselryttere': ('vekselrytter',),
'vekselrytteren': ('vekselrytter',),
'vekselrytterer': ('vekselrytter',),
'vekselrytterne': ('vekselrytter',),
'vekselrytteri': ('vekselrytteri',),
'vekselrytteria': ('vekselrytteri',),
'vekselrytteriene': ('vekselrytteri',),
'vekselrytterier': ('vekselrytteri',),
'vekselrytteriet': ('vekselrytteri',),
'vekselsang': ('vekselsang',),
'vekselsangen': ('vekselsang',),
'vekselsangene': ('vekselsang',),
'vekselsanger': ('vekselsang',),
'vekselspill': ('vekselspill',),
'vekselspilla': ('vekselspill',),
'vekselspillene': ('vekselspill',),
'vekselspillet': ('vekselspill',),
'vekselstrøm': ('vekselstrøm',),
'vekselstrømmen': ('vekselstrøm',),
'vekselstrømmene': ('vekselstrøm',),
'vekselstrømmer': ('vekselstrøm',),
'vekselvirkning': ('vekselvirkning',),
'vekselvirkninga': ('vekselvirkning',),
'vekselvirkningen': ('vekselvirkning',),
'vekselvirkningene': ('vekselvirkning',),
'vekselvirkninger': ('vekselvirkning',),
'vekslepengene': ('vekslepenger',),
'vekslepenger': ('vekslepenger',),
'veksler': ('veksler',),
'vekslere': ('veksler',),
'veksleren': ('veksler',),
'vekslerer': ('veksler',),
'vekslerne': ('veksler',),
'veksling': ('veksling',),
'vekslinga': ('veksling',),
'vekslingen': ('veksling',),
'vekslingene': ('veksling',),
'vekslinger': ('veksling',),
'vekslingsautomat': ('vekslingsautomat',),
'vekslingsautomaten': ('vekslingsautomat',),
'vekslingsautomatene': ('vekslingsautomat',),
'vekslingsautomater': ('vekslingsautomat',),
'vekslingskontor': ('vekslingskontor',),
'vekslingskontora': ('vekslingskontor',),
'vekslingskontorene': ('vekslingskontor',),
'vekslingskontorer': ('vekslingskontor',),
'vekslingskontoret': ('vekslingskontor',),
'vekslingskurs': ('vekslingskurs',),
'vekslingskursen': ('vekslingskurs',),
'vekslingskursene': ('vekslingskurs',),
'vekslingskurser': ('vekslingskurs',),
'vekslingssida': ('vekslingsside',),
'vekslingsside': ('vekslingsside',),
'vekslingssiden': ('vekslingsside',),
'vekslingssidene': ('vekslingsside',),
'vekslingssider': ('vekslingsside',),
'vekslingssted': ('vekslingssted',),
'vekslingsstedene': ('vekslingssted',),
'vekslingssteder': ('vekslingssted',),
'vekslingsstedet': ('vekslingssted',),
'vekst': ('vekst',),
'veksten': ('vekst',),
'vekstene': ('vekst',),
'vekster': ('vekst',),
'vekstaksje': ('vekstaksje',),
'vekstaksjen': ('vekstaksje',),
'vekstaksjene': ('vekstaksje',),
'vekstaksjer': ('vekstaksje',),
'vekstbenk': ('vekstbenk',),
'vekstbenken': ('vekstbenk',),
'vekstbenkene': ('vekstbenk',),
'vekstbenker': ('vekstbenk',),
'vekstbetingelse': ('vekstbetingelse',),
'vekstbetingelsen': ('vekstbetingelse',),
'vekstbetingelsene': ('vekstbetingelse',),
'vekstbetingelser': ('vekstbetingelse',),
'vekstfaktor': ('vekstfaktor',),
'vekstfaktoren': ('vekstfaktor',),
'vekstfaktorene': ('vekstfaktor',),
'vekstfaktorer': ('vekstfaktor',),
'vekstforhold': ('vekstforhold',),
'vekstforholda': ('vekstforhold',),
'vekstforholdene': ('vekstforhold',),
'vekstforholdet': ('vekstforhold',),
'vekstgrunn': ('vekstgrunn',),
'vekstgrunnen': ('vekstgrunn',),
'vekstgrunnene': ('vekstgrunn',),
'vekstgrunner': ('vekstgrunn',),
'veksthastighet': ('veksthastighet',),
'veksthastigheta': ('veksthastighet',),
'veksthastigheten': ('veksthastighet',),
'veksthastighetene': ('veksthastighet',),
'veksthastigheter': ('veksthastighet',),
'veksthemning': ('veksthemning',),
'veksthemninga': ('veksthemning',),
'veksthemningen': ('veksthemning',),
'veksthemningene': ('veksthemning',),
'veksthemninger': ('veksthemning',),
'veksthormon': ('veksthormon',),
'veksthormona': ('veksthormon',),
'veksthormonene': ('veksthormon',),
'veksthormoner': ('veksthormon',),
'veksthormonet': ('veksthormon',),
'veksthus': ('veksthus',),
'veksthusa': ('veksthus',),
'veksthusene': ('veksthus',),
'veksthuset': ('veksthus',),
'vekstklima': ('vekstklima',),
'vekstklimaene': ('vekstklima',),
'vekstklimaer': ('vekstklima',),
'vekstklimaet': ('vekstklima',),
'vekstlag': ('vekstlag',),
'vekstlaga': ('vekstlag',),
'vekstlagene': ('vekstlag',),
'vekstlaget': ('vekstlag',),
'vekstområda': ('vekstområde',),
'vekstområde': ('vekstområde',),
'vekstområdene': ('vekstområde',),
'vekstområder': ('vekstområde',),
'vekstområdet': ('vekstområde',),
'vekstpunkt': ('vekstpunkt',),
'vekstpunkta': ('vekstpunkt',),
'vekstpunktene': ('vekstpunkt',),
'vekstpunkter': ('vekstpunkt',),
'vekstpunktet': ('vekstpunkt',),
'vekstrate': ('vekstrate',),
'vekstraten': ('vekstrate',),
'vekstratene': ('vekstrate',),
'vekstrater': ('vekstrate',),
'vekstsenter': ('vekstsenter',),
'vekstsenteret': ('vekstsenter',),
'vekstsentra': ('vekstsenter',),
'vekstsentre': ('vekstsenter',),
'vekstsentrene': ('vekstsenter',),
'vekstsentret': ('vekstsenter',),
'vekststoff': ('vekststoff',),
'vekststoffa': ('vekststoff',),
'vekststoffene': ('vekststoff',),
'vekststoffer': ('vekststoff',),
'vekststoffet': ('vekststoff',),
'veksttempi': ('veksttempo',),
'veksttempiene': ('veksttempo',),
'veksttempo': ('veksttempo',),
'veksttempoa': ('veksttempo',),
'veksttempoene': ('veksttempo',),
'veksttempoer': ('veksttempo',),
'veksttempoet': ('veksttempo',),
'veksttorv': ('veksttorv',),
'veksttorva': ('veksttorv',),
'veksttorven': ('veksttorv',),
'veksttorvene': ('veksttorv',),
'veksttorver': ('veksttorv',),
'veksttorvet': ('veksttorv',),
'vekstvilkår': ('vekstvilkår',),
'vekstvilkåra': ('vekstvilkår',),
'vekstvilkårene': ('vekstvilkår',),
'vekstvilkåret': ('vekstvilkår',),
'vekstøkonomi': ('vekstøkonomi',),
'vekstøkonomien': ('vekstøkonomi',),
'vekstøkonomiene': ('vekstøkonomi',),
'vekstøkonomier': ('vekstøkonomi',),
'vekt': ('vekt',),
'vekta': ('vekt',),
'vekten': ('vekt',),
'vektene': ('vekt',),
'vekter': ('vekt',),
'vektarm': ('vektarm',),
'vektarmen': ('vektarm',),
'vektarmene': ('vektarm',),
'vektarmer': ('vektarm',),
'vektenhet': ('vektenhet',),
'vektenheten': ('vektenhet',),
'vektenhetene': ('vektenhet',),
'vektenheter': ('vektenhet',),
'vekter': ('vekter',),
'vektere': ('vekter',),
'vekteren': ('vekter',),
'vekterer': ('vekter',),
'vekterne': ('vekter',),
'vekterrop': ('vekterrop',),
'vekterropa': ('vekterrop',),
'vekterropene': ('vekterrop',),
'vekterropet': ('vekterrop',),
'vekterrunde': ('vekterrunde',),
'vekterrunden': ('vekterrunde',),
'vekterrundene': ('vekterrunde',),
'vekterrunder': ('vekterrunde',),
'vektersang': ('vektersang',),
'vektersangen': ('vektersang',),
'vektersangene': ('vektersang',),
'vektersanger': ('vektersang',),
'vekterstav': ('vekterstav',),
'vekterstaven': ('vekterstav',),
'vekterstavene': ('vekterstav',),
'vekterstaver': ('vekterstav',),
'vektfordeling': ('vektfordeling',),
'vektfordelinga': ('vektfordeling',),
'vektfordelingen': ('vektfordeling',),
'vektfordelingene': ('vektfordeling',),
'vektfordelinger': ('vektfordeling',),
'vektgrensa': ('vektgrense',),
'vektgrense': ('vektgrense',),
'vektgrensen': ('vektgrense',),
'vektgrensene': ('vektgrense',),
'vektgrenser': ('vektgrense',),
'vektklassa': ('vektklasse',),
'vektklasse': ('vektklasse',),
'vektklassen': ('vektklasse',),
'vektklassene': ('vektklasse',),
'vektklasser': ('vektklasse',),
'vektløfter': ('vektløfter',),
'vektløftere': ('vektløfter',),
'vektløfteren': ('vektløfter',),
'vektløfterer': ('vektløfter',),
'vektløfterne': ('vektløfter',),
'vektløfting': ('vektløfting',),
'vektløftinga': ('vektløfting',),
'vektløftingen': ('vektløfting',),
'vektløftingene': ('vektløfting',),
'vektløftinger': ('vektløfting',),
'vektløshet': ('vektløshet',),
'vektløsheta': ('vektløshet',),
'vektløsheten': ('vektløshet',),
'vektløshetene': ('vektløshet',),
'vektløsheter': ('vektløshet',),
'vektløysa': ('vektløyse',),
'vektløyse': ('vektløyse',),
'vektløysen': ('vektløyse',),
'vektløysene': ('vektløyse',),
'vektløyser': ('vektløyse',),
'vektor': ('vektor',),
'vektoren': ('vektor',),
'vektorene': ('vektor',),
'vektorer': ('vektor',),
'vektorregning': ('vektorregning',),
'vektorregninga': ('vektorregning',),
'vektorregningen': ('vektorregning',),
'vektorregningene': ('vektorregning',),
'vektorregninger': ('vektorregning',),
'vektorrekning': ('vektorrekning',),
'vektorrekninga': ('vektorrekning',),
'vektorrekningen': ('vektorrekning',),
'vektorrekningene': ('vektorrekning',),
'vektorrekninger': ('vektorrekning',),
'vektprosent': ('vektprosent',),
'vektprosenten': ('vektprosent',),
'vektprosentene': ('vektprosent',),
'vektprosenter': ('vektprosent',),
'vektrør': ('vektrør',),
'vektrøra': ('vektrør',),
'vektrørene': ('vektrør',),
'vektrøret': ('vektrør',),
'vektskål': ('vektskål',),
'vektskåla': ('vektskål',),
'vektskålen': ('vektskål',),
'vektskålene': ('vektskål',),
'vektskåler': ('vektskål',),
'vektstang': ('vektstang',),
'vektstanga': ('vektstang',),
'vektstangen': ('vektstang',),
'vektstengene': ('vektstang',),
'vektstenger': ('vektstang',),
'vektsystem': ('vektsystem',),
'vektsystema': ('vektsystem',),
'vektsystemene': ('vektsystem',),
'vektsystemer': ('vektsystem',),
'vektsystemet': ('vektsystem',),
'vekttal': ('vekttal',),
'vekttala': ('vekttal',),
'vekttalene': ('vekttal',),
'vekttalet': ('vekttal',),
'vekttall': ('vekttall',),
'vekttalla': ('vekttall',),
'vekttallene': ('vekttall',),
'vekttallet': ('vekttall',),
'vekttap': ('vekttap',),
'vekttapa': ('vekttap',),
'vekttapene': ('vekttap',),
'vekttapet': ('vekttap',),
'vel': ('vel',),
'vela': ('vel',),
'velene': ('vel',),
'velet': ('vel',),
'vel': ('vel',),
'velar': ('velar',),
'velaren': ('velar',),
'velarene': ('velar',),
'velarer': ('velar',),
'velbefinnende': ('velbefinnende',),
'velbehag': ('velbehag',),
'velbehaga': ('velbehag',),
'velbehagene': ('velbehag',),
'velbehaget': ('velbehag',),
'velbårenhet': ('velbårenhet',),
'velbårenheta': ('velbårenhet',),
'velbårenheten': ('velbårenhet',),
'velbårenhetene': ('velbårenhet',),
'velbårenheter': ('velbårenhet',),
'velda': ('velde',),
'velde': ('velde',),
'veldene': ('velde',),
'velder': ('velde',),
'veldet': ('velde',),
'veldedighet': ('veldedighet',),
'veldedigheta': ('veldedighet',),
'veldedigheten': ('veldedighet',),
'veldedighetene': ('veldedighet',),
'veldedigheter': ('veldedighet',),
'veldedighetsforestilling': ('veldedighetsforestilling',),
'veldedighetsforestillinga': ('veldedighetsforestilling',),
'veldedighetsforestillingen': ('veldedighetsforestilling',),
'veldedighetsforestillingene': ('veldedighetsforestilling',),
'veldedighetsforestillinger': ('veldedighetsforestilling',),
'vela': ('vele',),
'vele': ('vele',),
'velene': ('vele',),
'veler': ('vele',),
'velet': ('vele',),
'velferd': ('velferd',),
'velferda': ('velferd',),
'velferden': ('velferd',),
'velferdene': ('velferd',),
'velferder': ('velferd',),
'velferdsbygg': ('velferdsbygg',),
'velferdsbygga': ('velferdsbygg',),
'velferdsbyggene': ('velferdsbygg',),
'velferdsbygget': ('velferdsbygg',),
'velferdsfravær': ('velferdsfravær',),
'velferdsfraværa': ('velferdsfravær',),
'velferdsfraværene': ('velferdsfravær',),
'velferdsfraværet': ('velferdsfravær',),
'velferdskontor': ('velferdskontor',),
'velferdskontora': ('velferdskontor',),
'velferdskontorene': ('velferdskontor',),
'velferdskontorer': ('velferdskontor',),
'velferdskontoret': ('velferdskontor',),
'velferdskort': ('velferdskort',),
'velferdskorta': ('velferdskort',),
'velferdskortene': ('velferdskort',),
'velferdskortet': ('velferdskort',),
'velferdsoffiser': ('velferdsoffiser',),
'velferdsoffiseren': ('velferdsoffiser',),
'velferdsoffiserene': ('velferdsoffiser',),
'velferdsoffiserer': ('velferdsoffiser',),
'velferdspermisjon': ('velferdspermisjon',),
'velferdspermisjonen': ('velferdspermisjon',),
'velferdspermisjonene': ('velferdspermisjon',),
'velferdspermisjoner': ('velferdspermisjon',),
'velferdssamfunn': ('velferdssamfunn',),
'velferdssamfunna': ('velferdssamfunn',),
'velferdssamfunnene': ('velferdssamfunn',),
'velferdssamfunnet': ('velferdssamfunn',),
'velferdssekretær': ('velferdssekretær',),
'velferdssekretæren': ('velferdssekretær',),
'velferdssekretærene': ('velferdssekretær',),
'velferdssekretærer': ('velferdssekretær',),
'velferdssenter': ('velferdssenter',),
'velferdssenteret': ('velferdssenter',),
'velferdssentra': ('velferdssenter',),
'velferdssentre': ('velferdssenter',),
'velferdssentrene': ('velferdssenter',),
'velferdssentret': ('velferdssenter',),
'velferdssentral': ('velferdssentral',),
'velferdssentralen': ('velferdssentral',),
'velferdssentralene': ('velferdssentral',),
'velferdssentraler': ('velferdssentral',),
'velferdsstat': ('velferdsstat',),
'velferdsstaten': ('velferdsstat',),
'velferdsstatene': ('velferdsstat',),
'velferdsstater': ('velferdsstat',),
'velferdstap': ('velferdstap',),
'velferdstapa': ('velferdstap',),
'velferdstapene': ('velferdstap',),
'velferdstapet': ('velferdstap',),
'velferdstiltak': ('velferdstiltak',),
'velferdstiltaka': ('velferdstiltak',),
'velferdstiltakene': ('velferdstiltak',),
'velferdstiltaket': ('velferdstiltak',),
'velferdstjeneste': ('velferdstjeneste',),
'velferdstjenesten': ('velferdstjeneste',),
'velferdstjenestene': ('velferdstjeneste',),
'velferdstjenester': ('velferdstjeneste',),
'velferdsutvalg': ('velferdsutvalg',),
'velferdsutvalga': ('velferdsutvalg',),
'velferdsutvalgene': ('velferdsutvalg',),
'velferdsutvalget': ('velferdsutvalg',),
'velforening': ('velforening',),
'velforeninga': ('velforening',),
'velforeningen': ('velforening',),
'velforeningene': ('velforening',),
'velforeninger': ('velforening',),
'velger': ('velger',),
'velgere': ('velger',),
'velgeren': ('velger',),
'velgerer': ('velger',),
'velgerne': ('velger',),
'velgerflertal': ('velgerflertal',),
'velgerflertala': ('velgerflertal',),
'velgerflertalene': ('velgerflertal',),
'velgerflertalet': ('velgerflertal',),
'velgerflertall': ('velgerflertall',),
'velgerflertalla': ('velgerflertall',),
'velgerflertallene': ('velgerflertall',),
'velgerflertallet': ('velgerflertall',),
'velgermasse': ('velgermasse',),
'velgermassen': ('velgermasse',),
'velgermassene': ('velgermasse',),
'velgermasser': ('velgermasse',),
'velgerunderlag': ('velgerunderlag',),
'velgerunderlaga': ('velgerunderlag',),
'velgerunderlagene': ('velgerunderlag',),
'velgerunderlaget': ('velgerunderlag',),
'velgjerning': ('velgjerning',),
'velgjerninga': ('velgjerning',),
'velgjerningen': ('velgjerning',),
'velgjerningene': ('velgjerning',),
'velgjerninger': ('velgjerning',),
'velgjørenhet': ('velgjørenhet',),
'velgjørenheta': ('velgjørenhet',),
'velgjørenheten': ('velgjørenhet',),
'velgjørenhetene': ('velgjørenhet',),
'velgjørenheter': ('velgjørenhet',),
'velgjørenhetsarbeid': ('velgjørenhetsarbeid',),
'velgjørenhetsarbeida': ('velgjørenhetsarbeid',),
'velgjørenhetsarbeidene': ('velgjørenhetsarbeid',),
'velgjørenhetsarbeider': ('velgjørenhetsarbeid',),
'velgjørenhetsarbeidet': ('velgjørenhetsarbeid',),
'velgjører': ('velgjører',),
'velgjørere': ('velgjører',),
'velgjøreren': ('velgjører',),
'velgjørerer': ('velgjører',),
'velgjørerne': ('velgjører',),
'velgående': ('velgående',),
'velin': ('velin',),
'velina': ('velin',),
'velinene': ('velin',),
'velinet': ('velin',),
'velinpapir': ('velinpapir',),
'velinpapira': ('velinpapir',),
'velinpapirene': ('velinpapir',),
'velinpapirer': ('velinpapir',),
'velinpapiret': ('velinpapir',),
'velinpergament': ('velinpergament',),
'velinpergamenta': ('velinpergament',),
'velinpergamentene': ('velinpergament',),
'velinpergamenter': ('velinpergament',),
'velinpergamentet': ('velinpergament',),
'veljunksjon': ('veljunksjon',),
'veljunksjonen': ('veljunksjon',),
'veljunksjonene': ('veljunksjon',),
'veljunksjoner': ('veljunksjon',),
'velklang': ('velklang',),
'velklangen': ('velklang',),
'velklangene': ('velklang',),
'velklanger': ('velklang',),
'velkommen': ('velkommen',),
'velkomst': ('velkomst',),
'velkomsten': ('velkomst',),
'velkomstene': ('velkomst',),
'velkomster': ('velkomst',),
'velkomstdrikk': ('velkomstdrikk',),
'velkomstdrikken': ('velkomstdrikk',),
'velkomstdrikkene': ('velkomstdrikk',),
'velkomstdrikker': ('velkomstdrikk',),
'velkomsthelsing': ('velkomsthelsing',),
'velkomsthelsinga': ('velkomsthelsing',),
'velkomsthelsingen': ('velkomsthelsing',),
'velkomsthelsingene': ('velkomsthelsing',),
'velkomsthelsinger': ('velkomsthelsing',),
'velkomsthilsen': ('velkomsthilsen',),
'velkomsthilsenen': ('velkomsthilsen',),
'velkomsthilsenene': ('velkomsthilsen',),
'velkomsthilsener': ('velkomsthilsen',),
'velkomsttale': ('velkomsttale',),
'velkomsttalen': ('velkomsttale',),
'velkomsttalene': ('velkomsttale',),
'velkomsttaler': ('velkomsttale',),
'vell': ('vell',),
'vella': ('vell',),
'vellene': ('vell',),
'vellet': ('vell',),
'vell': ('vell',),
'vella': ('vell',),
'vellene': ('vell',),
'vellet': ('vell',),
'vellevnet': ('vellevnet',),
'vellforening': ('vellforening',),
'vellforeninga': ('vellforening',),
'vellforeningen': ('vellforening',),
'vellforeningene': ('vellforening',),
'vellforeninger': ('vellforening',),
'velling': ('velling',),
'vellinga': ('velling',),
'vellingen': ('velling',),
'vellingene': ('velling',),
'vellinger': ('velling',),
'vellukt': ('vellukt',),
'vellukta': ('vellukt',),
'vellukten': ('vellukt',),
'velluktene': ('vellukt',),
'vellukter': ('vellukt',),
'vellyd': ('vellyd',),
'vellyden': ('vellyd',),
'vellydene': ('vellyd',),
'vellyder': ('vellyd',),
'vellyst': ('vellyst',),
'vellysta': ('vellyst',),
'vellysten': ('vellyst',),
'vellystene': ('vellyst',),
'vellyster': ('vellyst',),
'vellystfølelse': ('vellystfølelse',),
'vellystfølelsen': ('vellystfølelse',),
'vellystfølelsene': ('vellystfølelse',),
'vellystfølelser': ('vellystfølelse',),
'vellysting': ('vellysting',),
'vellystingen': ('vellysting',),
'vellystingene': ('vellysting',),
'vellystinger': ('vellysting',),
'velmakt': ('velmakt',),
'velmakta': ('velmakt',),
'velmakten': ('velmakt',),
'velmaktene': ('velmakt',),
'velmakter': ('velmakt',),
'velmaktsdagene': ('velmaktsdager',),
'velmaktsdager': ('velmaktsdager',),
'velmaktstid': ('velmaktstid',),
'velmaktstida': ('velmaktstid',),
'velmaktstiden': ('velmaktstid',),
'velmaktstidene': ('velmaktstid',),
'velmaktstider': ('velmaktstid',),
'velodrom': ('velodrom',),
'velodromen': ('velodrom',),
'velodromene': ('velodrom',),
'velodromer': ('velodrom',),
'velosiped': ('velosiped',),
'velosipeden': ('velosiped',),
'velosipedene': ('velosiped',),
'velosipeder': ('velosiped',),
'velsignelse': ('velsignelse',),
'velsignelsen': ('velsignelse',),
'velsignelsene': ('velsignelse',),
'velsignelser': ('velsignelse',),
'velsk': ('velsk',),
'velsken': ('velsk',),
'velskene': ('velsk',),
'velsker': ('velsk',),
'velskbind': ('velskbind',),
'velskbinda': ('velskbind',),
'velskbindene': ('velskbind',),
'velskbindet': ('velskbind',),
'velstand': ('velstand',),
'velstanden': ('velstand',),
'velstandene': ('velstand',),
'velstander': ('velstand',),
'velstandsfamilie': ('velstandsfamilie',),
'velstandsfamilien': ('velstandsfamilie',),
'velstandsfamiliene': ('velstandsfamilie',),
'velstandsfamilier': ('velstandsfamilie',),
'velstandsfolk': ('velstandsfolk',),
'velstandsfolka': ('velstandsfolk',),
'velstandsfolkene': ('velstandsfolk',),
'velstandsfolket': ('velstandsfolk',),
'velstandssamfunn': ('velstandssamfunn',),
'velstandssamfunna': ('velstandssamfunn',),
'velstandssamfunnene': ('velstandssamfunn',),
'velstandssamfunnet': ('velstandssamfunn',),
'velt': ('velt',),
'velten': ('velt',),
'veltene': ('velt',),
'velter': ('velt',),
'veltalenhet': ('veltalenhet',),
'veltalenheta': ('veltalenhet',),
'veltalenheten': ('veltalenhet',),
'veltalenhetene': ('veltalenhet',),
'veltalenheter': ('veltalenhet',),
'velta': ('velte',),
'velte': ('velte',),
'velten': ('velte',),
'veltene': ('velte',),
'velter': ('velte',),
'veltefjel': ('veltefjel',),
'veltefjela': ('veltefjel',),
'veltefjelen': ('veltefjel',),
'veltefjelene': ('veltefjel',),
'veltefjeler': ('veltefjel',),
'veltefjøl': ('veltefjøl',),
'veltefjøla': ('veltefjøl',),
'veltefjølen': ('veltefjøl',),
'veltefjølene': ('veltefjøl',),
'veltefjøler': ('veltefjøl',),
'velteplass': ('velteplass',),
'velteplassen': ('velteplass',),
'velteplassene': ('velteplass',),
'velteplasser': ('velteplass',),
'vela': ('velum',),
'velaene': ('velum',),
'velum': ('velum',),
'velumet': ('velum',),
'velur': ('velur',),
'velura': ('velur',),
'veluren': ('velur',),
'velurene': ('velur',),
'velurer': ('velur',),
'veluret': ('velur',),
'velvilje': ('velvilje',),
'velviljen': ('velvilje',),
'velviljene': ('velvilje',),
'velviljer': ('velvilje',),
'velværa': ('velvære',),
'velvære': ('velvære',),
'velværene': ('velvære',),
'velværer': ('velvære',),
'velværet': ('velvære',),
'velynder': ('velynder',),
'velyndere': ('velynder',),
'velynderen': ('velynder',),
'velynderer': ('velynder',),
'velynderne': ('velynder',),
'vemling': ('vemling',),
'vemlingen': ('vemling',),
'vemlingene': ('vemling',),
'vemlinger': ('vemling',),
'vemmelse': ('vemmelse',),
'vemmelsen': ('vemmelse',),
'vemmelsene': ('vemmelse',),
'vemmelser': ('vemmelse',),
'vemod': ('vemod',),
'vemoda': ('vemod',),
'vemodene': ('vemod',),
'vemodet': ('vemod',),
'vemodstanke': ('vemodstanke',),
'vemodstanken': ('vemodstanke',),
'vemodstankene': ('vemodstanke',),
'vemodstanker': ('vemodstanke',),
'venda': ('vende',),
'vende': ('vende',),
'venden': ('vende',),
'vendene': ('vende',),
'vender': ('vende',),
'vendehake': ('vendehake',),
'vendehaken': ('vendehake',),
'vendehakene': ('vendehake',),
'vendehaker': ('vendehake',),
'vendekrets': ('vendekrets',),
'vendekretsen': ('vendekrets',),
'vendekretsene': ('vendekrets',),
'vendekretser': ('vendekrets',),
'vendelrot': ('vendelrot',),
'vendelrota': ('vendelrot',),
'vendelroten': ('vendelrot',),
'vendelrotene': ('vendelrot',),
'vendemål': ('vendemål',),
'vendemåla': ('vendemål',),
'vendemålene': ('vendemål',),
'vendemålet': ('vendemål',),
'vendepunkt': ('vendepunkt',),
'vendepunkta': ('vendepunkt',),
'vendepunktene': ('vendepunkt',),
'vendepunkter': ('vendepunkt',),
'vendepunktet': ('vendepunkt',),
'vender': ('vender',),
'vendere': ('vender',),
'venderen': ('vender',),
'venderer': ('vender',),
'venderne': ('vender',),
'vender': ('vender',),
'vendere': ('vender',),
'venderen': ('vender',),
'venderer': ('vender',),
'venderne': ('vender',),
'vendereis': ('vendereis',),
'vendereisa': ('vendereis',),
'vendereisen': ('vendereis',),
'vendereisene': ('vendereis',),
'vendereiser': ('vendereis',),
'vendereisa': ('vendereise',),
'vendereise': ('vendereise',),
'vendereisen': ('vendereise',),
'vendereisene': ('vendereise',),
'vendereiser': ('vendereise',),
'vendesirkel': ('vendesirkel',),
'vendesirkelen': ('vendesirkel',),
'vendesirklene': ('vendesirkel',),
'vendesirkler': ('vendesirkel',),
'vendetta': ('vendetta',),
'vendettaen': ('vendetta',),
'vendettaene': ('vendetta',),
'vendettaer': ('vendetta',),
'vending': ('vending',),
'vendinga': ('vending',),
'vendingen': ('vending',),
'vendingene': ('vending',),
'vendinger': ('vending',),
'vene': ('vene',),
'venen': ('vene',),
'venene': ('vene',),
'vener': ('vene',),
'venerasjon': ('venerasjon',),
'venerasjonen': ('venerasjon',),
'venerasjonene': ('venerasjon',),
'venerasjoner': ('venerasjon',),
'venetianer': ('venetianer',),
'venetianere': ('venetianer',),
'venetianeren': ('venetianer',),
'venetianerer': ('venetianer',),
'venetianerne': ('venetianer',),
'venezuelaner': ('venezuelaner',),
'venezuelanere': ('venezuelaner',),
'venezuelaneren': ('venezuelaner',),
'venezuelanerer': ('venezuelaner',),
'venezuelanerne': ('venezuelaner',),
'veng': ('veng',),
'vengen': ('veng',),
'vengene': ('veng',),
'venger': ('veng',),
'veng': ('veng',),
'vengen': ('veng',),
'vengene': ('veng',),
'venger': ('veng',),
'veng': ('veng',),
'vengen': ('veng',),
'vengene': ('veng',),
'venger': ('veng',),
'vengbåt': ('vengbåt',),
'vengbåten': ('vengbåt',),
'vengbåtene': ('vengbåt',),
'vengbåter': ('vengbåt',),
'vengbåt': ('vengbåt',),
'vengbåten': ('vengbåt',),
'vengbåtene': ('vengbåt',),
'vengbåter': ('vengbåt',),
'vengebein': ('vengebein',),
'vengebeina': ('vengebein',),
'vengebeinene': ('vengebein',),
'vengebeinet': ('vengebein',),
'vengebein': ('vengebein',),
'vengebeina': ('vengebein',),
'vengebeinene': ('vengebein',),
'vengebeinet': ('vengebein',),
'vengeben': ('vengeben',),
'vengebena': ('vengeben',),
'vengebenene': ('vengeben',),
'vengebenet': ('vengeben',),
'vengeben': ('vengeben',),
'vengebena': ('vengeben',),
'vengebenene': ('vengeben',),
'vengebenet': ('vengeben',),
'vengebåt': ('vengebåt',),
'vengebåten': ('vengebåt',),
'vengebåtene': ('vengebåt',),
'vengebåter': ('vengebåt',),
'vengebåt': ('vengebåt',),
'vengebåten': ('vengebåt',),
'vengebåtene': ('vengebåt',),
'vengebåter': ('vengebåt',),
'vengefang': ('vengefang',),
'vengefanga': ('vengefang',),
'vengefangene': ('vengefang',),
'vengefanget': ('vengefang',),
'vengefang': ('vengefang',),
'vengefanga': ('vengefang',),
'vengefangene': ('vengefang',),
'vengefanget': ('vengefang',),
'vengefrukt': ('vengefrukt',),
'vengefrukta': ('vengefrukt',),
'vengefrukten': ('vengefrukt',),
'vengefruktene': ('vengefrukt',),
'vengefrukter': ('vengefrukt',),
'vengefrukt': ('vengefrukt',),
'vengefrukta': ('vengefrukt',),
'vengefrukten': ('vengefrukt',),
'vengefruktene': ('vengefrukt',),
'vengefrukter': ('vengefrukt',),
'vengehest': ('vengehest',),
'vengehesten': ('vengehest',),
'vengehestene': ('vengehest',),
'vengehester': ('vengehest',),
'vengehest': ('vengehest',),
'vengehesten': ('vengehest',),
'vengehestene': ('vengehest',),
'vengehester': ('vengehest',),
'vengeklaff': ('vengeklaff',),
'vengeklaffen': ('vengeklaff',),
'vengeklaffene': ('vengeklaff',),
'vengeklaffer': ('vengeklaff',),
'vengeklaff': ('vengeklaff',),
'vengeklaffen': ('vengeklaff',),
'vengeklaffene': ('vengeklaff',),
'vengeklaffer': ('vengeklaff',),
'vengemerka': ('vengemerke',),
'vengemerke': ('vengemerke',),
'vengemerkene': ('vengemerke',),
'vengemerker': ('vengemerke',),
'vengemerket': ('vengemerke',),
'vengemutrene': ('vengemutter',),
'vengemutrer': ('vengemutter',),
'vengemutter': ('vengemutter',),
'vengemuttere': ('vengemutter',),
'vengemutteren': ('vengemutter',),
'vengemutterer': ('vengemutter',),
'vengemutterne': ('vengemutter',),
'vengemutrene': ('vengemutter',),
'vengemutrer': ('vengemutter',),
'vengemutter': ('vengemutter',),
'vengemuttere': ('vengemutter',),
'vengemutteren': ('vengemutter',),
'vengemutterer': ('vengemutter',),
'vengemutterne': ('vengemutter',),
'vengepar': ('vengepar',),
'vengepara': ('vengepar',),
'vengeparene': ('vengepar',),
'vengeparet': ('vengepar',),
'vengepar': ('vengepar',),
'vengepara': ('vengepar',),
'vengeparene': ('vengepar',),
'vengeparet': ('vengepar',),
'vengeskrue': ('vengeskrue',),
'vengeskruen': ('vengeskrue',),
'vengeskruene': ('vengeskrue',),
'vengeskruer': ('vengeskrue',),
'vengeskrue': ('vengeskrue',),
'vengeskruen': ('vengeskrue',),
'vengeskruene': ('vengeskrue',),
'vengeskruer': ('vengeskrue',),
'vengeskruve': ('vengeskruve',),
'vengeskruven': ('vengeskruve',),
'vengeskruvene': ('vengeskruve',),
'vengeskruver': ('vengeskruve',),
'vengeskruve': ('vengeskruve',),
'vengeskruven': ('vengeskruve',),
'vengeskruvene': ('vengeskruve',),
'vengeskruver': ('vengeskruve',),
'vengeskutt': ('vengeskutt',),
'vengeskutta': ('vengeskutt',),
'vengeskuttene': ('vengeskutt',),
'vengeskuttet': ('vengeskutt',),
'vengeslag': ('vengeslag',),
'vengeslaga': ('vengeslag',),
'vengeslagene': ('vengeslag',),
'vengeslaget': ('vengeslag',),
'vengeslag': ('vengeslag',),
'vengeslaga': ('vengeslag',),
'vengeslagene': ('vengeslag',),
'vengeslaget': ('vengeslag',),
'vengespenn': ('vengespenn',),
'vengespenna': ('vengespenn',),
'vengespennene': ('vengespenn',),
'vengespennet': ('vengespenn',),
'vengespenn': ('vengespenn',),
'vengespenna': ('vengespenn',),
'vengespennene': ('vengespenn',),
'vengespennet': ('vengespenn',),
'vengesus': ('vengesus',),
'vengesusa': ('vengesus',),
'vengesusen': ('vengesus',),
'vengesusene': ('vengesus',),
'vengesuset': ('vengesus',),
'vengesus': ('vengesus',),
'vengesusa': ('vengesus',),
'vengesusen': ('vengesus',),
'vengesusene': ('vengesus',),
'vengesuset': ('vengesus',),
'venn': ('venn',),
'vennen': ('venn',),
'vennene': ('venn',),
'venner': ('venn',),
'venneflokk': ('venneflokk',),
'venneflokken': ('venneflokk',),
'venneflokkene': ('venneflokk',),
'venneflokker': ('venneflokk',),
'vennegava': ('vennegave',),
'vennegave': ('vennegave',),
'vennegaven': ('vennegave',),
'vennegavene': ('vennegave',),
'vennegaver': ('vennegave',),
'vennekrets': ('vennekrets',),
'vennekretsen': ('vennekrets',),
'vennekretsene': ('vennekrets',),
'vennekretser': ('vennekrets',),
'venneråd': ('venneråd',),
'venneråda': ('venneråd',),
'vennerådene': ('venneråd',),
'vennerådet': ('venneråd',),
'vennesamfunn': ('vennesamfunn',),
'vennesamfunna': ('vennesamfunn',),
'vennesamfunnene': ('vennesamfunn',),
'vennesamfunnet': ('vennesamfunn',),
'vennetjeneste': ('vennetjeneste',),
'vennetjenesten': ('vennetjeneste',),
'vennetjenestene': ('vennetjeneste',),
'vennetjenester': ('vennetjeneste',),
'vennevis': ('vennevis',),
'vennevisa': ('vennevis',),
'vennevisen': ('vennevis',),
'vennevisene': ('vennevis',),
'venneviset': ('vennevis',),
'venninna': ('venninne',),
'venninne': ('venninne',),
'venninnen': ('venninne',),
'venninnene': ('venninne',),
'venninner': ('venninne',),
'venninneklubb': ('venninneklubb',),
'venninneklubben': ('venninneklubb',),
'venninneklubbene': ('venninneklubb',),
'venninneklubber': ('venninneklubb',),
'venninneselskap': ('venninneselskap',),
'venninneselskapa': ('venninneselskap',),
'venninneselskapene': ('venninneselskap',),
'venninneselskaper': ('venninneselskap',),
'venninneselskapet': ('venninneselskap',),
'vennlighet': ('vennlighet',),
'vennligheta': ('vennlighet',),
'vennligheten': ('vennlighet',),
'vennlighetene': ('vennlighet',),
'vennligheter': ('vennlighet',),
'vennskap': ('vennskap',),
'vennskapa': ('vennskap',),
'vennskapen': ('vennskap',),
'vennskapene': ('vennskap',),
'vennskaper': ('vennskap',),
'vennskapet': ('vennskap',),
'vennskapsband': ('vennskapsband',),
'vennskapsbanda': ('vennskapsband',),
'vennskapsbandene': ('vennskapsband',),
'vennskapsbandet': ('vennskapsband',),
'vennskapsbesøk': ('vennskapsbesøk',),
'vennskapsbesøka': ('vennskapsbesøk',),
'vennskapsbesøkene': ('vennskapsbesøk',),
'vennskapsbesøket': ('vennskapsbesøk',),
'vennskapsbrott': ('vennskapsbrott',),
'vennskapsbrotta': ('vennskapsbrott',),
'vennskapsbrottene': ('vennskapsbrott',),
'vennskapsbrottet': ('vennskapsbrott',),
'vennskapsbrudd': ('vennskapsbrudd',),
'vennskapsbrudda': ('vennskapsbrudd',),
'vennskapsbruddene': ('vennskapsbrudd',),
'vennskapsbruddet': ('vennskapsbrudd',),
'vennskapsby': ('vennskapsby',),
'vennskapsbyen': ('vennskapsby',),
'vennskapsbyene': ('vennskapsby',),
'vennskapsbyer': ('vennskapsby',),
'vennskapsbånd': ('vennskapsbånd',),
'vennskapsbånda': ('vennskapsbånd',),
'vennskapsbåndene': ('vennskapsbånd',),
'vennskapsbåndet': ('vennskapsbånd',),
'vennskapsforhold': ('vennskapsforhold',),
'vennskapsforholda': ('vennskapsforhold',),
'vennskapsforholdene': ('vennskapsforhold',),
'vennskapsforholdet': ('vennskapsforhold',),
'vennskapskamp': ('vennskapskamp',),
'vennskapskampen': ('vennskapskamp',),
'vennskapskampene': ('vennskapskamp',),
'vennskapskamper': ('vennskapskamp',),
'vennskapskommune': ('vennskapskommune',),
'vennskapskommunen': ('vennskapskommune',),
'vennskapskommunene': ('vennskapskommune',),
'vennskapskommuner': ('vennskapskommune',),
'vennskapspakt': ('vennskapspakt',),
'vennskapspakta': ('vennskapspakt',),
'vennskapspakten': ('vennskapspakt',),
'vennskapspaktene': ('vennskapspakt',),
'vennskapspakter': ('vennskapspakt',),
'vennskapstraktat': ('vennskapstraktat',),
'vennskapstraktaten': ('vennskapstraktat',),
'vennskapstraktatene': ('vennskapstraktat',),
'vennskapstraktater': ('vennskapstraktat',),
'venstre': ('venstre',),
'venstrearm': ('venstrearm',),
'venstrearmen': ('venstrearm',),
'venstrearmene': ('venstrearm',),
'venstrearmer': ('venstrearm',),
'venstreavis': ('venstreavis',),
'venstreavisa': ('venstreavis',),
'venstreavisen': ('venstreavis',),
'venstreavisene': ('venstreavis',),
'venstreaviser': ('venstreavis',),
'venstrebein': ('venstrebein',),
'venstrebeina': ('venstrebein',),
'venstrebeinene': ('venstrebein',),
'venstrebeinet': ('venstrebein',),
'venstreben': ('venstreben',),
'venstrebena': ('venstreben',),
'venstrebenene': ('venstreben',),
'venstrebenet': ('venstreben',),
'venstredreiing': ('venstredreiing',),
'venstredreiinga': ('venstredreiing',),
'venstredreiingen': ('venstredreiing',),
'venstredreiingene': ('venstredreiing',),
'venstredreiinger': ('venstredreiing',),
'venstredreining': ('venstredreining',),
'venstredreininga': ('venstredreining',),
'venstredreiningen': ('venstredreining',),
'venstredreiningene': ('venstredreining',),
'venstredreininger': ('venstredreining',),
'venstreekstremist': ('venstreekstremist',),
'venstreekstremisten': ('venstreekstremist',),
'venstreekstremistene': ('venstreekstremist',),
'venstreekstremister': ('venstreekstremist',),
'venstrefløy': ('venstrefløy',),
'venstrefløya': ('venstrefløy',),
'venstrefløyen': ('venstrefløy',),
'venstrefløyene': ('venstrefløy',),
'venstrefløyer': ('venstrefløy',),
'venstrehandsarbeid': ('venstrehandsarbeid',),
'venstrehandsarbeida': ('venstrehandsarbeid',),
'venstrehandsarbeidene': ('venstrehandsarbeid',),
'venstrehandsarbeider': ('venstrehandsarbeid',),
'venstrehandsarbeidet': ('venstrehandsarbeid',),
'venstrehåndsarbeid': ('venstrehåndsarbeid',),
'venstrehåndsarbeida': ('venstrehåndsarbeid',),
'venstrehåndsarbeidene': ('venstrehåndsarbeid',),
'venstrehåndsarbeider': ('venstrehåndsarbeid',),
'venstrehåndsarbeidet': ('venstrehåndsarbeid',),
'venstrekjøring': ('venstrekjøring',),
'venstrekjøringa': ('venstrekjøring',),
'venstrekjøringen': ('venstrekjøring',),
'venstrekjøringene': ('venstrekjøring',),
'venstrekjøringer': ('venstrekjøring',),
'venstrekvinna': ('venstrekvinne',),
'venstrekvinne': ('venstrekvinne',),
'venstrekvinnen': ('venstrekvinne',),
'venstrekvinnene': ('venstrekvinne',),
'venstrekvinner': ('venstrekvinne',),
'venstremann': ('venstremann',),
'venstremannen': ('venstremann',),
'venstremenn': ('venstremann',),
'venstremennene': ('venstremann',),
'venstreparti': ('venstreparti',),
'venstrepartia': ('venstreparti',),
'venstrepartiene': ('venstreparti',),
'venstrepartier': ('venstreparti',),
'venstrepartiet': ('venstreparti',),
'venstresida': ('venstreside',),
'venstreside': ('venstreside',),
'venstresiden': ('venstreside',),
'venstresidene': ('venstreside',),
'venstresider': ('venstreside',),
'venstresosialist': ('venstresosialist',),
'venstresosialisten': ('venstresosialist',),
'venstresosialistene': ('venstresosialist',),
'venstresosialister': ('venstresosialist',),
'venstretrafikk': ('venstretrafikk',),
'venstretrafikken': ('venstretrafikk',),
'venstretrafikkene': ('venstretrafikk',),
'venstretrafikker': ('venstretrafikk',),
'venstreving': ('venstreving',),
'venstrevingen': ('venstreving',),
'venstrevingene': ('venstreving',),
'venstrevinger': ('venstreving',),
'vente': ('vente',),
'ventehall': ('ventehall',),
'ventehallen': ('ventehall',),
'ventehallene': ('ventehall',),
'ventehaller': ('ventehall',),
'venteklær': ('venteklær',),
'venteklærne': ('venteklær',),
'ventelista': ('venteliste',),
'venteliste': ('venteliste',),
'ventelisten': ('venteliste',),
'ventelistene': ('venteliste',),
'ventelister': ('venteliste',),
'ventepengene': ('ventepenger',),
'ventepenger': ('ventepenger',),
'venterom': ('venterom',),
'venteromma': ('venterom',),
'venterommene': ('venterom',),
'venterommet': ('venterom',),
'ventetid': ('ventetid',),
'ventetida': ('ventetid',),
'ventetiden': ('ventetid',),
'ventetidene': ('ventetid',),
'ventetider': ('ventetid',),
'venteværelsa': ('venteværelse',),
'venteværelse': ('venteværelse',),
'venteværelsene': ('venteværelse',),
'venteværelser': ('venteværelse',),
'venteværelset': ('venteværelse',),
'ventil': ('ventil',),
'ventilen': ('ventil',),
'ventilene': ('ventil',),
'ventiler': ('ventil',),
'ventilasjon': ('ventilasjon',),
'ventilasjonen': ('ventilasjon',),
'ventilasjonene': ('ventilasjon',),
'ventilasjoner': ('ventilasjon',),
'ventilasjonsanlegg': ('ventilasjonsanlegg',),
'ventilasjonsanlegga': ('ventilasjonsanlegg',),
'ventilasjonsanleggene': ('ventilasjonsanlegg',),
'ventilasjonsanlegget': ('ventilasjonsanlegg',),
'ventilator': ('ventilator',),
'ventilatoren': ('ventilator',),
'ventilatorene': ('ventilator',),
'ventilatorer': ('ventilator',),
'ventilbasun': ('ventilbasun',),
'ventilbasunen': ('ventilbasun',),
'ventilbasunene': ('ventilbasun',),
'ventilbasuner': ('ventilbasun',),
'ventilfjær': ('ventilfjær',),
'ventilfjæra': ('ventilfjær',),
'ventilfjæren': ('ventilfjær',),
'ventilfjærene': ('ventilfjær',),
'ventilfjærer': ('ventilfjær',),
'ventilfjør': ('ventilfjør',),
'ventilfjøra': ('ventilfjør',),
'ventilfjøren': ('ventilfjør',),
'ventilfjørene': ('ventilfjør',),
'ventilfjører': ('ventilfjør',),
'ventilgummi': ('ventilgummi',),
'ventilgummien': ('ventilgummi',),
'ventilgummiene': ('ventilgummi',),
'ventilgummier': ('ventilgummi',),
'ventilklaff': ('ventilklaff',),
'ventilklaffen': ('ventilklaff',),
'ventilklaffene': ('ventilklaff',),
'ventilklaffer': ('ventilklaff',),
'ventilslange': ('ventilslange',),
'ventilslangen': ('ventilslange',),
'ventilslangene': ('ventilslange',),
'ventilslanger': ('ventilslange',),
'ventiltre': ('ventiltre',),
'ventiltrea': ('ventiltre',),
'ventiltreet': ('ventiltre',),
'ventiltrær': ('ventiltre',),
'ventiltrærne': ('ventiltre',),
'ventrikkel': ('ventrikkel',),
'ventrikkelen': ('ventrikkel',),
'ventriklene': ('ventrikkel',),
'ventrikler': ('ventrikkel',),
'ventrilokvist': ('ventrilokvist',),
'ventrilokvisten': ('ventrilokvist',),
'ventrilokvistene': ('ventrilokvist',),
'ventrilokvister': ('ventrilokvist',),
'venusberg': ('venusberg',),
'venusberga': ('venusberg',),
'venusbergene': ('venusberg',),
'venusberget': ('venusberg',),
'venushår': ('venushår',),
'venushåra': ('venushår',),
'venushåren': ('venushår',),
'venushårene': ('venushår',),
'venushårer': ('venushår',),
'venushåret': ('venushår',),
'venusmål': ('venusmål',),
'venusmåla': ('venusmål',),
'venusmålene': ('venusmål',),
'venusmålet': ('venusmål',),
'veps': ('veps',),
'vepsen': ('veps',),
'vepsene': ('veps',),
'vepser': ('veps',),
'vepsebol': ('vepsebol',),
'vepsebola': ('vepsebol',),
'vepsebolene': ('vepsebol',),
'vepsebolet': ('vepsebol',),
'vepsestikk': ('vepsestikk',),
'vepsestikka': ('vepsestikk',),
'vepsestikkene': ('vepsestikk',),
'vepsestikket': ('vepsestikk',),
'vepsetalja': ('vepsetalje',),
'vepsetalje': ('vepsetalje',),
'vepsetaljen': ('vepsetalje',),
'vepsetaljene': ('vepsetalje',),
'vepsetaljer': ('vepsetalje',),
'veranda': ('veranda',),
'verandaen': ('veranda',),
'verandaene': ('veranda',),
'verandaer': ('veranda',),
'verandadør': ('verandadør',),
'verandadøra': ('verandadør',),
'verandadøren': ('verandadør',),
'verandadørene': ('verandadør',),
'verandadører': ('verandadør',),
'verandakassa': ('verandakasse',),
'verandakasse': ('verandakasse',),
'verandakassen': ('verandakasse',),
'verandakassene': ('verandakasse',),
'verandakasser': ('verandakasse',),
'verandatrapp': ('verandatrapp',),
'verandatrappa': ('verandatrapp',),
'verandatrappen': ('verandatrapp',),
'verandatrappene': ('verandatrapp',),
'verandatrapper': ('verandatrapp',),
'verb': ('verb',),
'verba': ('verb',),
'verbene': ('verb',),
'verber': ('verb',),
'verbet': ('verb',),
'verbal': ('verbal',),
'verbala': ('verbal',),
'verbalene': ('verbal',),
'verbaler': ('verbal',),
'verbalet': ('verbal',),
'verbalbøying': ('verbalbøying',),
'verbalbøyinga': ('verbalbøying',),
'verbalbøyingen': ('verbalbøying',),
'verbalbøyingene': ('verbalbøying',),
'verbalbøyinger': ('verbalbøying',),
'verbalbøyning': ('verbalbøyning',),
'verbalbøyninga': ('verbalbøyning',),
'verbalbøyningen': ('verbalbøyning',),
'verbalbøyningene': ('verbalbøyning',),
'verbalbøyninger': ('verbalbøyning',),
'verbalfleksjon': ('verbalfleksjon',),
'verbalfleksjonen': ('verbalfleksjon',),
'verbalfleksjonene': ('verbalfleksjon',),
'verbalfleksjoner': ('verbalfleksjon',),
'verbalform': ('verbalform',),
'verbalforma': ('verbalform',),
'verbalformen': ('verbalform',),
'verbalformene': ('verbalform',),
'verbalformer': ('verbalform',),
'verbalisme': ('verbalisme',),
'verbalismen': ('verbalisme',),
'verbalismene': ('verbalisme',),
'verbalismer': ('verbalisme',),
'verbalitet': ('verbalitet',),
'verbaliteten': ('verbalitet',),
'verbalitetene': ('verbalitet',),
'verbaliteter': ('verbalitet',),
'verbalklassa': ('verbalklasse',),
'verbalklasse': ('verbalklasse',),
'verbalklassen': ('verbalklasse',),
'verbalklassene': ('verbalklasse',),
'verbalklasser': ('verbalklasse',),
'verballedd': ('verballedd',),
'verballedda': ('verballedd',),
'verballeddene': ('verballedd',),
'verballeddet': ('verballedd',),
'verbalnote': ('verbalnote',),
'verbalnoten': ('verbalnote',),
'verbalnotene': ('verbalnote',),
'verbalnoter': ('verbalnote',),
'verbalpartikkel': ('verbalpartikkel',),
'verbalpartikkelen': ('verbalpartikkel',),
'verbalpartiklene': ('verbalpartikkel',),
'verbalpartikler': ('verbalpartikkel',),
'verbalsubstantiv': ('verbalsubstantiv',),
'verbalsubstantiva': ('verbalsubstantiv',),
'verbalsubstantivene': ('verbalsubstantiv',),
'verbalsubstantiver': ('verbalsubstantiv',),
'verbalsubstantivet': ('verbalsubstantiv',),
'verba': ('verbum',),
'verbene': ('verbum',),
'verber': ('verbum',),
'verbet': ('verbum',),
'verbum': ('verbum',),
'verbumet': ('verbum',),
'verd': ('verd',),
'verden': ('verd',),
'verdene': ('verd',),
'verder': ('verd',),
'verd': ('verd',),
'verda': ('verd',),
'verdene': ('verd',),
'verdet': ('verd',),
'verd': ('verd',),
'verda': ('verd',),
'verden': ('verd',),
'verdene': ('verd',),
'verder': ('verd',),
'verdauke': ('verdauke',),
'verdauken': ('verdauke',),
'verdaukene': ('verdauke',),
'verdauker': ('verdauke',),
'verden': ('verden',),
'verdenen': ('verden',),
'verdenene': ('verden',),
'verdener': ('verden',),
'verdensalt': ('verdensalt',),
'verdensalta': ('verdensalt',),
'verdensaltene': ('verdensalt',),
'verdensaltet': ('verdensalt',),
'verdensanskuelse': ('verdensanskuelse',),
'verdensanskuelsen': ('verdensanskuelse',),
'verdensanskuelsene': ('verdensanskuelse',),
'verdensanskuelser': ('verdensanskuelse',),
'verdensatlas': ('verdensatlas',),
'verdensatlasa': ('verdensatlas',),
'verdensatlasene': ('verdensatlas',),
'verdensatlaser': ('verdensatlas',),
'verdensatlaset': ('verdensatlas',),
'verdensbank': ('verdensbank',),
'verdensbanken': ('verdensbank',),
'verdensbankene': ('verdensbank',),
'verdensbanker': ('verdensbank',),
'verdensbasis': ('verdensbasis',),
'verdensbasisen': ('verdensbasis',),
'verdensbasisene': ('verdensbasis',),
'verdensbasiser': ('verdensbasis',),
'verdensbegivenhet': ('verdensbegivenhet',),
'verdensbegivenheta': ('verdensbegivenhet',),
'verdensbegivenheten': ('verdensbegivenhet',),
'verdensbegivenhetene': ('verdensbegivenhet',),
'verdensbegivenheter': ('verdensbegivenhet',),
'verdensbilda': ('verdensbilde',),
'verdensbilde': ('verdensbilde',),
'verdensbildene': ('verdensbilde',),
'verdensbilder': ('verdensbilde',),
'verdensbildet': ('verdensbilde',),
'verdensborger': ('verdensborger',),
'verdensborgere': ('verdensborger',),
'verdensborgeren': ('verdensborger',),
'verdensborgerer': ('verdensborger',),
'verdensborgerne': ('verdensborger',),
'verdensby': ('verdensby',),
'verdensbyen': ('verdensby',),
'verdensbyene': ('verdensby',),
'verdensbyer': ('verdensby',),
'verdenscup': ('verdenscup',),
'verdenscupen': ('verdenscup',),
'verdenscupene': ('verdenscup',),
'verdenscuper': ('verdenscup',),
'verdenscuprenn': ('verdenscuprenn',),
'verdenscuprenna': ('verdenscuprenn',),
'verdenscuprennene': ('verdenscuprenn',),
'verdenscuprennet': ('verdenscuprenn',),
'verdensdama': ('verdensdame',),
'verdensdame': ('verdensdame',),
'verdensdamen': ('verdensdame',),
'verdensdamene': ('verdensdame',),
'verdensdamer': ('verdensdame',),
'verdensdel': ('verdensdel',),
'verdensdelen': ('verdensdel',),
'verdensdelene': ('verdensdel',),
'verdensdeler': ('verdensdel',),
'verdenselite': ('verdenselite',),
'verdenseliten': ('verdenselite',),
'verdenselitene': ('verdenselite',),
'verdenseliter': ('verdenselite',),
'verdensformat': ('verdensformat',),
'verdensformata': ('verdensformat',),
'verdensformatene': ('verdensformat',),
'verdensformater': ('verdensformat',),
'verdensformatet': ('verdensformat',),
'verdensfred': ('verdensfred',),
'verdensfreden': ('verdensfred',),
'verdensfredene': ('verdensfred',),
'verdensfreder': ('verdensfred',),
'verdenshandel': ('verdenshandel',),
'verdenshandelen': ('verdenshandel',),
'verdenshandlene': ('verdenshandel',),
'verdenshandler': ('verdenshandel',),
'verdenshav': ('verdenshav',),
'verdenshava': ('verdenshav',),
'verdenshavene': ('verdenshav',),
'verdenshavet': ('verdenshav',),
'verdenshegemoni': ('verdenshegemoni',),
'verdenshegemonia': ('verdenshegemoni',),
'verdenshegemoniene': ('verdenshegemoni',),
'verdenshegemonier': ('verdenshegemoni',),
'verdenshegemoniet': ('verdenshegemoni',),
'verdensherredømma': ('verdensherredømme',),
'verdensherredømme': ('verdensherredømme',),
'verdensherredømmene': ('verdensherredømme',),
'verdensherredømmer': ('verdensherredømme',),
'verdensherredømmet': ('verdensherredømme',),
'verdenshistoria': ('verdenshistorie',),
'verdenshistorie': ('verdenshistorie',),
'verdenshistorien': ('verdenshistorie',),
'verdenshistoriene': ('verdenshistorie',),
'verdenshistorier': ('verdenshistorie',),
'verdenshjørna': ('verdenshjørne',),
'verdenshjørne': ('verdenshjørne',),
'verdenshjørnene': ('verdenshjørne',),
'verdenshjørner': ('verdenshjørne',),
'verdenshjørnet': ('verdenshjørne',),
'verdenshusholdning': ('verdenshusholdning',),
'verdenshusholdninga': ('verdenshusholdning',),
'verdenshusholdningen': ('verdenshusholdning',),
'verdenshusholdningene': ('verdenshusholdning',),
'verdenshusholdninger': ('verdenshusholdning',),
'verdenskart': ('verdenskart',),
'verdenskarta': ('verdenskart',),
'verdenskartene': ('verdenskart',),
'verdenskarter': ('verdenskart',),
'verdenskartet': ('verdenskart',),
'verdensklassa': ('verdensklasse',),
'verdensklasse': ('verdensklasse',),
'verdensklassen': ('verdensklasse',),
'verdensklassene': ('verdensklasse',),
'verdensklasser': ('verdensklasse',),
'verdenskongress': ('verdenskongress',),
'verdenskongressen': ('verdenskongress',),
'verdenskongressene': ('verdenskongress',),
'verdenskongresser': ('verdenskongress',),
'verdenskrig': ('verdenskrig',),
'verdenskrigen': ('verdenskrig',),
'verdenskrigene': ('verdenskrig',),
'verdenskriger': ('verdenskrig',),
'verdenskrisa': ('verdenskrise',),
'verdenskrise': ('verdenskrise',),
'verdenskrisen': ('verdenskrise',),
'verdenskrisene': ('verdenskrise',),
'verdenskriser': ('verdenskrise',),
'verdenslitteratur': ('verdenslitteratur',),
'verdenslitteraturen': ('verdenslitteratur',),
'verdenslitteraturene': ('verdenslitteratur',),
'verdenslitteraturer': ('verdenslitteratur',),
'verdensmakt': ('verdensmakt',),
'verdensmakta': ('verdensmakt',),
'verdensmakten': ('verdensmakt',),
'verdensmaktene': ('verdensmakt',),
'verdensmakter': ('verdensmakt',),
'verdensmann': ('verdensmann',),
'verdensmannen': ('verdensmann',),
'verdensmenn': ('verdensmann',),
'verdensmennene': ('verdensmann',),
'verdensmarked': ('verdensmarked',),
'verdensmarkeda': ('verdensmarked',),
'verdensmarkedene': ('verdensmarked',),
'verdensmarkeder': ('verdensmarked',),
'verdensmarkedet': ('verdensmarked',),
'verdensmarknad': ('verdensmarknad',),
'verdensmarknaden': ('verdensmarknad',),
'verdensmarknadene': ('verdensmarknad',),
'verdensmarknader': ('verdensmarknad',),
'verdensmester': ('verdensmester',),
'verdensmestere': ('verdensmester',),
'verdensmesteren': ('verdensmester',),
'verdensmesterer': ('verdensmester',),
'verdensmesterne': ('verdensmester',),
'verdensmestre': ('verdensmester',),
'verdensmestrene': ('verdensmester',),
'verdensmestrer': ('verdensmester',),
'verdensmesterskap': ('verdensmesterskap',),
'verdensmesterskapa': ('verdensmesterskap',),
'verdensmesterskapene': ('verdensmesterskap',),
'verdensmesterskaper': ('verdensmesterskap',),
'verdensmesterskapet': ('verdensmesterskap',),
'verdensmålestokk': ('verdensmålestokk',),
'verdensmålestokken': ('verdensmålestokk',),
'verdensmålestokkene': ('verdensmålestokk',),
'verdensmålestokker': ('verdensmålestokk',),
'verdensnavn': ('verdensnavn',),
'verdensnavna': ('verdensnavn',),
'verdensnavnene': ('verdensnavn',),
'verdensnavnet': ('verdensnavn',),
'verdensomsegling': ('verdensomsegling',),
'verdensomseglinga': ('verdensomsegling',),
'verdensomseglingen': ('verdensomsegling',),
'verdensomseglingene': ('verdensomsegling',),
'verdensomseglinger': ('verdensomsegling',),
'verdensomseiling': ('verdensomseiling',),
'verdensomseilinga': ('verdensomseiling',),
'verdensomseilingen': ('verdensomseiling',),
'verdensomseilingene': ('verdensomseiling',),
'verdensomseilinger': ('verdensomseiling',),
'verdensopinion': ('verdensopinion',),
'verdensopinionen': ('verdensopinion',),
'verdensopinionene': ('verdensopinion',),
'verdensopinioner': ('verdensopinion',),
'verdensorden': ('verdensorden',),
'verdensordenen': ('verdensorden',),
'verdensordenene': ('verdensorden',),
'verdensordener': ('verdensorden',),
'verdensordning': ('verdensordning',),
'verdensordninga': ('verdensordning',),
'verdensordningen': ('verdensordning',),
'verdensordningene': ('verdensordning',),
'verdensordninger': ('verdensordning',),
'verdensorganisasjon': ('verdensorganisasjon',),
'verdensorganisasjonen': ('verdensorganisasjon',),
'verdensorganisasjonene': ('verdensorganisasjon',),
'verdensorganisasjoner': ('verdensorganisasjon',),
'verdenspatent': ('verdenspatent',),
'verdenspatenta': ('verdenspatent',),
'verdenspatentene': ('verdenspatent',),
'verdenspatenter': ('verdenspatent',),
'verdenspatentet': ('verdenspatent',),
'verdenspolitikk': ('verdenspolitikk',),
'verdenspolitikken': ('verdenspolitikk',),
'verdenspolitikkene': ('verdenspolitikk',),
'verdenspolitikker': ('verdenspolitikk',),
'verdenspressa': ('verdenspresse',),
'verdenspresse': ('verdenspresse',),
'verdenspressen': ('verdenspresse',),
'verdenspressene': ('verdenspresse',),
'verdenspresser': ('verdenspresse',),
'verdensrekord': ('verdensrekord',),
'verdensrekorden': ('verdensrekord',),
'verdensrekordene': ('verdensrekord',),
'verdensrekorder': ('verdensrekord',),
'verdensrevolusjon': ('verdensrevolusjon',),
'verdensrevolusjonen': ('verdensrevolusjon',),
'verdensrevolusjonene': ('verdensrevolusjon',),
'verdensrevolusjoner': ('verdensrevolusjon',),
'verdensrika': ('verdensrike',),
'verdensrike': ('verdensrike',),
'verdensrikene': ('verdensrike',),
'verdensriker': ('verdensrike',),
'verdensriket': ('verdensrike',),
'verdensrom': ('verdensrom',),
'verdensromma': ('verdensrom',),
'verdensrommene': ('verdensrom',),
'verdensrommet': ('verdensrom',),
'verdensry': ('verdensry',),
'verdensrya': ('verdensry',),
'verdensryene': ('verdensry',),
'verdensryet': ('verdensry',),
'verdenssituasjon': ('verdenssituasjon',),
'verdenssituasjonen': ('verdenssituasjon',),
'verdenssituasjonene': ('verdenssituasjon',),
'verdenssituasjoner': ('verdenssituasjon',),
'verdensspråk': ('verdensspråk',),
'verdensspråka': ('verdensspråk',),
'verdensspråkene': ('verdensspråk',),
'verdensspråket': ('verdensspråk',),
'verdenssyn': ('verdenssyn',),
'verdenssyna': ('verdenssyn',),
'verdenssynene': ('verdenssyn',),
'verdenssynet': ('verdenssyn',),
'verdenstopp': ('verdenstopp',),
'verdenstoppen': ('verdenstopp',),
'verdenstoppene': ('verdenstopp',),
'verdenstopper': ('verdenstopp',),
'verdensutstilling': ('verdensutstilling',),
'verdensutstillinga': ('verdensutstilling',),
'verdensutstillingen': ('verdensutstilling',),
'verdensutstillingene': ('verdensutstilling',),
'verdensutstillinger': ('verdensutstilling',),
'verdensøkonomi': ('verdensøkonomi',),
'verdensøkonomien': ('verdensøkonomi',),
'verdensøkonomiene': ('verdensøkonomi',),
'verdensøkonomier': ('verdensøkonomi',),
'verdi': ('verdi',),
'verdien': ('verdi',),
'verdiene': ('verdi',),
'verdier': ('verdi',),
'verdibrev': ('verdibrev',),
'verdibreva': ('verdibrev',),
'verdibrevene': ('verdibrev',),
'verdibrever': ('verdibrev',),
'verdibrevet': ('verdibrev',),
'verdidom': ('verdidom',),
'verdidommen': ('verdidom',),
'verdidommene': ('verdidom',),
'verdidommer': ('verdidom',),
'verdighet': ('verdighet',),
'verdigheta': ('verdighet',),
'verdigheten': ('verdighet',),
'verdighetene': ('verdighet',),
'verdigheter': ('verdighet',),
'verdigjenstand': ('verdigjenstand',),
'verdigjenstanden': ('verdigjenstand',),
'verdigjenstandene': ('verdigjenstand',),
'verdigjenstander': ('verdigjenstand',),
'verdigrunnlag': ('verdigrunnlag',),
'verdigrunnlaga': ('verdigrunnlag',),
'verdigrunnlagene': ('verdigrunnlag',),
'verdigrunnlaget': ('verdigrunnlag',),
'verdiinnhold': ('verdiinnhold',),
'verdiinnholda': ('verdiinnhold',),
'verdiinnholdene': ('verdiinnhold',),
'verdiinnholdet': ('verdiinnhold',),
'verdimåler': ('verdimåler',),
'verdimålere': ('verdimåler',),
'verdimåleren': ('verdimåler',),
'verdimålerer': ('verdimåler',),
'verdimålerne': ('verdimåler',),
'verdinorm': ('verdinorm',),
'verdinormen': ('verdinorm',),
'verdinormene': ('verdinorm',),
'verdinormer': ('verdinorm',),
'verdioppskriving': ('verdioppskriving',),
'verdioppskrivinga': ('verdioppskriving',),
'verdioppskrivingen': ('verdioppskriving',),
'verdioppskrivingene': ('verdioppskriving',),
'verdioppskrivinger': ('verdioppskriving',),
'verdioppskrivning': ('verdioppskrivning',),
'verdioppskrivninga': ('verdioppskrivning',),
'verdioppskrivningen': ('verdioppskrivning',),
'verdioppskrivningene': ('verdioppskrivning',),
'verdioppskrivninger': ('verdioppskrivning',),
'verdipakka': ('verdipakke',),
'verdipakke': ('verdipakke',),
'verdipakken': ('verdipakke',),
'verdipakkene': ('verdipakke',),
'verdipakker': ('verdipakke',),
'verdipapir': ('verdipapir',),
'verdipapira': ('verdipapir',),
'verdipapirene': ('verdipapir',),
'verdipapirer': ('verdipapir',),
'verdipapiret': ('verdipapir',),
'verdipost': ('verdipost',),
'verdiposten': ('verdipost',),
'verdipostene': ('verdipost',),
'verdiposter': ('verdipost',),
'verdisak': ('verdisak',),
'verdisaka': ('verdisak',),
'verdisaken': ('verdisak',),
'verdisakene': ('verdisak',),
'verdisaker': ('verdisak',),
'verdistiging': ('verdistiging',),
'verdistiginga': ('verdistiging',),
'verdistigingen': ('verdistiging',),
'verdistigingene': ('verdistiging',),
'verdistiginger': ('verdistiging',),
'verdistigning': ('verdistigning',),
'verdistigninga': ('verdistigning',),
'verdistigningen': ('verdistigning',),
'verdistigningene': ('verdistigning',),
'verdistigninger': ('verdistigning',),
'verditakst': ('verditakst',),
'verditaksten': ('verditakst',),
'verditakstene': ('verditakst',),
'verditakster': ('verditakst',),
'verditoll': ('verditoll',),
'verditollen': ('verditoll',),
'verditollene': ('verditoll',),
'verditoller': ('verditoll',),
'verft': ('verft',),
'verfta': ('verft',),
'verftene': ('verft',),
'verftet': ('verft',),
'verftsarbeider': ('verftsarbeider',),
'verftsarbeidere': ('verftsarbeider',),
'verftsarbeideren': ('verftsarbeider',),
'verftsarbeiderer': ('verftsarbeider',),
'verftsarbeiderne': ('verftsarbeider',),
'verge': ('verge',),
'vergen': ('verge',),
'vergene': ('verge',),
'verger': ('verge',),
'verge': ('verge',),
'vergen': ('verge',),
'vergene': ('verge',),
'verger': ('verge',),
'vergemål': ('vergemål',),
'vergemåla': ('vergemål',),
'vergemålene': ('vergemål',),
'vergemålet': ('vergemål',),
'vergemål': ('vergemål',),
'vergemåla': ('vergemål',),
'vergemålene': ('vergemål',),
'vergemålet': ('vergemål',),
'vergemålslov': ('vergemålslov',),
'vergemålsloven': ('vergemålslov',),
'vergemålslovene': ('vergemålslov',),
'vergemålslover': ('vergemålslov',),
'vergemålslov': ('vergemålslov',),
'vergemålsloven': ('vergemålslov',),
'vergemålslovene': ('vergemålslov',),
'vergemålslover': ('vergemålslov',),
'vergemålsrett': ('vergemålsrett',),
'vergemålsretten': ('vergemålsrett',),
'vergemålsrettene': ('vergemålsrett',),
'vergemålsretter': ('vergemålsrett',),
'vergemålsrett': ('vergemålsrett',),
'vergemålsretten': ('vergemålsrett',),
'vergemålsrettene': ('vergemålsrett',),
'vergemålsretter': ('vergemålsrett',),
'vergeråd': ('vergeråd',),
'vergeråda': ('vergeråd',),
'vergerådene': ('vergeråd',),
'vergerådet': ('vergeråd',),
'vergeråd': ('vergeråd',),
'vergeråda': ('vergeråd',),
'vergerådene': ('vergeråd',),
'vergerådet': ('vergeråd',),
'verifikasjon': ('verifikasjon',),
'verifikasjonen': ('verifikasjon',),
'verifikasjonene': ('verifikasjon',),
'verifikasjoner': ('verifikasjon',),
'verisme': ('verisme',),
'verismen': ('verisme',),
'verismene': ('verisme',),
'verismer': ('verisme',),
'verist': ('verist',),
'veristen': ('verist',),
'veristene': ('verist',),
'verister': ('verist',),
'verje': ('verje',),
'verjen': ('verje',),
'verjene': ('verje',),
'verjer': ('verje',),
'verje': ('verje',),
'verjen': ('verje',),
'verjene': ('verje',),
'verjer': ('verje',),
'verja': ('verje',),
'verje': ('verje',),
'verjene': ('verje',),
'verjer': ('verje',),
'verjet': ('verje',),
'verja': ('verje',),
'verje': ('verje',),
'verjene': ('verje',),
'verjer': ('verje',),
'verjet': ('verje',),
'verja': ('verje',),
'verje': ('verje',),
'verjen': ('verje',),
'verjene': ('verje',),
'verjer': ('verje',),
'verja': ('verje',),
'verje': ('verje',),
'verjen': ('verje',),
'verjene': ('verje',),
'verjer': ('verje',),
'verjemål': ('verjemål',),
'verjemåla': ('verjemål',),
'verjemålene': ('verjemål',),
'verjemålet': ('verjemål',),
'verjemål': ('verjemål',),
'verjemåla': ('verjemål',),
'verjemålene': ('verjemål',),
'verjemålet': ('verjemål',),
'verjemålslov': ('verjemålslov',),
'verjemålsloven': ('verjemålslov',),
'verjemålslovene': ('verjemålslov',),
'verjemålslover': ('verjemålslov',),
'verjemålslov': ('verjemålslov',),
'verjemålsloven': ('verjemålslov',),
'verjemålslovene': ('verjemålslov',),
'verjemålslover': ('verjemålslov',),
'verjemålsrett': ('verjemålsrett',),
'verjemålsretten': ('verjemålsrett',),
'verjemålsrettene': ('verjemålsrett',),
'verjemålsretter': ('verjemålsrett',),
'verjemålsrett': ('verjemålsrett',),
'verjemålsretten': ('verjemålsrett',),
'verjemålsrettene': ('verjemålsrett',),
'verjemålsretter': ('verjemålsrett',),
'verjeråd': ('verjeråd',),
'verjeråda': ('verjeråd',),
'verjerådene': ('verjeråd',),
'verjerådet': ('verjeråd',),
'verjeråd': ('verjeråd',),
'verjeråda': ('verjeråd',),
'verjerådene': ('verjeråd',),
'verjerådet': ('verjeråd',),
'verk': ('verk',),
'verken': ('verk',),
'verkene': ('verk',),
'verker': ('verk',),
'verk': ('verk',),
'verka': ('verk',),
'verkene': ('verk',),
'verker': ('verk',),
'verket': ('verk',),
'verkefinger': ('verkefinger',),
'verkefingeren': ('verkefinger',),
'verkefingre': ('verkefinger',),
'verkefingrene': ('verkefinger',),
'verkefingrer': ('verkefinger',),
'verken': ('verken',),
'verkena': ('verken',),
'verkenene': ('verken',),
'verkenet': ('verken',),
'verkenskjole': ('verkenskjole',),
'verkenskjolen': ('verkenskjole',),
'verkenskjolene': ('verkenskjole',),
'verkenskjoler': ('verkenskjole',),
'verkenstøy': ('verkenstøy',),
'verkenstøya': ('verkenstøy',),
'verkenstøyene': ('verkenstøy',),
'verkenstøyer': ('verkenstøy',),
'verkenstøyet': ('verkenstøy',),
'verketå': ('verketå',),
'verketåa': ('verketå',),
'verketåen': ('verketå',),
'verketær': ('verketå',),
'verketærne': ('verketå',),
'verknad': ('verknad',),
'verknaden': ('verknad',),
'verknadene': ('verknad',),
'verknader': ('verknad',),
'verksarbeider': ('verksarbeider',),
'verksarbeidere': ('verksarbeider',),
'verksarbeideren': ('verksarbeider',),
'verksarbeiderer': ('verksarbeider',),
'verksarbeiderne': ('verksarbeider',),
'verksmester': ('verksmester',),
'verksmestere': ('verksmester',),
'verksmesteren': ('verksmester',),
'verksmesterer': ('verksmester',),
'verksmesterne': ('verksmester',),
'verksmestre': ('verksmester',),
'verksmestrene': ('verksmester',),
'verksmestrer': ('verksmester',),
'verksted': ('verksted',),
'verkstedene': ('verksted',),
'verksteder': ('verksted',),
'verkstedet': ('verksted',),
'verkstedarbeider': ('verkstedarbeider',),
'verkstedarbeidere': ('verkstedarbeider',),
'verkstedarbeideren': ('verkstedarbeider',),
'verkstedarbeiderer': ('verkstedarbeider',),
'verkstedarbeiderne': ('verkstedarbeider',),
'verkstedindustri': ('verkstedindustri',),
'verkstedindustrien': ('verkstedindustri',),
'verkstedindustriene': ('verkstedindustri',),
'verkstedindustrier': ('verkstedindustri',),
'verkstedklubb': ('verkstedklubb',),
'verkstedklubben': ('verkstedklubb',),
'verkstedklubbene': ('verkstedklubb',),
'verkstedklubber': ('verkstedklubb',),
'verktøy': ('verktøy',),
'verktøya': ('verktøy',),
'verktøyene': ('verktøy',),
'verktøyer': ('verktøy',),
'verktøyet': ('verktøy',),
'verktøyavdeling': ('verktøyavdeling',),
'verktøyavdelinga': ('verktøyavdeling',),
'verktøyavdelingen': ('verktøyavdeling',),
'verktøyavdelingene': ('verktøyavdeling',),
'verktøyavdelinger': ('verktøyavdeling',),
'verktøykassa': ('verktøykasse',),
'verktøykasse': ('verktøykasse',),
'verktøykassen': ('verktøykasse',),
'verktøykassene': ('verktøykasse',),
'verktøykasser': ('verktøykasse',),
'verktøymaskin': ('verktøymaskin',),
'verktøymaskina': ('verktøymaskin',),
'verktøymaskinen': ('verktøymaskin',),
'verktøymaskinene': ('verktøymaskin',),
'verktøymaskiner': ('verktøymaskin',),
'verktøystål': ('verktøystål',),
'verktøyståla': ('verktøystål',),
'verktøystålene': ('verktøystål',),
'verktøystålet': ('verktøystål',),
'vermut': ('vermut',),
'vermuten': ('vermut',),
'vermutene': ('vermut',),
'vermuter': ('vermut',),
'vern': ('vern',),
'verna': ('vern',),
'vernene': ('vern',),
'vernet': ('vern',),
'vernearbeid': ('vernearbeid',),
'vernearbeida': ('vernearbeid',),
'vernearbeidene': ('vernearbeid',),
'vernearbeider': ('vernearbeid',),
'vernearbeidet': ('vernearbeid',),
'vernebedrift': ('vernebedrift',),
'vernebedriften': ('vernebedrift',),
'vernebedriftene': ('vernebedrift',),
'vernebedrifter': ('vernebedrift',),
'vernebrilla': ('vernebrille',),
'vernebrille': ('vernebrille',),
'vernebrillen': ('vernebrille',),
'vernebrillene': ('vernebrille',),
'vernebriller': ('vernebrille',),
'vernebøyle': ('vernebøyle',),
'vernebøylen': ('vernebøyle',),
'vernebøylene': ('vernebøyle',),
'vernebøyler': ('vernebøyle',),
'vernefarge': ('vernefarge',),
'vernefargen': ('vernefarge',),
'vernefargene': ('vernefarge',),
'vernefarger': ('vernefarge',),
'vernefugl': ('vernefugl',),
'vernefuglen': ('vernefugl',),
'vernefuglene': ('vernefugl',),
'vernefugler': ('vernefugl',),
'vernegud': ('vernegud',),
'verneguden': ('vernegud',),
'vernegudene': ('vernegud',),
'verneguder': ('vernegud',),
'verneheim': ('verneheim',),
'verneheimen': ('verneheim',),
'verneheimene': ('verneheim',),
'verneheimer': ('verneheim',),
'vernehelgen': ('vernehelgen',),
'vernehelgenen': ('vernehelgen',),
'vernehelgenene': ('vernehelgen',),
'vernehelgener': ('vernehelgen',),
'vernehjem': ('vernehjem',),
'vernehjemma': ('vernehjem',),
'vernehjemmene': ('vernehjem',),
'vernehjemmet': ('vernehjem',),
'vernehytta': ('vernehytte',),
'vernehytte': ('vernehytte',),
'vernehytten': ('vernehytte',),
'vernehyttene': ('vernehytte',),
'vernehytter': ('vernehytte',),
'vernelag': ('vernelag',),
'vernelaga': ('vernelag',),
'vernelagene': ('vernelag',),
'vernelaget': ('vernelag',),
'vernemaska': ('vernemaske',),
'vernemaske': ('vernemaske',),
'vernemasken': ('vernemaske',),
'vernemaskene': ('vernemaske',),
'vernemasker': ('vernemaske',),
'vernemiddel': ('vernemiddel',),
'vernemiddelet': ('vernemiddel',),
'vernemidla': ('vernemiddel',),
'vernemidlene': ('vernemiddel',),
'vernemidler': ('vernemiddel',),
'vernemidlet': ('vernemiddel',),
'verneombud': ('verneombud',),
'verneombuda': ('verneombud',),
'verneombudene': ('verneombud',),
'verneombudet': ('verneombud',),
'vernepleier': ('vernepleier',),
'vernepleiere': ('vernepleier',),
'vernepleieren': ('vernepleier',),
'vernepleierer': ('vernepleier',),
'vernepleierne': ('vernepleier',),
'vernepleierskole': ('vernepleierskole',),
'vernepleierskolen': ('vernepleierskole',),
'vernepleierskolene': ('vernepleierskole',),
'vernepleierskoler': ('vernepleierskole',),
'verneplikt': ('verneplikt',),
'verneplikta': ('verneplikt',),
'verneplikten': ('verneplikt',),
'vernepliktene': ('verneplikt',),
'verneplikter': ('verneplikt',),
'vernepliktsalder': ('vernepliktsalder',),
'vernepliktsaldere': ('vernepliktsalder',),
'vernepliktsalderen': ('vernepliktsalder',),
'vernepliktsalderer': ('vernepliktsalder',),
'vernepliktsalderne': ('vernepliktsalder',),
'vernepliktsaldre': ('vernepliktsalder',),
'vernepliktsaldrene': ('vernepliktsalder',),
'vernepliktsaldrer': ('vernepliktsalder',),
'vernepliktstid': ('vernepliktstid',),
'vernepliktstida': ('vernepliktstid',),
'vernepliktstiden': ('vernepliktstid',),
'vernepliktstidene': ('vernepliktstid',),
'vernepliktstider': ('vernepliktstid',),
'verner': ('verner',),
'vernere': ('verner',),
'verneren': ('verner',),
'vernerer': ('verner',),
'vernerne': ('verner',),
'vernesamband': ('vernesamband',),
'vernesambanda': ('vernesamband',),
'vernesambandene': ('vernesamband',),
'vernesambandet': ('vernesamband',),
'verneskatt': ('verneskatt',),
'verneskatten': ('verneskatt',),
'verneskattene': ('verneskatt',),
'verneskatter': ('verneskatt',),
'verneskog': ('verneskog',),
'verneskogen': ('verneskog',),
'verneskogene': ('verneskog',),
'verneskoger': ('verneskog',),
'verneskole': ('verneskole',),
'verneskolen': ('verneskole',),
'verneskolene': ('verneskole',),
'verneskoler': ('verneskole',),
'vernetid': ('vernetid',),
'vernetida': ('vernetid',),
'vernetiden': ('vernetid',),
'vernetidene': ('vernetid',),
'vernetider': ('vernetid',),
'vernetiltak': ('vernetiltak',),
'vernetiltaka': ('vernetiltak',),
'vernetiltakene': ('vernetiltak',),
'vernetiltaket': ('vernetiltak',),
'verneting': ('verneting',),
'vernetinga': ('verneting',),
'vernetingene': ('verneting',),
'vernetinget': ('verneting',),
'vernetoll': ('vernetoll',),
'vernetollen': ('vernetoll',),
'vernetollene': ('vernetoll',),
'vernetoller': ('vernetoll',),
'verneutstyr': ('verneutstyr',),
'verneutstyra': ('verneutstyr',),
'verneutstyrene': ('verneutstyr',),
'verneutstyret': ('verneutstyr',),
'vernissasje': ('vernissasje',),
'vernissasjen': ('vernissasje',),
'vernissasjene': ('vernissasje',),
'vernissasjer': ('vernissasje',),
'veronal': ('veronal',),
'veronalen': ('veronal',),
'veronalene': ('veronal',),
'veronaler': ('veronal',),
'veronalforgiftning': ('veronalforgiftning',),
'veronalforgiftninga': ('veronalforgiftning',),
'veronalforgiftningen': ('veronalforgiftning',),
'veronalforgiftningene': ('veronalforgiftning',),
'veronalforgiftninger': ('veronalforgiftning',),
'veronika': ('veronika',),
'veronikaen': ('veronika',),
'veronikaene': ('veronika',),
'veronikaer': ('veronika',),
'verp': ('verp',),
'verpa': ('verp',),
'verpene': ('verp',),
'verpet': ('verp',),
'verpa': ('verpe',),
'verpe': ('verpe',),
'verpene': ('verpe',),
'verper': ('verpe',),
'verpet': ('verpe',),
'verpehøna': ('verpehøne',),
'verpehøne': ('verpehøne',),
'verpehønen': ('verpehøne',),
'verpehønene': ('verpehøne',),
'verpehøner': ('verpehøne',),
'verpehøns': ('verpehøns',),
'verpehønsa': ('verpehøns',),
'verpehønsene': ('verpehøns',),
'verpehønset': ('verpehøns',),
'verpekassa': ('verpekasse',),
'verpekasse': ('verpekasse',),
'verpekassen': ('verpekasse',),
'verpekassene': ('verpekasse',),
'verpekasser': ('verpekasse',),
'verper': ('verper',),
'verpere': ('verper',),
'verperen': ('verper',),
'verperer': ('verper',),
'verperne': ('verper',),
'vers': ('vers',),
'versa': ('vers',),
'versene': ('vers',),
'verset': ('vers',),
'versal': ('versal',),
'versalen': ('versal',),
'versalene': ('versal',),
'versaler': ('versal',),
'versatilitet': ('versatilitet',),
'versatiliteten': ('versatilitet',),
'versatilitetene': ('versatilitet',),
'versatiliteter': ('versatilitet',),
'versbygning': ('versbygning',),
'versbygninga': ('versbygning',),
'versbygningen': ('versbygning',),
'versbygningene': ('versbygning',),
'versbygninger': ('versbygning',),
'versdrama': ('versdrama',),
'versdramaene': ('versdrama',),
'versdramaer': ('versdrama',),
'versdramaet': ('versdrama',),
'versedrama': ('versedrama',),
'versedramaene': ('versedrama',),
'versedramaer': ('versedrama',),
'versedramaet': ('versedrama',),
'verseform': ('verseform',),
'verseforma': ('verseform',),
'verseformen': ('verseform',),
'verseformene': ('verseform',),
'verseformer': ('verseform',),
'versekunst': ('versekunst',),
'versekunsten': ('versekunst',),
'versekunstene': ('versekunst',),
'versekunster': ('versekunst',),
'versekunstner': ('versekunstner',),
'versekunstnere': ('versekunstner',),
'versekunstneren': ('versekunstner',),
'versekunstnerer': ('versekunstner',),
'versekunstnerne': ('versekunstner',),
'verselinja': ('verselinje',),
'verselinje': ('verselinje',),
'verselinjen': ('verselinje',),
'verselinjene': ('verselinje',),
'verselinjer': ('verselinje',),
'verselæra': ('verselære',),
'verselære': ('verselære',),
'verselæren': ('verselære',),
'verselærene': ('verselære',),
'verselærer': ('verselære',),
'versemaker': ('versemaker',),
'versemakere': ('versemaker',),
'versemakeren': ('versemaker',),
'versemakerer': ('versemaker',),
'versemakerne': ('versemaker',),
'versemakeri': ('versemakeri',),
'versemakeria': ('versemakeri',),
'versemakeriene': ('versemakeri',),
'versemakerier': ('versemakeri',),
'versemakeriet': ('versemakeri',),
'versemål': ('versemål',),
'versemåla': ('versemål',),
'versemålene': ('versemål',),
'versemålet': ('versemål',),
'verserytme': ('verserytme',),
'verserytmen': ('verserytme',),
'verserytmene': ('verserytme',),
'verserytmer': ('verserytme',),
'verseskjema': ('verseskjema',),
'verseskjemaene': ('verseskjema',),
'verseskjemaer': ('verseskjema',),
'verseskjemaet': ('verseskjema',),
'versestubb': ('versestubb',),
'versestubben': ('versestubb',),
'versestubbene': ('versestubb',),
'versestubber': ('versestubb',),
'versform': ('versform',),
'versforma': ('versform',),
'versformen': ('versform',),
'versformene': ('versform',),
'versformer': ('versform',),
'versifikasjon': ('versifikasjon',),
'versifikasjonen': ('versifikasjon',),
'versifikasjonene': ('versifikasjon',),
'versifikasjoner': ('versifikasjon',),
'versifikator': ('versifikator',),
'versifikatoren': ('versifikator',),
'versifikatorene': ('versifikator',),
'versifikatorer': ('versifikator',),
'versjon': ('versjon',),
'versjonen': ('versjon',),
'versjonene': ('versjon',),
'versjoner': ('versjon',),
'verskunst': ('verskunst',),
'verskunsten': ('verskunst',),
'verskunstene': ('verskunst',),
'verskunster': ('verskunst',),
'verskunstner': ('verskunstner',),
'verskunstnere': ('verskunstner',),
'verskunstneren': ('verskunstner',),
'verskunstnerer': ('verskunstner',),
'verskunstnerne': ('verskunstner',),
'verslinja': ('verslinje',),
'verslinje': ('verslinje',),
'verslinjen': ('verslinje',),
'verslinjene': ('verslinje',),
'verslinjer': ('verslinje',),
'verslæra': ('verslære',),
'verslære': ('verslære',),
'verslæren': ('verslære',),
'verslærene': ('verslære',),
'verslærer': ('verslære',),
'versmaker': ('versmaker',),
'versmakere': ('versmaker',),
'versmakeren': ('versmaker',),
'versmakerer': ('versmaker',),
'versmakerne': ('versmaker',),
'versmakeri': ('versmakeri',),
'versmakeria': ('versmakeri',),
'versmakeriene': ('versmakeri',),
'versmakeriet': ('versmakeri',),
'verspar': ('verspar',),
'verspara': ('verspar',),
'versparene': ('verspar',),
'versparet': ('verspar',),
'versrytme': ('versrytme',),
'versrytmen': ('versrytme',),
'versrytmene': ('versrytme',),
'versrytmer': ('versrytme',),
'versskjema': ('versskjema',),
'versskjemaene': ('versskjema',),
'versskjemaer': ('versskjema',),
'versskjemaet': ('versskjema',),
'verst': ('verst',),
'versten': ('verst',),
'verstene': ('verst',),
'versting': ('versting',),
'verstingen': ('versting',),
'verstingene': ('versting',),
'verstinger': ('versting',),
'vert': ('vert',),
'verten': ('vert',),
'vertene': ('vert',),
'verter': ('vert',),
'vertdyr': ('vertdyr',),
'vertdyra': ('vertdyr',),
'vertdyrene': ('vertdyr',),
'vertdyret': ('vertdyr',),
'vertebrat': ('vertebrat',),
'vertebraten': ('vertebrat',),
'vertebratene': ('vertebrat',),
'vertebrater': ('vertebrat',),
'vertikal': ('vertikal',),
'vertikalen': ('vertikal',),
'vertikalene': ('vertikal',),
'vertikaler': ('vertikal',),
'vertikalakse': ('vertikalakse',),
'vertikalaksen': ('vertikalakse',),
'vertikalaksene': ('vertikalakse',),
'vertikalakser': ('vertikalakse',),
'vertikallinja': ('vertikallinje',),
'vertikallinje': ('vertikallinje',),
'vertikallinjen': ('vertikallinje',),
'vertikallinjene': ('vertikallinje',),
'vertikallinjer': ('vertikallinje',),
'vertikalplan': ('vertikalplan',),
'vertikalplana': ('vertikalplan',),
'vertikalplanene': ('vertikalplan',),
'vertikalplanet': ('vertikalplan',),
'vertikalport': ('vertikalport',),
'vertikalporten': ('vertikalport',),
'vertikalportene': ('vertikalport',),
'vertikalporter': ('vertikalport',),
'vertikalsirkel': ('vertikalsirkel',),
'vertikalsirkelen': ('vertikalsirkel',),
'vertikalsirklene': ('vertikalsirkel',),
'vertikalsirkler': ('vertikalsirkel',),
'vertinna': ('vertinne',),
'vertinne': ('vertinne',),
'vertinnen': ('vertinne',),
'vertinnene': ('vertinne',),
'vertinner': ('vertinne',),
'vertinnekjole': ('vertinnekjole',),
'vertinnekjolen': ('vertinnekjole',),
'vertinnekjolene': ('vertinnekjole',),
'vertinnekjoler': ('vertinnekjole',),
'vertinneplikt': ('vertinneplikt',),
'vertinneplikta': ('vertinneplikt',),
'vertinneplikten': ('vertinneplikt',),
'vertinnepliktene': ('vertinneplikt',),
'vertinneplikter': ('vertinneplikt',),
'vertland': ('vertland',),
'vertlanda': ('vertland',),
'vertlandene': ('vertland',),
'vertlandet': ('vertland',),
'vertplanta': ('vertplante',),
'vertplante': ('vertplante',),
'vertplanten': ('vertplante',),
'vertplantene': ('vertplante',),
'vertplanter': ('vertplante',),
'vertsdyr': ('vertsdyr',),
'vertsdyra': ('vertsdyr',),
'vertsdyrene': ('vertsdyr',),
'vertsdyret': ('vertsdyr',),
'vertsfolk': ('vertsfolk',),
'vertsfolka': ('vertsfolk',),
'vertsfolkene': ('vertsfolk',),
'vertsfolket': ('vertsfolk',),
'vertshus': ('vertshus',),
'vertshusa': ('vertshus',),
'vertshusene': ('vertshus',),
'vertshuset': ('vertshus',),
'vertshusholder': ('vertshusholder',),
'vertshusholdere': ('vertshusholder',),
'vertshusholderen': ('vertshusholder',),
'vertshusholderer': ('vertshusholder',),
'vertshusholderne': ('vertshusholder',),
'vertskap': ('vertskap',),
'vertskapa': ('vertskap',),
'vertskapene': ('vertskap',),
'vertskaper': ('vertskap',),
'vertskapet': ('vertskap',),
'vertskifta': ('vertskifte',),
'vertskifte': ('vertskifte',),
'vertskiftene': ('vertskifte',),
'vertskifter': ('vertskifte',),
'vertskiftet': ('vertskifte',),
'vertsland': ('vertsland',),
'vertslanda': ('vertsland',),
'vertslandene': ('vertsland',),
'vertslandet': ('vertsland',),
'vertsmaskin': ('vertsmaskin',),
'vertsmaskina': ('vertsmaskin',),
'vertsmaskinen': ('vertsmaskin',),
'vertsmaskinene': ('vertsmaskin',),
'vertsmaskiner': ('vertsmaskin',),
'vertsplanta': ('vertsplante',),
'vertsplante': ('vertsplante',),
'vertsplanten': ('vertsplante',),
'vertsplantene': ('vertsplante',),
'vertsplanter': ('vertsplante',),
'vertsskifta': ('vertsskifte',),
'vertsskifte': ('vertsskifte',),
'vertsskiftene': ('vertsskifte',),
'vertsskifter': ('vertsskifte',),
'vertsskiftet': ('vertsskifte',),
'verv': ('verv',),
'verven': ('verv',),
'vervene': ('verv',),
'verver': ('verv',),
'verv': ('verv',),
'verva': ('verv',),
'vervene': ('verv',),
'vervet': ('verv',),
'verver': ('verver',),
'ververe': ('verver',),
'ververen': ('verver',),
'ververer': ('verver',),
'ververne': ('verver',),
'vesaldom': ('vesaldom',),
'vesaldommen': ('vesaldom',),
'vesaldommene': ('vesaldom',),
'vesaldommer': ('vesaldom',),
'vesel': ('vesel',),
'veselen': ('vesel',),
'veslene': ('vesel',),
'vesler': ('vesel',),
'vesen': ('vesen',),
'vesena': ('vesen',),
'vesenene': ('vesen',),
'vesener': ('vesen',),
'vesenet': ('vesen',),
'vesensforskjell': ('vesensforskjell',),
'vesensforskjellen': ('vesensforskjell',),
'vesensforskjellene': ('vesensforskjell',),
'vesensforskjeller': ('vesensforskjell',),
'vesentlighet': ('vesentlighet',),
'vesentligheta': ('vesentlighet',),
'vesentligheten': ('vesentlighet',),
'vesentlighetene': ('vesentlighet',),
'vesentligheter': ('vesentlighet',),
'vesikkel': ('vesikkel',),
'vesikkelen': ('vesikkel',),
'vesiklene': ('vesikkel',),
'vesikler': ('vesikkel',),
'vesir': ('vesir',),
'vesiren': ('vesir',),
'vesirene': ('vesir',),
'vesirer': ('vesir',),
'veska': ('veske',),
'veske': ('veske',),
'vesken': ('veske',),
'veskene': ('veske',),
'vesker': ('veske',),
'veskenapper': ('veskenapper',),
'veskenappere': ('veskenapper',),
'veskenapperen': ('veskenapper',),
'veskenapperer': ('veskenapper',),
'veskenapperne': ('veskenapper',),
'veskenapping': ('veskenapping',),
'veskenappinga': ('veskenapping',),
'veskenappingen': ('veskenapping',),
'veskenappingene': ('veskenapping',),
'veskenappinger': ('veskenapping',),
'vesketjuv': ('vesketjuv',),
'vesketjuven': ('vesketjuv',),
'vesketjuvene': ('vesketjuv',),
'vesketjuver': ('vesketjuv',),
'vesketyv': ('vesketyv',),
'vesketyven': ('vesketyv',),
'vesketyvene': ('vesketyv',),
'vesketyver': ('vesketyv',),
'vesla': ('vesla',),
'veslebror': ('veslebror',),
'veslebroren': ('veslebror',),
'veslebrødre': ('veslebror',),
'veslebrødrene': ('veslebror',),
'veslegutt': ('veslegutt',),
'veslegutten': ('veslegutt',),
'vesleguttene': ('veslegutt',),
'veslegutter': ('veslegutt',),
'veslehus': ('veslehus',),
'veslehusa': ('veslehus',),
'veslehusene': ('veslehus',),
'veslehuset': ('veslehus',),
'veslesøster': ('veslesøster',),
'veslesøstera': ('veslesøster',),
'veslesøsteren': ('veslesøster',),
'veslesøstre': ('veslesøster',),
'veslesøstrene': ('veslesøster',),
'veslesøstrer': ('veslesøster',),
'vesling': ('vesling',),
'veslingen': ('vesling',),
'veslingene': ('vesling',),
'veslinger': ('vesling',),
'vesper': ('vesper',),
'vespere': ('vesper',),
'vesperen': ('vesper',),
'vesperer': ('vesper',),
'vesperne': ('vesper',),
'vest': ('vest',),
'vesten': ('vest',),
'vestene': ('vest',),
'vester': ('vest',),
'vest': ('vest',),
'vesta': ('vest',),
'vestene': ('vest',),
'vestet': ('vest',),
'vestadrag': ('vestadrag',),
'vestadraga': ('vestadrag',),
'vestadragene': ('vestadrag',),
'vestadraget': ('vestadrag',),
'vestafrikaner': ('vestafrikaner',),
'vestafrikanere': ('vestafrikaner',),
'vestafrikaneren': ('vestafrikaner',),
'vestafrikanerer': ('vestafrikaner',),
'vestafrikanerne': ('vestafrikaner',),
'vestalinna': ('vestalinne',),
'vestalinne': ('vestalinne',),
'vestalinnen': ('vestalinne',),
'vestalinnene': ('vestalinne',),
'vestalinner': ('vestalinne',),
'vestapa': ('vestape',),
'vestape': ('vestape',),
'vestapen': ('vestape',),
'vestapene': ('vestape',),
'vestaper': ('vestape',),
'vestasiat': ('vestasiat',),
'vestasiaten': ('vestasiat',),
'vestasiatene': ('vestasiat',),
'vestasiater': ('vestasiat',),
'vestavind': ('vestavind',),
'vestavinden': ('vestavind',),
'vestavindene': ('vestavind',),
'vestavinder': ('vestavind',),
'vestavær': ('vestavær',),
'vestaværa': ('vestavær',),
'vestaværene': ('vestavær',),
'vestaværet': ('vestavær',),
'vestblokk': ('vestblokk',),
'vestblokka': ('vestblokk',),
'vestblokken': ('vestblokk',),
'vestblokkene': ('vestblokk',),
'vestblokker': ('vestblokk',),
'vestegd': ('vestegd',),
'vestegden': ('vestegd',),
'vestegdene': ('vestegd',),
'vestegder': ('vestegd',),
'vestegde': ('vestegde',),
'vestegden': ('vestegde',),
'vestegdene': ('vestegde',),
'vestegder': ('vestegde',),
'vesteknapp': ('vesteknapp',),
'vesteknappen': ('vesteknapp',),
'vesteknappene': ('vesteknapp',),
'vesteknapper': ('vesteknapp',),
'vestelomma': ('vestelomme',),
'vestelomme': ('vestelomme',),
'vestelommen': ('vestelomme',),
'vestelommene': ('vestelomme',),
'vestelommer': ('vestelomme',),
'vesterhavsøy': ('vesterhavsøy',),
'vesterhavsøya': ('vesterhavsøy',),
'vesterhavsøyen': ('vesterhavsøy',),
'vesterhavsøyene': ('vesterhavsøy',),
'vesterhavsøyer': ('vesterhavsøy',),
'vesterland': ('vesterland',),
'vesterlanda': ('vesterland',),
'vesterlandene': ('vesterland',),
'vesterlandet': ('vesterland',),
'vesterled': ('vesterled',),
'vesterleden': ('vesterled',),
'vesterledene': ('vesterled',),
'vesterleder': ('vesterled',),
'vesterlending': ('vesterlending',),
'vesterlendingen': ('vesterlending',),
'vesterlendingene': ('vesterlending',),
'vesterlendinger': ('vesterlending',),
'vesterveg': ('vesterveg',),
'vestervegen': ('vesterveg',),
'vestervegene': ('vesterveg',),
'vesterveger': ('vesterveg',),
'vesteuropeer': ('vesteuropeer',),
'vesteuropeere': ('vesteuropeer',),
'vesteuropeeren': ('vesteuropeer',),
'vesteuropeerer': ('vesteuropeer',),
'vesteuropeerne': ('vesteuropeer',),
'vestfolding': ('vestfolding',),
'vestfoldingen': ('vestfolding',),
'vestfoldingene': ('vestfolding',),
'vestfoldinger': ('vestfolding',),
'vestgermansk': ('vestgermansk',),
'vestgermansken': ('vestgermansk',),
'vestgermanskene': ('vestgermansk',),
'vestgermansker': ('vestgermansk',),
'vestgoter': ('vestgoter',),
'vestgotere': ('vestgoter',),
'vestgoteren': ('vestgoter',),
'vestgoterer': ('vestgoter',),
'vestgoterne': ('vestgoter',),
'vestgotisk': ('vestgotisk',),
'vestgotisken': ('vestgotisk',),
'vestgotiskene': ('vestgotisk',),
'vestgotisker': ('vestgotisk',),
'vesthelling': ('vesthelling',),
'vesthellinga': ('vesthelling',),
'vesthellingen': ('vesthelling',),
'vesthellingene': ('vesthelling',),
'vesthellinger': ('vesthelling',),
'vesthimlene': ('vesthimmel',),
'vesthimler': ('vesthimmel',),
'vesthimmel': ('vesthimmel',),
'vesthimmelen': ('vesthimmel',),
'vestibyle': ('vestibyle',),
'vestibylen': ('vestibyle',),
'vestibylene': ('vestibyle',),
'vestibyler': ('vestibyle',),
'vestindier': ('vestindier',),
'vestindiere': ('vestindier',),
'vestindieren': ('vestindier',),
'vestindierer': ('vestindier',),
'vestindierne': ('vestindier',),
'vestkant': ('vestkant',),
'vestkanten': ('vestkant',),
'vestkantene': ('vestkant',),
'vestkanter': ('vestkant',),
'vestkantstrøk': ('vestkantstrøk',),
'vestkantstrøka': ('vestkantstrøk',),
'vestkantstrøkene': ('vestkantstrøk',),
'vestkantstrøket': ('vestkantstrøk',),
'vestknapp': ('vestknapp',),
'vestknappen': ('vestknapp',),
'vestknappene': ('vestknapp',),
'vestknapper': ('vestknapp',),
'vestkyst': ('vestkyst',),
'vestkysten': ('vestkyst',),
'vestkystene': ('vestkyst',),
'vestkyster': ('vestkyst',),
'vestlandsfanden': ('vestlandsfanden',),
'vestlandsk': ('vestlandsk',),
'vestlandsken': ('vestlandsk',),
'vestlandskene': ('vestlandsk',),
'vestlandsker': ('vestlandsk',),
'vestlandspanel': ('vestlandspanel',),
'vestlandspanela': ('vestlandspanel',),
'vestlandspanelene': ('vestlandspanel',),
'vestlandspaneler': ('vestlandspanel',),
'vestlandspanelet': ('vestlandspanel',),
'vestlending': ('vestlending',),
'vestlendingen': ('vestlending',),
'vestlendingene': ('vestlending',),
'vestlendinger': ('vestlending',),
'vestlomma': ('vestlomme',),
'vestlomme': ('vestlomme',),
'vestlommen': ('vestlomme',),
'vestlommene': ('vestlomme',),
'vestlommer': ('vestlomme',),
'vestmakt': ('vestmakt',),
'vestmakta': ('vestmakt',),
'vestmakten': ('vestmakt',),
'vestmaktene': ('vestmakt',),
'vestmakter': ('vestmakt',),
'vestmark': ('vestmark',),
'vestmarka': ('vestmark',),
'vestmarken': ('vestmark',),
'vestmarkene': ('vestmark',),
'vestnorsk': ('vestnorsk',),
'vestnorsken': ('vestnorsk',),
'vestnorskene': ('vestnorsk',),
'vestnorsker': ('vestnorsk',),
'vestsamoaner': ('vestsamoaner',),
'vestsamoanere': ('vestsamoaner',),
'vestsamoaneren': ('vestsamoaner',),
'vestsamoanerer': ('vestsamoaner',),
'vestsamoanerne': ('vestsamoaner',),
'vestsida': ('vestside',),
'vestside': ('vestside',),
'vestsiden': ('vestside',),
'vestsidene': ('vestside',),
'vestsider': ('vestside',),
'vesttysker': ('vesttysker',),
'vesttyskere': ('vesttysker',),
'vesttyskeren': ('vesttysker',),
'vesttyskerer': ('vesttysker',),
'vesttyskerne': ('vesttysker',),
'vete': ('vete',),
'veten': ('vete',),
'vetene': ('vete',),
'veter': ('vete',),
'veteran': ('veteran',),
'veteranen': ('veteran',),
'veteranene': ('veteran',),
'veteraner': ('veteran',),
'veteranbil': ('veteranbil',),
'veteranbilen': ('veteranbil',),
'veteranbilene': ('veteranbil',),
'veteranbiler': ('veteranbil',),
'veteranskip': ('veteranskip',),
'veteranskipa': ('veteranskip',),
'veteranskipene': ('veteranskip',),
'veteranskipet': ('veteranskip',),
'veterinær': ('veterinær',),
'veterinæren': ('veterinær',),
'veterinærene': ('veterinær',),
'veterinærer': ('veterinær',),
'veterinærhøgskole': ('veterinærhøgskole',),
'veterinærhøgskolen': ('veterinærhøgskole',),
'veterinærhøgskolene': ('veterinærhøgskole',),
'veterinærhøgskoler': ('veterinærhøgskole',),
'veterinærhøyskole': ('veterinærhøyskole',),
'veterinærhøyskolen': ('veterinærhøyskole',),
'veterinærhøyskolene': ('veterinærhøyskole',),
'veterinærhøyskoler': ('veterinærhøyskole',),
'veterinærtilsyn': ('veterinærtilsyn',),
'veterinærtilsyna': ('veterinærtilsyn',),
'veterinærtilsynene': ('veterinærtilsyn',),
'veterinærtilsynet': ('veterinærtilsyn',),
'veterinærvesen': ('veterinærvesen',),
'veterinærvesena': ('veterinærvesen',),
'veterinærvesenene': ('veterinærvesen',),
'veterinærvesener': ('veterinærvesen',),
'veterinærvesenet': ('veterinærvesen',),
'veterinærvitenskap': ('veterinærvitenskap',),
'veterinærvitenskapen': ('veterinærvitenskap',),
'veterinærvitenskapene': ('veterinærvitenskap',),
'veterinærvitenskaper': ('veterinærvitenskap',),
'veterinærvitskap': ('veterinærvitskap',),
'veterinærvitskapen': ('veterinærvitskap',),
'veterinærvitskapene': ('veterinærvitskap',),
'veterinærvitskaper': ('veterinærvitskap',),
'veto': ('veto',),
'vetoa': ('veto',),
'vetoene': ('veto',),
'vetoer': ('veto',),
'vetoet': ('veto',),
'vetorett': ('vetorett',),
'vetoretten': ('vetorett',),
'vetorettene': ('vetorett',),
'vetoretter': ('vetorett',),
'vetostrid': ('vetostrid',),
'vetostriden': ('vetostrid',),
'vetostridene': ('vetostrid',),
'vetostrider': ('vetostrid',),
'vett': ('vett',),
'vetta': ('vett',),
'vettene': ('vett',),
'vettet': ('vett',),
'vetta': ('vette',),
'vette': ('vette',),
'vetten': ('vette',),
'vettene': ('vette',),
'vetter': ('vette',),
'vettet': ('vette',),
'vettefolk': ('vettefolk',),
'vettefolka': ('vettefolk',),
'vettefolkene': ('vettefolk',),
'vettefolket': ('vettefolk',),
'vettugskap': ('vettugskap',),
'vettugskapen': ('vettugskap',),
'vettugskapene': ('vettugskap',),
'vettugskaper': ('vettugskap',),
'veum': ('veum',),
'vev': ('vev',),
'veven': ('vev',),
'vevene': ('vev',),
'vever': ('vev',),
'vev': ('vev',),
'veva': ('vev',),
'vevene': ('vev',),
'vevet': ('vev',),
'vevbom': ('vevbom',),
'vevbommen': ('vevbom',),
'vevbommene': ('vevbom',),
'vevbommer': ('vevbom',),
'vever': ('vever',),
'vevere': ('vever',),
'veveren': ('vever',),
'veverer': ('vever',),
'veverne': ('vever',),
'veverfugl': ('veverfugl',),
'veverfuglen': ('veverfugl',),
'veverfuglene': ('veverfugl',),
'veverfugler': ('veverfugl',),
'veveri': ('veveri',),
'veveria': ('veveri',),
'veveriene': ('veveri',),
'veverier': ('veveri',),
'veveriet': ('veveri',),
'veverska': ('veverske',),
'veverske': ('veverske',),
'veversken': ('veverske',),
'veverskene': ('veverske',),
'veversker': ('veverske',),
'vevgogn': ('vevgogn',),
'vevgogna': ('vevgogn',),
'vevgognen': ('vevgogn',),
'vevgognene': ('vevgogn',),
'vevgogner': ('vevgogn',),
'veving': ('veving',),
'vevinga': ('veving',),
'vevingen': ('veving',),
'vevingene': ('veving',),
'vevinger': ('veving',),
'vevkjerring': ('vevkjerring',),
'vevkjerringa': ('vevkjerring',),
'vevkjerringen': ('vevkjerring',),
'vevkjerringene': ('vevkjerring',),
'vevkjerringer': ('vevkjerring',),
'vevkona': ('vevkone',),
'vevkone': ('vevkone',),
'vevkonen': ('vevkone',),
'vevkonene': ('vevkone',),
'vevkoner': ('vevkone',),
'vevling': ('vevling',),
'vevlingen': ('vevling',),
'vevlingene': ('vevling',),
'vevlinger': ('vevling',),
'vevlodd': ('vevlodd',),
'vevlodda': ('vevlodd',),
'vevloddene': ('vevlodd',),
'vevlodder': ('vevlodd',),
'vevloddet': ('vevlodd',),
'vevnad': ('vevnad',),
'vevnaden': ('vevnad',),
'vevnadene': ('vevnad',),
'vevnader': ('vevnad',),
'vevning': ('vevning',),
'vevninga': ('vevning',),
'vevningen': ('vevning',),
'vevningene': ('vevning',),
'vevninger': ('vevning',),
'vevskei': ('vevskei',),
'vevskeia': ('vevskei',),
'vevskeien': ('vevskei',),
'vevskeiene': ('vevskei',),
'vevskeier': ('vevskei',),
'vevskje': ('vevskje',),
'vevskjea': ('vevskje',),
'vevskjeen': ('vevskje',),
'vevskjeene': ('vevskje',),
'vevskjeer': ('vevskje',),
'vevskultur': ('vevskultur',),
'vevskulturen': ('vevskultur',),
'vevskulturene': ('vevskultur',),
'vevskulturer': ('vevskultur',),
'vevslæra': ('vevslære',),
'vevslære': ('vevslære',),
'vevslæren': ('vevslære',),
'vevslærene': ('vevslære',),
'vevslærer': ('vevslære',),
'vevstein': ('vevstein',),
'vevsteinen': ('vevstein',),
'vevsteinene': ('vevstein',),
'vevsteiner': ('vevstein',),
'vevstol': ('vevstol',),
'vevstolen': ('vevstol',),
'vevstolene': ('vevstol',),
'vevstoler': ('vevstol',),
'vevstype': ('vevstype',),
'vevstypen': ('vevstype',),
'vevstypene': ('vevstype',),
'vevstyper': ('vevstype',),
'vevsvæska': ('vevsvæske',),
'vevsvæske': ('vevsvæske',),
'vevsvæsken': ('vevsvæske',),
'vevsvæskene': ('vevsvæske',),
'vevsvæsker': ('vevsvæske',),
'viadukt': ('viadukt',),
'viadukten': ('viadukt',),
'viaduktene': ('viadukt',),
'viadukter': ('viadukt',),
'vibrafon': ('vibrafon',),
'vibrafonen': ('vibrafon',),
'vibrafonene': ('vibrafon',),
'vibrafoner': ('vibrafon',),
'vibrafonist': ('vibrafonist',),
'vibrafonisten': ('vibrafonist',),
'vibrafonistene': ('vibrafonist',),
'vibrafonister': ('vibrafonist',),
'vibrant': ('vibrant',),
'vibranten': ('vibrant',),
'vibrantene': ('vibrant',),
'vibranter': ('vibrant',),
'vibrasjon': ('vibrasjon',),
'vibrasjonen': ('vibrasjon',),
'vibrasjonene': ('vibrasjon',),
'vibrasjoner': ('vibrasjon',),
'vibrato': ('vibrato',),
'vibratoa': ('vibrato',),
'vibratoen': ('vibrato',),
'vibratoene': ('vibrato',),
'vibratoer': ('vibrato',),
'vibratoet': ('vibrato',),
'vibrator': ('vibrator',),
'vibratoren': ('vibrator',),
'vibratorene': ('vibrator',),
'vibratorer': ('vibrator',),
'vibrion': ('vibrion',),
'vibrionen': ('vibrion',),
'vibrionene': ('vibrion',),
'vibrioner': ('vibrion',),
'vibriose': ('vibriose',),
'vibriosen': ('vibriose',),
'vibriosene': ('vibriose',),
'vibrioser': ('vibriose',),
'vibrobetong': ('vibrobetong',),
'vibrobetongen': ('vibrobetong',),
'vibrobetongene': ('vibrobetong',),
'vibrobetonger': ('vibrobetong',),
'vibroskop': ('vibroskop',),
'vibroskopa': ('vibroskop',),
'vibroskopene': ('vibroskop',),
'vibroskoper': ('vibroskop',),
'vibroskopet': ('vibroskop',),
'vicomte': ('vicomte',),
'vicomten': ('vicomte',),
'vicomtene': ('vicomte',),
'vicomter': ('vicomte',),
'vicomtessa': ('vicomtesse',),
'vicomtesse': ('vicomtesse',),
'vicomtessen': ('vicomtesse',),
'vicomtessene': ('vicomtesse',),
'vicomtesser': ('vicomtesse',),
'vidd': ('vidd',),
'vidda': ('vidd',),
'viddene': ('vidd',),
'viddet': ('vidd',),
'vidda': ('vidde',),
'vidde': ('vidde',),
'vidden': ('vidde',),
'viddene': ('vidde',),
'vidder': ('vidde',),
'vidda': ('vidde',),
'vidde': ('vidde',),
'vidden': ('vidde',),
'viddene': ('vidde',),
'vidder': ('vidde',),
'video': ('video',),
'videoen': ('video',),
'videoene': ('video',),
'videoer': ('video',),
'videoband': ('videoband',),
'videobanda': ('videoband',),
'videobandene': ('videoband',),
'videobandet': ('videoband',),
'videobånd': ('videobånd',),
'videobånda': ('videobånd',),
'videobåndene': ('videobånd',),
'videobåndet': ('videobånd',),
'videofilm': ('videofilm',),
'videofilmen': ('videofilm',),
'videofilmene': ('videofilm',),
'videofilmer': ('videofilm',),
'videogram': ('videogram',),
'videogramma': ('videogram',),
'videogrammene': ('videogram',),
'videogrammer': ('videogram',),
'videogrammet': ('videogram',),
'videokassett': ('videokassett',),
'videokassetten': ('videokassett',),
'videokassettene': ('videokassett',),
'videokassetter': ('videokassett',),
'videokassettspeller': ('videokassettspeller',),
'videokassettspellere': ('videokassettspeller',),
'videokassettspelleren': ('videokassettspeller',),
'videokassettspellerer': ('videokassettspeller',),
'videokassettspellerne': ('videokassettspeller',),
'videokassettspiller': ('videokassettspiller',),
'videokassettspillere': ('videokassettspiller',),
'videokassettspilleren': ('videokassettspiller',),
'videokassettspillerer': ('videokassettspiller',),
'videokassettspillerne': ('videokassettspiller',),
'videomaskin': ('videomaskin',),
'videomaskina': ('videomaskin',),
'videomaskinen': ('videomaskin',),
'videomaskinene': ('videomaskin',),
'videomaskiner': ('videomaskin',),
'videoproduksjon': ('videoproduksjon',),
'videoproduksjonen': ('videoproduksjon',),
'videoproduksjonene': ('videoproduksjon',),
'videoproduksjoner': ('videoproduksjon',),
'videoprodusent': ('videoprodusent',),
'videoprodusenten': ('videoprodusent',),
'videoprodusentene': ('videoprodusent',),
'videoprodusenter': ('videoprodusent',),
'videospell': ('videospell',),
'videospella': ('videospell',),
'videospellene': ('videospell',),
'videospellet': ('videospell',),
'videospill': ('videospill',),
'videospilla': ('videospill',),
'videospillene': ('videospill',),
'videospillet': ('videospill',),
'videotek': ('videotek',),
'videoteka': ('videotek',),
'videotekene': ('videotek',),
'videoteker': ('videotek',),
'videoteket': ('videotek',),
'videovold': ('videovold',),
'videovolden': ('videovold',),
'videovoldene': ('videovold',),
'videovolder': ('videovold',),
'videresalg': ('videresalg',),
'videresalga': ('videresalg',),
'videresalgene': ('videresalg',),
'videresalget': ('videresalg',),
'videreutdannelse': ('videreutdannelse',),
'videreutdannelsen': ('videreutdannelse',),
'videreutdannelsene': ('videreutdannelse',),
'videreutdannelser': ('videreutdannelse',),
'videreutdanning': ('videreutdanning',),
'videreutdanninga': ('videreutdanning',),
'videreutdanningen': ('videreutdanning',),
'videreutdanningene': ('videreutdanning',),
'videreutdanninger': ('videreutdanning',),
'viderverdighet': ('viderverdighet',),
'viderverdigheta': ('viderverdighet',),
'viderverdigheten': ('viderverdighet',),
'viderverdighetene': ('viderverdighet',),
'viderverdigheter': ('viderverdighet',),
'vidfilm': ('vidfilm',),
'vidfilmen': ('vidfilm',),
'vidfilmene': ('vidfilm',),
'vidfilmer': ('vidfilm',),
'vidisse': ('vidisse',),
'vidissen': ('vidisse',),
'vidissene': ('vidisse',),
'vidisser': ('vidisse',),
'vidja': ('vidje',),
'vidje': ('vidje',),
'vidjen': ('vidje',),
'vidjene': ('vidje',),
'vidjer': ('vidje',),
'vidjeband': ('vidjeband',),
'vidjebanda': ('vidjeband',),
'vidjebandene': ('vidjeband',),
'vidjebandet': ('vidjeband',),
'vidjebånd': ('vidjebånd',),
'vidjebånda': ('vidjebånd',),
'vidjebåndene': ('vidjebånd',),
'vidjebåndet': ('vidjebånd',),
'vidjekorg': ('vidjekorg',),
'vidjekorga': ('vidjekorg',),
'vidjekorgen': ('vidjekorg',),
'vidjekorgene': ('vidjekorg',),
'vidjekorger': ('vidjekorg',),
'vidjekurv': ('vidjekurv',),
'vidjekurva': ('vidjekurv',),
'vidjekurven': ('vidjekurv',),
'vidjekurvene': ('vidjekurv',),
'vidjekurver': ('vidjekurv',),
'vidjepil': ('vidjepil',),
'vidjepila': ('vidjepil',),
'vidjepilen': ('vidjepil',),
'vidjepilene': ('vidjepil',),
'vidjepiler': ('vidjepil',),
'vidjespenning': ('vidjespenning',),
'vidjespenninga': ('vidjespenning',),
'vidjespenningen': ('vidjespenning',),
'vidjespenningene': ('vidjespenning',),
'vidjespenninger': ('vidjespenning',),
'vidsyn': ('vidsyn',),
'vidsyna': ('vidsyn',),
'vidsynene': ('vidsyn',),
'vidsynet': ('vidsyn',),
'vidunder': ('vidunder',),
'vidundera': ('vidunder',),
'vidundere': ('vidunder',),
'vidunderet': ('vidunder',),
'vidunderne': ('vidunder',),
'vidundra': ('vidunder',),
'vidundre': ('vidunder',),
'vidundrene': ('vidunder',),
'vidundret': ('vidunder',),
'vidunderbarn': ('vidunderbarn',),
'vidunderbarna': ('vidunderbarn',),
'vidunderbarnene': ('vidunderbarn',),
'vidunderbarnet': ('vidunderbarn',),
'vidunderdoktor': ('vidunderdoktor',),
'vidunderdoktoren': ('vidunderdoktor',),
'vidunderdoktorene': ('vidunderdoktor',),
'vidunderdoktorer': ('vidunderdoktor',),
'vidundermedisin': ('vidundermedisin',),
'vidundermedisinen': ('vidundermedisin',),
'vidundermedisinene': ('vidundermedisin',),
'vidundermedisiner': ('vidundermedisin',),
'vidvank': ('vidvank',),
'vidvanke': ('vidvanke',),
'vidvinkel': ('vidvinkel',),
'vidvinkelen': ('vidvinkel',),
'vidvinklene': ('vidvinkel',),
'vidvinkler': ('vidvinkel',),
'vidvinkelfilm': ('vidvinkelfilm',),
'vidvinkelfilmen': ('vidvinkelfilm',),
'vidvinkelfilmene': ('vidvinkelfilm',),
'vidvinkelfilmer': ('vidvinkelfilm',),
'vidvinkelkamera': ('vidvinkelkamera',),
'vidvinkelkameraene': ('vidvinkelkamera',),
'vidvinkelkameraer': ('vidvinkelkamera',),
'vidvinkelkameraet': ('vidvinkelkamera',),
'vidvinkelobjektiv': ('vidvinkelobjektiv',),
'vidvinkelobjektiva': ('vidvinkelobjektiv',),
'vidvinkelobjektivene': ('vidvinkelobjektiv',),
'vidvinkelobjektiver': ('vidvinkelobjektiv',),
'vidvinkelobjektivet': ('vidvinkelobjektiv',),
'vidvinkelopptak': ('vidvinkelopptak',),
'vidvinkelopptaka': ('vidvinkelopptak',),
'vidvinkelopptakene': ('vidvinkelopptak',),
'vidvinkelopptaket': ('vidvinkelopptak',),
'vidåtta': ('vidåtte',),
'vidåtte': ('vidåtte',),
'vidåtten': ('vidåtte',),
'vidåttene': ('vidåtte',),
'vidåtter': ('vidåtte',),
'vielse': ('vielse',),
'vielsen': ('vielse',),
'vielsene': ('vielse',),
'vielser': ('vielse',),
'vielsesattest': ('vielsesattest',),
'vielsesattesten': ('vielsesattest',),
'vielsesattestene': ('vielsesattest',),
'vielsesattester': ('vielsesattest',),
'vier': ('vier',),
'viere': ('vier',),
'vieren': ('vier',),
'vierer': ('vier',),
'vierne': ('vier',),
'vierbelta': ('vierbelte',),
'vierbelte': ('vierbelte',),
'vierbeltene': ('vierbelte',),
'vierbelter': ('vierbelte',),
'vierbeltet': ('vierbelte',),
'vierkjerr': ('vierkjerr',),
'vierkjerra': ('vierkjerr',),
'vierkjerrene': ('vierkjerr',),
'vierkjerret': ('vierkjerr',),
'vietnameser': ('vietnameser',),
'vietnamesere': ('vietnameser',),
'vietnameseren': ('vietnameser',),
'vietnameserer': ('vietnameser',),
'vietnameserne': ('vietnameser',),
'vietnamesisk': ('vietnamesisk',),
'vietnamesisken': ('vietnamesisk',),
'vietnamesiskene': ('vietnamesisk',),
'vietnamesisker': ('vietnamesisk',),
'vievann': ('vievann',),
'vievanna': ('vievann',),
'vievannene': ('vievann',),
'vievannet': ('vievann',),
'vievatn': ('vievatn',),
'vievatna': ('vievatn',),
'vievatnene': ('vievatn',),
'vievatnet': ('vievatn',),
'vift': ('vift',),
'viften': ('vift',),
'viftene': ('vift',),
'vifter': ('vift',),
'vift': ('vift',),
'vifta': ('vift',),
'viftene': ('vift',),
'viftet': ('vift',),
'vifta': ('vifte',),
'vifte': ('vifte',),
'viften': ('vifte',),
'viftene': ('vifte',),
'vifter': ('vifte',),
'vifteomn': ('vifteomn',),
'vifteomnen': ('vifteomn',),
'vifteomnene': ('vifteomn',),
'vifteomner': ('vifteomn',),
'vifteovn': ('vifteovn',),
'vifteovnen': ('vifteovn',),
'vifteovnene': ('vifteovn',),
'vifteovner': ('vifteovn',),
'viftepalme': ('viftepalme',),
'viftepalmen': ('viftepalme',),
'viftepalmene': ('viftepalme',),
'viftepalmer': ('viftepalme',),
'viftereim': ('viftereim',),
'viftereima': ('viftereim',),
'viftereimen': ('viftereim',),
'viftereimene': ('viftereim',),
'viftereimer': ('viftereim',),
'vigga': ('vigge',),
'vigge': ('vigge',),
'viggen': ('vigge',),
'viggene': ('vigge',),
'vigger': ('vigge',),
'vigilant': ('vigilant',),
'vigilanten': ('vigilant',),
'vigilantene': ('vigilant',),
'vigilanter': ('vigilant',),
'vigilie': ('vigilie',),
'vigilien': ('vigilie',),
'vigiliene': ('vigilie',),
'vigilier': ('vigilie',),
'vigler': ('vigler',),
'viglere': ('vigler',),
'vigleren': ('vigler',),
'viglerer': ('vigler',),
'viglerne': ('vigler',),
'vigleri': ('vigleri',),
'vigleria': ('vigleri',),
'vigleriene': ('vigleri',),
'viglerier': ('vigleri',),
'vigleriet': ('vigleri',),
'vignett': ('vignett',),
'vignetten': ('vignett',),
'vignettene': ('vignett',),
'vignetter': ('vignett',),
'vignettmelodi': ('vignettmelodi',),
'vignettmelodien': ('vignettmelodi',),
'vignettmelodiene': ('vignettmelodi',),
'vignettmelodier': ('vignettmelodi',),
'vigsel': ('vigsel',),
'vigselen': ('vigsel',),
'vigslene': ('vigsel',),
'vigsler': ('vigsel',),
'vigselattest': ('vigselattest',),
'vigselattesten': ('vigselattest',),
'vigselattestene': ('vigselattest',),
'vigselattester': ('vigselattest',),
'vigselmann': ('vigselmann',),
'vigselmannen': ('vigselmann',),
'vigselmenn': ('vigselmann',),
'vigselmennene': ('vigselmann',),
'vigselsattest': ('vigselsattest',),
'vigselsattesten': ('vigselsattest',),
'vigselsattestene': ('vigselsattest',),
'vigselsattester': ('vigselsattest',),
'vigselsmann': ('vigselsmann',),
'vigselsmannen': ('vigselsmann',),
'vigselsmenn': ('vigselsmann',),
'vigselsmennene': ('vigselsmann',),
'vigslevann': ('vigslevann',),
'vigslevanna': ('vigslevann',),
'vigslevannene': ('vigslevann',),
'vigslevannet': ('vigslevann',),
'vigslevatn': ('vigslevatn',),
'vigslevatna': ('vigslevatn',),
'vigslevatnene': ('vigslevatn',),
'vigslevatnet': ('vigslevatn',),
'vigør': ('vigør',),
'vigøren': ('vigør',),
'vigørene': ('vigør',),
'vigører': ('vigør',),
'vik': ('vik',),
'vika': ('vik',),
'viken': ('vik',),
'vikene': ('vik',),
'viker': ('vik',),
'vikamål': ('vikamål',),
'vikamåla': ('vikamål',),
'vikamålene': ('vikamål',),
'vikamålet': ('vikamål',),
'vikar': ('vikar',),
'vikaren': ('vikar',),
'vikarene': ('vikar',),
'vikarer': ('vikar',),
'vikariat': ('vikariat',),
'vikariata': ('vikariat',),
'vikariatene': ('vikariat',),
'vikariater': ('vikariat',),
'vikariatet': ('vikariat',),
'vikelse': ('vikelse',),
'vikelsen': ('vikelse',),
'vikelsene': ('vikelse',),
'vikelser': ('vikelse',),
'vikemanøver': ('vikemanøver',),
'vikemanøvere': ('vikemanøver',),
'vikemanøveren': ('vikemanøver',),
'vikemanøverne': ('vikemanøver',),
'vikemanøvre': ('vikemanøver',),
'vikemanøvrene': ('vikemanøver',),
'vikemanøvrer': ('vikemanøver',),
'vikeplikt': ('vikeplikt',),
'vikeplikta': ('vikeplikt',),
'vikeplikten': ('vikeplikt',),
'vikepliktene': ('vikeplikt',),
'vikeplikter': ('vikeplikt',),
'vikespor': ('vikespor',),
'vikespora': ('vikespor',),
'vikesporene': ('vikespor',),
'vikesporet': ('vikespor',),
'viking': ('viking',),
'vikingen': ('viking',),
'vikingene': ('viking',),
'vikinger': ('viking',),
'viking': ('viking',),
'vikingferd': ('vikingferd',),
'vikingferda': ('vikingferd',),
'vikingferden': ('vikingferd',),
'vikingferdene': ('vikingferd',),
'vikingferder': ('vikingferd',),
'vikingflåte': ('vikingflåte',),
'vikingflåten': ('vikingflåte',),
'vikingflåtene': ('vikingflåte',),
'vikingflåter': ('vikingflåte',),
'vikingrika': ('vikingrike',),
'vikingrike': ('vikingrike',),
'vikingrikene': ('vikingrike',),
'vikingriker': ('vikingrike',),
'vikingriket': ('vikingrike',),
'vikingskip': ('vikingskip',),
'vikingskipa': ('vikingskip',),
'vikingskipene': ('vikingskip',),
'vikingskipet': ('vikingskip',),
'vikingtid': ('vikingtid',),
'vikingtida': ('vikingtid',),
'vikingtiden': ('vikingtid',),
'vikingtidene': ('vikingtid',),
'vikingtider': ('vikingtid',),
'vikka': ('vikke',),
'vikke': ('vikke',),
'vikken': ('vikke',),
'vikkene': ('vikke',),
'vikker': ('vikke',),
'vikler': ('vikler',),
'viklere': ('vikler',),
'vikleren': ('vikler',),
'viklerer': ('vikler',),
'viklerne': ('vikler',),
'vikling': ('vikling',),
'viklinga': ('vikling',),
'viklingen': ('vikling',),
'viklingene': ('vikling',),
'viklinger': ('vikling',),
'viktigmaker': ('viktigmaker',),
'viktigmakere': ('viktigmaker',),
'viktigmakeren': ('viktigmaker',),
'viktigmakerer': ('viktigmaker',),
'viktigmakerne': ('viktigmaker',),
'viktigper': ('viktigper',),
'viktigperen': ('viktigper',),
'viktigperene': ('viktigper',),
'viktigperer': ('viktigper',),
'viktorianer': ('viktorianer',),
'viktorianere': ('viktorianer',),
'viktorianeren': ('viktorianer',),
'viktorianerer': ('viktorianer',),
'viktorianerne': ('viktorianer',),
'viktualiene': ('viktualier',),
'viktualier': ('viktualier',),
'vikværing': ('vikværing',),
'vikværingen': ('vikværing',),
'vikværingene': ('vikværing',),
'vikværinger': ('vikværing',),
'vilje': ('vilje',),
'viljen': ('vilje',),
'viljene': ('vilje',),
'viljer': ('vilje',),
'viljefrihet': ('viljefrihet',),
'viljefriheta': ('viljefrihet',),
'viljefriheten': ('viljefrihet',),
'viljefrihetene': ('viljefrihet',),
'viljefriheter': ('viljefrihet',),
'viljehands': ('viljehands',),
'viljehandsen': ('viljehands',),
'viljehandsene': ('viljehands',),
'viljehandser': ('viljehands',),
'viljekraft': ('viljekraft',),
'viljekrafta': ('viljekraft',),
'viljekraften': ('viljekraft',),
'viljekreftene': ('viljekraft',),
'viljekrefter': ('viljekraft',),
'viljeløshet': ('viljeløshet',),
'viljeløsheta': ('viljeløshet',),
'viljeløsheten': ('viljeløshet',),
'viljeløshetene': ('viljeløshet',),
'viljeløsheter': ('viljeløshet',),
'viljeløysa': ('viljeløyse',),
'viljeløyse': ('viljeløyse',),
'viljeløysen': ('viljeløyse',),
'viljeløysene': ('viljeløyse',),
'viljeløyser': ('viljeløyse',),
'viljesak': ('viljesak',),
'viljesaka': ('viljesak',),
'viljesaken': ('viljesak',),
'viljesakene': ('viljesak',),
'viljesaker': ('viljesak',),
'viljesakt': ('viljesakt',),
'viljesakta': ('viljesakt',),
'viljesakten': ('viljesakt',),
'viljesaktene': ('viljesakt',),
'viljesakter': ('viljesakt',),
'viljeserklæring': ('viljeserklæring',),
'viljeserklæringa': ('viljeserklæring',),
'viljeserklæringen': ('viljeserklæring',),
'viljeserklæringene': ('viljeserklæring',),
'viljeserklæringer': ('viljeserklæring',),
'viljesfrihet': ('viljesfrihet',),
'viljesfriheta': ('viljesfrihet',),
'viljesfriheten': ('viljesfrihet',),
'viljesfrihetene': ('viljesfrihet',),
'viljesfriheter': ('viljesfrihet',),
'viljeshandling': ('viljeshandling',),
'viljeshandlinga': ('viljeshandling',),
'viljeshandlingen': ('viljeshandling',),
'viljeshandlingene': ('viljeshandling',),
'viljeshandlinger': ('viljeshandling',),
'viljespørsmål': ('viljespørsmål',),
'viljespørsmåla': ('viljespørsmål',),
'viljespørsmålene': ('viljespørsmål',),
'viljespørsmålet': ('viljespørsmål',),
'viljessak': ('viljessak',),
'viljessaka': ('viljessak',),
'viljessaken': ('viljessak',),
'viljessakene': ('viljessak',),
'viljessaker': ('viljessak',),
'viljesspørsmål': ('viljesspørsmål',),
'viljesspørsmåla': ('viljesspørsmål',),
'viljesspørsmålene': ('viljesspørsmål',),
'viljesspørsmålet': ('viljesspørsmål',),
'viljestyrke': ('viljestyrke',),
'viljestyrken': ('viljestyrke',),
'viljestyrkene': ('viljestyrke',),
'viljestyrker': ('viljestyrke',),
'viljesverb': ('viljesverb',),
'viljesverba': ('viljesverb',),
'viljesverbene': ('viljesverb',),
'viljesverber': ('viljesverb',),
'viljesverbet': ('viljesverb',),
'viljesverba': ('viljesverbum',),
'viljesverbene': ('viljesverbum',),
'viljesverber': ('viljesverbum',),
'viljesverbet': ('viljesverbum',),
'viljesverbum': ('viljesverbum',),
'viljesverbumet': ('viljesverbum',),
'viljesytring': ('viljesytring',),
'viljesytringa': ('viljesytring',),
'viljesytringen': ('viljesytring',),
'viljesytringene': ('viljesytring',),
'viljesytringer': ('viljesytring',),
'vilkår': ('vilkår',),
'vilkåra': ('vilkår',),
'vilkårene': ('vilkår',),
'vilkåret': ('vilkår',),
'vilkårsdom': ('vilkårsdom',),
'vilkårsdommen': ('vilkårsdom',),
'vilkårsdommene': ('vilkårsdom',),
'vilkårsdommer': ('vilkårsdom',),
'vilkårskonjunksjon': ('vilkårskonjunksjon',),
'vilkårskonjunksjonen': ('vilkårskonjunksjon',),
'vilkårskonjunksjonene': ('vilkårskonjunksjon',),
'vilkårskonjunksjoner': ('vilkårskonjunksjon',),
'vilkårsrefleks': ('vilkårsrefleks',),
'vilkårsrefleksen': ('vilkårsrefleks',),
'vilkårsrefleksene': ('vilkårsrefleks',),
'vilkårsreflekser': ('vilkårsrefleks',),
'vilkårssetning': ('vilkårssetning',),
'vilkårssetninga': ('vilkårssetning',),
'vilkårssetningen': ('vilkårssetning',),
'vilkårssetningene': ('vilkårssetning',),
'vilkårssetninger': ('vilkårssetning',),
'villa': ('villa',),
'villaen': ('villa',),
'villaene': ('villa',),
'villaer': ('villa',),
'villabebyggelse': ('villabebyggelse',),
'villabebyggelsen': ('villabebyggelse',),
'villabebyggelsene': ('villabebyggelse',),
'villabebyggelser': ('villabebyggelse',),
'villaklausul': ('villaklausul',),
'villaklausulen': ('villaklausul',),
'villaklausulene': ('villaklausul',),
'villaklausuler': ('villaklausul',),
'villand': ('villand',),
'villanda': ('villand',),
'villanden': ('villand',),
'villendene': ('villand',),
'villender': ('villand',),
'villapal': ('villapal',),
'villapalen': ('villapal',),
'villapalene': ('villapal',),
'villapaler': ('villapal',),
'villastrøk': ('villastrøk',),
'villastrøka': ('villastrøk',),
'villastrøkene': ('villastrøk',),
'villastrøket': ('villastrøk',),
'villbasse': ('villbasse',),
'villbassen': ('villbasse',),
'villbassene': ('villbasse',),
'villbasser': ('villbasse',),
'villbringebær': ('villbringebær',),
'villbringebæra': ('villbringebær',),
'villbringebærene': ('villbringebær',),
'villbringebæret': ('villbringebær',),
'villbær': ('villbær',),
'villbæra': ('villbær',),
'villbærene': ('villbær',),
'villbæret': ('villbær',),
'villdyr': ('villdyr',),
'villdyra': ('villdyr',),
'villdyrene': ('villdyr',),
'villdyret': ('villdyr',),
'villa': ('ville',),
'ville': ('ville',),
'villen': ('ville',),
'villene': ('ville',),
'viller': ('ville',),
'villelse': ('villelse',),
'villelsen': ('villelse',),
'villelsene': ('villelse',),
'villelser': ('villelse',),
'villepla': ('villeple',),
'villeple': ('villeple',),
'villeplene': ('villeple',),
'villepler': ('villeple',),
'villeplet': ('villeple',),
'villfarelse': ('villfarelse',),
'villfarelsen': ('villfarelse',),
'villfarelsene': ('villfarelse',),
'villfarelser': ('villfarelse',),
'villhavre': ('villhavre',),
'villhavren': ('villhavre',),
'villhavrene': ('villhavre',),
'villhavrer': ('villhavre',),
'villing': ('villing',),
'villingen': ('villing',),
'villingene': ('villing',),
'villinger': ('villing',),
'villkatt': ('villkatt',),
'villkatten': ('villkatt',),
'villkattene': ('villkatt',),
'villkatter': ('villkatt',),
'villmann': ('villmann',),
'villmannen': ('villmann',),
'villmenn': ('villmann',),
'villmennene': ('villmann',),
'villmannsferd': ('villmannsferd',),
'villmannsferda': ('villmannsferd',),
'villmannsferden': ('villmannsferd',),
'villmannsferdene': ('villmannsferd',),
'villmannsferder': ('villmannsferd',),
'villmannsliv': ('villmannsliv',),
'villmannsliva': ('villmannsliv',),
'villmannslivene': ('villmannsliv',),
'villmannslivet': ('villmannsliv',),
'villmark': ('villmark',),
'villmarka': ('villmark',),
'villmarken': ('villmark',),
'villmarkene': ('villmark',),
'villmarker': ('villmark',),
'villmink': ('villmink',),
'villminken': ('villmink',),
'villminkene': ('villmink',),
'villminker': ('villmink',),
'villnis': ('villnis',),
'villnisa': ('villnis',),
'villnisene': ('villnis',),
'villniset': ('villnis',),
'villrede': ('villrede',),
'villrein': ('villrein',),
'villreinen': ('villrein',),
'villreinene': ('villrein',),
'villreiner': ('villrein',),
'villrot': ('villrot',),
'villrota': ('villrot',),
'villroten': ('villrot',),
'villrøttene': ('villrot',),
'villrøtter': ('villrot',),
'villskap': ('villskap',),
'villskapen': ('villskap',),
'villskapene': ('villskap',),
'villskaper': ('villskap',),
'villskott': ('villskott',),
'villskotta': ('villskott',),
'villskottene': ('villskott',),
'villskottet': ('villskott',),
'villskudd': ('villskudd',),
'villskudda': ('villskudd',),
'villskuddene': ('villskudd',),
'villskuddet': ('villskudd',),
'villspor': ('villspor',),
'villspora': ('villspor',),
'villsporene': ('villspor',),
'villsporet': ('villspor',),
'villstrå': ('villstrå',),
'villstråa': ('villstrå',),
'villstråene': ('villstrå',),
'villstrået': ('villstrå',),
'villstyring': ('villstyring',),
'villstyringen': ('villstyring',),
'villstyringene': ('villstyring',),
'villstyringer': ('villstyring',),
'villsvin': ('villsvin',),
'villsvina': ('villsvin',),
'villsvinene': ('villsvin',),
'villsvinet': ('villsvin',),
'villvest': ('villvest',),
'villvesten': ('villvest',),
'villvestene': ('villvest',),
'villvester': ('villvest',),
'villvestdrama': ('villvestdrama',),
'villvestdramaene': ('villvestdrama',),
'villvestdramaer': ('villvestdrama',),
'villvestdramaet': ('villvestdrama',),
'villvestfilm': ('villvestfilm',),
'villvestfilmen': ('villvestfilm',),
'villvestfilmene': ('villvestfilm',),
'villvestfilmer': ('villvestfilm',),
'villvin': ('villvin',),
'villvinen': ('villvin',),
'villvinene': ('villvin',),
'villviner': ('villvin',),
'vilska': ('vilske',),
'vilske': ('vilske',),
'vilsken': ('vilske',),
'vilskene': ('vilske',),
'vilsker': ('vilske',),
'vilt': ('vilt',),
'vilta': ('vilt',),
'viltene': ('vilt',),
'viltet': ('vilt',),
'viltbestand': ('viltbestand',),
'viltbestanden': ('viltbestand',),
'viltbestandene': ('viltbestand',),
'viltbestander': ('viltbestand',),
'viltbutikk': ('viltbutikk',),
'viltbutikken': ('viltbutikk',),
'viltbutikkene': ('viltbutikk',),
'viltbutikker': ('viltbutikk',),
'viltfreding': ('viltfreding',),
'viltfredinga': ('viltfreding',),
'viltfredingen': ('viltfreding',),
'viltfredingene': ('viltfreding',),
'viltfredinger': ('viltfreding',),
'viltfredning': ('viltfredning',),
'viltfredninga': ('viltfredning',),
'viltfredningen': ('viltfredning',),
'viltfredningene': ('viltfredning',),
'viltfredninger': ('viltfredning',),
'viltnemnd': ('viltnemnd',),
'viltnemnda': ('viltnemnd',),
'viltnemnden': ('viltnemnd',),
'viltnemndene': ('viltnemnd',),
'viltnemnder': ('viltnemnd',),
'viltpleia': ('viltpleie',),
'viltpleie': ('viltpleie',),
'viltpleien': ('viltpleie',),
'viltpleiene': ('viltpleie',),
'viltpleier': ('viltpleie',),
'viltråd': ('viltråd',),
'viltråda': ('viltråd',),
'viltrådene': ('viltråd',),
'viltrådet': ('viltråd',),
'viltsaus': ('viltsaus',),
'viltsausen': ('viltsaus',),
'viltsausene': ('viltsaus',),
'viltsauser': ('viltsaus',),
'viltskade': ('viltskade',),
'viltskaden': ('viltskade',),
'viltskadene': ('viltskade',),
'viltskader': ('viltskade',),
'viltspeil': ('viltspeil',),
'viltspeila': ('viltspeil',),
'viltspeilene': ('viltspeil',),
'viltspeilet': ('viltspeil',),
'viltstamme': ('viltstamme',),
'viltstammen': ('viltstamme',),
'viltstammene': ('viltstamme',),
'viltstammer': ('viltstamme',),
'viltstell': ('viltstell',),
'viltstella': ('viltstell',),
'viltstellene': ('viltstell',),
'viltstellet': ('viltstell',),
'viltstyra': ('viltstyre',),
'viltstyre': ('viltstyre',),
'viltstyrene': ('viltstyre',),
'viltstyrer': ('viltstyre',),
'viltstyret': ('viltstyre',),
'vilttrygdavgift': ('vilttrygdavgift',),
'vilttrygdavgifta': ('vilttrygdavgift',),
'vilttrygdavgiften': ('vilttrygdavgift',),
'vilttrygdavgiftene': ('vilttrygdavgift',),
'vilttrygdavgifter': ('vilttrygdavgift',),
'vim': ('vim',),
'vima': ('vim',),
'vimene': ('vim',),
'vimet': ('vim',),
'vima': ('vime',),
'vime': ('vime',),
'vimen': ('vime',),
'vimene': ('vime',),
'vimer': ('vime',),
'vimpel': ('vimpel',),
'vimpelen': ('vimpel',),
'vimplene': ('vimpel',),
'vimpler': ('vimpel',),
'vims': ('vims',),
'vimsen': ('vims',),
'vimsene': ('vims',),
'vimser': ('vims',),
'vin': ('vin',),
'vinen': ('vin',),
'vinene': ('vin',),
'viner': ('vin',),
'vinanker': ('vinanker',),
'vinankera': ('vinanker',),
'vinankere': ('vinanker',),
'vinankeret': ('vinanker',),
'vinankra': ('vinanker',),
'vinankre': ('vinanker',),
'vinankrene': ('vinanker',),
'vinankret': ('vinanker',),
'vinavl': ('vinavl',),
'vinavlen': ('vinavl',),
'vinavlene': ('vinavl',),
'vinavler': ('vinavl',),
'vinballong': ('vinballong',),
'vinballongen': ('vinballong',),
'vinballongene': ('vinballong',),
'vinballonger': ('vinballong',),
'vinberg': ('vinberg',),
'vinberga': ('vinberg',),
'vinbergene': ('vinberg',),
'vinberget': ('vinberg',),
'vind': ('vind',),
'vinden': ('vind',),
'vindene': ('vind',),
'vinder': ('vind',),
'vindbuksa': ('vindbukse',),
'vindbukse': ('vindbukse',),
'vindbuksen': ('vindbukse',),
'vindbuksene': ('vindbukse',),
'vindbukser': ('vindbukse',),
'vindbya': ('vindbye',),
'vindbye': ('vindbye',),
'vindbyen': ('vindbye',),
'vindbyene': ('vindbye',),
'vindbyer': ('vindbye',),
'vindbyga': ('vindbyge',),
'vindbyge': ('vindbyge',),
'vindbygen': ('vindbyge',),
'vindbygene': ('vindbyge',),
'vindbyger': ('vindbyge',),
'vindbøya': ('vindbøye',),
'vindbøye': ('vindbøye',),
'vindbøyen': ('vindbøye',),
'vindbøyene': ('vindbøye',),
'vindbøyer': ('vindbøye',),
'vinddrag': ('vinddrag',),
'vinddraga': ('vinddrag',),
'vinddragene': ('vinddrag',),
'vinddraget': ('vinddrag',),
'vinddreiing': ('vinddreiing',),
'vinddreiinga': ('vinddreiing',),
'vinddreiingen': ('vinddreiing',),
'vinddreiingene': ('vinddreiing',),
'vinddreiinger': ('vinddreiing',),
'vinddreining': ('vinddreining',),
'vinddreininga': ('vinddreining',),
'vinddreiningen': ('vinddreining',),
'vinddreiningene': ('vinddreining',),
'vinddreininger': ('vinddreining',),
'vinda': ('vinde',),
'vinde': ('vinde',),
'vinden': ('vinde',),
'vindene': ('vinde',),
'vinder': ('vinde',),
'vindebro': ('vindebro',),
'vindebroa': ('vindebro',),
'vindebroen': ('vindebro',),
'vindebroene': ('vindebro',),
'vindebroer': ('vindebro',),
'vindebru': ('vindebru',),
'vindebrua': ('vindebru',),
'vindebruen': ('vindebru',),
'vindebruene': ('vindebru',),
'vindebruer': ('vindebru',),
'vindegg': ('vindegg',),
'vindegga': ('vindegg',),
'vindeggene': ('vindegg',),
'vindegget': ('vindegg',),
'vindel': ('vindel',),
'vindelen': ('vindel',),
'vindlene': ('vindel',),
'vindler': ('vindel',),
'vindelfamilie': ('vindelfamilie',),
'vindelfamilien': ('vindelfamilie',),
'vindelfamiliene': ('vindelfamilie',),
'vindelfamilier': ('vindelfamilie',),
'vindeltrapp': ('vindeltrapp',),
'vindeltrappa': ('vindeltrapp',),
'vindeltrappen': ('vindeltrapp',),
'vindeltrappene': ('vindeltrapp',),
'vindeltrapper': ('vindeltrapp',),
'vindfall': ('vindfall',),
'vindfalla': ('vindfall',),
'vindfallene': ('vindfall',),
'vindfallet': ('vindfall',),
'vindfallstømmer': ('vindfallstømmer',),
'vindfallstømmera': ('vindfallstømmer',),
'vindfallstømmerene': ('vindfallstømmer',),
'vindfallstømmeret': ('vindfallstømmer',),
'vindfallstømra': ('vindfallstømmer',),
'vindfallstømre': ('vindfallstømmer',),
'vindfallstømrene': ('vindfallstømmer',),
'vindfang': ('vindfang',),
'vindfanga': ('vindfang',),
'vindfangene': ('vindfang',),
'vindfanget': ('vindfang',),
'vindfelling': ('vindfelling',),
'vindfellinga': ('vindfelling',),
'vindfellingen': ('vindfelling',),
'vindfellingene': ('vindfelling',),
'vindfellinger': ('vindfelling',),
'vindflaga': ('vindflage',),
'vindflage': ('vindflage',),
'vindflagen': ('vindflage',),
'vindflagene': ('vindflage',),
'vindflager': ('vindflage',),
'vindfløy': ('vindfløy',),
'vindfløya': ('vindfløy',),
'vindfløyen': ('vindfløy',),
'vindfløyene': ('vindfløy',),
'vindfløyer': ('vindfløy',),
'vindforhold': ('vindforhold',),
'vindforholda': ('vindforhold',),
'vindforholdene': ('vindforhold',),
'vindforholdet': ('vindforhold',),
'vindhane': ('vindhane',),
'vindhanen': ('vindhane',),
'vindhanene': ('vindhane',),
'vindhaner': ('vindhane',),
'vindharpa': ('vindharpe',),
'vindharpe': ('vindharpe',),
'vindharpen': ('vindharpe',),
'vindharpene': ('vindharpe',),
'vindharper': ('vindharpe',),
'vindhastighet': ('vindhastighet',),
'vindhastigheta': ('vindhastighet',),
'vindhastigheten': ('vindhastighet',),
'vindhastighetene': ('vindhastighet',),
'vindhastigheter': ('vindhastighet',),
'vindhol': ('vindhol',),
'vindhola': ('vindhol',),
'vindholene': ('vindhol',),
'vindholet': ('vindhol',),
'vindhull': ('vindhull',),
'vindhulla': ('vindhull',),
'vindhullene': ('vindhull',),
'vindhuller': ('vindhull',),
'vindhullet': ('vindhull',),
'vindikant': ('vindikant',),
'vindikanten': ('vindikant',),
'vindikantene': ('vindikant',),
'vindikanter': ('vindikant',),
'vindikasjon': ('vindikasjon',),
'vindikasjonen': ('vindikasjon',),
'vindikasjonene': ('vindikasjon',),
'vindikasjoner': ('vindikasjon',),
'vindikasjonsrett': ('vindikasjonsrett',),
'vindikasjonsretten': ('vindikasjonsrett',),
'vindikasjonsrettene': ('vindikasjonsrett',),
'vindikasjonsretter': ('vindikasjonsrett',),
'vinding': ('vinding',),
'vindinga': ('vinding',),
'vindingen': ('vinding',),
'vindingene': ('vinding',),
'vindinger': ('vinding',),
'vindjakka': ('vindjakke',),
'vindjakke': ('vindjakke',),
'vindjakken': ('vindjakke',),
'vindjakkene': ('vindjakke',),
'vindjakker': ('vindjakke',),
'vindkast': ('vindkast',),
'vindkasta': ('vindkast',),
'vindkastene': ('vindkast',),
'vindkastet': ('vindkast',),
'vindkraft': ('vindkraft',),
'vindkrafta': ('vindkraft',),
'vindkraften': ('vindkraft',),
'vindkreftene': ('vindkraft',),
'vindkrefter': ('vindkraft',),
'vindkraftverk': ('vindkraftverk',),
'vindkraftverka': ('vindkraftverk',),
'vindkraftverkene': ('vindkraftverk',),
'vindkraftverker': ('vindkraftverk',),
'vindkraftverket': ('vindkraftverk',),
'vindkula': ('vindkule',),
'vindkule': ('vindkule',),
'vindkulen': ('vindkule',),
'vindkulene': ('vindkule',),
'vindkuler': ('vindkule',),
'vindmaskin': ('vindmaskin',),
'vindmaskina': ('vindmaskin',),
'vindmaskinen': ('vindmaskin',),
'vindmaskinene': ('vindmaskin',),
'vindmaskiner': ('vindmaskin',),
'vindmotor': ('vindmotor',),
'vindmotoren': ('vindmotor',),
'vindmotorene': ('vindmotor',),
'vindmotorer': ('vindmotor',),
'vindmåler': ('vindmåler',),
'vindmålere': ('vindmåler',),
'vindmåleren': ('vindmåler',),
'vindmålerer': ('vindmåler',),
'vindmålerne': ('vindmåler',),
'vindmølla': ('vindmølle',),
'vindmølle': ('vindmølle',),
'vindmøllen': ('vindmølle',),
'vindmøllene': ('vindmølle',),
'vindmøller': ('vindmølle',),
'vindpust': ('vindpust',),
'vindpusta': ('vindpust',),
'vindpustene': ('vindpust',),
'vindpustet': ('vindpust',),
'vindpølsa': ('vindpølse',),
'vindpølse': ('vindpølse',),
'vindpølsen': ('vindpølse',),
'vindpølsene': ('vindpølse',),
'vindpølser': ('vindpølse',),
'vindretning': ('vindretning',),
'vindretninga': ('vindretning',),
'vindretningen': ('vindretning',),
'vindretningene': ('vindretning',),
'vindretninger': ('vindretning',),
'vindrosa': ('vindrose',),
'vindrose': ('vindrose',),
'vindrosen': ('vindrose',),
'vindrosene': ('vindrose',),
'vindroser': ('vindrose',),
'vindrossa': ('vindrosse',),
'vindrosse': ('vindrosse',),
'vindrossen': ('vindrosse',),
'vindrossene': ('vindrosse',),
'vindrosser': ('vindrosse',),
'vindrua': ('vindrue',),
'vindrue': ('vindrue',),
'vindruen': ('vindrue',),
'vindruene': ('vindrue',),
'vindruer': ('vindrue',),
'vindsel': ('vindsel',),
'vindselen': ('vindsel',),
'vindslene': ('vindsel',),
'vindsler': ('vindsel',),
'vindsida': ('vindside',),
'vindside': ('vindside',),
'vindsiden': ('vindside',),
'vindsidene': ('vindside',),
'vindsider': ('vindside',),
'vindskade': ('vindskade',),
'vindskaden': ('vindskade',),
'vindskadene': ('vindskade',),
'vindskader': ('vindskade',),
'vindskala': ('vindskala',),
'vindskalaen': ('vindskala',),
'vindskalaene': ('vindskala',),
'vindskalaer': ('vindskala',),
'vindski': ('vindski',),
'vindskia': ('vindski',),
'vindskien': ('vindski',),
'vindskiene': ('vindski',),
'vindskier': ('vindski',),
'vindskia': ('vindskie',),
'vindskie': ('vindskie',),
'vindskien': ('vindskie',),
'vindskiene': ('vindskie',),
'vindskier': ('vindskie',),
'vindskjerm': ('vindskjerm',),
'vindskjermen': ('vindskjerm',),
'vindskjermene': ('vindskjerm',),
'vindskjermer': ('vindskjerm',),
'vindstoff': ('vindstoff',),
'vindstoffa': ('vindstoff',),
'vindstoffene': ('vindstoff',),
'vindstoffer': ('vindstoff',),
'vindstoffet': ('vindstoff',),
'vindstyrke': ('vindstyrke',),
'vindstyrken': ('vindstyrke',),
'vindstyrkene': ('vindstyrke',),
'vindstyrker': ('vindstyrke',),
'vindtunnel': ('vindtunnel',),
'vindtunnelen': ('vindtunnel',),
'vindtunnelene': ('vindtunnel',),
'vindtunneler': ('vindtunnel',),
'vindturbin': ('vindturbin',),
'vindturbinen': ('vindturbin',),
'vindturbinene': ('vindturbin',),
'vindturbiner': ('vindturbin',),
'vindtøy': ('vindtøy',),
'vindtøya': ('vindtøy',),
'vindtøyene': ('vindtøy',),
'vindtøyer': ('vindtøy',),
'vindtøyet': ('vindtøy',),
'vindu': ('vindu',),
'vindua': ('vindu',),
'vinduene': ('vindu',),
'vinduer': ('vindu',),
'vinduet': ('vindu',),
'vindusglas': ('vindusglas',),
'vindusglasa': ('vindusglas',),
'vindusglasene': ('vindusglas',),
'vindusglaset': ('vindusglas',),
'vindusglass': ('vindusglass',),
'vindusglassa': ('vindusglass',),
'vindusglassene': ('vindusglass',),
'vindusglasset': ('vindusglass',),
'vindushasp': ('vindushasp',),
'vindushaspen': ('vindushasp',),
'vindushaspene': ('vindushasp',),
'vindushasper': ('vindushasp',),
'vindushaspe': ('vindushaspe',),
'vindushaspen': ('vindushaspe',),
'vindushaspene': ('vindushaspe',),
'vindushasper': ('vindushaspe',),
'vinduskarm': ('vinduskarm',),
'vinduskarmen': ('vinduskarm',),
'vinduskarmene': ('vinduskarm',),
'vinduskarmer': ('vinduskarm',),
'vinduskonvolutt': ('vinduskonvolutt',),
'vinduskonvolutten': ('vinduskonvolutt',),
'vinduskonvoluttene': ('vinduskonvolutt',),
'vinduskonvolutter': ('vinduskonvolutt',),
'vindusplass': ('vindusplass',),
'vindusplassen': ('vindusplass',),
'vindusplassene': ('vindusplass',),
'vindusplasser': ('vindusplass',),
'vinduspost': ('vinduspost',),
'vindusposten': ('vinduspost',),
'vinduspostene': ('vinduspost',),
'vindusposter': ('vinduspost',),
'vinduspusser': ('vinduspusser',),
'vinduspussere': ('vinduspusser',),
'vinduspusseren': ('vinduspusser',),
'vinduspusserer': ('vinduspusser',),
'vinduspusserne': ('vinduspusser',),
'vindusramma': ('vindusramme',),
'vindusramme': ('vindusramme',),
'vindusrammen': ('vindusramme',),
'vindusrammene': ('vindusramme',),
'vindusrammer': ('vindusramme',),
'vindusruta': ('vindusrute',),
'vindusrute': ('vindusrute',),
'vindusruten': ('vindusrute',),
'vindusrutene': ('vindusrute',),
'vindusruter': ('vindusrute',),
'vindussprossa': ('vindussprosse',),
'vindussprosse': ('vindussprosse',),
'vindussprossen': ('vindussprosse',),
'vindussprossene': ('vindussprosse',),
'vindussprosser': ('vindussprosse',),
'vindusspyler': ('vindusspyler',),
'vindusspylere': ('vindusspyler',),
'vindusspyleren': ('vindusspyler',),
'vindusspylerer': ('vindusspyler',),
'vindusspylerne': ('vindusspyler',),
'vindusutstilling': ('vindusutstilling',),
'vindusutstillinga': ('vindusutstilling',),
'vindusutstillingen': ('vindusutstilling',),
'vindusutstillingene': ('vindusutstilling',),
'vindusutstillinger': ('vindusutstilling',),
'vindusvisker': ('vindusvisker',),
'vindusviskere': ('vindusvisker',),
'vindusviskeren': ('vindusvisker',),
'vindusviskerer': ('vindusvisker',),
'vindusviskerne': ('vindusvisker',),
'vindvott': ('vindvott',),
'vindvotten': ('vindvott',),
'vindvottene': ('vindvott',),
'vindvotter': ('vindvott',),
'vindyrker': ('vindyrker',),
'vindyrkere': ('vindyrker',),
'vindyrkeren': ('vindyrker',),
'vindyrkerer': ('vindyrker',),
'vindyrkerne': ('vindyrker',),
'vineddik': ('vineddik',),
'vineddiken': ('vineddik',),
'vineddikene': ('vineddik',),
'vineddiker': ('vineddik',),
'vineger': ('vineger',),
'vinegeren': ('vineger',),
'vinegerene': ('vineger',),
'vinegerer': ('vineger',),
'vinfamilie': ('vinfamilie',),
'vinfamilien': ('vinfamilie',),
'vinfamiliene': ('vinfamilie',),
'vinfamilier': ('vinfamilie',),
'vinflaska': ('vinflaske',),
'vinflaske': ('vinflaske',),
'vinflasken': ('vinflaske',),
'vinflaskene': ('vinflaske',),
'vinflasker': ('vinflaske',),
'ving': ('ving',),
'vingen': ('ving',),
'vingene': ('ving',),
'vinger': ('ving',),
'ving': ('ving',),
'vingen': ('ving',),
'vingene': ('ving',),
'vinger': ('ving',),
'ving': ('ving',),
'vingen': ('ving',),
'vingene': ('ving',),
'vinger': ('ving',),
'vingard': ('vingard',),
'vingarden': ('vingard',),
'vingardene': ('vingard',),
'vingarder': ('vingard',),
'vingardssøndag': ('vingardssøndag',),
'vingardssøndagen': ('vingardssøndag',),
'vingardssøndagene': ('vingardssøndag',),
'vingardssøndager': ('vingardssøndag',),
'vinge': ('vinge',),
'vingen': ('vinge',),
'vingene': ('vinge',),
'vinger': ('vinge',),
'vinge': ('vinge',),
'vingen': ('vinge',),
'vingene': ('vinge',),
'vinger': ('vinge',),
'vingebein': ('vingebein',),
'vingebeina': ('vingebein',),
'vingebeinene': ('vingebein',),
'vingebeinet': ('vingebein',),
'vingebein': ('vingebein',),
'vingebeina': ('vingebein',),
'vingebeinene': ('vingebein',),
'vingebeinet': ('vingebein',),
'vingeben': ('vingeben',),
'vingebena': ('vingeben',),
'vingebenene': ('vingeben',),
'vingebenet': ('vingeben',),
'vingeben': ('vingeben',),
'vingebena': ('vingeben',),
'vingebenene': ('vingeben',),
'vingebenet': ('vingeben',),
'vingefang': ('vingefang',),
'vingefanga': ('vingefang',),
'vingefangene': ('vingefang',),
'vingefanget': ('vingefang',),
'vingefang': ('vingefang',),
'vingefanga': ('vingefang',),
'vingefangene': ('vingefang',),
'vingefanget': ('vingefang',),
'vingefrukt': ('vingefrukt',),
'vingefrukta': ('vingefrukt',),
'vingefrukten': ('vingefrukt',),
'vingefruktene': ('vingefrukt',),
'vingefrukter': ('vingefrukt',),
'vingefrukt': ('vingefrukt',),
'vingefrukta': ('vingefrukt',),
'vingefrukten': ('vingefrukt',),
'vingefruktene': ('vingefrukt',),
'vingefrukter': ('vingefrukt',),
'vingehest': ('vingehest',),
'vingehesten': ('vingehest',),
'vingehestene': ('vingehest',),
'vingehester': ('vingehest',),
'vingehest': ('vingehest',),
'vingehesten': ('vingehest',),
'vingehestene': ('vingehest',),
'vingehester': ('vingehest',),
'vingeklaff': ('vingeklaff',),
'vingeklaffen': ('vingeklaff',),
'vingeklaffene': ('vingeklaff',),
'vingeklaffer': ('vingeklaff',),
'vingeklaff': ('vingeklaff',),
'vingeklaffen': ('vingeklaff',),
'vingeklaffene': ('vingeklaff',),
'vingeklaffer': ('vingeklaff',),
'vingel': ('vingel',),
'vingelet': ('vingel',),
'vingla': ('vingel',),
'vinglene': ('vingel',),
'vingler': ('vingel',),
'vinglet': ('vingel',),
'vingemerka': ('vingemerke',),
'vingemerke': ('vingemerke',),
'vingemerkene': ('vingemerke',),
'vingemerker': ('vingemerke',),
'vingemerket': ('vingemerke',),
'vingemerka': ('vingemerke',),
'vingemerke': ('vingemerke',),
'vingemerkene': ('vingemerke',),
'vingemerker': ('vingemerke',),
'vingemerket': ('vingemerke',),
'vingemutrene': ('vingemutter',),
'vingemutrer': ('vingemutter',),
'vingemutter': ('vingemutter',),
'vingemuttere': ('vingemutter',),
'vingemutteren': ('vingemutter',),
'vingemutterer': ('vingemutter',),
'vingemutterne': ('vingemutter',),
'vingemutrene': ('vingemutter',),
'vingemutrer': ('vingemutter',),
'vingemutter': ('vingemutter',),
'vingemuttere': ('vingemutter',),
'vingemutteren': ('vingemutter',),
'vingemutterer': ('vingemutter',),
'vingemutterne': ('vingemutter',),
'vingepar': ('vingepar',),
'vingepara': ('vingepar',),
'vingeparene': ('vingepar',),
'vingeparet': ('vingepar',),
'vingepar': ('vingepar',),
'vingepara': ('vingepar',),
'vingeparene': ('vingepar',),
'vingeparet': ('vingepar',),
'vingeskrue': ('vingeskrue',),
'vingeskruen': ('vingeskrue',),
'vingeskruene': ('vingeskrue',),
'vingeskruer': ('vingeskrue',),
'vingeskrue': ('vingeskrue',),
'vingeskruen': ('vingeskrue',),
'vingeskruene': ('vingeskrue',),
'vingeskruer': ('vingeskrue',),
'vingeskruve': ('vingeskruve',),
'vingeskruven': ('vingeskruve',),
'vingeskruvene': ('vingeskruve',),
'vingeskruver': ('vingeskruve',),
'vingeskruve': ('vingeskruve',),
'vingeskruven': ('vingeskruve',),
'vingeskruvene': ('vingeskruve',),
'vingeskruver': ('vingeskruve',),
'vingeskutt': ('vingeskutt',),
'vingeskutta': ('vingeskutt',),
'vingeskuttene': ('vingeskutt',),
'vingeskuttet': ('vingeskutt',),
'vingeslag': ('vingeslag',),
'vingeslaga': ('vingeslag',),
'vingeslagene': ('vingeslag',),
'vingeslaget': ('vingeslag',),
'vingeslag': ('vingeslag',),
'vingeslaga': ('vingeslag',),
'vingeslagene': ('vingeslag',),
'vingeslaget': ('vingeslag',),
'vingespenn': ('vingespenn',),
'vingespenna': ('vingespenn',),
'vingespennene': ('vingespenn',),
'vingespennet': ('vingespenn',),
'vingespenn': ('vingespenn',),
'vingespenna': ('vingespenn',),
'vingespennene': ('vingespenn',),
'vingespennet': ('vingespenn',),
'vingesus': ('vingesus',),
'vingesusa': ('vingesus',),
'vingesusen': ('vingesus',),
'vingesusene': ('vingesus',),
'vingesuset': ('vingesus',),
'vingesus': ('vingesus',),
'vingesusa': ('vingesus',),
'vingesusen': ('vingesus',),
'vingesusene': ('vingesus',),
'vingesuset': ('vingesus',),
'vinghalf': ('vinghalf',),
'vinghalfen': ('vinghalf',),
'vinghalfene': ('vinghalf',),
'vinghalfer': ('vinghalf',),
'vinglekopp': ('vinglekopp',),
'vinglekoppen': ('vinglekopp',),
'vinglekoppene': ('vinglekopp',),
'vinglekopper': ('vinglekopp',),
'vingler': ('vingler',),
'vinglere': ('vingler',),
'vingleren': ('vingler',),
'vinglerer': ('vingler',),
'vinglerne': ('vingler',),
'vingleri': ('vingleri',),
'vingleria': ('vingleri',),
'vingleriene': ('vingleri',),
'vinglerier': ('vingleri',),
'vingleriet': ('vingleri',),
'vingsersjant': ('vingsersjant',),
'vingsersjanten': ('vingsersjant',),
'vingsersjantene': ('vingsersjant',),
'vingsersjanter': ('vingsersjant',),
'vingsjef': ('vingsjef',),
'vingsjefen': ('vingsjef',),
'vingsjefene': ('vingsjef',),
'vingsjefer': ('vingsjef',),
'vingsoldat': ('vingsoldat',),
'vingsoldaten': ('vingsoldat',),
'vingsoldatene': ('vingsoldat',),
'vingsoldater': ('vingsoldat',),
'vingspell': ('vingspell',),
'vingspella': ('vingspell',),
'vingspellene': ('vingspell',),
'vingspellet': ('vingspell',),
'vingspill': ('vingspill',),
'vingspilla': ('vingspill',),
'vingspillene': ('vingspill',),
'vingspillet': ('vingspill',),
'vingud': ('vingud',),
'vinguden': ('vingud',),
'vingudene': ('vingud',),
'vinguder': ('vingud',),
'vingård': ('vingård',),
'vingården': ('vingård',),
'vingårdene': ('vingård',),
'vingårder': ('vingård',),
'vingårdssøndag': ('vingårdssøndag',),
'vingårdssøndagen': ('vingårdssøndag',),
'vingårdssøndagene': ('vingårdssøndag',),
'vingårdssøndager': ('vingårdssøndag',),
'vinhus': ('vinhus',),
'vinhusa': ('vinhus',),
'vinhusene': ('vinhus',),
'vinhuset': ('vinhus',),
'vink': ('vink',),
'vinka': ('vink',),
'vinkene': ('vink',),
'vinket': ('vink',),
'vinkart': ('vinkart',),
'vinkarta': ('vinkart',),
'vinkartene': ('vinkart',),
'vinkarter': ('vinkart',),
'vinkartet': ('vinkart',),
'vinkel': ('vinkel',),
'vinkelen': ('vinkel',),
'vinklene': ('vinkel',),
'vinkler': ('vinkel',),
'vinkelbein': ('vinkelbein',),
'vinkelbeina': ('vinkelbein',),
'vinkelbeinene': ('vinkelbein',),
'vinkelbeinet': ('vinkelbein',),
'vinkelben': ('vinkelben',),
'vinkelbena': ('vinkelben',),
'vinkelbenene': ('vinkelben',),
'vinkelbenet': ('vinkelben',),
'vinkelboge': ('vinkelboge',),
'vinkelbogen': ('vinkelboge',),
'vinkelbogene': ('vinkelboge',),
'vinkelboger': ('vinkelboge',),
'vinkelbue': ('vinkelbue',),
'vinkelbuen': ('vinkelbue',),
'vinkelbuene': ('vinkelbue',),
'vinkelbuer': ('vinkelbue',),
'vinkelgrad': ('vinkelgrad',),
'vinkelgraden': ('vinkelgrad',),
'vinkelgradene': ('vinkelgrad',),
'vinkelgrader': ('vinkelgrad',),
'vinkelhake': ('vinkelhake',),
'vinkelhaken': ('vinkelhake',),
'vinkelhakene': ('vinkelhake',),
'vinkelhaker': ('vinkelhake',),
'vinkeljern': ('vinkeljern',),
'vinkeljerna': ('vinkeljern',),
'vinkeljernene': ('vinkeljern',),
'vinkeljernet': ('vinkeljern',),
'vinkelminutt': ('vinkelminutt',),
'vinkelminutta': ('vinkelminutt',),
'vinkelminuttene': ('vinkelminutt',),
'vinkelminutter': ('vinkelminutt',),
'vinkelminuttet': ('vinkelminutt',),
'vinkelmåler': ('vinkelmåler',),
'vinkelmålere': ('vinkelmåler',),
'vinkelmåleren': ('vinkelmåler',),
'vinkelmålerer': ('vinkelmåler',),
'vinkelmålerne': ('vinkelmåler',),
'vinkelparentes': ('vinkelparentes',),
'vinkelparentesen': ('vinkelparentes',),
'vinkelparentesene': ('vinkelparentes',),
'vinkelparenteser': ('vinkelparentes',),
'vinkelsekund': ('vinkelsekund',),
'vinkelsekunda': ('vinkelsekund',),
'vinkelsekundene': ('vinkelsekund',),
'vinkelsekunder': ('vinkelsekund',),
'vinkelsekundet': ('vinkelsekund',),
'vinkelskriver': ('vinkelskriver',),
'vinkelskrivere': ('vinkelskriver',),
'vinkelskriveren': ('vinkelskriver',),
'vinkelskriverer': ('vinkelskriver',),
'vinkelskriverne': ('vinkelskriver',),
'vinkelstova': ('vinkelstove',),
'vinkelstove': ('vinkelstove',),
'vinkelstoven': ('vinkelstove',),
'vinkelstovene': ('vinkelstove',),
'vinkelstover': ('vinkelstove',),
'vinkelstua': ('vinkelstue',),
'vinkelstue': ('vinkelstue',),
'vinkelstuen': ('vinkelstue',),
'vinkelstuene': ('vinkelstue',),
'vinkelstuer': ('vinkelstue',),
'vinkelstål': ('vinkelstål',),
'vinkelståla': ('vinkelstål',),
'vinkelstålene': ('vinkelstål',),
'vinkelstålet': ('vinkelstål',),
'vinkjeller': ('vinkjeller',),
'vinkjellere': ('vinkjeller',),
'vinkjelleren': ('vinkjeller',),
'vinkjellerer': ('vinkjeller',),
'vinkjellerne': ('vinkjeller',),
'vinkjenner': ('vinkjenner',),
'vinkjennere': ('vinkjenner',),
'vinkjenneren': ('vinkjenner',),
'vinkjennerer': ('vinkjenner',),
'vinkjennerne': ('vinkjenner',),
'vinkling': ('vinkling',),
'vinklingen': ('vinkling',),
'vinklingene': ('vinkling',),
'vinklinger': ('vinkling',),
'vinlauv': ('vinlauv',),
'vinlauva': ('vinlauv',),
'vinlauvene': ('vinlauv',),
'vinlauvet': ('vinlauv',),
'vinlegging': ('vinlegging',),
'vinlegginga': ('vinlegging',),
'vinleggingen': ('vinlegging',),
'vinleggingene': ('vinlegging',),
'vinlegginger': ('vinlegging',),
'vinløv': ('vinløv',),
'vinløva': ('vinløv',),
'vinløvene': ('vinløv',),
'vinløvet': ('vinløv',),
'vinmonopol': ('vinmonopol',),
'vinmonopola': ('vinmonopol',),
'vinmonopolene': ('vinmonopol',),
'vinmonopoler': ('vinmonopol',),
'vinmonopolet': ('vinmonopol',),
'vinn': ('vinn',),
'vinna': ('vinne',),
'vinne': ('vinne',),
'vinnen': ('vinne',),
'vinnene': ('vinne',),
'vinner': ('vinne',),
'vinner': ('vinner',),
'vinnere': ('vinner',),
'vinneren': ('vinner',),
'vinnerer': ('vinner',),
'vinnerne': ('vinner',),
'vinnerlykka': ('vinnerlykke',),
'vinnerlykke': ('vinnerlykke',),
'vinnerlykken': ('vinnerlykke',),
'vinnerlykkene': ('vinnerlykke',),
'vinnerlykker': ('vinnerlykke',),
'vinnersjanse': ('vinnersjanse',),
'vinnersjansen': ('vinnersjanse',),
'vinnersjansene': ('vinnersjanse',),
'vinnersjanser': ('vinnersjanse',),
'vinnertype': ('vinnertype',),
'vinnertypen': ('vinnertype',),
'vinnertypene': ('vinnertype',),
'vinnertyper': ('vinnertype',),
'vinnesjuka': ('vinnesjuke',),
'vinnesjuke': ('vinnesjuke',),
'vinnesjuken': ('vinnesjuke',),
'vinnesjukene': ('vinnesjuke',),
'vinnesjuker': ('vinnesjuke',),
'vinnesyka': ('vinnesyke',),
'vinnesyke': ('vinnesyke',),
'vinnesyken': ('vinnesyke',),
'vinnesykene': ('vinnesyke',),
'vinnesyker': ('vinnesyke',),
'vinning': ('vinning',),
'vinninga': ('vinning',),
'vinningen': ('vinning',),
'vinningene': ('vinning',),
'vinninger': ('vinning',),
'vinningsforbrytelse': ('vinningsforbrytelse',),
'vinningsforbrytelsen': ('vinningsforbrytelse',),
'vinningsforbrytelsene': ('vinningsforbrytelse',),
'vinningsforbrytelser': ('vinningsforbrytelse',),
'vinningskonti': ('vinningskonto',),
'vinningskontiene': ('vinningskonto',),
'vinningskonto': ('vinningskonto',),
'vinningskontoen': ('vinningskonto',),
'vinningskontoene': ('vinningskonto',),
'vinningskontoer': ('vinningskonto',),
'vinplanta': ('vinplante',),
'vinplante': ('vinplante',),
'vinplanten': ('vinplante',),
'vinplantene': ('vinplante',),
'vinplanter': ('vinplante',),
'vinranke': ('vinranke',),
'vinranken': ('vinranke',),
'vinrankene': ('vinranke',),
'vinranker': ('vinranke',),
'vinrett': ('vinrett',),
'vinretten': ('vinrett',),
'vinrettene': ('vinrett',),
'vinretter': ('vinrett',),
'vinsaus': ('vinsaus',),
'vinsausen': ('vinsaus',),
'vinsausene': ('vinsaus',),
'vinsauser': ('vinsaus',),
'vinsj': ('vinsj',),
'vinsjen': ('vinsj',),
'vinsjene': ('vinsj',),
'vinsjer': ('vinsj',),
'vinskjønner': ('vinskjønner',),
'vinskjønnere': ('vinskjønner',),
'vinskjønneren': ('vinskjønner',),
'vinskjønnerer': ('vinskjønner',),
'vinskjønnerne': ('vinskjønner',),
'vinsmaker': ('vinsmaker',),
'vinsmakere': ('vinsmaker',),
'vinsmakeren': ('vinsmaker',),
'vinsmakerer': ('vinsmaker',),
'vinsmakerne': ('vinsmaker',),
'vinst': ('vinst',),
'vinsten': ('vinst',),
'vinstene': ('vinst',),
'vinster': ('vinst',),
'vinstein': ('vinstein',),
'vinsteinen': ('vinstein',),
'vinsteinene': ('vinstein',),
'vinsteiner': ('vinstein',),
'vinstokk': ('vinstokk',),
'vinstokken': ('vinstokk',),
'vinstokkene': ('vinstokk',),
'vinstokker': ('vinstokk',),
'vinstova': ('vinstove',),
'vinstove': ('vinstove',),
'vinstoven': ('vinstove',),
'vinstovene': ('vinstove',),
'vinstover': ('vinstove',),
'vinstua': ('vinstue',),
'vinstue': ('vinstue',),
'vinstuen': ('vinstue',),
'vinstuene': ('vinstue',),
'vinstuer': ('vinstue',),
'vinsyra': ('vinsyre',),
'vinsyre': ('vinsyre',),
'vinsyren': ('vinsyre',),
'vinsyrene': ('vinsyre',),
'vinsyrer': ('vinsyre',),
'vintage': ('vintage',),
'vintagen': ('vintage',),
'vintagene': ('vintage',),
'vintager': ('vintage',),
'vinter': ('vinter',),
'vintere': ('vinter',),
'vinteren': ('vinter',),
'vinterne': ('vinter',),
'vintre': ('vinter',),
'vintrene': ('vinter',),
'vintrer': ('vinter',),
'vinterdag': ('vinterdag',),
'vinterdagen': ('vinterdag',),
'vinterdagene': ('vinterdag',),
'vinterdager': ('vinterdag',),
'vinterdekk': ('vinterdekk',),
'vinterdekka': ('vinterdekk',),
'vinterdekkene': ('vinterdekk',),
'vinterdekket': ('vinterdekk',),
'vinterdrakt': ('vinterdrakt',),
'vinterdrakta': ('vinterdrakt',),
'vinterdrakten': ('vinterdrakt',),
'vinterdraktene': ('vinterdrakt',),
'vinterdrakter': ('vinterdrakt',),
'vinterdvale': ('vinterdvale',),
'vinterdvalen': ('vinterdvale',),
'vinterdvalene': ('vinterdvale',),
'vinterdvaler': ('vinterdvale',),
'vintereik': ('vintereik',),
'vintereika': ('vintereik',),
'vintereiken': ('vintereik',),
'vintereikene': ('vintereik',),
'vintereiker': ('vintereik',),
'vinterepla': ('vintereple',),
'vintereple': ('vintereple',),
'vintereplene': ('vintereple',),
'vinterepler': ('vintereple',),
'vintereplet': ('vintereple',),
'vinterferie': ('vinterferie',),
'vinterferien': ('vinterferie',),
'vinterferiene': ('vinterferie',),
'vinterferier': ('vinterferie',),
'vinterfiska': ('vinterfiske',),
'vinterfiske': ('vinterfiske',),
'vinterfiskene': ('vinterfiske',),
'vinterfisker': ('vinterfiske',),
'vinterfisket': ('vinterfiske',),
'vinterfrakk': ('vinterfrakk',),
'vinterfrakken': ('vinterfrakk',),
'vinterfrakkene': ('vinterfrakk',),
'vinterfrakker': ('vinterfrakk',),
'vinterfrukt': ('vinterfrukt',),
'vinterfrukta': ('vinterfrukt',),
'vinterfrukten': ('vinterfrukt',),
'vinterfruktene': ('vinterfrukt',),
'vinterfrukter': ('vinterfrukt',),
'vinterføra': ('vinterføre',),
'vinterføre': ('vinterføre',),
'vinterførene': ('vinterføre',),
'vinterfører': ('vinterføre',),
'vinterføret': ('vinterføre',),
'vintergrøn': ('vintergrøn',),
'vintergrønen': ('vintergrøn',),
'vintergrønene': ('vintergrøn',),
'vintergrøner': ('vintergrøn',),
'vintergrønn': ('vintergrønn',),
'vintergrønnen': ('vintergrønn',),
'vintergrønnene': ('vintergrønn',),
'vinterhage': ('vinterhage',),
'vinterhagen': ('vinterhage',),
'vinterhagene': ('vinterhage',),
'vinterhager': ('vinterhage',),
'vinterhalvår': ('vinterhalvår',),
'vinterhalvåra': ('vinterhalvår',),
'vinterhalvårene': ('vinterhalvår',),
'vinterhalvåret': ('vinterhalvår',),
'vinterham': ('vinterham',),
'vinterhammen': ('vinterham',),
'vinterhammene': ('vinterham',),
'vinterhammer': ('vinterham',),
'vinterhi': ('vinterhi',),
'vinterhia': ('vinterhi',),
'vinterhiene': ('vinterhi',),
'vinterhiet': ('vinterhi',),
'vinteridrett': ('vinteridrett',),
'vinteridretten': ('vinteridrett',),
'vinteridrettene': ('vinteridrett',),
'vinteridretter': ('vinteridrett',),
'vinterkjøring': ('vinterkjøring',),
'vinterkjøringa': ('vinterkjøring',),
'vinterkjøringen': ('vinterkjøring',),
'vinterkjøringene': ('vinterkjøring',),
'vinterkjøringer': ('vinterkjøring',),
'vinterkåpa': ('vinterkåpe',),
'vinterkåpe': ('vinterkåpe',),
'vinterkåpen': ('vinterkåpe',),
'vinterkåpene': ('vinterkåpe',),
'vinterkåper': ('vinterkåpe',),
'vinterleikene': ('vinterleiker',),
'vinterleiker': ('vinterleiker',),
'vinterlekene': ('vinterleker',),
'vinterleker': ('vinterleker',),
'vintermåned': ('vintermåned',),
'vintermåneden': ('vintermåned',),
'vintermånedene': ('vintermåned',),
'vintermåneder': ('vintermåned',),
'vinternatt': ('vinternatt',),
'vinternatta': ('vinternatt',),
'vinternatten': ('vinternatt',),
'vinternettene': ('vinternatt',),
'vinternetter': ('vinternatt',),
'vinteropplag': ('vinteropplag',),
'vinteropplaga': ('vinteropplag',),
'vinteropplagene': ('vinteropplag',),
'vinteropplaget': ('vinteropplag',),
'vinterpels': ('vinterpels',),
'vinterpelsen': ('vinterpels',),
'vinterpelsene': ('vinterpels',),
'vinterpelser': ('vinterpels',),
'vinterrug': ('vinterrug',),
'vinterrugen': ('vinterrug',),
'vinterrugene': ('vinterrug',),
'vinterruger': ('vinterrug',),
'vinterruta': ('vinterrute',),
'vinterrute': ('vinterrute',),
'vinterruten': ('vinterrute',),
'vinterrutene': ('vinterrute',),
'vinterruter': ('vinterrute',),
'vintersild': ('vintersild',),
'vintersilda': ('vintersild',),
'vintersilden': ('vintersild',),
'vintersildene': ('vintersild',),
'vintersilder': ('vintersild',),
'vintersildfiska': ('vintersildfiske',),
'vintersildfiske': ('vintersildfiske',),
'vintersildfiskene': ('vintersildfiske',),
'vintersildfisker': ('vintersildfiske',),
'vintersildfisket': ('vintersildfiske',),
'vintersolverv': ('vintersolverv',),
'vintersolverva': ('vintersolverv',),
'vintersolvervene': ('vintersolverv',),
'vintersolvervet': ('vintersolverv',),
'vintersport': ('vintersport',),
'vintersporten': ('vintersport',),
'vintersportene': ('vintersport',),
'vintersporter': ('vintersport',),
'vintersportssted': ('vintersportssted',),
'vintersportsstedene': ('vintersportssted',),
'vintersportssteder': ('vintersportssted',),
'vintersportsstedet': ('vintersportssted',),
'vintersæd': ('vintersæd',),
'vintersæden': ('vintersæd',),
'vintersædene': ('vintersæd',),
'vintersæder': ('vintersæd',),
'vintersøvn': ('vintersøvn',),
'vintersøvnen': ('vintersøvn',),
'vintersøvnene': ('vintersøvn',),
'vintersøvner': ('vintersøvn',),
'vintertid': ('vintertid',),
'vintertida': ('vintertid',),
'vintertiden': ('vintertid',),
'vintertidene': ('vintertid',),
'vintertider': ('vintertid',),
'vinterveg': ('vinterveg',),
'vintervegen': ('vinterveg',),
'vintervegene': ('vinterveg',),
'vinterveger': ('vinterveg',),
'vintervei': ('vintervei',),
'vinterveien': ('vintervei',),
'vinterveiene': ('vintervei',),
'vinterveier': ('vintervei',),
'vinyl': ('vinyl',),
'vinyla': ('vinyl',),
'vinylen': ('vinyl',),
'vinylene': ('vinyl',),
'vinyler': ('vinyl',),
'vinylet': ('vinyl',),
'vinylfilt': ('vinylfilt',),
'vinylfilten': ('vinylfilt',),
'vinylfiltene': ('vinylfilt',),
'vinylfilter': ('vinylfilt',),
'vinylflis': ('vinylflis',),
'vinylflisa': ('vinylflis',),
'vinylflisen': ('vinylflis',),
'vinylflisene': ('vinylflis',),
'vinylfliser': ('vinylflis',),
'vinylflisa': ('vinylflise',),
'vinylflise': ('vinylflise',),
'vinylflisen': ('vinylflise',),
'vinylflisene': ('vinylflise',),
'vinylfliser': ('vinylflise',),
'vinylklorid': ('vinylklorid',),
'vinylklorida': ('vinylklorid',),
'vinylkloridene': ('vinylklorid',),
'vinylklorider': ('vinylklorid',),
'vinylkloridet': ('vinylklorid',),
'vinylplast': ('vinylplast',),
'vinylplasten': ('vinylplast',),
'vinylplastene': ('vinylplast',),
'vinylplaster': ('vinylplast',),
'vinyltapet': ('vinyltapet',),
'vinyltapeta': ('vinyltapet',),
'vinyltapetene': ('vinyltapet',),
'vinyltapeter': ('vinyltapet',),
'vinyltapetet': ('vinyltapet',),
'violoncell': ('violoncell',),
'violoncellen': ('violoncell',),
'violoncellene': ('violoncell',),
'violonceller': ('violoncell',),
'vipa': ('vipe',),
'vipe': ('vipe',),
'vipen': ('vipe',),
'vipene': ('vipe',),
'viper': ('vipe',),
'vippe': ('vippe',),
'vippen': ('vippe',),
'vippene': ('vippe',),
'vipper': ('vippe',),
'vippa': ('vippe',),
'vippe': ('vippe',),
'vippen': ('vippe',),
'vippene': ('vippe',),
'vipper': ('vippe',),
'vippebom': ('vippebom',),
'vippebommen': ('vippebom',),
'vippebommene': ('vippebom',),
'vippebommer': ('vippebom',),
'vippebro': ('vippebro',),
'vippebroa': ('vippebro',),
'vippebroen': ('vippebro',),
'vippebroene': ('vippebro',),
'vippebroer': ('vippebro',),
'vippebru': ('vippebru',),
'vippebrua': ('vippebru',),
'vippebruen': ('vippebru',),
'vippebruene': ('vippebru',),
'vippebruer': ('vippebru',),
'vippebrønn': ('vippebrønn',),
'vippebrønnen': ('vippebrønn',),
'vippebrønnene': ('vippebrønn',),
'vippebrønner': ('vippebrønn',),
'vippekjerra': ('vippekjerre',),
'vippekjerre': ('vippekjerre',),
'vippekjerren': ('vippekjerre',),
'vippekjerrene': ('vippekjerre',),
'vippekjerrer': ('vippekjerre',),
'vippeparti': ('vippeparti',),
'vippepartia': ('vippeparti',),
'vippepartiene': ('vippeparti',),
'vippepartier': ('vippeparti',),
'vippepartiet': ('vippeparti',),
'vippeport': ('vippeport',),
'vippeporten': ('vippeport',),
'vippeportene': ('vippeport',),
'vippeporter': ('vippeport',),
'vippeposisjon': ('vippeposisjon',),
'vippeposisjonen': ('vippeposisjon',),
'vippeposisjonene': ('vippeposisjon',),
'vippeposisjoner': ('vippeposisjon',),
'vippestang': ('vippestang',),
'vippestanga': ('vippestang',),
'vippestangen': ('vippestang',),
'vippestengene': ('vippestang',),
'vippestenger': ('vippestang',),
'vippestyra': ('vippestyre',),
'vippestyre': ('vippestyre',),
'vippestyrene': ('vippestyre',),
'vippestyrer': ('vippestyre',),
'vippestyret': ('vippestyre',),
'vippevindu': ('vippevindu',),
'vippevindua': ('vippevindu',),
'vippevinduene': ('vippevindu',),
'vippevinduer': ('vippevindu',),
'vippevinduet': ('vippevindu',),
'vippevogn': ('vippevogn',),
'vippevogna': ('vippevogn',),
'vippevognen': ('vippevogn',),
'vippevognene': ('vippevogn',),
'vippevogner': ('vippevogn',),
'virak': ('virak',),
'viraken': ('virak',),
'virakene': ('virak',),
'viraker': ('virak',),
'virginiasigarett': ('virginiasigarett',),
'virginiasigaretten': ('virginiasigarett',),
'virginiasigarettene': ('virginiasigarett',),
'virginiasigaretter': ('virginiasigarett',),
'virginiatobakk': ('virginiatobakk',),
'virginiatobakken': ('virginiatobakk',),
'virginiatobakkene': ('virginiatobakk',),
'virginiatobakker': ('virginiatobakk',),
'virilitet': ('virilitet',),
'viriliteten': ('virilitet',),
'virilitetene': ('virilitet',),
'viriliteter': ('virilitet',),
'virka': ('virke',),
'virke': ('virke',),
'virkene': ('virke',),
'virker': ('virke',),
'virket': ('virke',),
'virkedag': ('virkedag',),
'virkedagen': ('virkedag',),
'virkedagene': ('virkedag',),
'virkedager': ('virkedag',),
'virkefelt': ('virkefelt',),
'virkefelta': ('virkefelt',),
'virkefeltene': ('virkefelt',),
'virkefelter': ('virkefelt',),
'virkefeltet': ('virkefelt',),
'virkekrets': ('virkekrets',),
'virkekretsen': ('virkekrets',),
'virkekretsene': ('virkekrets',),
'virkekretser': ('virkekrets',),
'virkeliggjørelse': ('virkeliggjørelse',),
'virkeliggjørelsen': ('virkeliggjørelse',),
'virkeliggjørelsene': ('virkeliggjørelse',),
'virkeliggjørelser': ('virkeliggjørelse',),
'virkeliggjøring': ('virkeliggjøring',),
'virkeliggjøringa': ('virkeliggjøring',),
'virkeliggjøringen': ('virkeliggjøring',),
'virkeliggjøringene': ('virkeliggjøring',),
'virkeliggjøringer': ('virkeliggjøring',),
'virkelighet': ('virkelighet',),
'virkeligheta': ('virkelighet',),
'virkeligheten': ('virkelighet',),
'virkelighetene': ('virkelighet',),
'virkeligheter': ('virkelighet',),
'virkelighetsflukt': ('virkelighetsflukt',),
'virkelighetsflukta': ('virkelighetsflukt',),
'virkelighetsflukten': ('virkelighetsflukt',),
'virkelighetsfluktene': ('virkelighetsflukt',),
'virkelighetsflukter': ('virkelighetsflukt',),
'virkelighetssans': ('virkelighetssans',),
'virkelighetssansen': ('virkelighetssans',),
'virkelighetssansene': ('virkelighetssans',),
'virkelighetssanser': ('virkelighetssans',),
'virkelyst': ('virkelyst',),
'virkelysta': ('virkelyst',),
'virkelysten': ('virkelyst',),
'virkelystene': ('virkelyst',),
'virkelyster': ('virkelyst',),
'virkemiddel': ('virkemiddel',),
'virkemiddelet': ('virkemiddel',),
'virkemidla': ('virkemiddel',),
'virkemidlene': ('virkemiddel',),
'virkemidler': ('virkemiddel',),
'virkemidlet': ('virkemiddel',),
'virkemåte': ('virkemåte',),
'virkemåten': ('virkemåte',),
'virkemåtene': ('virkemåte',),
'virkemåter': ('virkemåte',),
'virkning': ('virkning',),
'virkninga': ('virkning',),
'virkningen': ('virkning',),
'virkningene': ('virkning',),
'virkninger': ('virkning',),
'virkningsgrad': ('virkningsgrad',),
'virkningsgraden': ('virkningsgrad',),
'virkningsgradene': ('virkningsgrad',),
'virkningsgrader': ('virkningsgrad',),
'virksomhet': ('virksomhet',),
'virksomheta': ('virksomhet',),
'virksomheten': ('virksomhet',),
'virksomhetene': ('virksomhet',),
'virksomheter': ('virksomhet',),
'virolog': ('virolog',),
'virologen': ('virolog',),
'virologene': ('virolog',),
'virologer': ('virolog',),
'virologi': ('virologi',),
'virologien': ('virologi',),
'virologiene': ('virologi',),
'virologier': ('virologi',),
'virtuos': ('virtuos',),
'virtuosen': ('virtuos',),
'virtuosene': ('virtuos',),
'virtuoser': ('virtuos',),
'virtuoseri': ('virtuoseri',),
'virtuoseria': ('virtuoseri',),
'virtuoseriene': ('virtuoseri',),
'virtuoseriet': ('virtuoseri',),
'virtuositet': ('virtuositet',),
'virtuositeten': ('virtuositet',),
'virtuositetene': ('virtuositet',),
'virtuositeter': ('virtuositet',),
'virulens': ('virulens',),
'virulensen': ('virulens',),
'virulensene': ('virulens',),
'virulenser': ('virulens',),
'virus': ('virus',),
'virusa': ('virus',),
'virusene': ('virus',),
'viruset': ('virus',),
'virusbærer': ('virusbærer',),
'virusbærere': ('virusbærer',),
'virusbæreren': ('virusbærer',),
'virusbærerer': ('virusbærer',),
'virusbærerne': ('virusbærer',),
'virusinfeksjon': ('virusinfeksjon',),
'virusinfeksjonen': ('virusinfeksjon',),
'virusinfeksjonene': ('virusinfeksjon',),
'virusinfeksjoner': ('virusinfeksjon',),
'virussjukdom': ('virussjukdom',),
'virussjukdommen': ('virussjukdom',),
'virussjukdommene': ('virussjukdom',),
'virussjukdommer': ('virussjukdom',),
'virussykdom': ('virussykdom',),
'virussykdommen': ('virussykdom',),
'virussykdommene': ('virussykdom',),
'virussykdommer': ('virussykdom',),
'virusvaksina': ('virusvaksine',),
'virusvaksine': ('virusvaksine',),
'virusvaksinen': ('virusvaksine',),
'virusvaksinene': ('virusvaksine',),
'virusvaksiner': ('virusvaksine',),
'virvar': ('virvar',),
'virvara': ('virvar',),
'virvarene': ('virvar',),
'virvaret': ('virvar',),
'virvel': ('virvel',),
'virvelen': ('virvel',),
'virvlene': ('virvel',),
'virvler': ('virvel',),
'virvelbevegelse': ('virvelbevegelse',),
'virvelbevegelsen': ('virvelbevegelse',),
'virvelbevegelsene': ('virvelbevegelse',),
'virvelbevegelser': ('virvelbevegelse',),
'virveldyr': ('virveldyr',),
'virveldyra': ('virveldyr',),
'virveldyrene': ('virveldyr',),
'virveldyret': ('virveldyr',),
'virvelstorm': ('virvelstorm',),
'virvelstormen': ('virvelstorm',),
'virvelstormene': ('virvelstorm',),
'virvelstormer': ('virvelstorm',),
'virvelsøyla': ('virvelsøyle',),
'virvelsøyle': ('virvelsøyle',),
'virvelsøylen': ('virvelsøyle',),
'virvelsøylene': ('virvelsøyle',),
'virvelsøyler': ('virvelsøyle',),
'virvelvind': ('virvelvind',),
'virvelvinden': ('virvelvind',),
'virvelvindene': ('virvelvind',),
'virvelvinder': ('virvelvind',),
'vis': ('vis',),
'visa': ('vis',),
'visen': ('vis',),
'visene': ('vis',),
'viset': ('vis',),
'visdom': ('visdom',),
'visdommen': ('visdom',),
'visdommene': ('visdom',),
'visdommer': ('visdom',),
'visdomskilde': ('visdomskilde',),
'visdomskilden': ('visdomskilde',),
'visdomskildene': ('visdomskilde',),
'visdomskilder': ('visdomskilde',),
'visdomskjelda': ('visdomskjelde',),
'visdomskjelde': ('visdomskjelde',),
'visdomskjelden': ('visdomskjelde',),
'visdomskjeldene': ('visdomskjelde',),
'visdomskjelder': ('visdomskjelde',),
'visdomsord': ('visdomsord',),
'visdomsorda': ('visdomsord',),
'visdomsordene': ('visdomsord',),
'visdomsordet': ('visdomsord',),
'visdomstann': ('visdomstann',),
'visdomstanna': ('visdomstann',),
'visdomstannen': ('visdomstann',),
'visdomstennene': ('visdomstann',),
'visdomstenner': ('visdomstann',),
'visa': ('vise',),
'vise': ('vise',),
'visen': ('vise',),
'visene': ('vise',),
'viser': ('vise',),
'viseadmiral': ('viseadmiral',),
'viseadmiralen': ('viseadmiral',),
'viseadmiralene': ('viseadmiral',),
'viseadmiraler': ('viseadmiral',),
'visebok': ('visebok',),
'viseboka': ('visebok',),
'viseboken': ('visebok',),
'visebøkene': ('visebok',),
'visebøker': ('visebok',),
'visedikter': ('visedikter',),
'visediktere': ('visedikter',),
'visedikteren': ('visedikter',),
'visedikterer': ('visedikter',),
'visedikterne': ('visedikter',),
'visedikting': ('visedikting',),
'visediktinga': ('visedikting',),
'visediktingen': ('visedikting',),
'visediktingene': ('visedikting',),
'visediktinger': ('visedikting',),
'visediktning': ('visediktning',),
'visediktninga': ('visediktning',),
'visediktningen': ('visediktning',),
'visediktningene': ('visediktning',),
'visediktninger': ('visediktning',),
'viseformann': ('viseformann',),
'viseformannen': ('viseformann',),
'viseformenn': ('viseformann',),
'viseformennene': ('viseformann',),
'visegruppa': ('visegruppe',),
'visegruppe': ('visegruppe',),
'visegruppen': ('visegruppe',),
'visegruppene': ('visegruppe',),
'visegrupper': ('visegruppe',),
'visekonge': ('visekonge',),
'visekongen': ('visekonge',),
'visekongene': ('visekonge',),
'visekonger': ('visekonge',),
'visekonsul': ('visekonsul',),
'visekonsulen': ('visekonsul',),
'visekonsulene': ('visekonsul',),
'visekonsuler': ('visekonsul',),
'visekorporal': ('visekorporal',),
'visekorporalen': ('visekorporal',),
'visekorporalene': ('visekorporal',),
'visekorporaler': ('visekorporal',),
'visende': ('visende',),
'visent': ('visent',),
'visenten': ('visent',),
'visentene': ('visent',),
'visenter': ('visent',),
'visepresident': ('visepresident',),
'visepresidenten': ('visepresident',),
'visepresidentene': ('visepresident',),
'visepresidenter': ('visepresident',),
'viser': ('viser',),
'visere': ('viser',),
'viseren': ('viser',),
'viserer': ('viser',),
'viserne': ('viser',),
'visergutt': ('visergutt',),
'visergutten': ('visergutt',),
'viserguttene': ('visergutt',),
'visergutter': ('visergutt',),
'viserjenta': ('viserjente',),
'viserjente': ('viserjente',),
'viserjenten': ('viserjente',),
'viserjentene': ('viserjente',),
'viserjenter': ('viserjente',),
'viserur': ('viserur',),
'viserura': ('viserur',),
'viserurene': ('viserur',),
'viseruret': ('viserur',),
'visesamling': ('visesamling',),
'visesamlinga': ('visesamling',),
'visesamlingen': ('visesamling',),
'visesamlingene': ('visesamling',),
'visesamlinger': ('visesamling',),
'visesang': ('visesang',),
'visesangen': ('visesang',),
'visesangene': ('visesang',),
'visesanger': ('visesang',),
'visesanger': ('visesanger',),
'visesangere': ('visesanger',),
'visesangeren': ('visesanger',),
'visesangerer': ('visesanger',),
'visesangerne': ('visesanger',),
'viseverksted': ('viseverksted',),
'viseverkstedene': ('viseverksted',),
'viseverksteder': ('viseverksted',),
'viseverkstedet': ('viseverksted',),
'visevert': ('visevert',),
'viseverten': ('visevert',),
'visevertene': ('visevert',),
'viseverter': ('visevert',),
'visir': ('visir',),
'visira': ('visir',),
'visirene': ('visir',),
'visirer': ('visir',),
'visiret': ('visir',),
'visitas': ('visitas',),
'visitasen': ('visitas',),
'visitasene': ('visitas',),
'visitaser': ('visitas',),
'visitasgudstjeneste': ('visitasgudstjeneste',),
'visitasgudstjenesten': ('visitasgudstjeneste',),
'visitasgudstjenestene': ('visitasgudstjeneste',),
'visitasgudstjenester': ('visitasgudstjeneste',),
'visitasjon': ('visitasjon',),
'visitasjonen': ('visitasjon',),
'visitasjonene': ('visitasjon',),
'visitasjoner': ('visitasjon',),
'visitasjonsrett': ('visitasjonsrett',),
'visitasjonsretten': ('visitasjonsrett',),
'visitasjonsrettene': ('visitasjonsrett',),
'visitasjonsretter': ('visitasjonsrett',),
'visitasreisa': ('visitasreise',),
'visitasreise': ('visitasreise',),
'visitasreisen': ('visitasreise',),
'visitasreisene': ('visitasreise',),
'visitasreiser': ('visitasreise',),
'visitator': ('visitator',),
'visitatoren': ('visitator',),
'visitatorene': ('visitator',),
'visitatorer': ('visitator',),
'visitt': ('visitt',),
'visitten': ('visitt',),
'visittene': ('visitt',),
'visitter': ('visitt',),
'visitt-tid': ('visitt-tid',),
'visitt-tida': ('visitt-tid',),
'visitt-tiden': ('visitt-tid',),
'visitt-tidene': ('visitt-tid',),
'visitt-tider': ('visitt-tid',),
'visittid': ('visittid',),
'visittida': ('visittid',),
'visittiden': ('visittid',),
'visittidene': ('visittid',),
'visittider': ('visittid',),
'visittkort': ('visittkort',),
'visittkorta': ('visittkort',),
'visittkortene': ('visittkort',),
'visittkortet': ('visittkort',),
'visittrunde': ('visittrunde',),
'visittrunden': ('visittrunde',),
'visittrundene': ('visittrunde',),
'visittrunder': ('visittrunde',),
'visitør': ('visitør',),
'visitøren': ('visitør',),
'visitørene': ('visitør',),
'visitører': ('visitør',),
'visjon': ('visjon',),
'visjonen': ('visjon',),
'visjonene': ('visjon',),
'visjoner': ('visjon',),
'visjonsdikt': ('visjonsdikt',),
'visjonsdikta': ('visjonsdikt',),
'visjonsdiktene': ('visjonsdikt',),
'visjonsdiktet': ('visjonsdikt',),
'visjonslitteratur': ('visjonslitteratur',),
'visjonslitteraturen': ('visjonslitteratur',),
'visjonslitteraturene': ('visjonslitteratur',),
'visjonslitteraturer': ('visjonslitteratur',),
'visjonær': ('visjonær',),
'visjonæren': ('visjonær',),
'visjonærene': ('visjonær',),
'visjonærer': ('visjonær',),
'visk': ('visk',),
'viska': ('visk',),
'visken': ('visk',),
'viskene': ('visk',),
'visket': ('visk',),
'viskelær': ('viskelær',),
'viskelæra': ('viskelær',),
'viskelærene': ('viskelær',),
'viskelæret': ('viskelær',),
'visker': ('visker',),
'viskere': ('visker',),
'viskeren': ('visker',),
'viskerer': ('visker',),
'viskerne': ('visker',),
'viskose': ('viskose',),
'viskosen': ('viskose',),
'viskosene': ('viskose',),
'viskoser': ('viskose',),
'viskosimeter': ('viskosimeter',),
'viskosimeteret': ('viskosimeter',),
'viskosimetra': ('viskosimeter',),
'viskosimetre': ('viskosimeter',),
'viskosimetrene': ('viskosimeter',),
'viskosimetret': ('viskosimeter',),
'viskositet': ('viskositet',),
'viskositeten': ('viskositet',),
'viskositetene': ('viskositet',),
'viskositeter': ('viskositet',),
'viskositetsindeks': ('viskositetsindeks',),
'viskositetsindeksen': ('viskositetsindeks',),
'viskositetsindeksene': ('viskositetsindeks',),
'viskositetsindekser': ('viskositetsindeks',),
'viskositetsmåler': ('viskositetsmåler',),
'viskositetsmålere': ('viskositetsmåler',),
'viskositetsmåleren': ('viskositetsmåler',),
'viskositetsmålerer': ('viskositetsmåler',),
'viskositetsmålerne': ('viskositetsmåler',),
'viskositetstal': ('viskositetstal',),
'viskositetstala': ('viskositetstal',),
'viskositetstalene': ('viskositetstal',),
'viskositetstalet': ('viskositetstal',),
'viskositetstall': ('viskositetstall',),
'viskositetstalla': ('viskositetstall',),
'viskositetstallene': ('viskositetstall',),
'viskositetstallet': ('viskositetstall',),
'vislelyd': ('vislelyd',),
'vislelyden': ('vislelyd',),
'vislelydene': ('vislelyd',),
'vislelyder': ('vislelyd',),
'vismann': ('vismann',),
'vismannen': ('vismann',),
'vismenn': ('vismann',),
'vismennene': ('vismann',),
'vismut': ('vismut',),
'vismuta': ('vismut',),
'vismuten': ('vismut',),
'vismutene': ('vismut',),
'vismuter': ('vismut',),
'vismutet': ('vismut',),
'vismutglans': ('vismutglans',),
'vismutglansen': ('vismutglans',),
'vismutglansene': ('vismutglans',),
'vismutglanser': ('vismutglans',),
'visning': ('visning',),
'visninga': ('visning',),
'visningen': ('visning',),
'visningene': ('visning',),
'visninger': ('visning',),
'visningsreisa': ('visningsreise',),
'visningsreise': ('visningsreise',),
'visningsreisen': ('visningsreise',),
'visningsreisene': ('visningsreise',),
'visningsreiser': ('visningsreise',),
'visp': ('visp',),
'vispen': ('visp',),
'vispene': ('visp',),
'visper': ('visp',),
'visp': ('visp',),
'vispa': ('visp',),
'vispen': ('visp',),
'vispene': ('visp',),
'vispet': ('visp',),
'vissa': ('visse',),
'visse': ('visse',),
'vissen': ('visse',),
'vissene': ('visse',),
'visser': ('visse',),
'visshet': ('visshet',),
'vissheta': ('visshet',),
'vissheten': ('visshet',),
'visshetene': ('visshet',),
'vissheter': ('visshet',),
'vissøre': ('vissøre',),
'vissøren': ('vissøre',),
'vissørene': ('vissøre',),
'vissører': ('vissøre',),
'vist': ('vist',),
'vista': ('vist',),
'visten': ('vist',),
'vistene': ('vist',),
'vister': ('vist',),
'visualiserer': ('visualiserer',),
'visualiserere': ('visualiserer',),
'visualisereren': ('visualiserer',),
'visualisererer': ('visualiserer',),
'visualisererne': ('visualiserer',),
'visualizer': ('visualizer',),
'visualizere': ('visualizer',),
'visualizeren': ('visualizer',),
'visualizerer': ('visualizer',),
'visualizerne': ('visualizer',),
'visa': ('visum',),
'visaene': ('visum',),
'visum': ('visum',),
'visuma': ('visum',),
'visumene': ('visum',),
'visumer': ('visum',),
'visumet': ('visum',),
'visumplikt': ('visumplikt',),
'visumplikta': ('visumplikt',),
'visumplikten': ('visumplikt',),
'visumpliktene': ('visumplikt',),
'visumplikter': ('visumplikt',),
'visumtvang': ('visumtvang',),
'visumtvangen': ('visumtvang',),
'visumtvangene': ('visumtvang',),
'visumtvanger': ('visumtvang',),
'visvas': ('visvas',),
'visvasa': ('visvas',),
'visvasene': ('visvas',),
'visvaset': ('visvas',),
'vita': ('vita',),
'vitaene': ('vita',),
'vitaer': ('vita',),
'vitaet': ('vita',),
'vitabrød': ('vitabrød',),
'vitabrøda': ('vitabrød',),
'vitabrødene': ('vitabrød',),
'vitabrødet': ('vitabrød',),
'vitalisme': ('vitalisme',),
'vitalismen': ('vitalisme',),
'vitalismene': ('vitalisme',),
'vitalismer': ('vitalisme',),
'vitalist': ('vitalist',),
'vitalisten': ('vitalist',),
'vitalistene': ('vitalist',),
'vitalister': ('vitalist',),
'vitalitet': ('vitalitet',),
'vitaliteten': ('vitalitet',),
'vitalitetene': ('vitalitet',),
'vitaliteter': ('vitalitet',),
'vitamin': ('vitamin',),
'vitamina': ('vitamin',),
'vitaminene': ('vitamin',),
'vitaminer': ('vitamin',),
'vitaminet': ('vitamin',),
'vitaminbehov': ('vitaminbehov',),
'vitaminbehova': ('vitaminbehov',),
'vitaminbehovene': ('vitaminbehov',),
'vitaminbehovet': ('vitaminbehov',),
'vitamininnhold': ('vitamininnhold',),
'vitamininnholda': ('vitamininnhold',),
'vitamininnholdene': ('vitamininnhold',),
'vitamininnholdet': ('vitamininnhold',),
'vitamininnsprøyting': ('vitamininnsprøyting',),
'vitamininnsprøytinga': ('vitamininnsprøyting',),
'vitamininnsprøytingen': ('vitamininnsprøyting',),
'vitamininnsprøytingene': ('vitamininnsprøyting',),
'vitamininnsprøytinger': ('vitamininnsprøyting',),
'vitamininnsprøytning': ('vitamininnsprøytning',),
'vitamininnsprøytninga': ('vitamininnsprøytning',),
'vitamininnsprøytningen': ('vitamininnsprøytning',),
'vitamininnsprøytningene': ('vitamininnsprøytning',),
'vitamininnsprøytninger': ('vitamininnsprøytning',),
'vitaminmangel': ('vitaminmangel',),
'vitaminmangelen': ('vitaminmangel',),
'vitaminmanglene': ('vitaminmangel',),
'vitaminmangler': ('vitaminmangel',),
'vitebegjær': ('vitebegjær',),
'vitebegjæra': ('vitebegjær',),
'vitebegjærene': ('vitebegjær',),
'vitebegjæret': ('vitebegjær',),
'vitelyst': ('vitelyst',),
'vitelysta': ('vitelyst',),
'vitelysten': ('vitelyst',),
'vitelystene': ('vitelyst',),
'vitelyster': ('vitelyst',),
'viten': ('viten',),
'vitenen': ('viten',),
'vitenene': ('viten',),
'vitener': ('viten',),
'vitenskap': ('vitenskap',),
'vitenskapen': ('vitenskap',),
'vitenskapene': ('vitenskap',),
'vitenskaper': ('vitenskap',),
'vitenskap': ('vitenskap',),
'vitenskapen': ('vitenskap',),
'vitenskapene': ('vitenskap',),
'vitenskaper': ('vitenskap',),
'vitenskapsakademi': ('vitenskapsakademi',),
'vitenskapsakademia': ('vitenskapsakademi',),
'vitenskapsakademiene': ('vitenskapsakademi',),
'vitenskapsakademier': ('vitenskapsakademi',),
'vitenskapsakademiet': ('vitenskapsakademi',),
'vitenskapsakademi': ('vitenskapsakademi',),
'vitenskapsakademia': ('vitenskapsakademi',),
'vitenskapsakademiene': ('vitenskapsakademi',),
'vitenskapsakademier': ('vitenskapsakademi',),
'vitenskapsakademiet': ('vitenskapsakademi',),
'vitenskapsgrein': ('vitenskapsgrein',),
'vitenskapsgreina': ('vitenskapsgrein',),
'vitenskapsgreinen': ('vitenskapsgrein',),
'vitenskapsgreinene': ('vitenskapsgrein',),
'vitenskapsgreiner': ('vitenskapsgrein',),
'vitenskapsgrein': ('vitenskapsgrein',),
'vitenskapsgreina': ('vitenskapsgrein',),
'vitenskapsgreinen': ('vitenskapsgrein',),
'vitenskapsgreinene': ('vitenskapsgrein',),
'vitenskapsgreiner': ('vitenskapsgrein',),
'vitenskapsgren': ('vitenskapsgren',),
'vitenskapsgrena': ('vitenskapsgren',),
'vitenskapsgrenen': ('vitenskapsgren',),
'vitenskapsgrenene': ('vitenskapsgren',),
'vitenskapsgrener': ('vitenskapsgren',),
'vitenskapshistoria': ('vitenskapshistorie',),
'vitenskapshistorie': ('vitenskapshistorie',),
'vitenskapshistorien': ('vitenskapshistorie',),
'vitenskapshistoriene': ('vitenskapshistorie',),
'vitenskapshistorier': ('vitenskapshistorie',),
'vitenskapshistoria': ('vitenskapshistorie',),
'vitenskapshistorie': ('vitenskapshistorie',),
'vitenskapshistorien': ('vitenskapshistorie',),
'vitenskapshistoriene': ('vitenskapshistorie',),
'vitenskapshistorier': ('vitenskapshistorie',),
'vitenskapskvinna': ('vitenskapskvinne',),
'vitenskapskvinne': ('vitenskapskvinne',),
'vitenskapskvinnen': ('vitenskapskvinne',),
'vitenskapskvinnene': ('vitenskapskvinne',),
'vitenskapskvinner': ('vitenskapskvinne',),
'vitenskapskvinna': ('vitenskapskvinne',),
'vitenskapskvinne': ('vitenskapskvinne',),
'vitenskapskvinnen': ('vitenskapskvinne',),
'vitenskapskvinnene': ('vitenskapskvinne',),
'vitenskapskvinner': ('vitenskapskvinne',),
'vitenskapsmann': ('vitenskapsmann',),
'vitenskapsmannen': ('vitenskapsmann',),
'vitenskapsmenn': ('vitenskapsmann',),
'vitenskapsmennene': ('vitenskapsmann',),
'vitenskapsmann': ('vitenskapsmann',),
'vitenskapsmannen': ('vitenskapsmann',),
'vitenskapsmenn': ('vitenskapsmann',),
'vitenskapsmennene': ('vitenskapsmann',),
'vitenskapsselskap': ('vitenskapsselskap',),
'vitenskapsselskapa': ('vitenskapsselskap',),
'vitenskapsselskapene': ('vitenskapsselskap',),
'vitenskapsselskaper': ('vitenskapsselskap',),
'vitenskapsselskapet': ('vitenskapsselskap',),
'vitenskapsselskap': ('vitenskapsselskap',),
'vitenskapsselskapa': ('vitenskapsselskap',),
'vitenskapsselskapene': ('vitenskapsselskap',),
'vitenskapsselskaper': ('vitenskapsselskap',),
'vitenskapsselskapet': ('vitenskapsselskap',),
'vitna': ('vitne',),
'vitne': ('vitne',),
'vitnene': ('vitne',),
'vitner': ('vitne',),
'vitnet': ('vitne',),
'vitneansvar': ('vitneansvar',),
'vitneansvara': ('vitneansvar',),
'vitneansvarene': ('vitneansvar',),
'vitneansvaret': ('vitneansvar',),
'vitneavhør': ('vitneavhør',),
'vitneavhøra': ('vitneavhør',),
'vitneavhørene': ('vitneavhør',),
'vitneavhøret': ('vitneavhør',),
'vitneavhøring': ('vitneavhøring',),
'vitneavhøringa': ('vitneavhøring',),
'vitneavhøringen': ('vitneavhøring',),
'vitneavhøringene': ('vitneavhøring',),
'vitneavhøringer': ('vitneavhøring',),
'vitneboks': ('vitneboks',),
'vitneboksen': ('vitneboks',),
'vitneboksene': ('vitneboks',),
'vitnebokser': ('vitneboks',),
'vitneforhør': ('vitneforhør',),
'vitneforhøra': ('vitneforhør',),
'vitneforhørene': ('vitneforhør',),
'vitneforhøret': ('vitneforhør',),
'vitneforklaring': ('vitneforklaring',),
'vitneforklaringa': ('vitneforklaring',),
'vitneforklaringen': ('vitneforklaring',),
'vitneforklaringene': ('vitneforklaring',),
'vitneforklaringer': ('vitneforklaring',),
'vitnemål': ('vitnemål',),
'vitnemåla': ('vitnemål',),
'vitnemålene': ('vitnemål',),
'vitnemålet': ('vitnemål',),
'vitnemøta': ('vitnemøte',),
'vitnemøte': ('vitnemøte',),
'vitnemøtene': ('vitnemøte',),
'vitnemøter': ('vitnemøte',),
'vitnemøtet': ('vitnemøte',),
'vitneplikt': ('vitneplikt',),
'vitneplikta': ('vitneplikt',),
'vitneplikten': ('vitneplikt',),
'vitnepliktene': ('vitneplikt',),
'vitneplikter': ('vitneplikt',),
'vitneprov': ('vitneprov',),
'vitneprova': ('vitneprov',),
'vitneprovene': ('vitneprov',),
'vitneprovet': ('vitneprov',),
'vitnesbyrd': ('vitnesbyrd',),
'vitnesbyrda': ('vitnesbyrd',),
'vitnesbyrdene': ('vitnesbyrd',),
'vitnesbyrdet': ('vitnesbyrd',),
'vitneutsagn': ('vitneutsagn',),
'vitneutsagna': ('vitneutsagn',),
'vitneutsagnene': ('vitneutsagn',),
'vitneutsagnet': ('vitneutsagn',),
'vitrine': ('vitrine',),
'vitrinen': ('vitrine',),
'vitrinene': ('vitrine',),
'vitriner': ('vitrine',),
'vitrineskap': ('vitrineskap',),
'vitrineskapa': ('vitrineskap',),
'vitrineskapene': ('vitrineskap',),
'vitrineskapet': ('vitrineskap',),
'vitriol': ('vitriol',),
'vitriolen': ('vitriol',),
'vitriolene': ('vitriol',),
'vitrioler': ('vitriol',),
'vits': ('vits',),
'vitsen': ('vits',),
'vitsene': ('vits',),
'vitser': ('vits',),
'vitsemaker': ('vitsemaker',),
'vitsemakere': ('vitsemaker',),
'vitsemakeren': ('vitsemaker',),
'vitsemakerer': ('vitsemaker',),
'vitsemakerne': ('vitsemaker',),
'vitsemaker': ('vitsemaker',),
'vitsemakere': ('vitsemaker',),
'vitsemakeren': ('vitsemaker',),
'vitsemakerer': ('vitsemaker',),
'vitsemakerne': ('vitsemaker',),
'vitsetegning': ('vitsetegning',),
'vitsetegninga': ('vitsetegning',),
'vitsetegningen': ('vitsetegning',),
'vitsetegningene': ('vitsetegning',),
'vitsetegninger': ('vitsetegning',),
'vitsetegning': ('vitsetegning',),
'vitsetegninga': ('vitsetegning',),
'vitsetegningen': ('vitsetegning',),
'vitsetegningene': ('vitsetegning',),
'vitsetegninger': ('vitsetegning',),
'vitskap': ('vitskap',),
'vitskapen': ('vitskap',),
'vitskapene': ('vitskap',),
'vitskaper': ('vitskap',),
'vitskap': ('vitskap',),
'vitskapen': ('vitskap',),
'vitskapene': ('vitskap',),
'vitskaper': ('vitskap',),
'vitskapsakademi': ('vitskapsakademi',),
'vitskapsakademia': ('vitskapsakademi',),
'vitskapsakademiene': ('vitskapsakademi',),
'vitskapsakademier': ('vitskapsakademi',),
'vitskapsakademiet': ('vitskapsakademi',),
'vitskapsakademi': ('vitskapsakademi',),
'vitskapsakademia': ('vitskapsakademi',),
'vitskapsakademiene': ('vitskapsakademi',),
'vitskapsakademier': ('vitskapsakademi',),
'vitskapsakademiet': ('vitskapsakademi',),
'vitskapsgrein': ('vitskapsgrein',),
'vitskapsgreina': ('vitskapsgrein',),
'vitskapsgreinen': ('vitskapsgrein',),
'vitskapsgreinene': ('vitskapsgrein',),
'vitskapsgreiner': ('vitskapsgrein',),
'vitskapsgrein': ('vitskapsgrein',),
'vitskapsgreina': ('vitskapsgrein',),
'vitskapsgreinen': ('vitskapsgrein',),
'vitskapsgreinene': ('vitskapsgrein',),
'vitskapsgreiner': ('vitskapsgrein',),
'vitskapsgren': ('vitskapsgren',),
'vitskapsgrena': ('vitskapsgren',),
'vitskapsgrenen': ('vitskapsgren',),
'vitskapsgrenene': ('vitskapsgren',),
'vitskapsgrener': ('vitskapsgren',),
'vitskapshistoria': ('vitskapshistorie',),
'vitskapshistorie': ('vitskapshistorie',),
'vitskapshistorien': ('vitskapshistorie',),
'vitskapshistoriene': ('vitskapshistorie',),
'vitskapshistorier': ('vitskapshistorie',),
'vitskapshistoria': ('vitskapshistorie',),
'vitskapshistorie': ('vitskapshistorie',),
'vitskapshistorien': ('vitskapshistorie',),
'vitskapshistoriene': ('vitskapshistorie',),
'vitskapshistorier': ('vitskapshistorie',),
'vitskapskvinna': ('vitskapskvinne',),
'vitskapskvinne': ('vitskapskvinne',),
'vitskapskvinnen': ('vitskapskvinne',),
'vitskapskvinnene': ('vitskapskvinne',),
'vitskapskvinner': ('vitskapskvinne',),
'vitskapskvinna': ('vitskapskvinne',),
'vitskapskvinne': ('vitskapskvinne',),
'vitskapskvinnen': ('vitskapskvinne',),
'vitskapskvinnene': ('vitskapskvinne',),
'vitskapskvinner': ('vitskapskvinne',),
'vitskapsmann': ('vitskapsmann',),
'vitskapsmannen': ('vitskapsmann',),
'vitskapsmenn': ('vitskapsmann',),
'vitskapsmennene': ('vitskapsmann',),
'vitskapsmann': ('vitskapsmann',),
'vitskapsmannen': ('vitskapsmann',),
'vitskapsmenn': ('vitskapsmann',),
'vitskapsmennene': ('vitskapsmann',),
'vitskapsselskap': ('vitskapsselskap',),
'vitskapsselskapa': ('vitskapsselskap',),
'vitskapsselskapene': ('vitskapsselskap',),
'vitskapsselskaper': ('vitskapsselskap',),
'vitskapsselskapet': ('vitskapsselskap',),
'vitskapsselskap': ('vitskapsselskap',),
'vitskapsselskapa': ('vitskapsselskap',),
'vitskapsselskapene': ('vitskapsselskap',),
'vitskapsselskaper': ('vitskapsselskap',),
'vitskapsselskapet': ('vitskapsselskap',),
'vitsmaker': ('vitsmaker',),
'vitsmakere': ('vitsmaker',),
'vitsmakeren': ('vitsmaker',),
'vitsmakerer': ('vitsmaker',),
'vitsmakerne': ('vitsmaker',),
'vitsmaker': ('vitsmaker',),
'vitsmakere': ('vitsmaker',),
'vitsmakeren': ('vitsmaker',),
'vitsmakerer': ('vitsmaker',),
'vitsmakerne': ('vitsmaker',),
'vitstegning': ('vitstegning',),
'vitstegninga': ('vitstegning',),
'vitstegningen': ('vitstegning',),
'vitstegningene': ('vitstegning',),
'vitstegninger': ('vitstegning',),
'vitstegning': ('vitstegning',),
'vitstegninga': ('vitstegning',),
'vitstegningen': ('vitstegning',),
'vitstegningene': ('vitstegning',),
'vitstegninger': ('vitstegning',),
'vitterlighet': ('vitterlighet',),
'vitterligheta': ('vitterlighet',),
'vitterligheten': ('vitterlighet',),
'vitterlighetene': ('vitterlighet',),
'vitterligheter': ('vitterlighet',),
'vittighet': ('vittighet',),
'vittigheta': ('vittighet',),
'vittigheten': ('vittighet',),
'vittighetene': ('vittighet',),
'vittigheter': ('vittighet',),
'vittighetsblad': ('vittighetsblad',),
'vittighetsblada': ('vittighetsblad',),
'vittighetsbladene': ('vittighetsblad',),
'vittighetsblader': ('vittighetsblad',),
'vittighetsbladet': ('vittighetsblad',),
'viv': ('viv',),
'viva': ('viv',),
'viven': ('viv',),
'vivene': ('viv',),
'vivet': ('viv',),
'vivasitet': ('vivasitet',),
'vivasiteten': ('vivasitet',),
'vivasitetene': ('vivasitet',),
'vivasiteter': ('vivasitet',),
'vivendel': ('vivendel',),
'vivendelen': ('vivendel',),
'vivendlene': ('vivendel',),
'vivendler': ('vivendel',),
'vivipari': ('vivipari',),
'viviparien': ('vivipari',),
'vivipariene': ('vivipari',),
'viviparier': ('vivipari',),
'viviseksjon': ('viviseksjon',),
'viviseksjonen': ('viviseksjon',),
'viviseksjonene': ('viviseksjon',),
'viviseksjoner': ('viviseksjon',),
'viviseksjonist': ('viviseksjonist',),
'viviseksjonisten': ('viviseksjonist',),
'viviseksjonistene': ('viviseksjonist',),
'viviseksjonister': ('viviseksjonist',),
'vivisektør': ('vivisektør',),
'vivisektøren': ('vivisektør',),
'vivisektørene': ('vivisektør',),
'vivisektører': ('vivisektør',),
'vodka': ('vodka',),
'vodkaen': ('vodka',),
'vodkaene': ('vodka',),
'vodkaer': ('vodka',),
'voffvoff': ('voffvoff',),
'voffvoffen': ('voffvoff',),
'voffvoffene': ('voffvoff',),
'voffvoffer': ('voffvoff',),
'vogga': ('vogge',),
'vogge': ('vogge',),
'voggen': ('vogge',),
'voggene': ('vogge',),
'vogger': ('vogge',),
'voggebarn': ('voggebarn',),
'voggebarna': ('voggebarn',),
'voggebarnene': ('voggebarn',),
'voggebarnet': ('voggebarn',),
'voggegava': ('voggegave',),
'voggegave': ('voggegave',),
'voggegaven': ('voggegave',),
'voggegavene': ('voggegave',),
'voggegaver': ('voggegave',),
'voggemei': ('voggemei',),
'voggemeien': ('voggemei',),
'voggemeiene': ('voggemei',),
'voggemeier': ('voggemei',),
'voggemeia': ('voggemeie',),
'voggemeie': ('voggemeie',),
'voggemeien': ('voggemeie',),
'voggemeiene': ('voggemeie',),
'voggemeier': ('voggemeie',),
'voggesang': ('voggesang',),
'voggesangen': ('voggesang',),
'voggesangene': ('voggesang',),
'voggesanger': ('voggesang',),
'voggevisa': ('voggevise',),
'voggevise': ('voggevise',),
'voggevisen': ('voggevise',),
'voggevisene': ('voggevise',),
'voggeviser': ('voggevise',),
'vogn': ('vogn',),
'vogna': ('vogn',),
'vognen': ('vogn',),
'vognene': ('vogn',),
'vogner': ('vogn',),
'vognfører': ('vognfører',),
'vognførere': ('vognfører',),
'vognføreren': ('vognfører',),
'vognførerer': ('vognfører',),
'vognførerne': ('vognfører',),
'vognhall': ('vognhall',),
'vognhallen': ('vognhall',),
'vognhallene': ('vognhall',),
'vognhaller': ('vognhall',),
'vognhjul': ('vognhjul',),
'vognhjula': ('vognhjul',),
'vognhjulene': ('vognhjul',),
'vognhjulet': ('vognhjul',),
'vognkort': ('vognkort',),
'vognkorta': ('vognkort',),
'vognkortene': ('vognkort',),
'vognkortet': ('vognkort',),
'vognladning': ('vognladning',),
'vognladninga': ('vognladning',),
'vognladningen': ('vognladning',),
'vognladningene': ('vognladning',),
'vognladninger': ('vognladning',),
'vognlass': ('vognlass',),
'vognlassa': ('vognlass',),
'vognlassene': ('vognlass',),
'vognlasset': ('vognlass',),
'vognlast': ('vognlast',),
'vognlasta': ('vognlast',),
'vognlasten': ('vognlast',),
'vognlastene': ('vognlast',),
'vognlaster': ('vognlast',),
'vognmann': ('vognmann',),
'vognmannen': ('vognmann',),
'vognmenn': ('vognmann',),
'vognmennene': ('vognmann',),
'vognpark': ('vognpark',),
'vognparken': ('vognpark',),
'vognparkene': ('vognpark',),
'vognparker': ('vognpark',),
'vognramla': ('vognrammel',),
'vognramlene': ('vognrammel',),
'vognramler': ('vognrammel',),
'vognramlet': ('vognrammel',),
'vognrammel': ('vognrammel',),
'vognrammelen': ('vognrammel',),
'vognrammelet': ('vognrammel',),
'vognskjul': ('vognskjul',),
'vognskjula': ('vognskjul',),
'vognskjulene': ('vognskjul',),
'vognskjulet': ('vognskjul',),
'vognskur': ('vognskur',),
'vognskura': ('vognskur',),
'vognskurene': ('vognskur',),
'vognskuret': ('vognskur',),
'vogntog': ('vogntog',),
'vogntoga': ('vogntog',),
'vogntogene': ('vogntog',),
'vogntoget': ('vogntog',),
'voile': ('voile',),
'voilen': ('voile',),
'voilene': ('voile',),
'voiler': ('voile',),
'vokabular': ('vokabular',),
'vokabulara': ('vokabular',),
'vokabularene': ('vokabular',),
'vokabularer': ('vokabular',),
'vokabularet': ('vokabular',),
'vokal': ('vokal',),
'vokalen': ('vokal',),
'vokalene': ('vokal',),
'vokaler': ('vokal',),
'vokalbalanse': ('vokalbalanse',),
'vokalbalansen': ('vokalbalanse',),
'vokalbalansene': ('vokalbalanse',),
'vokalbalanser': ('vokalbalanse',),
'vokalbortfall': ('vokalbortfall',),
'vokalbortfalla': ('vokalbortfall',),
'vokalbortfallene': ('vokalbortfall',),
'vokalbortfallet': ('vokalbortfall',),
'vokalharmoni': ('vokalharmoni',),
'vokalharmonien': ('vokalharmoni',),
'vokalharmoniene': ('vokalharmoni',),
'vokalharmonier': ('vokalharmoni',),
'vokalise': ('vokalise',),
'vokalisen': ('vokalise',),
'vokalisene': ('vokalise',),
'vokaliser': ('vokalise',),
'vokalisme': ('vokalisme',),
'vokalismen': ('vokalisme',),
'vokalismene': ('vokalisme',),
'vokalismer': ('vokalisme',),
'vokalist': ('vokalist',),
'vokalisten': ('vokalist',),
'vokalistene': ('vokalist',),
'vokalister': ('vokalist',),
'vokalistgruppa': ('vokalistgruppe',),
'vokalistgruppe': ('vokalistgruppe',),
'vokalistgruppen': ('vokalistgruppe',),
'vokalistgruppene': ('vokalistgruppe',),
'vokalistgrupper': ('vokalistgruppe',),
'vokaljamvekt': ('vokaljamvekt',),
'vokaljamvekta': ('vokaljamvekt',),
'vokaljamvekten': ('vokaljamvekt',),
'vokaljamvektene': ('vokaljamvekt',),
'vokaljamvekter': ('vokaljamvekt',),
'vokalkvalitet': ('vokalkvalitet',),
'vokalkvaliteten': ('vokalkvalitet',),
'vokalkvalitetene': ('vokalkvalitet',),
'vokalkvaliteter': ('vokalkvalitet',),
'vokalkvantitet': ('vokalkvantitet',),
'vokalkvantiteten': ('vokalkvantitet',),
'vokalkvantitetene': ('vokalkvantitet',),
'vokalkvantiteter': ('vokalkvantitet',),
'vokallengda': ('vokallengde',),
'vokallengde': ('vokallengde',),
'vokallengden': ('vokallengde',),
'vokallengdene': ('vokallengde',),
'vokallengder': ('vokallengde',),
'vokalmusikk': ('vokalmusikk',),
'vokalmusikken': ('vokalmusikk',),
'vokalmusikkene': ('vokalmusikk',),
'vokalmusikker': ('vokalmusikk',),
'vokalreduksjon': ('vokalreduksjon',),
'vokalreduksjonen': ('vokalreduksjon',),
'vokalreduksjonene': ('vokalreduksjon',),
'vokalreduksjoner': ('vokalreduksjon',),
'vokalsystem': ('vokalsystem',),
'vokalsystema': ('vokalsystem',),
'vokalsystemene': ('vokalsystem',),
'vokalsystemer': ('vokalsystem',),
'vokalsystemet': ('vokalsystem',),
'vokativ': ('vokativ',),
'vokativen': ('vokativ',),
'vokativene': ('vokativ',),
'vokativer': ('vokativ',),
'vokoid': ('vokoid',),
'vokoiden': ('vokoid',),
'vokoidene': ('vokoid',),
'vokoider': ('vokoid',),
'voks': ('voks',),
'voksa': ('voks',),
'voksen': ('voks',),
'voksene': ('voks',),
'vokser': ('voks',),
'vokset': ('voks',),
'voksavstøpning': ('voksavstøpning',),
'voksavstøpninga': ('voksavstøpning',),
'voksavstøpningen': ('voksavstøpning',),
'voksavstøpningene': ('voksavstøpning',),
'voksavstøpninger': ('voksavstøpning',),
'voksavstøyping': ('voksavstøyping',),
'voksavstøypinga': ('voksavstøyping',),
'voksavstøypingen': ('voksavstøyping',),
'voksavstøypingene': ('voksavstøyping',),
'voksavstøypinger': ('voksavstøyping',),
'voksbønna': ('voksbønne',),
'voksbønne': ('voksbønne',),
'voksbønnen': ('voksbønne',),
'voksbønnene': ('voksbønne',),
'voksbønner': ('voksbønne',),
'voksduk': ('voksduk',),
'voksduken': ('voksduk',),
'voksdukene': ('voksduk',),
'voksduker': ('voksduk',),
'voksealder': ('voksealder',),
'voksealdere': ('voksealder',),
'voksealderen': ('voksealder',),
'voksealderer': ('voksealder',),
'voksealderne': ('voksealder',),
'voksealdre': ('voksealder',),
'voksealdrene': ('voksealder',),
'voksealdrer': ('voksealder',),
'voksenbillett': ('voksenbillett',),
'voksenbilletten': ('voksenbillett',),
'voksenbillettene': ('voksenbillett',),
'voksenbilletter': ('voksenbillett',),
'voksendåp': ('voksendåp',),
'voksendåpen': ('voksendåp',),
'voksendåpene': ('voksendåp',),
'voksendåper': ('voksendåp',),
'voksengymnas': ('voksengymnas',),
'voksengymnasa': ('voksengymnas',),
'voksengymnasene': ('voksengymnas',),
'voksengymnaser': ('voksengymnas',),
'voksengymnaset': ('voksengymnas',),
'voksenlitteratur': ('voksenlitteratur',),
'voksenlitteraturen': ('voksenlitteratur',),
'voksenlitteraturene': ('voksenlitteratur',),
'voksenlitteraturer': ('voksenlitteratur',),
'voksenopplæring': ('voksenopplæring',),
'voksenopplæringa': ('voksenopplæring',),
'voksenopplæringen': ('voksenopplæring',),
'voksenopplæringene': ('voksenopplæring',),
'voksenopplæringer': ('voksenopplæring',),
'voksenopplæringskurs': ('voksenopplæringskurs',),
'voksenopplæringskursa': ('voksenopplæringskurs',),
'voksenopplæringskursene': ('voksenopplæringskurs',),
'voksenopplæringskurser': ('voksenopplæringskurs',),
'voksenopplæringskurset': ('voksenopplæringskurs',),
'voksenopplæringskursene': ('voksenopplæringskursus',),
'voksenopplæringskurser': ('voksenopplæringskursus',),
'voksenopplæringskursus': ('voksenopplæringskursus',),
'voksenopplæringskursuset': ('voksenopplæringskursus',),
'voksenundervisning': ('voksenundervisning',),
'voksenundervisninga': ('voksenundervisning',),
'voksenundervisningen': ('voksenundervisning',),
'voksenundervisningene': ('voksenundervisning',),
'voksenundervisninger': ('voksenundervisning',),
'vokseperiode': ('vokseperiode',),
'vokseperioden': ('vokseperiode',),
'vokseperiodene': ('vokseperiode',),
'vokseperioder': ('vokseperiode',),
'voksesmerte': ('voksesmerte',),
'voksesmerten': ('voksesmerte',),
'voksesmertene': ('voksesmerte',),
'voksesmerter': ('voksesmerte',),
'voksested': ('voksested',),
'voksestedene': ('voksested',),
'voksesteder': ('voksested',),
'voksestedet': ('voksested',),
'voksetid': ('voksetid',),
'voksetida': ('voksetid',),
'voksetiden': ('voksetid',),
'voksetidene': ('voksetid',),
'voksetider': ('voksetid',),
'voksfigur': ('voksfigur',),
'voksfiguren': ('voksfigur',),
'voksfigurene': ('voksfigur',),
'voksfigurer': ('voksfigur',),
'vokskabinett': ('vokskabinett',),
'vokskabinetta': ('vokskabinett',),
'vokskabinettene': ('vokskabinett',),
'vokskabinetter': ('vokskabinett',),
'vokskabinettet': ('vokskabinett',),
'vokskaka': ('vokskake',),
'vokskake': ('vokskake',),
'vokskaken': ('vokskake',),
'vokskakene': ('vokskake',),
'vokskaker': ('vokskake',),
'vokslys': ('vokslys',),
'vokslysa': ('vokslys',),
'vokslysene': ('vokslys',),
'vokslyset': ('vokslys',),
'vokspapir': ('vokspapir',),
'vokspapira': ('vokspapir',),
'vokspapirene': ('vokspapir',),
'vokspapirer': ('vokspapir',),
'vokspapiret': ('vokspapir',),
'vokstavla': ('vokstavle',),
'vokstavle': ('vokstavle',),
'vokstavlen': ('vokstavle',),
'vokstavlene': ('vokstavle',),
'vokstavler': ('vokstavle',),
'vokster': ('vokster',),
'vokstere': ('vokster',),
'voksteren': ('vokster',),
'voksterer': ('vokster',),
'voksterne': ('vokster',),
'vokstre': ('vokster',),
'vokstrene': ('vokster',),
'vokstrer': ('vokster',),
'vokstervilkår': ('vokstervilkår',),
'vokstervilkåra': ('vokstervilkår',),
'vokstervilkårene': ('vokstervilkår',),
'vokstervilkåret': ('vokstervilkår',),
'vokter': ('vokter',),
'voktere': ('vokter',),
'vokteren': ('vokter',),
'vokterer': ('vokter',),
'vokterne': ('vokter',),
'volang': ('volang',),
'volangen': ('volang',),
'volangene': ('volang',),
'volanger': ('volang',),
'volapyk': ('volapyk',),
'volapyken': ('volapyk',),
'volapykene': ('volapyk',),
'volapyker': ('volapyk',),
'vold': ('vold',),
'volden': ('vold',),
'voldene': ('vold',),
'volder': ('vold',),
'voldgift': ('voldgift',),
'voldgiften': ('voldgift',),
'voldgiftene': ('voldgift',),
'voldgifter': ('voldgift',),
'voldgiftsdomstol': ('voldgiftsdomstol',),
'voldgiftsdomstolen': ('voldgiftsdomstol',),
'voldgiftsdomstolene': ('voldgiftsdomstol',),
'voldgiftsdomstoler': ('voldgiftsdomstol',),
'voldgiftsmann': ('voldgiftsmann',),
'voldgiftsmannen': ('voldgiftsmann',),
'voldgiftsmenn': ('voldgiftsmann',),
'voldgiftsmennene': ('voldgiftsmann',),
'voldgiftsrett': ('voldgiftsrett',),
'voldgiftsretten': ('voldgiftsrett',),
'voldgiftsrettene': ('voldgiftsrett',),
'voldgiftsretter': ('voldgiftsrett',),
'voldsbruk': ('voldsbruk',),
'voldsbruka': ('voldsbruk',),
'voldsbruken': ('voldsbruk',),
'voldsbrukene': ('voldsbruk',),
'voldsbruker': ('voldsbruk',),
'voldsbruket': ('voldsbruk',),
'voldsferd': ('voldsferd',),
'voldsferda': ('voldsferd',),
'voldsferden': ('voldsferd',),
'voldsferdene': ('voldsferd',),
'voldsferder': ('voldsferd',),
'voldsfilm': ('voldsfilm',),
'voldsfilmen': ('voldsfilm',),
'voldsfilmene': ('voldsfilm',),
'voldsfilmer': ('voldsfilm',),
'voldsforbrytelse': ('voldsforbrytelse',),
'voldsforbrytelsen': ('voldsforbrytelse',),
'voldsforbrytelsene': ('voldsforbrytelse',),
'voldsforbrytelser': ('voldsforbrytelse',),
'voldsforbryter': ('voldsforbryter',),
'voldsforbrytere': ('voldsforbryter',),
'voldsforbryteren': ('voldsforbryter',),
'voldsforbryterer': ('voldsforbryter',),
'voldsforbryterne': ('voldsforbryter',),
'voldshandling': ('voldshandling',),
'voldshandlinga': ('voldshandling',),
'voldshandlingen': ('voldshandling',),
'voldshandlingene': ('voldshandling',),
'voldshandlinger': ('voldshandling',),
'voldsmann': ('voldsmann',),
'voldsmannen': ('voldsmann',),
'voldsmenn': ('voldsmann',),
'voldsmennene': ('voldsmann',),
'voldsmentalitet': ('voldsmentalitet',),
'voldsmentaliteten': ('voldsmentalitet',),
'voldsmentalitetene': ('voldsmentalitet',),
'voldsmentaliteter': ('voldsmentalitet',),
'voldsomhet': ('voldsomhet',),
'voldsomheta': ('voldsomhet',),
'voldsomheten': ('voldsomhet',),
'voldsomhetene': ('voldsomhet',),
'voldsomheter': ('voldsomhet',),
'voldsromantikk': ('voldsromantikk',),
'voldsromantikken': ('voldsromantikk',),
'voldsromantikkene': ('voldsromantikk',),
'voldsromantikker': ('voldsromantikk',),
'voldtekt': ('voldtekt',),
'voldtekta': ('voldtekt',),
'voldtekten': ('voldtekt',),
'voldtektene': ('voldtekt',),
'voldtekter': ('voldtekt',),
'voldtektsforbryter': ('voldtektsforbryter',),
'voldtektsforbrytere': ('voldtektsforbryter',),
'voldtektsforbryteren': ('voldtektsforbryter',),
'voldtektsforbryterer': ('voldtektsforbryter',),
'voldtektsforbryterne': ('voldtektsforbryter',),
'voldtektsforsøk': ('voldtektsforsøk',),
'voldtektsforsøka': ('voldtektsforsøk',),
'voldtektsforsøkene': ('voldtektsforsøk',),
'voldtektsforsøket': ('voldtektsforsøk',),
'voldtektsoffer': ('voldtektsoffer',),
'voldtektsofferet': ('voldtektsoffer',),
'voldtektsofra': ('voldtektsoffer',),
'voldtektsofre': ('voldtektsoffer',),
'voldtektsofrene': ('voldtektsoffer',),
'voll': ('voll',),
'vollen': ('voll',),
'vollene': ('voll',),
'voller': ('voll',),
'voll': ('voll',),
'vollen': ('voll',),
'vollene': ('voll',),
'voller': ('voll',),
'volley': ('volley',),
'volleyen': ('volley',),
'volleyene': ('volley',),
'volleyer': ('volley',),
'volleyball': ('volleyball',),
'volleyballen': ('volleyball',),
'volleyballene': ('volleyball',),
'volleyballer': ('volleyball',),
'vollgrav': ('vollgrav',),
'vollgrava': ('vollgrav',),
'vollgraven': ('vollgrav',),
'vollgravene': ('vollgrav',),
'vollgraver': ('vollgrav',),
'vollhøy': ('vollhøy',),
'vollhøya': ('vollhøy',),
'vollhøyene': ('vollhøy',),
'vollhøyet': ('vollhøy',),
'volontrisa': ('volontrise',),
'volontrise': ('volontrise',),
'volontrisen': ('volontrise',),
'volontrisene': ('volontrise',),
'volontriser': ('volontrise',),
'volontør': ('volontør',),
'volontøren': ('volontør',),
'volontørene': ('volontør',),
'volontører': ('volontør',),
'volt': ('volt',),
'volten': ('volt',),
'voltene': ('volt',),
'voltampere': ('voltampere',),
'voltamperen': ('voltampere',),
'voltamperene': ('voltampere',),
'voltaner': ('voltaner',),
'voltanere': ('voltaner',),
'voltaneren': ('voltaner',),
'voltanerer': ('voltaner',),
'voltanerne': ('voltaner',),
'volte': ('volte',),
'volten': ('volte',),
'voltene': ('volte',),
'volter': ('volte',),
'voltige': ('voltige',),
'voltigen': ('voltige',),
'voltigene': ('voltige',),
'voltiger': ('voltige',),
'voltmeter': ('voltmeter',),
'voltmeteret': ('voltmeter',),
'voltmetra': ('voltmeter',),
'voltmetre': ('voltmeter',),
'voltmetrene': ('voltmeter',),
'voltmetret': ('voltmeter',),
'volum': ('volum',),
'voluma': ('volum',),
'volumene': ('volum',),
'volumer': ('volum',),
'volumet': ('volum',),
'volumeter': ('volumeter',),
'volumeteret': ('volumeter',),
'volumetra': ('volumeter',),
'volumetre': ('volumeter',),
'volumetrene': ('volumeter',),
'volumetret': ('volumeter',),
'volumetri': ('volumetri',),
'volumetrien': ('volumetri',),
'volumetriene': ('volumetri',),
'volumetrier': ('volumetri',),
'volumkontroll': ('volumkontroll',),
'volumkontrollen': ('volumkontroll',),
'volumkontrollene': ('volumkontroll',),
'volumkontroller': ('volumkontroll',),
'volumprosent': ('volumprosent',),
'volumprosenten': ('volumprosent',),
'volumprosentene': ('volumprosent',),
'volumprosenter': ('volumprosent',),
'volumvekt': ('volumvekt',),
'volumvekta': ('volumvekt',),
'volumvekten': ('volumvekt',),
'volumvektene': ('volumvekt',),
'volumvekter': ('volumvekt',),
'volutt': ('volutt',),
'volutten': ('volutt',),
'voluttene': ('volutt',),
'volutter': ('volutt',),
'volva': ('volve',),
'volve': ('volve',),
'volven': ('volve',),
'volvene': ('volve',),
'volver': ('volve',),
'vom': ('vom',),
'vomma': ('vom',),
'vommen': ('vom',),
'vommene': ('vom',),
'vommer': ('vom',),
'vomfyll': ('vomfyll',),
'vomfylla': ('vomfyll',),
'vomfyllen': ('vomfyll',),
'vomfyllene': ('vomfyll',),
'vomfyller': ('vomfyll',),
'vomfyllet': ('vomfyll',),
'vomitiv': ('vomitiv',),
'vomitiva': ('vomitiv',),
'vomitivene': ('vomitiv',),
'vomitiver': ('vomitiv',),
'vomitivet': ('vomitiv',),
'von': ('von',),
'vona': ('von',),
'vonen': ('von',),
'vonene': ('von',),
'voner': ('von',),
'vondord': ('vondord',),
'vondorda': ('vondord',),
'vondordene': ('vondord',),
'vondordet': ('vondord',),
'vondskap': ('vondskap',),
'vondskapen': ('vondskap',),
'vondskapene': ('vondskap',),
'vondskaper': ('vondskap',),
'vondska': ('vondske',),
'vondske': ('vondske',),
'vondsken': ('vondske',),
'vondskene': ('vondske',),
'vondsker': ('vondske',),
'vonløshet': ('vonløshet',),
'vonløsheta': ('vonløshet',),
'vonløsheten': ('vonløshet',),
'vonløshetene': ('vonløshet',),
'vonløsheter': ('vonløshet',),
'vonløysa': ('vonløyse',),
'vonløyse': ('vonløyse',),
'vonløysen': ('vonløyse',),
'vonløysene': ('vonløyse',),
'vonløyser': ('vonløyse',),
'voodoo': ('voodoo',),
'voodooen': ('voodoo',),
'voodooene': ('voodoo',),
'voodooer': ('voodoo',),
'vor': ('vor',),
'voren': ('vor',),
'vorene': ('vor',),
'vorer': ('vor',),
'vord': ('vord',),
'vorden': ('vord',),
'vordene': ('vord',),
'vorder': ('vord',),
'vorden': ('vorden',),
'vorr': ('vorr',),
'vorren': ('vorr',),
'vorrene': ('vorr',),
'vorrer': ('vorr',),
'vorspiel': ('vorspiel',),
'vorspiela': ('vorspiel',),
'vorspielene': ('vorspiel',),
'vorspielet': ('vorspiel',),
'vorsteher': ('vorsteher',),
'vorstehere': ('vorsteher',),
'vorsteheren': ('vorsteher',),
'vorsteherer': ('vorsteher',),
'vorsteherne': ('vorsteher',),
'vorstehhund': ('vorstehhund',),
'vorstehhunden': ('vorstehhund',),
'vorstehhundene': ('vorstehhund',),
'vorstehhunder': ('vorstehhund',),
'vorstehvalp': ('vorstehvalp',),
'vorstehvalpen': ('vorstehvalp',),
'vorstehvalpene': ('vorstehvalp',),
'vorstehvalper': ('vorstehvalp',),
'vorta': ('vorte',),
'vorte': ('vorte',),
'vorten': ('vorte',),
'vortene': ('vorte',),
'vorter': ('vorte',),
'vortemelk': ('vortemelk',),
'vortemelken': ('vortemelk',),
'vortemelkene': ('vortemelk',),
'vortemjølk': ('vortemjølk',),
'vortemjølken': ('vortemjølk',),
'vortemjølkene': ('vortemjølk',),
'vortestein': ('vortestein',),
'vortesteinen': ('vortestein',),
'vortesteinene': ('vortestein',),
'vortesteiner': ('vortestein',),
'vortesvin': ('vortesvin',),
'vortesvina': ('vortesvin',),
'vortesvinene': ('vortesvin',),
'vortesvinet': ('vortesvin',),
'vossekurv': ('vossekurv',),
'vossekurven': ('vossekurv',),
'vossekurvene': ('vossekurv',),
'vossekurver': ('vossekurv',),
'vosserull': ('vosserull',),
'vosserullen': ('vosserull',),
'vosserullene': ('vosserull',),
'vosseruller': ('vosserull',),
'vossing': ('vossing',),
'vossingen': ('vossing',),
'vossingene': ('vossing',),
'vossinger': ('vossing',),
'votering': ('votering',),
'voteringa': ('votering',),
'voteringen': ('votering',),
'voteringene': ('votering',),
'voteringer': ('votering',),
'voteringsanlegg': ('voteringsanlegg',),
'voteringsanlegga': ('voteringsanlegg',),
'voteringsanleggene': ('voteringsanlegg',),
'voteringsanlegget': ('voteringsanlegg',),
'voteringsgrunnlag': ('voteringsgrunnlag',),
'voteringsgrunnlaga': ('voteringsgrunnlag',),
'voteringsgrunnlagene': ('voteringsgrunnlag',),
'voteringsgrunnlaget': ('voteringsgrunnlag',),
'voteringsknapp': ('voteringsknapp',),
'voteringsknappen': ('voteringsknapp',),
'voteringsknappene': ('voteringsknapp',),
'voteringsknapper': ('voteringsknapp',),
'votivgava': ('votivgave',),
'votivgave': ('votivgave',),
'votivgaven': ('votivgave',),
'votivgavene': ('votivgave',),
'votivgaver': ('votivgave',),
'vott': ('vott',),
'votten': ('vott',),
'vottene': ('vott',),
'votter': ('vott',),
'vottepar': ('vottepar',),
'vottepara': ('vottepar',),
'votteparene': ('vottepar',),
'votteparet': ('vottepar',),
'vottpar': ('vottpar',),
'vottpara': ('vottpar',),
'vottparene': ('vottpar',),
'vottparet': ('vottpar',),
'vota': ('votum',),
'votaene': ('votum',),
'votum': ('votum',),
'votumet': ('votum',),
'vov': ('vov',),
'voven': ('vov',),
'vovene': ('vov',),
'vover': ('vov',),
'vovvov': ('vovvov',),
'vovvoven': ('vovvov',),
'vovvovene': ('vovvov',),
'vovvover': ('vovvov',),
'vrak': ('vrak',),
'vraka': ('vrak',),
'vrakene': ('vrak',),
'vraket': ('vrak',),
'vraker': ('vraker',),
'vrakere': ('vraker',),
'vrakeren': ('vraker',),
'vrakerer': ('vraker',),
'vrakerne': ('vraker',),
'vrakfisk': ('vrakfisk',),
'vrakfisken': ('vrakfisk',),
'vrakfiskene': ('vrakfisk',),
'vrakfisker': ('vrakfisk',),
'vrakgods': ('vrakgods',),
'vrakgodsa': ('vrakgods',),
'vrakgodsene': ('vrakgods',),
'vrakgodset': ('vrakgods',),
'vrakpant': ('vrakpant',),
'vrakpanten': ('vrakpant',),
'vrakpantene': ('vrakpant',),
'vrakpanter': ('vrakpant',),
'vrakplyndring': ('vrakplyndring',),
'vrakplyndringa': ('vrakplyndring',),
'vrakplyndringen': ('vrakplyndring',),
'vrakplyndringene': ('vrakplyndring',),
'vrakplyndringer': ('vrakplyndring',),
'vrakrest': ('vrakrest',),
'vrakresten': ('vrakrest',),
'vrakrestene': ('vrakrest',),
'vrakrester': ('vrakrest',),
'vrakrøver': ('vrakrøver',),
'vrakrøvere': ('vrakrøver',),
'vrakrøveren': ('vrakrøver',),
'vrakrøverer': ('vrakrøver',),
'vrakrøverne': ('vrakrøver',),
'vraktømmer': ('vraktømmer',),
'vraktømmera': ('vraktømmer',),
'vraktømmerene': ('vraktømmer',),
'vraktømmeret': ('vraktømmer',),
'vraktømra': ('vraktømmer',),
'vraktømre': ('vraktømmer',),
'vraktømrene': ('vraktømmer',),
'vrangbord': ('vrangbord',),
'vrangborden': ('vrangbord',),
'vrangbordene': ('vrangbord',),
'vrangborder': ('vrangbord',),
'vrangborda': ('vrangborde',),
'vrangborde': ('vrangborde',),
'vrangborden': ('vrangborde',),
'vrangbordene': ('vrangborde',),
'vrangborder': ('vrangborde',),
'vranga': ('vrange',),
'vrange': ('vrange',),
'vrangen': ('vrange',),
'vrangene': ('vrange',),
'vranger': ('vrange',),
'vrangforestilling': ('vrangforestilling',),
'vrangforestillinga': ('vrangforestilling',),
'vrangforestillingen': ('vrangforestilling',),
'vrangforestillingene': ('vrangforestilling',),
'vrangforestillinger': ('vrangforestilling',),
'vranglås': ('vranglås',),
'vranglåsa': ('vranglås',),
'vranglåsen': ('vranglås',),
'vranglåsene': ('vranglås',),
'vranglåser': ('vranglås',),
'vranglåset': ('vranglås',),
'vranglæra': ('vranglære',),
'vranglære': ('vranglære',),
'vranglæren': ('vranglære',),
'vranglærene': ('vranglære',),
'vranglærer': ('vranglære',),
'vrangmaska': ('vrangmaske',),
'vrangmaske': ('vrangmaske',),
'vrangmasken': ('vrangmaske',),
'vrangmaskene': ('vrangmaske',),
'vrangmasker': ('vrangmaske',),
'vrangsida': ('vrangside',),
'vrangside': ('vrangside',),
'vrangsiden': ('vrangside',),
'vrangsidene': ('vrangside',),
'vrangsider': ('vrangside',),
'vrangstrupe': ('vrangstrupe',),
'vrangstrupen': ('vrangstrupe',),
'vrangstrupene': ('vrangstrupe',),
'vrangstruper': ('vrangstrupe',),
'vrangvilje': ('vrangvilje',),
'vrangviljen': ('vrangvilje',),
'vrangviljene': ('vrangvilje',),
'vrangviljer': ('vrangvilje',),
'vrede': ('vrede',),
'vreden': ('vrede',),
'vredene': ('vrede',),
'vreder': ('vrede',),
'vrengebilda': ('vrengebilde',),
'vrengebilde': ('vrengebilde',),
'vrengebildene': ('vrengebilde',),
'vrengebilder': ('vrengebilde',),
'vrengebildet': ('vrengebilde',),
'vri': ('vri',),
'vrien': ('vri',),
'vriene': ('vri',),
'vrier': ('vri',),
'vri': ('vri',),
'vrien': ('vri',),
'vriene': ('vri',),
'vrier': ('vri',),
'vrid': ('vrid',),
'vriden': ('vrid',),
'vridene': ('vrid',),
'vrider': ('vrid',),
'vrid': ('vrid',),
'vriden': ('vrid',),
'vridene': ('vrid',),
'vrider': ('vrid',),
'vrider': ('vrider',),
'vridere': ('vrider',),
'vrideren': ('vrider',),
'vriderer': ('vrider',),
'vriderne': ('vrider',),
'vriding': ('vriding',),
'vridinga': ('vriding',),
'vridingen': ('vriding',),
'vridingene': ('vriding',),
'vridinger': ('vriding',),
'vridning': ('vridning',),
'vridninga': ('vridning',),
'vridningen': ('vridning',),
'vridningene': ('vridning',),
'vridninger': ('vridning',),
'vridningsmoment': ('vridningsmoment',),
'vridningsmomenta': ('vridningsmoment',),
'vridningsmomentene': ('vridningsmoment',),
'vridningsmomenter': ('vridningsmoment',),
'vridningsmomentet': ('vridningsmoment',),
'vrier': ('vrier',),
'vriere': ('vrier',),
'vrieren': ('vrier',),
'vrierer': ('vrier',),
'vrierne': ('vrier',),
'vriing': ('vriing',),
'vriinga': ('vriing',),
'vriingen': ('vriing',),
'vriingene': ('vriing',),
'vriinger': ('vriing',),
'vrikk': ('vrikk',),
'vrikka': ('vrikk',),
'vrikkene': ('vrikk',),
'vrikket': ('vrikk',),
'vrimaskin': ('vrimaskin',),
'vrimaskina': ('vrimaskin',),
'vrimaskinen': ('vrimaskin',),
'vrimaskinene': ('vrimaskin',),
'vrimaskiner': ('vrimaskin',),
'vrimlene': ('vrimmel',),
'vrimler': ('vrimmel',),
'vrimmel': ('vrimmel',),
'vrimmelen': ('vrimmel',),
'vrimoment': ('vrimoment',),
'vrimomenta': ('vrimoment',),
'vrimomentene': ('vrimoment',),
'vrimomenter': ('vrimoment',),
'vrimomentet': ('vrimoment',),
'vringel': ('vringel',),
'vringelet': ('vringel',),
'vringla': ('vringel',),
'vringlene': ('vringel',),
'vringler': ('vringel',),
'vringlet': ('vringel',),
'vringler': ('vringler',),
'vringlere': ('vringler',),
'vringleren': ('vringler',),
'vringlerer': ('vringler',),
'vringlerne': ('vringler',),
'vringleri': ('vringleri',),
'vringleria': ('vringleri',),
'vringleriene': ('vringleri',),
'vringlerier': ('vringleri',),
'vringleriet': ('vringleri',),
'vrinsk': ('vrinsk',),
'vrinska': ('vrinsk',),
'vrinskene': ('vrinsk',),
'vrinsket': ('vrinsk',),
'vriompeis': ('vriompeis',),
'vriompeisen': ('vriompeis',),
'vriompeisene': ('vriompeis',),
'vriompeiser': ('vriompeis',),
'vriompeiseri': ('vriompeiseri',),
'vriompeiseria': ('vriompeiseri',),
'vriompeiseriene': ('vriompeiseri',),
'vriompeiserier': ('vriompeiseri',),
'vriompeiseriet': ('vriompeiseri',),
'vrist': ('vrist',),
'vrista': ('vrist',),
'vristen': ('vrist',),
'vristene': ('vrist',),
'vrister': ('vrist',),
'vrist': ('vrist',),
'vrista': ('vrist',),
'vristen': ('vrist',),
'vristene': ('vrist',),
'vrister': ('vrist',),
'vrå': ('vrå',),
'vråen': ('vrå',),
'vråene': ('vrå',),
'vråer': ('vrå',),
'vræl': ('vræl',),
'vræla': ('vræl',),
'vrælene': ('vræl',),
'vrælet': ('vræl',),
'vrøvl': ('vrøvl',),
'vrøvla': ('vrøvl',),
'vrøvlene': ('vrøvl',),
'vrøvlet': ('vrøvl',),
'vrøvlekopp': ('vrøvlekopp',),
'vrøvlekoppen': ('vrøvlekopp',),
'vrøvlekoppene': ('vrøvlekopp',),
'vrøvlekopper': ('vrøvlekopp',),
'vrøvler': ('vrøvler',),
'vrøvlere': ('vrøvler',),
'vrøvleren': ('vrøvler',),
'vrøvlerer': ('vrøvler',),
'vrøvlerne': ('vrøvler',),
'vuggebarn': ('vuggebarn',),
'vuggebarna': ('vuggebarn',),
'vuggebarnene': ('vuggebarn',),
'vuggebarnet': ('vuggebarn',),
'vuggegava': ('vuggegave',),
'vuggegave': ('vuggegave',),
'vuggegaven': ('vuggegave',),
'vuggegavene': ('vuggegave',),
'vuggegaver': ('vuggegave',),
'vuggemei': ('vuggemei',),
'vuggemeien': ('vuggemei',),
'vuggemeiene': ('vuggemei',),
'vuggemeier': ('vuggemei',),
'vuggemeia': ('vuggemeie',),
'vuggemeie': ('vuggemeie',),
'vuggemeien': ('vuggemeie',),
'vuggemeiene': ('vuggemeie',),
'vuggemeier': ('vuggemeie',),
'vuggesang': ('vuggesang',),
'vuggesangen': ('vuggesang',),
'vuggesangene': ('vuggesang',),
'vuggesanger': ('vuggesang',),
'vuggevisa': ('vuggevise',),
'vuggevise': ('vuggevise',),
'vuggevisen': ('vuggevise',),
'vuggevisene': ('vuggevise',),
'vuggeviser': ('vuggevise',),
'vulgarisme': ('vulgarisme',),
'vulgarismen': ('vulgarisme',),
'vulgarismene': ('vulgarisme',),
'vulgarismer': ('vulgarisme',),
'vulgaritet': ('vulgaritet',),
'vulgariteten': ('vulgaritet',),
'vulgaritetene': ('vulgaritet',),
'vulgariteter': ('vulgaritet',),
'vulgæragitasjon': ('vulgæragitasjon',),
'vulgæragitasjonen': ('vulgæragitasjon',),
'vulgæragitasjonene': ('vulgæragitasjon',),
'vulgæragitasjoner': ('vulgæragitasjon',),
'vulgærlatin': ('vulgærlatin',),
'vulgærlatinen': ('vulgærlatin',),
'vulgærlatinene': ('vulgærlatin',),
'vulgærlatiner': ('vulgærlatin',),
'vulgærpropaganda': ('vulgærpropaganda',),
'vulgærpropagandaen': ('vulgærpropaganda',),
'vulgærpropagandaene': ('vulgærpropaganda',),
'vulgærpropagandaer': ('vulgærpropaganda',),
'vulgærspråk': ('vulgærspråk',),
'vulgærspråka': ('vulgærspråk',),
'vulgærspråkene': ('vulgærspråk',),
'vulgærspråket': ('vulgærspråk',),
'vulkan': ('vulkan',),
'vulkanen': ('vulkan',),
'vulkanene': ('vulkan',),
'vulkaner': ('vulkan',),
'vulkanfiber': ('vulkanfiber',),
'vulkanfibere': ('vulkanfiber',),
'vulkanfiberen': ('vulkanfiber',),
'vulkanfiberer': ('vulkanfiber',),
'vulkanfiberne': ('vulkanfiber',),
'vulkanfibre': ('vulkanfiber',),
'vulkanfibrene': ('vulkanfiber',),
'vulkanfibrer': ('vulkanfiber',),
'vulkanfjell': ('vulkanfjell',),
'vulkanfjella': ('vulkanfjell',),
'vulkanfjellene': ('vulkanfjell',),
'vulkanfjellet': ('vulkanfjell',),
'vulkanisat': ('vulkanisat',),
'vulkanisata': ('vulkanisat',),
'vulkanisatene': ('vulkanisat',),
'vulkanisatet': ('vulkanisat',),
'vulkanisering': ('vulkanisering',),
'vulkaniseringa': ('vulkanisering',),
'vulkaniseringen': ('vulkanisering',),
'vulkaniseringene': ('vulkanisering',),
'vulkaniseringer': ('vulkanisering',),
'vulkaniseringsverksted': ('vulkaniseringsverksted',),
'vulkaniseringsverkstedene': ('vulkaniseringsverksted',),
'vulkaniseringsverksteder': ('vulkaniseringsverksted',),
'vulkaniseringsverkstedet': ('vulkaniseringsverksted',),
'vulkanisme': ('vulkanisme',),
'vulkanismen': ('vulkanisme',),
'vulkanismene': ('vulkanisme',),
'vulkanismer': ('vulkanisme',),
'vulkanisør': ('vulkanisør',),
'vulkanisøren': ('vulkanisør',),
'vulkanisørene': ('vulkanisør',),
'vulkanisører': ('vulkanisør',),
'vulkanolog': ('vulkanolog',),
'vulkanologen': ('vulkanolog',),
'vulkanologene': ('vulkanolog',),
'vulkanologer': ('vulkanolog',),
'vulkanologi': ('vulkanologi',),
'vulkanologien': ('vulkanologi',),
'vulkanologiene': ('vulkanologi',),
'vulkanologier': ('vulkanologi',),
'vulkanutbrott': ('vulkanutbrott',),
'vulkanutbrotta': ('vulkanutbrott',),
'vulkanutbrottene': ('vulkanutbrott',),
'vulkanutbrottet': ('vulkanutbrott',),
'vulkanutbrudd': ('vulkanutbrudd',),
'vulkanutbrudda': ('vulkanutbrudd',),
'vulkanutbruddene': ('vulkanutbrudd',),
'vulkanutbruddet': ('vulkanutbrudd',),
'vulkanøy': ('vulkanøy',),
'vulkanøya': ('vulkanøy',),
'vulkanøyen': ('vulkanøy',),
'vulkanøyene': ('vulkanøy',),
'vulkanøyer': ('vulkanøy',),
'vulst': ('vulst',),
'vulsten': ('vulst',),
'vulstene': ('vulst',),
'vulster': ('vulst',),
'vulstdekk': ('vulstdekk',),
'vulstdekka': ('vulstdekk',),
'vulstdekkene': ('vulstdekk',),
'vulstdekket': ('vulstdekk',),
'vulva': ('vulva',),
'vurdering': ('vurdering',),
'vurderinga': ('vurdering',),
'vurderingen': ('vurdering',),
'vurderingene': ('vurdering',),
'vurderinger': ('vurdering',),
'vurderingsevna': ('vurderingsevne',),
'vurderingsevne': ('vurderingsevne',),
'vurderingsevnen': ('vurderingsevne',),
'vurderingsevnene': ('vurderingsevne',),
'vurderingsevner': ('vurderingsevne',),
'vurderingsgrunnlag': ('vurderingsgrunnlag',),
'vurderingsgrunnlaga': ('vurderingsgrunnlag',),
'vurderingsgrunnlagene': ('vurderingsgrunnlag',),
'vurderingsgrunnlaget': ('vurderingsgrunnlag',),
'vurderingsmåte': ('vurderingsmåte',),
'vurderingsmåten': ('vurderingsmåte',),
'vurderingsmåtene': ('vurderingsmåte',),
'vurderingsmåter': ('vurderingsmåte',),
'vurderingssak': ('vurderingssak',),
'vurderingssaka': ('vurderingssak',),
'vurderingssaken': ('vurderingssak',),
'vurderingssakene': ('vurderingssak',),
'vurderingssaker': ('vurderingssak',),
'vy': ('vy',),
'vyen': ('vy',),
'vyene': ('vy',),
'vyer': ('vy',),
'vå': ('vå',),
'våa': ('vå',),
'våen': ('vå',),
'våene': ('vå',),
'våer': ('vå',),
'våbønn': ('våbønn',),
'våbønna': ('våbønn',),
'våbønnen': ('våbønn',),
'våbønnene': ('våbønn',),
'våbønner': ('våbønn',),
'våd': ('våd',),
'våda': ('våd',),
'våden': ('våd',),
'vådene': ('våd',),
'våder': ('våd',),
'våde': ('våde',),
'våden': ('våde',),
'vådene': ('våde',),
'våder': ('våde',),
'vådedrap': ('vådedrap',),
'vådedrapa': ('vådedrap',),
'vådedrapene': ('vådedrap',),
'vådedrapet': ('vådedrap',),
'vådedød': ('vådedød',),
'vådedøden': ('vådedød',),
'vådedødene': ('vådedød',),
'vådedøder': ('vådedød',),
'vådeeld': ('vådeeld',),
'vådeelden': ('vådeeld',),
'vådeeldene': ('vådeeld',),
'vådeelder': ('vådeeld',),
'vådeild': ('vådeild',),
'vådeilden': ('vådeild',),
'vådeildene': ('vådeild',),
'vådeilder': ('vådeild',),
'vådeskott': ('vådeskott',),
'vådeskotta': ('vådeskott',),
'vådeskottene': ('vådeskott',),
'vådeskottet': ('vådeskott',),
'vådeskudd': ('vådeskudd',),
'vådeskudda': ('vådeskudd',),
'vådeskuddene': ('vådeskudd',),
'vådeskuddet': ('vådeskudd',),
'vådeverk': ('vådeverk',),
'vådeverka': ('vådeverk',),
'vådeverkene': ('vådeverk',),
'vådeverker': ('vådeverk',),
'vådeverket': ('vådeverk',),
'våe': ('våe',),
'våen': ('våe',),
'våene': ('våe',),
'våer': ('våe',),
'våg': ('våg',),
'våga': ('våg',),
'vågene': ('våg',),
'våget': ('våg',),
'vågehals': ('vågehals',),
'vågehalsen': ('vågehals',),
'vågehalsene': ('vågehals',),
'vågehalser': ('vågehals',),
'vågehval': ('vågehval',),
'vågehvalen': ('vågehval',),
'vågehvalene': ('vågehval',),
'vågehvaler': ('vågehval',),
'vågekval': ('vågekval',),
'vågekvalen': ('vågekval',),
'vågekvalene': ('vågekval',),
'vågekvaler': ('vågekval',),
'vågemot': ('vågemot',),
'vågemota': ('vågemot',),
'vågemotene': ('vågemot',),
'vågemotet': ('vågemot',),
'vågespell': ('vågespell',),
'vågespella': ('vågespell',),
'vågespellene': ('vågespell',),
'vågespellet': ('vågespell',),
'vågespill': ('vågespill',),
'vågespilla': ('vågespill',),
'vågespillene': ('vågespill',),
'vågespillet': ('vågespill',),
'vågestykka': ('vågestykke',),
'vågestykke': ('vågestykke',),
'vågestykkene': ('vågestykke',),
'vågestykker': ('vågestykke',),
'vågestykket': ('vågestykke',),
'våghals': ('våghals',),
'våghalsen': ('våghals',),
'våghalsene': ('våghals',),
'våghalser': ('våghals',),
'vågmor': ('vågmor',),
'vågmora': ('vågmor',),
'vågmoren': ('vågmor',),
'vågmorene': ('vågmor',),
'vågmorer': ('vågmor',),
'vågnad': ('vågnad',),
'vågnaden': ('vågnad',),
'vågnadene': ('vågnad',),
'vågnader': ('vågnad',),
'vågsbotn': ('vågsbotn',),
'vågsbotnen': ('vågsbotn',),
'vågsbotnene': ('vågsbotn',),
'vågsbotner': ('vågsbotn',),
'våk': ('våk',),
'våken': ('våk',),
'våkene': ('våk',),
'våker': ('våk',),
'våk': ('våk',),
'våken': ('våk',),
'våkene': ('våk',),
'våker': ('våk',),
'våk': ('våk',),
'våka': ('våk',),
'våken': ('våk',),
'våkene': ('våk',),
'våker': ('våk',),
'våket': ('våk',),
'våk': ('våk',),
'våka': ('våk',),
'våken': ('våk',),
'våkene': ('våk',),
'våker': ('våk',),
'vål': ('vål',),
'våla': ('vål',),
'vålene': ('vål',),
'vålet': ('vål',),
'vånd': ('vånd',),
'vånden': ('vånd',),
'våndene': ('vånd',),
'vånder': ('vånd',),
'vånd': ('vånd',),
'vånden': ('vånd',),
'våndene': ('vånd',),
'vånder': ('vånd',),
'vånde': ('vånde',),
'vånden': ('vånde',),
'våndene': ('vånde',),
'vånder': ('vånde',),
'våning': ('våning',),
'våninga': ('våning',),
'våningen': ('våning',),
'våningene': ('våning',),
'våninger': ('våning',),
'våningshus': ('våningshus',),
'våningshusa': ('våningshus',),
'våningshusene': ('våningshus',),
'våningshuset': ('våningshus',),
'våpen': ('våpen',),
'våpenet': ('våpen',),
'våpna': ('våpen',),
'våpnene': ('våpen',),
'våpenarsenal': ('våpenarsenal',),
'våpenarsenala': ('våpenarsenal',),
'våpenarsenalene': ('våpenarsenal',),
'våpenarsenaler': ('våpenarsenal',),
'våpenarsenalet': ('våpenarsenal',),
'våpenart': ('våpenart',),
'våpenarta': ('våpenart',),
'våpenarten': ('våpenart',),
'våpenartene': ('våpenart',),
'våpenarter': ('våpenart',),
'våpenbror': ('våpenbror',),
'våpenbroren': ('våpenbror',),
'våpenbrødre': ('våpenbror',),
'våpenbrødrene': ('våpenbror',),
'våpenbruk': ('våpenbruk',),
'våpenbruka': ('våpenbruk',),
'våpenbruken': ('våpenbruk',),
'våpenbrukene': ('våpenbruk',),
'våpenbruker': ('våpenbruk',),
'våpenbruket': ('våpenbruk',),
'våpendrager': ('våpendrager',),
'våpendragere': ('våpendrager',),
'våpendrageren': ('våpendrager',),
'våpendragerer': ('våpendrager',),
'våpendragerne': ('våpendrager',),
'våpengny': ('våpengny',),
'våpengnya': ('våpengny',),
'våpengnyene': ('våpengny',),
'våpengnyet': ('våpengny',),
'våpengrein': ('våpengrein',),
'våpengreina': ('våpengrein',),
'våpengreinen': ('våpengrein',),
'våpengreinene': ('våpengrein',),
'våpengreiner': ('våpengrein',),
'våpengren': ('våpengren',),
'våpengrena': ('våpengren',),
'våpengrenen': ('våpengren',),
'våpengrenene': ('våpengren',),
'våpengrener': ('våpengren',),
'våpenhjelp': ('våpenhjelp',),
'våpenhjelpa': ('våpenhjelp',),
'våpenhjelpen': ('våpenhjelp',),
'våpenhjelpene': ('våpenhjelp',),
'våpenhjelper': ('våpenhjelp',),
'våpenhus': ('våpenhus',),
'våpenhusa': ('våpenhus',),
'våpenhusene': ('våpenhus',),
'våpenhuset': ('våpenhus',),
'våpenhvila': ('våpenhvile',),
'våpenhvile': ('våpenhvile',),
'våpenhvilen': ('våpenhvile',),
'våpenhvilene': ('våpenhvile',),
'våpenhviler': ('våpenhvile',),
'våpenkappløp': ('våpenkappløp',),
'våpenkappløpa': ('våpenkappløp',),
'våpenkappløpene': ('våpenkappløp',),
'våpenkappløpet': ('våpenkappløp',),
'våpenkvila': ('våpenkvile',),
'våpenkvile': ('våpenkvile',),
'våpenkvilen': ('våpenkvile',),
'våpenkvilene': ('våpenkvile',),
'våpenkviler': ('våpenkvile',),
'våpenlarm': ('våpenlarm',),
'våpenlarmen': ('våpenlarm',),
'våpenlarmene': ('våpenlarm',),
'våpenlarmer': ('våpenlarm',),
'våpenlisens': ('våpenlisens',),
'våpenlisensen': ('våpenlisens',),
'våpenlisensene': ('våpenlisens',),
'våpenlisenser': ('våpenlisens',),
'våpenmakt': ('våpenmakt',),
'våpenmakta': ('våpenmakt',),
'våpenmakten': ('våpenmakt',),
'våpenmaktene': ('våpenmakt',),
'våpenmakter': ('våpenmakt',),
'våpenmerka': ('våpenmerke',),
'våpenmerke': ('våpenmerke',),
'våpenmerkene': ('våpenmerke',),
'våpenmerker': ('våpenmerke',),
'våpenmerket': ('våpenmerke',),
'våpenskjold': ('våpenskjold',),
'våpenskjolda': ('våpenskjold',),
'våpenskjoldene': ('våpenskjold',),
'våpenskjoldet': ('våpenskjold',),
'våpensmugler': ('våpensmugler',),
'våpensmuglere': ('våpensmugler',),
'våpensmugleren': ('våpensmugler',),
'våpensmuglerer': ('våpensmugler',),
'våpensmuglerne': ('våpensmugler',),
'våpenstillstand': ('våpenstillstand',),
'våpenstillstanden': ('våpenstillstand',),
'våpenstillstandene': ('våpenstillstand',),
'våpenstillstander': ('våpenstillstand',),
'våpenstripa': ('våpenstripe',),
'våpenstripe': ('våpenstripe',),
'våpenstripen': ('våpenstripe',),
'våpenstripene': ('våpenstripe',),
'våpenstriper': ('våpenstripe',),
'våpensvenn': ('våpensvenn',),
'våpensvennen': ('våpensvenn',),
'våpensvennene': ('våpensvenn',),
'våpensvenner': ('våpensvenn',),
'våpensystem': ('våpensystem',),
'våpensystema': ('våpensystem',),
'våpensystemene': ('våpensystem',),
'våpensystemer': ('våpensystem',),
'våpensystemet': ('våpensystem',),
'våpenting': ('våpenting',),
'våpentinga': ('våpenting',),
'våpentingene': ('våpenting',),
'våpentinget': ('våpenting',),
'våpenøvelse': ('våpenøvelse',),
'våpenøvelsen': ('våpenøvelse',),
'våpenøvelsene': ('våpenøvelse',),
'våpenøvelser': ('våpenøvelse',),
'våpenøving': ('våpenøving',),
'våpenøvinga': ('våpenøving',),
'våpenøvingen': ('våpenøving',),
'våpenøvingene': ('våpenøving',),
'våpenøvinger': ('våpenøving',),
'vår': ('vår',),
'våren': ('vår',),
'vårene': ('vår',),
'vårer': ('vår',),
'vårblomst': ('vårblomst',),
'vårblomsten': ('vårblomst',),
'vårblomstene': ('vårblomst',),
'vårblomster': ('vårblomst',),
'vårbløyta': ('vårbløyte',),
'vårbløyte': ('vårbløyte',),
'vårbløyten': ('vårbløyte',),
'vårbløytene': ('vårbløyte',),
'vårbløyter': ('vårbløyte',),
'vårdag': ('vårdag',),
'vårdagen': ('vårdag',),
'vårdagene': ('vårdag',),
'vårdager': ('vårdag',),
'vårdrag': ('vårdrag',),
'vårdraga': ('vårdrag',),
'vårdragene': ('vårdrag',),
'vårdraget': ('vårdrag',),
'vårfag': ('vårfag',),
'vårfaga': ('vårfag',),
'vårfagene': ('vårfag',),
'vårfaget': ('vårfag',),
'vårfiska': ('vårfiske',),
'vårfiske': ('vårfiske',),
'vårfiskene': ('vårfiske',),
'vårfisker': ('vårfiske',),
'vårfisket': ('vårfiske',),
'vårfjøs': ('vårfjøs',),
'vårfjøsa': ('vårfjøs',),
'vårfjøsen': ('vårfjøs',),
'vårfjøsene': ('vårfjøs',),
'vårfjøset': ('vårfjøs',),
'vårfornemmelse': ('vårfornemmelse',),
'vårfornemmelsen': ('vårfornemmelse',),
'vårfornemmelsene': ('vårfornemmelse',),
'vårfornemmelser': ('vårfornemmelse',),
'vårfrumess': ('vårfrumess',),
'vårfrumess': ('vårfrumess',),
'vårfrumesse': ('vårfrumesse',),
'vårhvete': ('vårhvete',),
'vårhveten': ('vårhvete',),
'vårhvetene': ('vårhvete',),
'vårhveter': ('vårhvete',),
'vårhvete': ('vårhvete',),
'vårhveten': ('vårhvete',),
'vårhvetene': ('vårhvete',),
'vårhveter': ('vårhvete',),
'vårjamdøger': ('vårjamdøger',),
'vårjamdøgeret': ('vårjamdøger',),
'vårjamdøgerne': ('vårjamdøger',),
'vårjamdøgn': ('vårjamdøgn',),
'vårjamdøgna': ('vårjamdøgn',),
'vårjamdøgnene': ('vårjamdøgn',),
'vårjamdøgnet': ('vårjamdøgn',),
'vårjevndøgn': ('vårjevndøgn',),
'vårjevndøgna': ('vårjevndøgn',),
'vårjevndøgnene': ('vårjevndøgn',),
'vårjevndøgnet': ('vårjevndøgn',),
'vårkjensla': ('vårkjensle',),
'vårkjensle': ('vårkjensle',),
'vårkjenslen': ('vårkjensle',),
'vårkjenslene': ('vårkjensle',),
'vårkjensler': ('vårkjensle',),
'vårknipa': ('vårknipe',),
'vårknipe': ('vårknipe',),
'vårknipen': ('vårknipe',),
'vårknipene': ('vårknipe',),
'vårkniper': ('vårknipe',),
'vårkveite': ('vårkveite',),
'vårkveiten': ('vårkveite',),
'vårkveitene': ('vårkveite',),
'vårkveiter': ('vårkveite',),
'vårkveite': ('vårkveite',),
'vårkveiten': ('vårkveite',),
'vårkveitene': ('vårkveite',),
'vårkveiter': ('vårkveite',),
'vårkål': ('vårkål',),
'vårkålen': ('vårkål',),
'vårkålene': ('vårkål',),
'vårkåler': ('vårkål',),
'vårluft': ('vårluft',),
'vårlufta': ('vårluft',),
'vårluften': ('vårluft',),
'vårluftene': ('vårluft',),
'vårlufter': ('vårluft',),
'vårløsning': ('vårløsning',),
'vårløsninga': ('vårløsning',),
'vårløsningen': ('vårløsning',),
'vårløsningene': ('vårløsning',),
'vårløsninger': ('vårløsning',),
'vårløysing': ('vårløysing',),
'vårløysinga': ('vårløysing',),
'vårløysingen': ('vårløysing',),
'vårløysingene': ('vårløysing',),
'vårløysinger': ('vårløysing',),
'vårmåned': ('vårmåned',),
'vårmåneden': ('vårmåned',),
'vårmånedene': ('vårmåned',),
'vårmåneder': ('vårmåned',),
'våronn': ('våronn',),
'våronna': ('våronn',),
'våronnen': ('våronn',),
'våronnene': ('våronn',),
'våronner': ('våronn',),
'vårpart': ('vårpart',),
'vårparten': ('vårpart',),
'vårpartene': ('vårpart',),
'vårparter': ('vårpart',),
'vårregn': ('vårregn',),
'vårregna': ('vårregn',),
'vårregnene': ('vårregn',),
'vårregnet': ('vårregn',),
'vårreingjøring': ('vårreingjøring',),
'vårreingjøringa': ('vårreingjøring',),
'vårreingjøringen': ('vårreingjøring',),
'vårreingjøringene': ('vårreingjøring',),
'vårreingjøringer': ('vårreingjøring',),
'vårrengjøring': ('vårrengjøring',),
'vårrengjøringa': ('vårrengjøring',),
'vårrengjøringen': ('vårrengjøring',),
'vårrengjøringene': ('vårrengjøring',),
'vårrengjøringer': ('vårrengjøring',),
'vårsemester': ('vårsemester',),
'vårsemesteret': ('vårsemester',),
'vårsemestra': ('vårsemester',),
'vårsemestre': ('vårsemester',),
'vårsemestrene': ('vårsemester',),
'vårsemestret': ('vårsemester',),
'vårsesjon': ('vårsesjon',),
'vårsesjonen': ('vårsesjon',),
'vårsesjonene': ('vårsesjon',),
'vårsesjoner': ('vårsesjon',),
'vårsesong': ('vårsesong',),
'vårsesongen': ('vårsesong',),
'vårsesongene': ('vårsesong',),
'vårsesonger': ('vårsesong',),
'vårsida': ('vårside',),
'vårside': ('vårside',),
'vårsiden': ('vårside',),
'vårsidene': ('vårside',),
'vårsider': ('vårside',),
'vårsild': ('vårsild',),
'vårsilda': ('vårsild',),
'vårsilden': ('vårsild',),
'vårsildene': ('vårsild',),
'vårsilder': ('vårsild',),
'vårsildfiska': ('vårsildfiske',),
'vårsildfiske': ('vårsildfiske',),
'vårsildfiskene': ('vårsildfiske',),
'vårsildfisker': ('vårsildfiske',),
'vårsildfisket': ('vårsildfiske',),
'vårslepp': ('vårslepp',),
'vårsleppa': ('vårslepp',),
'vårsleppene': ('vårslepp',),
'vårsleppet': ('vårslepp',),
'vårslipp': ('vårslipp',),
'vårslippa': ('vårslipp',),
'vårslippene': ('vårslipp',),
'vårslippet': ('vårslipp',),
'vårsol': ('vårsol',),
'vårsola': ('vårsol',),
'vårsolen': ('vårsol',),
'vårsolene': ('vårsol',),
'vårsoler': ('vårsol',),
'vårsæd': ('vårsæd',),
'vårsæden': ('vårsæd',),
'vårsædene': ('vårsæd',),
'vårsæder': ('vårsæd',),
'vårtegn': ('vårtegn',),
'vårtegna': ('vårtegn',),
'vårtegnene': ('vårtegn',),
'vårtegnet': ('vårtegn',),
'vårtid': ('vårtid',),
'vårtida': ('vårtid',),
'vårtiden': ('vårtid',),
'vårtidene': ('vårtid',),
'vårtider': ('vårtid',),
'vårtorsk': ('vårtorsk',),
'vårtorsken': ('vårtorsk',),
'vårtorskene': ('vårtorsk',),
'vårtorsker': ('vårtorsk',),
'vårtorskefiska': ('vårtorskefiske',),
'vårtorskefiske': ('vårtorskefiske',),
'vårtorskefiskene': ('vårtorskefiske',),
'vårtorskefisker': ('vårtorskefiske',),
'vårtorskefisket': ('vårtorskefiske',),
'vårvinna': ('vårvinne',),
'vårvinne': ('vårvinne',),
'vårvinnen': ('vårvinne',),
'vårvinnene': ('vårvinne',),
'vårvinner': ('vårvinne',),
'vårvær': ('vårvær',),
'vårværa': ('vårvær',),
'vårværene': ('vårvær',),
'vårværet': ('vårvær',),
'vås': ('vås',),
'våsa': ('vås',),
'våsene': ('vås',),
'våset': ('vås',),
'våtdrakt': ('våtdrakt',),
'våtdrakta': ('våtdrakt',),
'våtdrakten': ('våtdrakt',),
'våtdraktene': ('våtdrakt',),
'våtdrakter': ('våtdrakt',),
'våtelement': ('våtelement',),
'våtelementa': ('våtelement',),
'våtelementene': ('våtelement',),
'våtelementer': ('våtelement',),
'våtelementet': ('våtelement',),
'våtflua': ('våtflue',),
'våtflue': ('våtflue',),
'våtfluen': ('våtflue',),
'våtfluene': ('våtflue',),
'våtfluer': ('våtflue',),
'våtgass': ('våtgass',),
'våtgassen': ('våtgass',),
'våtgassene': ('våtgass',),
'våtgasser': ('våtgass',),
'våtkopiering': ('våtkopiering',),
'våtkopieringa': ('våtkopiering',),
'våtkopieringen': ('våtkopiering',),
'våtkopieringene': ('våtkopiering',),
'våtkopieringer': ('våtkopiering',),
'våtmark': ('våtmark',),
'våtmarka': ('våtmark',),
'våtmarken': ('våtmark',),
'våtmarkene': ('våtmark',),
'våtmarker': ('våtmark',),
'våtmarksområda': ('våtmarksområde',),
'våtmarksområde': ('våtmarksområde',),
'våtmarksområdene': ('våtmarksområde',),
'våtmarksområder': ('våtmarksområde',),
'våtmarksområdet': ('våtmarksområde',),
'våtrom': ('våtrom',),
'våtromma': ('våtrom',),
'våtrommene': ('våtrom',),
'våtrommet': ('våtrom',),
'våtserviett': ('våtserviett',),
'våtservietten': ('våtserviett',),
'våtserviettene': ('våtserviett',),
'våtservietter': ('våtserviett',),
'våtsig': ('våtsig',),
'våtsiga': ('våtsig',),
'våtsigene': ('våtsig',),
'våtsiget': ('våtsig',),
'våtsnø': ('våtsnø',),
'våtsnøen': ('våtsnø',),
'våtsnøene': ('våtsnø',),
'våtsnøer': ('våtsnø',),
'våtsnøklister': ('våtsnøklister',),
'våtsnøklisteret': ('våtsnøklister',),
'våtsnøklistra': ('våtsnøklister',),
'våtsnøklistre': ('våtsnøklister',),
'våtsnøklistrene': ('våtsnøklister',),
'våtsnøklistret': ('våtsnøklister',),
'våtsnøsmurning': ('våtsnøsmurning',),
'våtsnøsmurninga': ('våtsnøsmurning',),
'våtsnøsmurningen': ('våtsnøsmurning',),
'våtsnøsmurningene': ('våtsnøsmurning',),
'våtsnøsmurninger': ('våtsnøsmurning',),
'våtsnøsmøring': ('våtsnøsmøring',),
'våtsnøsmøringa': ('våtsnøsmøring',),
'våtsnøsmøringen': ('våtsnøsmøring',),
'våtsnøsmøringene': ('våtsnøsmøring',),
'våtsnøsmøringer': ('våtsnøsmøring',),
'våtsommer': ('våtsommer',),
'våtsommere': ('våtsommer',),
'våtsommeren': ('våtsommer',),
'våtsommerne': ('våtsommer',),
'våtsomre': ('våtsommer',),
'våtsomrene': ('våtsommer',),
'våtsomrer': ('våtsommer',),
'væpner': ('væpner',),
'væpnere': ('væpner',),
'væpneren': ('væpner',),
'væpnerer': ('væpner',),
'væpnerne': ('væpner',),
'vær': ('vær',),
'væren': ('vær',),
'værene': ('vær',),
'værer': ('vær',),
'værbror': ('værbror',),
'værbroren': ('værbror',),
'værbrødre': ('værbror',),
'værbrødrene': ('værbror',),
'værdatter': ('værdatter',),
'værdattera': ('værdatter',),
'værdatteren': ('værdatter',),
'værdøtre': ('værdatter',),
'værdøtrene': ('værdatter',),
'værdøtrer': ('værdatter',),
'være': ('være',),
'væreier': ('væreier',),
'væreiere': ('væreier',),
'væreieren': ('væreier',),
'væreierer': ('væreier',),
'væreierne': ('væreier',),
'værelsa': ('værelse',),
'værelse': ('værelse',),
'værelsene': ('værelse',),
'værelser': ('værelse',),
'værelset': ('værelse',),
'værelsesbetjening': ('værelsesbetjening',),
'værelsesbetjeninga': ('værelsesbetjening',),
'værelsesbetjeningen': ('værelsesbetjening',),
'værelsesbetjeningene': ('værelsesbetjening',),
'værelsesbetjeninger': ('værelsesbetjening',),
'værelseskamerat': ('værelseskamerat',),
'værelseskameraten': ('værelseskamerat',),
'værelseskameratene': ('værelseskamerat',),
'værelseskamerater': ('værelseskamerat',),
'værelsespika': ('værelsespike',),
'værelsespike': ('værelsespike',),
'værelsespiken': ('værelsespike',),
'værelsespikene': ('værelsespike',),
'værelsespiker': ('værelsespike',),
'værelsestemperatur': ('værelsestemperatur',),
'værelsestemperaturen': ('værelsestemperatur',),
'værelsestemperaturene': ('værelsestemperatur',),
'værelsestemperaturer': ('værelsestemperatur',),
'væremåte': ('væremåte',),
'væremåten': ('væremåte',),
'væremåtene': ('væremåte',),
'væremåter': ('væremåte',),
'væren': ('væren',),
'værenen': ('væren',),
'værenene': ('væren',),
'værener': ('væren',),
'værested': ('værested',),
'værestedene': ('værested',),
'væresteder': ('værested',),
'værestedet': ('værested',),
'værfar': ('værfar',),
'værfaren': ('værfar',),
'værfedre': ('værfar',),
'værfedrene': ('værfar',),
'værforandring': ('værforandring',),
'værforandringa': ('værforandring',),
'værforandringen': ('værforandring',),
'værforandringene': ('værforandring',),
'værforandringer': ('værforandring',),
'værforhold': ('værforhold',),
'værforholda': ('værforhold',),
'værforholdene': ('værforhold',),
'værforholdet': ('værforhold',),
'værgud': ('værgud',),
'værguden': ('værgud',),
'værgudene': ('værgud',),
'værguder': ('værgud',),
'værhane': ('værhane',),
'værhanen': ('værhane',),
'værhanene': ('værhane',),
'værhaner': ('værhane',),
'værhår': ('værhår',),
'værhåra': ('værhår',),
'værhårene': ('værhår',),
'værhåret': ('værhår',),
'væring': ('væring',),
'væringen': ('væring',),
'væringene': ('væring',),
'væringer': ('væring',),
'værkart': ('værkart',),
'værkarta': ('værkart',),
'værkartene': ('værkart',),
'værkarter': ('værkart',),
'værkartet': ('værkart',),
'værlag': ('værlag',),
'værlaga': ('værlag',),
'værlagene': ('værlag',),
'værlaget': ('værlag',),
'værlam': ('værlam',),
'værlamma': ('værlam',),
'værlammene': ('værlam',),
'værlammet': ('værlam',),
'værmann': ('værmann',),
'værmannen': ('værmann',),
'værmenn': ('værmann',),
'værmennene': ('værmann',),
'værmelding': ('værmelding',),
'værmeldinga': ('værmelding',),
'værmeldingen': ('værmelding',),
'værmeldingene': ('værmelding',),
'værmeldinger': ('værmelding',),
'værmerka': ('værmerke',),
'værmerke': ('værmerke',),
'værmerkene': ('værmerke',),
'værmerker': ('værmerke',),
'værmerket': ('værmerke',),
'værmor': ('værmor',),
'værmora': ('værmor',),
'værmoren': ('værmor',),
'værmødre': ('værmor',),
'værmødrene': ('værmor',),
'værmødrer': ('værmor',),
'væromslag': ('væromslag',),
'væromslaga': ('væromslag',),
'væromslagene': ('væromslag',),
'væromslaget': ('væromslag',),
'værsatellitt': ('værsatellitt',),
'værsatellitten': ('værsatellitt',),
'værsatellittene': ('værsatellitt',),
'værsatellitter': ('værsatellitt',),
'værsituasjon': ('værsituasjon',),
'værsituasjonen': ('værsituasjon',),
'værsituasjonene': ('værsituasjon',),
'værsituasjoner': ('værsituasjon',),
'værskip': ('værskip',),
'værskipa': ('værskip',),
'værskipene': ('værskip',),
'værskipet': ('værskip',),
'værsønn': ('værsønn',),
'værsønnen': ('værsønn',),
'værsønnene': ('værsønn',),
'værsønner': ('værsønn',),
'værsøster': ('værsøster',),
'værsøstera': ('værsøster',),
'værsøsteren': ('værsøster',),
'værsøstre': ('værsøster',),
'værsøstrene': ('værsøster',),
'værsøstrer': ('værsøster',),
'værutsikt': ('værutsikt',),
'værutsikta': ('værutsikt',),
'værutsikten': ('værutsikt',),
'værutsiktene': ('værutsikt',),
'værutsikter': ('værutsikt',),
'værvarsel': ('værvarsel',),
'værvarselet': ('værvarsel',),
'værvarsla': ('værvarsel',),
'værvarslene': ('værvarsel',),
'værvarsler': ('værvarsel',),
'værvarslet': ('værvarsel',),
'værvarsling': ('værvarsling',),
'værvarslinga': ('værvarsling',),
'værvarslingen': ('værvarsling',),
'værvarslingene': ('værvarsling',),
'værvarslinger': ('værvarsling',),
'værvarslingstjeneste': ('værvarslingstjeneste',),
'værvarslingstjenesten': ('værvarslingstjeneste',),
'værvarslingstjenestene': ('værvarslingstjeneste',),
'værvarslingstjenester': ('værvarslingstjeneste',),
'væska': ('væske',),
'væske': ('væske',),
'væsken': ('væske',),
'væskene': ('væske',),
'væsker': ('væske',),
'væskeform': ('væskeform',),
'væskeforma': ('væskeform',),
'væskeformen': ('væskeform',),
'væskeformene': ('væskeform',),
'væskeformer': ('væskeform',),
'væskekjøling': ('væskekjøling',),
'væskekjølinga': ('væskekjøling',),
'væskekjølingen': ('væskekjøling',),
'væskekjølingene': ('væskekjøling',),
'væskekjølinger': ('væskekjøling',),
'væskesøyla': ('væskesøyle',),
'væskesøyle': ('væskesøyle',),
'væskesøylen': ('væskesøyle',),
'væskesøylene': ('væskesøyle',),
'væskesøyler': ('væskesøyle',),
'væsketap': ('væsketap',),
'væsketapa': ('væsketap',),
'væsketapene': ('væsketap',),
'væsketapet': ('væsketap',),
'væta': ('væte',),
'væte': ('væte',),
'væten': ('væte',),
'vætene': ('væte',),
'væter': ('væte',),
'væter': ('væter',),
'vætere': ('væter',),
'væteren': ('væter',),
'væterer': ('væter',),
'væterne': ('væter',),
'vøla': ('vøle',),
'vøle': ('vøle',),
'vølen': ('vøle',),
'vølene': ('vøle',),
'vøler': ('vøle',),
'vørdnad': ('vørdnad',),
'vørdnaden': ('vørdnad',),
'vørdnadene': ('vørdnad',),
'vørdnader': ('vørdnad',),
'vørdsamhet': ('vørdsamhet',),
'vørdsamheta': ('vørdsamhet',),
'vørdsamheten': ('vørdsamhet',),
'vørdsamhetene': ('vørdsamhet',),
'vørdsamheter': ('vørdsamhet',),
'vørdsløshet': ('vørdsløshet',),
'vørdsløsheta': ('vørdsløshet',),
'vørdsløsheten': ('vørdsløshet',),
'vørdsløshetene': ('vørdsløshet',),
'vørdsløsheter': ('vørdsløshet',),
'vørdsløysa': ('vørdsløyse',),
'vørdsløyse': ('vørdsløyse',),
'vørdsløysen': ('vørdsløyse',),
'vørdsløysene': ('vørdsløyse',),
'vørdsløyser': ('vørdsløyse',),
'vørnad': ('vørnad',),
'vørnaden': ('vørnad',),
'vørnadene': ('vørnad',),
'vørnader': ('vørnad',),
'vørsamhet': ('vørsamhet',),
'vørsamheta': ('vørsamhet',),
'vørsamheten': ('vørsamhet',),
'vørsamhetene': ('vørsamhet',),
'vørsamheter': ('vørsamhet',),
'vørsløshet': ('vørsløshet',),
'vørsløsheta': ('vørsløshet',),
'vørsløsheten': ('vørsløshet',),
'vørsløshetene': ('vørsløshet',),
'vørsløsheter': ('vørsløshet',),
'vørsløysa': ('vørsløyse',),
'vørsløyse': ('vørsløyse',),
'vørsløysen': ('vørsløyse',),
'vørsløysene': ('vørsløyse',),
'vørsløyser': ('vørsløyse',),
'vørter': ('vørter',),
'vørtera': ('vørter',),
'vørtere': ('vørter',),
'vørteren': ('vørter',),
'vørterene': ('vørter',),
'vørterer': ('vørter',),
'vørteret': ('vørter',),
'vørterne': ('vørter',),
'vørtra': ('vørter',),
'vørtre': ('vørter',),
'vørtrene': ('vørter',),
'vørtrer': ('vørter',),
'vørterbrød': ('vørterbrød',),
'vørterbrøda': ('vørterbrød',),
'vørterbrødene': ('vørterbrød',),
'vørterbrødet': ('vørterbrød',),
'vørterkaka': ('vørterkake',),
'vørterkake': ('vørterkake',),
'vørterkaken': ('vørterkake',),
'vørterkakene': ('vørterkake',),
'vørterkaker': ('vørterkake',),
'w': ('w',),
'w\'en': ('w',),
'w-en': ('w',),
'w-ene': ('w',),
'w-er': ('w',),
'wagnerianer': ('wagnerianer',),
'wagnerianere': ('wagnerianer',),
'wagnerianeren': ('wagnerianer',),
'wagnerianerer': ('wagnerianer',),
'wagnerianerne': ('wagnerianer',),
'wagnerianisme': ('wagnerianisme',),
'wagnerianismen': ('wagnerianisme',),
'wagnerianismene': ('wagnerianisme',),
'wagnerianismer': ('wagnerianisme',),
'wagneritt': ('wagneritt',),
'wagneritten': ('wagneritt',),
'wagnerittene': ('wagneritt',),
'wagneritter': ('wagneritt',),
'waldorfsalat': ('waldorfsalat',),
'waldorfsalaten': ('waldorfsalat',),
'waldorfsalatene': ('waldorfsalat',),
'waldorfsalater': ('waldorfsalat',),
'waleskringla': ('waleskringle',),
'waleskringle': ('waleskringle',),
'waleskringlen': ('waleskringle',),
'waleskringlene': ('waleskringle',),
'waleskringler': ('waleskringle',),
'waliser': ('waliser',),
'walisere': ('waliser',),
'waliseren': ('waliser',),
'waliserer': ('waliser',),
'waliserne': ('waliser',),
'walisisk': ('walisisk',),
'walisisken': ('walisisk',),
'walisiskene': ('walisisk',),
'walisisker': ('walisisk',),
'walkie-talkie': ('walkie-talkie',),
'walkie-talkien': ('walkie-talkie',),
'walkie-talkiene': ('walkie-talkie',),
'walkie-talkier': ('walkie-talkie',),
'walkover': ('walkover',),
'walkoveren': ('walkover',),
'walkoverene': ('walkover',),
'walkoverer': ('walkover',),
'wankelmotor': ('wankelmotor',),
'wankelmotoren': ('wankelmotor',),
'wankelmotorene': ('wankelmotor',),
'wankelmotorer': ('wankelmotor',),
'water': ('water',),
'watera': ('water',),
'watere': ('water',),
'wateret': ('water',),
'waterne': ('water',),
'waterproof': ('waterproof',),
'waterproofen': ('waterproof',),
'waterproofene': ('waterproof',),
'waterproofer': ('waterproof',),
'waterproofs': ('waterproof',),
'watt': ('watt',),
'watten': ('watt',),
'wattene': ('watt',),
'watt-time': ('watt-time',),
'watt-timen': ('watt-time',),
'watt-timene': ('watt-time',),
'watt-timer': ('watt-time',),
'wattime': ('wattime',),
'wattimen': ('wattime',),
'wattimene': ('wattime',),
'wattimer': ('wattime',),
'wattmeter': ('wattmeter',),
'wattmeteret': ('wattmeter',),
'wattmetra': ('wattmeter',),
'wattmetre': ('wattmeter',),
'wattmetrene': ('wattmeter',),
'wattmetret': ('wattmeter',),
'watutsi': ('watutsi',),
'watutsien': ('watutsi',),
'watutsiene': ('watutsi',),
'watutsier': ('watutsi',),
'wc': ('wc',),
'wca': ('wc',),
'wcene': ('wc',),
'wcer': ('wc',),
'wcet': ('wc',),
'weasel': ('weasel',),
'weaselen': ('weasel',),
'weaselene': ('weasel',),
'weaseler': ('weasel',),
'webbstoff': ('webbstoff',),
'webbstoffa': ('webbstoff',),
'webbstoffene': ('webbstoff',),
'webbstoffer': ('webbstoff',),
'webbstoffet': ('webbstoff',),
'webbutstyr': ('webbutstyr',),
'webbutstyra': ('webbutstyr',),
'webbutstyrene': ('webbutstyr',),
'webbutstyret': ('webbutstyr',),
'weber': ('weber',),
'weberen': ('weber',),
'weberene': ('weber',),
'weekend': ('weekend',),
'weekenden': ('weekend',),
'weekendene': ('weekend',),
'weekender': ('weekend',),
'welfer': ('welfer',),
'welfere': ('welfer',),
'welferen': ('welfer',),
'welferer': ('welfer',),
'welferne': ('welfer',),
'weltervekt': ('weltervekt',),
'weltervekta': ('weltervekt',),
'weltervekten': ('weltervekt',),
'weltervektene': ('weltervekt',),
'weltervekter': ('weltervekt',),
'weltervekter': ('weltervekter',),
'weltervektere': ('weltervekter',),
'weltervekteren': ('weltervekter',),
'weltervekterer': ('weltervekter',),
'weltervekterne': ('weltervekter',),
'weltervektklassa': ('weltervektklasse',),
'weltervektklasse': ('weltervektklasse',),
'weltervektklassen': ('weltervektklasse',),
'weltervektklassene': ('weltervektklasse',),
'weltervektklasser': ('weltervektklasse',),
'weltervektsklassa': ('weltervektsklasse',),
'weltervektsklasse': ('weltervektsklasse',),
'weltervektsklassen': ('weltervektsklasse',),
'weltervektsklassene': ('weltervektsklasse',),
'weltervektsklasser': ('weltervektsklasse',),
'weltschmerz': ('weltschmerz',),
'weltschmerzen': ('weltschmerz',),
'weltschmerzene': ('weltschmerz',),
'weltschmerzer': ('weltschmerz',),
'wesleyaner': ('wesleyaner',),
'wesleyanere': ('wesleyaner',),
'wesleyaneren': ('wesleyaner',),
'wesleyanerer': ('wesleyaner',),
'wesleyanerne': ('wesleyaner',),
'west-end': ('west-end',),
'western': ('western',),
'westernen': ('western',),
'westernene': ('western',),
'westerner': ('western',),
'westernfilm': ('westernfilm',),
'westernfilmen': ('westernfilm',),
'westernfilmene': ('westernfilm',),
'westernfilmer': ('westernfilm',),
'whig': ('whig',),
'whigen': ('whig',),
'whigene': ('whig',),
'whiger': ('whig',),
'whipcord': ('whipcord',),
'whipcorden': ('whipcord',),
'whipcordene': ('whipcord',),
'whipcorder': ('whipcord',),
'whippet': ('whippet',),
'whippeten': ('whippet',),
'whippetene': ('whippet',),
'whippeter': ('whippet',),
'whiskers': ('whiskers',),
'whiskersene': ('whiskers',),
'whisky': ('whisky',),
'whiskyen': ('whisky',),
'whiskyene': ('whisky',),
'whiskyer': ('whisky',),
'whist': ('whist',),
'whisten': ('whist',),
'whistene': ('whist',),
'whister': ('whist',),
'white-spirit': ('white-spirit',),
'white-spiriten': ('white-spirit',),
'white-spiritene': ('white-spirit',),
'white-spiriter': ('white-spirit',),
'whitecoat': ('whitecoat',),
'whitecoaten': ('whitecoat',),
'whitecoatene': ('whitecoat',),
'whitecoater': ('whitecoat',),
'widescreen': ('widescreen',),
'widescreenen': ('widescreen',),
'widescreenene': ('widescreen',),
'widescreener': ('widescreen',),
'wiener': ('wiener',),
'wienere': ('wiener',),
'wieneren': ('wiener',),
'wienerer': ('wiener',),
'wienerne': ('wiener',),
'wienerbakeri': ('wienerbakeri',),
'wienerbakeria': ('wienerbakeri',),
'wienerbakeriene': ('wienerbakeri',),
'wienerbakerier': ('wienerbakeri',),
'wienerbakeriet': ('wienerbakeri',),
'wienerbrød': ('wienerbrød',),
'wienerbrøda': ('wienerbrød',),
'wienerbrødene': ('wienerbrød',),
'wienerbrødet': ('wienerbrød',),
'wienerklassiker': ('wienerklassiker',),
'wienerklassikere': ('wienerklassiker',),
'wienerklassikeren': ('wienerklassiker',),
'wienerklassikerer': ('wienerklassiker',),
'wienerklassikerne': ('wienerklassiker',),
'wienerklassisisme': ('wienerklassisisme',),
'wienerklassisismen': ('wienerklassisisme',),
'wienerklassisismene': ('wienerklassisisme',),
'wienerklassisismer': ('wienerklassisisme',),
'wienerpølsa': ('wienerpølse',),
'wienerpølse': ('wienerpølse',),
'wienerpølsen': ('wienerpølse',),
'wienerpølsene': ('wienerpølse',),
'wienerpølser': ('wienerpølse',),
'wienerschnitzel': ('wienerschnitzel',),
'wienerschnitzelen': ('wienerschnitzel',),
'wienerschnitzlene': ('wienerschnitzel',),
'wienerschnitzler': ('wienerschnitzel',),
'wienersnitsel': ('wienersnitsel',),
'wienersnitselen': ('wienersnitsel',),
'wienersnitslene': ('wienersnitsel',),
'wienersnitsler': ('wienersnitsel',),
'wienerstang': ('wienerstang',),
'wienerstanga': ('wienerstang',),
'wienerstangen': ('wienerstang',),
'wienerstengene': ('wienerstang',),
'wienerstenger': ('wienerstang',),
'wienerstol': ('wienerstol',),
'wienerstolen': ('wienerstol',),
'wienerstolene': ('wienerstol',),
'wienerstoler': ('wienerstol',),
'wienervals': ('wienervals',),
'wienervalsen': ('wienervals',),
'wienervalsene': ('wienervals',),
'wienervalser': ('wienervals',),
'wienerwurst': ('wienerwurst',),
'wienerwursten': ('wienerwurst',),
'wienerwurstene': ('wienerwurst',),
'wienstol': ('wienstol',),
'wienstolen': ('wienstol',),
'wienstolene': ('wienstol',),
'wienstoler': ('wienstol',),
'wigwam': ('wigwam',),
'wigwamen': ('wigwam',),
'wigwamene': ('wigwam',),
'wigwamer': ('wigwam',),
'wild west': ('wild west',),
'wiltonteppa': ('wiltonteppe',),
'wiltonteppe': ('wiltonteppe',),
'wiltonteppene': ('wiltonteppe',),
'wiltontepper': ('wiltonteppe',),
'wiltonteppet': ('wiltonteppe',),
'windsurfer': ('windsurfer',),
'windsurfere': ('windsurfer',),
'windsurferen': ('windsurfer',),
'windsurferer': ('windsurfer',),
'windsurferne': ('windsurfer',),
'windsurfing': ('windsurfing',),
'windsurfinga': ('windsurfing',),
'windsurfingen': ('windsurfing',),
'windsurfingene': ('windsurfing',),
'windsurfinger': ('windsurfing',),
'wire': ('wire',),
'wiren': ('wire',),
'wirene': ('wire',),
'wirer': ('wire',),
'wolfram': ('wolfram',),
'wolframa': ('wolfram',),
'wolframene': ('wolfram',),
'wolframet': ('wolfram',),
'worcestersaus': ('worcestersaus',),
'worcestersausen': ('worcestersaus',),
'worcestersausene': ('worcestersaus',),
'worcestersauser': ('worcestersaus',),
'world cup': ('world cup',),
'world cupen': ('world cup',),
'world cupene': ('world cup',),
'world cuper': ('world cup',),
'world cup-renn': ('world cup-renn',),
'world cup-renna': ('world cup-renn',),
'world cup-rennene': ('world cup-renn',),
'world cup-rennet': ('world cup-renn',),
'x': ('x',),
'x\'en': ('x',),
'x-en': ('x',),
'x-ene': ('x',),
'x-er': ('x',),
'x-akse': ('x-akse',),
'x-aksen': ('x-akse',),
'x-aksene': ('x-akse',),
'x-akser': ('x-akse',),
'x-krok': ('x-krok',),
'x-kroken': ('x-krok',),
'x-krokene': ('x-krok',),
'x-kroker': ('x-krok',),
'x-kromosom': ('x-kromosom',),
'x-kromosoma': ('x-kromosom',),
'x-kromosomene': ('x-kromosom',),
'x-kromosomer': ('x-kromosom',),
'x-kromosomet': ('x-kromosom',),
'xantippa': ('xantippe',),
'xantippe': ('xantippe',),
'xantippen': ('xantippe',),
'xantippene': ('xantippe',),
'xantipper': ('xantippe',),
'xantofyll': ('xantofyll',),
'xantofylla': ('xantofyll',),
'xantofyllene': ('xantofyll',),
'xantofyllet': ('xantofyll',),
'xantogenat': ('xantogenat',),
'xantogenata': ('xantogenat',),
'xantogenatene': ('xantogenat',),
'xantogenater': ('xantogenat',),
'xantogenatet': ('xantogenat',),
'xantogensyra': ('xantogensyre',),
'xantogensyre': ('xantogensyre',),
'xantogensyren': ('xantogensyre',),
'xantogensyrene': ('xantogensyre',),
'xantogensyrer': ('xantogensyre',),
'xantokromi': ('xantokromi',),
'xantokromien': ('xantokromi',),
'xantokromiene': ('xantokromi',),
'xantokromier': ('xantokromi',),
'xantom': ('xantom',),
'xantoma': ('xantom',),
'xantomene': ('xantom',),
'xantomer': ('xantom',),
'xantomet': ('xantom',),
'xenie': ('xenie',),
'xenien': ('xenie',),
'xeniene': ('xenie',),
'xenier': ('xenie',),
'xenofili': ('xenofili',),
'xenofilien': ('xenofili',),
'xenofiliene': ('xenofili',),
'xenofilier': ('xenofili',),
'xenofobi': ('xenofobi',),
'xenofobien': ('xenofobi',),
'xenofobiene': ('xenofobi',),
'xenofobier': ('xenofobi',),
'xenogami': ('xenogami',),
'xenogamien': ('xenogami',),
'xenogamiene': ('xenogami',),
'xenogamier': ('xenogami',),
'xenon': ('xenon',),
'xenona': ('xenon',),
'xenonene': ('xenon',),
'xenonet': ('xenon',),
'xeroform': ('xeroform',),
'xeroformen': ('xeroform',),
'xeroformene': ('xeroform',),
'xeroformer': ('xeroform',),
'xerofytt': ('xerofytt',),
'xerofytten': ('xerofytt',),
'xerofyttene': ('xerofytt',),
'xerofytter': ('xerofytt',),
'xerografi': ('xerografi',),
'xerografien': ('xerografi',),
'xerografiene': ('xerografi',),
'xerografier': ('xerografi',),
'xylofon': ('xylofon',),
'xylofonen': ('xylofon',),
'xylofonene': ('xylofon',),
'xylofoner': ('xylofon',),
'xylofonist': ('xylofonist',),
'xylofonisten': ('xylofonist',),
'xylofonistene': ('xylofonist',),
'xylofonister': ('xylofonist',),
'xylograf': ('xylograf',),
'xylografen': ('xylograf',),
'xylografene': ('xylograf',),
'xylografer': ('xylograf',),
'xylografi': ('xylografi',),
'xylografien': ('xylografi',),
'xylografiene': ('xylografi',),
'xylografier': ('xylografi',),
'xylografi': ('xylografi',),
'xylografia': ('xylografi',),
'xylografiene': ('xylografi',),
'xylografier': ('xylografi',),
'xylografiet': ('xylografi',),
'y': ('y',),
'y\'en': ('y',),
'y-en': ('y',),
'y-ene': ('y',),
'y-er': ('y',),
'yüan': ('yüan',),
'yüanen': ('yüan',),
'yüanene': ('yüan',),
'y-akse': ('y-akse',),
'y-aksen': ('y-akse',),
'y-aksene': ('y-akse',),
'y-akser': ('y-akse',),
'y-kromosom': ('y-kromosom',),
'y-kromosoma': ('y-kromosom',),
'y-kromosomene': ('y-kromosom',),
'y-kromosomer': ('y-kromosom',),
'y-kromosomet': ('y-kromosom',),
'yacht': ('yacht',),
'yachten': ('yacht',),
'yachtene': ('yacht',),
'yachter': ('yacht',),
'yalelås': ('yalelås',),
'yalelåsa': ('yalelås',),
'yalelåsen': ('yalelås',),
'yalelåsene': ('yalelås',),
'yalelåser': ('yalelås',),
'yalelåset': ('yalelås',),
'yams': ('yams',),
'yamsen': ('yams',),
'yamsene': ('yams',),
'yamser': ('yams',),
'yankee': ('yankee',),
'yankeen': ('yankee',),
'yankeene': ('yankee',),
'yankeer': ('yankee',),
'yard': ('yard',),
'yarden': ('yard',),
'yardene': ('yard',),
'yatzy': ('yatzy',),
'yatzyen': ('yatzy',),
'yatzyene': ('yatzy',),
'yatzyer': ('yatzy',),
'yawl': ('yawl',),
'yawlen': ('yawl',),
'yawlene': ('yawl',),
'yawler': ('yawl',),
'ydmykelse': ('ydmykelse',),
'ydmykelsen': ('ydmykelse',),
'ydmykelsene': ('ydmykelse',),
'ydmykelser': ('ydmykelse',),
'ydmykhet': ('ydmykhet',),
'ydmykheta': ('ydmykhet',),
'ydmykheten': ('ydmykhet',),
'ydmykhetene': ('ydmykhet',),
'ydmykheter': ('ydmykhet',),
'yemenitt': ('yemenitt',),
'yemenitten': ('yemenitt',),
'yemenittene': ('yemenitt',),
'yemenitter': ('yemenitt',),
'yemenitt': ('yemenitt',),
'yemenitten': ('yemenitt',),
'yemenittene': ('yemenitt',),
'yemenitter': ('yemenitt',),
'yen': ('yen',),
'yenen': ('yen',),
'yenene': ('yen',),
'yeti': ('yeti',),
'yetien': ('yeti',),
'yetiene': ('yeti',),
'yetier': ('yeti',),
'yl': ('yl',),
'yla': ('yl',),
'ylene': ('yl',),
'ylet': ('yl',),
'ymt': ('ymt',),
'ymta': ('ymt',),
'ymten': ('ymt',),
'ymtene': ('ymt',),
'ymtet': ('ymt',),
'ynde': ('ynde',),
'ynden': ('ynde',),
'yndene': ('ynde',),
'ynder': ('ynde',),
'ynder': ('ynder',),
'yndere': ('ynder',),
'ynderen': ('ynder',),
'ynderer': ('ynder',),
'ynderne': ('ynder',),
'yndest': ('yndest',),
'yndesten': ('yndest',),
'yndestene': ('yndest',),
'yndester': ('yndest',),
'yndighet': ('yndighet',),
'yndigheta': ('yndighet',),
'yndigheten': ('yndighet',),
'yndighetene': ('yndighet',),
'yndigheter': ('yndighet',),
'yndling': ('yndling',),
'yndlingen': ('yndling',),
'yndlingene': ('yndling',),
'yndlinger': ('yndling',),
'yndlingsbeskjeftigelse': ('yndlingsbeskjeftigelse',),
'yndlingsbeskjeftigelsen': ('yndlingsbeskjeftigelse',),
'yndlingsbeskjeftigelsene': ('yndlingsbeskjeftigelse',),
'yndlingsbeskjeftigelser': ('yndlingsbeskjeftigelse',),
'yndlingsforfatter': ('yndlingsforfatter',),
'yndlingsforfattere': ('yndlingsforfatter',),
'yndlingsforfatteren': ('yndlingsforfatter',),
'yndlingsforfatterer': ('yndlingsforfatter',),
'yndlingsforfatterne': ('yndlingsforfatter',),
'yndlingsrett': ('yndlingsrett',),
'yndlingsretten': ('yndlingsrett',),
'yndlingsrettene': ('yndlingsrett',),
'yndlingsretter': ('yndlingsrett',),
'yngel': ('yngel',),
'yngelen': ('yngel',),
'ynglene': ('yngel',),
'yngeloppdrett': ('yngeloppdrett',),
'yngeloppdretta': ('yngeloppdrett',),
'yngeloppdrettene': ('yngeloppdrett',),
'yngeloppdrettet': ('yngeloppdrett',),
'yngelpleia': ('yngelpleie',),
'yngelpleie': ('yngelpleie',),
'yngelpleien': ('yngelpleie',),
'yngelpleiene': ('yngelpleie',),
'yngelpleier': ('yngelpleie',),
'yngledam': ('yngledam',),
'yngledammen': ('yngledam',),
'yngledammene': ('yngledam',),
'yngledammer': ('yngledam',),
'yngleknopp': ('yngleknopp',),
'yngleknoppen': ('yngleknopp',),
'yngleknoppene': ('yngleknopp',),
'yngleknopper': ('yngleknopp',),
'yngleplass': ('yngleplass',),
'yngleplassen': ('yngleplass',),
'yngleplassene': ('yngleplass',),
'yngleplasser': ('yngleplass',),
'yngletid': ('yngletid',),
'yngletida': ('yngletid',),
'yngletiden': ('yngletid',),
'yngletidene': ('yngletid',),
'yngletider': ('yngletid',),
'yngling': ('yngling',),
'ynglingen': ('yngling',),
'ynglingene': ('yngling',),
'ynglinger': ('yngling',),
'ynglingalder': ('ynglingalder',),
'ynglingaldere': ('ynglingalder',),
'ynglingalderen': ('ynglingalder',),
'ynglingalderer': ('ynglingalder',),
'ynglingalderne': ('ynglingalder',),
'ynglingaldre': ('ynglingalder',),
'ynglingaldrene': ('ynglingalder',),
'ynglingaldrer': ('ynglingalder',),
'yngstedama': ('yngstedame',),
'yngstedame': ('yngstedame',),
'yngstedamen': ('yngstedame',),
'yngstedamene': ('yngstedame',),
'yngstedamer': ('yngstedame',),
'yngstemann': ('yngstemann',),
'yngstemannen': ('yngstemann',),
'yngstemannene': ('yngstemann',),
'yngstemanner': ('yngstemann',),
'ynk': ('ynk',),
'ynken': ('ynk',),
'ynkene': ('ynk',),
'ynker': ('ynk',),
'ynkelighet': ('ynkelighet',),
'ynkeligheta': ('ynkelighet',),
'ynkeligheten': ('ynkelighet',),
'ynkelighetene': ('ynkelighet',),
'ynkeligheter': ('ynkelighet',),
'yoga': ('yoga',),
'yogaen': ('yoga',),
'yogaene': ('yoga',),
'yogaer': ('yoga',),
'yoghurt': ('yoghurt',),
'yoghurten': ('yoghurt',),
'yoghurtene': ('yoghurt',),
'yoghurter': ('yoghurt',),
'yoghurt': ('yoghurt',),
'yoghurten': ('yoghurt',),
'yoghurtene': ('yoghurt',),
'yoghurter': ('yoghurt',),
'yogi': ('yogi',),
'yogien': ('yogi',),
'yogiene': ('yogi',),
'yogier': ('yogi',),
'yoruba': ('yoruba',),
'yorubaen': ('yoruba',),
'yorubaene': ('yoruba',),
'yorubaer': ('yoruba',),
'yoruba': ('yoruba',),
'yorubaen': ('yoruba',),
'yorubaene': ('yoruba',),
'yorubaer': ('yoruba',),
'yppersteprest': ('yppersteprest',),
'ypperstepresten': ('yppersteprest',),
'yppersteprestene': ('yppersteprest',),
'yppersteprester': ('yppersteprest',),
'ypsilon': ('ypsilon',),
'ypsilonen': ('ypsilon',),
'ypsilonene': ('ypsilon',),
'ypsiloner': ('ypsilon',),
'yr': ('yr',),
'yra': ('yr',),
'yrene': ('yr',),
'yret': ('yr',),
'yr': ('yr',),
'yra': ('yr',),
'yrene': ('yr',),
'yret': ('yr',),
'yrhet': ('yrhet',),
'yrheta': ('yrhet',),
'yrheten': ('yrhet',),
'yrhetene': ('yrhet',),
'yrheter': ('yrhet',),
'yrka': ('yrke',),
'yrke': ('yrke',),
'yrkene': ('yrke',),
'yrker': ('yrke',),
'yrket': ('yrke',),
'yrka': ('yrke',),
'yrke': ('yrke',),
'yrken': ('yrke',),
'yrkene': ('yrke',),
'yrker': ('yrke',),
'yrkesbefal': ('yrkesbefal',),
'yrkesbefala': ('yrkesbefal',),
'yrkesbefalene': ('yrkesbefal',),
'yrkesbefalet': ('yrkesbefal',),
'yrkesbefolkning': ('yrkesbefolkning',),
'yrkesbefolkninga': ('yrkesbefolkning',),
'yrkesbefolkningen': ('yrkesbefolkning',),
'yrkesbefolkningene': ('yrkesbefolkning',),
'yrkesbefolkninger': ('yrkesbefolkning',),
'yrkesdemonstrant': ('yrkesdemonstrant',),
'yrkesdemonstranten': ('yrkesdemonstrant',),
'yrkesdemonstrantene': ('yrkesdemonstrant',),
'yrkesdemonstranter': ('yrkesdemonstrant',),
'yrkesdiplomat': ('yrkesdiplomat',),
'yrkesdiplomaten': ('yrkesdiplomat',),
'yrkesdiplomatene': ('yrkesdiplomat',),
'yrkesdiplomater': ('yrkesdiplomat',),
'yrkesetikk': ('yrkesetikk',),
'yrkesetikken': ('yrkesetikk',),
'yrkesetikkene': ('yrkesetikk',),
'yrkesetikker': ('yrkesetikk',),
'yrkeshygiene': ('yrkeshygiene',),
'yrkeshygienen': ('yrkeshygiene',),
'yrkeshygienene': ('yrkeshygiene',),
'yrkeshygiener': ('yrkeshygiene',),
'yrkeshygieniker': ('yrkeshygieniker',),
'yrkeshygienikere': ('yrkeshygieniker',),
'yrkeshygienikeren': ('yrkeshygieniker',),
'yrkeshygienikerer': ('yrkeshygieniker',),
'yrkeshygienikerne': ('yrkeshygieniker',),
'yrkeskarriera': ('yrkeskarriere',),
'yrkeskarriere': ('yrkeskarriere',),
'yrkeskarrieren': ('yrkeskarriere',),
'yrkeskarrierene': ('yrkeskarriere',),
'yrkeskarrierer': ('yrkeskarriere',),
'yrkeskvinna': ('yrkeskvinne',),
'yrkeskvinne': ('yrkeskvinne',),
'yrkeskvinnen': ('yrkeskvinne',),
'yrkeskvinnene': ('yrkeskvinne',),
'yrkeskvinner': ('yrkeskvinne',),
'yrkesliv': ('yrkesliv',),
'yrkesliva': ('yrkesliv',),
'yrkeslivene': ('yrkesliv',),
'yrkeslivet': ('yrkesliv',),
'yrkesmann': ('yrkesmann',),
'yrkesmannen': ('yrkesmann',),
'yrkesmenn': ('yrkesmann',),
'yrkesmennene': ('yrkesmann',),
'yrkesmyalgi': ('yrkesmyalgi',),
'yrkesmyalgien': ('yrkesmyalgi',),
'yrkesmyalgiene': ('yrkesmyalgi',),
'yrkesmyalgier': ('yrkesmyalgi',),
'yrkesneurose': ('yrkesneurose',),
'yrkesneurosen': ('yrkesneurose',),
'yrkesneurosene': ('yrkesneurose',),
'yrkesneuroser': ('yrkesneurose',),
'yrkesnevrose': ('yrkesnevrose',),
'yrkesnevrosen': ('yrkesnevrose',),
'yrkesnevrosene': ('yrkesnevrose',),
'yrkesnevroser': ('yrkesnevrose',),
'yrkesorientering': ('yrkesorientering',),
'yrkesorienteringa': ('yrkesorientering',),
'yrkesorienteringen': ('yrkesorientering',),
'yrkesorienteringene': ('yrkesorientering',),
'yrkesorienteringer': ('yrkesorientering',),
'yrkesrettleder': ('yrkesrettleder',),
'yrkesrettledere': ('yrkesrettleder',),
'yrkesrettlederen': ('yrkesrettleder',),
'yrkesrettlederer': ('yrkesrettleder',),
'yrkesrettlederne': ('yrkesrettleder',),
'yrkesrettleiing': ('yrkesrettleiing',),
'yrkesrettleiinga': ('yrkesrettleiing',),
'yrkesrettleiingen': ('yrkesrettleiing',),
'yrkesrettleiingene': ('yrkesrettleiing',),
'yrkesrettleiinger': ('yrkesrettleiing',),
'yrkesrolla': ('yrkesrolle',),
'yrkesrolle': ('yrkesrolle',),
'yrkesrollen': ('yrkesrolle',),
'yrkesrollene': ('yrkesrolle',),
'yrkesroller': ('yrkesrolle',),
'yrkesskade': ('yrkesskade',),
'yrkesskaden': ('yrkesskade',),
'yrkesskadene': ('yrkesskade',),
'yrkesskader': ('yrkesskade',),
'yrkesskadetrygd': ('yrkesskadetrygd',),
'yrkesskadetrygda': ('yrkesskadetrygd',),
'yrkesskadetrygden': ('yrkesskadetrygd',),
'yrkesskadetrygdene': ('yrkesskadetrygd',),
'yrkesskadetrygder': ('yrkesskadetrygd',),
'yrkesskole': ('yrkesskole',),
'yrkesskolen': ('yrkesskole',),
'yrkesskolene': ('yrkesskole',),
'yrkesskoler': ('yrkesskole',),
'yrkesuka': ('yrkesuke',),
'yrkesuke': ('yrkesuke',),
'yrkesuken': ('yrkesuke',),
'yrkesukene': ('yrkesuke',),
'yrkesuker': ('yrkesuke',),
'yrkesuka': ('yrkesuke',),
'yrkesuke': ('yrkesuke',),
'yrkesuken': ('yrkesuke',),
'yrkesukene': ('yrkesuke',),
'yrkesuker': ('yrkesuke',),
'yrkesutdannelse': ('yrkesutdannelse',),
'yrkesutdannelsen': ('yrkesutdannelse',),
'yrkesutdannelsene': ('yrkesutdannelse',),
'yrkesutdannelser': ('yrkesutdannelse',),
'yrkesutdanning': ('yrkesutdanning',),
'yrkesutdanninga': ('yrkesutdanning',),
'yrkesutdanningen': ('yrkesutdanning',),
'yrkesutdanningene': ('yrkesutdanning',),
'yrkesutdanninger': ('yrkesutdanning',),
'yrkesvalg': ('yrkesvalg',),
'yrkesvalga': ('yrkesvalg',),
'yrkesvalgene': ('yrkesvalg',),
'yrkesvalget': ('yrkesvalg',),
'yrkesveileder': ('yrkesveileder',),
'yrkesveiledere': ('yrkesveileder',),
'yrkesveilederen': ('yrkesveileder',),
'yrkesveilederer': ('yrkesveileder',),
'yrkesveilederne': ('yrkesveileder',),
'yrkesveiledning': ('yrkesveiledning',),
'yrkesveiledninga': ('yrkesveiledning',),
'yrkesveiledningen': ('yrkesveiledning',),
'yrkesveiledningene': ('yrkesveiledning',),
'yrkesveiledninger': ('yrkesveiledning',),
'yrkesveka': ('yrkesveke',),
'yrkesveke': ('yrkesveke',),
'yrkesveken': ('yrkesveke',),
'yrkesvekene': ('yrkesveke',),
'yrkesveker': ('yrkesveke',),
'yrkesveka': ('yrkesveke',),
'yrkesveke': ('yrkesveke',),
'yrkesveken': ('yrkesveke',),
'yrkesvekene': ('yrkesveke',),
'yrkesveker': ('yrkesveke',),
'ystekjel': ('ystekjel',),
'ystekjelen': ('ystekjel',),
'ystekjelene': ('ystekjel',),
'ystekjeler': ('ystekjel',),
'ystekjele': ('ystekjele',),
'ystekjelen': ('ystekjele',),
'ystekjelene': ('ystekjele',),
'ystekjeler': ('ystekjele',),
'ystel': ('ystel',),
'ystelen': ('ystel',),
'ystlene': ('ystel',),
'ystler': ('ystel',),
'yster': ('yster',),
'ystere': ('yster',),
'ysteren': ('yster',),
'ysterer': ('yster',),
'ysterne': ('yster',),
'ysteri': ('ysteri',),
'ysteria': ('ysteri',),
'ysteriene': ('ysteri',),
'ysterier': ('ysteri',),
'ysteriet': ('ysteri',),
'yta': ('yte',),
'yte': ('yte',),
'yten': ('yte',),
'ytene': ('yte',),
'yter': ('yte',),
'yteevna': ('yteevne',),
'yteevne': ('yteevne',),
'yteevnen': ('yteevne',),
'yteevnene': ('yteevne',),
'yteevner': ('yteevne',),
'ytelse': ('ytelse',),
'ytelsen': ('ytelse',),
'ytelsene': ('ytelse',),
'ytelser': ('ytelse',),
'yter': ('yter',),
'ytere': ('yter',),
'yteren': ('yter',),
'yterer': ('yter',),
'yterne': ('yter',),
'ytra': ('ytre',),
'ytre': ('ytre',),
'ytrene': ('ytre',),
'ytrer': ('ytre',),
'ytret': ('ytre',),
'ytrefilet': ('ytrefilet',),
'ytrefileten': ('ytrefilet',),
'ytrefiletene': ('ytrefilet',),
'ytrefileter': ('ytrefilet',),
'ytreløper': ('ytreløper',),
'ytreløpere': ('ytreløper',),
'ytreløperen': ('ytreløper',),
'ytreløperer': ('ytreløper',),
'ytreløperne': ('ytreløper',),
'ytremisjon': ('ytremisjon',),
'ytremisjonen': ('ytremisjon',),
'ytremisjonene': ('ytremisjon',),
'ytremisjoner': ('ytremisjon',),
'ytring': ('ytring',),
'ytringa': ('ytring',),
'ytringen': ('ytring',),
'ytringene': ('ytring',),
'ytringer': ('ytring',),
'ytringsfrihet': ('ytringsfrihet',),
'ytringsfriheta': ('ytringsfrihet',),
'ytringsfriheten': ('ytringsfrihet',),
'ytringsfrihetene': ('ytringsfrihet',),
'ytringsfriheter': ('ytringsfrihet',),
'ytterbeger': ('ytterbeger',),
'ytterbegeret': ('ytterbeger',),
'ytterbegra': ('ytterbeger',),
'ytterbegre': ('ytterbeger',),
'ytterbegrene': ('ytterbeger',),
'ytterbium': ('ytterbium',),
'ytterbiuma': ('ytterbium',),
'ytterbiumene': ('ytterbium',),
'ytterbiumet': ('ytterbium',),
'ytterdel': ('ytterdel',),
'ytterdelen': ('ytterdel',),
'ytterdelene': ('ytterdel',),
'ytterdeler': ('ytterdel',),
'ytterdør': ('ytterdør',),
'ytterdøra': ('ytterdør',),
'ytterdøren': ('ytterdør',),
'ytterdørene': ('ytterdør',),
'ytterdører': ('ytterdør',),
'ytterfrakk': ('ytterfrakk',),
'ytterfrakken': ('ytterfrakk',),
'ytterfrakkene': ('ytterfrakk',),
'ytterfrakker': ('ytterfrakk',),
'ytterkant': ('ytterkant',),
'ytterkanten': ('ytterkant',),
'ytterkantene': ('ytterkant',),
'ytterkanter': ('ytterkant',),
'ytterklær': ('ytterklær',),
'ytterklærne': ('ytterklær',),
'ytterlighet': ('ytterlighet',),
'ytterligheta': ('ytterlighet',),
'ytterligheten': ('ytterlighet',),
'ytterlighetene': ('ytterlighet',),
'ytterligheter': ('ytterlighet',),
'ytterlomma': ('ytterlomme',),
'ytterlomme': ('ytterlomme',),
'ytterlommen': ('ytterlomme',),
'ytterlommene': ('ytterlomme',),
'ytterlommer': ('ytterlomme',),
'ytterplagg': ('ytterplagg',),
'ytterplagga': ('ytterplagg',),
'ytterplaggene': ('ytterplagg',),
'ytterplagget': ('ytterplagg',),
'ytterpunkt': ('ytterpunkt',),
'ytterpunkta': ('ytterpunkt',),
'ytterpunktene': ('ytterpunkt',),
'ytterpunkter': ('ytterpunkt',),
'ytterpunktet': ('ytterpunkt',),
'yttersida': ('ytterside',),
'ytterside': ('ytterside',),
'yttersiden': ('ytterside',),
'yttersidene': ('ytterside',),
'yttersider': ('ytterside',),
'yttersving': ('yttersving',),
'yttersvingen': ('yttersving',),
'yttersvingene': ('yttersving',),
'yttersvinger': ('yttersving',),
'yttrium': ('yttrium',),
'yttriuma': ('yttrium',),
'yttriumene': ('yttrium',),
'yttriumet': ('yttrium',),
'z': ('z',),
'z\'en': ('z',),
'z-en': ('z',),
'z-ene': ('z',),
'z-er': ('z',),
'z-sno': ('z-sno',),
'z-snoen': ('z-sno',),
'z-snoene': ('z-sno',),
'z-snoer': ('z-sno',),
'z-tvinn': ('z-tvinn',),
'z-tvinna': ('z-tvinn',),
'z-tvinnene': ('z-tvinn',),
'z-tvinnet': ('z-tvinn',),
'zairer': ('zairer',),
'zairere': ('zairer',),
'zaireren': ('zairer',),
'zairerer': ('zairer',),
'zairerne': ('zairer',),
'zambier': ('zambier',),
'zambiere': ('zambier',),
'zambieren': ('zambier',),
'zambierer': ('zambier',),
'zambierne': ('zambier',),
'zebu': ('zebu',),
'zebuen': ('zebu',),
'zebuene': ('zebu',),
'zebuer': ('zebu',),
'zebu': ('zebu',),
'zebuen': ('zebu',),
'zebuene': ('zebu',),
'zebuer': ('zebu',),
'zen': ('zen',),
'zenbuddhisme': ('zenbuddhisme',),
'zenbuddhismen': ('zenbuddhisme',),
'zenbuddhismene': ('zenbuddhisme',),
'zenbuddhismer': ('zenbuddhisme',),
'zeolitt': ('zeolitt',),
'zeolitten': ('zeolitt',),
'zeolittene': ('zeolitt',),
'zeolitter': ('zeolitt',),
'zeppeliner': ('zeppeliner',),
'zeppelinere': ('zeppeliner',),
'zeppelineren': ('zeppeliner',),
'zeppelinerer': ('zeppeliner',),
'zeppelinerne': ('zeppeliner',),
'zeugma': ('zeugma',),
'zeugmaene': ('zeugma',),
'zeugmaer': ('zeugma',),
'zeugmaet': ('zeugma',),
'ziggurat': ('ziggurat',),
'zigguraten': ('ziggurat',),
'zigguratene': ('ziggurat',),
'ziggurater': ('ziggurat',),
'zimbabwer': ('zimbabwer',),
'zimbabwere': ('zimbabwer',),
'zimbabweren': ('zimbabwer',),
'zimbabwerer': ('zimbabwer',),
'zimbabwerne': ('zimbabwer',),
'zinnia': ('zinnia',),
'zinniaen': ('zinnia',),
'zinniaene': ('zinnia',),
'zinniaer': ('zinnia',),
'zirkon': ('zirkon',),
'zirkona': ('zirkon',),
'zirkonene': ('zirkon',),
'zirkonet': ('zirkon',),
'zirkonium': ('zirkonium',),
'zirkoniuma': ('zirkonium',),
'zirkoniumene': ('zirkonium',),
'zirkoniumet': ('zirkonium',),
'zloty': ('zloty',),
'zlotyen': ('zloty',),
'zlotyene': ('zloty',),
'zodiakallys': ('zodiakallys',),
'zodiakallysa': ('zodiakallys',),
'zodiakallysene': ('zodiakallys',),
'zodiakallyset': ('zodiakallys',),
'zoisitt': ('zoisitt',),
'zoisitten': ('zoisitt',),
'zoisittene': ('zoisitt',),
'zoisitter': ('zoisitt',),
'zoo': ('zoo',),
'zooen': ('zoo',),
'zooene': ('zoo',),
'zooer': ('zoo',),
'zoofag': ('zoofag',),
'zoofagen': ('zoofag',),
'zoofagene': ('zoofag',),
'zoofager': ('zoofag',),
'zoofobi': ('zoofobi',),
'zoofobien': ('zoofobi',),
'zoofobiene': ('zoofobi',),
'zoofobier': ('zoofobi',),
'zoofysikk': ('zoofysikk',),
'zoofysikken': ('zoofysikk',),
'zoofysikkene': ('zoofysikk',),
'zoofysikker': ('zoofysikk',),
'zoofysiologi': ('zoofysiologi',),
'zoofysiologien': ('zoofysiologi',),
'zoofysiologiene': ('zoofysiologi',),
'zoofysiologier': ('zoofysiologi',),
'zoofytt': ('zoofytt',),
'zoofytten': ('zoofytt',),
'zoofyttene': ('zoofytt',),
'zoofytter': ('zoofytt',),
'zoogeografi': ('zoogeografi',),
'zoogeografien': ('zoogeografi',),
'zoogeografiene': ('zoogeografi',),
'zoogeografier': ('zoogeografi',),
'zoograf': ('zoograf',),
'zoografen': ('zoograf',),
'zoografene': ('zoograf',),
'zoografer': ('zoograf',),
'zoografi': ('zoografi',),
'zoografien': ('zoografi',),
'zoografiene': ('zoografi',),
'zoografier': ('zoografi',),
'zookjemi': ('zookjemi',),
'zookjemien': ('zookjemi',),
'zookjemiene': ('zookjemi',),
'zookjemier': ('zookjemi',),
'zoolitt': ('zoolitt',),
'zoolitten': ('zoolitt',),
'zoolittene': ('zoolitt',),
'zoolitter': ('zoolitt',),
'zoolog': ('zoolog',),
'zoologen': ('zoolog',),
'zoologene': ('zoolog',),
'zoologer': ('zoolog',),
'zoologi': ('zoologi',),
'zoologien': ('zoologi',),
'zoologiene': ('zoologi',),
'zoologier': ('zoologi',),
'zoomlinsa': ('zoomlinse',),
'zoomlinse': ('zoomlinse',),
'zoomlinsen': ('zoomlinse',),
'zoomlinsene': ('zoomlinse',),
'zoomlinser': ('zoomlinse',),
'zoomobjektiv': ('zoomobjektiv',),
'zoomobjektiva': ('zoomobjektiv',),
'zoomobjektivene': ('zoomobjektiv',),
'zoomobjektiver': ('zoomobjektiv',),
'zoomobjektivet': ('zoomobjektiv',),
'zoonose': ('zoonose',),
'zoonosen': ('zoonose',),
'zoonosene': ('zoonose',),
'zoonoser': ('zoonose',),
'zorilla': ('zorilla',),
'zorillaen': ('zorilla',),
'zorillaene': ('zorilla',),
'zorillaer': ('zorilla',),
'zulu': ('zulu',),
'zuluen': ('zulu',),
'zuluene': ('zulu',),
'zuluer': ('zulu',),
'zulukaffer': ('zulukaffer',),
'zulukaffere': ('zulukaffer',),
'zulukafferen': ('zulukaffer',),
'zulukafferer': ('zulukaffer',),
'zulukafferne': ('zulukaffer',),
'zulumisjon': ('zulumisjon',),
'zulumisjonen': ('zulumisjon',),
'zulumisjonene': ('zulumisjon',),
'zulumisjoner': ('zulumisjon',),
'zwinglianer': ('zwinglianer',),
'zwinglianere': ('zwinglianer',),
'zwinglianeren': ('zwinglianer',),
'zwinglianerer': ('zwinglianer',),
'zwinglianerne': ('zwinglianer',),
'zygote': ('zygote',),
'zygoten': ('zygote',),
'zygotene': ('zygote',),
'zygoter': ('zygote',),
'Å': ('Å',),
'Å\'en': ('Å',),
'Å-en': ('Å',),
'Å-ene': ('Å',),
'Å-er': ('Å',),
'å': ('å',),
'å\'en': ('å',),
'å-en': ('å',),
'å-ene': ('å',),
'å-er': ('å',),
'å': ('å',),
'åa': ('å',),
'åen': ('å',),
'åene': ('å',),
'åer': ('å',),
'åbit': ('åbit',),
'åbiten': ('åbit',),
'åbitene': ('åbit',),
'åbiter': ('åbit',),
'åbor': ('åbor',),
'åboren': ('åbor',),
'åborene': ('åbor',),
'åborer': ('åbor',),
'åbor': ('åbor',),
'åboren': ('åbor',),
'åborene': ('åbor',),
'åborer': ('åbor',),
'åger': ('åger',),
'ågera': ('åger',),
'ågeren': ('åger',),
'ågerene': ('åger',),
'ågerer': ('åger',),
'ågeret': ('åger',),
'ågra': ('åger',),
'ågre': ('åger',),
'ågrene': ('åger',),
'ågerkar': ('ågerkar',),
'ågerkaren': ('ågerkar',),
'ågerkarene': ('ågerkar',),
'ågerkarer': ('ågerkar',),
'ågerpris': ('ågerpris',),
'ågerprisen': ('ågerpris',),
'ågerprisene': ('ågerpris',),
'ågerpriser': ('ågerpris',),
'ågrer': ('ågrer',),
'ågrere': ('ågrer',),
'ågreren': ('ågrer',),
'ågrerer': ('ågrer',),
'ågrerne': ('ågrer',),
'åk': ('åk',),
'åka': ('åk',),
'åkene': ('åk',),
'åket': ('åk',),
'åker': ('åker',),
'åkere': ('åker',),
'åkeren': ('åker',),
'åkerne': ('åker',),
'åkre': ('åker',),
'åkrene': ('åker',),
'åkrer': ('åker',),
'åkerbruk': ('åkerbruk',),
'åkerbruka': ('åkerbruk',),
'åkerbrukene': ('åkerbruk',),
'åkerbruket': ('åkerbruk',),
'åkerbruker': ('åkerbruker',),
'åkerbrukere': ('åkerbruker',),
'åkerbrukeren': ('åkerbruker',),
'åkerbrukerer': ('åkerbruker',),
'åkerbrukerne': ('åkerbruker',),
'åkerbær': ('åkerbær',),
'åkerbæra': ('åkerbær',),
'åkerbærene': ('åkerbær',),
'åkerbæret': ('åkerbær',),
'åkerdylla': ('åkerdylle',),
'åkerdylle': ('åkerdylle',),
'åkerdyllen': ('åkerdylle',),
'åkerdyllene': ('åkerdylle',),
'åkerdyller': ('åkerdylle',),
'åkerert': ('åkerert',),
'åkererta': ('åkerert',),
'åkererten': ('åkerert',),
'åkerertene': ('åkerert',),
'åkererter': ('åkerert',),
'åkergull': ('åkergull',),
'åkergullen': ('åkergull',),
'åkergullene': ('åkergull',),
'åkerguller': ('åkergull',),
'åkerhøna': ('åkerhøne',),
'åkerhøne': ('åkerhøne',),
'åkerhønen': ('åkerhøne',),
'åkerhønene': ('åkerhøne',),
'åkerhøner': ('åkerhøne',),
'åkerhøns': ('åkerhøns',),
'åkerhønsa': ('åkerhøns',),
'åkerhønsene': ('åkerhøns',),
'åkerhønset': ('åkerhøns',),
'åkerkål': ('åkerkål',),
'åkerkålen': ('åkerkål',),
'åkerkålene': ('åkerkål',),
'åkerkåler': ('åkerkål',),
'åkermynta': ('åkermynte',),
'åkermynte': ('åkermynte',),
'åkermynten': ('åkermynte',),
'åkermyntene': ('åkermynte',),
'åkermynter': ('åkermynte',),
'åkermåne': ('åkermåne',),
'åkermånen': ('åkermåne',),
'åkermånene': ('åkermåne',),
'åkermåner': ('åkermåne',),
'åkerreddik': ('åkerreddik',),
'åkerreddiken': ('åkerreddik',),
'åkerreddikene': ('åkerreddik',),
'åkerreddiker': ('åkerreddik',),
'åkerriksa': ('åkerrikse',),
'åkerrikse': ('åkerrikse',),
'åkerriksen': ('åkerrikse',),
'åkerriksene': ('åkerrikse',),
'åkerrikser': ('åkerrikse',),
'åkersennep': ('åkersennep',),
'åkersennepen': ('åkersennep',),
'åkersennepene': ('åkersennep',),
'åkersenneper': ('åkersennep',),
'åkersnegl': ('åkersnegl',),
'åkersneglen': ('åkersnegl',),
'åkersneglene': ('åkersnegl',),
'åkersnegler': ('åkersnegl',),
'åkersnile': ('åkersnile',),
'åkersnilen': ('åkersnile',),
'åkersnilene': ('åkersnile',),
'åkersniler': ('åkersnile',),
'åkertistel': ('åkertistel',),
'åkertistelen': ('åkertistel',),
'åkertistlene': ('åkertistel',),
'åkertistler': ('åkertistel',),
'åkerøepla': ('åkerøeple',),
'åkerøeple': ('åkerøeple',),
'åkerøeplene': ('åkerøeple',),
'åkerøepler': ('åkerøeple',),
'åkerøeplet': ('åkerøeple',),
'åkle': ('åkle',),
'åkleet': ('åkle',),
'åklær': ('åkle',),
'åklærne': ('åkle',),
'ål': ('ål',),
'ålen': ('ål',),
'ålene': ('ål',),
'åler': ('ål',),
'ål': ('ål',),
'ålen': ('ål',),
'ålene': ('ål',),
'åler': ('ål',),
'ål': ('ål',),
'ålen': ('ål',),
'ålene': ('ål',),
'åler': ('ål',),
'ål': ('ål',),
'ålen': ('ål',),
'ålene': ('ål',),
'åler': ('ål',),
'ålefamilie': ('ålefamilie',),
'ålefamilien': ('ålefamilie',),
'ålefamiliene': ('ålefamilie',),
'ålefamilier': ('ålefamilie',),
'ålefaring': ('ålefaring',),
'ålefaringen': ('ålefaring',),
'ålefaringene': ('ålefaring',),
'ålefaringer': ('ålefaring',),
'ålegard': ('ålegard',),
'ålegarden': ('ålegard',),
'ålegardene': ('ålegard',),
'ålegarder': ('ålegard',),
'ålegjerda': ('ålegjerde',),
'ålegjerde': ('ålegjerde',),
'ålegjerdene': ('ålegjerde',),
'ålegjerder': ('ålegjerde',),
'ålegjerdet': ('ålegjerde',),
'ålegras': ('ålegras',),
'ålegrasa': ('ålegras',),
'ålegrasene': ('ålegras',),
'ålegraset': ('ålegras',),
'ålegress': ('ålegress',),
'ålegressa': ('ålegress',),
'ålegressene': ('ålegress',),
'ålegresset': ('ålegress',),
'ålejern': ('ålejern',),
'ålejerna': ('ålejern',),
'ålejernene': ('ålejern',),
'ålejernet': ('ålejern',),
'ålekista': ('ålekiste',),
'ålekiste': ('ålekiste',),
'ålekisten': ('ålekiste',),
'ålekistene': ('ålekiste',),
'ålekister': ('ålekiste',),
'ålekona': ('ålekone',),
'ålekone': ('ålekone',),
'ålekonen': ('ålekone',),
'ålekonene': ('ålekone',),
'ålekoner': ('ålekone',),
'ålekvabbe': ('ålekvabbe',),
'ålekvabben': ('ålekvabbe',),
'ålekvabbene': ('ålekvabbe',),
'ålekvabber': ('ålekvabbe',),
'ålending': ('ålending',),
'ålendingen': ('ålending',),
'ålendingene': ('ålending',),
'ålendinger': ('ålending',),
'ålepadda': ('ålepadde',),
'ålepadde': ('ålepadde',),
'ålepadden': ('ålepadde',),
'ålepaddene': ('ålepadde',),
'ålepadder': ('ålepadde',),
'ålerusa': ('åleruse',),
'åleruse': ('åleruse',),
'ålerusen': ('åleruse',),
'ålerusene': ('åleruse',),
'åleruser': ('åleruse',),
'åleyngel': ('åleyngel',),
'åleyngelen': ('åleyngel',),
'åleynglene': ('åleyngel',),
'åma': ('åme',),
'åme': ('åme',),
'åmen': ('åme',),
'åmene': ('åme',),
'åmer': ('åme',),
'åmot': ('åmot',),
'åmota': ('åmot',),
'åmotene': ('åmot',),
'åmotet': ('åmot',),
'ånd': ('ånd',),
'ånden': ('ånd',),
'åndene': ('ånd',),
'ånder': ('ånd',),
'ånde': ('ånde',),
'ånden': ('ånde',),
'åndene': ('ånde',),
'ånder': ('ånde',),
'åndebanking': ('åndebanking',),
'åndebankinga': ('åndebanking',),
'åndebankingen': ('åndebanking',),
'åndebankingene': ('åndebanking',),
'åndebankinger': ('åndebanking',),
'åndebesvergelse': ('åndebesvergelse',),
'åndebesvergelsen': ('åndebesvergelse',),
'åndebesvergelsene': ('åndebesvergelse',),
'åndebesvergelser': ('åndebesvergelse',),
'åndedrag': ('åndedrag',),
'åndedraga': ('åndedrag',),
'åndedragene': ('åndedrag',),
'åndedraget': ('åndedrag',),
'åndedrett': ('åndedrett',),
'åndedretta': ('åndedrett',),
'åndedrettene': ('åndedrett',),
'åndedrettet': ('åndedrett',),
'åndedyrkelse': ('åndedyrkelse',),
'åndedyrkelsen': ('åndedyrkelse',),
'åndedyrkelsene': ('åndedyrkelse',),
'åndedyrkelser': ('åndedyrkelse',),
'åndedyrking': ('åndedyrking',),
'åndedyrkinga': ('åndedyrking',),
'åndedyrkingen': ('åndedyrking',),
'åndedyrkingene': ('åndedyrking',),
'åndedyrkinger': ('åndedyrking',),
'åndehol': ('åndehol',),
'åndehola': ('åndehol',),
'åndeholene': ('åndehol',),
'åndeholet': ('åndehol',),
'åndehull': ('åndehull',),
'åndehulla': ('åndehull',),
'åndehullene': ('åndehull',),
'åndehuller': ('åndehull',),
'åndehullet': ('åndehull',),
'åndemaner': ('åndemaner',),
'åndemanere': ('åndemaner',),
'åndemaneren': ('åndemaner',),
'åndemanerer': ('åndemaner',),
'åndemanerne': ('åndemaner',),
'åndemaning': ('åndemaning',),
'åndemaninga': ('åndemaning',),
'åndemaningen': ('åndemaning',),
'åndemaningene': ('åndemaning',),
'åndemaninger': ('åndemaning',),
'åndenød': ('åndenød',),
'åndenøda': ('åndenød',),
'åndenøden': ('åndenød',),
'åndenødene': ('åndenød',),
'åndenøder': ('åndenød',),
'ånder': ('ånder',),
'åndere': ('ånder',),
'ånderen': ('ånder',),
'ånderne': ('ånder',),
'åndra': ('ånder',),
'åndre': ('ånder',),
'åndrene': ('ånder',),
'åndrer': ('ånder',),
'ånderot': ('ånderot',),
'ånderota': ('ånderot',),
'ånderoten': ('ånderot',),
'ånderøttene': ('ånderot',),
'ånderøtter': ('ånderot',),
'ånderør': ('ånderør',),
'ånderøra': ('ånderør',),
'ånderørene': ('ånderør',),
'ånderøret': ('ånderør',),
'åndfullhet': ('åndfullhet',),
'åndfullheta': ('åndfullhet',),
'åndfullheten': ('åndfullhet',),
'åndfullhetene': ('åndfullhet',),
'åndfullheter': ('åndfullhet',),
'åndløshet': ('åndløshet',),
'åndløsheta': ('åndløshet',),
'åndløsheten': ('åndløshet',),
'åndløshetene': ('åndløshet',),
'åndløsheter': ('åndløshet',),
'åndløysa': ('åndløyse',),
'åndløyse': ('åndløyse',),
'åndløysen': ('åndløyse',),
'åndløysene': ('åndløyse',),
'åndløyser': ('åndløyse',),
'åndsarbeid': ('åndsarbeid',),
'åndsarbeida': ('åndsarbeid',),
'åndsarbeidene': ('åndsarbeid',),
'åndsarbeider': ('åndsarbeid',),
'åndsarbeidet': ('åndsarbeid',),
'åndsarbeider': ('åndsarbeider',),
'åndsarbeidere': ('åndsarbeider',),
'åndsarbeideren': ('åndsarbeider',),
'åndsarbeiderer': ('åndsarbeider',),
'åndsarbeiderne': ('åndsarbeider',),
'åndsaristokrat': ('åndsaristokrat',),
'åndsaristokraten': ('åndsaristokrat',),
'åndsaristokratene': ('åndsaristokrat',),
'åndsaristokrater': ('åndsaristokrat',),
'åndsdåp': ('åndsdåp',),
'åndsdåpen': ('åndsdåp',),
'åndsdåpene': ('åndsdåp',),
'åndsdåper': ('åndsdåp',),
'åndselite': ('åndselite',),
'åndseliten': ('åndselite',),
'åndselitene': ('åndselite',),
'åndseliter': ('åndselite',),
'åndsevna': ('åndsevne',),
'åndsevne': ('åndsevne',),
'åndsevnen': ('åndsevne',),
'åndsevnene': ('åndsevne',),
'åndsevner': ('åndsevne',),
'åndsfattigdom': ('åndsfattigdom',),
'åndsfattigdommen': ('åndsfattigdom',),
'åndsfattigdommene': ('åndsfattigdom',),
'åndsfattigdommer': ('åndsfattigdom',),
'åndsfelle': ('åndsfelle',),
'åndsfellen': ('åndsfelle',),
'åndsfellene': ('åndsfelle',),
'åndsfeller': ('åndsfelle',),
'åndsfravær': ('åndsfravær',),
'åndsfraværa': ('åndsfravær',),
'åndsfraværene': ('åndsfravær',),
'åndsfraværet': ('åndsfravær',),
'åndsfraværelse': ('åndsfraværelse',),
'åndsfraværelsen': ('åndsfraværelse',),
'åndsfraværelsene': ('åndsfraværelse',),
'åndsfraværelser': ('åndsfraværelse',),
'åndsfrende': ('åndsfrende',),
'åndsfrenden': ('åndsfrende',),
'åndsfrendene': ('åndsfrende',),
'åndsfrender': ('åndsfrende',),
'åndsfridom': ('åndsfridom',),
'åndsfridommen': ('åndsfridom',),
'åndsfridommene': ('åndsfridom',),
'åndsfridommer': ('åndsfridom',),
'åndsfrihet': ('åndsfrihet',),
'åndsfriheta': ('åndsfrihet',),
'åndsfriheten': ('åndsfrihet',),
'åndsfrihetene': ('åndsfrihet',),
'åndsfriheter': ('åndsfrihet',),
'åndshistoria': ('åndshistorie',),
'åndshistorie': ('åndshistorie',),
'åndshistorien': ('åndshistorie',),
'åndshistoriene': ('åndshistorie',),
'åndshistorier': ('åndshistorie',),
'åndshovmod': ('åndshovmod',),
'åndshovmoda': ('åndshovmod',),
'åndshovmodene': ('åndshovmod',),
'åndshovmodet': ('åndshovmod',),
'åndsliv': ('åndsliv',),
'åndsliva': ('åndsliv',),
'åndslivene': ('åndsliv',),
'åndslivet': ('åndsliv',),
'åndsnærvær': ('åndsnærvær',),
'åndsnærværa': ('åndsnærvær',),
'åndsnærværene': ('åndsnærvær',),
'åndsnærværet': ('åndsnærvær',),
'åndsnærværelse': ('åndsnærværelse',),
'åndsnærværelsen': ('åndsnærværelse',),
'åndsnærværelsene': ('åndsnærværelse',),
'åndsnærværelser': ('åndsnærværelse',),
'åndsretning': ('åndsretning',),
'åndsretninga': ('åndsretning',),
'åndsretningen': ('åndsretning',),
'åndsretningene': ('åndsretning',),
'åndsretninger': ('åndsretning',),
'åndssløvhet': ('åndssløvhet',),
'åndssløvheta': ('åndssløvhet',),
'åndssløvheten': ('åndssløvhet',),
'åndssløvhetene': ('åndssløvhet',),
'åndssløvheter': ('åndssløvhet',),
'åndssnobb': ('åndssnobb',),
'åndssnobben': ('åndssnobb',),
'åndssnobbene': ('åndssnobb',),
'åndssnobber': ('åndssnobb',),
'åndssnobberi': ('åndssnobberi',),
'åndssnobberia': ('åndssnobberi',),
'åndssnobberiene': ('åndssnobberi',),
'åndssnobberier': ('åndssnobberi',),
'åndssnobberiet': ('åndssnobberi',),
'åndssvakeomsorg': ('åndssvakeomsorg',),
'åndssvakeomsorga': ('åndssvakeomsorg',),
'åndssvakeomsorgen': ('åndssvakeomsorg',),
'åndssvakeomsorgene': ('åndssvakeomsorg',),
'åndssvakeomsorger': ('åndssvakeomsorg',),
'åndsverk': ('åndsverk',),
'åndsverka': ('åndsverk',),
'åndsverkene': ('åndsverk',),
'åndsverker': ('åndsverk',),
'åndsverket': ('åndsverk',),
'åndsverklov': ('åndsverklov',),
'åndsverkloven': ('åndsverklov',),
'åndsverklovene': ('åndsverklov',),
'åndsverklover': ('åndsverklov',),
'ångstrøm': ('ångstrøm',),
'ångstrømen': ('ångstrøm',),
'ångstrømene': ('ångstrøm',),
'åpenbaring': ('åpenbaring',),
'åpenbaringa': ('åpenbaring',),
'åpenbaringen': ('åpenbaring',),
'åpenbaringene': ('åpenbaring',),
'åpenbaringer': ('åpenbaring',),
'åpenbaringsreligion': ('åpenbaringsreligion',),
'åpenbaringsreligionen': ('åpenbaringsreligion',),
'åpenbaringsreligionene': ('åpenbaringsreligion',),
'åpenbaringsreligioner': ('åpenbaringsreligion',),
'åpner': ('åpner',),
'åpnere': ('åpner',),
'åpneren': ('åpner',),
'åpnerer': ('åpner',),
'åpnerne': ('åpner',),
'åpning': ('åpning',),
'åpninga': ('åpning',),
'åpningen': ('åpning',),
'åpningene': ('åpning',),
'åpninger': ('åpning',),
'åpningsdag': ('åpningsdag',),
'åpningsdagen': ('åpningsdag',),
'åpningsdagene': ('åpningsdag',),
'åpningsdager': ('åpningsdag',),
'åpningsforestilling': ('åpningsforestilling',),
'åpningsforestillinga': ('åpningsforestilling',),
'åpningsforestillingen': ('åpningsforestilling',),
'åpningsforestillingene': ('åpningsforestilling',),
'åpningsforestillinger': ('åpningsforestilling',),
'åpningsgnist': ('åpningsgnist',),
'åpningsgnisten': ('åpningsgnist',),
'åpningsgnistene': ('åpningsgnist',),
'åpningsgnister': ('åpningsgnist',),
'åpningshøgtidelighet': ('åpningshøgtidelighet',),
'åpningshøgtideligheta': ('åpningshøgtidelighet',),
'åpningshøgtideligheten': ('åpningshøgtidelighet',),
'åpningshøgtidelighetene': ('åpningshøgtidelighet',),
'åpningshøgtideligheter': ('åpningshøgtidelighet',),
'åpningshøytidelighet': ('åpningshøytidelighet',),
'åpningshøytideligheta': ('åpningshøytidelighet',),
'åpningshøytideligheten': ('åpningshøytidelighet',),
'åpningshøytidelighetene': ('åpningshøytidelighet',),
'åpningshøytideligheter': ('åpningshøytidelighet',),
'åpningsmøta': ('åpningsmøte',),
'åpningsmøte': ('åpningsmøte',),
'åpningsmøtene': ('åpningsmøte',),
'åpningsmøter': ('åpningsmøte',),
'åpningsmøtet': ('åpningsmøte',),
'åpningssang': ('åpningssang',),
'åpningssangen': ('åpningssang',),
'åpningssangene': ('åpningssang',),
'åpningssanger': ('åpningssang',),
'åpningsstrøm': ('åpningsstrøm',),
'åpningsstrømmen': ('åpningsstrøm',),
'åpningsstrømmene': ('åpningsstrøm',),
'åpningsstrømmer': ('åpningsstrøm',),
'åpningstid': ('åpningstid',),
'åpningstida': ('åpningstid',),
'åpningstiden': ('åpningstid',),
'åpningstidene': ('åpningstid',),
'åpningstider': ('åpningstid',),
'år': ('år',),
'åra': ('år',),
'årene': ('år',),
'året': ('år',),
'år': ('år',),
'åra': ('år',),
'årene': ('år',),
'årer': ('år',),
'år': ('år',),
'åra': ('år',),
'årene': ('år',),
'årer': ('år',),
'årbok': ('årbok',),
'årboka': ('årbok',),
'årboken': ('årbok',),
'årbøkene': ('årbok',),
'årbøker': ('årbok',),
'årbokforfatter': ('årbokforfatter',),
'årbokforfattere': ('årbokforfatter',),
'årbokforfatteren': ('årbokforfatter',),
'årbokforfatterer': ('årbokforfatter',),
'årbokforfatterne': ('årbokforfatter',),
'årbuk': ('årbuk',),
'årbuken': ('årbuk',),
'årbukene': ('årbuk',),
'årbuker': ('årbuk',),
'åre': ('åre',),
'åren': ('åre',),
'årene': ('åre',),
'årer': ('åre',),
'åra': ('åre',),
'åre': ('åre',),
'åren': ('åre',),
'årene': ('åre',),
'årer': ('åre',),
'åra': ('åre',),
'åre': ('åre',),
'åren': ('åre',),
'årene': ('åre',),
'årer': ('åre',),
'åra': ('åre',),
'åre': ('åre',),
'åren': ('åre',),
'årene': ('åre',),
'årer': ('åre',),
'åreband': ('åreband',),
'årebanda': ('åreband',),
'årebandene': ('åreband',),
'årebandet': ('åreband',),
'årebetennelse': ('årebetennelse',),
'årebetennelsen': ('årebetennelse',),
'årebetennelsene': ('årebetennelse',),
'årebetennelser': ('årebetennelse',),
'åreblad': ('åreblad',),
'åreblada': ('åreblad',),
'årebladene': ('åreblad',),
'åreblader': ('åreblad',),
'årebladet': ('åreblad',),
'årebånd': ('årebånd',),
'årebånda': ('årebånd',),
'årebåndene': ('årebånd',),
'årebåndet': ('årebånd',),
'åreforkalking': ('åreforkalking',),
'åreforkalkinga': ('åreforkalking',),
'åreforkalkingen': ('åreforkalking',),
'åreforkalkingene': ('åreforkalking',),
'åreforkalkinger': ('åreforkalking',),
'åreforkalkning': ('åreforkalkning',),
'åreforkalkninga': ('åreforkalkning',),
'åreforkalkningen': ('åreforkalkning',),
'åreforkalkningene': ('åreforkalkning',),
'åreforkalkninger': ('åreforkalkning',),
'årefot': ('årefot',),
'årefoten': ('årefot',),
'åreføttene': ('årefot',),
'åreføtter': ('årefot',),
'årefoting': ('årefoting',),
'årefotingen': ('årefoting',),
'årefotingene': ('årefoting',),
'årefotinger': ('årefoting',),
'åreføtting': ('åreføtting',),
'åreføttingen': ('åreføtting',),
'åreføttingene': ('åreføtting',),
'åreføttinger': ('åreføtting',),
'åregaffel': ('åregaffel',),
'åregaffelen': ('åregaffel',),
'åregaflene': ('åregaffel',),
'åregafler': ('åregaffel',),
'åregang': ('åregang',),
'åregangen': ('åregang',),
'åregangene': ('åregang',),
'åreganger': ('åregang',),
'årehinna': ('årehinne',),
'årehinne': ('årehinne',),
'årehinnen': ('årehinne',),
'årehinnene': ('årehinne',),
'årehinner': ('årehinne',),
'årehinnebetennelse': ('årehinnebetennelse',),
'årehinnebetennelsen': ('årehinnebetennelse',),
'årehinnebetennelsene': ('årehinnebetennelse',),
'årehinnebetennelser': ('årehinnebetennelse',),
'årekeip': ('årekeip',),
'årekeipen': ('årekeip',),
'årekeipene': ('årekeip',),
'årekeiper': ('årekeip',),
'årekeipa': ('årekeipe',),
'årekeipe': ('årekeipe',),
'årekeipen': ('årekeipe',),
'årekeipene': ('årekeipe',),
'årekeiper': ('årekeipe',),
'åreknute': ('åreknute',),
'åreknuten': ('åreknute',),
'åreknutene': ('åreknute',),
'åreknuter': ('åreknute',),
'åremål': ('åremål',),
'åremåla': ('åremål',),
'åremålene': ('åremål',),
'åremålet': ('åremål',),
'åremålsansettelse': ('åremålsansettelse',),
'åremålsansettelsen': ('åremålsansettelse',),
'åremålsansettelsene': ('åremålsansettelse',),
'åremålsansettelser': ('åremålsansettelse',),
'åremålsdag': ('åremålsdag',),
'åremålsdagen': ('åremålsdag',),
'åremålsdagene': ('åremålsdag',),
'åremålsdager': ('åremålsdag',),
'åremålstilsetting': ('åremålstilsetting',),
'åremålstilsettinga': ('åremålstilsetting',),
'åremålstilsettingen': ('åremålstilsetting',),
'åremålstilsettingene': ('åremålstilsetting',),
'åremålstilsettinger': ('åremålstilsetting',),
'årenett': ('årenett',),
'årenetta': ('årenett',),
'årenettene': ('årenett',),
'årenettet': ('årenett',),
'årepinne': ('årepinne',),
'årepinnen': ('årepinne',),
'årepinnene': ('årepinne',),
'årepinner': ('årepinne',),
'årestova': ('årestove',),
'årestove': ('årestove',),
'årestoven': ('årestove',),
'årestovene': ('årestove',),
'årestover': ('årestove',),
'årestua': ('årestue',),
'årestue': ('årestue',),
'årestuen': ('årestue',),
'årestuene': ('årestue',),
'årestuer': ('årestue',),
'åretak': ('åretak',),
'åretaka': ('åretak',),
'åretakene': ('åretak',),
'åretaket': ('åretak',),
'åreveng': ('åreveng',),
'årevengen': ('åreveng',),
'årevengene': ('åreveng',),
'årevenger': ('åreveng',),
'åreveng': ('åreveng',),
'årevengen': ('åreveng',),
'årevengene': ('åreveng',),
'årevenger': ('åreveng',),
'åreving': ('åreving',),
'årevingen': ('åreving',),
'årevingene': ('åreving',),
'årevinger': ('åreving',),
'åreving': ('åreving',),
'årevingen': ('åreving',),
'årevingene': ('åreving',),
'årevinger': ('åreving',),
'årevinge': ('årevinge',),
'årevingen': ('årevinge',),
'årevingene': ('årevinge',),
'årevinger': ('årevinge',),
'årevinge': ('årevinge',),
'årevingen': ('årevinge',),
'årevingene': ('årevinge',),
'årevinger': ('årevinge',),
'årgang': ('årgang',),
'årgangen': ('årgang',),
'årgangene': ('årgang',),
'årganger': ('årgang',),
'årgangsvin': ('årgangsvin',),
'årgangsvinen': ('årgangsvin',),
'årgangsvinene': ('årgangsvin',),
'årgangsviner': ('årgangsvin',),
'århundra': ('århundre',),
'århundre': ('århundre',),
'århundrene': ('århundre',),
'århundrer': ('århundre',),
'århundret': ('århundre',),
'århundreskifta': ('århundreskifte',),
'århundreskifte': ('århundreskifte',),
'århundreskiftene': ('århundreskifte',),
'århundreskifter': ('århundreskifte',),
'århundreskiftet': ('århundreskifte',),
'åring': ('åring',),
'åringen': ('åring',),
'åringene': ('åring',),
'åringer': ('åring',),
'åring': ('åring',),
'åringen': ('åring',),
'åringene': ('åring',),
'åringer': ('åring',),
'årmann': ('årmann',),
'årmannen': ('årmann',),
'årmenn': ('årmann',),
'årmennene': ('årmann',),
'årrekka': ('årrekke',),
'årrekke': ('årrekke',),
'årrekken': ('årrekke',),
'årrekkene': ('årrekke',),
'årrekker': ('årrekke',),
'årring': ('årring',),
'årringen': ('årring',),
'årringene': ('årring',),
'årringer': ('årring',),
'årsak': ('årsak',),
'årsaka': ('årsak',),
'årsaken': ('årsak',),
'årsakene': ('årsak',),
'årsaker': ('årsak',),
'årsaksforhold': ('årsaksforhold',),
'årsaksforholda': ('årsaksforhold',),
'årsaksforholdene': ('årsaksforhold',),
'årsaksforholdet': ('årsaksforhold',),
'årsakskonjunksjon': ('årsakskonjunksjon',),
'årsakskonjunksjonen': ('årsakskonjunksjon',),
'årsakskonjunksjonene': ('årsakskonjunksjon',),
'årsakskonjunksjoner': ('årsakskonjunksjon',),
'årsakslov': ('årsakslov',),
'årsaksloven': ('årsakslov',),
'årsakslovene': ('årsakslov',),
'årsakslover': ('årsakslov',),
'årsaksrekka': ('årsaksrekke',),
'årsaksrekke': ('årsaksrekke',),
'årsaksrekken': ('årsaksrekke',),
'årsaksrekkene': ('årsaksrekke',),
'årsaksrekker': ('årsaksrekke',),
'årsakssetning': ('årsakssetning',),
'årsakssetninga': ('årsakssetning',),
'årsakssetningen': ('årsakssetning',),
'årsakssetningene': ('årsakssetning',),
'årsakssetninger': ('årsakssetning',),
'årsavgift': ('årsavgift',),
'årsavgifta': ('årsavgift',),
'årsavgiften': ('årsavgift',),
'årsavgiftene': ('årsavgift',),
'årsavgifter': ('årsavgift',),
'årsbasis': ('årsbasis',),
'årsbasisen': ('årsbasis',),
'årsbasisene': ('årsbasis',),
'årsbasiser': ('årsbasis',),
'årsberetning': ('årsberetning',),
'årsberetninga': ('årsberetning',),
'årsberetningen': ('årsberetning',),
'årsberetningene': ('årsberetning',),
'årsberetninger': ('årsberetning',),
'årsdag': ('årsdag',),
'årsdagen': ('årsdag',),
'årsdagene': ('årsdag',),
'årsdager': ('årsdag',),
'årsfest': ('årsfest',),
'årsfesten': ('årsfest',),
'årsfestene': ('årsfest',),
'årsfester': ('årsfest',),
'årsinntekt': ('årsinntekt',),
'årsinntekta': ('årsinntekt',),
'årsinntekten': ('årsinntekt',),
'årsinntektene': ('årsinntekt',),
'årsinntekter': ('årsinntekt',),
'årsklassa': ('årsklasse',),
'årsklasse': ('årsklasse',),
'årsklassen': ('årsklasse',),
'årsklassene': ('årsklasse',),
'årsklasser': ('årsklasse',),
'årskull': ('årskull',),
'årskulla': ('årskull',),
'årskullene': ('årskull',),
'årskullet': ('årskull',),
'årsmelding': ('årsmelding',),
'årsmeldinga': ('årsmelding',),
'årsmeldingen': ('årsmelding',),
'årsmeldingene': ('årsmelding',),
'årsmeldinger': ('årsmelding',),
'årsmøta': ('årsmøte',),
'årsmøte': ('årsmøte',),
'årsmøtene': ('årsmøte',),
'årsmøter': ('årsmøte',),
'årsmøtet': ('årsmøte',),
'årsoppgjør': ('årsoppgjør',),
'årsoppgjøra': ('årsoppgjør',),
'årsoppgjørene': ('årsoppgjør',),
'årsoppgjøret': ('årsoppgjør',),
'årsskifta': ('årsskifte',),
'årsskifte': ('årsskifte',),
'årsskiftene': ('årsskifte',),
'årsskifter': ('årsskifte',),
'årsskiftet': ('årsskifte',),
'årsskott': ('årsskott',),
'årsskotta': ('årsskott',),
'årsskottene': ('årsskott',),
'årsskottet': ('årsskott',),
'årsskrift': ('årsskrift',),
'årsskrifta': ('årsskrift',),
'årsskriftene': ('årsskrift',),
'årsskrifter': ('årsskrift',),
'årsskriftet': ('årsskrift',),
'årsskudd': ('årsskudd',),
'årsskudda': ('årsskudd',),
'årsskuddene': ('årsskudd',),
'årsskuddet': ('årsskudd',),
'årstal': ('årstal',),
'årstala': ('årstal',),
'årstalene': ('årstal',),
'årstalet': ('årstal',),
'årstall': ('årstall',),
'årstalla': ('årstall',),
'årstallene': ('årstall',),
'årstallet': ('årstall',),
'årstid': ('årstid',),
'årstida': ('årstid',),
'årstiden': ('årstid',),
'årstidene': ('årstid',),
'årstider': ('årstid',),
'årsunge': ('årsunge',),
'årsungen': ('årsunge',),
'årsungene': ('årsunge',),
'årsunger': ('årsunge',),
'årsvekst': ('årsvekst',),
'årsveksten': ('årsvekst',),
'årsvekstene': ('årsvekst',),
'årsvekster': ('årsvekst',),
'årsverk': ('årsverk',),
'årsverka': ('årsverk',),
'årsverkene': ('årsverk',),
'årsverker': ('årsverk',),
'årsverket': ('årsverk',),
'årti': ('årti',),
'årtia': ('årti',),
'årtiene': ('årti',),
'årtier': ('årti',),
'årtiet': ('årti',),
'årtusen': ('årtusen',),
'årtusena': ('årtusen',),
'årtusenene': ('årtusen',),
'årtusener': ('årtusen',),
'årtusenet': ('årtusen',),
'årveg': ('årveg',),
'årvegen': ('årveg',),
'årvegene': ('årveg',),
'årveger': ('årveg',),
'årvei': ('årvei',),
'årveien': ('årvei',),
'årveiene': ('årvei',),
'årveier': ('årvei',),
'åsatro': ('åsatro',),
'åsatroa': ('åsatro',),
'åsatroen': ('åsatro',),
'åsatroene': ('åsatro',),
'åsatroer': ('åsatro',),
'åsatru': ('åsatru',),
'åsatrua': ('åsatru',),
'åsatruen': ('åsatru',),
'åsatruene': ('åsatru',),
'åsatruer': ('åsatru',),
'åsetesrett': ('åsetesrett',),
'åsetesretten': ('åsetesrett',),
'åsetesrettene': ('åsetesrett',),
'åsetesretter': ('åsetesrett',),
'åsgårdsrei': ('åsgårdsrei',),
'åsgårdsreia': ('åsgårdsrei',),
'åsgårdsreien': ('åsgårdsrei',),
'åsgårdsreiene': ('åsgårdsrei',),
'åsgårdsreier': ('åsgårdsrei',),
'åsing': ('åsing',),
'åsingen': ('åsing',),
'åsingene': ('åsing',),
'åsinger': ('åsing',),
'åsrygg': ('åsrygg',),
'åsryggen': ('åsrygg',),
'åsryggene': ('åsrygg',),
'åsrygger': ('åsrygg',),
'åssida': ('åsside',),
'åsside': ('åsside',),
'åssiden': ('åsside',),
'åssidene': ('åsside',),
'åssider': ('åsside',),
'åstak': ('åstak',),
'åstaka': ('åstak',),
'åstakene': ('åstak',),
'åstaket': ('åstak',),
'åsted': ('åsted',),
'åstedene': ('åsted',),
'åsteder': ('åsted',),
'åstedet': ('åsted',),
'åstedsbefaring': ('åstedsbefaring',),
'åstedsbefaringa': ('åstedsbefaring',),
'åstedsbefaringen': ('åstedsbefaring',),
'åstedsbefaringene': ('åstedsbefaring',),
'åstedsbefaringer': ('åstedsbefaring',),
'åstedsforretning': ('åstedsforretning',),
'åstedsforretninga': ('åstedsforretning',),
'åstedsforretningen': ('åstedsforretning',),
'åstedsforretningene': ('åstedsforretning',),
'åstedsforretninger': ('åstedsforretning',),
'åstedsgang': ('åstedsgang',),
'åstedsgangen': ('åstedsgang',),
'åstedsgangene': ('åstedsgang',),
'åstedsganger': ('åstedsgang',),
'åstedssak': ('åstedssak',),
'åstedssaka': ('åstedssak',),
'åstedssaken': ('åstedssak',),
'åstedssakene': ('åstedssak',),
'åstedssaker': ('åstedssak',),
'åsyn': ('åsyn',),
'åsyna': ('åsyn',),
'åsynene': ('åsyn',),
'åsynet': ('åsyn',),
'åsynja': ('åsynje',),
'åsynje': ('åsynje',),
'åsynjen': ('åsynje',),
'åsynjene': ('åsynje',),
'åsynjer': ('åsynje',),
'åt': ('åt',),
'åta': ('åt',),
'åtene': ('åt',),
'åtet': ('åt',),
'åtak': ('åtak',),
'åtaka': ('åtak',),
'åtakene': ('åtak',),
'åtaket': ('åtak',),
'åta': ('åte',),
'åte': ('åte',),
'åten': ('åte',),
'åtene': ('åte',),
'åter': ('åte',),
'åtet': ('åte',),
'åtferd': ('åtferd',),
'åtferda': ('åtferd',),
'åtferden': ('åtferd',),
'åtferdene': ('åtferd',),
'åtferder': ('åtferd',),
'åtgjerd': ('åtgjerd',),
'åtgjerda': ('åtgjerd',),
'åtgjerden': ('åtgjerd',),
'åtgjerdene': ('åtgjerd',),
'åtgjerder': ('åtgjerd',),
'åtsel': ('åtsel',),
'åtselet': ('åtsel',),
'åtsla': ('åtsel',),
'åtslene': ('åtsel',),
'åtsler': ('åtsel',),
'åtslet': ('åtsel',),
'åtselbille': ('åtselbille',),
'åtselbillen': ('åtselbille',),
'åtselbillene': ('åtselbille',),
'åtselbiller': ('åtselbille',),
'åtselbille': ('åtselbille',),
'åtselbillen': ('åtselbille',),
'åtselbillene': ('åtselbille',),
'åtselbiller': ('åtselbille',),
'åtselblomst': ('åtselblomst',),
'åtselblomsten': ('åtselblomst',),
'åtselblomstene': ('åtselblomst',),
'åtselblomster': ('åtselblomst',),
'åtseleter': ('åtseleter',),
'åtseletere': ('åtseleter',),
'åtseleteren': ('åtseleter',),
'åtseleterer': ('åtseleter',),
'åtseleterne': ('åtseleter',),
'åtselflua': ('åtselflue',),
'åtselflue': ('åtselflue',),
'åtselfluen': ('åtselflue',),
'åtselfluene': ('åtselflue',),
'åtselfluer': ('åtselflue',),
'åtselfugl': ('åtselfugl',),
'åtselfuglen': ('åtselfugl',),
'åtselfuglene': ('åtselfugl',),
'åtselfugler': ('åtselfugl',),
'åtselgift': ('åtselgift',),
'åtselgifta': ('åtselgift',),
'åtselgiften': ('åtselgift',),
'åtselgiftene': ('åtselgift',),
'åtselgifter': ('åtselgift',),
'åtselgraver': ('åtselgraver',),
'åtselgravere': ('åtselgraver',),
'åtselgraveren': ('åtselgraver',),
'åtselgraverer': ('åtselgraver',),
'åtselgraverne': ('åtselgraver',),
'åtselgribb': ('åtselgribb',),
'åtselgribben': ('åtselgribb',),
'åtselgribbene': ('åtselgribb',),
'åtselgribber': ('åtselgribb',),
'åtselsopp': ('åtselsopp',),
'åtselsoppen': ('åtselsopp',),
'åtselsoppene': ('åtselsopp',),
'åtselsopper': ('åtselsopp',),
'åttedel': ('åttedel',),
'åttedelen': ('åttedel',),
'åttedelene': ('åttedel',),
'åttedeler': ('åttedel',),
'åttekant': ('åttekant',),
'åttekanten': ('åttekant',),
'åttekantene': ('åttekant',),
'åttekanter': ('åttekant',),
'åttendedel': ('åttendedel',),
'åttendedelen': ('åttendedel',),
'åttendedelene': ('åttendedel',),
'åttendedeler': ('åttendedel',),
'åtter': ('åtter',),
'åttere': ('åtter',),
'åtteren': ('åtter',),
'åtterer': ('åtter',),
'åtterne': ('åtter',),
'åttetal': ('åttetal',),
'åttetala': ('åttetal',),
'åttetalene': ('åttetal',),
'åttetalet': ('åttetal',),
'åttetall': ('åttetall',),
'åttetalla': ('åttetall',),
'åttetallene': ('åttetall',),
'åttetallet': ('åttetall',),
'åttetiden': ('åttetiden',),
'åtteåring': ('åtteåring',),
'åtteåringen': ('åtteåring',),
'åtteåringene': ('åtteåring',),
'åtteåringer': ('åtteåring',),
'åtteårsalder': ('åtteårsalder',),
'åtteårsaldere': ('åtteårsalder',),
'åtteårsalderen': ('åtteårsalder',),
'åtteårsalderer': ('åtteårsalder',),
'åtteårsalderne': ('åtteårsalder',),
'åtteårsaldre': ('åtteårsalder',),
'åtteårsaldrene': ('åtteårsalder',),
'åtteårsaldrer': ('åtteårsalder',),
'åttidel': ('åttidel',),
'åttidelen': ('åttidel',),
'åttidelene': ('åttidel',),
'åttideler': ('åttidel',),
'åtting': ('åtting',),
'åttingen': ('åtting',),
'åttingene': ('åtting',),
'åttinger': ('åtting',),
'åttiår': ('åttiår',),
'åttiåra': ('åttiår',),
'åttiårene': ('åttiår',),
'åttiåret': ('åttiår',),
'åttiåring': ('åttiåring',),
'åttiåringen': ('åttiåring',),
'åttiåringene': ('åttiåring',),
'åttiåringer': ('åttiåring',),
'åttiårsdag': ('åttiårsdag',),
'åttiårsdagen': ('åttiårsdag',),
'åttiårsdagene': ('åttiårsdag',),
'åttiårsdager': ('åttiårsdag',),
'åttring': ('åttring',),
'åttringen': ('åttring',),
'åttringene': ('åttring',),
'åttringer': ('åttring',),
'åttæring': ('åttæring',),
'åttæringen': ('åttæring',),
'åttæringene': ('åttæring',),
'åttæringer': ('åttæring',),
'åtvaring': ('åtvaring',),
'åtvaringa': ('åtvaring',),
'åtvaringen': ('åtvaring',),
'åtvaringene': ('åtvaring',),
'åtvaringer': ('åtvaring',),
'åvelta': ('åvelte',),
'åvelte': ('åvelte',),
'åvelten': ('åvelte',),
'åveltene': ('åvelte',),
'åvelter': ('åvelte',),
'åverk': ('åverk',),
'åverka': ('åverk',),
'åverkene': ('åverk',),
'åverket': ('åverk',),
'åvirka': ('åvirke',),
'åvirke': ('åvirke',),
'åvirkene': ('åvirke',),
'åvirker': ('åvirke',),
'åvirket': ('åvirke',),
'åvokster': ('åvokster',),
'åvokstere': ('åvokster',),
'åvoksteren': ('åvokster',),
'åvoksterer': ('åvokster',),
'åvoksterne': ('åvokster',),
'åvokstre': ('åvokster',),
'åvokstrene': ('åvokster',),
'åvokstrer': ('åvokster',),
'Æ': ('Æ',),
'Æ\'en': ('Æ',),
'Æ-en': ('Æ',),
'Æ-ene': ('Æ',),
'Æ-er': ('Æ',),
'Østen': ('Østen',),
'Ø': ('Ø',),
'Ø\'en': ('Ø',),
'Ø-en': ('Ø',),
'Ø-ene': ('Ø',),
'Ø-er': ('Ø',),
'æ': ('æ',),
'æ\'en': ('æ',),
'æ-en': ('æ',),
'æ-ene': ('æ',),
'æ-er': ('æ',),
'ægide': ('ægide',),
'ægiden': ('ægide',),
'ægidene': ('ægide',),
'ægider': ('ægide',),
'ær': ('ær',),
'æra': ('ær',),
'æren': ('ær',),
'ærene': ('ær',),
'ærer': ('ær',),
'æra': ('æra',),
'æraen': ('æra',),
'æraene': ('æra',),
'æraer': ('æra',),
'ærbarhet': ('ærbarhet',),
'ærbarheta': ('ærbarhet',),
'ærbarheten': ('ærbarhet',),
'ærbarhetene': ('ærbarhet',),
'ærbarheter': ('ærbarhet',),
'ærbødighet': ('ærbødighet',),
'ærbødigheta': ('ærbødighet',),
'ærbødigheten': ('ærbødighet',),
'ærbødighetene': ('ærbødighet',),
'ærbødigheter': ('ærbødighet',),
'æra': ('ære',),
'ære': ('ære',),
'æren': ('ære',),
'ærene': ('ære',),
'ærer': ('ære',),
'ærefrykt': ('ærefrykt',),
'ærefrykten': ('ærefrykt',),
'ærefryktene': ('ærefrykt',),
'ærefrykter': ('ærefrykt',),
'ærekjensla': ('ærekjensle',),
'ærekjensle': ('ærekjensle',),
'ærekjenslen': ('ærekjensle',),
'ærekjenslene': ('ærekjensle',),
'ærekjensler': ('ærekjensle',),
'ærekrenkelse': ('ærekrenkelse',),
'ærekrenkelsen': ('ærekrenkelse',),
'ærekrenkelsene': ('ærekrenkelse',),
'ærekrenkelser': ('ærekrenkelse',),
'ærekrenking': ('ærekrenking',),
'ærekrenkinga': ('ærekrenking',),
'ærekrenkingen': ('ærekrenking',),
'ærekrenkingene': ('ærekrenking',),
'ærekrenkinger': ('ærekrenking',),
'æreløshet': ('æreløshet',),
'æreløsheta': ('æreløshet',),
'æreløsheten': ('æreløshet',),
'æreløshetene': ('æreløshet',),
'æreløsheter': ('æreløshet',),
'æreløysa': ('æreløyse',),
'æreløyse': ('æreløyse',),
'æreløysen': ('æreløyse',),
'æreløysene': ('æreløyse',),
'æreløyser': ('æreløyse',),
'ærend': ('ærend',),
'ærenda': ('ærend',),
'ærendene': ('ærend',),
'ærender': ('ærend',),
'ærendet': ('ærend',),
'ærendsgutt': ('ærendsgutt',),
'ærendsgutten': ('ærendsgutt',),
'ærendsguttene': ('ærendsgutt',),
'ærendsgutter': ('ærendsgutt',),
'æresbevisning': ('æresbevisning',),
'æresbevisninga': ('æresbevisning',),
'æresbevisningen': ('æresbevisning',),
'æresbevisningene': ('æresbevisning',),
'æresbevisninger': ('æresbevisning',),
'æresborger': ('æresborger',),
'æresborgere': ('æresborger',),
'æresborgeren': ('æresborger',),
'æresborgerer': ('æresborger',),
'æresborgerne': ('æresborger',),
'æresdoktor': ('æresdoktor',),
'æresdoktoren': ('æresdoktor',),
'æresdoktorene': ('æresdoktor',),
'æresdoktorer': ('æresdoktor',),
'æresforpliktelse': ('æresforpliktelse',),
'æresforpliktelsen': ('æresforpliktelse',),
'æresforpliktelsene': ('æresforpliktelse',),
'æresforpliktelser': ('æresforpliktelse',),
'æresfølelse': ('æresfølelse',),
'æresfølelsen': ('æresfølelse',),
'æresfølelsene': ('æresfølelse',),
'æresfølelser': ('æresfølelse',),
'æresgjeld': ('æresgjeld',),
'æresgjelda': ('æresgjeld',),
'æresgjelden': ('æresgjeld',),
'æresgjeldene': ('æresgjeld',),
'æresgjelder': ('æresgjeld',),
'æresgjest': ('æresgjest',),
'æresgjesten': ('æresgjest',),
'æresgjestene': ('æresgjest',),
'æresgjester': ('æresgjest',),
'æresjuka': ('æresjuke',),
'æresjuke': ('æresjuke',),
'æresjuken': ('æresjuke',),
'æresjukene': ('æresjuke',),
'æresjuker': ('æresjuke',),
'æreskompani': ('æreskompani',),
'æreskompania': ('æreskompani',),
'æreskompaniene': ('æreskompani',),
'æreskompanier': ('æreskompani',),
'æreskompaniet': ('æreskompani',),
'æreskrans': ('æreskrans',),
'æreskransen': ('æreskrans',),
'æreskransene': ('æreskrans',),
'æreskranser': ('æreskrans',),
'æresmedlem': ('æresmedlem',),
'æresmedlemma': ('æresmedlem',),
'æresmedlemmene': ('æresmedlem',),
'æresmedlemmer': ('æresmedlem',),
'æresmedlemmet': ('æresmedlem',),
'æresoppreisning': ('æresoppreisning',),
'æresoppreisninga': ('æresoppreisning',),
'æresoppreisningen': ('æresoppreisning',),
'æresoppreisningene': ('æresoppreisning',),
'æresoppreisninger': ('æresoppreisning',),
'æresord': ('æresord',),
'æresorda': ('æresord',),
'æresordene': ('æresord',),
'æresordet': ('æresord',),
'ærespris': ('ærespris',),
'æresprisen': ('ærespris',),
'æresprisene': ('ærespris',),
'ærespriser': ('ærespris',),
'æresrunde': ('æresrunde',),
'æresrunden': ('æresrunde',),
'æresrundene': ('æresrunde',),
'æresrunder': ('æresrunde',),
'æressak': ('æressak',),
'æressaka': ('æressak',),
'æressaken': ('æressak',),
'æressakene': ('æressak',),
'æressaker': ('æressak',),
'æresvakt': ('æresvakt',),
'æresvakta': ('æresvakt',),
'æresvakten': ('æresvakt',),
'æresvaktene': ('æresvakt',),
'æresvakter': ('æresvakt',),
'æresyka': ('æresyke',),
'æresyke': ('æresyke',),
'æresyken': ('æresyke',),
'æresykene': ('æresyke',),
'æresyker': ('æresyke',),
'ærfugl': ('ærfugl',),
'ærfuglen': ('ærfugl',),
'ærfuglene': ('ærfugl',),
'ærfugler': ('ærfugl',),
'ærfuglslekt': ('ærfuglslekt',),
'ærfuglslekta': ('ærfuglslekt',),
'ærfuglslekten': ('ærfuglslekt',),
'ærfuglslektene': ('ærfuglslekt',),
'ærfuglslekter': ('ærfuglslekt',),
'ærgjerrighet': ('ærgjerrighet',),
'ærgjerrigheta': ('ærgjerrighet',),
'ærgjerrigheten': ('ærgjerrighet',),
'ærgjerrighetene': ('ærgjerrighet',),
'ærgjerrigheter': ('ærgjerrighet',),
'ærlighet': ('ærlighet',),
'ærligheta': ('ærlighet',),
'ærligheten': ('ærlighet',),
'ærlighetene': ('ærlighet',),
'ærligheter': ('ærlighet',),
'ærverdighet': ('ærverdighet',),
'ærverdigheta': ('ærverdighet',),
'ærverdigheten': ('ærverdighet',),
'ærverdighetene': ('ærverdighet',),
'ærverdigheter': ('ærverdighet',),
'æsa': ('æse',),
'æse': ('æse',),
'æsene': ('æse',),
'æser': ('æse',),
'æset': ('æse',),
'ætling': ('ætling',),
'ætlingen': ('ætling',),
'ætlingene': ('ætling',),
'ætlinger': ('ætling',),
'ættedrap': ('ættedrap',),
'ættedrapa': ('ættedrap',),
'ættedrapene': ('ættedrap',),
'ættedrapet': ('ættedrap',),
'ættefeide': ('ættefeide',),
'ættefeiden': ('ættefeide',),
'ættefeidene': ('ættefeide',),
'ættefeider': ('ættefeide',),
'ættegard': ('ættegard',),
'ættegarden': ('ættegard',),
'ættegardene': ('ættegard',),
'ættegarder': ('ættegard',),
'ættegransker': ('ættegransker',),
'ættegranskere': ('ættegransker',),
'ættegranskeren': ('ættegransker',),
'ættegranskerer': ('ættegransker',),
'ættegranskerne': ('ættegransker',),
'ættegransking': ('ættegransking',),
'ættegranskinga': ('ættegransking',),
'ættegranskingen': ('ættegransking',),
'ættegranskingene': ('ættegransking',),
'ættegranskinger': ('ættegransking',),
'ættegård': ('ættegård',),
'ættegården': ('ættegård',),
'ættegårdene': ('ættegård',),
'ættegårder': ('ættegård',),
'ættesaga': ('ættesaga',),
'ættesagaen': ('ættesaga',),
'ættesagaene': ('ættesaga',),
'ættesagaer': ('ættesaga',),
'ættesamfunn': ('ættesamfunn',),
'ættesamfunna': ('ættesamfunn',),
'ættesamfunnene': ('ættesamfunn',),
'ættesamfunnet': ('ættesamfunn',),
'ættesoga': ('ættesoge',),
'ættesoge': ('ættesoge',),
'ættesogen': ('ættesoge',),
'ættesogene': ('ættesoge',),
'ættesoger': ('ættesoge',),
'ættetavla': ('ættetavle',),
'ættetavle': ('ættetavle',),
'ættetavlen': ('ættetavle',),
'ættetavlene': ('ættetavle',),
'ættetavler': ('ættetavle',),
'ættetre': ('ættetre',),
'ættetrea': ('ættetre',),
'ættetreet': ('ættetre',),
'ættetrær': ('ættetre',),
'ættetrærne': ('ættetre',),
'ætting': ('ætting',),
'ættingen': ('ætting',),
'ættingene': ('ætting',),
'ættinger': ('ætting',),
'ættledd': ('ættledd',),
'ættledda': ('ættledd',),
'ættleddene': ('ættledd',),
'ættleddet': ('ættledd',),
'æva': ('æve',),
'æve': ('æve',),
'æven': ('æve',),
'ævene': ('æve',),
'æver': ('æve',),
'ø': ('ø',),
'ø\'en': ('ø',),
'ø-en': ('ø',),
'ø-ene': ('ø',),
'ø-er': ('ø',),
'øda': ('øde',),
'øde': ('øde',),
'ødene': ('øde',),
'øder': ('øde',),
'ødet': ('øde',),
'ødegard': ('ødegard',),
'ødegarden': ('ødegard',),
'ødegardene': ('ødegard',),
'ødegarder': ('ødegard',),
'ødegård': ('ødegård',),
'ødegården': ('ødegård',),
'ødegårdene': ('ødegård',),
'ødegårder': ('ødegård',),
'ødeland': ('ødeland',),
'ødelanden': ('ødeland',),
'ødelandene': ('ødeland',),
'ødelander': ('ødeland',),
'ødeleggelse': ('ødeleggelse',),
'ødeleggelsen': ('ødeleggelse',),
'ødeleggelsene': ('ødeleggelse',),
'ødeleggelser': ('ødeleggelse',),
'ødeleggelseslyst': ('ødeleggelseslyst',),
'ødeleggelseslysta': ('ødeleggelseslyst',),
'ødeleggelseslysten': ('ødeleggelseslyst',),
'ødeleggelseslystene': ('ødeleggelseslyst',),
'ødeleggelseslyster': ('ødeleggelseslyst',),
'ødelegger': ('ødelegger',),
'ødeleggere': ('ødelegger',),
'ødeleggeren': ('ødelegger',),
'ødeleggerer': ('ødelegger',),
'ødeleggerne': ('ødelegger',),
'ødelegging': ('ødelegging',),
'ødelegginga': ('ødelegging',),
'ødeleggingen': ('ødelegging',),
'ødeleggingene': ('ødelegging',),
'ødelegginger': ('ødelegging',),
'ødem': ('ødem',),
'ødema': ('ødem',),
'ødemene': ('ødem',),
'ødemer': ('ødem',),
'ødemet': ('ødem',),
'ødemark': ('ødemark',),
'ødemarka': ('ødemark',),
'ødemarken': ('ødemark',),
'ødemarkene': ('ødemark',),
'ødemarker': ('ødemark',),
'ødemarkstillegg': ('ødemarkstillegg',),
'ødemarkstillegga': ('ødemarkstillegg',),
'ødemarkstilleggene': ('ødemarkstillegg',),
'ødemarkstillegget': ('ødemarkstillegg',),
'øder': ('øder',),
'ødere': ('øder',),
'øderen': ('øder',),
'øderer': ('øder',),
'øderne': ('øder',),
'ødipalkonflikt': ('ødipalkonflikt',),
'ødipalkonflikten': ('ødipalkonflikt',),
'ødipalkonfliktene': ('ødipalkonflikt',),
'ødipalkonflikter': ('ødipalkonflikt',),
'ødipuskompleks': ('ødipuskompleks',),
'ødipuskompleksa': ('ødipuskompleks',),
'ødipuskompleksene': ('ødipuskompleks',),
'ødipuskomplekser': ('ødipuskompleks',),
'ødipuskomplekset': ('ødipuskompleks',),
'ødselhet': ('ødselhet',),
'ødselheta': ('ødselhet',),
'ødselheten': ('ødselhet',),
'ødselhetene': ('ødselhet',),
'ødselheter': ('ødselhet',),
'ødsler': ('ødsler',),
'ødslere': ('ødsler',),
'ødsleren': ('ødsler',),
'ødslerer': ('ødsler',),
'ødslerne': ('ødsler',),
'øgla': ('øgle',),
'øgle': ('øgle',),
'øglen': ('øgle',),
'øglene': ('øgle',),
'øgler': ('øgle',),
'øk': ('øk',),
'øka': ('øk',),
'økene': ('øk',),
'øket': ('øk',),
'økenavn': ('økenavn',),
'økenavna': ('økenavn',),
'økenavnene': ('økenavn',),
'økenavnet': ('økenavn',),
'øking': ('øking',),
'økinga': ('øking',),
'økingen': ('øking',),
'økingene': ('øking',),
'økinger': ('øking',),
'økning': ('økning',),
'økninga': ('økning',),
'økningen': ('økning',),
'økningene': ('økning',),
'økninger': ('økning',),
'økofilosof': ('økofilosof',),
'økofilosofen': ('økofilosof',),
'økofilosofene': ('økofilosof',),
'økofilosofer': ('økofilosof',),
'økofilosofi': ('økofilosofi',),
'økofilosofien': ('økofilosofi',),
'økofilosofiene': ('økofilosofi',),
'økofilosofier': ('økofilosofi',),
'økokatastrofa': ('økokatastrofe',),
'økokatastrofe': ('økokatastrofe',),
'økokatastrofen': ('økokatastrofe',),
'økokatastrofene': ('økokatastrofe',),
'økokatastrofer': ('økokatastrofe',),
'økokrisa': ('økokrise',),
'økokrise': ('økokrise',),
'økokrisen': ('økokrise',),
'økokrisene': ('økokrise',),
'økokriser': ('økokrise',),
'økolog': ('økolog',),
'økologen': ('økolog',),
'økologene': ('økolog',),
'økologer': ('økolog',),
'økologi': ('økologi',),
'økologien': ('økologi',),
'økologiene': ('økologi',),
'økologier': ('økologi',),
'økonom': ('økonom',),
'økonomen': ('økonom',),
'økonomene': ('økonom',),
'økonomer': ('økonom',),
'økonometri': ('økonometri',),
'økonometrien': ('økonometri',),
'økonometriene': ('økonometri',),
'økonometrier': ('økonometri',),
'økonomi': ('økonomi',),
'økonomien': ('økonomi',),
'økonomiene': ('økonomi',),
'økonomier': ('økonomi',),
'økonomiflaska': ('økonomiflaske',),
'økonomiflaske': ('økonomiflaske',),
'økonomiflasken': ('økonomiflaske',),
'økonomiflaskene': ('økonomiflaske',),
'økonomiflasker': ('økonomiflaske',),
'økonomikk': ('økonomikk',),
'økonomikken': ('økonomikk',),
'økonomikkene': ('økonomikk',),
'økonomikker': ('økonomikk',),
'økonomiklassa': ('økonomiklasse',),
'økonomiklasse': ('økonomiklasse',),
'økonomiklassen': ('økonomiklasse',),
'økonomiklassene': ('økonomiklasse',),
'økonomiklasser': ('økonomiklasse',),
'økonomiløp': ('økonomiløp',),
'økonomiløpa': ('økonomiløp',),
'økonomiløpene': ('økonomiløp',),
'økonomiløpet': ('økonomiløp',),
'økonomipakka': ('økonomipakke',),
'økonomipakke': ('økonomipakke',),
'økonomipakken': ('økonomipakke',),
'økonomipakkene': ('økonomipakke',),
'økonomipakker': ('økonomipakke',),
'økopolitikk': ('økopolitikk',),
'økopolitikken': ('økopolitikk',),
'økopolitikkene': ('økopolitikk',),
'økopolitikker': ('økopolitikk',),
'økosystem': ('økosystem',),
'økosystema': ('økosystem',),
'økosystemene': ('økosystem',),
'økosystemer': ('økosystem',),
'økosystemet': ('økosystem',),
'økotype': ('økotype',),
'økotypen': ('økotype',),
'økotypene': ('økotype',),
'økotyper': ('økotype',),
'øks': ('øks',),
'øksa': ('øks',),
'øksen': ('øks',),
'øksene': ('øks',),
'økser': ('øks',),
'økseblad': ('økseblad',),
'økseblada': ('økseblad',),
'øksebladene': ('økseblad',),
'økseblader': ('økseblad',),
'øksebladet': ('økseblad',),
'økseegg': ('økseegg',),
'økseegga': ('økseegg',),
'økseeggen': ('økseegg',),
'økseeggene': ('økseegg',),
'økseegger': ('økseegg',),
'øksegg': ('øksegg',),
'øksegga': ('øksegg',),
'økseggen': ('øksegg',),
'økseggene': ('øksegg',),
'øksegger': ('øksegg',),
'øksehammar': ('øksehammar',),
'øksehammaren': ('øksehammar',),
'øksehamrene': ('øksehammar',),
'øksehamrer': ('øksehammar',),
'øksehammer': ('øksehammer',),
'øksehammere': ('øksehammer',),
'øksehammeren': ('øksehammer',),
'øksehammerer': ('øksehammer',),
'øksehammerne': ('øksehammer',),
'øksehamrene': ('øksehammer',),
'øksehamrer': ('øksehammer',),
'øksehoda': ('øksehode',),
'øksehode': ('øksehode',),
'øksehodene': ('øksehode',),
'øksehoder': ('øksehode',),
'øksehodet': ('øksehode',),
'øksekinn': ('øksekinn',),
'øksekinna': ('øksekinn',),
'øksekinnene': ('øksekinn',),
'øksekinner': ('øksekinn',),
'øksekinnet': ('øksekinn',),
'øksel': ('øksel',),
'økselet': ('øksel',),
'øksla': ('øksel',),
'økslene': ('øksel',),
'øksler': ('øksel',),
'økslet': ('øksel',),
'økseskaft': ('økseskaft',),
'økseskafta': ('økseskaft',),
'økseskaftene': ('økseskaft',),
'økseskafter': ('økseskaft',),
'økseskaftet': ('økseskaft',),
'økt': ('økt',),
'økta': ('økt',),
'økten': ('økt',),
'øktene': ('økt',),
'økter': ('økt',),
'økumen': ('økumen',),
'økumenen': ('økumen',),
'økumenene': ('økumen',),
'økumener': ('økumen',),
'økumena': ('økumene',),
'økumene': ('økumene',),
'økumenene': ('økumene',),
'økumener': ('økumene',),
'økumenet': ('økumene',),
'økumenikk': ('økumenikk',),
'økumenikken': ('økumenikk',),
'økumenikkene': ('økumenikk',),
'økumenikker': ('økumenikk',),
'øl': ('øl',),
'ølen': ('øl',),
'ølene': ('øl',),
'øler': ('øl',),
'øl': ('øl',),
'ølen': ('øl',),
'ølene': ('øl',),
'øl': ('øl',),
'øla': ('øl',),
'ølene': ('øl',),
'ølet': ('øl',),
'ølbevilling': ('ølbevilling',),
'ølbevillingen': ('ølbevilling',),
'ølbevillingene': ('ølbevilling',),
'ølbevillinger': ('ølbevilling',),
'ølbolle': ('ølbolle',),
'ølbollen': ('ølbolle',),
'ølbollene': ('ølbolle',),
'ølboller': ('ølbolle',),
'ølbrikka': ('ølbrikke',),
'ølbrikke': ('ølbrikke',),
'ølbrikken': ('ølbrikke',),
'ølbrikkene': ('ølbrikke',),
'ølbrikker': ('ølbrikke',),
'ølbrygger': ('ølbrygger',),
'ølbryggere': ('ølbrygger',),
'ølbryggeren': ('ølbrygger',),
'ølbryggerer': ('ølbrygger',),
'ølbryggerne': ('ølbrygger',),
'ølbryggeri': ('ølbryggeri',),
'ølbryggeria': ('ølbryggeri',),
'ølbryggeriene': ('ølbryggeri',),
'ølbryggerier': ('ølbryggeri',),
'ølbryggeriet': ('ølbryggeri',),
'ølbrygging': ('ølbrygging',),
'ølbrygginga': ('ølbrygging',),
'ølbryggingen': ('ølbrygging',),
'ølbryggingene': ('ølbrygging',),
'ølbrygginger': ('ølbrygging',),
'ølebrød': ('ølebrød',),
'ølebrøda': ('ølebrød',),
'ølebrødene': ('ølebrød',),
'ølebrødet': ('ølebrød',),
'ølending': ('ølending',),
'ølendingen': ('ølending',),
'ølendingene': ('ølending',),
'ølendinger': ('ølending',),
'ølfat': ('ølfat',),
'ølfata': ('ølfat',),
'ølfatene': ('ølfat',),
'ølfater': ('ølfat',),
'ølfatet': ('ølfat',),
'ølflaska': ('ølflaske',),
'ølflaske': ('ølflaske',),
'ølflasken': ('ølflaske',),
'ølflaskene': ('ølflaske',),
'ølflasker': ('ølflaske',),
'ølgjær': ('ølgjær',),
'ølgjæren': ('ølgjær',),
'ølgjærene': ('ølgjær',),
'ølgjærer': ('ølgjær',),
'ølglas': ('ølglas',),
'ølglasa': ('ølglas',),
'ølglasene': ('ølglas',),
'ølglaset': ('ølglas',),
'ølglass': ('ølglass',),
'ølglassa': ('ølglass',),
'ølglassene': ('ølglass',),
'ølglasset': ('ølglass',),
'ølhøna': ('ølhøne',),
'ølhøne': ('ølhøne',),
'ølhønen': ('ølhøne',),
'ølhønene': ('ølhøne',),
'ølhøner': ('ølhøne',),
'ølkall': ('ølkall',),
'ølkallen': ('ølkall',),
'ølkallene': ('ølkall',),
'ølkaller': ('ølkall',),
'ølkjører': ('ølkjører',),
'ølkjørere': ('ølkjører',),
'ølkjøreren': ('ølkjører',),
'ølkjørerer': ('ølkjører',),
'ølkjørerne': ('ølkjører',),
'ølost': ('ølost',),
'ølosten': ('ølost',),
'ølostene': ('ølost',),
'øloster': ('ølost',),
'ølrett': ('ølrett',),
'ølretten': ('ølrett',),
'ølrettene': ('ølrett',),
'ølretter': ('ølrett',),
'ølrøyk': ('ølrøyk',),
'ølrøyken': ('ølrøyk',),
'ølrøykene': ('ølrøyk',),
'ølrøyker': ('ølrøyk',),
'ømhet': ('ømhet',),
'ømheta': ('ømhet',),
'ømheten': ('ømhet',),
'ømhetene': ('ømhet',),
'ømheter': ('ømhet',),
'ønska': ('ønske',),
'ønske': ('ønske',),
'ønskene': ('ønske',),
'ønsker': ('ønske',),
'ønsket': ('ønske',),
'ønskedrøm': ('ønskedrøm',),
'ønskedrømmen': ('ønskedrøm',),
'ønskedrømmene': ('ønskedrøm',),
'ønskedrømmer': ('ønskedrøm',),
'ønskekonsert': ('ønskekonsert',),
'ønskekonserten': ('ønskekonsert',),
'ønskekonsertene': ('ønskekonsert',),
'ønskekonserter': ('ønskekonsert',),
'ønskekvist': ('ønskekvist',),
'ønskekvisten': ('ønskekvist',),
'ønskekvistene': ('ønskekvist',),
'ønskekvister': ('ønskekvist',),
'ønskelista': ('ønskeliste',),
'ønskeliste': ('ønskeliste',),
'ønskelisten': ('ønskeliste',),
'ønskelistene': ('ønskeliste',),
'ønskelister': ('ønskeliste',),
'ønskemål': ('ønskemål',),
'ønskemåla': ('ønskemål',),
'ønskemålene': ('ønskemål',),
'ønskemålet': ('ønskemål',),
'ønskeplata': ('ønskeplate',),
'ønskeplate': ('ønskeplate',),
'ønskeplaten': ('ønskeplate',),
'ønskeplatene': ('ønskeplate',),
'ønskeplater': ('ønskeplate',),
'ønsketenking': ('ønsketenking',),
'ønsketenkinga': ('ønsketenking',),
'ønsketenkingen': ('ønsketenking',),
'ønsketenkingene': ('ønsketenking',),
'ønsketenkinger': ('ønsketenking',),
'ønsketenkning': ('ønsketenkning',),
'ønsketenkninga': ('ønsketenkning',),
'ønsketenkningen': ('ønsketenkning',),
'ønsketenkningene': ('ønsketenkning',),
'ønsketenkninger': ('ønsketenkning',),
'øra': ('øre',),
'øre': ('øre',),
'ørene': ('øre',),
'ører': ('øre',),
'øret': ('øre',),
'ørebein': ('ørebein',),
'ørebeina': ('ørebein',),
'ørebeinene': ('ørebein',),
'ørebeinet': ('ørebein',),
'øreben': ('øreben',),
'ørebena': ('øreben',),
'ørebenene': ('øreben',),
'ørebenet': ('øreben',),
'ørebeskytter': ('ørebeskytter',),
'ørebeskyttere': ('ørebeskytter',),
'ørebeskytteren': ('ørebeskytter',),
'ørebeskytterer': ('ørebeskytter',),
'ørebeskytterne': ('ørebeskytter',),
'ørebetennelse': ('ørebetennelse',),
'ørebetennelsen': ('ørebetennelse',),
'ørebetennelsene': ('ørebetennelse',),
'ørebetennelser': ('ørebetennelse',),
'øreblad': ('øreblad',),
'øreblada': ('øreblad',),
'ørebladene': ('øreblad',),
'øreblader': ('øreblad',),
'ørebladet': ('øreblad',),
'øreblåsing': ('øreblåsing',),
'øreblåsinga': ('øreblåsing',),
'øreblåsingen': ('øreblåsing',),
'øreblåsingene': ('øreblåsing',),
'øreblåsinger': ('øreblåsing',),
'ørebrusk': ('ørebrusk',),
'ørebrusken': ('ørebrusk',),
'ørebruskene': ('ørebrusk',),
'ørebrusker': ('ørebrusk',),
'øredobb': ('øredobb',),
'øredobben': ('øredobb',),
'øredobbene': ('øredobb',),
'øredobber': ('øredobb',),
'øredobba': ('øredobbe',),
'øredobbe': ('øredobbe',),
'øredobben': ('øredobbe',),
'øredobbene': ('øredobbe',),
'øredobber': ('øredobbe',),
'ørefik': ('ørefik',),
'ørefiken': ('ørefik',),
'ørefikene': ('ørefik',),
'ørefiker': ('ørefik',),
'øreflipp': ('øreflipp',),
'øreflippen': ('øreflipp',),
'øreflippene': ('øreflipp',),
'øreflipper': ('øreflipp',),
'øreflod': ('øreflod',),
'ørefloden': ('øreflod',),
'øreflodene': ('øreflod',),
'ørefloder': ('øreflod',),
'øregang': ('øregang',),
'øregangen': ('øregang',),
'øregangene': ('øregang',),
'øreganger': ('øregang',),
'ørehola': ('ørehole',),
'ørehole': ('ørehole',),
'øreholen': ('ørehole',),
'øreholene': ('ørehole',),
'øreholer': ('ørehole',),
'ørehula': ('ørehule',),
'ørehule': ('ørehule',),
'ørehulen': ('ørehule',),
'ørehulene': ('ørehule',),
'ørehuler': ('ørehule',),
'øreklaff': ('øreklaff',),
'øreklaffen': ('øreklaff',),
'øreklaffene': ('øreklaff',),
'øreklaffer': ('øreklaff',),
'øreklips': ('øreklips',),
'øreklipsa': ('øreklips',),
'øreklipsen': ('øreklips',),
'øreklipsene': ('øreklips',),
'øreklipset': ('øreklips',),
'ørekyt': ('ørekyt',),
'ørekyta': ('ørekyt',),
'ørekyten': ('ørekyt',),
'ørekytene': ('ørekyt',),
'ørekyter': ('ørekyt',),
'ørekyta': ('ørekyte',),
'ørekyte': ('ørekyte',),
'ørekyten': ('ørekyte',),
'ørekytene': ('ørekyte',),
'ørekyter': ('ørekyte',),
'ørelapp': ('ørelapp',),
'ørelappen': ('ørelapp',),
'ørelappene': ('ørelapp',),
'ørelapper': ('ørelapp',),
'ørelappstol': ('ørelappstol',),
'ørelappstolen': ('ørelappstol',),
'ørelappstolene': ('ørelappstol',),
'ørelappstoler': ('ørelappstol',),
'øremerka': ('øremerke',),
'øremerke': ('øremerke',),
'øremerkene': ('øremerke',),
'øremerker': ('øremerke',),
'øremerket': ('øremerke',),
'øremusling': ('øremusling',),
'øremuslingen': ('øremusling',),
'øremuslingene': ('øremusling',),
'øremuslinger': ('øremusling',),
'ørenslyd': ('ørenslyd',),
'ørenslyst': ('ørenslyst',),
'ørenslysta': ('ørenslyst',),
'ørenslysten': ('ørenslyst',),
'ørenslystene': ('ørenslyst',),
'ørenslyster': ('ørenslyst',),
'ørepil': ('ørepil',),
'ørepila': ('ørepil',),
'ørepilen': ('ørepil',),
'ørepilene': ('ørepil',),
'ørepiler': ('ørepil',),
'ørepina': ('ørepine',),
'ørepine': ('ørepine',),
'ørepinen': ('ørepine',),
'ørepinene': ('ørepine',),
'ørepiner': ('ørepine',),
'ørering': ('ørering',),
'øreringen': ('ørering',),
'øreringene': ('ørering',),
'øreringer': ('ørering',),
'øresekk': ('øresekk',),
'øresekken': ('øresekk',),
'øresekkene': ('øresekk',),
'øresekker': ('øresekk',),
'øresel': ('øresel',),
'øreselen': ('øresel',),
'øreselene': ('øresel',),
'øreseler': ('øresel',),
'øresmykka': ('øresmykke',),
'øresmykke': ('øresmykke',),
'øresmykkene': ('øresmykke',),
'øresmykker': ('øresmykke',),
'øresmykket': ('øresmykke',),
'øresnipp': ('øresnipp',),
'øresnippen': ('øresnipp',),
'øresnippene': ('øresnipp',),
'øresnipper': ('øresnipp',),
'ørespyttkjertel': ('ørespyttkjertel',),
'ørespyttkjertelen': ('ørespyttkjertel',),
'ørespyttkjertlene': ('ørespyttkjertel',),
'ørespyttkjertler': ('ørespyttkjertel',),
'øresus': ('øresus',),
'øresusa': ('øresus',),
'øresusen': ('øresus',),
'øresusene': ('øresus',),
'øresuset': ('øresus',),
'øresusing': ('øresusing',),
'øresusinga': ('øresusing',),
'øresusingen': ('øresusing',),
'øresusingene': ('øresusing',),
'øresusinger': ('øresusing',),
'øretrompet': ('øretrompet',),
'øretrompeten': ('øretrompet',),
'øretrompetene': ('øretrompet',),
'øretrompeter': ('øretrompet',),
'ørevarmer': ('ørevarmer',),
'ørevarmere': ('ørevarmer',),
'ørevarmeren': ('ørevarmer',),
'ørevarmerer': ('ørevarmer',),
'ørevarmerne': ('ørevarmer',),
'øreverk': ('øreverk',),
'øreverken': ('øreverk',),
'øreverkene': ('øreverk',),
'øreverker': ('øreverk',),
'ørevier': ('ørevier',),
'øreviere': ('ørevier',),
'ørevieren': ('ørevier',),
'ørevierer': ('ørevier',),
'ørevierne': ('ørevier',),
'ørevoks': ('ørevoks',),
'ørevoksa': ('ørevoks',),
'ørevoksen': ('ørevoks',),
'ørevoksene': ('ørevoks',),
'ørevokser': ('ørevoks',),
'ørevokset': ('ørevoks',),
'ørken': ('ørken',),
'ørkenen': ('ørken',),
'ørkenene': ('ørken',),
'ørkener': ('ørken',),
'ørkengaupa': ('ørkengaupe',),
'ørkengaupe': ('ørkengaupe',),
'ørkengaupen': ('ørkengaupe',),
'ørkengaupene': ('ørkengaupe',),
'ørkengauper': ('ørkengaupe',),
'ørkenlerka': ('ørkenlerke',),
'ørkenlerke': ('ørkenlerke',),
'ørkenlerken': ('ørkenlerke',),
'ørkenlerkene': ('ørkenlerke',),
'ørkenlerker': ('ørkenlerke',),
'ørkenløper': ('ørkenløper',),
'ørkenløpere': ('ørkenløper',),
'ørkenløperen': ('ørkenløper',),
'ørkenløperer': ('ørkenløper',),
'ørkenløperne': ('ørkenløper',),
'ørkenrev': ('ørkenrev',),
'ørkenreven': ('ørkenrev',),
'ørkenrevene': ('ørkenrev',),
'ørkenrever': ('ørkenrev',),
'ørkenrotta': ('ørkenrotte',),
'ørkenrotte': ('ørkenrotte',),
'ørkenrotten': ('ørkenrotte',),
'ørkenrottene': ('ørkenrotte',),
'ørkenrotter': ('ørkenrotte',),
'ørkenspredning': ('ørkenspredning',),
'ørkenspredninga': ('ørkenspredning',),
'ørkenspredningen': ('ørkenspredning',),
'ørkenspredningene': ('ørkenspredning',),
'ørkenspredninger': ('ørkenspredning',),
'ørkenvandring': ('ørkenvandring',),
'ørkenvandringa': ('ørkenvandring',),
'ørkenvandringen': ('ørkenvandring',),
'ørkenvandringene': ('ørkenvandring',),
'ørkenvandringer': ('ørkenvandring',),
'ørn': ('ørn',),
'ørna': ('ørn',),
'ørnen': ('ørn',),
'ørnene': ('ørn',),
'ørner': ('ørn',),
'ørneblikk': ('ørneblikk',),
'ørneblikka': ('ørneblikk',),
'ørneblikkene': ('ørneblikk',),
'ørneblikket': ('ørneblikk',),
'ørnebregna': ('ørnebregne',),
'ørnebregne': ('ørnebregne',),
'ørnebregnen': ('ørnebregne',),
'ørnebregnene': ('ørnebregne',),
'ørnebregner': ('ørnebregne',),
'ørnenesa': ('ørnenese',),
'ørnenese': ('ørnenese',),
'ørnenesen': ('ørnenese',),
'ørnenesene': ('ørnenese',),
'ørneneser': ('ørnenese',),
'ørret': ('ørret',),
'ørreten': ('ørret',),
'ørretene': ('ørret',),
'ørreter': ('ørret',),
'ørska': ('ørske',),
'ørske': ('ørske',),
'ørsken': ('ørske',),
'ørskene': ('ørske',),
'ørsker': ('ørske',),
'ørsted': ('ørsted',),
'ørsteden': ('ørsted',),
'ørstedene': ('ørsted',),
'ørtug': ('ørtug',),
'ørtugen': ('ørtug',),
'ørtugene': ('ørtug',),
'ørtuger': ('ørtug',),
'øs': ('øs',),
'øsa': ('øs',),
'øsene': ('øs',),
'øset': ('øs',),
'øsa': ('øse',),
'øse': ('øse',),
'øsene': ('øse',),
'øser': ('øse',),
'øset': ('øse',),
'øsa': ('øse',),
'øse': ('øse',),
'øsen': ('øse',),
'øsene': ('øse',),
'øser': ('øse',),
'øsa': ('øse',),
'øse': ('øse',),
'øsen': ('øse',),
'øsene': ('øse',),
'øser': ('øse',),
'øsefat': ('øsefat',),
'øsefata': ('øsefat',),
'øsefatene': ('øsefat',),
'øsefater': ('øsefat',),
'øsefatet': ('øsefat',),
'øsekar': ('øsekar',),
'øsekara': ('øsekar',),
'øsekarene': ('øsekar',),
'øsekaret': ('øsekar',),
'øskja': ('øskje',),
'øskje': ('øskje',),
'øskjen': ('øskje',),
'øskjene': ('øskje',),
'øskjer': ('øskje',),
'øsregn': ('øsregn',),
'øsregna': ('øsregn',),
'øsregnene': ('øsregn',),
'øsregnet': ('øsregn',),
'øst': ('øst',),
'østasiat': ('østasiat',),
'østasiaten': ('østasiat',),
'østasiatene': ('østasiat',),
'østasiater': ('østasiat',),
'østavind': ('østavind',),
'østavinden': ('østavind',),
'østavindene': ('østavind',),
'østavinder': ('østavind',),
'østavær': ('østavær',),
'østaværa': ('østavær',),
'østaværene': ('østavær',),
'østaværet': ('østavær',),
'østblokk': ('østblokk',),
'østblokka': ('østblokk',),
'østblokken': ('østblokk',),
'østblokkene': ('østblokk',),
'østblokker': ('østblokk',),
'østblokkland': ('østblokkland',),
'østblokklanda': ('østblokkland',),
'østblokklandene': ('østblokkland',),
'østblokklandet': ('østblokkland',),
'østerdalslua': ('østerdalslue',),
'østerdalslue': ('østerdalslue',),
'østerdalsluen': ('østerdalslue',),
'østerdalsluene': ('østerdalslue',),
'østerdalsluer': ('østerdalslue',),
'østerdalsluva': ('østerdalsluve',),
'østerdalsluve': ('østerdalsluve',),
'østerdalsluven': ('østerdalsluve',),
'østerdalsluvene': ('østerdalsluve',),
'østerdalsluver': ('østerdalsluve',),
'østerdalssokk': ('østerdalssokk',),
'østerdalssokken': ('østerdalssokk',),
'østerdalssokkene': ('østerdalssokk',),
'østerdalssokker': ('østerdalssokk',),
'østerdøl': ('østerdøl',),
'østerdølen': ('østerdøl',),
'østerdølene': ('østerdøl',),
'østerdøler': ('østerdøl',),
'østerland': ('østerland',),
'østerlanda': ('østerland',),
'østerlandene': ('østerland',),
'østerlandet': ('østerland',),
'østerled': ('østerled',),
'østerleden': ('østerled',),
'østerledene': ('østerled',),
'østerleder': ('østerled',),
'østerlending': ('østerlending',),
'østerlendingen': ('østerlending',),
'østerlendingene': ('østerlending',),
'østerlendinger': ('østerlending',),
'østerriker': ('østerriker',),
'østerrikere': ('østerriker',),
'østerrikeren': ('østerriker',),
'østerrikerer': ('østerriker',),
'østerrikerne': ('østerriker',),
'østers': ('østers',),
'østersen': ('østers',),
'østersene': ('østers',),
'østerser': ('østers',),
'østersfarm': ('østersfarm',),
'østersfarmen': ('østersfarm',),
'østersfarmene': ('østersfarm',),
'østersfarmer': ('østersfarm',),
'østersjøland': ('østersjøland',),
'østersjølanda': ('østersjøland',),
'østersjølandene': ('østersjøland',),
'østersjølandet': ('østersjøland',),
'østersjøstat': ('østersjøstat',),
'østersjøstaten': ('østersjøstat',),
'østersjøstatene': ('østersjøstat',),
'østersjøstater': ('østersjøstat',),
'østeuropeer': ('østeuropeer',),
'østeuropeere': ('østeuropeer',),
'østeuropeeren': ('østeuropeer',),
'østeuropeerer': ('østeuropeer',),
'østeuropeerne': ('østeuropeer',),
'østfolding': ('østfolding',),
'østfoldingen': ('østfolding',),
'østfoldingene': ('østfolding',),
'østfoldinger': ('østfolding',),
'østfront': ('østfront',),
'østfronten': ('østfront',),
'østfrontene': ('østfront',),
'østfronter': ('østfront',),
'østgoter': ('østgoter',),
'østgotere': ('østgoter',),
'østgoteren': ('østgoter',),
'østgoterer': ('østgoter',),
'østgoterne': ('østgoter',),
'østhandel': ('østhandel',),
'østhandelen': ('østhandel',),
'østhandlene': ('østhandel',),
'østhandler': ('østhandel',),
'østhimlene': ('østhimmel',),
'østhimler': ('østhimmel',),
'østhimmel': ('østhimmel',),
'østhimmelen': ('østhimmel',),
'østkant': ('østkant',),
'østkanten': ('østkant',),
'østkantene': ('østkant',),
'østkanter': ('østkant',),
'østkyst': ('østkyst',),
'østkysten': ('østkyst',),
'østkystene': ('østkyst',),
'østkyster': ('østkyst',),
'østlandsk': ('østlandsk',),
'østlandsken': ('østlandsk',),
'østlandskene': ('østlandsk',),
'østlandsker': ('østlandsk',),
'østlandsmål': ('østlandsmål',),
'østlandsmåla': ('østlandsmål',),
'østlandsmålene': ('østlandsmål',),
'østlandsmålet': ('østlandsmål',),
'østlending': ('østlending',),
'østlendingen': ('østlending',),
'østlendingene': ('østlending',),
'østlendinger': ('østlending',),
'østmark': ('østmark',),
'østmarka': ('østmark',),
'østmarken': ('østmark',),
'østmarkene': ('østmark',),
'østmarker': ('østmark',),
'østnorsk': ('østnorsk',),
'østnorsken': ('østnorsk',),
'østnorskene': ('østnorsk',),
'østnorsker': ('østnorsk',),
'østrogen': ('østrogen',),
'østrogena': ('østrogen',),
'østrogenene': ('østrogen',),
'østrogener': ('østrogen',),
'østrogenet': ('østrogen',),
'østron': ('østron',),
'østrona': ('østron',),
'østronene': ('østron',),
'østroner': ('østron',),
'østronet': ('østron',),
'østrus': ('østrus',),
'østrusen': ('østrus',),
'østrusene': ('østrus',),
'østruser': ('østrus',),
'østsida': ('østside',),
'østside': ('østside',),
'østsiden': ('østside',),
'østsidene': ('østside',),
'østsider': ('østside',),
'østtysker': ('østtysker',),
'østtyskere': ('østtysker',),
'østtyskeren': ('østtysker',),
'østtyskerer': ('østtysker',),
'østtyskerne': ('østtysker',),
'øvelse': ('øvelse',),
'øvelsen': ('øvelse',),
'øvelsene': ('øvelse',),
'øvelser': ('øvelse',),
'øvelsesflyging': ('øvelsesflyging',),
'øvelsesflyginga': ('øvelsesflyging',),
'øvelsesflygingen': ('øvelsesflyging',),
'øvelsesflygingene': ('øvelsesflyging',),
'øvelsesflyginger': ('øvelsesflyging',),
'øvelsesflying': ('øvelsesflying',),
'øvelsesflyinga': ('øvelsesflying',),
'øvelsesflyingen': ('øvelsesflying',),
'øvelsesflyingene': ('øvelsesflying',),
'øvelsesflyinger': ('øvelsesflying',),
'øvelseskjøring': ('øvelseskjøring',),
'øvelseskjøringa': ('øvelseskjøring',),
'øvelseskjøringen': ('øvelseskjøring',),
'øvelseskjøringene': ('øvelseskjøring',),
'øvelseskjøringer': ('øvelseskjøring',),
'øvelsesskyting': ('øvelsesskyting',),
'øvelsesskytinga': ('øvelsesskyting',),
'øvelsesskytingen': ('øvelsesskyting',),
'øvelsesskytingene': ('øvelsesskyting',),
'øvelsesskytinger': ('øvelsesskyting',),
'øversteprest': ('øversteprest',),
'øverstepresten': ('øversteprest',),
'øversteprestene': ('øversteprest',),
'øversteprester': ('øversteprest',),
'øverstkommanderende': ('øverstkommanderende',),
'øverstkommanderenden': ('øverstkommanderende',),
'øverstkommanderendene': ('øverstkommanderende',),
'øverstkommanderender': ('øverstkommanderende',),
'øving': ('øving',),
'øvinga': ('øving',),
'øvingen': ('øving',),
'øvingene': ('øving',),
'øvinger': ('øving',),
'øvingsavdeling': ('øvingsavdeling',),
'øvingsavdelinga': ('øvingsavdeling',),
'øvingsavdelingen': ('øvingsavdeling',),
'øvingsavdelingene': ('øvingsavdeling',),
'øvingsavdelinger': ('øvingsavdeling',),
'øvingsflyging': ('øvingsflyging',),
'øvingsflyginga': ('øvingsflyging',),
'øvingsflygingen': ('øvingsflyging',),
'øvingsflygingene': ('øvingsflyging',),
'øvingsflyginger': ('øvingsflyging',),
'øvingsflying': ('øvingsflying',),
'øvingsflyinga': ('øvingsflying',),
'øvingsflyingen': ('øvingsflying',),
'øvingsflyingene': ('øvingsflying',),
'øvingsflyinger': ('øvingsflying',),
'øvingskjøring': ('øvingskjøring',),
'øvingskjøringa': ('øvingskjøring',),
'øvingskjøringen': ('øvingskjøring',),
'øvingskjøringene': ('øvingskjøring',),
'øvingskjøringer': ('øvingskjøring',),
'øvingslærer': ('øvingslærer',),
'øvingslærere': ('øvingslærer',),
'øvingslæreren': ('øvingslærer',),
'øvingslærerer': ('øvingslærer',),
'øvingslærerne': ('øvingslærer',),
'øvingsskyting': ('øvingsskyting',),
'øvingsskytinga': ('øvingsskyting',),
'øvingsskytingen': ('øvingsskyting',),
'øvingsskytingene': ('øvingsskyting',),
'øvingsskytinger': ('øvingsskyting',),
'øvrighet': ('øvrighet',),
'øvrigheta': ('øvrighet',),
'øvrigheten': ('øvrighet',),
'øvrighetene': ('øvrighet',),
'øvrigheter': ('øvrighet',),
'øvrighetsperson': ('øvrighetsperson',),
'øvrighetspersonen': ('øvrighetsperson',),
'øvrighetspersonene': ('øvrighetsperson',),
'øvrighetspersoner': ('øvrighetsperson',),
'øy': ('øy',),
'øya': ('øy',),
'øyen': ('øy',),
'øyene': ('øy',),
'øyer': ('øy',),
'øyboer': ('øyboer',),
'øyboere': ('øyboer',),
'øyboeren': ('øyboer',),
'øyboerer': ('øyboer',),
'øyboerne': ('øyboer',),
'øybu': ('øybu',),
'øybuen': ('øybu',),
'øybuene': ('øybu',),
'øybuer': ('øybu',),
'øybuer': ('øybuer',),
'øybuere': ('øybuer',),
'øybueren': ('øybuer',),
'øybuerer': ('øybuer',),
'øybuerne': ('øybuer',),
'øydegard': ('øydegard',),
'øydegarden': ('øydegard',),
'øydegardene': ('øydegard',),
'øydegarder': ('øydegard',),
'øydelegger': ('øydelegger',),
'øydeleggere': ('øydelegger',),
'øydeleggeren': ('øydelegger',),
'øydeleggerer': ('øydelegger',),
'øydeleggerne': ('øydelegger',),
'øydelegging': ('øydelegging',),
'øydelegginga': ('øydelegging',),
'øydeleggingen': ('øydelegging',),
'øydeleggingene': ('øydelegging',),
'øydelegginger': ('øydelegging',),
'øydemark': ('øydemark',),
'øydemarka': ('øydemark',),
'øydemarken': ('øydemark',),
'øydemarkene': ('øydemark',),
'øydemarker': ('øydemark',),
'øydemarkstillegg': ('øydemarkstillegg',),
'øydemarkstillegga': ('øydemarkstillegg',),
'øydemarkstilleggene': ('øydemarkstillegg',),
'øydemarkstillegget': ('øydemarkstillegg',),
'øyder': ('øyder',),
'øydere': ('øyder',),
'øyderen': ('øyder',),
'øyderer': ('øyder',),
'øyderne': ('øyder',),
'øya': ('øye',),
'øye': ('øye',),
'øyene': ('øye',),
'øyer': ('øye',),
'øyet': ('øye',),
'øyne': ('øye',),
'øynene': ('øye',),
'øyeblikk': ('øyeblikk',),
'øyeblikka': ('øyeblikk',),
'øyeblikkene': ('øyeblikk',),
'øyeblikket': ('øyeblikk',),
'øyeblikksbilda': ('øyeblikksbilde',),
'øyeblikksbilde': ('øyeblikksbilde',),
'øyeblikksbildene': ('øyeblikksbilde',),
'øyeblikksbilder': ('øyeblikksbilde',),
'øyeblikksbildet': ('øyeblikksbilde',),
'øyebryn': ('øyebryn',),
'øyebryna': ('øyebryn',),
'øyebrynene': ('øyebryn',),
'øyebrynet': ('øyebryn',),
'øyedråpene': ('øyedråper',),
'øyedråper': ('øyedråper',),
'øyeepla': ('øyeeple',),
'øyeeple': ('øyeeple',),
'øyeeplene': ('øyeeple',),
'øyeepler': ('øyeeple',),
'øyeeplet': ('øyeeple',),
'øyefarge': ('øyefarge',),
'øyefargen': ('øyefarge',),
'øyefargene': ('øyefarge',),
'øyefarger': ('øyefarge',),
'øyeglas': ('øyeglas',),
'øyeglasa': ('øyeglas',),
'øyeglasene': ('øyeglas',),
'øyeglaset': ('øyeglas',),
'øyeglass': ('øyeglass',),
'øyeglassa': ('øyeglass',),
'øyeglassene': ('øyeglass',),
'øyeglasset': ('øyeglass',),
'øyehår': ('øyehår',),
'øyehåra': ('øyehår',),
'øyehårene': ('øyehår',),
'øyehåret': ('øyehår',),
'øyekast': ('øyekast',),
'øyekasta': ('øyekast',),
'øyekastene': ('øyekast',),
'øyekastet': ('øyekast',),
'øyekatarr': ('øyekatarr',),
'øyekatarren': ('øyekatarr',),
'øyekatarrene': ('øyekatarr',),
'øyekatarrer': ('øyekatarr',),
'øyekontakt': ('øyekontakt',),
'øyekontakten': ('øyekontakt',),
'øyekontaktene': ('øyekontakt',),
'øyekontakter': ('øyekontakt',),
'øyekrik': ('øyekrik',),
'øyekriken': ('øyekrik',),
'øyekrikene': ('øyekrik',),
'øyekriker': ('øyekrik',),
'øyekrok': ('øyekrok',),
'øyekroken': ('øyekrok',),
'øyekrokene': ('øyekrok',),
'øyekroker': ('øyekrok',),
'øyelege': ('øyelege',),
'øyelegen': ('øyelege',),
'øyelegene': ('øyelege',),
'øyeleger': ('øyelege',),
'øyelokk': ('øyelokk',),
'øyelokka': ('øyelokk',),
'øyelokkene': ('øyelokk',),
'øyelokket': ('øyelokk',),
'øyemed': ('øyemed',),
'øyemeda': ('øyemed',),
'øyemedene': ('øyemed',),
'øyemedet': ('øyemed',),
'øyemål': ('øyemål',),
'øyemåla': ('øyemål',),
'øyemålene': ('øyemål',),
'øyemålet': ('øyemål',),
'øyenbryn': ('øyenbryn',),
'øyenbryna': ('øyenbryn',),
'øyenbrynene': ('øyenbryn',),
'øyenbrynet': ('øyenbryn',),
'øyendråpene': ('øyendråper',),
'øyendråper': ('øyendråper',),
'øyenfarge': ('øyenfarge',),
'øyenfargen': ('øyenfarge',),
'øyenfargene': ('øyenfarge',),
'øyenfarger': ('øyenfarge',),
'øyenhår': ('øyenhår',),
'øyenhåra': ('øyenhår',),
'øyenhårene': ('øyenhår',),
'øyenhåret': ('øyenhår',),
'øyenlokk': ('øyenlokk',),
'øyenlokka': ('øyenlokk',),
'øyenlokkene': ('øyenlokk',),
'øyenlokket': ('øyenlokk',),
'øyensalva': ('øyensalve',),
'øyensalve': ('øyensalve',),
'øyensalven': ('øyensalve',),
'øyensalvene': ('øyensalve',),
'øyensalver': ('øyensalve',),
'øyenskygge': ('øyenskygge',),
'øyenskyggen': ('øyenskygge',),
'øyenskyggene': ('øyenskygge',),
'øyenskygger': ('øyenskygge',),
'øyenslyst': ('øyenslyst',),
'øyenslysta': ('øyenslyst',),
'øyenslysten': ('øyenslyst',),
'øyenslystene': ('øyenslyst',),
'øyenslyster': ('øyenslyst',),
'øyenstein': ('øyenstein',),
'øyensteinen': ('øyenstein',),
'øyensteinene': ('øyenstein',),
'øyensteiner': ('øyenstein',),
'øyenstein': ('øyenstein',),
'øyensteinen': ('øyenstein',),
'øyensteinene': ('øyenstein',),
'øyensteiner': ('øyenstein',),
'øyensten': ('øyensten',),
'øyenstenen': ('øyensten',),
'øyenstenene': ('øyensten',),
'øyenstener': ('øyensten',),
'øyensverta': ('øyensverte',),
'øyensverte': ('øyensverte',),
'øyensverten': ('øyensverte',),
'øyensvertene': ('øyensverte',),
'øyensverter': ('øyensverte',),
'øyentjener': ('øyentjener',),
'øyentjenere': ('øyentjener',),
'øyentjeneren': ('øyentjener',),
'øyentjenerer': ('øyentjener',),
'øyentjenerne': ('øyentjener',),
'øyentjeneri': ('øyentjeneri',),
'øyentjeneria': ('øyentjeneri',),
'øyentjeneriene': ('øyentjeneri',),
'øyentjenerier': ('øyentjeneri',),
'øyentjeneriet': ('øyentjeneri',),
'øyentrøst': ('øyentrøst',),
'øyentrøsta': ('øyentrøst',),
'øyentrøsten': ('øyentrøst',),
'øyentrøstene': ('øyentrøst',),
'øyentrøster': ('øyentrøst',),
'øyenvipp': ('øyenvipp',),
'øyenvippen': ('øyenvipp',),
'øyenvippene': ('øyenvipp',),
'øyenvipper': ('øyenvipp',),
'øyenvippe': ('øyenvippe',),
'øyenvippen': ('øyenvippe',),
'øyenvippene': ('øyenvippe',),
'øyenvipper': ('øyenvippe',),
'øyenvitna': ('øyenvitne',),
'øyenvitne': ('øyenvitne',),
'øyenvitnene': ('øyenvitne',),
'øyenvitner': ('øyenvitne',),
'øyenvitnet': ('øyenvitne',),
'øyerim': ('øyerim',),
'øyerima': ('øyerim',),
'øyerimene': ('øyerim',),
'øyerimet': ('øyerim',),
'øyesalva': ('øyesalve',),
'øyesalve': ('øyesalve',),
'øyesalven': ('øyesalve',),
'øyesalvene': ('øyesalve',),
'øyesalver': ('øyesalve',),
'øyesjukdom': ('øyesjukdom',),
'øyesjukdommen': ('øyesjukdom',),
'øyesjukdommene': ('øyesjukdom',),
'øyesjukdommer': ('øyesjukdom',),
'øyeskrue': ('øyeskrue',),
'øyeskruen': ('øyeskrue',),
'øyeskruene': ('øyeskrue',),
'øyeskruer': ('øyeskrue',),
'øyeskruve': ('øyeskruve',),
'øyeskruven': ('øyeskruve',),
'øyeskruvene': ('øyeskruve',),
'øyeskruver': ('øyeskruve',),
'øyeskygge': ('øyeskygge',),
'øyeskyggen': ('øyeskygge',),
'øyeskyggene': ('øyeskygge',),
'øyeskygger': ('øyeskygge',),
'øyestein': ('øyestein',),
'øyesteinen': ('øyestein',),
'øyesteinene': ('øyestein',),
'øyesteiner': ('øyestein',),
'øyestein': ('øyestein',),
'øyesteinen': ('øyestein',),
'øyesteinene': ('øyestein',),
'øyesteiner': ('øyestein',),
'øyesten': ('øyesten',),
'øyestenen': ('øyesten',),
'øyestenene': ('øyesten',),
'øyestener': ('øyesten',),
'øyestikker': ('øyestikker',),
'øyestikkere': ('øyestikker',),
'øyestikkeren': ('øyestikker',),
'øyestikkerer': ('øyestikker',),
'øyestikkerne': ('øyestikker',),
'øyesverta': ('øyesverte',),
'øyesverte': ('øyesverte',),
'øyesverten': ('øyesverte',),
'øyesvertene': ('øyesverte',),
'øyesverter': ('øyesverte',),
'øyesykdom': ('øyesykdom',),
'øyesykdommen': ('øyesykdom',),
'øyesykdommene': ('øyesykdom',),
'øyesykdommer': ('øyesykdom',),
'øyesyn': ('øyesyn',),
'øyesyna': ('øyesyn',),
'øyesynene': ('øyesyn',),
'øyesyner': ('øyesyn',),
'øyesynet': ('øyesyn',),
'øyetann': ('øyetann',),
'øyetanna': ('øyetann',),
'øyetannen': ('øyetann',),
'øyetennene': ('øyetann',),
'øyetenner': ('øyetann',),
'øyevipp': ('øyevipp',),
'øyevippen': ('øyevipp',),
'øyevippene': ('øyevipp',),
'øyevipper': ('øyevipp',),
'øyevippe': ('øyevippe',),
'øyevippen': ('øyevippe',),
'øyevippene': ('øyevippe',),
'øyevipper': ('øyevippe',),
'øyevitna': ('øyevitne',),
'øyevitne': ('øyevitne',),
'øyevitnene': ('øyevitne',),
'øyevitner': ('øyevitne',),
'øyevitnet': ('øyevitne',),
'øygard': ('øygard',),
'øygarden': ('øygard',),
'øygardene': ('øygard',),
'øygarder': ('øygard',),
'øygruppa': ('øygruppe',),
'øygruppe': ('øygruppe',),
'øygruppen': ('øygruppe',),
'øygruppene': ('øygruppe',),
'øygrupper': ('øygruppe',),
'øying': ('øying',),
'øyingen': ('øying',),
'øyingene': ('øying',),
'øyinger': ('øying',),
'øyk': ('øyk',),
'øyken': ('øyk',),
'øykene': ('øyk',),
'øyker': ('øyk',),
'øyr': ('øyr',),
'øyra': ('øyr',),
'øyren': ('øyr',),
'øyrene': ('øyr',),
'øyrer': ('øyr',),
'øyrika': ('øyrike',),
'øyrike': ('øyrike',),
'øyrikene': ('øyrike',),
'øyriker': ('øyrike',),
'øyriket': ('øyrike',),
'øyværing': ('øyværing',),
'øyværingen': ('øyværing',),
'øyværingene': ('øyværing',),
'øyværinger': ('øyværing',),
'akt': ('akt',),
'akten': ('akt',),
'aktene': ('akt',),
'akter': ('akt',),
'akt': ('akt',),
'akten': ('akt',),
'aktene': ('akt',),
'akter': ('akt',),
'ås': ('ås',),
'åsen': ('ås',),
'åsene': ('ås',),
'åser': ('ås',),
'ås': ('ås',),
'åsen': ('ås',),
'åsene': ('ås',),
'åser': ('ås',),
'ætt': ('ætt',),
'ætta': ('ætt',),
'ætten': ('ætt',),
'ættene': ('ætt',),
'ætter': ('ætt',),
'ætt': ('ætt',),
'ætta': ('ætt',),
'ætten': ('ætt',),
'ættene': ('ætt',),
'ætter': ('ætt',),
'atlas': ('atlas',),
'atlasen': ('atlas',),
'atlasene': ('atlas',),
'atlaser': ('atlas',),
'atlas': ('atlas',),
'atlasen': ('atlas',),
'atlasene': ('atlas',),
'atlaser': ('atlas',),
'atlas': ('atlas',),
'atlasen': ('atlas',),
'atlasene': ('atlas',),
'atlaser': ('atlas',),
'avl': ('avl',),
'avlen': ('avl',),
'avlene': ('avl',),
'avler': ('avl',),
'avl': ('avl',),
'avlen': ('avl',),
'avlene': ('avl',),
'avler': ('avl',),
'bahai': ('bahai',),
'bahaien': ('bahai',),
'bahaiene': ('bahai',),
'bahaier': ('bahai',),
'bahai': ('bahai',),
'bahaien': ('bahai',),
'bahaiene': ('bahai',),
'bahaier': ('bahai',),
'bane': ('bane',),
'banen': ('bane',),
'banene': ('bane',),
'baner': ('bane',),
'bane': ('bane',),
'banen': ('bane',),
'banene': ('bane',),
'baner': ('bane',),
'bank': ('bank',),
'banken': ('bank',),
'bankene': ('bank',),
'banker': ('bank',),
'bank': ('bank',),
'banken': ('bank',),
'bankene': ('bank',),
'banker': ('bank',),
'bank': ('bank',),
'banken': ('bank',),
'bankene': ('bank',),
'banker': ('bank',),
'bark': ('bark',),
'barken': ('bark',),
'barkene': ('bark',),
'barker': ('bark',),
'bark': ('bark',),
'barken': ('bark',),
'barkene': ('bark',),
'barker': ('bark',),
'bestikk': ('bestikk',),
'bestikka': ('bestikk',),
'bestikkene': ('bestikk',),
'bestikket': ('bestikk',),
'bestikk': ('bestikk',),
'bestikka': ('bestikk',),
'bestikkene': ('bestikk',),
'bestikket': ('bestikk',),
'bisp': ('bisp',),
'bispen': ('bisp',),
'bispene': ('bisp',),
'bisper': ('bisp',),
'bisp': ('bisp',),
'bispen': ('bisp',),
'bispene': ('bisp',),
'bisper': ('bisp',),
'blazer': ('blazer',),
'blazere': ('blazer',),
'blazeren': ('blazer',),
'blazerer': ('blazer',),
'blazerne': ('blazer',),
'bleser': ('bleser',),
'blesere': ('bleser',),
'bleseren': ('bleser',),
'bleserer': ('bleser',),
'bleserne': ('bleser',),
'blikk': ('blikk',),
'blikka': ('blikk',),
'blikkene': ('blikk',),
'blikket': ('blikk',),
'blikk': ('blikk',),
'blikka': ('blikk',),
'blikkene': ('blikk',),
'blikket': ('blikk',),
'blikk': ('blikk',),
'blikka': ('blikk',),
'blikkene': ('blikk',),
'blikket': ('blikk',),
'bogeføring': ('bogeføring',),
'bogeføringa': ('bogeføring',),
'bogeføringen': ('bogeføring',),
'bogeføringene': ('bogeføring',),
'bogeføringer': ('bogeføring',),
'bueføring': ('bueføring',),
'bueføringa': ('bueføring',),
'bueføringen': ('bueføring',),
'bueføringene': ('bueføring',),
'bueføringer': ('bueføring',),
'bom': ('bom',),
'bommen': ('bom',),
'bommene': ('bom',),
'bommer': ('bom',),
'bom': ('bom',),
'bommen': ('bom',),
'bommene': ('bom',),
'bommer': ('bom',),
'bom': ('bom',),
'bommen': ('bom',),
'bommene': ('bom',),
'bommer': ('bom',),
'bor': ('bor',),
'bora': ('bor',),
'borene': ('bor',),
'boret': ('bor',),
'bor': ('bor',),
'bora': ('bor',),
'borene': ('bor',),
'boret': ('bor',),
'busetting': ('busetting',),
'busettinga': ('busetting',),
'busettingen': ('busetting',),
'busettingene': ('busetting',),
'busettinger': ('busetting',),
'brigg': ('brigg',),
'briggen': ('brigg',),
'briggene': ('brigg',),
'brigger': ('brigg',),
'brigg': ('brigg',),
'briggen': ('brigg',),
'briggene': ('brigg',),
'brigger': ('brigg',),
'bogeføring': ('bogeføring',),
'bogeføringa': ('bogeføring',),
'bogeføringen': ('bogeføring',),
'bogeføringene': ('bogeføring',),
'bogeføringer': ('bogeføring',),
'bueføring': ('bueføring',),
'bueføringa': ('bueføring',),
'bueføringen': ('bueføring',),
'bueføringene': ('bueføring',),
'bueføringer': ('bueføring',),
'bulk': ('bulk',),
'bulken': ('bulk',),
'bulkene': ('bulk',),
'bulker': ('bulk',),
'bulk': ('bulk',),
'bulken': ('bulk',),
'bulkene': ('bulk',),
'bulker': ('bulk',),
'bør': ('bør',),
'børen': ('bør',),
'børene': ('bør',),
'bører': ('bør',),
'bør': ('bør',),
'børen': ('bør',),
'børene': ('bør',),
'bører': ('bør',),
'coitus': ('coitus',),
'coitusen': ('coitus',),
'coitusene': ('coitus',),
'coituser': ('coitus',),
'daddel': ('daddel',),
'daddelen': ('daddel',),
'dadlene': ('daddel',),
'dadler': ('daddel',),
'daddel': ('daddel',),
'daddelen': ('daddel',),
'dadlene': ('daddel',),
'dadler': ('daddel',),
'diett': ('diett',),
'dietten': ('diett',),
'diettene': ('diett',),
'dietter': ('diett',),
'diett': ('diett',),
'dietten': ('diett',),
'diettene': ('diett',),
'dietter': ('diett',),
'diss': ('diss',),
'dissen': ('diss',),
'dissene': ('diss',),
'disser': ('diss',),
'diss': ('diss',),
'dissa': ('diss',),
'dissen': ('diss',),
'dissene': ('diss',),
'disser': ('diss',),
'disset': ('diss',),
'dekkene': ('dokk',),
'dekker': ('dokk',),
'dokk': ('dokk',),
'dokka': ('dokk',),
'dokken': ('dokk',),
'dokkene': ('dokk',),
'dokker': ('dokk',),
'dokk': ('dokk',),
'dokka': ('dokk',),
'dokken': ('dokk',),
'dokkene': ('dokk',),
'dokker': ('dokk',),
'domino': ('domino',),
'dominoen': ('domino',),
'dominoene': ('domino',),
'dominoer': ('domino',),
'domino': ('domino',),
'dominoen': ('domino',),
'dominoene': ('domino',),
'dominoer': ('domino',),
'drill': ('drill',),
'drillen': ('drill',),
'drillene': ('drill',),
'driller': ('drill',),
'drill': ('drill',),
'drillen': ('drill',),
'drillene': ('drill',),
'driller': ('drill',),
'drill': ('drill',),
'drillen': ('drill',),
'drillene': ('drill',),
'driller': ('drill',),
'drill': ('drill',),
'drilla': ('drill',),
'drillen': ('drill',),
'drillene': ('drill',),
'driller': ('drill',),
'drillet': ('drill',),
'dur': ('dur',),
'duren': ('dur',),
'durene': ('dur',),
'durer': ('dur',),
'dur': ('dur',),
'duren': ('dur',),
'durene': ('dur',),
'durer': ('dur',),
'eika': ('eike',),
'eike': ('eike',),
'eiken': ('eike',),
'eikene': ('eike',),
'eiker': ('eike',),
'eika': ('eike',),
'eike': ('eike',),
'eiken': ('eike',),
'eikene': ('eike',),
'eiker': ('eike',),
'ekorn': ('ekorn',),
'ekorna': ('ekorn',),
'ekornen': ('ekorn',),
'ekornene': ('ekorn',),
'ekorner': ('ekorn',),
'ekornet': ('ekorn',),
'ikorn': ('ikorn',),
'ikorna': ('ikorn',),
'ikornen': ('ikorn',),
'ikornene': ('ikorn',),
'ikorner': ('ikorn',),
'ikornet': ('ikorn',),
'fader': ('fader',),
'fadere': ('fader',),
'faderen': ('fader',),
'faderer': ('fader',),
'faderne': ('fader',),
'fader': ('fader',),
'faderen': ('fader',),
'fedre': ('fader',),
'fedrene': ('fader',),
'fals': ('fals',),
'falsen': ('fals',),
'falsene': ('fals',),
'falser': ('fals',),
'fals': ('fals',),
'falsen': ('fals',),
'falsene': ('fals',),
'falser': ('fals',),
'fals': ('fals',),
'falsen': ('fals',),
'falsene': ('fals',),
'falser': ('fals',),
'fan': ('fan',),
'fanen': ('fan',),
'fanene': ('fan',),
'fans': ('fan',),
'fan': ('fan',),
'fersken': ('fersken',),
'ferskenen': ('fersken',),
'ferskenene': ('fersken',),
'ferskener': ('fersken',),
'flo': ('flo',),
'floa': ('flo',),
'floen': ('flo',),
'floene': ('flo',),
'floer': ('flo',),
'flor': ('flor',),
'flora': ('flor',),
'florene': ('flor',),
'floret': ('flor',),
'flor': ('flor',),
'flora': ('flor',),
'florene': ('flor',),
'floret': ('flor',),
'forslag': ('forslag',),
'forslaga': ('forslag',),
'forslagene': ('forslag',),
'forslaget': ('forslag',),
'forslag': ('forslag',),
'forslaga': ('forslag',),
'forslagene': ('forslag',),
'forslaget': ('forslag',),
'forslag': ('forslag',),
'forslaga': ('forslag',),
'forslagene': ('forslag',),
'forslaget': ('forslag',),
'forsyn': ('forsyn',),
'forsyna': ('forsyn',),
'forsynene': ('forsyn',),
'forsynet': ('forsyn',),
'forsyn': ('forsyn',),
'forsyna': ('forsyn',),
'forsynene': ('forsyn',),
'forsynet': ('forsyn',),
'fot': ('fot',),
'foten': ('fot',),
'fotene': ('fot',),
'fraflytting': ('fraflytting',),
'fraflyttinga': ('fraflytting',),
'fraflyttingen': ('fraflytting',),
'fraflyttingene': ('fraflytting',),
'fraflyttinger': ('fraflytting',),
'fraflytting': ('fraflytting',),
'fraflyttinga': ('fraflytting',),
'fraflyttingen': ('fraflytting',),
'fraflyttingene': ('fraflytting',),
'fraflyttinger': ('fraflytting',),
'frilista': ('friliste',),
'friliste': ('friliste',),
'frilisten': ('friliste',),
'frilistene': ('friliste',),
'frilister': ('friliste',),
'frys': ('frys',),
'frysen': ('frys',),
'frysene': ('frys',),
'fryser': ('frys',),
'frys': ('frys',),
'fyll': ('fyll',),
'fylla': ('fyll',),
'fyllen': ('fyll',),
'fyllene': ('fyll',),
'fyller': ('fyll',),
'galleblæra': ('galleblære',),
'galleblære': ('galleblære',),
'galleblæren': ('galleblære',),
'galleblærene': ('galleblære',),
'galleblærer': ('galleblære',),
'galleblæra': ('galleblære',),
'galleblære': ('galleblære',),
'galleblæren': ('galleblære',),
'galleblærene': ('galleblære',),
'galleblærer': ('galleblære',),
'garde': ('garde',),
'garden': ('garde',),
'gardene': ('garde',),
'garder': ('garde',),
'garde': ('garde',),
'garden': ('garde',),
'gardene': ('garde',),
'garder': ('garde',),
'garde': ('garde',),
'garden': ('garde',),
'gardene': ('garde',),
'garder': ('garde',),
'golf': ('golf',),
'golfen': ('golf',),
'golfene': ('golf',),
'golfer': ('golf',),
'golf': ('golf',),
'golfen': ('golf',),
'golfene': ('golf',),
'golfer': ('golf',),
'gon': ('gon',),
'gonen': ('gon',),
'gonene': ('gon',),
'gon': ('gon',),
'gonen': ('gon',),
'gonene': ('gon',),
'goner': ('gon',),
'gris': ('gris',),
'grisen': ('gris',),
'grisene': ('gris',),
'griser': ('gris',),
'gris': ('gris',),
'grisen': ('gris',),
'grisene': ('gris',),
'griser': ('gris',),
'gross': ('gross',),
'grossa': ('gross',),
'grossene': ('gross',),
'grosset': ('gross',),
'gross': ('gross',),
'grossa': ('gross',),
'grossene': ('gross',),
'grosset': ('gross',),
'grovær': ('grovær',),
'groværa': ('grovær',),
'groværene': ('grovær',),
'groværet': ('grovær',),
'grovær': ('grovær',),
'groværa': ('grovær',),
'groværene': ('grovær',),
'groværet': ('grovær',),
'gytja': ('gytje',),
'gytje': ('gytje',),
'gytjen': ('gytje',),
'gytjene': ('gytje',),
'gytjer': ('gytje',),
'gytja': ('gytje',),
'gytje': ('gytje',),
'gytjen': ('gytje',),
'gytjene': ('gytje',),
'gytjer': ('gytje',),
'hakk': ('hakk',),
'hakka': ('hakk',),
'hakkene': ('hakk',),
'hakket': ('hakk',),
'hakk': ('hakk',),
'hakka': ('hakk',),
'hakkene': ('hakk',),
'hakket': ('hakk',),
'handbak': ('handbak',),
'handbaken': ('handbak',),
'handbakene': ('handbak',),
'handbaker': ('handbak',),
'handgemeng': ('handgemeng',),
'handgemenga': ('handgemeng',),
'handgemengene': ('handgemeng',),
'handgemenger': ('handgemeng',),
'handgemenget': ('handgemeng',),
'håndgemeng': ('håndgemeng',),
'håndgemenga': ('håndgemeng',),
'håndgemengene': ('håndgemeng',),
'håndgemenger': ('håndgemeng',),
'håndgemenget': ('håndgemeng',),
'hegd': ('hegd',),
'hegda': ('hegd',),
'hegden': ('hegd',),
'hegdene': ('hegd',),
'hegder': ('hegd',),
'hegd': ('hegd',),
'hegda': ('hegd',),
'hegden': ('hegd',),
'hegdene': ('hegd',),
'hegder': ('hegd',),
'hell': ('hell',),
'hella': ('hell',),
'hellene': ('hell',),
'hellet': ('hell',),
'hell': ('hell',),
'hella': ('hell',),
'hellene': ('hell',),
'hellet': ('hell',),
'hestehov': ('hestehov',),
'hestehoven': ('hestehov',),
'hestehovene': ('hestehov',),
'hestehover': ('hestehov',),
'hestehov': ('hestehov',),
'hestehoven': ('hestehov',),
'hestehovene': ('hestehov',),
'hestehover': ('hestehov',),
'hevd': ('hevd',),
'hevda': ('hevd',),
'hevden': ('hevd',),
'hevdene': ('hevd',),
'hevder': ('hevd',),
'hevd': ('hevd',),
'hevden': ('hevd',),
'hevdene': ('hevd',),
'hevder': ('hevd',),
'hogg': ('hogg',),
'hogga': ('hogg',),
'hoggene': ('hogg',),
'hogget': ('hogg',),
'hogg': ('hogg',),
'hogga': ('hogg',),
'hoggene': ('hogg',),
'hogget': ('hogg',),
'hold': ('hold',),
'holda': ('hold',),
'holdene': ('hold',),
'holdet': ('hold',),
'hold': ('hold',),
'holda': ('hold',),
'holdene': ('hold',),
'holdet': ('hold',),
'horg': ('horg',),
'horga': ('horg',),
'horgen': ('horg',),
'horgene': ('horg',),
'horger': ('horg',),
'horg': ('horg',),
'horga': ('horg',),
'horgen': ('horg',),
'horgene': ('horg',),
'horger': ('horg',),
'horg': ('horg',),
'horga': ('horg',),
'horgen': ('horg',),
'horgene': ('horg',),
'horger': ('horg',),
'hull': ('hull',),
'hulla': ('hull',),
'hullene': ('hull',),
'huller': ('hull',),
'hullet': ('hull',),
'husk': ('husk',),
'husken': ('husk',),
'huskene': ('husk',),
'husker': ('husk',),
'husk': ('husk',),
'huska': ('husk',),
'husken': ('husk',),
'huskene': ('husk',),
'husket': ('husk',),
'hvitvasking': ('hvitvasking',),
'hvitvaskinga': ('hvitvasking',),
'hvitvaskingen': ('hvitvasking',),
'hvitvaskingene': ('hvitvasking',),
'hvitvaskinger': ('hvitvasking',),
'kvitvasking': ('kvitvasking',),
'kvitvaskinga': ('kvitvasking',),
'kvitvaskingen': ('kvitvasking',),
'kvitvaskingene': ('kvitvasking',),
'kvitvaskinger': ('kvitvasking',),
'hand': ('hand',),
'handa': ('hand',),
'handen': ('hand',),
'hendene': ('hand',),
'hender': ('hand',),
'hendene': ('hånd',),
'hender': ('hånd',),
'hånd': ('hånd',),
'hånda': ('hånd',),
'hånden': ('hånd',),
'handbak': ('handbak',),
'handbaken': ('handbak',),
'handbakene': ('handbak',),
'handbaker': ('handbak',),
'handgemeng': ('handgemeng',),
'handgemenga': ('handgemeng',),
'handgemengene': ('handgemeng',),
'handgemenget': ('handgemeng',),
'håndgemeng': ('håndgemeng',),
'håndgemenga': ('håndgemeng',),
'håndgemengene': ('håndgemeng',),
'håndgemenget': ('håndgemeng',),
'håndgivelse': ('håndgivelse',),
'håndgivelsen': ('håndgivelse',),
'håndgivelsene': ('håndgivelse',),
'håndgivelser': ('håndgivelse',),
'handverkslæra': ('handverkslære',),
'handverkslære': ('handverkslære',),
'handverkslæren': ('handverkslære',),
'handverkslærene': ('handverkslære',),
'handverkslærer': ('handverkslære',),
'håndverkslæra': ('håndverkslære',),
'håndverkslære': ('håndverkslære',),
'håndverkslæren': ('håndverkslære',),
'håndverkslærene': ('håndverkslære',),
'håndverkslærer': ('håndverkslære',),
'ekorn': ('ekorn',),
'ekorna': ('ekorn',),
'ekornen': ('ekorn',),
'ekornene': ('ekorn',),
'ekorner': ('ekorn',),
'ekornet': ('ekorn',),
'ikorn': ('ikorn',),
'ikorna': ('ikorn',),
'ikornen': ('ikorn',),
'ikornene': ('ikorn',),
'ikorner': ('ikorn',),
'ikornet': ('ikorn',),
'il': ('il',),
'ila': ('il',),
'ilen': ('il',),
'ilene': ('il',),
'iler': ('il',),
'il': ('il',),
'ila': ('il',),
'ilen': ('il',),
'ilene': ('il',),
'iler': ('il',),
'il': ('il',),
'ilen': ('il',),
'ilene': ('il',),
'iler': ('il',),
'illvær': ('illvær',),
'illværa': ('illvær',),
'illværene': ('illvær',),
'illværet': ('illvær',),
'illvær': ('illvær',),
'illværa': ('illvær',),
'illværene': ('illvær',),
'illværet': ('illvær',),
'jamne': ('jamne',),
'jamnen': ('jamne',),
'jamnene': ('jamne',),
'jamner': ('jamne',),
'jamne': ('jamne',),
'jamnen': ('jamne',),
'jamnene': ('jamne',),
'jamner': ('jamne',),
'jura': ('jura',),
'juraen': ('jura',),
'juraene': ('jura',),
'juraer': ('jura',),
'jura': ('jura',),
'juraen': ('jura',),
'juraene': ('jura',),
'juraer': ('jura',),
'jus': ('jus',),
'jusen': ('jus',),
'jusene': ('jus',),
'juser': ('jus',),
'jus': ('jus',),
'jusen': ('jus',),
'jusene': ('jus',),
'juser': ('jus',),
'kalk': ('kalk',),
'kalken': ('kalk',),
'kalkene': ('kalk',),
'kalker': ('kalk',),
'kalk': ('kalk',),
'kalken': ('kalk',),
'kalkene': ('kalk',),
'kalker': ('kalk',),
'kant': ('kant',),
'kanten': ('kant',),
'kantene': ('kant',),
'kanter': ('kant',),
'kant': ('kant',),
'kanta': ('kant',),
'kanten': ('kant',),
'kantene': ('kant',),
'kanter': ('kant',),
'kantet': ('kant',),
'kis': ('kis',),
'kisen': ('kis',),
'kisene': ('kis',),
'kiser': ('kis',),
'kis': ('kis',),
'kisen': ('kis',),
'kisene': ('kis',),
'kiser': ('kis',),
'klaff': ('klaff',),
'klaffen': ('klaff',),
'klaffene': ('klaff',),
'klaffer': ('klaff',),
'klaff': ('klaff',),
'klaffen': ('klaff',),
'klaffene': ('klaff',),
'klaffer': ('klaff',),
'klikk': ('klikk',),
'klikken': ('klikk',),
'klikkene': ('klikk',),
'klikker': ('klikk',),
'klink': ('klink',),
'klinken': ('klink',),
'klinkene': ('klink',),
'klinker': ('klink',),
'klink': ('klink',),
'klinken': ('klink',),
'klinkene': ('klink',),
'klinker': ('klink',),
'klink': ('klink',),
'klinka': ('klink',),
'klinken': ('klink',),
'klinkene': ('klink',),
'klinker': ('klink',),
'klinket': ('klink',),
'klor': ('klor',),
'klora': ('klor',),
'klorene': ('klor',),
'kloret': ('klor',),
'klor': ('klor',),
'klora': ('klor',),
'klorene': ('klor',),
'kloret': ('klor',),
'kløver': ('kløver',),
'kløvere': ('kløver',),
'kløveren': ('kløver',),
'kløverer': ('kløver',),
'kløverne': ('kløver',),
'kløver': ('kløver',),
'kløvere': ('kløver',),
'kløveren': ('kløver',),
'kløverer': ('kløver',),
'kløverne': ('kløver',),
'knekk': ('knekk',),
'knekken': ('knekk',),
'knekkene': ('knekk',),
'knekker': ('knekk',),
'knop': ('knop',),
'knopen': ('knop',),
'knopene': ('knop',),
'knoper': ('knop',),
'knop': ('knop',),
'knopen': ('knop',),
'knopene': ('knop',),
'knott': ('knott',),
'knotten': ('knott',),
'knottene': ('knott',),
'knotter': ('knott',),
'knott': ('knott',),
'knotten': ('knott',),
'knottene': ('knott',),
'kok': ('kok',),
'koken': ('kok',),
'kokene': ('kok',),
'koker': ('kok',),
'kok': ('kok',),
'koka': ('kok',),
'koken': ('kok',),
'kokene': ('kok',),
'koker': ('kok',),
'koket': ('kok',),
'kost': ('kost',),
'kosten': ('kost',),
'kostene': ('kost',),
'koster': ('kost',),
'kol': ('kol',),
'kola': ('kol',),
'kolene': ('kol',),
'kolet': ('kol',),
'korg': ('korg',),
'korga': ('korg',),
'korgen': ('korg',),
'korgene': ('korg',),
'korger': ('korg',),
'kvark': ('kvark',),
'kvarken': ('kvark',),
'kvarkene': ('kvark',),
'kvarker': ('kvark',),
'kvark': ('kvark',),
'kvarken': ('kvark',),
'kvarkene': ('kvark',),
'kvarker': ('kvark',),
'hvitvasking': ('hvitvasking',),
'hvitvaskinga': ('hvitvasking',),
'hvitvaskingen': ('hvitvasking',),
'hvitvaskingene': ('hvitvasking',),
'hvitvaskinger': ('hvitvasking',),
'kvitvasking': ('kvitvasking',),
'kvitvaskinga': ('kvitvasking',),
'kvitvaskingen': ('kvitvasking',),
'kvitvaskingene': ('kvitvasking',),
'kvitvaskinger': ('kvitvasking',),
'land': ('land',),
'landa': ('land',),
'landene': ('land',),
'landet': ('land',),
'land': ('land',),
'landa': ('land',),
'landene': ('land',),
'landet': ('land',),
'langve': ('langve',),
'langven': ('langve',),
'langvene': ('langve',),
'langver': ('langve',),
'legg': ('legg',),
'leggen': ('legg',),
'leggene': ('legg',),
'legger': ('legg',),
'legg': ('legg',),
'leia': ('leie',),
'leie': ('leie',),
'leien': ('leie',),
'leiene': ('leie',),
'leier': ('leie',),
'leia': ('leie',),
'leie': ('leie',),
'leien': ('leie',),
'leiene': ('leie',),
'leier': ('leie',),
'løftning': ('løftning',),
'løftninga': ('løftning',),
'løftningen': ('løftning',),
'løftningene': ('løftning',),
'løftninger': ('løftning',),
'løftning': ('løftning',),
'løftninga': ('løftning',),
'løftningen': ('løftning',),
'løftningene': ('løftning',),
'løftninger': ('løftning',),
'løkka': ('løkke',),
'løkke': ('løkke',),
'løkken': ('løkke',),
'løkkene': ('løkke',),
'løkker': ('løkke',),
'løkka': ('løkke',),
'løkke': ('løkke',),
'løkken': ('løkke',),
'løkkene': ('løkke',),
'løkker': ('løkke',),
'løsepengene': ('løsepenger',),
'løsepenger': ('løsepenger',),
'list': ('list',),
'lista': ('list',),
'listen': ('list',),
'listene': ('list',),
'lister': ('list',),
'list': ('list',),
'lista': ('list',),
'listen': ('list',),
'listene': ('list',),
'lister': ('list',),
'litografi': ('litografi',),
'litografien': ('litografi',),
'litografiene': ('litografi',),
'litografier': ('litografi',),
'litografi': ('litografi',),
'litografia': ('litografi',),
'litografien': ('litografi',),
'litografiene': ('litografi',),
'litografier': ('litografi',),
'litografiet': ('litografi',),
'lo': ('lo',),
'loa': ('lo',),
'loen': ('lo',),
'loene': ('lo',),
'loer': ('lo',),
'lo': ('lo',),
'loa': ('lo',),
'loen': ('lo',),
'loene': ('lo',),
'loer': ('lo',),
'lo': ('lo',),
'loa': ('lo',),
'loen': ('lo',),
'loene': ('lo',),
'loer': ('lo',),
'lo': ('lo',),
'loa': ('lo',),
'loen': ('lo',),
'loene': ('lo',),
'loer': ('lo',),
'luv': ('luv',),
'luven': ('luv',),
'luvene': ('luv',),
'luver': ('luv',),
'loff': ('loff',),
'loffen': ('loff',),
'loffene': ('loff',),
'loffer': ('loff',),
'loff': ('loff',),
'loffen': ('loff',),
'loffene': ('loff',),
'loffer': ('loff',),
'lov': ('lov',),
'loven': ('lov',),
'lovene': ('lov',),
'lover': ('lov',),
'lov': ('lov',),
'lov': ('lov',),
'luv': ('luv',),
'luven': ('luv',),
'luvene': ('luv',),
'luver': ('luv',),
'luv': ('luv',),
'luven': ('luv',),
'luvene': ('luv',),
'luver': ('luv',),
'lyr': ('lyr',),
'lyren': ('lyr',),
'lyrene': ('lyr',),
'lyrer': ('lyr',),
'lyr': ('lyr',),
'lyra': ('lyr',),
'lyren': ('lyr',),
'lyrene': ('lyr',),
'lyrer': ('lyr',),
'lyra': ('lyre',),
'lyre': ('lyre',),
'lyren': ('lyre',),
'lyrene': ('lyre',),
'lyrer': ('lyre',),
'lyra': ('lyre',),
'lyre': ('lyre',),
'lyren': ('lyre',),
'lyrene': ('lyre',),
'lyrer': ('lyre',),
'læra': ('lære',),
'lære': ('lære',),
'læren': ('lære',),
'lærene': ('lære',),
'lærer': ('lære',),
'læra': ('lære',),
'lære': ('lære',),
'læren': ('lære',),
'lærene': ('lære',),
'lærer': ('lære',),
'læret': ('lære',),
'maki': ('maki',),
'makien': ('maki',),
'makiene': ('maki',),
'makier': ('maki',),
'maki': ('maki',),
'makien': ('maki',),
'makiene': ('maki',),
'makier': ('maki',),
'maquis': ('maquis',),
'maquisen': ('maquis',),
'maquisene': ('maquis',),
'maquiser': ('maquis',),
'malm': ('malm',),
'malmen': ('malm',),
'malmene': ('malm',),
'malmer': ('malm',),
'malm': ('malm',),
'malmen': ('malm',),
'malmene': ('malm',),
'malmer': ('malm',),
'maori': ('maori',),
'maorien': ('maori',),
'maoriene': ('maori',),
'maorier': ('maori',),
'maori': ('maori',),
'maorien': ('maori',),
'maoriene': ('maori',),
'maorier': ('maori',),
'maki': ('maki',),
'makien': ('maki',),
'makiene': ('maki',),
'makier': ('maki',),
'maquis': ('maquis',),
'maquisen': ('maquis',),
'maquisene': ('maquis',),
'maquiser': ('maquis',),
'mark': ('mark',),
'marka': ('mark',),
'marken': ('mark',),
'markene': ('mark',),
'marker': ('mark',),
'mot': ('mot',),
'mota': ('mot',),
'motene': ('mot',),
'motet': ('mot',),
'mot': ('mot',),
'mota': ('mot',),
'motene': ('mot',),
'motet': ('mot',),
'mua': ('mue',),
'mue': ('mue',),
'muen': ('mue',),
'muene': ('mue',),
'muer': ('mue',),
'mua': ('mue',),
'mue': ('mue',),
'muen': ('mue',),
'muene': ('mue',),
'muer': ('mue',),
'neurologi': ('neurologi',),
'neurologien': ('neurologi',),
'neurologiene': ('neurologi',),
'neurologier': ('neurologi',),
'nevrologi': ('nevrologi',),
'nevrologien': ('nevrologi',),
'nevrologiene': ('nevrologi',),
'nevrologier': ('nevrologi',),
'neurologi': ('neurologi',),
'neurologien': ('neurologi',),
'neurologiene': ('neurologi',),
'neurologier': ('neurologi',),
'nevrologi': ('nevrologi',),
'nevrologien': ('nevrologi',),
'nevrologiene': ('nevrologi',),
'nevrologier': ('nevrologi',),
'nipp': ('nipp',),
'nippa': ('nipp',),
'nippen': ('nipp',),
'nippene': ('nipp',),
'nipper': ('nipp',),
'nippet': ('nipp',),
'nipp': ('nipp',),
'nippa': ('nipp',),
'nippene': ('nipp',),
'nippet': ('nipp',),
'not': ('not',),
'nota': ('not',),
'noten': ('not',),
'nøtene': ('not',),
'nøter': ('not',),
'not': ('not',),
'nota': ('not',),
'noten': ('not',),
'notene': ('not',),
'noter': ('not',),
'omgang': ('omgang',),
'omgangen': ('omgang',),
'omgangene': ('omgang',),
'omganger': ('omgang',),
'omgang': ('omgang',),
'omgangen': ('omgang',),
'omgangene': ('omgang',),
'omganger': ('omgang',),
'ør': ('ør',),
'øra': ('ør',),
'øren': ('ør',),
'ørene': ('ør',),
'ører': ('ør',),
'øre': ('øre',),
'øren': ('øre',),
'ørene': ('øre',),
'ører': ('øre',),
'opptaksprøva': ('opptaksprøve',),
'opptaksprøve': ('opptaksprøve',),
'opptaksprøven': ('opptaksprøve',),
'opptaksprøvene': ('opptaksprøve',),
'opptaksprøver': ('opptaksprøve',),
'pass': ('pass',),
'passa': ('pass',),
'passene': ('pass',),
'passet': ('pass',),
'pass': ('pass',),
'passa': ('pass',),
'passene': ('pass',),
'passet': ('pass',),
'pass': ('pass',),
'passa': ('pass',),
'passene': ('pass',),
'passet': ('pass',),
'pass': ('pass',),
'perm': ('perm',),
'permen': ('perm',),
'permene': ('perm',),
'permer': ('perm',),
'perm': ('perm',),
'permen': ('perm',),
'permene': ('perm',),
'permer': ('perm',),
'perm': ('perm',),
'pers': ('pers',),
'persen': ('pers',),
'persene': ('pers',),
'perser': ('pers',),
'pers': ('pers',),
'persen': ('pers',),
'persene': ('pers',),
'perser': ('pers',),
'pers': ('pers',),
'persen': ('pers',),
'persene': ('pers',),
'perser': ('pers',),
'pikk': ('pikk',),
'pikka': ('pikk',),
'pikkene': ('pikk',),
'pikket': ('pikk',),
'pikk': ('pikk',),
'pikka': ('pikk',),
'pikkene': ('pikk',),
'pikket': ('pikk',),
'pikk': ('pikk',),
'pikka': ('pikk',),
'pikkene': ('pikk',),
'pikket': ('pikk',),
'pikk': ('pikk',),
'pikka': ('pikk',),
'pikkene': ('pikk',),
'pikket': ('pikk',),
'plett': ('plett',),
'pletten': ('plett',),
'plettene': ('plett',),
'pletter': ('plett',),
'plett': ('plett',),
'pletten': ('plett',),
'plettene': ('plett',),
'pletter': ('plett',),
'pomp': ('pomp',),
'pomp': ('pomp',),
'pompen': ('pomp',),
'pompene': ('pomp',),
'pomper': ('pomp',),
'post': ('post',),
'posten': ('post',),
'postene': ('post',),
'poster': ('post',),
'post': ('post',),
'posten': ('post',),
'postene': ('post',),
'poster': ('post',),
'post': ('post',),
'posten': ('post',),
'postene': ('post',),
'poster': ('post',),
'post': ('post',),
'posten': ('post',),
'postene': ('post',),
'poster': ('post',),
'prim': ('prim',),
'primen': ('prim',),
'primene': ('prim',),
'primer': ('prim',),
'prim': ('prim',),
'prima': ('prim',),
'primen': ('prim',),
'primene': ('prim',),
'primer': ('prim',),
'primet': ('prim',),
'purr': ('purr',),
'purra': ('purr',),
'purrene': ('purr',),
'purret': ('purr',),
'pynt': ('pynt',),
'pynten': ('pynt',),
'pyntene': ('pynt',),
'pynter': ('pynt',),
'pynt': ('pynt',),
'pynten': ('pynt',),
'pyntene': ('pynt',),
'pynter': ('pynt',),
'rap': ('rap',),
'rapen': ('rap',),
'rapene': ('rap',),
'raper': ('rap',),
'rap': ('rap',),
'rapa': ('rap',),
'rapen': ('rap',),
'rapene': ('rap',),
'raper': ('rap',),
'rapet': ('rap',),
'rap': ('rap',),
'rapa': ('rap',),
'rapene': ('rap',),
'rapet': ('rap',),
'rap': ('rap',),
'rapen': ('rap',),
'rapene': ('rap',),
'raper': ('rap',),
'rap': ('rap',),
'rapen': ('rap',),
'rapene': ('rap',),
'raper': ('rap',),
'rein': ('rein',),
'reina': ('rein',),
'reinen': ('rein',),
'reinene': ('rein',),
'reiner': ('rein',),
'rein': ('rein',),
'reinen': ('rein',),
'reinene': ('rein',),
'reiner': ('rein',),
'reumatisme': ('reumatisme',),
'reumatismen': ('reumatisme',),
'reumatismene': ('reumatisme',),
'reumatismer': ('reumatisme',),
'revmatisme': ('revmatisme',),
'revmatismen': ('revmatisme',),
'revmatismene': ('revmatisme',),
'revmatismer': ('revmatisme',),
'reumatisme': ('reumatisme',),
'reumatismen': ('reumatisme',),
'reumatismene': ('reumatisme',),
'reumatismer': ('reumatisme',),
'revmatisme': ('revmatisme',),
'revmatismen': ('revmatisme',),
'revmatismene': ('revmatisme',),
'revmatismer': ('revmatisme',),
'riks': ('riks',),
'riksen': ('riks',),
'riksene': ('riks',),
'rikser': ('riks',),
'riks': ('riks',),
'riksa': ('riks',),
'riksen': ('riks',),
'riksene': ('riks',),
'rikser': ('riks',),
'rikset': ('riks',),
'rips': ('rips',),
'ripsen': ('rips',),
'ripsene': ('rips',),
'ripser': ('rips',),
'rips': ('rips',),
'ripsen': ('rips',),
'ripsene': ('rips',),
'ripser': ('rips',),
'ro': ('ro',),
'roa': ('ro',),
'roen': ('ro',),
'roene': ('ro',),
'roer': ('ro',),
'ro': ('ro',),
'roa': ('ro',),
'roen': ('ro',),
'roene': ('ro',),
'roer': ('ro',),
'ro': ('ro',),
'roa': ('ro',),
'roen': ('ro',),
'roene': ('ro',),
'roer': ('ro',),
'rogn': ('rogn',),
'rogna': ('rogn',),
'rognen': ('rogn',),
'rognene': ('rogn',),
'rogner': ('rogn',),
'rogn': ('rogn',),
'rogna': ('rogn',),
'rognen': ('rogn',),
'rognene': ('rogn',),
'rogner': ('rogn',),
'ruff': ('ruff',),
'ruff': ('ruff',),
'ruffen': ('ruff',),
'ruffene': ('ruff',),
'ruffer': ('ruff',),
'rust': ('rust',),
'rusta': ('rust',),
'rusten': ('rust',),
'rustene': ('rust',),
'ruster': ('rust',),
'rust': ('rust',),
'rusta': ('rust',),
'rusten': ('rust',),
'rustene': ('rust',),
'ruster': ('rust',),
'rustning': ('rustning',),
'rustninga': ('rustning',),
'rustningen': ('rustning',),
'rustningene': ('rustning',),
'rustninger': ('rustning',),
'rustning': ('rustning',),
'rustninga': ('rustning',),
'rustningen': ('rustning',),
'rustningene': ('rustning',),
'rustninger': ('rustning',),
'røkelse': ('røkelse',),
'røkelsen': ('røkelse',),
'røkelsene': ('røkelse',),
'røkelser': ('røkelse',),
'røykelse': ('røykelse',),
'røykelsen': ('røykelse',),
'røykelsene': ('røykelse',),
'røykelser': ('røykelse',),
'rør': ('rør',),
'røra': ('rør',),
'rørene': ('rør',),
'røret': ('rør',),
'rør': ('rør',),
'røra': ('rør',),
'rørene': ('rør',),
'røret': ('rør',),
'røra': ('røre',),
'røre': ('røre',),
'røren': ('røre',),
'rørene': ('røre',),
'rører': ('røre',),
'røyk': ('røyk',),
'røyken': ('røyk',),
'røykene': ('røyk',),
'røyker': ('røyk',),
'røyk': ('røyk',),
'røyken': ('røyk',),
'røykene': ('røyk',),
'røkelse': ('røkelse',),
'røkelsen': ('røkelse',),
'røkelsene': ('røkelse',),
'røkelser': ('røkelse',),
'røykelse': ('røykelse',),
'røykelsen': ('røykelse',),
'røykelsene': ('røykelse',),
'røykelser': ('røykelse',),
'rå': ('rå',),
'råa': ('rå',),
'råen': ('rå',),
'råene': ('rå',),
'råer': ('rå',),
'råd': ('råd',),
'råke': ('råke',),
'råken': ('råke',),
'råkene': ('råke',),
'råker': ('råke',),
'råke': ('råke',),
'råken': ('råke',),
'råkene': ('råke',),
'råker': ('råke',),
'råke': ('råke',),
'råken': ('råke',),
'råkene': ('råke',),
'råker': ('råke',),
'saks': ('saks',),
'saksen': ('saks',),
'saksene': ('saks',),
'sakser': ('saks',),
'saks': ('saks',),
'saksen': ('saks',),
'saksene': ('saks',),
'sakser': ('saks',),
'segl': ('segl',),
'segla': ('segl',),
'seglene': ('segl',),
'seglet': ('segl',),
'segl': ('segl',),
'segla': ('segl',),
'seglene': ('segl',),
'seglet': ('segl',),
'selvfornektelse': ('selvfornektelse',),
'selvfornektelsen': ('selvfornektelse',),
'selvfornektelsene': ('selvfornektelse',),
'selvfornektelser': ('selvfornektelse',),
'sjølfornektelse': ('sjølfornektelse',),
'sjølfornektelsen': ('sjølfornektelse',),
'sjølfornektelsene': ('sjølfornektelse',),
'sjølfornektelser': ('sjølfornektelse',),
'sjølfornekting': ('sjølfornekting',),
'sjølfornektinga': ('sjølfornekting',),
'sjølfornektingen': ('sjølfornekting',),
'sjølfornektingene': ('sjølfornekting',),
'sjølfornektinger': ('sjølfornekting',),
'selvovervinning': ('selvovervinning',),
'selvovervinninga': ('selvovervinning',),
'selvovervinningen': ('selvovervinning',),
'selvovervinningene': ('selvovervinning',),
'selvovervinninger': ('selvovervinning',),
'sjølovervinning': ('sjølovervinning',),
'sjølovervinninga': ('sjølovervinning',),
'sjølovervinningen': ('sjølovervinning',),
'sjølovervinningene': ('sjølovervinning',),
'sjølovervinninger': ('sjølovervinning',),
'selvpining': ('selvpining',),
'selvpininga': ('selvpining',),
'selvpiningen': ('selvpining',),
'selvpiningene': ('selvpining',),
'selvpininger': ('selvpining',),
'sjølpining': ('sjølpining',),
'sjølpininga': ('sjølpining',),
'sjølpiningen': ('sjølpining',),
'sjølpiningene': ('sjølpining',),
'sjølpininger': ('sjølpining',),
'selvsyn': ('selvsyn',),
'selvsyna': ('selvsyn',),
'selvsynene': ('selvsyn',),
'selvsynet': ('selvsyn',),
'sen': ('sen',),
'sena': ('sen',),
'senen': ('sen',),
'senene': ('sen',),
'sener': ('sen',),
'sjalusi': ('sjalusi',),
'sjalusien': ('sjalusi',),
'sjalusiene': ('sjalusi',),
'sjalusier': ('sjalusi',),
'sjalusi': ('sjalusi',),
'sjalusien': ('sjalusi',),
'sjalusiene': ('sjalusi',),
'sjalusier': ('sjalusi',),
'sjarm': ('sjarm',),
'sjarmen': ('sjarm',),
'sjarmene': ('sjarm',),
'sjarmer': ('sjarm',),
'sjarme': ('sjarme',),
'sjarmen': ('sjarme',),
'sjarmene': ('sjarme',),
'sjarmer': ('sjarme',),
'sjarm': ('sjarm',),
'sjarmen': ('sjarm',),
'sjarmene': ('sjarm',),
'sjarmer': ('sjarm',),
'sjarme': ('sjarme',),
'sjarmen': ('sjarme',),
'sjarmene': ('sjarme',),
'sjarmer': ('sjarme',),
'selvfornektelse': ('selvfornektelse',),
'selvfornektelsen': ('selvfornektelse',),
'selvfornektelsene': ('selvfornektelse',),
'selvfornektelser': ('selvfornektelse',),
'sjølfornektelse': ('sjølfornektelse',),
'sjølfornektelsen': ('sjølfornektelse',),
'sjølfornektelsene': ('sjølfornektelse',),
'sjølfornektelser': ('sjølfornektelse',),
'sjølfornekting': ('sjølfornekting',),
'sjølfornektinga': ('sjølfornekting',),
'sjølfornektingen': ('sjølfornekting',),
'sjølfornektingene': ('sjølfornekting',),
'sjølfornektinger': ('sjølfornekting',),
'selvpining': ('selvpining',),
'selvpininga': ('selvpining',),
'selvpiningen': ('selvpining',),
'selvpiningene': ('selvpining',),
'selvpininger': ('selvpining',),
'sjølpining': ('sjølpining',),
'sjølpininga': ('sjølpining',),
'sjølpiningen': ('sjølpining',),
'sjølpiningene': ('sjølpining',),
'sjølpininger': ('sjølpining',),
'selvsyn': ('selvsyn',),
'selvsyna': ('selvsyn',),
'selvsynene': ('selvsyn',),
'selvsyner': ('selvsyn',),
'selvsynet': ('selvsyn',),
'skare': ('skare',),
'skaren': ('skare',),
'skarene': ('skare',),
'skarer': ('skare',),
'skare': ('skare',),
'skaren': ('skare',),
'skarene': ('skare',),
'skarer': ('skare',),
'skarv': ('skarv',),
'skarva': ('skarv',),
'skarvene': ('skarv',),
'skarvet': ('skarv',),
'skarv': ('skarv',),
'skarva': ('skarv',),
'skarvene': ('skarv',),
'skarvet': ('skarv',),
'skarv': ('skarv',),
'skarva': ('skarv',),
'skarvene': ('skarv',),
'skarvet': ('skarv',),
'skjøt': ('skjøt',),
'skjøta': ('skjøt',),
'skjøtene': ('skjøt',),
'skjøtet': ('skjøt',),
'skimlene': ('skimmel',),
'skimler': ('skimmel',),
'skimmel': ('skimmel',),
'skimmelen': ('skimmel',),
'skimlene': ('skimmel',),
'skimler': ('skimmel',),
'skimmel': ('skimmel',),
'skimmelen': ('skimmel',),
'skinn': ('skinn',),
'skinna': ('skinn',),
'skinnene': ('skinn',),
'skinnet': ('skinn',),
'skinn': ('skinn',),
'skinna': ('skinn',),
'skinnene': ('skinn',),
'skinnet': ('skinn',),
'skjell': ('skjell',),
'skjella': ('skjell',),
'skjellene': ('skjell',),
'skjellet': ('skjell',),
'skjell': ('skjell',),
'skjøt': ('skjøt',),
'skjøta': ('skjøt',),
'skjøtene': ('skjøt',),
'skjøter': ('skjøt',),
'skjøtet': ('skjøt',),
'skjøt': ('skjøt',),
'skjøta': ('skjøt',),
'skjøtene': ('skjøt',),
'skjøter': ('skjøt',),
'skjøtet': ('skjøt',),
'skrå': ('skrå',),
'skråa': ('skrå',),
'skråen': ('skrå',),
'skråene': ('skrå',),
'skråer': ('skrå',),
'skytte': ('skytte',),
'skytten': ('skytte',),
'skyttene': ('skytte',),
'skytter': ('skytte',),
'skytte': ('skytte',),
'skytten': ('skytte',),
'skyttene': ('skytte',),
'skytter': ('skytte',),
'slark': ('slark',),
'slarken': ('slark',),
'slarkene': ('slark',),
'slarker': ('slark',),
'slark': ('slark',),
'slarka': ('slark',),
'slarken': ('slark',),
'slarkene': ('slark',),
'slarker': ('slark',),
'slarket': ('slark',),
'sletta': ('slette',),
'slette': ('slette',),
'sletten': ('slette',),
'slettene': ('slette',),
'sletter': ('slette',),
'sletta': ('slette',),
'slette': ('slette',),
'sletten': ('slette',),
'slettene': ('slette',),
'sletter': ('slette',),
'slit': ('slit',),
'slita': ('slit',),
'slitene': ('slit',),
'slitet': ('slit',),
'slit': ('slit',),
'slita': ('slit',),
'slitene': ('slit',),
'slitet': ('slit',),
'slått': ('slått',),
'slåtten': ('slått',),
'slåttene': ('slått',),
'slåtter': ('slått',),
'slått': ('slått',),
'slåtten': ('slått',),
'slåttene': ('slått',),
'slåtter': ('slått',),
'smekk': ('smekk',),
'smekken': ('smekk',),
'smekkene': ('smekk',),
'smekker': ('smekk',),
'smell': ('smell',),
'smellen': ('smell',),
'smellene': ('smell',),
'smeller': ('smell',),
'sneis': ('sneis',),
'sneisa': ('sneis',),
'sneisen': ('sneis',),
'sneisene': ('sneis',),
'sneiser': ('sneis',),
'snerp': ('snerp',),
'snerpa': ('snerp',),
'snerpene': ('snerp',),
'snerpet': ('snerp',),
'snerp': ('snerp',),
'snerpa': ('snerp',),
'snerpen': ('snerp',),
'snerpene': ('snerp',),
'snerper': ('snerp',),
'snerpet': ('snerp',),
'snitt': ('snitt',),
'snitten': ('snitt',),
'snittene': ('snitt',),
'snitter': ('snitt',),
'snitt': ('snitt',),
'snitten': ('snitt',),
'snittene': ('snitt',),
'snitt': ('snitt',),
'snitten': ('snitt',),
'snittene': ('snitt',),
'snitter': ('snitt',),
'sokn': ('sokn',),
'sokna': ('sokn',),
'soknen': ('sokn',),
'soknene': ('sokn',),
'sokner': ('sokn',),
'soknet': ('sokn',),
'sokn': ('sokn',),
'sokna': ('sokn',),
'soknen': ('sokn',),
'soknene': ('sokn',),
'sokner': ('sokn',),
'spann': ('spann',),
'spanna': ('spann',),
'spannene': ('spann',),
'spannet': ('spann',),
'spann': ('spann',),
'spanna': ('spann',),
'spannene': ('spann',),
'spannet': ('spann',),
'spann': ('spann',),
'spark': ('spark',),
'sparken': ('spark',),
'sparkene': ('spark',),
'sparker': ('spark',),
'spark': ('spark',),
'sparken': ('spark',),
'sparkene': ('spark',),
'sparker': ('spark',),
'spikk': ('spikk',),
'spikka': ('spikk',),
'spikkene': ('spikk',),
'spikket': ('spikk',),
'spikk': ('spikk',),
'spikka': ('spikk',),
'spikkene': ('spikk',),
'spikket': ('spikk',),
'splint': ('splint',),
'splinten': ('splint',),
'splintene': ('splint',),
'splinter': ('splint',),
'splint': ('splint',),
'splinten': ('splint',),
'splintene': ('splint',),
'splinter': ('splint',),
'splint': ('splint',),
'splinten': ('splint',),
'splintene': ('splint',),
'splinter': ('splint',),
'sprett': ('sprett',),
'spretten': ('sprett',),
'sprettene': ('sprett',),
'spretter': ('sprett',),
'sprett': ('sprett',),
'spretta': ('sprett',),
'spretten': ('sprett',),
'sprettene': ('sprett',),
'spretter': ('sprett',),
'sprettet': ('sprett',),
'squash': ('squash',),
'squashen': ('squash',),
'squashene': ('squash',),
'squasher': ('squash',),
'squash': ('squash',),
'squashen': ('squash',),
'squashene': ('squash',),
'squasher': ('squash',),
'stamp': ('stamp',),
'stampen': ('stamp',),
'stampene': ('stamp',),
'stamper': ('stamp',),
'stamp': ('stamp',),
'stampen': ('stamp',),
'stampene': ('stamp',),
'stamper': ('stamp',),
'stamp': ('stamp',),
'stampen': ('stamp',),
'stampene': ('stamp',),
'stamper': ('stamp',),
'stand': ('stand',),
'standen': ('stand',),
'standene': ('stand',),
'stander': ('stand',),
'stand': ('stand',),
'standen': ('stand',),
'standene': ('stand',),
'stander': ('stand',),
'styr': ('styr',),
'styr': ('styr',),
'styra': ('styr',),
'styrene': ('styr',),
'styret': ('styr',),
'stær': ('stær',),
'stæren': ('stær',),
'stærene': ('stær',),
'stærer': ('stær',),
'stær': ('stær',),
'stæren': ('stær',),
'stærene': ('stær',),
'stærer': ('stær',),
'svai': ('svai',),
'svaien': ('svai',),
'svaiene': ('svai',),
'svaier': ('svai',),
'svai': ('svai',),
'svaien': ('svai',),
'svaiene': ('svai',),
'svaier': ('svai',),
'svart-hvitt': ('svart-hvitt',),
'sveis': ('sveis',),
'sveisen': ('sveis',),
'sveisene': ('sveis',),
'sveiser': ('sveis',),
'sveis': ('sveis',),
'sveisen': ('sveis',),
'sveisene': ('sveis',),
'sveiser': ('sveis',),
'sverta': ('sverte',),
'sverte': ('sverte',),
'sverten': ('sverte',),
'svertene': ('sverte',),
'sverter': ('sverte',),
'sverta': ('sverte',),
'sverte': ('sverte',),
'sverten': ('sverte',),
'svertene': ('sverte',),
'sverter': ('sverte',),
'sydvest': ('sydvest',),
'sydvesten': ('sydvest',),
'sydvestene': ('sydvest',),
'sydvester': ('sydvest',),
'sydvest': ('sydvest',),
'sydvesten': ('sydvest',),
'sydvestene': ('sydvest',),
'sydvester': ('sydvest',),
'takt': ('takt',),
'takta': ('takt',),
'takten': ('takt',),
'taktene': ('takt',),
'takter': ('takt',),
'takt': ('takt',),
'takta': ('takt',),
'takten': ('takt',),
'taktene': ('takt',),
'takter': ('takt',),
'tamil': ('tamil',),
'tamilen': ('tamil',),
'tamilene': ('tamil',),
'tamiler': ('tamil',),
'tamil': ('tamil',),
'tamilen': ('tamil',),
'tamilene': ('tamil',),
'tamiler': ('tamil',),
'tannrot': ('tannrot',),
'tannrota': ('tannrot',),
'tannroten': ('tannrot',),
'tannrøttene': ('tannrot',),
'tannrøtter': ('tannrot',),
'tannrot': ('tannrot',),
'tannrota': ('tannrot',),
'tannroten': ('tannrot',),
'tannrotene': ('tannrot',),
'tekka': ('tekke',),
'tekke': ('tekke',),
'tekkene': ('tekke',),
'tekker': ('tekke',),
'tekket': ('tekke',),
'tekka': ('tekke',),
'tekke': ('tekke',),
'tekkene': ('tekke',),
'tekker': ('tekke',),
'tekket': ('tekke',),
'teksaner': ('teksaner',),
'teksanere': ('teksaner',),
'teksaneren': ('teksaner',),
'teksanerer': ('teksaner',),
'teksanerne': ('teksaner',),
'texaner': ('texaner',),
'texanere': ('texaner',),
'texaneren': ('texaner',),
'texanerer': ('texaner',),
'texanerne': ('texaner',),
'tele': ('tele',),
'telen': ('tele',),
'telene': ('tele',),
'teler': ('tele',),
'tele': ('tele',),
'telen': ('tele',),
'telene': ('tele',),
'teler': ('tele',),
'tjørn': ('tjørn',),
'tjørna': ('tjørn',),
'tjørnene': ('tjørn',),
'tjørner': ('tjørn',),
'tjørnet': ('tjørn',),
'tjørn': ('tjørn',),
'tjørna': ('tjørn',),
'tjørnene': ('tjørn',),
'tjørner': ('tjørn',),
'tjørnet': ('tjørn',),
'toll': ('toll',),
'tollen': ('toll',),
'tollene': ('toll',),
'toller': ('toll',),
'toll': ('toll',),
'tollen': ('toll',),
'tollene': ('toll',),
'toller': ('toll',),
'trekt': ('trekt',),
'trekta': ('trekt',),
'trekten': ('trekt',),
'trektene': ('trekt',),
'trekter': ('trekt',),
'trekt': ('trekt',),
'trekta': ('trekt',),
'trekten': ('trekt',),
'trektene': ('trekt',),
'trekter': ('trekt',),
'tupi': ('tupi',),
'tupien': ('tupi',),
'tupiene': ('tupi',),
'tupier': ('tupi',),
'tupi': ('tupi',),
'tupien': ('tupi',),
'tupiene': ('tupi',),
'tupier': ('tupi',),
'tur': ('tur',),
'turen': ('tur',),
'turene': ('tur',),
'turer': ('tur',),
'tur': ('tur',),
'turen': ('tur',),
'turene': ('tur',),
'turer': ('tur',),
'tusse': ('tusse',),
'tussen': ('tusse',),
'tussene': ('tusse',),
'tusser': ('tusse',),
'tussa': ('tusse',),
'tusse': ('tusse',),
'tussen': ('tusse',),
'tussene': ('tusse',),
'tusser': ('tusse',),
'tvist': ('tvist',),
'tvisten': ('tvist',),
'tvistene': ('tvist',),
'tvister': ('tvist',),
'tvist': ('tvist',),
'tvisten': ('tvist',),
'tvistene': ('tvist',),
'tvister': ('tvist',),
'tjuv': ('tjuv',),
'tjuven': ('tjuv',),
'tjuvene': ('tjuv',),
'tjuver': ('tjuv',),
'ugreia': ('ugreie',),
'ugreie': ('ugreie',),
'ugreien': ('ugreie',),
'ugreiene': ('ugreie',),
'ugreier': ('ugreie',),
'umbra': ('umbra',),
'umbraen': ('umbra',),
'umbraene': ('umbra',),
'umbraer': ('umbra',),
'umbra': ('umbra',),
'umbraen': ('umbra',),
'umbraene': ('umbra',),
'umbraer': ('umbra',),
'ureinhet': ('ureinhet',),
'ureinheta': ('ureinhet',),
'ureinheten': ('ureinhet',),
'ureinhetene': ('ureinhet',),
'ureinheter': ('ureinhet',),
'uthogging': ('uthogging',),
'uthogginga': ('uthogging',),
'uthoggingen': ('uthogging',),
'uthoggingene': ('uthogging',),
'uthogginger': ('uthogging',),
'uthugging': ('uthugging',),
'uthugginga': ('uthugging',),
'uthuggingen': ('uthugging',),
'uthuggingene': ('uthugging',),
'uthugginger': ('uthugging',),
'uthogging': ('uthogging',),
'uthogginga': ('uthogging',),
'uthoggingen': ('uthogging',),
'uthoggingene': ('uthogging',),
'uthogginger': ('uthogging',),
'uthugging': ('uthugging',),
'uthugginga': ('uthugging',),
'uthuggingen': ('uthugging',),
'uthuggingene': ('uthugging',),
'uthugginger': ('uthugging',),
'utkik': ('utkik',),
'utkiken': ('utkik',),
'utkikene': ('utkik',),
'utkiker': ('utkik',),
'utkikk': ('utkikk',),
'utkikken': ('utkikk',),
'utkikkene': ('utkikk',),
'utkikker': ('utkikk',),
'utkik': ('utkik',),
'utkika': ('utkik',),
'utkiken': ('utkik',),
'utkikene': ('utkik',),
'utkiket': ('utkik',),
'utkikk': ('utkikk',),
'utkikka': ('utkikk',),
'utkikken': ('utkikk',),
'utkikkene': ('utkikk',),
'utkikket': ('utkikk',),
'utleia': ('utleie',),
'utleie': ('utleie',),
'utleien': ('utleie',),
'utleiene': ('utleie',),
'utleier': ('utleie',),
'utrustning': ('utrustning',),
'utrustninga': ('utrustning',),
'utrustningen': ('utrustning',),
'utrustningene': ('utrustning',),
'utrustninger': ('utrustning',),
'utrustning': ('utrustning',),
'utrustninga': ('utrustning',),
'utrustningen': ('utrustning',),
'utrustningene': ('utrustning',),
'utrustninger': ('utrustning',),
'utøy': ('utøy',),
'utøya': ('utøy',),
'utøyene': ('utøy',),
'utøyet': ('utøy',),
'utøy': ('utøy',),
'utøya': ('utøy',),
'utøyene': ('utøy',),
'utøyet': ('utøy',),
'val': ('val',),
'valen': ('val',),
'valene': ('val',),
'valer': ('val',),
'val': ('val',),
'valen': ('val',),
'valene': ('val',),
'valer': ('val',),
'vannplaning': ('vannplaning',),
'vannplaninga': ('vannplaning',),
'vannplaningen': ('vannplaning',),
'vannplaningene': ('vannplaning',),
'vannplaninger': ('vannplaning',),
'vassplaning': ('vassplaning',),
'vassplaninga': ('vassplaning',),
'vassplaningen': ('vassplaning',),
'vassplaningene': ('vassplaning',),
'vassplaninger': ('vassplaning',),
'vannplaning': ('vannplaning',),
'vannplaninga': ('vannplaning',),
'vannplaningen': ('vannplaning',),
'vannplaningene': ('vannplaning',),
'vannplaninger': ('vannplaning',),
'vassplaning': ('vassplaning',),
'vassplaninga': ('vassplaning',),
'vassplaningen': ('vassplaning',),
'vassplaningene': ('vassplaning',),
'vassplaninger': ('vassplaning',),
've': ('ve',),
'vea': ('ve',),
'veene': ('ve',),
'veet': ('ve',),
've': ('ve',),
'vea': ('ve',),
'veene': ('ve',),
'veet': ('ve',),
'verga': ('verge',),
'verge': ('verge',),
'vergene': ('verge',),
'verger': ('verge',),
'verget': ('verge',),
'verga': ('verge',),
'verge': ('verge',),
'vergene': ('verge',),
'verger': ('verge',),
'verget': ('verge',),
'verga': ('verge',),
'verge': ('verge',),
'vergene': ('verge',),
'verger': ('verge',),
'verget': ('verge',),
'verga': ('verge',),
'verge': ('verge',),
'vergene': ('verge',),
'verger': ('verge',),
'verget': ('verge',),
'vipp': ('vipp',),
'vippa': ('vipp',),
'vippen': ('vipp',),
'vippene': ('vipp',),
'vipper': ('vipp',),
'vippet': ('vipp',),
'vipp': ('vipp',),
'vippen': ('vipp',),
'vippene': ('vipp',),
'vipper': ('vipp',),
'visk': ('visk',),
'visken': ('visk',),
'viskene': ('visk',),
'visker': ('visk',),
'visk': ('visk',),
'visken': ('visk',),
'viskene': ('visk',),
'visker': ('visk',),
'vugga': ('vugge',),
'vugge': ('vugge',),
'vuggen': ('vugge',),
'vuggene': ('vugge',),
'vugger': ('vugge',),
'vær': ('vær',),
'væra': ('vær',),
'værene': ('vær',),
'været': ('vær',),
'vær': ('vær',),
'væra': ('vær',),
'værene': ('vær',),
'været': ('vær',),
'våg': ('våg',),
'våga': ('våg',),
'vågen': ('våg',),
'vågene': ('våg',),
'våger': ('våg',),
'våg': ('våg',),
'vågen': ('våg',),
'vågene': ('våg',),
'våger': ('våg',),
'våg': ('våg',),
'vågen': ('våg',),
'vågene': ('våg',),
'våger': ('våg',),
'forhand': ('forhand',),
'forhånd': ('forhånd',),
'forhånd': ('forhånd',),
'flo': ('flo',),
'floa': ('flo',),
'floen': ('flo',),
'floene': ('flo',),
'floer': ('flo',),
'flør': ('flo',),
'flørne': ('flo',),
'flo': ('flo',),
'floa': ('flo',),
'floene': ('flo',),
'floer': ('flo',),
'floet': ('flo',),
'flør': ('flo',),
'flørne': ('flo',),
'ås': ('ås',),
'åsen': ('ås',),
'æsene': ('ås',),
'æser': ('ås',),
'fot': ('fot',),
'foten': ('fot',),
'føttene': ('fot',),
'føtter': ('fot',),
'fyll': ('fyll',),
'fylla': ('fyll',),
'fyllen': ('fyll',),
'fyllene': ('fyll',),
'fyller': ('fyll',),
'fyllet': ('fyll',),
'klikk': ('klikk',),
'klikka': ('klikk',),
'klikken': ('klikk',),
'klikkene': ('klikk',),
'klikker': ('klikk',),
'klikket': ('klikk',),
'knekk': ('knekk',),
'knekka': ('knekk',),
'knekken': ('knekk',),
'knekkene': ('knekk',),
'knekket': ('knekk',),
'mark': ('mark',),
'marka': ('mark',),
'marken': ('mark',),
'merkene': ('mark',),
'merker': ('mark',),
'mark': ('mark',),
'marka': ('mark',),
'marken': ('mark',),
'markene': ('mark',),
'øre': ('øre',),
'øren': ('øre',),
'ørene': ('øre',),
'øret': ('øre',),
'purr': ('purr',),
'purra': ('purr',),
'purren': ('purr',),
'purrene': ('purr',),
'purrer': ('purr',),
'purret': ('purr',),
'ro': ('ro',),
'roa': ('ro',),
'roen': ('ro',),
'roene': ('ro',),
'roer': ('ro',),
'rør': ('ro',),
'rørne': ('ro',),
'røra': ('røre',),
'røre': ('røre',),
'røren': ('røre',),
'rørene': ('røre',),
'rører': ('røre',),
'røret': ('røre',),
'rå': ('rå',),
'råa': ('rå',),
'råen': ('rå',),
'rær': ('rå',),
'rærne': ('rå',),
'råd': ('råd',),
'råda': ('råd',),
'råden': ('råd',),
'rådene': ('råd',),
'råder': ('råd',),
'rådet': ('råd',),
'skrå': ('skrå',),
'skråa': ('skrå',),
'skråen': ('skrå',),
'skråene': ('skrå',),
'skråer': ('skrå',),
'skrået': ('skrå',),
'smell': ('smell',),
'smella': ('smell',),
'smellen': ('smell',),
'smellene': ('smell',),
'smeller': ('smell',),
'smellet': ('smell',),
'smekk': ('smekk',),
'smekka': ('smekk',),
'smekken': ('smekk',),
'smekkene': ('smekk',),
'smekker': ('smekk',),
'smekket': ('smekk',),
'sneis': ('sneis',),
'sneisa': ('sneis',),
'sneisen': ('sneis',),
'sneisene': ('sneis',),
'sneiser': ('sneis',),
'sneiset': ('sneis',),
'stand': ('stand',),
'standen': ('stand',),
'stendene': ('stand',),
'stender': ('stand',),
'accent': ('accent',),
'accenten': ('accent',),
'accentene': ('accent',),
'accenter': ('accent',),
'adferd': ('adferd',),
'adferda': ('adferd',),
'adferden': ('adferd',),
'adferdene': ('adferd',),
'adferder': ('adferd',),
'ad hoc-komiteen': ('ad hoc-komité',),
'ad hoc-komiteene': ('ad hoc-komité',),
'ad hoc-komiteer': ('ad hoc-komité',),
'ad hoc-komité': ('ad hoc-komité',),
'ad hoc-komitéen': ('ad hoc-komité',),
'ad hoc-komitéene': ('ad hoc-komité',),
'ad hoc-komitéer': ('ad hoc-komité',),
'adoptivforeldre': ('adoptivforeldre',),
'adoptivforeldrene': ('adoptivforeldre',),
'adressebok': ('adressebok',),
'adresseboka': ('adressebok',),
'adresseboken': ('adressebok',),
'adressebøkene': ('adressebok',),
'adressebøker': ('adressebok',),
'air-conditioning': ('air-conditioning',),
'air-conditioningen': ('air-conditioning',),
'air-conditioningene': ('air-conditioning',),
'air-conditioninger': ('air-conditioning',),
'akslebein': ('akslebein',),
'akslebeina': ('akslebein',),
'akslebeinene': ('akslebein',),
'akslebeinet': ('akslebein',),
'aksleben': ('aksleben',),
'akslebena': ('aksleben',),
'akslebenene': ('aksleben',),
'akslebenet': ('aksleben',),
'aksjonskomiteen': ('aksjonskomité',),
'aksjonskomiteene': ('aksjonskomité',),
'aksjonskomiteer': ('aksjonskomité',),
'aksjonskomité': ('aksjonskomité',),
'aksjonskomitéen': ('aksjonskomité',),
'aksjonskomitéene': ('aksjonskomité',),
'aksjonskomitéer': ('aksjonskomité',),
'aktivitetsleier': ('aktivitetsleier',),
'aktivitetsleiere': ('aktivitetsleier',),
'aktivitetsleieren': ('aktivitetsleier',),
'aktivitetsleierer': ('aktivitetsleier',),
'aktivitetsleierne': ('aktivitetsleier',),
'albogeskjell': ('albogeskjell',),
'albogeskjella': ('albogeskjell',),
'albogeskjellen': ('albogeskjell',),
'albogeskjellene': ('albogeskjell',),
'albogeskjellet': ('albogeskjell',),
'albueskjell': ('albueskjell',),
'albueskjella': ('albueskjell',),
'albueskjellen': ('albueskjell',),
'albueskjellene': ('albueskjell',),
'albueskjellet': ('albueskjell',),
'albuskjell': ('albuskjell',),
'albuskjella': ('albuskjell',),
'albuskjellen': ('albuskjell',),
'albuskjellene': ('albuskjell',),
'albuskjellet': ('albuskjell',),
'alkoholmisbruk': ('alkoholmisbruk',),
'alkoholmisbruka': ('alkoholmisbruk',),
'alkoholmisbruken': ('alkoholmisbruk',),
'alkoholmisbrukene': ('alkoholmisbruk',),
'alkoholmisbruker': ('alkoholmisbruk',),
'alkoholmisbruket': ('alkoholmisbruk',),
'allmenningsskau': ('allmenningsskau',),
'allmenningsskauen': ('allmenningsskau',),
'allmenningsskauene': ('allmenningsskau',),
'allmenningsskauer': ('allmenningsskau',),
'alterbok': ('alterbok',),
'alterboka': ('alterbok',),
'alterboken': ('alterbok',),
'alterbøkene': ('alterbok',),
'alterbøker': ('alterbok',),
'ananasgeleen': ('ananasgelé',),
'ananasgeleene': ('ananasgelé',),
'ananasgeleer': ('ananasgelé',),
'ananasgelé': ('ananasgelé',),
'ananasgeléen': ('ananasgelé',),
'ananasgeléene': ('ananasgelé',),
'ananasgeléer': ('ananasgelé',),
'arbeiderleier': ('arbeiderleier',),
'arbeiderleiere': ('arbeiderleier',),
'arbeiderleieren': ('arbeiderleier',),
'arbeiderleierer': ('arbeiderleier',),
'arbeiderleierne': ('arbeiderleier',),
'arbeidsbok': ('arbeidsbok',),
'arbeidsboka': ('arbeidsbok',),
'arbeidsboken': ('arbeidsbok',),
'arbeidsbøkene': ('arbeidsbok',),
'arbeidsbøker': ('arbeidsbok',),
'arbeidsleier': ('arbeidsleier',),
'arbeidsleiere': ('arbeidsleier',),
'arbeidsleieren': ('arbeidsleier',),
'arbeidsleierer': ('arbeidsleier',),
'arbeidsleierne': ('arbeidsleier',),
'arbeidstøy': ('arbeidstøy',),
'arbeidstøya': ('arbeidstøy',),
'arbeidstøyene': ('arbeidstøy',),
'arbeidstøyer': ('arbeidstøy',),
'arbeidstøyet': ('arbeidstøy',),
'arrangementskomite': ('arrangementskomite',),
'arrangementskomiteen': ('arrangementskomite',),
'arrangementskomiteene': ('arrangementskomite',),
'arrangementskomiteer': ('arrangementskomite',),
'aurbonn': ('aurbonn',),
'aurbonnen': ('aurbonn',),
'aurbonnene': ('aurbonn',),
'aurbonner': ('aurbonn',),
'autografbok': ('autografbok',),
'autografboka': ('autografbok',),
'autografboken': ('autografbok',),
'autografbøkene': ('autografbok',),
'autografbøker': ('autografbok',),
'autoritetstro': ('autoritetstro',),
'autoritetstroa': ('autoritetstro',),
'autoritetstroen': ('autoritetstro',),
'autoritetstroene': ('autoritetstro',),
'autoritetstroer': ('autoritetstro',),
'avbitertang': ('avbitertang',),
'avbitertanga': ('avbitertang',),
'avbitertangen': ('avbitertang',),
'avbitertengene': ('avbitertang',),
'avbitertenger': ('avbitertang',),
'avdelingsleier': ('avdelingsleier',),
'avdelingsleiere': ('avdelingsleier',),
'avdelingsleieren': ('avdelingsleier',),
'avdelingsleierer': ('avdelingsleier',),
'avdelingsleierne': ('avdelingsleier',),
'avisutklypp': ('avisutklypp',),
'avisutklyppen': ('avisutklypp',),
'avisutklyppene': ('avisutklypp',),
'avisutklypper': ('avisutklypp',),
'avlydveksel': ('avlydveksel',),
'avlydvekselen': ('avlydveksel',),
'avlydvekslene': ('avlydveksel',),
'avlydveksler': ('avlydveksel',),
'avtagerland': ('avtagerland',),
'avtagerlanda': ('avtagerland',),
'avtagerlandene': ('avtagerland',),
'avtagerlandet': ('avtagerland',),
'bahaitru': ('bahaitru',),
'bahaitrua': ('bahaitru',),
'bahaitruen': ('bahaitru',),
'bahaitruene': ('bahaitru',),
'bahaitruer': ('bahaitru',),
'bakfot': ('bakfot',),
'bakfoten': ('bakfot',),
'bakføttene': ('bakfot',),
'bakføtter': ('bakfot',),
'bakhand': ('bakhand',),
'bakhanda': ('bakhand',),
'bakhanden': ('bakhand',),
'bakhendene': ('bakhand',),
'bakhender': ('bakhand',),
'ballsko': ('ballsko',),
'ballskoa': ('ballsko',),
'ballskoen': ('ballsko',),
'ballskoene': ('ballsko',),
'ballskor': ('ballsko',),
'ballskorne': ('ballsko',),
'balltre': ('balltre',),
'balltrea': ('balltre',),
'balltreet': ('balltre',),
'balltrær': ('balltre',),
'balltrærne': ('balltre',),
'bamsefar': ('bamsefar',),
'bamsefaren': ('bamsefar',),
'bamsefedre': ('bamsefar',),
'bamsefedrene': ('bamsefar',),
'bankbok': ('bankbok',),
'bankboka': ('bankbok',),
'bankboken': ('bankbok',),
'bankbøkene': ('bankbok',),
'bankbøker': ('bankbok',),
'barcarole': ('barcarole',),
'barcarolen': ('barcarole',),
'barcarolene': ('barcarole',),
'barcaroler': ('barcarole',),
'berrfotdans': ('berrfotdans',),
'berrfotdansen': ('berrfotdans',),
'berrfotdansene': ('berrfotdans',),
'berrfotdanser': ('berrfotdans',),
'berrfotmunk': ('berrfotmunk',),
'berrfotmunken': ('berrfotmunk',),
'berrfotmunkene': ('berrfotmunk',),
'berrfotmunker': ('berrfotmunk',),
'berrfotnonna': ('berrfotnonne',),
'berrfotnonne': ('berrfotnonne',),
'berrfotnonnen': ('berrfotnonne',),
'berrfotnonnene': ('berrfotnonne',),
'berrfotnonner': ('berrfotnonne',),
'berrfrost': ('berrfrost',),
'berrfrosten': ('berrfrost',),
'berrfrostene': ('berrfrost',),
'berrfroster': ('berrfrost',),
'berrmark': ('berrmark',),
'berrmarka': ('berrmark',),
'berrmarken': ('berrmark',),
'berrmarkene': ('berrmark',),
'berrmarker': ('berrmark',),
'berrmarksamling': ('berrmarksamling',),
'berrmarksamlinga': ('berrmarksamling',),
'berrmarksamlingen': ('berrmarksamling',),
'berrmarksamlingene': ('berrmarksamling',),
'berrmarksamlinger': ('berrmarksamling',),
'barnebok': ('barnebok',),
'barneboka': ('barnebok',),
'barneboken': ('barnebok',),
'barnebøkene': ('barnebok',),
'barnebøker': ('barnebok',),
'barnefar': ('barnefar',),
'barnefaren': ('barnefar',),
'barnefedre': ('barnefar',),
'barnefedrene': ('barnefar',),
'barnesko': ('barnesko',),
'barneskoa': ('barnesko',),
'barneskoen': ('barnesko',),
'barneskoene': ('barnesko',),
'barneskor': ('barnesko',),
'barneskorne': ('barnesko',),
'barnetru': ('barnetru',),
'barnetrua': ('barnetru',),
'barnetruen': ('barnetru',),
'barnetruene': ('barnetru',),
'barnetruer': ('barnetru',),
'barskau': ('barskau',),
'barskauen': ('barskau',),
'barskauene': ('barskau',),
'barskauer': ('barskau',),
'barskaubelta': ('barskaubelte',),
'barskaubelte': ('barskaubelte',),
'barskaubeltene': ('barskaubelte',),
'barskaubelter': ('barskaubelte',),
'barskaubeltet': ('barskaubelte',),
'bedømmelseskomiteen': ('bedømmelseskomité',),
'bedømmelseskomiteene': ('bedømmelseskomité',),
'bedømmelseskomiteer': ('bedømmelseskomité',),
'bedømmelseskomité': ('bedømmelseskomité',),
'bedømmelseskomitéen': ('bedømmelseskomité',),
'bedømmelseskomitéene': ('bedømmelseskomité',),
'bedømmelseskomitéer': ('bedømmelseskomité',),
'begynnerbok': ('begynnerbok',),
'begynnerboka': ('begynnerbok',),
'begynnerboken': ('begynnerbok',),
'begynnerbøkene': ('begynnerbok',),
'begynnerbøker': ('begynnerbok',),
'beinbrott': ('beinbrott',),
'beinbrotta': ('beinbrott',),
'beinbrottene': ('beinbrott',),
'beinbrottet': ('beinbrott',),
'bengrind': ('bengrind',),
'bengrinda': ('bengrind',),
'bengrinden': ('bengrind',),
'bengrindene': ('bengrind',),
'bengrinder': ('bengrind',),
'bet': ('bet',),
'beten': ('bet',),
'betene': ('bet',),
'beter': ('bet',),
'bisla': ('bissel',),
'bislene': ('bissel',),
'bisler': ('bissel',),
'bislet': ('bissel',),
'bissel': ('bissel',),
'bisselet': ('bissel',),
'bensol': ('bensol',),
'bensola': ('bensol',),
'bensolene': ('bensol',),
'bensolet': ('bensol',),
'bergstad': ('bergstad',),
'bergstaden': ('bergstad',),
'bergstedene': ('bergstad',),
'bergsteder': ('bergstad',),
'bestefar': ('bestefar',),
'bestefaren': ('bestefar',),
'bestefedre': ('bestefar',),
'bestefedrene': ('bestefar',),
'besteforeldre': ('besteforeldre',),
'besteforeldrene': ('besteforeldre',),
'billedbok': ('billedbok',),
'billedboka': ('billedbok',),
'billedboken': ('billedbok',),
'billedbøkene': ('billedbok',),
'billedbøker': ('billedbok',),
'bildebok': ('bildebok',),
'bildeboka': ('bildebok',),
'bildeboken': ('bildebok',),
'bildebøkene': ('bildebok',),
'bildebøker': ('bildebok',),
'billigbok': ('billigbok',),
'billigboka': ('billigbok',),
'billigboken': ('billigbok',),
'billigbøkene': ('billigbok',),
'billigbøker': ('billigbok',),
'bisla': ('bissel',),
'bislene': ('bissel',),
'bisler': ('bissel',),
'bislet': ('bissel',),
'bissel': ('bissel',),
'bisselet': ('bissel',),
'bjerkealleen': ('bjerkeallé',),
'bjerkealleene': ('bjerkeallé',),
'bjerkealleer': ('bjerkeallé',),
'bjerkeallé': ('bjerkeallé',),
'bjerkealléen': ('bjerkeallé',),
'bjerkealléene': ('bjerkeallé',),
'bjerkealléer': ('bjerkeallé',),
'bjørkealleen': ('bjørkeallé',),
'bjørkealleene': ('bjørkeallé',),
'bjørkealleer': ('bjørkeallé',),
'bjørkeallé': ('bjørkeallé',),
'bjørkealléen': ('bjørkeallé',),
'bjørkealléene': ('bjørkeallé',),
'bjørkealléer': ('bjørkeallé',),
'bjørketre': ('bjørketre',),
'bjørketrea': ('bjørketre',),
'bjørketreet': ('bjørketre',),
'bjørketrær': ('bjørketre',),
'bjørketrærne': ('bjørketre',),
'bjerketre': ('bjerketre',),
'bjerketrea': ('bjerketre',),
'bjerketreet': ('bjerketre',),
'bjerketrær': ('bjerketre',),
'bjerketrærne': ('bjerketre',),
'blandfôr': ('blandfôr',),
'blandfôra': ('blandfôr',),
'blandfôrene': ('blandfôr',),
'blandfôret': ('blandfôr',),
'blandingsskau': ('blandingsskau',),
'blandingsskauen': ('blandingsskau',),
'blandingsskauene': ('blandingsskau',),
'blandingsskauer': ('blandingsskau',),
'blestkomiteen': ('blestkomité',),
'blestkomiteene': ('blestkomité',),
'blestkomiteer': ('blestkomité',),
'blestkomité': ('blestkomité',),
'blestkomitéen': ('blestkomité',),
'blestkomitéene': ('blestkomité',),
'blestkomitéer': ('blestkomité',),
'blomsterbonn': ('blomsterbonn',),
'blomsterbonnen': ('blomsterbonn',),
'blomsterbonnene': ('blomsterbonn',),
'blomsterbonner': ('blomsterbonn',),
'bluff': ('bluff',),
'bluffen': ('bluff',),
'bluffene': ('bluff',),
'bluffer': ('bluff',),
'blåmåndag': ('blåmåndag',),
'blåmåndagen': ('blåmåndag',),
'blåmåndagene': ('blåmåndag',),
'blåmåndager': ('blåmåndag',),
'bokautodafeen': ('bokautodafé',),
'bokautodafeene': ('bokautodafé',),
'bokautodafeer': ('bokautodafé',),
'bokautodafé': ('bokautodafé',),
'bokautodaféen': ('bokautodafé',),
'bokautodaféene': ('bokautodafé',),
'bokautodaféer': ('bokautodafé',),
'bokkafeen': ('bokkafé',),
'bokkafeene': ('bokkafé',),
'bokkafeer': ('bokkafé',),
'bokkafé': ('bokkafé',),
'bokkaféen': ('bokkafé',),
'bokkaféene': ('bokkafé',),
'bokkaféer': ('bokkafé',),
'bolignød': ('bolignød',),
'bolignøda': ('bolignød',),
'bolignøden': ('bolignød',),
'bolignødene': ('bolignød',),
'bolignøder': ('bolignød',),
'bomullstøy': ('bomullstøy',),
'bomullstøya': ('bomullstøy',),
'bomullstøyene': ('bomullstøy',),
'bomullstøyer': ('bomullstøy',),
'bomullstøyet': ('bomullstøy',),
'bonn': ('bonn',),
'bonnen': ('bonn',),
'bonnene': ('bonn',),
'bonner': ('bonn',),
'boomerang': ('boomerang',),
'boomerangen': ('boomerang',),
'boomerangene': ('boomerang',),
'boomeranger': ('boomerang',),
'boteråd': ('boteråd',),
'boteråda': ('boteråd',),
'boteråden': ('boteråd',),
'boterådene': ('boteråd',),
'boteråder': ('boteråd',),
'boterådet': ('boteråd',),
'boulevard': ('boulevard',),
'boulevarden': ('boulevard',),
'boulevardene': ('boulevard',),
'boulevarder': ('boulevard',),
'brannsløkking': ('brannsløkking',),
'brannsløkkinga': ('brannsløkking',),
'brannsløkkingen': ('brannsløkking',),
'brannsløkkingene': ('brannsløkking',),
'brannsløkkinger': ('brannsløkking',),
'brannsløkkingsapparat': ('brannsløkkingsapparat',),
'brannsløkkingsapparata': ('brannsløkkingsapparat',),
'brannsløkkingsapparatene': ('brannsløkkingsapparat',),
'brannsløkkingsapparater': ('brannsløkkingsapparat',),
'brannsløkkingsapparatet': ('brannsløkkingsapparat',),
'bringebærgeleen': ('bringebærgelé',),
'bringebærgeleene': ('bringebærgelé',),
'bringebærgeleer': ('bringebærgelé',),
'bringebærgelé': ('bringebærgelé',),
'bringebærgeléen': ('bringebærgelé',),
'bringebærgeléene': ('bringebærgelé',),
'bringebærgeléer': ('bringebærgelé',),
'briskelog': ('briskelog',),
'briskelogen': ('briskelog',),
'briskelogene': ('briskelog',),
'briskeloger': ('briskelog',),
'broccoli': ('broccoli',),
'broccolien': ('broccoli',),
'broccoliene': ('broccoli',),
'broccolier': ('broccoli',),
'bruksskau': ('bruksskau',),
'bruksskauen': ('bruksskau',),
'bruksskauene': ('bruksskau',),
'bruksskauer': ('bruksskau',),
'brunkoltjøra': ('brunkoltjøre',),
'brunkoltjøre': ('brunkoltjøre',),
'brunkoltjøren': ('brunkoltjøre',),
'brunkoltjørene': ('brunkoltjøre',),
'brunkoltjører': ('brunkoltjøre',),
'brunkulltjøra': ('brunkulltjøre',),
'brunkulltjøre': ('brunkulltjøre',),
'brunkulltjøren': ('brunkulltjøre',),
'brunkulltjørene': ('brunkulltjøre',),
'brunkulltjører': ('brunkulltjøre',),
'brødsbrytelse': ('brødsbrytelse',),
'brødsbrytelsen': ('brødsbrytelse',),
'brødsbrytelsene': ('brødsbrytelse',),
'brødsbrytelser': ('brødsbrytelse',),
'bråterøk': ('bråterøk',),
'bråterøken': ('bråterøk',),
'bråterøkene': ('bråterøk',),
'bråterøker': ('bråterøk',),
'bouquet': ('bouquet',),
'bouqueten': ('bouquet',),
'bouquetene': ('bouquet',),
'bouqueter': ('bouquet',),
'bonn': ('bonn',),
'bonnen': ('bonn',),
'bonnene': ('bonn',),
'bonner': ('bonn',),
'bonnbord': ('bonnbord',),
'bonnborda': ('bonnbord',),
'bonnbordene': ('bonnbord',),
'bonnborder': ('bonnbord',),
'bonnbordet': ('bonnbord',),
'bonnbånd': ('bonnbånd',),
'bonnbånda': ('bonnbånd',),
'bonnbåndene': ('bonnbånd',),
'bonnbåndet': ('bonnbånd',),
'bonnband': ('bonnband',),
'bonnbanda': ('bonnband',),
'bonnbandene': ('bonnband',),
'bonnbandet': ('bonnband',),
'bonnfall': ('bonnfall',),
'bonnfalla': ('bonnfall',),
'bonnfallene': ('bonnfall',),
'bonnfallet': ('bonnfall',),
'bonnfisk': ('bonnfisk',),
'bonnfisken': ('bonnfisk',),
'bonnfiskene': ('bonnfisk',),
'bonnfisker': ('bonnfisk',),
'bonnflata': ('bonnflate',),
'bonnflate': ('bonnflate',),
'bonnflaten': ('bonnflate',),
'bonnflatene': ('bonnflate',),
'bonnflater': ('bonnflate',),
'bonnlag': ('bonnlag',),
'bonnlaga': ('bonnlag',),
'bonnlagene': ('bonnlag',),
'bonnlaget': ('bonnlag',),
'bonnløshet': ('bonnløshet',),
'bonnløsheta': ('bonnløshet',),
'bonnløsheten': ('bonnløshet',),
'bonnløshetene': ('bonnløshet',),
'bonnløsheter': ('bonnløshet',),
'bonnmorene': ('bonnmorene',),
'bonnmorenen': ('bonnmorene',),
'bonnmorenene': ('bonnmorene',),
'bonnmorener': ('bonnmorene',),
'bonn-nivå': ('bonn-nivå',),
'bonn-nivåa': ('bonn-nivå',),
'bonn-nivåene': ('bonn-nivå',),
'bonn-nivåer': ('bonn-nivå',),
'bonn-nivået': ('bonn-nivå',),
'bonnivå': ('bonnivå',),
'bonnivåa': ('bonnivå',),
'bonnivåene': ('bonnivå',),
'bonnivåer': ('bonnivå',),
'bonnivået': ('bonnivå',),
'bonnpanna': ('bonnpanne',),
'bonnpanne': ('bonnpanne',),
'bonnpannen': ('bonnpanne',),
'bonnpannene': ('bonnpanne',),
'bonnpanner': ('bonnpanne',),
'bonnrekord': ('bonnrekord',),
'bonnrekorden': ('bonnrekord',),
'bonnrekordene': ('bonnrekord',),
'bonnrekorder': ('bonnrekord',),
'bonnstoff': ('bonnstoff',),
'bonnstoffa': ('bonnstoff',),
'bonnstoffene': ('bonnstoff',),
'bonnstoffer': ('bonnstoff',),
'bonnstoffet': ('bonnstoff',),
'bonnstrid': ('bonnstrid',),
'bonnstriden': ('bonnstrid',),
'bonnstridene': ('bonnstrid',),
'bonnstrider': ('bonnstrid',),
'bydelspoliti': ('bydelspoliti',),
'bydelspolitia': ('bydelspoliti',),
'bydelspolitiene': ('bydelspoliti',),
'bydelspolitier': ('bydelspoliti',),
'bydelspolitiet': ('bydelspoliti',),
'bygdebok': ('bygdebok',),
'bygdeboka': ('bygdebok',),
'bygdeboken': ('bygdebok',),
'bygdebøkene': ('bygdebok',),
'bygdebøker': ('bygdebok',),
'byggekomiteen': ('byggekomité',),
'byggekomiteene': ('byggekomité',),
'byggekomiteer': ('byggekomité',),
'byggekomité': ('byggekomité',),
'byggekomitéen': ('byggekomité',),
'byggekomitéene': ('byggekomité',),
'byggekomitéer': ('byggekomité',),
'byggeleier': ('byggeleier',),
'byggeleiere': ('byggeleier',),
'byggeleieren': ('byggeleier',),
'byggeleierer': ('byggeleier',),
'byggeleierne': ('byggeleier',),
'byrådsleier': ('byrådsleier',),
'byrådsleiere': ('byrådsleier',),
'byrådsleieren': ('byrådsleier',),
'byrådsleierer': ('byrådsleier',),
'byrådsleierne': ('byrådsleier',),
'bærhaust': ('bærhaust',),
'bærhausten': ('bærhaust',),
'bærhaustene': ('bærhaust',),
'bærhauster': ('bærhaust',),
'bøkeskau': ('bøkeskau',),
'bøkeskauen': ('bøkeskau',),
'bøkeskauene': ('bøkeskau',),
'bøkeskauer': ('bøkeskau',),
'canadagjess': ('canadagås',),
'canadagjessene': ('canadagås',),
'canadagjæsene': ('canadagås',),
'canadagjæser': ('canadagås',),
'canadagås': ('canadagås',),
'canadagåsa': ('canadagås',),
'canadagåsen': ('canadagås',),
'canossagang': ('canossagang',),
'canossagangen': ('canossagang',),
'canossagangene': ('canossagang',),
'canossaganger': ('canossagang',),
'canvas': ('canvas',),
'canvasa': ('canvas',),
'canvasen': ('canvas',),
'canvasene': ('canvas',),
'canvaser': ('canvas',),
'canvaset': ('canvas',),
'capotasto': ('capotasto',),
'capotastoen': ('capotasto',),
'capotastoene': ('capotasto',),
'capotastoer': ('capotasto',),
'catalonier': ('catalonier',),
'cataloniere': ('catalonier',),
'catalonieren': ('catalonier',),
'catalonierer': ('catalonier',),
'catalonierne': ('catalonier',),
'centiliter': ('centiliter',),
'centiliteren': ('centiliter',),
'centiliterne': ('centiliter',),
'champignon': ('champignon',),
'champignonen': ('champignon',),
'champignonene': ('champignon',),
'champignoner': ('champignon',),
'charme': ('charme',),
'charmen': ('charme',),
'charmene': ('charme',),
'charmer': ('charme',),
'charmør': ('charmør',),
'charmøren': ('charmør',),
'charmørene': ('charmør',),
'charmører': ('charmør',),
'codex': ('codex',),
'codexen': ('codex',),
'codexene': ('codex',),
'codexer': ('codex',),
'croquis': ('croquis',),
'croquisen': ('croquis',),
'croquisene': ('croquis',),
'croquiser': ('croquis',),
'dalbonn': ('dalbonn',),
'dalbonnen': ('dalbonn',),
'dalbonnene': ('dalbonn',),
'dalbonner': ('dalbonn',),
'dalbonn': ('dalbonn',),
'dalbonnen': ('dalbonn',),
'dalbonnene': ('dalbonn',),
'dalbonner': ('dalbonn',),
'daude': ('daude',),
'dauden': ('daude',),
'daudene': ('daude',),
'dauder': ('daude',),
'debutbok': ('debutbok',),
'debutboka': ('debutbok',),
'debutboken': ('debutbok',),
'debutbøkene': ('debutbok',),
'debutbøker': ('debutbok',),
'desiliter': ('desiliter',),
'desiliteren': ('desiliter',),
'desiliterne': ('desiliter',),
'desimeter': ('desimeter',),
'desimeteren': ('desimeter',),
'desimeterne': ('desimeter',),
'desisjonskomiteen': ('desisjonskomité',),
'desisjonskomiteene': ('desisjonskomité',),
'desisjonskomiteer': ('desisjonskomité',),
'desisjonskomité': ('desisjonskomité',),
'desisjonskomitéen': ('desisjonskomité',),
'desisjonskomitéene': ('desisjonskomité',),
'desisjonskomitéer': ('desisjonskomité',),
'diasporajødene': ('diasporajøder',),
'diasporajøder': ('diasporajøder',),
'dommereid': ('dommereid',),
'dommereiden': ('dommereid',),
'dommereidene': ('dommereid',),
'dommereider': ('dommereid',),
'dreiebok': ('dreiebok',),
'dreieboka': ('dreiebok',),
'dreieboken': ('dreiebok',),
'dreiebøkene': ('dreiebok',),
'dreiebøker': ('dreiebok',),
'drivanker': ('drivanker',),
'drivankera': ('drivanker',),
'drivankere': ('drivanker',),
'drivankeret': ('drivanker',),
'drivankra': ('drivanker',),
'drivankre': ('drivanker',),
'drivankrene': ('drivanker',),
'drivankret': ('drivanker',),
'drivfjær': ('drivfjær',),
'drivfjæra': ('drivfjær',),
'drivfjæren': ('drivfjær',),
'drivfjærene': ('drivfjær',),
'drivfjærer': ('drivfjær',),
'drivfjør': ('drivfjør',),
'drivfjøra': ('drivfjør',),
'drivfjøren': ('drivfjør',),
'drivfjørene': ('drivfjør',),
'drivfjører': ('drivfjør',),
'dronningmor': ('dronningmor',),
'dronningmora': ('dronningmor',),
'dronningmoren': ('dronningmor',),
'dronningmødre': ('dronningmor',),
'dronningmødrene': ('dronningmor',),
'dronningmødrer': ('dronningmor',),
'drømmemil': ('drømmemil',),
'drømmemila': ('drømmemil',),
'drømmemilen': ('drømmemil',),
'drømmemilene': ('drømmemil',),
'duffelcoat': ('duffelcoat',),
'duffelcoaten': ('duffelcoat',),
'duffelcoatene': ('duffelcoat',),
'duffelcoater': ('duffelcoat',),
'daude': ('daude',),
'dauden': ('daude',),
'daudene': ('daude',),
'dauder': ('daude',),
'dønnis': ('dønnis',),
'dønnisen': ('dønnis',),
'dønnisene': ('dønnis',),
'dønniser': ('dønnis',),
'eid': ('eid',),
'eiden': ('eid',),
'eidene': ('eid',),
'eider': ('eid',),
'edellauvskau': ('edellauvskau',),
'edellauvskauen': ('edellauvskau',),
'edellauvskauene': ('edellauvskau',),
'edellauvskauer': ('edellauvskau',),
'edelløvskau': ('edelløvskau',),
'edelløvskauen': ('edelløvskau',),
'edelløvskauene': ('edelløvskau',),
'edelløvskauer': ('edelløvskau',),
'eidfesta': ('eidfeste',),
'eidfeste': ('eidfeste',),
'eidfestene': ('eidfeste',),
'eidfester': ('eidfeste',),
'eidfestet': ('eidfeste',),
'eidsformular': ('eidsformular',),
'eidsformulara': ('eidsformular',),
'eidsformularen': ('eidsformular',),
'eidsformularene': ('eidsformular',),
'eidsformularer': ('eidsformular',),
'eidsformularet': ('eidsformular',),
'eggleier': ('eggleier',),
'eggleiere': ('eggleier',),
'eggleieren': ('eggleier',),
'eggleierer': ('eggleier',),
'eggleierne': ('eggleier',),
'eid': ('eid',),
'eiden': ('eid',),
'eidene': ('eid',),
'eider': ('eid',),
'eikeskau': ('eikeskau',),
'eikeskauen': ('eikeskau',),
'eikeskauene': ('eikeskau',),
'eikeskauer': ('eikeskau',),
'eiketre': ('eiketre',),
'eiketrea': ('eiketre',),
'eiketreet': ('eiketre',),
'eiketrær': ('eiketre',),
'eiketrærne': ('eiketre',),
'einerlog': ('einerlog',),
'einerlogen': ('einerlog',),
'einerlogene': ('einerlog',),
'einerloger': ('einerlog',),
'einelog': ('einelog',),
'einelogen': ('einelog',),
'einelogene': ('einelog',),
'eineloger': ('einelog',),
'eksekutivkomiteen': ('eksekutivkomité',),
'eksekutivkomiteene': ('eksekutivkomité',),
'eksekutivkomiteer': ('eksekutivkomité',),
'eksekutivkomité': ('eksekutivkomité',),
'eksekutivkomitéen': ('eksekutivkomité',),
'eksekutivkomitéene': ('eksekutivkomité',),
'eksekutivkomitéer': ('eksekutivkomité',),
'ekshaust': ('ekshaust',),
'ekshausten': ('ekshaust',),
'ekshaustene': ('ekshaust',),
'ekshauster': ('ekshaust',),
'eldtang': ('eldtang',),
'eldtanga': ('eldtang',),
'eldtangen': ('eldtang',),
'eldtengene': ('eldtang',),
'eldtenger': ('eldtang',),
'ildtang': ('ildtang',),
'ildtanga': ('ildtang',),
'ildtangen': ('ildtang',),
'ildtengene': ('ildtang',),
'ildtenger': ('ildtang',),
'elveos': ('elveos',),
'elveosen': ('elveos',),
'elveosene': ('elveos',),
'elveoser': ('elveos',),
'embetseid': ('embetseid',),
'embetseiden': ('embetseid',),
'embetseidene': ('embetseid',),
'embetseider': ('embetseid',),
'enfant terrible': ('enfant terrible',),
'enfants terribles': ('enfant terrible',),
'englevakt': ('englevakt',),
'englevakta': ('englevakt',),
'englevakten': ('englevakt',),
'englevaktene': ('englevakt',),
'englevakter': ('englevakt',),
'eplegeleen': ('eplegelé',),
'eplegeleene': ('eplegelé',),
'eplegeleer': ('eplegelé',),
'eplegelé': ('eplegelé',),
'eplegeléen': ('eplegelé',),
'eplegeléene': ('eplegelé',),
'eplegeléer': ('eplegelé',),
'epletre': ('epletre',),
'epletrea': ('epletre',),
'epletreet': ('epletre',),
'epletrær': ('epletre',),
'epletrærne': ('epletre',),
'etterskottsbevilgning': ('etterskottsbevilgning',),
'etterskottsbevilgninga': ('etterskottsbevilgning',),
'etterskottsbevilgningen': ('etterskottsbevilgning',),
'etterskottsbevilgningene': ('etterskottsbevilgning',),
'etterskottsbevilgninger': ('etterskottsbevilgning',),
'eventyrbok': ('eventyrbok',),
'eventyrboka': ('eventyrbok',),
'eventyrboken': ('eventyrbok',),
'eventyrbøkene': ('eventyrbok',),
'eventyrbøker': ('eventyrbok',),
'facilitet': ('facilitet',),
'faciliteten': ('facilitet',),
'facilitetene': ('facilitet',),
'faciliteter': ('facilitet',),
'factoring': ('factoring',),
'factoringen': ('factoring',),
'factoringene': ('factoring',),
'factoringer': ('factoring',),
'fallrep': ('fallrep',),
'fallrepa': ('fallrep',),
'fallrepet': ('fallrep',),
'femmil': ('femmil',),
'femmila': ('femmil',),
'femmilen': ('femmil',),
'femmilene': ('femmil',),
'festkomiteen': ('festkomité',),
'festkomiteene': ('festkomité',),
'festkomiteer': ('festkomité',),
'festkomité': ('festkomité',),
'festkomitéen': ('festkomité',),
'festkomitéene': ('festkomité',),
'festkomitéer': ('festkomité',),
'fiendehendene': ('fiendehånd',),
'fiendehender': ('fiendehånd',),
'fiendehånd': ('fiendehånd',),
'fiendehånda': ('fiendehånd',),
'fiendehånden': ('fiendehånd',),
'fiendehand': ('fiendehand',),
'fiendehanda': ('fiendehand',),
'fiendehanden': ('fiendehand',),
'fiendehendene': ('fiendehand',),
'fiendehender': ('fiendehand',),
'finanskomiteen': ('finanskomité',),
'finanskomiteene': ('finanskomité',),
'finanskomiteer': ('finanskomité',),
'finanskomité': ('finanskomité',),
'finanskomitéen': ('finanskomité',),
'finanskomitéene': ('finanskomité',),
'finanskomitéer': ('finanskomité',),
'fiskebensmønster': ('fiskebensmønster',),
'fiskebensmønsteret': ('fiskebensmønster',),
'fiskebensmønstra': ('fiskebensmønster',),
'fiskebensmønstre': ('fiskebensmønster',),
'fiskebensmønstrene': ('fiskebensmønster',),
'fiskebensmønstret': ('fiskebensmønster',),
'fjerdestand': ('fjerdestand',),
'fjerdestanden': ('fjerdestand',),
'fjerdestendene': ('fjerdestand',),
'fjerdestender': ('fjerdestand',),
'fjordbonn': ('fjordbonn',),
'fjordbonnen': ('fjordbonn',),
'fjordbonnene': ('fjordbonn',),
'fjordbonner': ('fjordbonn',),
'fjordbonn': ('fjordbonn',),
'fjordbonnen': ('fjordbonn',),
'fjordbonnene': ('fjordbonn',),
'fjordbonner': ('fjordbonn',),
'fjorhaust': ('fjorhaust',),
'fjorhausten': ('fjorhaust',),
'fjorhaustene': ('fjorhaust',),
'fjorhauster': ('fjorhaust',),
'fjøra': ('fjøre',),
'fjøre': ('fjøre',),
'fjøren': ('fjøre',),
'fjørene': ('fjøre',),
'fjører': ('fjøre',),
'fjøreknapp': ('fjøreknapp',),
'fjøreknappen': ('fjøreknapp',),
'fjøreknappene': ('fjøreknapp',),
'fjøreknapper': ('fjøreknapp',),
'flaskefôr': ('flaskefôr',),
'flaskefôra': ('flaskefôr',),
'flaskefôrene': ('flaskefôr',),
'flaskefôret': ('flaskefôr',),
'flaumfare': ('flaumfare',),
'flaumfaren': ('flaumfare',),
'flaumfarene': ('flaumfare',),
'flaumfarer': ('flaumfare',),
'flaumkatastrofa': ('flaumkatastrofe',),
'flaumkatastrofe': ('flaumkatastrofe',),
'flaumkatastrofen': ('flaumkatastrofe',),
'flaumkatastrofene': ('flaumkatastrofe',),
'flaumkatastrofer': ('flaumkatastrofe',),
'flaumlys': ('flaumlys',),
'flaumlysa': ('flaumlys',),
'flaumlysene': ('flaumlys',),
'flaumlyset': ('flaumlys',),
'flaumskade': ('flaumskade',),
'flaumskaden': ('flaumskade',),
'flaumskadene': ('flaumskade',),
'flaumskader': ('flaumskade',),
'flygeideen': ('flygeidé',),
'flygeideene': ('flygeidé',),
'flygeideer': ('flygeidé',),
'flygeidé': ('flygeidé',),
'flygeidéen': ('flygeidé',),
'flygeidéene': ('flygeidé',),
'flygeidéer': ('flygeidé',),
'flygeleier': ('flygeleier',),
'flygeleiere': ('flygeleier',),
'flygeleieren': ('flygeleier',),
'flygeleierer': ('flygeleier',),
'flygeleierne': ('flygeleier',),
'flyttefot': ('flyttefot',),
'flyttefoten': ('flyttefot',),
'flytteføttene': ('flyttefot',),
'flytteføtter': ('flyttefot',),
'flytting': ('flytting',),
'flyttinga': ('flytting',),
'flyttingen': ('flytting',),
'flyttingene': ('flytting',),
'flyttinger': ('flytting',),
'flyvning': ('flyvning',),
'flyvninga': ('flyvning',),
'flyvningen': ('flyvning',),
'flyvningene': ('flyvning',),
'flyvninger': ('flyvning',),
'folkemusé': ('folkemusé',),
'folkemuséa': ('folkemusé',),
'folkemuséene': ('folkemusé',),
'folkemuséer': ('folkemusé',),
'folkemuséet': ('folkemusé',),
'folketru': ('folketru',),
'folketrua': ('folketru',),
'folketruen': ('folketru',),
'folketruene': ('folketru',),
'folketruer': ('folketru',),
'fòr': ('fòr',),
'fòra': ('fòr',),
'fòren': ('fòr',),
'fòrene': ('fòr',),
'fòrer': ('fòr',),
'fordyping': ('fordyping',),
'fordypinga': ('fordyping',),
'fordypingen': ('fordyping',),
'fordypingene': ('fordyping',),
'fordypinger': ('fordyping',),
'fordjuping': ('fordjuping',),
'fordjupinga': ('fordjuping',),
'fordjupingen': ('fordjuping',),
'fordjupingene': ('fordjuping',),
'fordjupinger': ('fordjuping',),
'fordypning': ('fordypning',),
'fordypninga': ('fordypning',),
'fordypningen': ('fordypning',),
'fordypningene': ('fordypning',),
'fordypninger': ('fordypning',),
'fordjupning': ('fordjupning',),
'fordjupninga': ('fordjupning',),
'fordjupningen': ('fordjupning',),
'fordjupningene': ('fordjupning',),
'fordjupninger': ('fordjupning',),
'forsvarsattacheen': ('forsvarsattaché',),
'forsvarsattacheene': ('forsvarsattaché',),
'forsvarsattacheer': ('forsvarsattaché',),
'forsvarsattaché': ('forsvarsattaché',),
'forsvarsattachéen': ('forsvarsattaché',),
'forsvarsattachéene': ('forsvarsattaché',),
'forsvarsattachéer': ('forsvarsattaché',),
'fortaukafeen': ('fortaukafé',),
'fortaukafeene': ('fortaukafé',),
'fortaukafeer': ('fortaukafé',),
'fortaukafé': ('fortaukafé',),
'fortaukaféen': ('fortaukafé',),
'fortaukaféene': ('fortaukafé',),
'fortaukaféer': ('fortaukafé',),
'fortauskafeen': ('fortauskafé',),
'fortauskafeene': ('fortauskafé',),
'fortauskafeer': ('fortauskafé',),
'fortauskafé': ('fortauskafé',),
'fortauskaféen': ('fortauskafé',),
'fortauskaféene': ('fortauskafé',),
'fortauskaféer': ('fortauskafé',),
'fortauskafeen': ('fortauskafé',),
'fortauskafeene': ('fortauskafé',),
'fortauskafeer': ('fortauskafé',),
'fortauskafé': ('fortauskafé',),
'fortauskaféen': ('fortauskafé',),
'fortauskaféene': ('fortauskafé',),
'fortauskaféer': ('fortauskafé',),
'fortaukafeen': ('fortaukafé',),
'fortaukafeene': ('fortaukafé',),
'fortaukafeer': ('fortaukafé',),
'fortaukafé': ('fortaukafé',),
'fortaukaféen': ('fortaukafé',),
'fortaukaféene': ('fortaukafé',),
'fortaukaféer': ('fortaukafé',),
'fosterfar': ('fosterfar',),
'fosterfaren': ('fosterfar',),
'fosterfedre': ('fosterfar',),
'fosterfedrene': ('fosterfar',),
'fosterforeldre': ('fosterforeldre',),
'fosterforeldrene': ('fosterforeldre',),
'fostermor': ('fostermor',),
'fostermora': ('fostermor',),
'fostermoren': ('fostermor',),
'fostermødre': ('fostermor',),
'fostermødrene': ('fostermor',),
'fostermødrer': ('fostermor',),
'fraksjonsleier': ('fraksjonsleier',),
'fraksjonsleiere': ('fraksjonsleier',),
'fraksjonsleieren': ('fraksjonsleier',),
'fraksjonsleierer': ('fraksjonsleier',),
'fraksjonsleierne': ('fraksjonsleier',),
'frelsesarmeen': ('frelsesarmé',),
'frelsesarmeene': ('frelsesarmé',),
'frelsesarmeer': ('frelsesarmé',),
'frelsesarmé': ('frelsesarmé',),
'frelsesarméen': ('frelsesarmé',),
'frelsesarméene': ('frelsesarmé',),
'frelsesarméer': ('frelsesarmé',),
'frierfot': ('frierfot',),
'frierfoten': ('frierfot',),
'frierføttene': ('frierfot',),
'frierføtter': ('frierfot',),
'frifot': ('frifot',),
'frifoten': ('frifot',),
'friføttene': ('frifot',),
'friføtter': ('frifot',),
'frihendene': ('frihånd',),
'frihender': ('frihånd',),
'frihånd': ('frihånd',),
'frihånda': ('frihånd',),
'frihånden': ('frihånd',),
'frihand': ('frihand',),
'frihanda': ('frihand',),
'frihanden': ('frihand',),
'frihendene': ('frihand',),
'frihender': ('frihand',),
'fritidsleier': ('fritidsleier',),
'fritidsleiere': ('fritidsleier',),
'fritidsleieren': ('fritidsleier',),
'fritidsleierer': ('fritidsleier',),
'fritidsleierne': ('fritidsleier',),
'frukttre': ('frukttre',),
'frukttrea': ('frukttre',),
'frukttreet': ('frukttre',),
'frukttrær': ('frukttre',),
'frukttrærne': ('frukttre',),
'furuskau': ('furuskau',),
'furuskauen': ('furuskau',),
'furuskauene': ('furuskau',),
'furuskauer': ('furuskau',),
'fyrløkt': ('fyrløkt',),
'fyrløkta': ('fyrløkt',),
'fyrløkten': ('fyrløkt',),
'fyrløktene': ('fyrløkt',),
'fyrløkter': ('fyrløkt',),
'følgebrev': ('følgebrev',),
'følgebreva': ('følgebrev',),
'følgebrevene': ('følgebrev',),
'følgebrever': ('følgebrev',),
'følgebrevet': ('følgebrev',),
'fårefrikasseen': ('fårefrikassé',),
'fårefrikasseene': ('fårefrikassé',),
'fårefrikasseer': ('fårefrikassé',),
'fårefrikassé': ('fårefrikassé',),
'fårefrikasséen': ('fårefrikassé',),
'fårefrikasséene': ('fårefrikassé',),
'fårefrikasséer': ('fårefrikassé',),
'gærning': ('gærning',),
'gærningen': ('gærning',),
'gærningene': ('gærning',),
'gærninger': ('gærning',),
'gamlefar': ('gamlefar',),
'gamlefaren': ('gamlefar',),
'gamlefedre': ('gamlefar',),
'gamlefedrene': ('gamlefar',),
'gaselløya': ('gaselløyer',),
'gaselløyene': ('gaselløyer',),
'gaselløyer': ('gaselløyer',),
'gaselløyne': ('gaselløyer',),
'gaselløynene': ('gaselløyer',),
'gassløkt': ('gassløkt',),
'gassløkta': ('gassløkt',),
'gassløkten': ('gassløkt',),
'gassløktene': ('gassløkt',),
'gassløkter': ('gassløkt',),
'gaukemesse': ('gaukemesse',),
'gauksmesse': ('gauksmesse',),
'geitfivel': ('geitfivel',),
'geitfivelen': ('geitfivel',),
'geitfivlene': ('geitfivel',),
'geitfivler': ('geitfivel',),
'genever': ('genever',),
'geneveren': ('genever',),
'geneverene': ('genever',),
'geneverer': ('genever',),
'ghetto': ('ghetto',),
'ghettoen': ('ghetto',),
'ghettoene': ('ghetto',),
'ghettoer': ('ghetto',),
'giraff': ('giraff',),
'giraffen': ('giraff',),
'giraffene': ('giraff',),
'giraffer': ('giraff',),
'gitarsoli': ('gitarsolo',),
'gitarsoliene': ('gitarsolo',),
'gitarsolo': ('gitarsolo',),
'gitarsoloen': ('gitarsolo',),
'gitarsoloene': ('gitarsolo',),
'gitarsoloer': ('gitarsolo',),
'gjengjeld': ('gjengjeld',),
'gjengjelda': ('gjengjeld',),
'gjengjelden': ('gjengjeld',),
'gjengjeldene': ('gjengjeld',),
'gjengjelder': ('gjengjeld',),
'gjentagelsesstraff': ('gjentagelsesstraff',),
'gjentagelsesstraffen': ('gjentagelsesstraff',),
'gjentagelsesstraffene': ('gjentagelsesstraff',),
'gjentagelsesstraffer': ('gjentagelsesstraff',),
'gjentagelsestegn': ('gjentagelsestegn',),
'gjentagelsestegna': ('gjentagelsestegn',),
'gjentagelsestegnene': ('gjentagelsestegn',),
'gjentagelsestegnet': ('gjentagelsestegn',),
'gjentagelsestilfella': ('gjentagelsestilfelle',),
'gjentagelsestilfelle': ('gjentagelsestilfelle',),
'gjentagelsestilfellene': ('gjentagelsestilfelle',),
'gjentagelsestilfeller': ('gjentagelsestilfelle',),
'gjentagelsestilfellet': ('gjentagelsestilfelle',),
'gjestebok': ('gjestebok',),
'gjesteboka': ('gjestebok',),
'gjesteboken': ('gjestebok',),
'gjestebøkene': ('gjestebok',),
'gjestebøker': ('gjestebok',),
'glasfiberski': ('glasfiberski',),
'glasfiberskia': ('glasfiberski',),
'glasfiberskien': ('glasfiberski',),
'glasfiberskiene': ('glasfiberski',),
'glasfiberskier': ('glasfiberski',),
'glassfiberski': ('glassfiberski',),
'glassfiberskia': ('glassfiberski',),
'glassfiberskien': ('glassfiberski',),
'glassfiberskiene': ('glassfiberski',),
'glassfiberskier': ('glassfiberski',),
'glassfiberski': ('glassfiberski',),
'glassfiberskia': ('glassfiberski',),
'glassfiberskien': ('glassfiberski',),
'glassfiberskiene': ('glassfiberski',),
'glassfiberskier': ('glassfiberski',),
'glasfiberski': ('glasfiberski',),
'glasfiberskia': ('glasfiberski',),
'glasfiberskien': ('glasfiberski',),
'glasfiberskiene': ('glasfiberski',),
'glasfiberskier': ('glasfiberski',),
'glassøya': ('glassøye',),
'glassøye': ('glassøye',),
'glassøyene': ('glassøye',),
'glassøyer': ('glassøye',),
'glassøyet': ('glassøye',),
'glassøyne': ('glassøye',),
'glassøynene': ('glassøye',),
'glasøya': ('glasøye',),
'glasøye': ('glasøye',),
'glasøyene': ('glasøye',),
'glasøyer': ('glasøye',),
'glasøyet': ('glasøye',),
'glasøyne': ('glasøye',),
'glasøynene': ('glasøye',),
'glasøya': ('glasøye',),
'glasøye': ('glasøye',),
'glasøyene': ('glasøye',),
'glasøyer': ('glasøye',),
'glasøyet': ('glasøye',),
'glasøyne': ('glasøye',),
'glasøynene': ('glasøye',),
'glassøya': ('glassøye',),
'glassøye': ('glassøye',),
'glassøyene': ('glassøye',),
'glassøyer': ('glassøye',),
'glassøyet': ('glassøye',),
'glassøyne': ('glassøye',),
'glassøynene': ('glassøye',),
'glosebok': ('glosebok',),
'gloseboka': ('glosebok',),
'gloseboken': ('glosebok',),
'glosebøkene': ('glosebok',),
'glosebøker': ('glosebok',),
'go-cart': ('go-cart',),
'go-carten': ('go-cart',),
'go-cartene': ('go-cart',),
'go-carter': ('go-cart',),
'gomme': ('gomme',),
'gommen': ('gomme',),
'gommene': ('gomme',),
'gommer': ('gomme',),
'grad': ('grad',),
'graden': ('grad',),
'gradene': ('grad',),
'grader': ('grad',),
'granskau': ('granskau',),
'granskauen': ('granskau',),
'granskauene': ('granskau',),
'granskauer': ('granskau',),
'grantre': ('grantre',),
'grantrea': ('grantre',),
'grantreet': ('grantre',),
'grantrær': ('grantre',),
'grantrærne': ('grantre',),
'grat': ('grat',),
'graten': ('grat',),
'gratene': ('grat',),
'grater': ('grat',),
'grathøvel': ('grathøvel',),
'grathøvelen': ('grathøvel',),
'grathøvlene': ('grathøvel',),
'grathøvler': ('grathøvel',),
'gressrot': ('gressrot',),
'gressrota': ('gressrot',),
'gressroten': ('gressrot',),
'gressrøttene': ('gressrot',),
'gressrøtter': ('gressrot',),
'grasrot': ('grasrot',),
'grasrota': ('grasrot',),
'grasroten': ('grasrot',),
'grasrøttene': ('grasrot',),
'grasrøtter': ('grasrot',),
'grev': ('grev',),
'greven': ('grev',),
'grevene': ('grev',),
'grever': ('grev',),
'gripefot': ('gripefot',),
'gripefoten': ('gripefot',),
'gripeføttene': ('gripefot',),
'gripeføtter': ('gripefot',),
'grobonn': ('grobonn',),
'grobonnen': ('grobonn',),
'grobonnene': ('grobonn',),
'grobonner': ('grobonn',),
'grunnbok': ('grunnbok',),
'grunnboka': ('grunnbok',),
'grunnboken': ('grunnbok',),
'grunnbøkene': ('grunnbok',),
'grunnbøker': ('grunnbok',),
'gruppeleier': ('gruppeleier',),
'gruppeleiere': ('gruppeleier',),
'gruppeleieren': ('gruppeleier',),
'gruppeleierer': ('gruppeleier',),
'gruppeleierne': ('gruppeleier',),
'grønfôr': ('grønfôr',),
'grønfôra': ('grønfôr',),
'grønfôrene': ('grønfôr',),
'grønfôret': ('grønfôr',),
'grønnfôr': ('grønnfôr',),
'grønnfôra': ('grønnfôr',),
'grønnfôrene': ('grønnfôr',),
'grønnfôret': ('grønnfôr',),
'grønnfôr': ('grønnfôr',),
'grønnfôra': ('grønnfôr',),
'grønnfôrene': ('grønnfôr',),
'grønnfôret': ('grønnfôr',),
'grønfôr': ('grønfôr',),
'grønfôra': ('grønfôr',),
'grønfôrene': ('grønfôr',),
'grønfôret': ('grønfôr',),
'gudmor': ('gudmor',),
'gudmora': ('gudmor',),
'gudmoren': ('gudmor',),
'gudmødre': ('gudmor',),
'gudmødrene': ('gudmor',),
'gudmødrer': ('gudmor',),
'gudstru': ('gudstru',),
'gudstrua': ('gudstru',),
'gudstruen': ('gudstru',),
'gudstruene': ('gudstru',),
'gudstruer': ('gudstru',),
'guerilla': ('guerilla',),
'guerillaen': ('guerilla',),
'guerillaene': ('guerilla',),
'guerillaer': ('guerilla',),
'guillotine': ('guillotine',),
'guillotinen': ('guillotine',),
'guillotinene': ('guillotine',),
'guillotiner': ('guillotine',),
'gummisko': ('gummisko',),
'gummiskoa': ('gummisko',),
'gummiskoen': ('gummisko',),
'gummiskoene': ('gummisko',),
'gummiskor': ('gummisko',),
'gummiskorne': ('gummisko',),
'gummitre': ('gummitre',),
'gummitrea': ('gummitre',),
'gummitreet': ('gummitre',),
'gummitrær': ('gummitre',),
'gummitrærne': ('gummitre',),
'halefjær': ('halefjær',),
'halefjæra': ('halefjær',),
'halefjæren': ('halefjær',),
'halefjærene': ('halefjær',),
'halefjærer': ('halefjær',),
'halefjør': ('halefjør',),
'halefjøra': ('halefjør',),
'halefjøren': ('halefjør',),
'halefjørene': ('halefjør',),
'halefjører': ('halefjør',),
'halerot': ('halerot',),
'halerota': ('halerot',),
'haleroten': ('halerot',),
'halerøttene': ('halerot',),
'halerøtter': ('halerot',),
'halv': ('halv',),
'halvleier': ('halvleier',),
'halvleiere': ('halvleier',),
'halvleieren': ('halvleier',),
'halvleierer': ('halvleier',),
'halvleierne': ('halvleier',),
'hansastad': ('hansastad',),
'hansastaden': ('hansastad',),
'hansastedene': ('hansastad',),
'hansasteder': ('hansastad',),
'haremor': ('haremor',),
'haremora': ('haremor',),
'haremoren': ('haremor',),
'haremødre': ('haremor',),
'haremødrene': ('haremor',),
'haremødrer': ('haremor',),
'horv': ('horv',),
'horva': ('horv',),
'horven': ('horv',),
'horvene': ('horv',),
'horver': ('horv',),
'haust': ('haust',),
'hausten': ('haust',),
'haustene': ('haust',),
'hauster': ('haust',),
'havbonn': ('havbonn',),
'havbonnen': ('havbonn',),
'havbonnene': ('havbonn',),
'havbonner': ('havbonn',),
'have': ('have',),
'haven': ('have',),
'havene': ('have',),
'haver': ('have',),
'hektoliter': ('hektoliter',),
'hektoliteren': ('hektoliter',),
'hektoliterne': ('hektoliter',),
'heldagspost': ('heldagspost',),
'heldagsposten': ('heldagspost',),
'heldagspostene': ('heldagspost',),
'heldagsposter': ('heldagspost',),
'helmjølk': ('helmjølk',),
'helmjølka': ('helmjølk',),
'helmjølken': ('helmjølk',),
'helmjølkene': ('helmjølk',),
'helmjølker': ('helmjølk',),
'heilmjølk': ('heilmjølk',),
'heilmjølka': ('heilmjølk',),
'heilmjølken': ('heilmjølk',),
'heilmjølkene': ('heilmjølk',),
'heilmjølker': ('heilmjølk',),
'Herren': ('Herren',),
'hestesko': ('hestesko',),
'hesteskoa': ('hestesko',),
'hesteskoen': ('hestesko',),
'hesteskoene': ('hestesko',),
'hesteskor': ('hestesko',),
'hesteskorne': ('hestesko',),
'historiebok': ('historiebok',),
'historieboka': ('historiebok',),
'historieboken': ('historiebok',),
'historiebøkene': ('historiebok',),
'historiebøker': ('historiebok',),
'hjelpefôr': ('hjelpefôr',),
'hjelpefôra': ('hjelpefôr',),
'hjelpefôrene': ('hjelpefôr',),
'hjelpefôret': ('hjelpefôr',),
'hjertearytmi': ('hjertearytmi',),
'hjertearytmien': ('hjertearytmi',),
'hjertearytmiene': ('hjertearytmi',),
'hjertearytmier': ('hjertearytmi',),
'hjerterot': ('hjerterot',),
'hjerterota': ('hjerterot',),
'hjerteroten': ('hjerterot',),
'hjerterøttene': ('hjerterot',),
'hjerterøtter': ('hjerterot',),
'hodebonn': ('hodebonn',),
'hodebonnen': ('hodebonn',),
'hodebonnene': ('hodebonn',),
'hodebonner': ('hodebonn',),
'horv': ('horv',),
'horva': ('horv',),
'horven': ('horv',),
'horvene': ('horv',),
'horver': ('horv',),
'hovedbok': ('hovedbok',),
'hovedboka': ('hovedbok',),
'hovedboken': ('hovedbok',),
'hovedbøkene': ('hovedbok',),
'hovedbøker': ('hovedbok',),
'hovedstad': ('hovedstad',),
'hovedstaden': ('hovedstad',),
'hovedstedene': ('hovedstad',),
'hovedsteder': ('hovedstad',),
'huldretjern': ('huldretjern',),
'huldretjerna': ('huldretjern',),
'huldretjernene': ('huldretjern',),
'huldretjernet': ('huldretjern',),
'huldretjørn': ('huldretjørn',),
'huldretjørna': ('huldretjørn',),
'huldretjørnen': ('huldretjørn',),
'huldretjørnene': ('huldretjørn',),
'huldretjørner': ('huldretjørn',),
'huldretjørnet': ('huldretjørn',),
'hulltang': ('hulltang',),
'hulltanga': ('hulltang',),
'hulltangen': ('hulltang',),
'hulltengene': ('hulltang',),
'hulltenger': ('hulltang',),
'holtang': ('holtang',),
'holtanga': ('holtang',),
'holtangen': ('holtang',),
'holtengene': ('holtang',),
'holtenger': ('holtang',),
'hokjønn': ('hokjønn',),
'hokjønna': ('hokjønn',),
'hokjønnene': ('hokjønn',),
'hokjønnet': ('hokjønn',),
'hokjønnsord': ('hokjønnsord',),
'hokjønnsorda': ('hokjønnsord',),
'hokjønnsordene': ('hokjønnsord',),
'hokjønnsordet': ('hokjønnsord',),
'hoblomst': ('hoblomst',),
'hoblomsten': ('hoblomst',),
'hoblomstene': ('hoblomst',),
'hoblomster': ('hoblomst',),
'hodyr': ('hodyr',),
'hodyra': ('hodyr',),
'hodyrene': ('hodyr',),
'hodyret': ('hodyr',),
'hofisk': ('hofisk',),
'hofisken': ('hofisk',),
'hofiskene': ('hofisk',),
'hofisker': ('hofisk',),
'hofugl': ('hofugl',),
'hofuglen': ('hofugl',),
'hofuglene': ('hofugl',),
'hofugler': ('hofugl',),
'hokatt': ('hokatt',),
'hokatten': ('hokatt',),
'hokattene': ('hokatt',),
'hokatter': ('hokatt',),
'hoplanta': ('hoplante',),
'hoplante': ('hoplante',),
'hoplanten': ('hoplante',),
'hoplantene': ('hoplante',),
'hoplanter': ('hoplante',),
'horakle': ('horakle',),
'horaklen': ('horakle',),
'horaklene': ('horakle',),
'horakler': ('horakle',),
'husmor': ('husmor',),
'husmora': ('husmor',),
'husmoren': ('husmor',),
'husmødre': ('husmor',),
'husmødrene': ('husmor',),
'husmødrer': ('husmor',),
'hvirvel': ('hvirvel',),
'hvirvelen': ('hvirvel',),
'hvirvlene': ('hvirvel',),
'hvirvler': ('hvirvel',),
'hvitbok': ('hvitbok',),
'hvitboka': ('hvitbok',),
'hvitboken': ('hvitbok',),
'hvitbøkene': ('hvitbok',),
'hvitbøker': ('hvitbok',),
'kvitbok': ('kvitbok',),
'kvitboka': ('kvitbok',),
'kvitboken': ('kvitbok',),
'kvitbøkene': ('kvitbok',),
'kvitbøker': ('kvitbok',),
'hvitlaukfedd': ('hvitlaukfedd',),
'hvitlaukfedda': ('hvitlaukfedd',),
'hvitlaukfeddene': ('hvitlaukfedd',),
'hvitlaukfeddet': ('hvitlaukfedd',),
'hvitlaukpulver': ('hvitlaukpulver',),
'hvitlaukpulvera': ('hvitlaukpulver',),
'hvitlaukpulvere': ('hvitlaukpulver',),
'hvitlaukpulveret': ('hvitlaukpulver',),
'hvitlaukpulverne': ('hvitlaukpulver',),
'høgspenn': ('høgspenn',),
'høgspenna': ('høgspenn',),
'høgspennene': ('høgspenn',),
'høgspennet': ('høgspenn',),
'høgtalaleranlegg': ('høgtalaleranlegg',),
'høgtalaleranlegga': ('høgtalaleranlegg',),
'høgtalaleranleggene': ('høgtalaleranlegg',),
'høgtalaleranlegget': ('høgtalaleranlegg',),
'høl': ('høl',),
'høla': ('høl',),
'hølene': ('høl',),
'høler': ('høl',),
'hølet': ('høl',),
'hønemor': ('hønemor',),
'hønemora': ('hønemor',),
'hønemoren': ('hønemor',),
'hønemødre': ('hønemor',),
'hønemødrene': ('hønemor',),
'hønemødrer': ('hønemor',),
'hønsefôr': ('hønsefôr',),
'hønsefôra': ('hønsefôr',),
'hønsefôrene': ('hønsefôr',),
'hønsefôret': ('hønsefôr',),
'hønsefrikasseen': ('hønsefrikassé',),
'hønsefrikasseene': ('hønsefrikassé',),
'hønsefrikasseer': ('hønsefrikassé',),
'hønsefrikassé': ('hønsefrikassé',),
'hønsefrikasséen': ('hønsefrikassé',),
'hønsefrikasséene': ('hønsefrikassé',),
'hønsefrikasséer': ('hønsefrikassé',),
'haust': ('haust',),
'hausten': ('haust',),
'haustene': ('haust',),
'hauster': ('haust',),
'haustbær': ('haustbær',),
'haustbæra': ('haustbær',),
'haustbærene': ('haustbær',),
'haustbæret': ('haustbær',),
'haustjamdøgn': ('haustjamdøgn',),
'haustjamdøgna': ('haustjamdøgn',),
'haustjamdøgnene': ('haustjamdøgn',),
'haustjamdøgnet': ('haustjamdøgn',),
'haustjevndøgn': ('haustjevndøgn',),
'haustjevndøgna': ('haustjevndøgn',),
'haustjevndøgnene': ('haustjevndøgn',),
'haustjevndøgnet': ('haustjevndøgn',),
'haustmåned': ('haustmåned',),
'haustmåneden': ('haustmåned',),
'haustmånedene': ('haustmåned',),
'haustmåneder': ('haustmåned',),
'haustpart': ('haustpart',),
'haustparten': ('haustpart',),
'haustpartene': ('haustpart',),
'haustparter': ('haustpart',),
'haustrug': ('haustrug',),
'haustrugen': ('haustrug',),
'haustrugene': ('haustrug',),
'haustruger': ('haustrug',),
'hauststorm': ('hauststorm',),
'hauststormen': ('hauststorm',),
'hauststormene': ('hauststorm',),
'hauststormer': ('hauststorm',),
'hausttakkefest': ('hausttakkefest',),
'hausttakkefesten': ('hausttakkefest',),
'hausttakkefestene': ('hausttakkefest',),
'hausttakkefester': ('hausttakkefest',),
'haustull': ('haustull',),
'haustulla': ('haustull',),
'haustullen': ('haustull',),
'haustullene': ('haustull',),
'haustuller': ('haustull',),
'høgfjellshotell': ('høgfjellshotell',),
'høgfjellshotella': ('høgfjellshotell',),
'høgfjellshotellene': ('høgfjellshotell',),
'høgfjellshotellet': ('høgfjellshotell',),
'høyrefot': ('høyrefot',),
'høyrefoten': ('høyrefot',),
'høyreføttene': ('høyrefot',),
'høyreføtter': ('høyrefot',),
'høgrefot': ('høgrefot',),
'høgrefoten': ('høgrefot',),
'høgreføttene': ('høgrefot',),
'høgreføtter': ('høgrefot',),
'høyspenn': ('høyspenn',),
'høyspenna': ('høyspenn',),
'høyspennene': ('høyspenn',),
'høyspennet': ('høyspenn',),
'håndbok': ('håndbok',),
'håndboka': ('håndbok',),
'håndboken': ('håndbok',),
'håndbøkene': ('håndbok',),
'håndbøker': ('håndbok',),
'handbok': ('handbok',),
'handboka': ('handbok',),
'handboken': ('handbok',),
'handbøkene': ('handbok',),
'handbøker': ('handbok',),
'håndsløkkingsapparat': ('håndsløkkingsapparat',),
'håndsløkkingsapparata': ('håndsløkkingsapparat',),
'håndsløkkingsapparatene': ('håndsløkkingsapparat',),
'håndsløkkingsapparater': ('håndsløkkingsapparat',),
'håndsløkkingsapparatet': ('håndsløkkingsapparat',),
'handsløkkingsapparat': ('handsløkkingsapparat',),
'handsløkkingsapparata': ('handsløkkingsapparat',),
'handsløkkingsapparatene': ('handsløkkingsapparat',),
'handsløkkingsapparater': ('handsløkkingsapparat',),
'handsløkkingsapparatet': ('handsløkkingsapparat',),
'hårklypp': ('hårklypp',),
'hårklyppen': ('hårklypp',),
'hårklyppene': ('hårklypp',),
'hårklypper': ('hårklypp',),
'hårrot': ('hårrot',),
'hårrota': ('hårrot',),
'hårroten': ('hårrot',),
'hårrøttene': ('hårrot',),
'hårrøtter': ('hårrot',),
'hårspenna': ('hårspenne',),
'hårspenne': ('hårspenne',),
'hårspennen': ('hårspenne',),
'hårspennene': ('hårspenne',),
'hårspenner': ('hårspenne',),
'hårspennet': ('hårspenne',),
'iakttagelsesevna': ('iakttagelsesevne',),
'iakttagelsesevne': ('iakttagelsesevne',),
'iakttagelsesevnen': ('iakttagelsesevne',),
'iakttagelsesevnene': ('iakttagelsesevne',),
'iakttagelsesevner': ('iakttagelsesevne',),
'ikke-leier': ('ikke-leier',),
'ikke-leiere': ('ikke-leier',),
'ikke-leieren': ('ikke-leier',),
'ikke-leierer': ('ikke-leier',),
'ikke-leierne': ('ikke-leier',),
'ildhus': ('ildhus',),
'ildhusa': ('ildhus',),
'ildhusene': ('ildhus',),
'ildhuset': ('ildhus',),
'ildtang': ('ildtang',),
'ildtanga': ('ildtang',),
'ildtangen': ('ildtang',),
'ildtengene': ('ildtang',),
'ildtenger': ('ildtang',),
'eldtang': ('eldtang',),
'eldtanga': ('eldtang',),
'eldtangen': ('eldtang',),
'eldtengene': ('eldtang',),
'eldtenger': ('eldtang',),
'ingefærøl': ('ingefærøl',),
'ingefærøla': ('ingefærøl',),
'ingefærølene': ('ingefærøl',),
'ingefærølet': ('ingefærøl',),
'innefôring': ('innefôring',),
'innefôringa': ('innefôring',),
'innefôringen': ('innefôring',),
'innefôringene': ('innefôring',),
'innefôringer': ('innefôring',),
'innhugg': ('innhugg',),
'innhugga': ('innhugg',),
'innhuggene': ('innhugg',),
'innhugget': ('innhugg',),
'innleier': ('innleier',),
'innleiere': ('innleier',),
'innleieren': ('innleier',),
'innleierer': ('innleier',),
'innleierne': ('innleier',),
'innleier': ('innleier',),
'innleiere': ('innleier',),
'innleieren': ('innleier',),
'innleierer': ('innleier',),
'innleierne': ('innleier',),
'instituttstyrer': ('instituttstyrer',),
'instituttstyrere': ('instituttstyrer',),
'instituttstyreren': ('instituttstyrer',),
'instituttstyrerer': ('instituttstyrer',),
'instituttstyrerne': ('instituttstyrer',),
'invariant': ('invariant',),
'invarianten': ('invariant',),
'invariantene': ('invariant',),
'invarianter': ('invariant',),
'invariant': ('invariant',),
'invarianten': ('invariant',),
'invariantene': ('invariant',),
'invarianter': ('invariant',),
'iscenesetting': ('iscenesetting',),
'iscenesettinga': ('iscenesetting',),
'iscenesettingen': ('iscenesetting',),
'iscenesettingene': ('iscenesetting',),
'iscenesettinger': ('iscenesetting',),
'jasmin': ('jasmin',),
'jasminen': ('jasmin',),
'jasminene': ('jasmin',),
'jasminer': ('jasmin',),
'jegertrap': ('jegertrap',),
'jernbaneferja': ('jernbaneferje',),
'jernbaneferje': ('jernbaneferje',),
'jernbaneferjen': ('jernbaneferje',),
'jernbaneferjene': ('jernbaneferje',),
'jernbaneferjer': ('jernbaneferje',),
'jernbanekupeen': ('jernbanekupé',),
'jernbanekupeene': ('jernbanekupé',),
'jernbanekupeer': ('jernbanekupé',),
'jernbanekupé': ('jernbanekupé',),
'jernbanekupéen': ('jernbanekupé',),
'jernbanekupéene': ('jernbanekupé',),
'jernbanekupéer': ('jernbanekupé',),
'jernhendene': ('jernhånd',),
'jernhender': ('jernhånd',),
'jernhånd': ('jernhånd',),
'jernhånda': ('jernhånd',),
'jernhånden': ('jernhånd',),
'juletre': ('juletre',),
'juletrea': ('juletre',),
'juletreet': ('juletre',),
'juletrær': ('juletre',),
'juletrærne': ('juletre',),
'juleøl': ('juleøl',),
'juleøla': ('juleøl',),
'juleølene': ('juleøl',),
'juleølet': ('juleøl',),
'justiskomiteen': ('justiskomité',),
'justiskomiteene': ('justiskomité',),
'justiskomiteer': ('justiskomité',),
'justiskomité': ('justiskomité',),
'justiskomitéen': ('justiskomité',),
'justiskomitéene': ('justiskomité',),
'justiskomitéer': ('justiskomité',),
'kakebonn': ('kakebonn',),
'kakebonnen': ('kakebonn',),
'kakebonnene': ('kakebonn',),
'kakebonner': ('kakebonn',),
'kambrik': ('kambrik',),
'kambriken': ('kambrik',),
'kambrikene': ('kambrik',),
'kambriker': ('kambrik',),
'kamfertre': ('kamfertre',),
'kamfertrea': ('kamfertre',),
'kamfertreet': ('kamfertre',),
'kamfertrær': ('kamfertre',),
'kamfertrærne': ('kamfertre',),
'kampdikting': ('kampdikting',),
'kampdiktinga': ('kampdikting',),
'kampdiktingen': ('kampdikting',),
'kampdiktingene': ('kampdikting',),
'kampdiktinger': ('kampdikting',),
'kampleier': ('kampleier',),
'kampleiere': ('kampleier',),
'kampleieren': ('kampleier',),
'kampleierer': ('kampleier',),
'kampleierne': ('kampleier',),
'kapittelsbok': ('kapittelsbok',),
'kapittelsboka': ('kapittelsbok',),
'kapittelsboken': ('kapittelsbok',),
'kapittelsbøkene': ('kapittelsbok',),
'kapittelsbøker': ('kapittelsbok',),
'karakterbok': ('karakterbok',),
'karakterboka': ('karakterbok',),
'karakterboken': ('karakterbok',),
'karakterbøkene': ('karakterbok',),
'karakterbøker': ('karakterbok',),
'kassabok': ('kassabok',),
'kassaboka': ('kassabok',),
'kassaboken': ('kassabok',),
'kassabøkene': ('kassabok',),
'kassabøker': ('kassabok',),
'kassebok': ('kassebok',),
'kasseboka': ('kassebok',),
'kasseboken': ('kassebok',),
'kassebøkene': ('kassebok',),
'kassebøker': ('kassebok',),
'kastanjetre': ('kastanjetre',),
'kastanjetrea': ('kastanjetre',),
'kastanjetreet': ('kastanjetre',),
'kastanjetrær': ('kastanjetre',),
'kastanjetrærne': ('kastanjetre',),
'katteøya': ('katteøye',),
'katteøye': ('katteøye',),
'katteøyene': ('katteøye',),
'katteøyer': ('katteøye',),
'katteøyet': ('katteøye',),
'katteøyne': ('katteøye',),
'katteøynene': ('katteøye',),
'kilerem': ('kilerem',),
'kileremma': ('kilerem',),
'kileremmen': ('kilerem',),
'kileremmene': ('kilerem',),
'kileremmer': ('kilerem',),
'kilometer': ('kilometer',),
'kilometeren': ('kilometer',),
'kilometerne': ('kilometer',),
'kirkebok': ('kirkebok',),
'kirkeboka': ('kirkebok',),
'kirkeboken': ('kirkebok',),
'kirkebøkene': ('kirkebok',),
'kirkebøker': ('kirkebok',),
'kirkefader': ('kirkefader',),
'kirkefaderen': ('kirkefader',),
'kirkefedre': ('kirkefader',),
'kirkefedrene': ('kirkefader',),
'kirkesokn': ('kirkesokn',),
'kirkesokna': ('kirkesokn',),
'kirkesoknen': ('kirkesokn',),
'kirkesoknene': ('kirkesokn',),
'kirkesokner': ('kirkesokn',),
'kirkesoknet': ('kirkesokn',),
'kirsebærtre': ('kirsebærtre',),
'kirsebærtrea': ('kirsebærtre',),
'kirsebærtreet': ('kirsebærtre',),
'kirsebærtrær': ('kirsebærtre',),
'kirsebærtrærne': ('kirsebærtre',),
'kistebonn': ('kistebonn',),
'kistebonnen': ('kistebonn',),
'kistebonnene': ('kistebonn',),
'kistebonner': ('kistebonn',),
'kjerkebok': ('kjerkebok',),
'kjerkeboka': ('kjerkebok',),
'kjerkeboken': ('kjerkebok',),
'kjerkebøkene': ('kjerkebok',),
'kjerkebøker': ('kjerkebok',),
'kjerringråd': ('kjerringråd',),
'kjerringråda': ('kjerringråd',),
'kjerringråden': ('kjerringråd',),
'kjerringrådene': ('kjerringråd',),
'kjerringråder': ('kjerringråd',),
'kjerringrådet': ('kjerringråd',),
'kladdebok': ('kladdebok',),
'kladdeboka': ('kladdebok',),
'kladdeboken': ('kladdebok',),
'kladdebøkene': ('kladdebok',),
'kladdebøker': ('kladdebok',),
'klangbonn': ('klangbonn',),
'klangbonnen': ('klangbonn',),
'klangbonnene': ('klangbonn',),
'klangbonner': ('klangbonn',),
'klypparkiv': ('klypparkiv',),
'klypparkiva': ('klypparkiv',),
'klypparkivene': ('klypparkiv',),
'klypparkiver': ('klypparkiv',),
'klypparkivet': ('klypparkiv',),
'klyppekort': ('klyppekort',),
'klyppekorta': ('klyppekort',),
'klyppekortene': ('klyppekort',),
'klyppekortet': ('klyppekort',),
'klypper': ('klypper',),
'klyppere': ('klypper',),
'klypperen': ('klypper',),
'klypperer': ('klypper',),
'klypperne': ('klypper',),
'klokkertru': ('klokkertru',),
'klokkertrua': ('klokkertru',),
'klokkertruen': ('klokkertru',),
'klokkertruene': ('klokkertru',),
'klokkertruer': ('klokkertru',),
'klumpfot': ('klumpfot',),
'klumpfoten': ('klumpfot',),
'klumpføttene': ('klumpfot',),
'klumpføtter': ('klumpfot',),
'klypper': ('klypper',),
'klyppere': ('klypper',),
'klypperen': ('klypper',),
'klypperer': ('klypper',),
'klypperne': ('klypper',),
'klyssfôring': ('klyssfôring',),
'klyssfôringa': ('klyssfôring',),
'klyssfôringen': ('klyssfôring',),
'klyssfôringene': ('klyssfôring',),
'klyssfôringer': ('klyssfôring',),
'kneskjell': ('kneskjell',),
'kneskjella': ('kneskjell',),
'kneskjellen': ('kneskjell',),
'kneskjellene': ('kneskjell',),
'kneskjellet': ('kneskjell',),
'knipetang': ('knipetang',),
'knipetanga': ('knipetang',),
'knipetangen': ('knipetang',),
'knipetengene': ('knipetang',),
'knipetenger': ('knipetang',),
'kopparkjel': ('kopparkjel',),
'kopparkjelen': ('kopparkjel',),
'kopparkjelene': ('kopparkjel',),
'kopparkjeler': ('kopparkjel',),
'kopparstikk': ('kopparstikk',),
'kopparstikka': ('kopparstikk',),
'kopparstikkene': ('kopparstikk',),
'kopparstikket': ('kopparstikk',),
'kokebok': ('kokebok',),
'kokeboka': ('kokebok',),
'kokeboken': ('kokebok',),
'kokebøkene': ('kokebok',),
'kokebøker': ('kokebok',),
'kollokvieleier': ('kollokvieleier',),
'kollokvieleiere': ('kollokvieleier',),
'kollokvieleieren': ('kollokvieleier',),
'kollokvieleierer': ('kollokvieleier',),
'kollokvieleierne': ('kollokvieleier',),
'kong': ('kong',),
'kongen': ('kong',),
'kongene': ('kong',),
'konger': ('kong',),
'konstruksjonstegning': ('konstruksjonstegning',),
'konstruksjonstegninga': ('konstruksjonstegning',),
'konstruksjonstegningen': ('konstruksjonstegning',),
'konstruksjonstegningene': ('konstruksjonstegning',),
'konstruksjonstegninger': ('konstruksjonstegning',),
'konsummjølk': ('konsummjølk',),
'konsummjølka': ('konsummjølk',),
'konsummjølken': ('konsummjølk',),
'konsummjølkene': ('konsummjølk',),
'konsummjølker': ('konsummjølk',),
'koppar': ('koppar',),
'koppara': ('koppar',),
'kopparene': ('koppar',),
'kopparet': ('koppar',),
'koppar': ('koppar',),
'koppara': ('koppar',),
'kopparene': ('koppar',),
'kopparet': ('koppar',),
'koppargruva': ('koppargruve',),
'koppargruve': ('koppargruve',),
'koppargruven': ('koppargruve',),
'koppargruvene': ('koppargruve',),
'koppargruver': ('koppargruve',),
'kopparhud': ('kopparhud',),
'kopparhuda': ('kopparhud',),
'kopparhuden': ('kopparhud',),
'kopparhudene': ('kopparhud',),
'kopparhuder': ('kopparhud',),
'kopparkis': ('kopparkis',),
'kopparkisen': ('kopparkis',),
'kopparkisene': ('kopparkis',),
'kopparkiser': ('kopparkis',),
'kopparkjele': ('kopparkjele',),
'kopparkjelen': ('kopparkjele',),
'kopparkjelene': ('kopparkjele',),
'kopparkjeler': ('kopparkjele',),
'kopparnagle': ('kopparnagle',),
'kopparnaglen': ('kopparnagle',),
'kopparnaglene': ('kopparnagle',),
'kopparnagler': ('kopparnagle',),
'kopparstikk': ('kopparstikk',),
'kopparstikka': ('kopparstikk',),
'kopparstikkene': ('kopparstikk',),
'kopparstikket': ('kopparstikk',),
'koppartråd': ('koppartråd',),
'koppartråden': ('koppartråd',),
'koppartrådene': ('koppartråd',),
'koppartråder': ('koppartråd',),
'kraftfôr': ('kraftfôr',),
'kraftfôra': ('kraftfôr',),
'kraftfôrene': ('kraftfôr',),
'kraftfôret': ('kraftfôr',),
'krattskau': ('krattskau',),
'krattskauen': ('krattskau',),
'krattskauene': ('krattskau',),
'krattskauer': ('krattskau',),
'krimbok': ('krimbok',),
'krimboka': ('krimbok',),
'krimboken': ('krimbok',),
'krimbøkene': ('krimbok',),
'krimbøker': ('krimbok',),
'kristentru': ('kristentru',),
'kristentrua': ('kristentru',),
'kristentruen': ('kristentru',),
'kristentruene': ('kristentru',),
'kristentruer': ('kristentru',),
'kronglebjørk': ('kronglebjørk',),
'kronglebjørka': ('kronglebjørk',),
'kronglebjørken': ('kronglebjørk',),
'kronglebjørkene': ('kronglebjørk',),
'kronglebjørker': ('kronglebjørk',),
'kronglefuru': ('kronglefuru',),
'kronglefurua': ('kronglefuru',),
'kronglefuruen': ('kronglefuru',),
'kronglefuruene': ('kronglefuru',),
'kronglefuruer': ('kronglefuru',),
'kruttrøk': ('kruttrøk',),
'kruttrøken': ('kruttrøk',),
'kruttrøkene': ('kruttrøk',),
'kruttrøker': ('kruttrøk',),
'krønikebok': ('krønikebok',),
'krønikeboka': ('krønikebok',),
'krønikeboken': ('krønikebok',),
'krønikebøkene': ('krønikebok',),
'krønikebøker': ('krønikebok',),
'krøtterfôr': ('krøtterfôr',),
'krøtterfôra': ('krøtterfôr',),
'krøtterfôrene': ('krøtterfôr',),
'krøtterfôret': ('krøtterfôr',),
'kråkefot': ('kråkefot',),
'kråkefoten': ('kråkefot',),
'kråkeføttene': ('kråkefot',),
'kråkeføtter': ('kråkefot',),
'kråketær': ('kråketær',),
'kråketærne': ('kråketær',),
'kubikkmeter': ('kubikkmeter',),
'kubikkmeteren': ('kubikkmeter',),
'kubikkmeterne': ('kubikkmeter',),
'kufôr': ('kufôr',),
'kufôra': ('kufôr',),
'kufôrene': ('kufôr',),
'kufôret': ('kufôr',),
'kulemave': ('kulemave',),
'kulemaven': ('kulemave',),
'kulemavene': ('kulemave',),
'kulemaver': ('kulemave',),
'kulturattacheen': ('kulturattaché',),
'kulturattacheene': ('kulturattaché',),
'kulturattacheer': ('kulturattaché',),
'kulturattaché': ('kulturattaché',),
'kulturattachéen': ('kulturattaché',),
'kulturattachéene': ('kulturattaché',),
'kulturattachéer': ('kulturattaché',),
'kulturmjølk': ('kulturmjølk',),
'kulturmjølka': ('kulturmjølk',),
'kulturmjølken': ('kulturmjølk',),
'kulturmjølkene': ('kulturmjølk',),
'kulturmjølker': ('kulturmjølk',),
'kupongklypper': ('kupongklypper',),
'kupongklyppere': ('kupongklypper',),
'kupongklypperen': ('kupongklypper',),
'kupongklypperer': ('kupongklypper',),
'kupongklypperne': ('kupongklypper',),
'kursleder': ('kursleder',),
'kursledere': ('kursleder',),
'kurslederen': ('kursleder',),
'kurslederer': ('kursleder',),
'kurslederne': ('kursleder',),
'kursene': ('kursus',),
'kurser': ('kursus',),
'kursus': ('kursus',),
'kursuset': ('kursus',),
'kvadratmeter': ('kvadratmeter',),
'kvadratmeteren': ('kvadratmeter',),
'kvadratmeterne': ('kvadratmeter',),
'kvadratrot': ('kvadratrot',),
'kvadratrota': ('kvadratrot',),
'kvadratroten': ('kvadratrot',),
'kvadratrøttene': ('kvadratrot',),
'kvadratrøtter': ('kvadratrot',),
'hvete': ('hvete',),
'hveten': ('hvete',),
'hvetene': ('hvete',),
'hveter': ('hvete',),
'kvidder': ('kvidder',),
'kvidderet': ('kvidder',),
'kvidra': ('kvidder',),
'kvidre': ('kvidder',),
'kvidrene': ('kvidder',),
'kvidret': ('kvidder',),
'kålrot': ('kålrot',),
'kålrota': ('kålrot',),
'kålroten': ('kålrot',),
'kålrøttene': ('kålrot',),
'kålrøtter': ('kålrot',),
'lagerøl': ('lagerøl',),
'lagerøla': ('lagerøl',),
'lagerølene': ('lagerøl',),
'lagerølet': ('lagerøl',),
'lagsokn': ('lagsokn',),
'lagsokna': ('lagsokn',),
'lagsoknen': ('lagsokn',),
'lagsoknene': ('lagsokn',),
'lagsokner': ('lagsokn',),
'lagsoknet': ('lagsokn',),
'lakksko': ('lakksko',),
'lakkskoa': ('lakksko',),
'lakkskoen': ('lakksko',),
'lakkskoene': ('lakksko',),
'lakkskor': ('lakksko',),
'lakkskorne': ('lakksko',),
'laksenot': ('laksenot',),
'laksenota': ('laksenot',),
'laksenoten': ('laksenot',),
'laksenøtene': ('laksenot',),
'laksenøter': ('laksenot',),
'lammefrikasseen': ('lammefrikassé',),
'lammefrikasseene': ('lammefrikassé',),
'lammefrikasseer': ('lammefrikassé',),
'lammefrikassé': ('lammefrikassé',),
'lammefrikasséen': ('lammefrikassé',),
'lammefrikasséene': ('lammefrikassé',),
'lammefrikasséer': ('lammefrikassé',),
'landnot': ('landnot',),
'landnota': ('landnot',),
'landnoten': ('landnot',),
'landnøtene': ('landnot',),
'landnøter': ('landnot',),
'lavsko': ('lavsko',),
'lavskoa': ('lavsko',),
'lavskoen': ('lavsko',),
'lavskoene': ('lavsko',),
'lavskor': ('lavsko',),
'lavskorne': ('lavsko',),
'lågsko': ('lågsko',),
'lågskoa': ('lågsko',),
'lågskoen': ('lågsko',),
'lågskoene': ('lågsko',),
'lågskor': ('lågsko',),
'lågskorne': ('lågsko',),
'leier': ('leier',),
'leiere': ('leier',),
'leieren': ('leier',),
'leierer': ('leier',),
'leierne': ('leier',),
'leierartikkel': ('leierartikkel',),
'leierartikkelen': ('leierartikkel',),
'leierartiklene': ('leierartikkel',),
'leierartikler': ('leierartikkel',),
'leieregenskap': ('leieregenskap',),
'leieregenskapen': ('leieregenskap',),
'leieregenskapene': ('leieregenskap',),
'leieregenskaper': ('leieregenskap',),
'leierplass': ('leierplass',),
'leierplassen': ('leierplass',),
'leierplassene': ('leierplass',),
'leierplasser': ('leierplass',),
'leierposisjon': ('leierposisjon',),
'leierposisjonen': ('leierposisjon',),
'leierposisjonene': ('leierposisjon',),
'leierposisjoner': ('leierposisjon',),
'leiersjikt': ('leiersjikt',),
'leiersjikta': ('leiersjikt',),
'leiersjiktene': ('leiersjikt',),
'leiersjiktet': ('leiersjikt',),
'leierstilling': ('leierstilling',),
'leierstillinga': ('leierstilling',),
'leierstillingen': ('leierstilling',),
'leierstillingene': ('leierstilling',),
'leierstillinger': ('leierstilling',),
'leiertype': ('leiertype',),
'leiertypen': ('leiertype',),
'leiertypene': ('leiertype',),
'leiertyper': ('leiertype',),
'leding': ('leding',),
'ledingen': ('leding',),
'ledingene': ('leding',),
'ledinger': ('leding',),
'leirbonn': ('leirbonn',),
'leirbonnen': ('leirbonn',),
'leirbonnene': ('leirbonn',),
'leirbonner': ('leirbonn',),
'leirfivel': ('leirfivel',),
'leirfivelen': ('leirfivel',),
'leirfivlene': ('leirfivel',),
'leirfivler': ('leirfivel',),
'laukkuplene': ('laukkuppel',),
'laukkupler': ('laukkuppel',),
'laukkuppel': ('laukkuppel',),
'laukkuppelen': ('laukkuppel',),
'laukplanta': ('laukplante',),
'laukplante': ('laukplante',),
'laukplanten': ('laukplante',),
'laukplantene': ('laukplante',),
'laukplanter': ('laukplante',),
'lauksaus': ('lauksaus',),
'lauksausen': ('lauksaus',),
'lauksausene': ('lauksaus',),
'lauksauser': ('lauksaus',),
'lauksuppa': ('lauksuppe',),
'lauksuppe': ('lauksuppe',),
'lauksuppen': ('lauksuppe',),
'lauksuppene': ('lauksuppe',),
'lauksupper': ('lauksuppe',),
'løkt': ('løkt',),
'løkta': ('løkt',),
'løkten': ('løkt',),
'løktene': ('løkt',),
'løkter': ('løkt',),
'laukurt': ('laukurt',),
'laukurta': ('laukurt',),
'laukurten': ('laukurt',),
'laukurtene': ('laukurt',),
'laukurter': ('laukurt',),
'lønnsmottager': ('lønnsmottager',),
'lønnsmottagere': ('lønnsmottager',),
'lønnsmottageren': ('lønnsmottager',),
'lønnsmottagerer': ('lønnsmottager',),
'lønnsmottagerne': ('lønnsmottager',),
'løvskau': ('løvskau',),
'løvskauen': ('løvskau',),
'løvskauene': ('løvskau',),
'løvskauer': ('løvskau',),
'lauvskau': ('lauvskau',),
'lauvskauen': ('lauvskau',),
'lauvskauene': ('lauvskau',),
'lauvskauer': ('lauvskau',),
'løvskaubelta': ('løvskaubelte',),
'løvskaubelte': ('løvskaubelte',),
'løvskaubeltene': ('løvskaubelte',),
'løvskaubelter': ('løvskaubelte',),
'løvskaubeltet': ('løvskaubelte',),
'lauvskaubelta': ('lauvskaubelte',),
'lauvskaubelte': ('lauvskaubelte',),
'lauvskaubeltene': ('lauvskaubelte',),
'lauvskaubelter': ('lauvskaubelte',),
'lauvskaubeltet': ('lauvskaubelte',),
'løvtre': ('løvtre',),
'løvtrea': ('løvtre',),
'løvtreet': ('løvtre',),
'løvtrær': ('løvtre',),
'løvtrærne': ('løvtre',),
'lauvtre': ('lauvtre',),
'lauvtrea': ('lauvtre',),
'lauvtreet': ('lauvtre',),
'lauvtrær': ('lauvtre',),
'lauvtrærne': ('lauvtre',),
'log': ('log',),
'logen': ('log',),
'logene': ('log',),
'loger': ('log',),
'lårbeinsbrott': ('lårbeinsbrott',),
'lårbeinsbrotta': ('lårbeinsbrott',),
'lårbeinsbrottene': ('lårbeinsbrott',),
'lårbeinsbrottet': ('lårbeinsbrott',),
'lippeblomst': ('lippeblomst',),
'lippeblomsten': ('lippeblomst',),
'lippeblomstene': ('lippeblomst',),
'lippeblomster': ('lippeblomst',),
'lippeblomstfamilie': ('lippeblomstfamilie',),
'lippeblomstfamilien': ('lippeblomstfamilie',),
'lippeblomstfamiliene': ('lippeblomstfamilie',),
'lippeblomstfamilier': ('lippeblomstfamilie',),
'lippefisk': ('lippefisk',),
'lippefisken': ('lippefisk',),
'lippefiskene': ('lippefisk',),
'lippefisker': ('lippefisk',),
'lippelyd': ('lippelyd',),
'lippelyden': ('lippelyd',),
'lippelydene': ('lippelyd',),
'lippelyder': ('lippelyd',),
'lippepomade': ('lippepomade',),
'lippepomaden': ('lippepomade',),
'lippepomadene': ('lippepomade',),
'lippepomader': ('lippepomade',),
'letter': ('letter',),
'lettere': ('letter',),
'letteren': ('letter',),
'letterer': ('letter',),
'letterne': ('letter',),
'lettmjølk': ('lettmjølk',),
'lettmjølka': ('lettmjølk',),
'lettmjølken': ('lettmjølk',),
'lettmjølkene': ('lettmjølk',),
'lettmjølker': ('lettmjølk',),
'levevis': ('levevis',),
'levevisa': ('levevis',),
'levevisen': ('levevis',),
'levevisene': ('levevis',),
'leveviset': ('levevis',),
'lindetre': ('lindetre',),
'lindetrea': ('lindetre',),
'lindetreet': ('lindetre',),
'lindetrær': ('lindetre',),
'lindetrærne': ('lindetre',),
'lintøy': ('lintøy',),
'lintøya': ('lintøy',),
'lintøyene': ('lintøy',),
'lintøyer': ('lintøy',),
'lintøyet': ('lintøy',),
'livrem': ('livrem',),
'livremma': ('livrem',),
'livremmen': ('livrem',),
'livremmene': ('livrem',),
'livremmer': ('livrem',),
'livstre': ('livstre',),
'livstrea': ('livstre',),
'livstreet': ('livstre',),
'livstrær': ('livstre',),
'livstrærne': ('livstre',),
'ljoske': ('ljoske',),
'ljosken': ('ljoske',),
'ljoskene': ('ljoske',),
'ljosker': ('ljoske',),
'lokk': ('lokk',),
'lokka': ('lokk',),
'lokkene': ('lokk',),
'lokket': ('lokk',),
'lommebok': ('lommebok',),
'lommeboka': ('lommebok',),
'lommeboken': ('lommebok',),
'lommebøkene': ('lommebok',),
'lommebøker': ('lommebok',),
'lovbok': ('lovbok',),
'lovboka': ('lovbok',),
'lovboken': ('lovbok',),
'lovbøkene': ('lovbok',),
'lovbøker': ('lovbok',),
'lucerne': ('lucerne',),
'lucernen': ('lucerne',),
'lucernene': ('lucerne',),
'lucerner': ('lucerne',),
'luktesalt': ('luktesalt',),
'luktesalta': ('luktesalt',),
'luktesaltene': ('luktesalt',),
'luktesalter': ('luktesalt',),
'luktesaltet': ('luktesalt',),
'lunnender': ('lunnender',),
'lussinatt': ('lussinatt',),
'lussinatta': ('lussinatt',),
'lussinatten': ('lussinatt',),
'lussinettene': ('lussinatt',),
'lussinetter': ('lussinatt',),
'lutoska': ('lutoske',),
'lutoske': ('lutoske',),
'lutosken': ('lutoske',),
'lutoskene': ('lutoske',),
'lutosker': ('lutoske',),
'lydbok': ('lydbok',),
'lydboka': ('lydbok',),
'lydboken': ('lydbok',),
'lydbøkene': ('lydbok',),
'lydbøker': ('lydbok',),
'løktemann': ('løktemann',),
'løktemannen': ('løktemann',),
'løktemenn': ('løktemann',),
'løktemennene': ('løktemann',),
'løktestolpe': ('løktestolpe',),
'løktestolpen': ('løktestolpe',),
'løktestolpene': ('løktestolpe',),
'løktestolper': ('løktestolpe',),
'løktetenner': ('løktetenner',),
'løktetennere': ('løktetenner',),
'løktetenneren': ('løktetenner',),
'løktetennerer': ('løktetenner',),
'løktetennerne': ('løktetenner',),
'lynavleier': ('lynavleier',),
'lynavleiere': ('lynavleier',),
'lynavleieren': ('lynavleier',),
'lynavleierer': ('lynavleier',),
'lynavleierne': ('lynavleier',),
'lynda': ('lynde',),
'lynde': ('lynde',),
'lyndene': ('lynde',),
'lynder': ('lynde',),
'lyndet': ('lynde',),
'malebok': ('malebok',),
'maleboka': ('malebok',),
'maleboken': ('malebok',),
'malebøkene': ('malebok',),
'malebøker': ('malebok',),
'malerbok': ('malerbok',),
'malerboka': ('malerbok',),
'malerboken': ('malerbok',),
'malerbøkene': ('malerbok',),
'malerbøker': ('malerbok',),
'maltøl': ('maltøl',),
'maltøla': ('maltøl',),
'maltølene': ('maltøl',),
'maltølet': ('maltøl',),
'mandeltre': ('mandeltre',),
'mandeltrea': ('mandeltre',),
'mandeltreet': ('mandeltre',),
'mandeltrær': ('mandeltre',),
'mandeltrærne': ('mandeltre',),
'mangroveskau': ('mangroveskau',),
'mangroveskauen': ('mangroveskau',),
'mangroveskauene': ('mangroveskau',),
'mangroveskauer': ('mangroveskau',),
'marineattacheen': ('marineattaché',),
'marineattacheene': ('marineattaché',),
'marineattacheer': ('marineattaché',),
'marineattaché': ('marineattaché',),
'marineattachéen': ('marineattaché',),
'marineattachéene': ('marineattaché',),
'marineattachéer': ('marineattaché',),
'mascara': ('mascara',),
'mascaraen': ('mascara',),
'mascaraene': ('mascara',),
'mascaraer': ('mascara',),
'moske': ('moske',),
'mosken': ('moske',),
'moskene': ('moske',),
'mosker': ('moske',),
'moskestørrelse': ('moskestørrelse',),
'moskestørrelsen': ('moskestørrelse',),
'moskestørrelsene': ('moskestørrelse',),
'moskestørrelser': ('moskestørrelse',),
'mosketal': ('mosketal',),
'mosketala': ('mosketal',),
'mosketalene': ('mosketal',),
'mosketalet': ('mosketal',),
'mosketall': ('mosketall',),
'mosketalla': ('mosketall',),
'mosketallene': ('mosketall',),
'mosketallet': ('mosketall',),
'massing': ('massing',),
'massingen': ('massing',),
'massingene': ('massing',),
'massinger': ('massing',),
'matmor': ('matmor',),
'matmora': ('matmor',),
'matmoren': ('matmor',),
'matmødre': ('matmor',),
'matmødrene': ('matmor',),
'matmødrer': ('matmor',),
'medeid': ('medeid',),
'medeiden': ('medeid',),
'medeidene': ('medeid',),
'medeider': ('medeid',),
'meldrøyesopp': ('meldrøyesopp',),
'meldrøyesoppen': ('meldrøyesopp',),
'meldrøyesoppene': ('meldrøyesopp',),
'meldrøyesopper': ('meldrøyesopp',),
'menneskehendene': ('menneskehånd',),
'menneskehender': ('menneskehånd',),
'menneskehånd': ('menneskehånd',),
'menneskehånda': ('menneskehånd',),
'menneskehånden': ('menneskehånd',),
'menneskehand': ('menneskehand',),
'menneskehanda': ('menneskehand',),
'menneskehanden': ('menneskehand',),
'menneskehendene': ('menneskehand',),
'menneskehender': ('menneskehand',),
'mignonpæra': ('mignonpære',),
'mignonpære': ('mignonpære',),
'mignonpæren': ('mignonpære',),
'mignonpærene': ('mignonpære',),
'mignonpærer': ('mignonpære',),
'militærattacheen': ('militærattaché',),
'militærattacheene': ('militærattaché',),
'militærattacheer': ('militærattaché',),
'militærattaché': ('militærattaché',),
'militærattachéen': ('militærattaché',),
'militærattachéene': ('militærattaché',),
'militærattachéer': ('militærattaché',),
'milliliter': ('milliliter',),
'milliliteren': ('milliliter',),
'milliliterne': ('milliliter',),
'millimeter': ('millimeter',),
'millimeteren': ('millimeter',),
'millimeterne': ('millimeter',),
'mixmaster': ('mixmaster',),
'mixmastere': ('mixmaster',),
'mixmasteren': ('mixmaster',),
'mixmasterer': ('mixmaster',),
'mixmasterne': ('mixmaster',),
'moquetta': ('moquette',),
'moquette': ('moquette',),
'moquetten': ('moquette',),
'moquettene': ('moquette',),
'moquetter': ('moquette',),
'moquettet': ('moquette',),
'morderhand': ('morderhand',),
'morderhanda': ('morderhand',),
'morderhanden': ('morderhand',),
'morderhendene': ('morderhand',),
'morderhender': ('morderhand',),
'morderhendene': ('morderhånd',),
'morderhender': ('morderhånd',),
'morderhånd': ('morderhånd',),
'morderhånda': ('morderhånd',),
'morderhånden': ('morderhånd',),
'morelltre': ('morelltre',),
'morelltrea': ('morelltre',),
'morelltreet': ('morelltre',),
'morelltrær': ('morelltre',),
'morelltrærne': ('morelltre',),
'Mosebok': ('Mosebok',),
'Moseboka': ('Mosebok',),
'Moseboken': ('Mosebok',),
'Mosebøkene': ('Mosebok',),
'Mosebøker': ('Mosebok',),
'mosebok': ('mosebok',),
'moseboka': ('mosebok',),
'moseboken': ('mosebok',),
'mosebøkene': ('mosebok',),
'mosebøker': ('mosebok',),
'Moseloven': ('Moseloven',),
'moske': ('moske',),
'moskeen': ('moske',),
'moskeene': ('moske',),
'moskeer': ('moske',),
'motverga': ('motverge',),
'motverge': ('motverge',),
'motvergene': ('motverge',),
'motverger': ('motverge',),
'motverget': ('motverge',),
'motverja': ('motverje',),
'motverje': ('motverje',),
'motverjene': ('motverje',),
'motverjer': ('motverje',),
'motverjet': ('motverje',),
'munndiareen': ('munndiaré',),
'munndiareene': ('munndiaré',),
'munndiareer': ('munndiaré',),
'munndiaré': ('munndiaré',),
'munndiaréen': ('munndiaré',),
'munndiaréene': ('munndiaré',),
'munndiaréer': ('munndiaré',),
'munn-til-munn-metoden': ('munn-til-munn-metoden',),
'myntfot': ('myntfot',),
'myntfoten': ('myntfot',),
'myntføttene': ('myntfot',),
'myntføtter': ('myntfot',),
'mødrekupeen': ('mødrekupé',),
'mødrekupeene': ('mødrekupé',),
'mødrekupeer': ('mødrekupé',),
'mødrekupé': ('mødrekupé',),
'mødrekupéen': ('mødrekupé',),
'mødrekupéene': ('mødrekupé',),
'mødrekupéer': ('mødrekupé',),
'mørrpølsa': ('mørrpølse',),
'mørrpølse': ('mørrpølse',),
'mørrpølsen': ('mørrpølse',),
'mørrpølsene': ('mørrpølse',),
'mørrpølser': ('mørrpølse',),
'møtebok': ('møtebok',),
'møteboka': ('møtebok',),
'møteboken': ('møtebok',),
'møtebøkene': ('møtebok',),
'møtebøker': ('møtebok',),
'måndag': ('måndag',),
'måndagen': ('måndag',),
'måndagene': ('måndag',),
'måndager': ('måndag',),
'nabokrangel': ('nabokrangel',),
'nabokrangelen': ('nabokrangel',),
'nabokranglene': ('nabokrangel',),
'nabokrangler': ('nabokrangel',),
'nattens dronning': ('nattens dronning',),
'nattens dronninga': ('nattens dronning',),
'nattens dronningen': ('nattens dronning',),
'nattens dronningene': ('nattens dronning',),
'nattens dronninger': ('nattens dronning',),
'nattkafeen': ('nattkafé',),
'nattkafeene': ('nattkafé',),
'nattkafeer': ('nattkafé',),
'nattkafé': ('nattkafé',),
'nattkaféen': ('nattkafé',),
'nattkaféene': ('nattkafé',),
'nattkaféer': ('nattkafé',),
'nebbetang': ('nebbetang',),
'nebbetanga': ('nebbetang',),
'nebbetangen': ('nebbetang',),
'nebbetengene': ('nebbetang',),
'nebbetenger': ('nebbetang',),
'nebbtang': ('nebbtang',),
'nebbtanga': ('nebbtang',),
'nebbtangen': ('nebbtang',),
'nebbtengene': ('nebbtang',),
'nebbtenger': ('nebbtang',),
'naseblod': ('naseblod',),
'nasebloda': ('naseblod',),
'naseblodene': ('naseblod',),
'naseblodet': ('naseblod',),
'nasebor': ('nasebor',),
'nasebora': ('nasebor',),
'naseborene': ('nasebor',),
'naseboret': ('nasebor',),
'nasedrag': ('nasedrag',),
'nasedraga': ('nasedrag',),
'nasedragene': ('nasedrag',),
'nasedraget': ('nasedrag',),
'naseduk': ('naseduk',),
'naseduken': ('naseduk',),
'nasedukene': ('naseduk',),
'naseduker': ('naseduk',),
'nasegrev': ('nasegrev',),
'nasegreva': ('nasegrev',),
'nasegrevene': ('nasegrev',),
'nasegrevet': ('nasegrev',),
'nasehula': ('nasehule',),
'nasehule': ('nasehule',),
'nasehulen': ('nasehule',),
'nasehulene': ('nasehule',),
'nasehuler': ('nasehule',),
'naselyd': ('naselyd',),
'naselyden': ('naselyd',),
'naselydene': ('naselyd',),
'naselyder': ('naselyd',),
'naseputa': ('nasepute',),
'nasepute': ('nasepute',),
'naseputen': ('nasepute',),
'naseputene': ('nasepute',),
'naseputer': ('nasepute',),
'nasering': ('nasering',),
'naseringen': ('nasering',),
'naseringene': ('nasering',),
'naseringer': ('nasering',),
'naserot': ('naserot',),
'naserota': ('naserot',),
'naseroten': ('naserot',),
'naserøttene': ('naserot',),
'naserøtter': ('naserot',),
'nasestyver': ('nasestyver',),
'nasestyvere': ('nasestyver',),
'nasestyveren': ('nasestyver',),
'nasestyverer': ('nasestyver',),
'nasestyverne': ('nasestyver',),
'nasetipp': ('nasetipp',),
'nasetippen': ('nasetipp',),
'nasetippene': ('nasetipp',),
'nasetipper': ('nasetipp',),
'naseveng': ('naseveng',),
'nasevengen': ('naseveng',),
'nasevengene': ('naseveng',),
'nasevenger': ('naseveng',),
'naseving': ('naseving',),
'nasevingen': ('naseving',),
'nasevingene': ('naseving',),
'nasevinger': ('naseving',),
'nasevinge': ('nasevinge',),
'nasevingen': ('nasevinge',),
'nasevingene': ('nasevinge',),
'nasevinger': ('nasevinge',),
'nasevishet': ('nasevishet',),
'nasevisheta': ('nasevishet',),
'nasevisheten': ('nasevishet',),
'nasevishetene': ('nasevishet',),
'nasevisheter': ('nasevishet',),
'nestleier': ('nestleier',),
'nestleiere': ('nestleier',),
'nestleieren': ('nestleier',),
'nestleierer': ('nestleier',),
'nestleierne': ('nestleier',),
'Nordkalotten': ('Nordkalotten',),
'notisbok': ('notisbok',),
'notisboka': ('notisbok',),
'notisboken': ('notisbok',),
'notisbøkene': ('notisbok',),
'notisbøker': ('notisbok',),
'nøttetre': ('nøttetre',),
'nøttetrea': ('nøttetre',),
'nøttetreet': ('nøttetre',),
'nøttetrær': ('nøttetre',),
'nøttetrærne': ('nøttetre',),
'nåleskau': ('nåleskau',),
'nåleskauen': ('nåleskau',),
'nåleskauene': ('nåleskau',),
'nåleskauer': ('nåleskau',),
'nåletre': ('nåletre',),
'nåletrea': ('nåletre',),
'nåletreet': ('nåletre',),
'nåletrær': ('nåletre',),
'nåletrærne': ('nåletre',),
'oksyd': ('oksyd',),
'oksyda': ('oksyd',),
'oksydene': ('oksyd',),
'oksyder': ('oksyd',),
'oksydet': ('oksyd',),
'oldefar': ('oldefar',),
'oldefaren': ('oldefar',),
'oldefedre': ('oldefar',),
'oldefedrene': ('oldefar',),
'oldeforeldre': ('oldeforeldre',),
'oldeforeldrene': ('oldeforeldre',),
'oldemor': ('oldemor',),
'oldemora': ('oldemor',),
'oldemoren': ('oldemor',),
'oldemødre': ('oldemor',),
'oldemødrene': ('oldemor',),
'oldemødrer': ('oldemor',),
'oljehyra': ('oljehyre',),
'oljehyre': ('oljehyre',),
'oljehyren': ('oljehyre',),
'oljehyrene': ('oljehyre',),
'oljehyrer': ('oljehyre',),
'oljehyret': ('oljehyre',),
'opptagelsesprøva': ('opptagelsesprøve',),
'opptagelsesprøve': ('opptagelsesprøve',),
'opptagelsesprøven': ('opptagelsesprøve',),
'opptagelsesprøvene': ('opptagelsesprøve',),
'opptagelsesprøver': ('opptagelsesprøve',),
'ordbok': ('ordbok',),
'ordboka': ('ordbok',),
'ordboken': ('ordbok',),
'ordbøkene': ('ordbok',),
'ordbøker': ('ordbok',),
'ordrebok': ('ordrebok',),
'ordreboka': ('ordrebok',),
'ordreboken': ('ordrebok',),
'ordrebøkene': ('ordrebok',),
'ordrebøker': ('ordrebok',),
'overgivelse': ('overgivelse',),
'overgivelsen': ('overgivelse',),
'overgivelsene': ('overgivelse',),
'overgivelser': ('overgivelse',),
'paltorsk': ('paltorsk',),
'paltorsken': ('paltorsk',),
'paltorskene': ('paltorsk',),
'paltorsker': ('paltorsk',),
'paltosk': ('paltosk',),
'paltosken': ('paltosk',),
'paltoskene': ('paltosk',),
'paltosker': ('paltosk',),
'pappmjølk': ('pappmjølk',),
'pappmjølka': ('pappmjølk',),
'pappmjølken': ('pappmjølk',),
'pappmjølkene': ('pappmjølk',),
'pappmjølker': ('pappmjølk',),
'partibok': ('partibok',),
'partiboka': ('partibok',),
'partiboken': ('partibok',),
'partibøkene': ('partibok',),
'partibøker': ('partibok',),
'partileier': ('partileier',),
'partileiere': ('partileier',),
'partileieren': ('partileier',),
'partileierer': ('partileier',),
'partileierne': ('partileier',),
'patchwork': ('patchwork',),
'pekebok': ('pekebok',),
'pekeboka': ('pekebok',),
'pekeboken': ('pekebok',),
'pekebøkene': ('pekebok',),
'pekebøker': ('pekebok',),
'pel': ('pel',),
'pelen': ('pel',),
'pelene': ('pel',),
'peler': ('pel',),
'pepperrot': ('pepperrot',),
'pepperrota': ('pepperrot',),
'pepperroten': ('pepperrot',),
'pepperrøttene': ('pepperrot',),
'pepperrøtter': ('pepperrot',),
'permnekt': ('permnekt',),
'permnekten': ('permnekt',),
'permnektene': ('permnekt',),
'permnekter': ('permnekt',),
'piggsko': ('piggsko',),
'piggskoa': ('piggsko',),
'piggskoen': ('piggsko',),
'piggskoene': ('piggsko',),
'piggskor': ('piggsko',),
'piggskorne': ('piggsko',),
'plenklypper': ('plenklypper',),
'plenklyppere': ('plenklypper',),
'plenklypperen': ('plenklypper',),
'plenklypperer': ('plenklypper',),
'plenklypperne': ('plenklypper',),
'plommetre': ('plommetre',),
'plommetrea': ('plommetre',),
'plommetreet': ('plommetre',),
'plommetrær': ('plommetre',),
'plommetrærne': ('plommetre',),
'polermiddel': ('polermiddel',),
'polermiddelet': ('polermiddel',),
'polermidla': ('polermiddel',),
'polermidlene': ('polermiddel',),
'polermidler': ('polermiddel',),
'polermidlet': ('polermiddel',),
'postpakkmester': ('postpakkmester',),
'postpakkmestere': ('postpakkmester',),
'postpakkmesteren': ('postpakkmester',),
'postpakkmesterer': ('postpakkmester',),
'postpakkmesterne': ('postpakkmester',),
'postpakkmestre': ('postpakkmester',),
'postpakkmestrene': ('postpakkmester',),
'postpakkmestrer': ('postpakkmester',),
'potetpureen': ('potetpuré',),
'potetpureene': ('potetpuré',),
'potetpureer': ('potetpuré',),
'potetpuré': ('potetpuré',),
'potetpuréen': ('potetpuré',),
'potetpuréene': ('potetpuré',),
'potetpuréer': ('potetpuré',),
'presseattacheen': ('presseattaché',),
'presseattacheene': ('presseattaché',),
'presseattacheer': ('presseattaché',),
'presseattaché': ('presseattaché',),
'presseattachéen': ('presseattaché',),
'presseattachéene': ('presseattaché',),
'presseattachéer': ('presseattaché',),
'pressfôr': ('pressfôr',),
'pressfôra': ('pressfôr',),
'pressfôrene': ('pressfôr',),
'pressfôret': ('pressfôr',),
'primadonnanykka': ('primadonnanykke',),
'primadonnanykke': ('primadonnanykke',),
'primadonnanykken': ('primadonnanykke',),
'primadonnanykkene': ('primadonnanykke',),
'primadonnanykker': ('primadonnanykke',),
'primadonnanykket': ('primadonnanykke',),
'programleier': ('programleier',),
'programleiere': ('programleier',),
'programleieren': ('programleier',),
'programleierer': ('programleier',),
'programleierne': ('programleier',),
'protokollkomiteen': ('protokollkomité',),
'protokollkomiteene': ('protokollkomité',),
'protokollkomiteer': ('protokollkomité',),
'protokollkomité': ('protokollkomité',),
'protokollkomitéen': ('protokollkomité',),
'protokollkomitéene': ('protokollkomité',),
'protokollkomitéer': ('protokollkomité',),
'punjabi': ('punjabi',),
'punjabien': ('punjabi',),
'punjabiene': ('punjabi',),
'punjabier': ('punjabi',),
'punkrock': ('punkrock',),
'punkrocken': ('punkrock',),
'punkrockene': ('punkrock',),
'punkrocker': ('punkrock',),
'purrelauksuppa': ('purrelauksuppe',),
'purrelauksuppe': ('purrelauksuppe',),
'purrelauksuppen': ('purrelauksuppe',),
'purrelauksuppene': ('purrelauksuppe',),
'purrelauksupper': ('purrelauksuppe',),
'Pål': ('Pål',),
'Pålen': ('Pål',),
'Pålene': ('Pål',),
'Påler': ('Pål',),
'quadragesima': ('quadragesima',),
'quadragesimaa': ('quadragesima',),
'quadragesimaene': ('quadragesima',),
'quadragesimaet': ('quadragesima',),
'quinquagesima': ('quinquagesima',),
'quinquagesimaa': ('quinquagesima',),
'quinquagesimaene': ('quinquagesima',),
'quinquagesimaet': ('quinquagesima',),
'ramnemor': ('ramnemor',),
'ramnemora': ('ramnemor',),
'ramnemoren': ('ramnemor',),
'ramnemødre': ('ramnemor',),
'ramnemødrene': ('ramnemor',),
'ramnemødrer': ('ramnemor',),
'ravnemor': ('ravnemor',),
'ravnemora': ('ravnemor',),
'ravnemoren': ('ravnemor',),
'ravnemødre': ('ravnemor',),
'ravnemødrene': ('ravnemor',),
'ravnemødrer': ('ravnemor',),
'ravnemor': ('ravnemor',),
'ravnemora': ('ravnemor',),
'ravnemoren': ('ravnemor',),
'ravnemødre': ('ravnemor',),
'ravnemødrene': ('ravnemor',),
'ravnemødrer': ('ravnemor',),
'ramnemor': ('ramnemor',),
'ramnemora': ('ramnemor',),
'ramnemoren': ('ramnemor',),
'ramnemødre': ('ramnemor',),
'ramnemødrene': ('ramnemor',),
'ramnemødrer': ('ramnemor',),
'regnskau': ('regnskau',),
'regnskauen': ('regnskau',),
'regnskauene': ('regnskau',),
'regnskauer': ('regnskau',),
'rep': ('rep',),
'repa': ('rep',),
'repet': ('rep',),
'rephelda': ('rephelde',),
'rephelde': ('rephelde',),
'rephelden': ('rephelde',),
'repheldene': ('rephelde',),
'rephelder': ('rephelde',),
'reisefot': ('reisefot',),
'reisefoten': ('reisefot',),
'reiseføttene': ('reisefot',),
'reiseføtter': ('reisefot',),
'reiseleier': ('reiseleier',),
'reiseleiere': ('reiseleier',),
'reiseleieren': ('reiseleier',),
'reiseleierer': ('reiseleier',),
'reiseleierne': ('reiseleier',),
'resonansbonn': ('resonansbonn',),
'resonansbonnen': ('resonansbonn',),
'resonansbonnene': ('resonansbonn',),
'resonansbonner': ('resonansbonn',),
'rettleier': ('rettleier',),
'rettleiere': ('rettleier',),
'rettleieren': ('rettleier',),
'rettleierer': ('rettleier',),
'rettleierne': ('rettleier',),
'ringnot': ('ringnot',),
'ringnota': ('ringnot',),
'ringnoten': ('ringnot',),
'ringnøtene': ('ringnot',),
'ringnøter': ('ringnot',),
'ryggmerg': ('ryggmerg',),
'ryggmergen': ('ryggmerg',),
'ryggmergene': ('ryggmerg',),
'ryggmerger': ('ryggmerg',),
'raudbeta': ('raudbete',),
'raudbete': ('raudbete',),
'raudbeten': ('raudbete',),
'raudbetene': ('raudbete',),
'raudbeter': ('raudbete',),
'raudbetsaft': ('raudbetsaft',),
'raudbetsafta': ('raudbetsaft',),
'raudbetsaften': ('raudbetsaft',),
'raudbetsaftene': ('raudbetsaft',),
'raudbetsafter': ('raudbetsaft',),
'raudgraut': ('raudgraut',),
'raudgrauten': ('raudgraut',),
'raudgrautene': ('raudgraut',),
'raudgrauter': ('raudgraut',),
'raudgrøt': ('raudgrøt',),
'raudgrøten': ('raudgrøt',),
'raudgrøtene': ('raudgrøt',),
'raudgrøter': ('raudgrøt',),
'raudhud': ('raudhud',),
'raudhuda': ('raudhud',),
'raudhuden': ('raudhud',),
'raudhudene': ('raudhud',),
'raudhuder': ('raudhud',),
'raudruss': ('raudruss',),
'raudrussen': ('raudruss',),
'raudrussene': ('raudruss',),
'raudsprit': ('raudsprit',),
'raudspriten': ('raudsprit',),
'raudspritene': ('raudsprit',),
'raudspriter': ('raudsprit',),
'raudstrømpa': ('raudstrømpe',),
'raudstrømpe': ('raudstrømpe',),
'raudstrømpen': ('raudstrømpe',),
'raudstrømpene': ('raudstrømpe',),
'raudstrømper': ('raudstrømpe',),
'raudsyka': ('raudsyke',),
'raudsyke': ('raudsyke',),
'raudsyken': ('raudsyke',),
'raudsykene': ('raudsyke',),
'raudsyker': ('raudsyke',),
'raudsjuka': ('raudsjuke',),
'raudsjuke': ('raudsjuke',),
'raudsjuken': ('raudsjuke',),
'raudsjukene': ('raudsjuke',),
'raudsjuker': ('raudsjuke',),
'raudtopp': ('raudtopp',),
'raudtoppen': ('raudtopp',),
'raudtoppene': ('raudtopp',),
'raudtopper': ('raudtopp',),
'raudvin': ('raudvin',),
'raudvinen': ('raudvin',),
'raudvinene': ('raudvin',),
'raudviner': ('raudvin',),
'raudvinstoddi': ('raudvinstoddi',),
'raudvinstoddien': ('raudvinstoddi',),
'raudvinstoddiene': ('raudvinstoddi',),
'raudvinstoddier': ('raudvinstoddi',),
'rødåt': ('rødåt',),
'rødåta': ('rødåt',),
'rødåtene': ('rødåt',),
'rødåtet': ('rødåt',),
'raudåt': ('raudåt',),
'raudåta': ('raudåt',),
'raudåtene': ('raudåt',),
'raudåtet': ('raudåt',),
'røk': ('røk',),
'røken': ('røk',),
'røkene': ('røk',),
'røker': ('røk',),
'røntgenstrålene': ('røntgenstråler',),
'røntgenstråler': ('røntgenstråler',),
'rørtang': ('rørtang',),
'rørtanga': ('rørtang',),
'rørtangen': ('rørtang',),
'rørtengene': ('rørtang',),
'rørtenger': ('rørtang',),
'røkdykker': ('røkdykker',),
'røkdykkere': ('røkdykker',),
'røkdykkeren': ('røkdykker',),
'røkdykkerer': ('røkdykker',),
'røkdykkerne': ('røkdykker',),
'røkejakka': ('røkejakke',),
'røkejakke': ('røkejakke',),
'røkejakken': ('røkejakke',),
'røkejakkene': ('røkejakke',),
'røkejakker': ('røkejakke',),
'røykekupeen': ('røykekupé',),
'røykekupeene': ('røykekupé',),
'røykekupeer': ('røykekupé',),
'røykekupé': ('røykekupé',),
'røykekupéen': ('røykekupé',),
'røykekupéene': ('røykekupé',),
'røykekupéer': ('røykekupé',),
'røkekupeen': ('røkekupé',),
'røkekupeene': ('røkekupé',),
'røkekupeer': ('røkekupé',),
'røkekupé': ('røkekupé',),
'røkekupéen': ('røkekupé',),
'røkekupéene': ('røkekupé',),
'røkekupéer': ('røkekupé',),
'røkelaks': ('røkelaks',),
'røkelaksen': ('røkelaks',),
'røkelaksene': ('røkelaks',),
'røkelakser': ('røkelaks',),
'røkeri': ('røkeri',),
'røkeria': ('røkeri',),
'røkeriene': ('røkeri',),
'røkerier': ('røkeri',),
'røkeriet': ('røkeri',),
'røkeværelsa': ('røkeværelse',),
'røkeværelse': ('røkeværelse',),
'røkeværelsene': ('røkeværelse',),
'røkeværelser': ('røkeværelse',),
'røkeværelset': ('røkeværelse',),
'røkhatt': ('røkhatt',),
'røkhatten': ('røkhatt',),
'røkhattene': ('røkhatt',),
'røkhatter': ('røkhatt',),
'røkning': ('røkning',),
'røkninga': ('røkning',),
'røkningen': ('røkning',),
'røkningene': ('røkning',),
'røkninger': ('røkning',),
'røkoffer': ('røkoffer',),
'røkofferet': ('røkoffer',),
'røkofra': ('røkoffer',),
'røkofre': ('røkoffer',),
'røkofrene': ('røkoffer',),
'røkomn': ('røkomn',),
'røkomnen': ('røkomn',),
'røkomnene': ('røkomn',),
'røkomner': ('røkomn',),
'røkovn': ('røkovn',),
'røkovnen': ('røkovn',),
'røkovnene': ('røkovn',),
'røkovner': ('røkovn',),
'røkplaga': ('røkplage',),
'røkplage': ('røkplage',),
'røkplagen': ('røkplage',),
'røkplagene': ('røkplage',),
'røkplager': ('røkplage',),
'røksopp': ('røksopp',),
'røksoppen': ('røksopp',),
'røksoppene': ('røksopp',),
'røksopper': ('røksopp',),
'røkstua': ('røkstue',),
'røkstue': ('røkstue',),
'røkstuen': ('røkstue',),
'røkstuene': ('røkstue',),
'røkstuer': ('røkstue',),
'røkteppa': ('røkteppe',),
'røkteppe': ('røkteppe',),
'røkteppene': ('røkteppe',),
'røktepper': ('røkteppe',),
'røkteppet': ('røkteppe',),
'rågummisko': ('rågummisko',),
'rågummiskoa': ('rågummisko',),
'rågummiskoen': ('rågummisko',),
'rågummiskoene': ('rågummisko',),
'rågummiskor': ('rågummisko',),
'rågummiskorne': ('rågummisko',),
'sagmjøl': ('sagmjøl',),
'sagmjøla': ('sagmjøl',),
'sagmjølene': ('sagmjøl',),
'sagmjølet': ('sagmjøl',),
'salmebok': ('salmebok',),
'salmeboka': ('salmebok',),
'salmeboken': ('salmebok',),
'salmebøkene': ('salmebok',),
'salmebøker': ('salmebok',),
'sandeltre': ('sandeltre',),
'sandeltrea': ('sandeltre',),
'sandeltreet': ('sandeltre',),
'sandeltrær': ('sandeltre',),
'sandeltrærne': ('sandeltre',),
'sangbok': ('sangbok',),
'sangboka': ('sangbok',),
'sangboken': ('sangbok',),
'sangbøkene': ('sangbok',),
'sangbøker': ('sangbok',),
'scan': ('scan',),
'scana': ('scan',),
'scanene': ('scan',),
'scanet': ('scan',),
'sedertre': ('sedertre',),
'sedertrea': ('sedertre',),
'sedertreet': ('sedertre',),
'sedertrær': ('sedertre',),
'sedertrærne': ('sedertre',),
'sekretariatsleier': ('sekretariatsleier',),
'sekretariatsleiere': ('sekretariatsleier',),
'sekretariatsleieren': ('sekretariatsleier',),
'sekretariatsleierer': ('sekretariatsleier',),
'sekretariatsleierne': ('sekretariatsleier',),
'seksjonsleier': ('seksjonsleier',),
'seksjonsleiere': ('seksjonsleier',),
'seksjonsleieren': ('seksjonsleier',),
'seksjonsleierer': ('seksjonsleier',),
'seksjonsleierne': ('seksjonsleier',),
'sellerirot': ('sellerirot',),
'sellerirota': ('sellerirot',),
'selleriroten': ('sellerirot',),
'sellerirøttene': ('sellerirot',),
'sellerirøtter': ('sellerirot',),
'selvantennelse': ('selvantennelse',),
'selvantennelsen': ('selvantennelse',),
'selvantennelsene': ('selvantennelse',),
'selvantennelser': ('selvantennelse',),
'sengebonn': ('sengebonn',),
'sengebonnen': ('sengebonn',),
'sengebonnene': ('sengebonn',),
'sengebonner': ('sengebonn',),
'sengerøking': ('sengerøking',),
'sengerøkinga': ('sengerøking',),
'sengerøkingen': ('sengerøking',),
'sengerøkingene': ('sengerøking',),
'sengerøkinger': ('sengerøking',),
'sengetøy': ('sengetøy',),
'sengetøya': ('sengetøy',),
'sengetøyene': ('sengetøy',),
'sengetøyer': ('sengetøy',),
'sengetøyet': ('sengetøy',),
'sæterbruk': ('sæterbruk',),
'sæterbruka': ('sæterbruk',),
'sæterbrukene': ('sæterbruk',),
'sæterbruket': ('sæterbruk',),
'sikring': ('sikring',),
'sikringen': ('sikring',),
'sikringene': ('sikring',),
'sikringer': ('sikring',),
'sildemjøl': ('sildemjøl',),
'sildemjøla': ('sildemjøl',),
'sildemjølene': ('sildemjøl',),
'sildemjølet': ('sildemjøl',),
'sildenot': ('sildenot',),
'sildenota': ('sildenot',),
'sildenoten': ('sildenot',),
'sildenøtene': ('sildenot',),
'sildenøter': ('sildenot',),
'silofôr': ('silofôr',),
'silofôra': ('silofôr',),
'silofôrene': ('silofôr',),
'silofôret': ('silofôr',),
'sisalagava': ('sisalagave',),
'sisalagave': ('sisalagave',),
'sisalagaven': ('sisalagave',),
'sisalagavene': ('sisalagave',),
'sisalagaver': ('sisalagave',),
'sjøbein': ('sjøbein',),
'sjøbeina': ('sjøbein',),
'sjøbeinene': ('sjøbein',),
'sjøbeinet': ('sjøbein',),
'sjøbonn': ('sjøbonn',),
'sjøbonnen': ('sjøbonn',),
'sjøbonnene': ('sjøbonn',),
'sjøbonner': ('sjøbonn',),
'sjømil': ('sjømil',),
'sjømila': ('sjømil',),
'sjømilen': ('sjømil',),
'sjømilene': ('sjømil',),
'sjøsalt': ('sjøsalt',),
'sjøsalta': ('sjøsalt',),
'sjøsaltene': ('sjøsalt',),
'sjøsalter': ('sjøsalt',),
'sjøsaltet': ('sjøsalt',),
'skateboard': ('skateboard',),
'skateboarden': ('skateboard',),
'skateboardene': ('skateboard',),
'skateboarder': ('skateboard',),
'skavgress': ('skavgress',),
'skavgressa': ('skavgress',),
'skavgressene': ('skavgress',),
'skavgresset': ('skavgress',),
'skill': ('skill',),
'skilla': ('skill',),
'skillene': ('skill',),
'skillet': ('skill',),
'skivehorv': ('skivehorv',),
'skivehorva': ('skivehorv',),
'skivehorven': ('skivehorv',),
'skivehorvene': ('skivehorv',),
'skivehorver': ('skivehorv',),
'skei': ('skei',),
'skeia': ('skei',),
'skeien': ('skei',),
'skeiene': ('skei',),
'skeier': ('skei',),
'skjebnetru': ('skjebnetru',),
'skjebnetrua': ('skjebnetru',),
'skjebnetruen': ('skjebnetru',),
'skjebnetruene': ('skjebnetru',),
'skjebnetruer': ('skjebnetru',),
'skau': ('skau',),
'skauen': ('skau',),
'skauene': ('skau',),
'skauer': ('skau',),
'skauband': ('skauband',),
'skaubanda': ('skauband',),
'skaubandene': ('skauband',),
'skaubandet': ('skauband',),
'skaublomst': ('skaublomst',),
'skaublomsten': ('skaublomst',),
'skaublomstene': ('skaublomst',),
'skaublomster': ('skaublomst',),
'skaubrann': ('skaubrann',),
'skaubrannen': ('skaubrann',),
'skaubrannene': ('skaubrann',),
'skaubranner': ('skaubrann',),
'skaubruk': ('skaubruk',),
'skaubruka': ('skaubruk',),
'skaubrukene': ('skaubruk',),
'skaubruket': ('skaubruk',),
'skaubryn': ('skaubryn',),
'skaubryna': ('skaubryn',),
'skaubrynene': ('skaubryn',),
'skaubrynet': ('skaubryn',),
'skogbonn': ('skogbonn',),
'skogbonnen': ('skogbonn',),
'skogbonnene': ('skogbonn',),
'skogbonner': ('skogbonn',),
'skaubunn': ('skaubunn',),
'skaubunnen': ('skaubunn',),
'skaubunnene': ('skaubunn',),
'skaubunner': ('skaubunn',),
'skaubotn': ('skaubotn',),
'skaubotnen': ('skaubotn',),
'skaubotnene': ('skaubotn',),
'skaubotner': ('skaubotn',),
'skaubonn': ('skaubonn',),
'skaubonnen': ('skaubonn',),
'skaubonnene': ('skaubonn',),
'skaubonner': ('skaubonn',),
'skaubygd': ('skaubygd',),
'skaubygda': ('skaubygd',),
'skaubygden': ('skaubygd',),
'skaubygdene': ('skaubygd',),
'skaubygder': ('skaubygd',),
'skaudistrikt': ('skaudistrikt',),
'skaudistrikta': ('skaudistrikt',),
'skaudistriktene': ('skaudistrikt',),
'skaudistrikter': ('skaudistrikt',),
'skaudistriktet': ('skaudistrikt',),
'skaudrift': ('skaudrift',),
'skaudrifta': ('skaudrift',),
'skaudriften': ('skaudrift',),
'skaudriftene': ('skaudrift',),
'skaudrifter': ('skaudrift',),
'skaudua': ('skaudue',),
'skaudue': ('skaudue',),
'skauduen': ('skaudue',),
'skauduene': ('skaudue',),
'skauduer': ('skaudue',),
'skaudød': ('skaudød',),
'skaudøden': ('skaudød',),
'skaudødene': ('skaudød',),
'skaudøder': ('skaudød',),
'skaueier': ('skaueier',),
'skaueiere': ('skaueier',),
'skaueieren': ('skaueier',),
'skaueierer': ('skaueier',),
'skaueierne': ('skaueier',),
'skaufinne': ('skaufinne',),
'skaufinnen': ('skaufinne',),
'skaufinnene': ('skaufinne',),
'skaufinner': ('skaufinne',),
'skaufiol': ('skaufiol',),
'skaufiolen': ('skaufiol',),
'skaufiolene': ('skaufiol',),
'skaufioler': ('skaufiol',),
'skauflått': ('skauflått',),
'skauflåtten': ('skauflått',),
'skauflåttene': ('skauflått',),
'skauflåtter': ('skauflått',),
'skauforvalter': ('skauforvalter',),
'skauforvaltere': ('skauforvalter',),
'skauforvalteren': ('skauforvalter',),
'skauforvalterer': ('skauforvalter',),
'skauforvalterne': ('skauforvalter',),
'skaugang': ('skaugang',),
'skaugangen': ('skaugang',),
'skaugangene': ('skaugang',),
'skauganger': ('skaugang',),
'skaugangsmann': ('skaugangsmann',),
'skaugangsmannen': ('skaugangsmann',),
'skaugangsmenn': ('skaugangsmann',),
'skaugangsmennene': ('skaugangsmann',),
'skaugrensa': ('skaugrense',),
'skaugrense': ('skaugrense',),
'skaugrensen': ('skaugrense',),
'skaugrensene': ('skaugrense',),
'skaugrenser': ('skaugrense',),
'skauholt': ('skauholt',),
'skauholta': ('skauholt',),
'skauholtene': ('skauholt',),
'skauholtet': ('skauholt',),
'skaukant': ('skaukant',),
'skaukanten': ('skaukant',),
'skaukantene': ('skaukant',),
'skaukanter': ('skaukant',),
'skaukatt': ('skaukatt',),
'skaukatten': ('skaukatt',),
'skaukattene': ('skaukatt',),
'skaukatter': ('skaukatt',),
'skaukratt': ('skaukratt',),
'skaukratta': ('skaukratt',),
'skaukrattene': ('skaukratt',),
'skaukrattet': ('skaukratt',),
'skaukultur': ('skaukultur',),
'skaukulturen': ('skaukultur',),
'skaukulturene': ('skaukultur',),
'skaukulturer': ('skaukultur',),
'skaulenda': ('skaulende',),
'skaulende': ('skaulende',),
'skaulendene': ('skaulende',),
'skaulendet': ('skaulende',),
'skaumaur': ('skaumaur',),
'skaumauren': ('skaumaur',),
'skaumaurene': ('skaumaur',),
'skaumester': ('skaumester',),
'skaumestere': ('skaumester',),
'skaumesteren': ('skaumester',),
'skaumesterer': ('skaumester',),
'skaumesterne': ('skaumester',),
'skaumestre': ('skaumester',),
'skaumestrene': ('skaumester',),
'skaumestrer': ('skaumester',),
'skaumus': ('skaumus',),
'skaumusa': ('skaumus',),
'skaumusen': ('skaumus',),
'skaumusene': ('skaumus',),
'skauområda': ('skauområde',),
'skauområde': ('skauområde',),
'skauområdene': ('skauområde',),
'skauområder': ('skauområde',),
'skauområdet': ('skauområde',),
'skauoppsyn': ('skauoppsyn',),
'skauoppsyna': ('skauoppsyn',),
'skauoppsynene': ('skauoppsyn',),
'skauoppsynet': ('skauoppsyn',),
'skauoppsynsmann': ('skauoppsynsmann',),
'skauoppsynsmannen': ('skauoppsynsmann',),
'skauoppsynsmenn': ('skauoppsynsmann',),
'skauoppsynsmennene': ('skauoppsynsmann',),
'skauplanting': ('skauplanting',),
'skauplantinga': ('skauplanting',),
'skauplantingen': ('skauplanting',),
'skauplantingene': ('skauplanting',),
'skauplantinger': ('skauplanting',),
'skauplantning': ('skauplantning',),
'skauplantninga': ('skauplantning',),
'skauplantningen': ('skauplantning',),
'skauplantningene': ('skauplantning',),
'skauplantninger': ('skauplantning',),
'skauredsel': ('skauredsel',),
'skauredselen': ('skauredsel',),
'skauredslene': ('skauredsel',),
'skauredsler': ('skauredsel',),
'skaureising': ('skaureising',),
'skaureisinga': ('skaureising',),
'skaureisingen': ('skaureising',),
'skaureisingene': ('skaureising',),
'skaureisinger': ('skaureising',),
'skauråd': ('skauråd',),
'skauråda': ('skauråd',),
'skaurådene': ('skauråd',),
'skaurådet': ('skauråd',),
'skauarbeid': ('skauarbeid',),
'skauarbeida': ('skauarbeid',),
'skauarbeidene': ('skauarbeid',),
'skauarbeider': ('skauarbeid',),
'skauarbeidet': ('skauarbeid',),
'skauarbeider': ('skauarbeider',),
'skauarbeidere': ('skauarbeider',),
'skauarbeideren': ('skauarbeider',),
'skauarbeiderer': ('skauarbeider',),
'skauarbeiderne': ('skauarbeider',),
'skaubilveg': ('skaubilveg',),
'skaubilvegen': ('skaubilveg',),
'skaubilvegene': ('skaubilveg',),
'skaubilveger': ('skaubilveg',),
'skaubilvei': ('skaubilvei',),
'skaubilveien': ('skaubilvei',),
'skaubilveiene': ('skaubilvei',),
'skaubilveier': ('skaubilvei',),
'skauelefant': ('skauelefant',),
'skauelefanten': ('skauelefant',),
'skauelefantene': ('skauelefant',),
'skauelefanter': ('skauelefant',),
'skauselskap': ('skauselskap',),
'skauselskapa': ('skauselskap',),
'skauselskapene': ('skauselskap',),
'skauselskaper': ('skauselskap',),
'skauselskapet': ('skauselskap',),
'skaufugl': ('skaufugl',),
'skaufuglen': ('skaufugl',),
'skaufuglene': ('skaufugl',),
'skaufugler': ('skaufugl',),
'skauskjøtsel': ('skauskjøtsel',),
'skauskjøtselen': ('skauskjøtsel',),
'skauskjøtslene': ('skauskjøtsel',),
'skauskjøtsler': ('skauskjøtsel',),
'skauskole': ('skauskole',),
'skauskolen': ('skauskole',),
'skauskolene': ('skauskole',),
'skauskoler': ('skauskole',),
'skauløp': ('skauløp',),
'skauløpa': ('skauløp',),
'skauløpene': ('skauløp',),
'skauløpet': ('skauløp',),
'skausnar': ('skausnar',),
'skausnara': ('skausnar',),
'skausnarene': ('skausnar',),
'skausnaret': ('skausnar',),
'skausnegl': ('skausnegl',),
'skausneglen': ('skausnegl',),
'skausneglene': ('skausnegl',),
'skausnegler': ('skausnegl',),
'skausnile': ('skausnile',),
'skausnilen': ('skausnile',),
'skausnilene': ('skausnile',),
'skausniler': ('skausnile',),
'skaurå': ('skaurå',),
'skauråa': ('skaurå',),
'skauråen': ('skaurå',),
'skauråene': ('skaurå',),
'skauråer': ('skaurå',),
'skausti': ('skausti',),
'skaustien': ('skausti',),
'skaustiene': ('skausti',),
'skaustier': ('skausti',),
'skaustjerna': ('skaustjerne',),
'skaustjerne': ('skaustjerne',),
'skaustjernen': ('skaustjerne',),
'skaustjernene': ('skaustjerne',),
'skaustjerner': ('skaustjerne',),
'skaustorkenebb': ('skaustorkenebb',),
'skaustorkenebben': ('skaustorkenebb',),
'skaustorkenebbene': ('skaustorkenebb',),
'skaustorkenebber': ('skaustorkenebb',),
'skaustrekning': ('skaustrekning',),
'skaustrekninga': ('skaustrekning',),
'skaustrekningen': ('skaustrekning',),
'skaustrekningene': ('skaustrekning',),
'skaustrekninger': ('skaustrekning',),
'skautur': ('skautur',),
'skauturen': ('skautur',),
'skauturene': ('skautur',),
'skauturer': ('skautur',),
'skauvirka': ('skauvirke',),
'skauvirke': ('skauvirke',),
'skauvirkene': ('skauvirke',),
'skauvirker': ('skauvirke',),
'skauvirket': ('skauvirke',),
'skauteig': ('skauteig',),
'skauteigen': ('skauteig',),
'skauteigene': ('skauteig',),
'skauteiger': ('skauteig',),
'skautekniker': ('skautekniker',),
'skauteknikere': ('skautekniker',),
'skauteknikeren': ('skautekniker',),
'skauteknikerer': ('skautekniker',),
'skauteknikerne': ('skautekniker',),
'skautraver': ('skautraver',),
'skautravere': ('skautraver',),
'skautraveren': ('skautraver',),
'skautraverer': ('skautraver',),
'skautraverne': ('skautraver',),
'skautroll': ('skautroll',),
'skautrolla': ('skautroll',),
'skautrollene': ('skautroll',),
'skautrollet': ('skautroll',),
'skauvern': ('skauvern',),
'skauverna': ('skauvern',),
'skauvernene': ('skauvern',),
'skauvernet': ('skauvern',),
'skauvernlov': ('skauvernlov',),
'skauvernloven': ('skauvernlov',),
'skauvernlovene': ('skauvernlov',),
'skauvernlover': ('skauvernlov',),
'skauvokter': ('skauvokter',),
'skauvoktere': ('skauvokter',),
'skauvokteren': ('skauvokter',),
'skauvokterer': ('skauvokter',),
'skauvokterne': ('skauvokter',),
'skauås': ('skauås',),
'skauåsen': ('skauås',),
'skauåsene': ('skauås',),
'skauåser': ('skauås',),
'skolebestyrer': ('skolebestyrer',),
'skolebestyrere': ('skolebestyrer',),
'skolebestyreren': ('skolebestyrer',),
'skolebestyrerer': ('skolebestyrer',),
'skolebestyrerne': ('skolebestyrer',),
'skolebok': ('skolebok',),
'skoleboka': ('skolebok',),
'skoleboken': ('skolebok',),
'skolebøkene': ('skolebok',),
'skolebøker': ('skolebok',),
'skriftefar': ('skriftefar',),
'skriftefaren': ('skriftefar',),
'skriftefedre': ('skriftefar',),
'skriftefedrene': ('skriftefar',),
'skrivebok': ('skrivebok',),
'skriveboka': ('skrivebok',),
'skriveboken': ('skrivebok',),
'skrivebøkene': ('skrivebok',),
'skrivebøker': ('skrivebok',),
'skummetmjølk': ('skummetmjølk',),
'skummetmjølka': ('skummetmjølk',),
'skummetmjølken': ('skummetmjølk',),
'skummetmjølkene': ('skummetmjølk',),
'skummetmjølker': ('skummetmjølk',),
'skummamjølk': ('skummamjølk',),
'skummamjølka': ('skummamjølk',),
'skummamjølken': ('skummamjølk',),
'skummamjølkene': ('skummamjølk',),
'skummamjølker': ('skummamjølk',),
'skyldoffer': ('skyldoffer',),
'skyldofferet': ('skyldoffer',),
'skyldofra': ('skyldoffer',),
'skyldofre': ('skyldoffer',),
'skyldofrene': ('skyldoffer',),
'skyss-skaffer': ('skyss-skaffer',),
'skyss-skaffere': ('skyss-skaffer',),
'skyss-skafferen': ('skyss-skaffer',),
'skyss-skafferer': ('skyss-skaffer',),
'skyss-skafferne': ('skyss-skaffer',),
'skysskaffer': ('skysskaffer',),
'skysskaffere': ('skysskaffer',),
'skysskafferen': ('skysskaffer',),
'skysskafferer': ('skysskaffer',),
'skysskafferne': ('skysskaffer',),
'slalåmski': ('slalåmski',),
'slalåmskia': ('slalåmski',),
'slalåmskien': ('slalåmski',),
'slalåmskiene': ('slalåmski',),
'slalåmskier': ('slalåmski',),
'sliperem': ('sliperem',),
'sliperema': ('sliperem',),
'sliperemen': ('sliperem',),
'sliperemene': ('sliperem',),
'sliperemer': ('sliperem',),
'sliperemma': ('sliperem',),
'sliperemmen': ('sliperem',),
'sliperemmene': ('sliperem',),
'sliperemmer': ('sliperem',),
'sløkkingsarbeid': ('sløkkingsarbeid',),
'sløkkingsarbeida': ('sløkkingsarbeid',),
'sløkkingsarbeidene': ('sløkkingsarbeid',),
'sløkkingsarbeider': ('sløkkingsarbeid',),
'sløkkingsarbeidet': ('sløkkingsarbeid',),
'slåttegrøt': ('slåttegrøt',),
'slåttegrøten': ('slåttegrøt',),
'slåttegrøtene': ('slåttegrøt',),
'slåttegrøter': ('slåttegrøt',),
'smørøya': ('smørøye',),
'smørøye': ('smørøye',),
'smørøyene': ('smørøye',),
'smørøyer': ('smørøye',),
'smørøyet': ('smørøye',),
'smørøyne': ('smørøye',),
'smørøynene': ('smørøye',),
'småskau': ('småskau',),
'småskauen': ('småskau',),
'småskauene': ('småskau',),
'småskauer': ('småskau',),
'sne': ('sne',),
'sneen': ('sne',),
'sneene': ('sne',),
'sneer': ('sne',),
'snowboard': ('snowboard',),
'snowboarden': ('snowboard',),
'snowboardene': ('snowboard',),
'snowboarder': ('snowboard',),
'snurpenot': ('snurpenot',),
'snurpenota': ('snurpenot',),
'snurpenoten': ('snurpenot',),
'snurpenøtene': ('snurpenot',),
'snurpenøter': ('snurpenot',),
'sokkeleist': ('sokkeleist',),
'sokkeleisten': ('sokkeleist',),
'sokkeleistene': ('sokkeleist',),
'sokkeleister': ('sokkeleist',),
'soppdreper': ('soppdreper',),
'soppdrepere': ('soppdreper',),
'soppdreperen': ('soppdreper',),
'soppdreperer': ('soppdreper',),
'soppdreperne': ('soppdreper',),
'sovedukka': ('sovedukke',),
'sovedukke': ('sovedukke',),
'sovedukken': ('sovedukke',),
'sovedukkene': ('sovedukke',),
'sovedukker': ('sovedukke',),
'sovekupeen': ('sovekupé',),
'sovekupeene': ('sovekupé',),
'sovekupeer': ('sovekupé',),
'sovekupé': ('sovekupé',),
'sovekupéen': ('sovekupé',),
'sovekupéene': ('sovekupé',),
'sovekupéer': ('sovekupé',),
'sovjeter': ('sovjeter',),
'sovjetere': ('sovjeter',),
'sovjeteren': ('sovjeter',),
'sovjeterer': ('sovjeter',),
'sovjeterne': ('sovjeter',),
'spiralfjær': ('spiralfjær',),
'spiralfjæra': ('spiralfjær',),
'spiralfjæren': ('spiralfjær',),
'spiralfjærene': ('spiralfjær',),
'spiralfjærer': ('spiralfjær',),
'spiralfjør': ('spiralfjør',),
'spiralfjøra': ('spiralfjør',),
'spiralfjøren': ('spiralfjør',),
'spiralfjørene': ('spiralfjør',),
'spiralfjører': ('spiralfjør',),
'spissrotgang': ('spissrotgang',),
'spissrotgangen': ('spissrotgang',),
'spissrotgangene': ('spissrotgang',),
'spissrotganger': ('spissrotgang',),
'sprik': ('sprik',),
'spriken': ('sprik',),
'sprikene': ('sprik',),
'spriker': ('sprik',),
'stamfar': ('stamfar',),
'stamfaren': ('stamfar',),
'stamfedre': ('stamfar',),
'stamfedrene': ('stamfar',),
'stamkafeen': ('stamkafé',),
'stamkafeene': ('stamkafé',),
'stamkafeer': ('stamkafé',),
'stamkafé': ('stamkafé',),
'stamkaféen': ('stamkafé',),
'stamkaféene': ('stamkafé',),
'stamkaféer': ('stamkafé',),
'stamtre': ('stamtre',),
'stamtrea': ('stamtre',),
'stamtreet': ('stamtre',),
'stamtrær': ('stamtre',),
'stamtrærne': ('stamtre',),
'statsskau': ('statsskau',),
'statsskauen': ('statsskau',),
'statsskauene': ('statsskau',),
'statsskauer': ('statsskau',),
'staurhenning': ('staurhenning',),
'staurhenninga': ('staurhenning',),
'staurhenningen': ('staurhenning',),
'staurhenningene': ('staurhenning',),
'staurhenninger': ('staurhenning',),
'staurhyrning': ('staurhyrning',),
'staurhyrninga': ('staurhyrning',),
'staurhyrningen': ('staurhyrning',),
'staurhyrningene': ('staurhyrning',),
'staurhyrninger': ('staurhyrning',),
'staurhyrning': ('staurhyrning',),
'staurhyrninga': ('staurhyrning',),
'staurhyrningen': ('staurhyrning',),
'staurhyrningene': ('staurhyrning',),
'staurhyrninger': ('staurhyrning',),
'staurhenning': ('staurhenning',),
'staurhenninga': ('staurhenning',),
'staurhenningen': ('staurhenning',),
'staurhenningene': ('staurhenning',),
'staurhenninger': ('staurhenning',),
'stedsnavnsforskning': ('stedsnavnsforskning',),
'stedsnavnsforskninga': ('stedsnavnsforskning',),
'stedsnavnsforskningen': ('stedsnavnsforskning',),
'stedsnavnsforskningene': ('stedsnavnsforskning',),
'stedsnavnsforskninger': ('stedsnavnsforskning',),
'stempelfjær': ('stempelfjær',),
'stempelfjæra': ('stempelfjær',),
'stempelfjæren': ('stempelfjær',),
'stempelfjærene': ('stempelfjær',),
'stempelfjærer': ('stempelfjær',),
'stempelfjør': ('stempelfjør',),
'stempelfjøra': ('stempelfjør',),
'stempelfjøren': ('stempelfjør',),
'stempelfjørene': ('stempelfjør',),
'stempelfjører': ('stempelfjør',),
'stiftsstad': ('stiftsstad',),
'stiftsstaden': ('stiftsstad',),
'stiftsstedene': ('stiftsstad',),
'stiftssteder': ('stiftsstad',),
'stormløkt': ('stormløkt',),
'stormløkta': ('stormløkt',),
'stormløkten': ('stormløkt',),
'stormløktene': ('stormløkt',),
'stormløkter': ('stormløkt',),
'stortingskomiteen': ('stortingskomité',),
'stortingskomiteene': ('stortingskomité',),
'stortingskomiteer': ('stortingskomité',),
'stortingskomité': ('stortingskomité',),
'stortingskomitéen': ('stortingskomité',),
'stortingskomitéene': ('stortingskomité',),
'stortingskomitéer': ('stortingskomité',),
'striregn': ('striregn',),
'striregna': ('striregn',),
'striregnene': ('striregn',),
'striregnet': ('striregn',),
'stråfôr': ('stråfôr',),
'stråfôra': ('stråfôr',),
'stråfôrene': ('stråfôr',),
'stråfôret': ('stråfôr',),
'studieleier': ('studieleier',),
'studieleiere': ('studieleier',),
'studieleieren': ('studieleier',),
'studieleierer': ('studieleier',),
'studieleierne': ('studieleier',),
'stålfjær': ('stålfjær',),
'stålfjæra': ('stålfjær',),
'stålfjæren': ('stålfjær',),
'stålfjærene': ('stålfjær',),
'stålfjærer': ('stålfjær',),
'stålfjør': ('stålfjør',),
'stålfjøra': ('stålfjør',),
'stålfjøren': ('stålfjør',),
'stålfjørene': ('stålfjør',),
'stålfjører': ('stålfjør',),
'superleier': ('superleier',),
'superleiere': ('superleier',),
'superleieren': ('superleier',),
'superleierer': ('superleier',),
'superleierne': ('superleier',),
'supraleier': ('supraleier',),
'supraleiere': ('supraleier',),
'supraleieren': ('supraleier',),
'supraleierer': ('supraleier',),
'supraleierne': ('supraleier',),
'surfôr': ('surfôr',),
'surfôra': ('surfôr',),
'surfôrene': ('surfôr',),
'surfôret': ('surfôr',),
'surmjølk': ('surmjølk',),
'surmjølka': ('surmjølk',),
'surmjølken': ('surmjølk',),
'surmjølkene': ('surmjølk',),
'surmjølker': ('surmjølk',),
'svetterem': ('svetterem',),
'svetteremma': ('svetterem',),
'svetteremmen': ('svetterem',),
'svetteremmene': ('svetterem',),
'svetteremmer': ('svetterem',),
'svigerfar': ('svigerfar',),
'svigerfaren': ('svigerfar',),
'svigerfedre': ('svigerfar',),
'svigerfedrene': ('svigerfar',),
'svinestek': ('svinestek',),
'svinesteka': ('svinestek',),
'svinesteken': ('svinestek',),
'svinestekene': ('svinestek',),
'svinesteker': ('svinestek',),
'sviskegrøt': ('sviskegrøt',),
'sviskegrøten': ('sviskegrøt',),
'sviskegrøtene': ('sviskegrøt',),
'sviskegrøter': ('sviskegrøt',),
'svømmefot': ('svømmefot',),
'svømmefoten': ('svømmefot',),
'svømmeføttene': ('svømmefot',),
'svømmeføtter': ('svømmefot',),
'syltefôr': ('syltefôr',),
'syltefôra': ('syltefôr',),
'syltefôrene': ('syltefôr',),
'syltefôret': ('syltefôr',),
'synsrand': ('synsrand',),
'synsranda': ('synsrand',),
'synsranden': ('synsrand',),
'synsrendene': ('synsrand',),
'synsrender': ('synsrand',),
'søtmjølk': ('søtmjølk',),
'søtmjølka': ('søtmjølk',),
'søtmjølken': ('søtmjølk',),
'søtmjølkene': ('søtmjølk',),
'søtmjølker': ('søtmjølk',),
'talefot': ('talefot',),
'talefoten': ('talefot',),
'taleføttene': ('talefot',),
'taleføtter': ('talefot',),
'teddyfôr': ('teddyfôr',),
'teddyfôra': ('teddyfôr',),
'teddyfôrene': ('teddyfôr',),
'teddyfôret': ('teddyfôr',),
'tigerstad': ('tigerstad',),
'tigerstaden': ('tigerstad',),
'tigerstedene': ('tigerstad',),
'tigersteder': ('tigerstad',),
'tiltru': ('tiltru',),
'tiltrua': ('tiltru',),
'tiltruen': ('tiltru',),
'tiltruene': ('tiltru',),
'tiltruer': ('tiltru',),
'tippoldefar': ('tippoldefar',),
'tippoldefaren': ('tippoldefar',),
'tippoldefedre': ('tippoldefar',),
'tippoldefedrene': ('tippoldefar',),
'tippoldeforeldre': ('tippoldeforeldre',),
'tippoldeforeldrene': ('tippoldeforeldre',),
'tippoldemor': ('tippoldemor',),
'tippoldemora': ('tippoldemor',),
'tippoldemoren': ('tippoldemor',),
'tippoldemødre': ('tippoldemor',),
'tippoldemødrene': ('tippoldemor',),
'tippoldemødrer': ('tippoldemor',),
'tjøreblom': ('tjøreblom',),
'tjøreblommen': ('tjøreblom',),
'tjøreblommene': ('tjøreblom',),
'tjøreblommer': ('tjøreblom',),
'tjøreblomst': ('tjøreblomst',),
'tjøreblomsten': ('tjøreblomst',),
'tjøreblomstene': ('tjøreblomst',),
'tjøreblomster': ('tjøreblomst',),
'tjørebrenner': ('tjørebrenner',),
'tjørebrennere': ('tjørebrenner',),
'tjørebrenneren': ('tjørebrenner',),
'tjørebrennerer': ('tjørebrenner',),
'tjørebrennerne': ('tjørebrenner',),
'tjørebånd': ('tjørebånd',),
'tjørebånda': ('tjørebånd',),
'tjørebåndene': ('tjørebånd',),
'tjørebåndet': ('tjørebånd',),
'tjøreband': ('tjøreband',),
'tjørebanda': ('tjøreband',),
'tjørebandene': ('tjøreband',),
'tjørebandet': ('tjøreband',),
'tjørekost': ('tjørekost',),
'tjørekosten': ('tjørekost',),
'tjørekostene': ('tjørekost',),
'tjørekoster': ('tjørekost',),
'tjørepapp': ('tjørepapp',),
'tjørepappen': ('tjørepapp',),
'tjørepappene': ('tjørepapp',),
'tjørepapper': ('tjørepapp',),
'tjøresåpa': ('tjøresåpe',),
'tjøresåpe': ('tjøresåpe',),
'tjøresåpen': ('tjøresåpe',),
'tjøresåpene': ('tjøresåpe',),
'tjøresåper': ('tjøresåpe',),
'tomannshand': ('tomannshand',),
'tomannshanda': ('tomannshand',),
'tomannshanden': ('tomannshand',),
'tomannshendene': ('tomannshand',),
'tomannshender': ('tomannshand',),
'tomannshendene': ('tomannshånd',),
'tomannshender': ('tomannshånd',),
'tomannshånd': ('tomannshånd',),
'tomannshånda': ('tomannshånd',),
'tomannshånden': ('tomannshånd',),
'tomatpureen': ('tomatpuré',),
'tomatpureene': ('tomatpuré',),
'tomatpureer': ('tomatpuré',),
'tomatpuré': ('tomatpuré',),
'tomatpuréen': ('tomatpuré',),
'tomatpuréene': ('tomatpuré',),
'tomatpuréer': ('tomatpuré',),
'torv': ('torv',),
'torva': ('torv',),
'torvene': ('torv',),
'torvet': ('torv',),
'totalsystem': ('totalsystem',),
'totalsystema': ('totalsystem',),
'totalsystemene': ('totalsystem',),
'totalsystemer': ('totalsystem',),
'totalsystemet': ('totalsystem',),
'totallsystem': ('totallsystem',),
'totallsystema': ('totallsystem',),
'totallsystemene': ('totallsystem',),
'totallsystemer': ('totallsystem',),
'totallsystemet': ('totallsystem',),
'traktorsko': ('traktorsko',),
'traktorskoa': ('traktorsko',),
'traktorskoen': ('traktorsko',),
'traktorskoene': ('traktorsko',),
'traktorskor': ('traktorsko',),
'traktorskorne': ('traktorsko',),
'tresko': ('tresko',),
'treskoa': ('tresko',),
'treskoen': ('tresko',),
'treskoene': ('tresko',),
'treskor': ('tresko',),
'treskorne': ('tresko',),
'tretjøra': ('tretjøre',),
'tretjøre': ('tretjøre',),
'tretjøren': ('tretjøre',),
'tretjørene': ('tretjøre',),
'tretjører': ('tretjøre',),
'troskapseid': ('troskapseid',),
'troskapseiden': ('troskapseid',),
'troskapseidene': ('troskapseid',),
'troskapseider': ('troskapseid',),
'truskapseid': ('truskapseid',),
'truskapseiden': ('truskapseid',),
'truskapseidene': ('truskapseid',),
'truskapseider': ('truskapseid',),
'trusel': ('trusel',),
'truselen': ('trusel',),
'truselene': ('trusel',),
'truseler': ('trusel',),
'turnsko': ('turnsko',),
'turnskoa': ('turnsko',),
'turnskoen': ('turnsko',),
'turnskoene': ('turnsko',),
'turnskor': ('turnsko',),
'turnskorne': ('turnsko',),
'turu': ('turu',),
'turua': ('turu',),
'turuen': ('turu',),
'turuene': ('turu',),
'turuer': ('turu',),
'turu': ('turu',),
'turua': ('turu',),
'turuen': ('turu',),
'turuene': ('turu',),
'turuer': ('turu',),
'tvora': ('tvore',),
'tvore': ('tvore',),
'tvoren': ('tvore',),
'tvorene': ('tvore',),
'tvorer': ('tvore',),
'tvora': ('tvore',),
'tvore': ('tvore',),
'tvoren': ('tvore',),
'tvorene': ('tvore',),
'tvorer': ('tvore',),
'tønnebånd': ('tønnebånd',),
'tønnebånda': ('tønnebånd',),
'tønnebåndene': ('tønnebånd',),
'tønnebåndet': ('tønnebånd',),
'tyntøl': ('tyntøl',),
'tyntøla': ('tyntøl',),
'tyntølene': ('tyntøl',),
'tyntølet': ('tyntøl',),
'tytebær': ('tytebær',),
'tytebæra': ('tytebær',),
'tytebærene': ('tytebær',),
'tytebæret': ('tytebær',),
'tønnebånd': ('tønnebånd',),
'tønnebånda': ('tønnebånd',),
'tønnebåndene': ('tønnebånd',),
'tønnebåndet': ('tønnebånd',),
'tørrfôr': ('tørrfôr',),
'tørrfôra': ('tørrfôr',),
'tørrfôrene': ('tørrfôr',),
'tørrfôret': ('tørrfôr',),
'ubekjentskap': ('ubekjentskap',),
'ubekjentskapa': ('ubekjentskap',),
'ubekjentskapene': ('ubekjentskap',),
'ubekjentskaper': ('ubekjentskap',),
'ubekjentskapet': ('ubekjentskap',),
'ulikskap': ('ulikskap',),
'ulikskapen': ('ulikskap',),
'ulikskapene': ('ulikskap',),
'ulikskaper': ('ulikskap',),
'underskau': ('underskau',),
'underskauen': ('underskau',),
'underskauene': ('underskau',),
'underskauer': ('underskau',),
'ungdomsleier': ('ungdomsleier',),
'ungdomsleiere': ('ungdomsleier',),
'ungdomsleieren': ('ungdomsleier',),
'ungdomsleierer': ('ungdomsleier',),
'ungdomsleierne': ('ungdomsleier',),
'ungskau': ('ungskau',),
'ungskauen': ('ungskau',),
'ungskauene': ('ungskau',),
'ungskauer': ('ungskau',),
'unntagelseslov': ('unntagelseslov',),
'unntagelsesloven': ('unntagelseslov',),
'unntagelseslovene': ('unntagelseslov',),
'unntagelseslover': ('unntagelseslov',),
'unntagelsestilfella': ('unntagelsestilfelle',),
'unntagelsestilfelle': ('unntagelsestilfelle',),
'unntagelsestilfellene': ('unntagelsestilfelle',),
'unntagelsestilfeller': ('unntagelsestilfelle',),
'unntagelsestilfellet': ('unntagelsestilfelle',),
'unntagelsestilstand': ('unntagelsestilstand',),
'unntagelsestilstanden': ('unntagelsestilstand',),
'unntagelsestilstandene': ('unntagelsestilstand',),
'unntagelsestilstander': ('unntagelsestilstand',),
'uranbekerts': ('uranbekerts',),
'uranbekertsen': ('uranbekerts',),
'uranbekertsene': ('uranbekerts',),
'uranbekertser': ('uranbekerts',),
'urinleier': ('urinleier',),
'urinleiere': ('urinleier',),
'urinleieren': ('urinleier',),
'urinleierer': ('urinleier',),
'urinleierne': ('urinleier',),
'urskau': ('urskau',),
'urskauen': ('urskau',),
'urskauene': ('urskau',),
'urskauer': ('urskau',),
'utklypp': ('utklypp',),
'utklyppen': ('utklypp',),
'utklyppene': ('utklypp',),
'utklypper': ('utklypp',),
'utklypping': ('utklypping',),
'utklyppinga': ('utklypping',),
'utklyppingen': ('utklypping',),
'utklyppingene': ('utklypping',),
'utklyppinger': ('utklypping',),
'utklyppingsbyrå': ('utklyppingsbyrå',),
'utklyppingsbyråa': ('utklyppingsbyrå',),
'utklyppingsbyråene': ('utklyppingsbyrå',),
'utklyppingsbyråer': ('utklyppingsbyrå',),
'utklyppingsbyrået': ('utklyppingsbyrå',),
'utklyppsalbum': ('utklyppsalbum',),
'utklyppsalbuma': ('utklyppsalbum',),
'utklyppsalbumene': ('utklyppsalbum',),
'utklyppsalbumer': ('utklyppsalbum',),
'utklyppsalbumet': ('utklyppsalbum',),
'utklyppsbyrå': ('utklyppsbyrå',),
'utklyppsbyråa': ('utklyppsbyrå',),
'utklyppsbyråene': ('utklyppsbyrå',),
'utklyppsbyråer': ('utklyppsbyrå',),
'utklyppsbyrået': ('utklyppsbyrå',),
'utviklingshemming': ('utviklingshemming',),
'utviklingshemminga': ('utviklingshemming',),
'utviklingshemmingen': ('utviklingshemming',),
'utviklingshemmingene': ('utviklingshemming',),
'utviklingshemminger': ('utviklingshemming',),
'valgkomiteen': ('valgkomité',),
'valgkomiteene': ('valgkomité',),
'valgkomiteer': ('valgkomité',),
'valgkomité': ('valgkomité',),
'valgkomitéen': ('valgkomité',),
'valgkomitéene': ('valgkomité',),
'valgkomitéer': ('valgkomité',),
'vandremåndag': ('vandremåndag',),
'vandremåndagen': ('vandremåndag',),
'vandremåndagene': ('vandremåndag',),
'vandremåndager': ('vandremåndag',),
'vannski': ('vannski',),
'vannskia': ('vannski',),
'vannskien': ('vannski',),
'vannskiene': ('vannski',),
'vannskier': ('vannski',),
'vass-ski': ('vass-ski',),
'vass-skia': ('vass-ski',),
'vass-skien': ('vass-ski',),
'vass-skiene': ('vass-ski',),
'vass-skier': ('vass-ski',),
'vasski': ('vasski',),
'vasskia': ('vasski',),
'vasskien': ('vasski',),
'vasskiene': ('vasski',),
'vasskier': ('vasski',),
'varmeleier': ('varmeleier',),
'varmeleiere': ('varmeleier',),
'varmeleieren': ('varmeleier',),
'varmeleierer': ('varmeleier',),
'varmeleierne': ('varmeleier',),
'varmvatn': ('varmvatn',),
'varmvatna': ('varmvatn',),
'varmvatnene': ('varmvatn',),
'varmvatnet': ('varmvatn',),
'vattersott': ('vattersott',),
'vattersotta': ('vattersott',),
'vattersotten': ('vattersott',),
'vattersottene': ('vattersott',),
'vattersotter': ('vattersott',),
'veisalt': ('veisalt',),
'veisalta': ('veisalt',),
'veisaltene': ('veisalt',),
'veisalter': ('veisalt',),
'veisaltet': ('veisalt',),
'vegsalt': ('vegsalt',),
'vegsalta': ('vegsalt',),
'vegsaltene': ('vegsalt',),
'vegsalter': ('vegsalt',),
'vegsaltet': ('vegsalt',),
'veitraseen': ('veitrasé',),
'veitraseene': ('veitrasé',),
'veitraseer': ('veitrasé',),
'veitrasé': ('veitrasé',),
'veitraséen': ('veitrasé',),
'veitraséene': ('veitrasé',),
'veitraséer': ('veitrasé',),
'vegtraseen': ('vegtrasé',),
'vegtraseene': ('vegtrasé',),
'vegtraseer': ('vegtrasé',),
'vegtrasé': ('vegtrasé',),
'vegtraséen': ('vegtrasé',),
'vegtraséene': ('vegtrasé',),
'vegtraséer': ('vegtrasé',),
'venstrefot': ('venstrefot',),
'venstrefoten': ('venstrefot',),
'venstreføttene': ('venstrefot',),
'venstreføtter': ('venstrefot',),
'kvefsebol': ('kvefsebol',),
'kvefsebola': ('kvefsebol',),
'kvefsebolene': ('kvefsebol',),
'kvefsebolet': ('kvefsebol',),
'kvefsestikk': ('kvefsestikk',),
'kvefsestikka': ('kvefsestikk',),
'kvefsestikkene': ('kvefsestikk',),
'kvefsestikket': ('kvefsestikk',),
'kvefsetalja': ('kvefsetalje',),
'kvefsetalje': ('kvefsetalje',),
'kvefsetaljen': ('kvefsetalje',),
'kvefsetaljene': ('kvefsetalje',),
'kvefsetaljer': ('kvefsetalje',),
'vernepliktsbok': ('vernepliktsbok',),
'vernepliktsboka': ('vernepliktsbok',),
'vernepliktsboken': ('vernepliktsbok',),
'vernepliktsbøkene': ('vernepliktsbok',),
'vernepliktsbøker': ('vernepliktsbok',),
'vernesko': ('vernesko',),
'verneskoa': ('vernesko',),
'verneskoen': ('vernesko',),
'verneskoene': ('vernesko',),
'verneskor': ('vernesko',),
'verneskorne': ('vernesko',),
'verneskau': ('verneskau',),
'verneskauen': ('verneskau',),
'verneskauene': ('verneskau',),
'verneskauer': ('verneskau',),
'versefot': ('versefot',),
'versefoten': ('versefot',),
'verseføttene': ('versefot',),
'verseføtter': ('versefot',),
'versfot': ('versfot',),
'versfoten': ('versfot',),
'versføttene': ('versfot',),
'versføtter': ('versfot',),
'vestefôr': ('vestefôr',),
'vestefôra': ('vestefôr',),
'vestefôrene': ('vestefôr',),
'vestefôret': ('vestefôr',),
'vestfôr': ('vestfôr',),
'vestfôra': ('vestfôr',),
'vestfôrene': ('vestfôr',),
'vestfôret': ('vestfôr',),
'vifterem': ('vifterem',),
'vifteremma': ('vifterem',),
'vifteremmen': ('vifterem',),
'vifteremmene': ('vifterem',),
'vifteremmer': ('vifterem',),
'vindstilla': ('vindstille',),
'vindstille': ('vindstille',),
'vindstillen': ('vindstille',),
'vindstillene': ('vindstille',),
'vindstiller': ('vindstille',),
'vinterfôr': ('vinterfôr',),
'vinterfôra': ('vinterfôr',),
'vinterfôrene': ('vinterfôr',),
'vinterfôret': ('vinterfôr',),
'vinterfôring': ('vinterfôring',),
'vinterfôringa': ('vinterfôring',),
'vinterfôringen': ('vinterfôring',),
'vinterfôringene': ('vinterfôring',),
'vinterfôringer': ('vinterfôring',),
'vitende': ('vitende',),
'vrangmoska': ('vrangmoske',),
'vrangmoske': ('vrangmoske',),
'vrangmosken': ('vrangmoske',),
'vrangmoskene': ('vrangmoske',),
'vrangmosker': ('vrangmoske',),
'værforeldre': ('værforeldre',),
'værforeldrene': ('værforeldre',),
'vørterøl': ('vørterøl',),
'vørterøla': ('vørterøl',),
'vørterølene': ('vørterøl',),
'vørterølet': ('vørterøl',),
'vårflom': ('vårflom',),
'vårflommen': ('vårflom',),
'vårflommene': ('vårflom',),
'vårflommer': ('vårflom',),
'våtfôr': ('våtfôr',),
'våtfôra': ('våtfôr',),
'våtfôrene': ('våtfôr',),
'våtfôret': ('våtfôr',),
'whiplashskade': ('whiplashskade',),
'whiplashskaden': ('whiplashskade',),
'whiplashskadene': ('whiplashskade',),
'whiplashskader': ('whiplashskade',),
'yrkesrettleier': ('yrkesrettleier',),
'yrkesrettleiere': ('yrkesrettleier',),
'yrkesrettleieren': ('yrkesrettleier',),
'yrkesrettleierer': ('yrkesrettleier',),
'yrkesrettleierne': ('yrkesrettleier',),
'yttertøy': ('yttertøy',),
'yttertøya': ('yttertøy',),
'yttertøyene': ('yttertøy',),
'yttertøyer': ('yttertøy',),
'yttertøyet': ('yttertøy',),
'kvitlaukfedd': ('kvitlaukfedd',),
'kvitlaukfedda': ('kvitlaukfedd',),
'kvitlaukfeddene': ('kvitlaukfedd',),
'kvitlaukfeddet': ('kvitlaukfedd',),
'kvitlaukpulver': ('kvitlaukpulver',),
'kvitlaukpulvera': ('kvitlaukpulver',),
'kvitlaukpulvere': ('kvitlaukpulver',),
'kvitlaukpulveret': ('kvitlaukpulver',),
'kvitlaukpulverne': ('kvitlaukpulver',),
'pålsmess': ('pålsmess',),
'adkomst': ('adkomst',),
'adkomsten': ('adkomst',),
'adkomstene': ('adkomst',),
'adkomster': ('adkomst',),
'aker': ('aker',),
'akeren': ('aker',),
'akre': ('aker',),
'akrene': ('aker',),
'akrer': ('aker',),
'åndebesverger': ('åndebesverger',),
'åndebesvergere': ('åndebesverger',),
'åndebesvergeren': ('åndebesverger',),
'åndebesvergerer': ('åndebesverger',),
'åndebesvergerne': ('åndebesverger',),
'antagelse': ('antagelse',),
'antagelsen': ('antagelse',),
'antagelsene': ('antagelse',),
'antagelser': ('antagelse',),
'appelsintre': ('appelsintre',),
'appelsintrea': ('appelsintre',),
'appelsintreet': ('appelsintre',),
'appelsintrær': ('appelsintre',),
'appelsintrærne': ('appelsintre',),
'arbeidstager': ('arbeidstager',),
'arbeidstagere': ('arbeidstager',),
'arbeidstageren': ('arbeidstager',),
'arbeidstagerer': ('arbeidstager',),
'arbeidstagerne': ('arbeidstager',),
'arvtager': ('arvtager',),
'arvtagere': ('arvtager',),
'arvtageren': ('arvtager',),
'arvtagerer': ('arvtager',),
'arvtagerne': ('arvtager',),
'avtager': ('avtager',),
'avtagere': ('avtager',),
'avtageren': ('avtager',),
'avtagerer': ('avtager',),
'avtagerne': ('avtager',),
'B': ('B',),
'b': ('b',),
'babb': ('babb',),
'bandopptager': ('bandopptager',),
'bandopptagere': ('bandopptager',),
'bandopptageren': ('bandopptager',),
'bandopptagerer': ('bandopptager',),
'bandopptagerne': ('bandopptager',),
'blomsterlauk': ('blomsterlauk',),
'blomsterlauken': ('blomsterlauk',),
'blomsterlaukene': ('blomsterlauk',),
'blomsterlauker': ('blomsterlauk',),
'bo': ('bo',),
'boen': ('bo',),
'boene': ('bo',),
'boer': ('bo',),
'bolignaud': ('bolignaud',),
'bolignauda': ('bolignaud',),
'bolignauden': ('bolignaud',),
'bolignaudene': ('bolignaud',),
'bolignauder': ('bolignaud',),
'bonbon': ('bonbon',),
'bonbonen': ('bonbon',),
'bonbonene': ('bonbon',),
'bonboner': ('bonbon',),
'buké': ('buké',),
'bukéen': ('buké',),
'bukéene': ('buké',),
'bukéer': ('buké',),
'buklé': ('buklé',),
'bukléen': ('buklé',),
'bukléene': ('buklé',),
'bukléer': ('buklé',),
'båndopptager': ('båndopptager',),
'båndopptagere': ('båndopptager',),
'båndopptageren': ('båndopptager',),
'båndopptagerer': ('båndopptager',),
'båndopptagerne': ('båndopptager',),
'capo': ('capo',),
'capoen': ('capo',),
'capoene': ('capo',),
'capoer': ('capo',),
'castillaner': ('castillaner',),
'castillanere': ('castillaner',),
'castillaneren': ('castillaner',),
'castillanerer': ('castillaner',),
'castillanerne': ('castillaner',),
'charisma': ('charisma',),
'charismaen': ('charisma',),
'charismaene': ('charisma',),
'charismaer': ('charisma',),
'chiasme': ('chiasme',),
'chiasmen': ('chiasme',),
'chiasmene': ('chiasme',),
'chiasmer': ('chiasme',),
'chip': ('chip',),
'chipen': ('chip',),
'chipene': ('chip',),
'chiper': ('chip',),
'computer': ('computer',),
'computere': ('computer',),
'computeren': ('computer',),
'computerer': ('computer',),
'computerne': ('computer',),
'crawl': ('crawl',),
'crawlen': ('crawl',),
'crawlene': ('crawl',),
'crawler': ('crawl',),
'deltager': ('deltager',),
'deltagere': ('deltager',),
'deltageren': ('deltager',),
'deltagerer': ('deltager',),
'deltagerne': ('deltager',),
'deltagelse': ('deltagelse',),
'deltagelsen': ('deltagelse',),
'deltagelsene': ('deltagelse',),
'deltagelser': ('deltagelse',),
'dy': ('dy',),
'dya': ('dy',),
'dyene': ('dy',),
'dyet': ('dy',),
'eschatologi': ('eschatologi',),
'eschatologien': ('eschatologi',),
'eschatologiene': ('eschatologi',),
'eschatologier': ('eschatologi',),
'ess': ('ess',),
'essa': ('ess',),
'essene': ('ess',),
'esset': ('ess',),
'ess': ('ess',),
'falloskult': ('falloskult',),
'falloskulten': ('falloskult',),
'falloskultene': ('falloskult',),
'falloskulter': ('falloskult',),
'falloskultus': ('falloskultus',),
'falloskultusen': ('falloskultus',),
'falloskultusene': ('falloskultus',),
'falloskultuser': ('falloskultus',),
'feiltagelse': ('feiltagelse',),
'feiltagelsen': ('feiltagelse',),
'feiltagelsene': ('feiltagelse',),
'feiltagelser': ('feiltagelse',),
'fellessæter': ('fellessæter',),
'fellessæteren': ('fellessæter',),
'fellessætra': ('fellessæter',),
'fellessætre': ('fellessæter',),
'fellessætrene': ('fellessæter',),
'fellessætrer': ('fellessæter',),
'fellessæter': ('fellessæter',),
'fellessæteren': ('fellessæter',),
'fellessætra': ('fellessæter',),
'fellessætre': ('fellessæter',),
'fellessætrene': ('fellessæter',),
'fellessætrer': ('fellessæter',),
'fetisjtilbedelse': ('fetisjtilbedelse',),
'fetisjtilbedelsen': ('fetisjtilbedelse',),
'fetisjtilbedelsene': ('fetisjtilbedelse',),
'fetisjtilbedelser': ('fetisjtilbedelse',),
'fikentre': ('fikentre',),
'fikentrea': ('fikentre',),
'fikentreet': ('fikentre',),
'fikentrær': ('fikentre',),
'fikentrærne': ('fikentre',),
'fjernsynsmottager': ('fjernsynsmottager',),
'fjernsynsmottagere': ('fjernsynsmottager',),
'fjernsynsmottageren': ('fjernsynsmottager',),
'fjernsynsmottagerer': ('fjernsynsmottager',),
'fjernsynsmottagerne': ('fjernsynsmottager',),
'flaum': ('flaum',),
'flaumen': ('flaum',),
'flaumene': ('flaum',),
'flaumer': ('flaum',),
'flaum': ('flaum',),
'flaumen': ('flaum',),
'flaumene': ('flaum',),
'flaumer': ('flaum',),
'flyver': ('flyver',),
'flyvere': ('flyver',),
'flyveren': ('flyver',),
'flyverne': ('flyver',),
'fon': ('fon',),
'fonen': ('fon',),
'fonene': ('fon',),
'forsikringstager': ('forsikringstager',),
'forsikringstagere': ('forsikringstager',),
'forsikringstageren': ('forsikringstager',),
'forsikringstagerer': ('forsikringstager',),
'forsikringstagerne': ('forsikringstager',),
'fortaum': ('fortaum',),
'fortaumen': ('fortaum',),
'fortaumene': ('fortaum',),
'fortaumer': ('fortaum',),
'fortaum': ('fortaum',),
'fortaumen': ('fortaum',),
'fortaumene': ('fortaum',),
'fortaumer': ('fortaum',),
'foyer': ('foyer',),
'foyeren': ('foyer',),
'foyerene': ('foyer',),
'foyerer': ('foyer',),
'freak': ('freak',),
'freaken': ('freak',),
'freakene': ('freak',),
'freaker': ('freak',),
'fredskorpsdeltager': ('fredskorpsdeltager',),
'fredskorpsdeltagere': ('fredskorpsdeltager',),
'fredskorpsdeltageren': ('fredskorpsdeltager',),
'fredskorpsdeltagerer': ('fredskorpsdeltager',),
'fredskorpsdeltagerne': ('fredskorpsdeltager',),
'freelance': ('freelance',),
'freelancen': ('freelance',),
'freelancene': ('freelance',),
'freelancer': ('freelance',),
'freelancer': ('freelancer',),
'freelancere': ('freelancer',),
'freelanceren': ('freelancer',),
'freelancerer': ('freelancer',),
'freelancerne': ('freelancer',),
'fritagelse': ('fritagelse',),
'fritagelsen': ('fritagelse',),
'fritagelsene': ('fritagelse',),
'fritagelser': ('fritagelse',),
'gaselleøya': ('gaselleøyer',),
'gaselleøyene': ('gaselleøyer',),
'gaselleøyer': ('gaselleøyer',),
'gaselleøyne': ('gaselleøyer',),
'gaselleøynene': ('gaselleøyer',),
'gavn': ('gavn',),
'gavna': ('gavn',),
'gavnene': ('gavn',),
'gavnet': ('gavn',),
'genanse': ('genanse',),
'genansen': ('genanse',),
'genansene': ('genanse',),
'genanser': ('genanse',),
'gresslauk': ('gresslauk',),
'gresslauken': ('gresslauk',),
'gresslaukene': ('gresslauk',),
'gresslauker': ('gresslauk',),
'graslauk': ('graslauk',),
'graslauken': ('graslauk',),
'graslaukene': ('graslauk',),
'graslauker': ('graslauk',),
'grease': ('grease',),
'greasen': ('grease',),
'greasene': ('grease',),
'greaser': ('grease',),
'gruba': ('grube',),
'grube': ('grube',),
'gruben': ('grube',),
'grubene': ('grube',),
'gruber': ('grube',),
'gulf': ('gulf',),
'gulfen': ('gulf',),
'gulfene': ('gulf',),
'gulfer': ('gulf',),
'gumme': ('gumme',),
'gummen': ('gumme',),
'gummene': ('gumme',),
'gummer': ('gumme',),
'hagemøblene': ('hagemøbler',),
'hagemøbler': ('hagemøbler',),
'heimsæter': ('heimsæter',),
'heimsæteren': ('heimsæter',),
'heimsætra': ('heimsæter',),
'heimsætre': ('heimsæter',),
'heimsætrene': ('heimsæter',),
'heimsætrer': ('heimsæter',),
'heire': ('heire',),
'heiren': ('heire',),
'heirene': ('heire',),
'heirer': ('heire',),
'ho': ('ho',),
'hoa': ('ho',),
'hoen': ('ho',),
'hoene': ('ho',),
'hoer': ('ho',),
'ho': ('ho',),
'hoa': ('ho',),
'hoen': ('ho',),
'hoene': ('ho',),
'hoer': ('ho',),
'indantrenfargene': ('indantrenfarger',),
'indantrenfarger': ('indantrenfarger',),
'hvitlauk': ('hvitlauk',),
'hvitlauken': ('hvitlauk',),
'hvitlaukene': ('hvitlauk',),
'hvitlauker': ('hvitlauk',),
'kvitlauk': ('kvitlauk',),
'kvitlauken': ('kvitlauk',),
'kvitlaukene': ('kvitlauk',),
'kvitlauker': ('kvitlauk',),
'hvitlauk': ('hvitlauk',),
'hvitlauken': ('hvitlauk',),
'hvitlaukene': ('hvitlauk',),
'hvitlauker': ('hvitlauk',),
'kvitlauk': ('kvitlauk',),
'kvitlauken': ('kvitlauk',),
'kvitlaukene': ('kvitlauk',),
'kvitlauker': ('kvitlauk',),
'iakttager': ('iakttager',),
'iakttagere': ('iakttager',),
'iakttageren': ('iakttager',),
'iakttagerer': ('iakttager',),
'iakttagerne': ('iakttager',),
'ikke-røker': ('ikke-røker',),
'ikke-røkere': ('ikke-røker',),
'ikke-røkeren': ('ikke-røker',),
'ikke-røkerer': ('ikke-røker',),
'ikke-røkerne': ('ikke-røker',),
'initiativtager': ('initiativtager',),
'initiativtagere': ('initiativtager',),
'initiativtageren': ('initiativtager',),
'initiativtagerer': ('initiativtager',),
'initiativtagerne': ('initiativtager',),
'jernblåster': ('jernblåster',),
'jernblåstere': ('jernblåster',),
'jernblåsteren': ('jernblåster',),
'jernblåsterer': ('jernblåster',),
'jernblåsterne': ('jernblåster',),
'jernblåstre': ('jernblåster',),
'jernblåstrene': ('jernblåster',),
'jernblåstrer': ('jernblåster',),
'jordkvefs': ('jordkvefs',),
'jordkvefsen': ('jordkvefs',),
'jordkvefsene': ('jordkvefs',),
'jordkvefser': ('jordkvefs',),
'jordkvefs': ('jordkvefs',),
'jordkvefsen': ('jordkvefs',),
'jordkvefsene': ('jordkvefs',),
'jordkvefser': ('jordkvefs',),
'kampucheaner': ('kampucheaner',),
'kampucheanere': ('kampucheaner',),
'kampucheaneren': ('kampucheaner',),
'kampucheanerer': ('kampucheaner',),
'kampucheanerne': ('kampucheaner',),
'kepalauk': ('kepalauk',),
'kepalauken': ('kepalauk',),
'kepalaukene': ('kepalauk',),
'kepalauker': ('kepalauk',),
'khaki': ('khaki',),
'khakien': ('khaki',),
'khakiene': ('khaki',),
'khakier': ('khaki',),
'kjederøker': ('kjederøker',),
'kjederøkere': ('kjederøker',),
'kjederøkeren': ('kjederøker',),
'kjederøkerer': ('kjederøker',),
'kjederøkerne': ('kjederøker',),
'klypp': ('klypp',),
'klyppen': ('klypp',),
'klyppene': ('klypp',),
'klypper': ('klypp',),
'klypp': ('klypp',),
'klyppa': ('klypp',),
'klyppene': ('klypp',),
'klyppet': ('klypp',),
'klypp': ('klypp',),
'klyppa': ('klypp',),
'klyppene': ('klypp',),
'klyppet': ('klypp',),
'knickers': ('knickers',),
'knickersen': ('knickers',),
'knickersene': ('knickers',),
'knickerser': ('knickers',),
'kost': ('kost',),
'kosten': ('kost',),
'kostene': ('kost',),
'koster': ('kost',),
'kost': ('kost',),
'kosten': ('kost',),
'kostene': ('kost',),
'koster': ('kost',),
'koto': ('koto',),
'kotoen': ('koto',),
'kotoene': ('koto',),
'kotoer': ('koto',),
'koto': ('koto',),
'kotoen': ('koto',),
'kotoene': ('koto',),
'kotoer': ('koto',),
'krepp': ('krepp',),
'kreppen': ('krepp',),
'kreppene': ('krepp',),
'krepper': ('krepp',),
'krepp': ('krepp',),
'kreppen': ('krepp',),
'kreppene': ('krepp',),
'krepper': ('krepp',),
'kroknase': ('kroknase',),
'kroknasen': ('kroknase',),
'kroknasene': ('kroknase',),
'kroknaser': ('kroknase',),
'kvefs': ('kvefs',),
'kvefsen': ('kvefs',),
'kvefsene': ('kvefs',),
'kvefser': ('kvefs',),
'larveføttene': ('larveføtter',),
'larveføtter': ('larveføtter',),
'lauk': ('lauk',),
'lauken': ('lauk',),
'laukene': ('lauk',),
'lauker': ('lauk',),
'leietager': ('leietager',),
'leietagere': ('leietager',),
'leietageren': ('leietager',),
'leietagerer': ('leietager',),
'leietagerne': ('leietager',),
'lauk': ('lauk',),
'lauken': ('lauk',),
'laukene': ('lauk',),
'lauker': ('lauk',),
'lønnstager': ('lønnstager',),
'lønnstagere': ('lønnstager',),
'lønnstageren': ('lønnstager',),
'lønnstagerer': ('lønnstager',),
'lønnstagerne': ('lønnstager',),
'låntager': ('låntager',),
'låntagere': ('låntager',),
'låntageren': ('låntager',),
'låntagerer': ('låntager',),
'låntagerne': ('låntager',),
'lippa': ('lippe',),
'lippe': ('lippe',),
'lippen': ('lippe',),
'lippene': ('lippe',),
'lipper': ('lippe',),
'lavvanne': ('lavvanne',),
'lågvanne': ('lågvanne',),
'lippa': ('lippe',),
'lippe': ('lippe',),
'lippen': ('lippe',),
'lippene': ('lippe',),
'lipper': ('lippe',),
'lix': ('lix',),
'lixen': ('lix',),
'lixene': ('lix',),
'lixer': ('lix',),
'ljøske': ('ljøske',),
'ljøsken': ('ljøske',),
'ljøskene': ('ljøske',),
'ljøsker': ('ljøske',),
'lompa': ('lompe',),
'lompe': ('lompe',),
'lompen': ('lompe',),
'lompene': ('lompe',),
'lomper': ('lompe',),
'lompa': ('lompe',),
'lompe': ('lompe',),
'lompen': ('lompe',),
'lompene': ('lompe',),
'lomper': ('lompe',),
'luftlauk': ('luftlauk',),
'luftlauken': ('luftlauk',),
'luftlaukene': ('luftlauk',),
'luftlauker': ('luftlauk',),
'lycea': ('lyceum',),
'lyceene': ('lyceum',),
'lyceer': ('lyceum',),
'lyceet': ('lyceum',),
'lyceum': ('lyceum',),
'lydbåndopptager': ('lydbåndopptager',),
'lydbåndopptagere': ('lydbåndopptager',),
'lydbåndopptageren': ('lydbåndopptager',),
'lydbåndopptagerer': ('lydbåndopptager',),
'lydbåndopptagerne': ('lydbåndopptager',),
'lydbandopptager': ('lydbandopptager',),
'lydbandopptagere': ('lydbandopptager',),
'lydbandopptageren': ('lydbandopptager',),
'lydbandopptagerer': ('lydbandopptager',),
'lydbandopptagerne': ('lydbandopptager',),
'lysesløkker': ('lysesløkker',),
'lysesløkkere': ('lysesløkker',),
'lysesløkkeren': ('lysesløkker',),
'lysesløkkerer': ('lysesløkker',),
'lysesløkkerne': ('lysesløkker',),
'mottagelse': ('mottagelse',),
'mottagelsen': ('mottagelse',),
'mottagelsene': ('mottagelse',),
'mottagelser': ('mottagelse',),
'mottager': ('mottager',),
'mottagere': ('mottager',),
'mottageren': ('mottager',),
'mottagerer': ('mottager',),
'mottagerne': ('mottager',),
'muzak': ('muzak',),
'muzaken': ('muzak',),
'muzakene': ('muzak',),
'muzaker': ('muzak',),
'mørr': ('mørr',),
'mørren': ('mørr',),
'mørrene': ('mørr',),
'mørrer': ('mørr',),
'møtedeltager': ('møtedeltager',),
'møtedeltagere': ('møtedeltager',),
'møtedeltageren': ('møtedeltager',),
'møtedeltagerer': ('møtedeltager',),
'møtedeltagerne': ('møtedeltager',),
'naud': ('naud',),
'nauda': ('naud',),
'nauden': ('naud',),
'naudene': ('naud',),
'nauder': ('naud',),
'nyresteinknuser': ('nyresteinknuser',),
'nyresteinknusere': ('nyresteinknuser',),
'nyresteinknuseren': ('nyresteinknuser',),
'nyresteinknuserer': ('nyresteinknuser',),
'nyresteinknuserne': ('nyresteinknuser',),
'naud': ('naud',),
'nauda': ('naud',),
'nauden': ('naud',),
'naudene': ('naud',),
'nauder': ('naud',),
'nase': ('nase',),
'nasen': ('nase',),
'nasene': ('nase',),
'naser': ('nase',),
'nubbe': ('nubbe',),
'nubben': ('nubbe',),
'nubbene': ('nubbe',),
'nubber': ('nubbe',),
'opptager': ('opptager',),
'opptagere': ('opptager',),
'opptageren': ('opptager',),
'opptagerer': ('opptager',),
'opptagerne': ('opptager',),
'overlippa': ('overlippe',),
'overlippe': ('overlippe',),
'overlippen': ('overlippe',),
'overlippene': ('overlippe',),
'overlipper': ('overlippe',),
'oliventre': ('oliventre',),
'oliventrea': ('oliventre',),
'oliventreet': ('oliventre',),
'oliventrær': ('oliventre',),
'oliventrærne': ('oliventre',),
'opptagelse': ('opptagelse',),
'opptagelsen': ('opptagelse',),
'opptagelsene': ('opptagelse',),
'opptagelser': ('opptagelse',),
'p': ('p',),
'p\'en': ('p',),
'p-en': ('p',),
'p-ene': ('p',),
'p-er': ('p',),
'plateskifter': ('plateskifter',),
'plateskiftere': ('plateskifter',),
'plateskifteren': ('plateskifter',),
'plateskifterer': ('plateskifter',),
'plateskifterne': ('plateskifter',),
'potetopptager': ('potetopptager',),
'potetopptagere': ('potetopptager',),
'potetopptageren': ('potetopptager',),
'potetopptagerer': ('potetopptager',),
'potetopptagerne': ('potetopptager',),
'pristager': ('pristager',),
'pristagere': ('pristager',),
'pristageren': ('pristager',),
'pristagerer': ('pristager',),
'pristagerne': ('pristager',),
'protegeen': ('protegé',),
'protegeene': ('protegé',),
'protegeer': ('protegé',),
'protegé': ('protegé',),
'protegéen': ('protegé',),
'protegéene': ('protegé',),
'protegéer': ('protegé',),
'punk': ('punk',),
'punken': ('punk',),
'punkene': ('punk',),
'punker': ('punk',),
'punker': ('punker',),
'punkere': ('punker',),
'punkeren': ('punker',),
'punkerer': ('punker',),
'punkerne': ('punker',),
'purrelauk': ('purrelauk',),
'purrelauken': ('purrelauk',),
'purrelaukene': ('purrelauk',),
'purrelauker': ('purrelauk',),
'quichua': ('quichua',),
'quichuaen': ('quichua',),
'quichuaene': ('quichua',),
'quichuaer': ('quichua',),
'radiomottager': ('radiomottager',),
'radiomottagere': ('radiomottager',),
'radiomottageren': ('radiomottager',),
'radiomottagerer': ('radiomottager',),
'radiomottagerne': ('radiomottager',),
'ramslauk': ('ramslauk',),
'ramslauken': ('ramslauk',),
'ramslaukene': ('ramslauk',),
'ramslauker': ('ramslauk',),
'raudt': ('raudt',),
'rolleforventningene': ('rolleforventninger',),
'rolleforventninger': ('rolleforventninger',),
'raudt': ('raudt',),
'røker': ('røker',),
'røkere': ('røker',),
'røkeren': ('røker',),
'røkerer': ('røker',),
'røkerne': ('røker',),
'rosentre': ('rosentre',),
'rosentrea': ('rosentre',),
'rosentreet': ('rosentre',),
'rosetre': ('rosetre',),
'rosetrea': ('rosetre',),
'rosetreet': ('rosetre',),
'streta': ('strete',),
'strete': ('strete',),
'stretene': ('strete',),
'streter': ('strete',),
'stretet': ('strete',),
'synonympreparat': ('synonympreparat',),
'synonympreparata': ('synonympreparat',),
'synonympreparatene': ('synonympreparat',),
'synonympreparater': ('synonympreparat',),
'synonympreparatet': ('synonympreparat',),
'storpart': ('storpart',),
'storparten': ('storpart',),
'storpartene': ('storpart',),
'storparter': ('storpart',),
'scanner': ('scanner',),
'scannere': ('scanner',),
'scanneren': ('scanner',),
'scannerer': ('scanner',),
'scannerne': ('scanner',),
'sekstenhundretal': ('sekstenhundretal',),
'sekstenhundretala': ('sekstenhundretal',),
'sekstenhundretalene': ('sekstenhundretal',),
'sekstenhundretalet': ('sekstenhundretal',),
'sekstenhundretall': ('sekstenhundretall',),
'sekstenhundretalla': ('sekstenhundretall',),
'sekstenhundretallene': ('sekstenhundretall',),
'sekstenhundretallet': ('sekstenhundretall',),
'sengerøker': ('sengerøker',),
'sengerøkere': ('sengerøker',),
'sengerøkeren': ('sengerøker',),
'sengerøkerer': ('sengerøker',),
'sengerøkerne': ('sengerøker',),
'sæter': ('sæter',),
'sæteren': ('sæter',),
'sætra': ('sæter',),
'sætre': ('sæter',),
'sætrene': ('sæter',),
'sætrer': ('sæter',),
'sippa': ('sippe',),
'sippe': ('sippe',),
'sippen': ('sippe',),
'sippene': ('sippe',),
'sipper': ('sippe',),
'sjalottlauk': ('sjalottlauk',),
'sjalottlauken': ('sjalottlauk',),
'sjalottlaukene': ('sjalottlauk',),
'sjalottlauker': ('sjalottlauk',),
'skadeflaum': ('skadeflaum',),
'skadeflaumen': ('skadeflaum',),
'skadeflaumene': ('skadeflaum',),
'skadeflaumer': ('skadeflaum',),
'skamlippa': ('skamlippe',),
'skamlippe': ('skamlippe',),
'skamlippen': ('skamlippe',),
'skamlippene': ('skamlippe',),
'skamlipper': ('skamlippe',),
'skumsløkker': ('skumsløkker',),
'skumsløkkere': ('skumsløkker',),
'skumsløkkeren': ('skumsløkker',),
'skumsløkkerer': ('skumsløkker',),
'skumsløkkerne': ('skumsløkker',),
'slamavskiller': ('slamavskiller',),
'slamavskillere': ('slamavskiller',),
'slamavskilleren': ('slamavskiller',),
'slamavskillerer': ('slamavskiller',),
'slamavskillerne': ('slamavskiller',),
'sløkker': ('sløkker',),
'sløkkere': ('sløkker',),
'sløkkeren': ('sløkker',),
'sløkkerer': ('sløkker',),
'sløkkerne': ('sløkker',),
'sløkker': ('sløkker',),
'sløkkere': ('sløkker',),
'sløkkeren': ('sløkker',),
'sløkkerer': ('sløkker',),
'sløkkerne': ('sløkker',),
'smakslauk': ('smakslauk',),
'smakslauken': ('smakslauk',),
'smakslaukene': ('smakslauk',),
'smakslauker': ('smakslauk',),
'spanderbuksene': ('spanderbukser',),
'spanderbukser': ('spanderbukser',),
'stavn': ('stavn',),
'stavnen': ('stavn',),
'stavnene': ('stavn',),
'stavner': ('stavn',),
'stamn': ('stamn',),
'stamnen': ('stamn',),
'stamnene': ('stamn',),
'stamner': ('stamn',),
'stemnevitna': ('stemnevitne',),
'stemnevitne': ('stemnevitne',),
'stemnevitnene': ('stemnevitne',),
'stemnevitner': ('stemnevitne',),
'stemnevitnet': ('stemnevitne',),
'stevnevitna': ('stevnevitne',),
'stevnevitne': ('stevnevitne',),
'stevnevitnene': ('stevnevitne',),
'stevnevitner': ('stevnevitne',),
'stevnevitnet': ('stevnevitne',),
'stemning': ('stemning',),
'stemninga': ('stemning',),
'stemningen': ('stemning',),
'stemningene': ('stemning',),
'stemninger': ('stemning',),
'stemningsbilda': ('stemningsbilde',),
'stemningsbilde': ('stemningsbilde',),
'stemningsbildene': ('stemningsbilde',),
'stemningsbilder': ('stemningsbilde',),
'stemningsbildet': ('stemningsbilde',),
'stemningsbølga': ('stemningsbølge',),
'stemningsbølge': ('stemningsbølge',),
'stemningsbølgen': ('stemningsbølge',),
'stemningsbølgene': ('stemningsbølge',),
'stemningsbølger': ('stemningsbølge',),
'stemningsbølgja': ('stemningsbølgje',),
'stemningsbølgje': ('stemningsbølgje',),
'stemningsbølgjen': ('stemningsbølgje',),
'stemningsbølgjene': ('stemningsbølgje',),
'stemningsbølgjer': ('stemningsbølgje',),
'stemningsmenneska': ('stemningsmenneske',),
'stemningsmenneske': ('stemningsmenneske',),
'stemningsmenneskene': ('stemningsmenneske',),
'stemningsmennesker': ('stemningsmenneske',),
'stemningsmennesket': ('stemningsmenneske',),
'stemningsutbrott': ('stemningsutbrott',),
'stemningsutbrotta': ('stemningsutbrott',),
'stemningsutbrottene': ('stemningsutbrott',),
'stemningsutbrottet': ('stemningsutbrott',),
'stemningsutbrudd': ('stemningsutbrudd',),
'stemningsutbrudda': ('stemningsutbrudd',),
'stemningsutbruddene': ('stemningsutbrudd',),
'stemningsutbruddet': ('stemningsutbrudd',),
'stemor': ('stemor',),
'stemora': ('stemor',),
'stemoren': ('stemor',),
'stemødre': ('stemor',),
'stemødrene': ('stemor',),
'stemødrer': ('stemor',),
'stemorsblomst': ('stemorsblomst',),
'stemorsblomsten': ('stemorsblomst',),
'stemorsblomstene': ('stemorsblomst',),
'stemorsblomster': ('stemorsblomst',),
'stempel': ('stempel',),
'stempelet': ('stempel',),
'stempla': ('stempel',),
'stemplene': ('stempel',),
'stempler': ('stempel',),
'stemplet': ('stempel',),
'stempelavgift': ('stempelavgift',),
'stempelavgifta': ('stempelavgift',),
'stempelavgiften': ('stempelavgift',),
'stempelavgiftene': ('stempelavgift',),
'stempelavgifter': ('stempelavgift',),
'stempelmerka': ('stempelmerke',),
'stempelmerke': ('stempelmerke',),
'stempelmerkene': ('stempelmerke',),
'stempelmerker': ('stempelmerke',),
'stempelmerket': ('stempelmerke',),
'stempelputa': ('stempelpute',),
'stempelpute': ('stempelpute',),
'stempelputen': ('stempelpute',),
'stempelputene': ('stempelpute',),
'stempelputer': ('stempelpute',),
'stempelskatt': ('stempelskatt',),
'stempelskatten': ('stempelskatt',),
'stempelskattene': ('stempelskatt',),
'stempelskatter': ('stempelskatt',),
'stempelslag': ('stempelslag',),
'stempelslaga': ('stempelslag',),
'stempelslagene': ('stempelslag',),
'stempelslaget': ('stempelslag',),
'stemplingsur': ('stemplingsur',),
'stemplingsura': ('stemplingsur',),
'stemplingsurene': ('stemplingsur',),
'stemplingsuret': ('stemplingsur',),
'stender': ('stender',),
'stendere': ('stender',),
'stenderen': ('stender',),
'stenderer': ('stender',),
'stenderne': ('stender',),
'stenderforsamling': ('stenderforsamling',),
'stenderforsamlinga': ('stenderforsamling',),
'stenderforsamlingen': ('stenderforsamling',),
'stenderforsamlingene': ('stenderforsamling',),
'stenderforsamlinger': ('stenderforsamling',),
'stenderverk': ('stenderverk',),
'stenderverka': ('stenderverk',),
'stenderverkene': ('stenderverk',),
'stenderverker': ('stenderverk',),
'stenderverket': ('stenderverk',),
'steng': ('steng',),
'stenga': ('steng',),
'stengene': ('steng',),
'stenget': ('steng',),
'stenga': ('stenge',),
'stenge': ('stenge',),
'stengene': ('stenge',),
'stenger': ('stenge',),
'stenget': ('stenge',),
'stengel': ('stengel',),
'stengelen': ('stengel',),
'stenglene': ('stengel',),
'stengler': ('stengel',),
'stengelknoll': ('stengelknoll',),
'stengelknollen': ('stengelknoll',),
'stengelknollene': ('stengelknoll',),
'stengelknoller': ('stengelknoll',),
'stengetid': ('stengetid',),
'stengetida': ('stengetid',),
'stengetiden': ('stengetid',),
'stengetidene': ('stengetid',),
'stengetider': ('stengetid',),
'stengsel': ('stengsel',),
'stengselet': ('stengsel',),
'stengsla': ('stengsel',),
'stengslene': ('stengsel',),
'stengsler': ('stengsel',),
'stengslet': ('stengsel',),
'stengsla': ('stengsle',),
'stengsle': ('stengsle',),
'stengslen': ('stengsle',),
'stengslene': ('stengsle',),
'stengsler': ('stengsle',),
'stengun': ('stengun',),
'stengunen': ('stengun',),
'stengunene': ('stengun',),
'stenguner': ('stengun',),
'stenk': ('stenk',),
'stenka': ('stenk',),
'stenkene': ('stenk',),
'stenket': ('stenk',),
'stenograf': ('stenograf',),
'stenografen': ('stenograf',),
'stenografene': ('stenograf',),
'stenografer': ('stenograf',),
'stenografi': ('stenografi',),
'stenografien': ('stenografi',),
'stenografiene': ('stenografi',),
'stenografier': ('stenografi',),
'stenogram': ('stenogram',),
'stenogramma': ('stenogram',),
'stenogrammene': ('stenogram',),
'stenogrammer': ('stenogram',),
'stenogrammet': ('stenogram',),
'stenotypi': ('stenotypi',),
'stenotypien': ('stenotypi',),
'stenotypiene': ('stenotypi',),
'stenotypier': ('stenotypi',),
'stensil': ('stensil',),
'stensilen': ('stensil',),
'stensilene': ('stensil',),
'stensiler': ('stensil',),
'stensileringsmaskin': ('stensileringsmaskin',),
'stensileringsmaskina': ('stensileringsmaskin',),
'stensileringsmaskinen': ('stensileringsmaskin',),
'stensileringsmaskinene': ('stensileringsmaskin',),
'stensileringsmaskiner': ('stensileringsmaskin',),
'stensilmaskin': ('stensilmaskin',),
'stensilmaskina': ('stensilmaskin',),
'stensilmaskinen': ('stensilmaskin',),
'stensilmaskinene': ('stensilmaskin',),
'stensilmaskiner': ('stensilmaskin',),
'stensileringspapir': ('stensileringspapir',),
'stensileringspapira': ('stensileringspapir',),
'stensileringspapirene': ('stensileringspapir',),
'stensileringspapirer': ('stensileringspapir',),
'stensileringspapiret': ('stensileringspapir',),
'stensilpapir': ('stensilpapir',),
'stensilpapira': ('stensilpapir',),
'stensilpapirene': ('stensilpapir',),
'stensilpapirer': ('stensilpapir',),
'stensilpapiret': ('stensilpapir',),
'stentorstemme': ('stentorstemme',),
'stentorstemmen': ('stentorstemme',),
'stentorstemmene': ('stentorstemme',),
'stentorstemmer': ('stentorstemme',),
'steppe': ('steppe',),
'steppen': ('steppe',),
'steppene': ('steppe',),
'stepper': ('steppe',),
'steppedans': ('steppedans',),
'steppedansen': ('steppedans',),
'steppedansene': ('steppedans',),
'steppedanser': ('steppedans',),
'steppedanser': ('steppedanser',),
'steppedansere': ('steppedanser',),
'steppedanseren': ('steppedanser',),
'steppedanserer': ('steppedanser',),
'steppedanserne': ('steppedanser',),
'steppeland': ('steppeland',),
'steppelanda': ('steppeland',),
'steppelandene': ('steppeland',),
'steppelandet': ('steppeland',),
'stepper': ('stepper',),
'steppere': ('stepper',),
'stepperen': ('stepper',),
'stepperer': ('stepper',),
'stepperne': ('stepper',),
'stereo': ('stereo',),
'stereoen': ('stereo',),
'stereoene': ('stereo',),
'stereoer': ('stereo',),
'stereoanlegg': ('stereoanlegg',),
'stereoanlegga': ('stereoanlegg',),
'stereoanleggene': ('stereoanlegg',),
'stereoanlegget': ('stereoanlegg',),
'stereofoni': ('stereofoni',),
'stereofonien': ('stereofoni',),
'stereofoniene': ('stereofoni',),
'stereofonier': ('stereofoni',),
'stereografi': ('stereografi',),
'stereografien': ('stereografi',),
'stereografiene': ('stereografi',),
'stereografier': ('stereografi',),
'stereometri': ('stereometri',),
'stereometrien': ('stereometri',),
'stereometriene': ('stereometri',),
'stereometrier': ('stereometri',),
'stereosending': ('stereosending',),
'stereosendinga': ('stereosending',),
'stereosendingen': ('stereosending',),
'stereosendingene': ('stereosending',),
'stereosendinger': ('stereosending',),
'stereoskop': ('stereoskop',),
'stereoskopa': ('stereoskop',),
'stereoskopene': ('stereoskop',),
'stereoskoper': ('stereoskop',),
'stereoskopet': ('stereoskop',),
'stereotyp': ('stereotyp',),
'stereotypen': ('stereotyp',),
'stereotypene': ('stereotyp',),
'stereotyper': ('stereotyp',),
'stereotypi': ('stereotypi',),
'stereotypien': ('stereotypi',),
'stereotypiene': ('stereotypi',),
'stereotypier': ('stereotypi',),
'stereotypør': ('stereotypør',),
'stereotypøren': ('stereotypør',),
'stereotypørene': ('stereotypør',),
'stereotypører': ('stereotypør',),
'sterilisasjon': ('sterilisasjon',),
'sterilisasjonen': ('sterilisasjon',),
'sterilisasjonene': ('sterilisasjon',),
'sterilisasjoner': ('sterilisasjon',),
'sterilitet': ('sterilitet',),
'steriliteten': ('sterilitet',),
'sterilitetene': ('sterilitet',),
'steriliteter': ('sterilitet',),
'sterkstrøm': ('sterkstrøm',),
'sterkstrømmen': ('sterkstrøm',),
'sterkstrømmene': ('sterkstrøm',),
'sterkstrømmer': ('sterkstrøm',),
'sterkstrømsingeniør': ('sterkstrømsingeniør',),
'sterkstrømsingeniøren': ('sterkstrømsingeniør',),
'sterkstrømsingeniørene': ('sterkstrømsingeniør',),
'sterkstrømsingeniører': ('sterkstrømsingeniør',),
'sterkt': ('sterkt',),
'sterkvin': ('sterkvin',),
'sterkvinen': ('sterkvin',),
'sterkvinene': ('sterkvin',),
'sterkviner': ('sterkvin',),
'sterling': ('sterling',),
'sterlingen': ('sterling',),
'sterlingene': ('sterling',),
'sterlinger': ('sterling',),
'sterlingsølv': ('sterlingsølv',),
'sterlingsølva': ('sterlingsølv',),
'sterlingsølvene': ('sterlingsølv',),
'sterlingsølvet': ('sterlingsølv',),
'steroid': ('steroid',),
'steroida': ('steroid',),
'steroidene': ('steroid',),
'steroider': ('steroid',),
'steroidet': ('steroid',),
'sterol': ('sterol',),
'sterolen': ('sterol',),
'sterolene': ('sterol',),
'steroler': ('sterol',),
'stesønn': ('stesønn',),
'stesønnen': ('stesønn',),
'stesønnene': ('stesønn',),
'stesønner': ('stesønn',),
'stetoskop': ('stetoskop',),
'stetoskopa': ('stetoskop',),
'stetoskopene': ('stetoskop',),
'stetoskoper': ('stetoskop',),
'stetoskopet': ('stetoskop',),
'stett': ('stett',),
'stetten': ('stett',),
'stettene': ('stett',),
'stetter': ('stett',),
'stev': ('stev',),
'steva': ('stev',),
'stevene': ('stev',),
'stevet': ('stev',),
'stevkamp': ('stevkamp',),
'stevkampen': ('stevkamp',),
'stevkampene': ('stevkamp',),
'stevkamper': ('stevkamp',),
'stevleik': ('stevleik',),
'stevleiken': ('stevleik',),
'stevleikene': ('stevleik',),
'stevleiker': ('stevleik',),
'stevn': ('stevn',),
'stevnen': ('stevn',),
'stevnene': ('stevn',),
'stevner': ('stevn',),
'stevnevitna': ('stevnevitne',),
'stevnevitne': ('stevnevitne',),
'stevnevitnene': ('stevnevitne',),
'stevnevitner': ('stevnevitne',),
'stevnevitnet': ('stevnevitne',),
'stemnevitna': ('stemnevitne',),
'stemnevitne': ('stemnevitne',),
'stemnevitnene': ('stemnevitne',),
'stemnevitner': ('stemnevitne',),
'stemnevitnet': ('stemnevitne',),
'stevning': ('stevning',),
'stevninga': ('stevning',),
'stevningen': ('stevning',),
'stevningene': ('stevning',),
'stevninger': ('stevning',),
'stemning': ('stemning',),
'stemninga': ('stemning',),
'stemningen': ('stemning',),
'stemningene': ('stemning',),
'stemninger': ('stemning',),
'steward': ('steward',),
'stewarden': ('steward',),
'stewardene': ('steward',),
'stewarder': ('steward',),
'stewardess': ('stewardess',),
'stewardessa': ('stewardess',),
'stewardessen': ('stewardess',),
'stewardessene': ('stewardess',),
'stewardesser': ('stewardess',),
'sti': ('sti',),
'stien': ('sti',),
'stiene': ('sti',),
'stier': ('sti',),
'sti': ('sti',),
'stien': ('sti',),
'stiene': ('sti',),
'stier': ('sti',),
'sti': ('sti',),
'stia': ('sti',),
'stiene': ('sti',),
'stiet': ('sti',),
'stifinner': ('stifinner',),
'stifinnere': ('stifinner',),
'stifinneren': ('stifinner',),
'stifinnerer': ('stifinner',),
'stifinnerne': ('stifinner',),
'stift': ('stift',),
'stiften': ('stift',),
'stiftene': ('stift',),
'stifter': ('stift',),
'stift': ('stift',),
'stifta': ('stift',),
'stiftene': ('stift',),
'stiftet': ('stift',),
'stiftamtmann': ('stiftamtmann',),
'stiftamtmannen': ('stiftamtmann',),
'stiftamtmenn': ('stiftamtmann',),
'stiftamtmennene': ('stiftamtmann',),
'stiftelse': ('stiftelse',),
'stiftelsen': ('stiftelse',),
'stiftelsene': ('stiftelse',),
'stiftelser': ('stiftelse',),
'stiftelsesdag': ('stiftelsesdag',),
'stiftelsesdagen': ('stiftelsesdag',),
'stiftelsesdagene': ('stiftelsesdag',),
'stiftelsesdager': ('stiftelsesdag',),
'stiftemaskin': ('stiftemaskin',),
'stiftemaskina': ('stiftemaskin',),
'stiftemaskinen': ('stiftemaskin',),
'stiftemaskinene': ('stiftemaskin',),
'stiftemaskiner': ('stiftemaskin',),
'stifter': ('stifter',),
'stiftere': ('stifter',),
'stifteren': ('stifter',),
'stifterer': ('stifter',),
'stifterne': ('stifter',),
'stiftsdireksjon': ('stiftsdireksjon',),
'stiftsdireksjonen': ('stiftsdireksjon',),
'stiftsdireksjonene': ('stiftsdireksjon',),
'stiftsdireksjoner': ('stiftsdireksjon',),
'stiftsgard': ('stiftsgard',),
'stiftsgarden': ('stiftsgard',),
'stiftsgardene': ('stiftsgard',),
'stiftsgarder': ('stiftsgard',),
'stiftskapellan': ('stiftskapellan',),
'stiftskapellanen': ('stiftskapellan',),
'stiftskapellanene': ('stiftskapellan',),
'stiftskapellaner': ('stiftskapellan',),
'stigbrett': ('stigbrett',),
'stigbretta': ('stigbrett',),
'stigbrettene': ('stigbrett',),
'stigbretter': ('stigbrett',),
'stigbrettet': ('stigbrett',),
'stigbøyle': ('stigbøyle',),
'stigbøylen': ('stigbøyle',),
'stigbøylene': ('stigbøyle',),
'stigbøyler': ('stigbøyle',),
'stige': ('stige',),
'stigen': ('stige',),
'stigene': ('stige',),
'stiger': ('stige',),
'stigebil': ('stigebil',),
'stigebilen': ('stigebil',),
'stigebilene': ('stigebil',),
'stigebiler': ('stigebil',),
'stigeledning': ('stigeledning',),
'stigeledninga': ('stigeledning',),
'stigeledningen': ('stigeledning',),
'stigeledningene': ('stigeledning',),
'stigeledninger': ('stigeledning',),
'stiger': ('stiger',),
'stigere': ('stiger',),
'stigeren': ('stiger',),
'stigerer': ('stiger',),
'stigerne': ('stiger',),
'stigerør': ('stigerør',),
'stigerøra': ('stigerør',),
'stigerørene': ('stigerør',),
'stigerøret': ('stigerør',),
'stigma': ('stigma',),
'stigmaene': ('stigma',),
'stigmaer': ('stigma',),
'stigmaet': ('stigma',),
'stigma': ('stigme',),
'stigme': ('stigme',),
'stigmene': ('stigme',),
'stigmer': ('stigme',),
'stigmet': ('stigme',),
'stigmatisasjon': ('stigmatisasjon',),
'stigmatisasjonen': ('stigmatisasjon',),
'stigmatisasjonene': ('stigmatisasjon',),
'stigmatisasjoner': ('stigmatisasjon',),
'stigmatisering': ('stigmatisering',),
'stigmatiseringa': ('stigmatisering',),
'stigmatiseringen': ('stigmatisering',),
'stigmatiseringene': ('stigmatisering',),
'stigmatiseringer': ('stigmatisering',),
'stigning': ('stigning',),
'stigninga': ('stigning',),
'stigningen': ('stigning',),
'stigningene': ('stigning',),
'stigninger': ('stigning',),
'stigningstakt': ('stigningstakt',),
'stigningstakta': ('stigningstakt',),
'stigningstakten': ('stigningstakt',),
'stigningstaktene': ('stigningstakt',),
'stigningstakter': ('stigningstakt',),
'stigtrinn': ('stigtrinn',),
'stigtrinna': ('stigtrinn',),
'stigtrinnene': ('stigtrinn',),
'stigtrinnet': ('stigtrinn',),
'stikk': ('stikk',),
'stikka': ('stikk',),
'stikkene': ('stikk',),
'stikket': ('stikk',),
'stikkball': ('stikkball',),
'stikkballen': ('stikkball',),
'stikkballene': ('stikkball',),
'stikkballer': ('stikkball',),
'stikka': ('stikke',),
'stikke': ('stikke',),
'stikken': ('stikke',),
'stikkene': ('stikke',),
'stikker': ('stikke',),
'stikkekvefs': ('stikkekvefs',),
'stikkekvefsen': ('stikkekvefs',),
'stikkekvefsene': ('stikkekvefs',),
'stikkekvefser': ('stikkekvefs',),
'stikkelsbær': ('stikkelsbær',),
'stikkelsbæra': ('stikkelsbær',),
'stikkelsbærene': ('stikkelsbær',),
'stikkelsbæret': ('stikkelsbær',),
'stikkelsbærbusk': ('stikkelsbærbusk',),
'stikkelsbærbusken': ('stikkelsbærbusk',),
'stikkelsbærbuskene': ('stikkelsbærbusk',),
'stikkelsbærbusker': ('stikkelsbærbusk',),
'stikken': ('stikken',),
'stikker': ('stikker',),
'stikkere': ('stikker',),
'stikkeren': ('stikker',),
'stikkerer': ('stikker',),
'stikkerne': ('stikker',),
'stikkeveps': ('stikkeveps',),
'stikkevepsen': ('stikkeveps',),
'stikkevepsene': ('stikkeveps',),
'stikkevepser': ('stikkeveps',),
'stikkflamme': ('stikkflamme',),
'stikkflammen': ('stikkflamme',),
'stikkflammene': ('stikkflamme',),
'stikkflammer': ('stikkflamme',),
'stikkflua': ('stikkflue',),
'stikkflue': ('stikkflue',),
'stikkfluen': ('stikkflue',),
'stikkfluene': ('stikkflue',),
'stikkfluer': ('stikkflue',),
'stikkhevert': ('stikkhevert',),
'stikkheverten': ('stikkhevert',),
'stikkhevertene': ('stikkhevert',),
'stikkheverter': ('stikkhevert',),
'stikk-kontakt': ('stikk-kontakt',),
'stikk-kontakten': ('stikk-kontakt',),
'stikk-kontaktene': ('stikk-kontakt',),
'stikk-kontakter': ('stikk-kontakt',),
'stikkontakt': ('stikkontakt',),
'stikkontakten': ('stikkontakt',),
'stikkontaktene': ('stikkontakt',),
'stikkontakter': ('stikkontakt',),
'stikkledning': ('stikkledning',),
'stikkledninga': ('stikkledning',),
'stikkledningen': ('stikkledning',),
'stikkledningene': ('stikkledning',),
'stikkledninger': ('stikkledning',),
'stikklomma': ('stikklomme',),
'stikklomme': ('stikklomme',),
'stikklommen': ('stikklomme',),
'stikklommene': ('stikklomme',),
'stikklommer': ('stikklomme',),
'stikkord': ('stikkord',),
'stikkorda': ('stikkord',),
'stikkordene': ('stikkord',),
'stikkordet': ('stikkord',),
'stikkordregister': ('stikkordregister',),
'stikkordregisteret': ('stikkordregister',),
'stikkordregistra': ('stikkordregister',),
'stikkordregistre': ('stikkordregister',),
'stikkordregistrene': ('stikkordregister',),
'stikkordregistret': ('stikkordregister',),
'stikkpilla': ('stikkpille',),
'stikkpille': ('stikkpille',),
'stikkpillen': ('stikkpille',),
'stikkpillene': ('stikkpille',),
'stikkpiller': ('stikkpille',),
'stikkprøva': ('stikkprøve',),
'stikkprøve': ('stikkprøve',),
'stikkprøven': ('stikkprøve',),
'stikkprøvene': ('stikkprøve',),
'stikkprøver': ('stikkprøve',),
'stikkrenna': ('stikkrenne',),
'stikkrenne': ('stikkrenne',),
'stikkrennen': ('stikkrenne',),
'stikkrennene': ('stikkrenne',),
'stikkrenner': ('stikkrenne',),
'stikksag': ('stikksag',),
'stikksaga': ('stikksag',),
'stikksagen': ('stikksag',),
'stikksagene': ('stikksag',),
'stikksager': ('stikksag',),
'stikkveg': ('stikkveg',),
'stikkvegen': ('stikkveg',),
'stikkvegene': ('stikkveg',),
'stikkveger': ('stikkveg',),
'stikkvei': ('stikkvei',),
'stikkveien': ('stikkvei',),
'stikkveiene': ('stikkvei',),
'stikkveier': ('stikkvei',),
'stikkvåpen': ('stikkvåpen',),
'stikkvåpenet': ('stikkvåpen',),
'stikkvåpna': ('stikkvåpen',),
'stikkvåpnene': ('stikkvåpen',),
'stikling': ('stikling',),
'stiklingen': ('stikling',),
'stiklingene': ('stikling',),
'stiklinger': ('stikling',),
'stikning': ('stikning',),
'stikninga': ('stikning',),
'stikningen': ('stikning',),
'stikningene': ('stikning',),
'stikninger': ('stikning',),
'stil': ('stil',),
'stilen': ('stil',),
'stilene': ('stil',),
'stiler': ('stil',),
'stilart': ('stilart',),
'stilarta': ('stilart',),
'stilarten': ('stilart',),
'stilartene': ('stilart',),
'stilarter': ('stilart',),
'stilbedømmelse': ('stilbedømmelse',),
'stilbedømmelsen': ('stilbedømmelse',),
'stilbedømmelsene': ('stilbedømmelse',),
'stilbedømmelser': ('stilbedømmelse',),
'stilblanding': ('stilblanding',),
'stilblandinga': ('stilblanding',),
'stilblandingen': ('stilblanding',),
'stilblandingene': ('stilblanding',),
'stilblandinger': ('stilblanding',),
'stilbok': ('stilbok',),
'stilboka': ('stilbok',),
'stilboken': ('stilbok',),
'stilbøkene': ('stilbok',),
'stilbøker': ('stilbok',),
'stilebok': ('stilebok',),
'stileboka': ('stilebok',),
'stileboken': ('stilebok',),
'stilebøkene': ('stilebok',),
'stilebøker': ('stilebok',),
'stilbrott': ('stilbrott',),
'stilbrotta': ('stilbrott',),
'stilbrottene': ('stilbrott',),
'stilbrottet': ('stilbrott',),
'stilbrudd': ('stilbrudd',),
'stilbrudda': ('stilbrudd',),
'stilbruddene': ('stilbrudd',),
'stilbruddet': ('stilbrudd',),
'stilett': ('stilett',),
'stiletten': ('stilett',),
'stilettene': ('stilett',),
'stiletter': ('stilett',),
'stiletthæl': ('stiletthæl',),
'stiletthælen': ('stiletthæl',),
'stiletthælene': ('stiletthæl',),
'stiletthæler': ('stiletthæl',),
'stilhopper': ('stilhopper',),
'stilhoppere': ('stilhopper',),
'stilhopperen': ('stilhopper',),
'stilhopperer': ('stilhopper',),
'stilhopperne': ('stilhopper',),
'stilist': ('stilist',),
'stilisten': ('stilist',),
'stilistene': ('stilist',),
'stilister': ('stilist',),
'stilistikk': ('stilistikk',),
'stilistikken': ('stilistikk',),
'stilistikkene': ('stilistikk',),
'stilistikker': ('stilistikk',),
'stilk': ('stilk',),
'stilken': ('stilk',),
'stilkene': ('stilk',),
'stilker': ('stilk',),
'stilkarakter': ('stilkarakter',),
'stilkarakteren': ('stilkarakter',),
'stilkarakterene': ('stilkarakter',),
'stilkarakterer': ('stilkarakter',),
'stilkselleri': ('stilkselleri',),
'stilksellerien': ('stilkselleri',),
'stilkselleriene': ('stilkselleri',),
'stilksellerier': ('stilkselleri',),
'stilkunstner': ('stilkunstner',),
'stilkunstnere': ('stilkunstner',),
'stilkunstneren': ('stilkunstner',),
'stilkunstnerer': ('stilkunstner',),
'stilkunstnerne': ('stilkunstner',),
'still': ('still',),
'stillet': ('still',),
'stills': ('still',),
'stillsa': ('still',),
'stillsene': ('still',),
'stillas': ('stillas',),
'stillasa': ('stillas',),
'stillasene': ('stillas',),
'stillaser': ('stillas',),
'stillaset': ('stillas',),
'stillbilda': ('stillbilde',),
'stillbilde': ('stillbilde',),
'stillbildene': ('stillbilde',),
'stillbilder': ('stillbilde',),
'stillbildet': ('stillbilde',),
'stilla': ('stille',),
'stille': ('stille',),
'stillen': ('stille',),
'stillene': ('stille',),
'stiller': ('stille',),
'stilleben': ('stilleben',),
'stillebena': ('stilleben',),
'stillebenene': ('stilleben',),
'stillebener': ('stilleben',),
'stillebenet': ('stilleben',),
'stillehavsøy': ('stillehavsøy',),
'stillehavsøya': ('stillehavsøy',),
'stillehavsøyen': ('stillehavsøy',),
'stillehavsøyene': ('stillehavsøy',),
'stillehavsøyer': ('stillehavsøy',),
'stillelesning': ('stillelesning',),
'stillelesninga': ('stillelesning',),
'stillelesningen': ('stillelesning',),
'stillelesningene': ('stillelesning',),
'stillelesninger': ('stillelesning',),
'stiller': ('stiller',),
'stillere': ('stiller',),
'stilleren': ('stiller',),
'stillerer': ('stiller',),
'stillerne': ('stiller',),
'stilleskrue': ('stilleskrue',),
'stilleskruen': ('stilleskrue',),
'stilleskruene': ('stilleskrue',),
'stilleskruer': ('stilleskrue',),
'stilleskruve': ('stilleskruve',),
'stilleskruven': ('stilleskruve',),
'stilleskruvene': ('stilleskruve',),
'stilleskruver': ('stilleskruve',),
'stillfoto': ('stillfoto',),
'stillfotoa': ('stillfoto',),
'stillfotoene': ('stillfoto',),
'stillfotoer': ('stillfoto',),
'stillfotoet': ('stillfoto',),
'stillhet': ('stillhet',),
'stillheta': ('stillhet',),
'stillheten': ('stillhet',),
'stillhetene': ('stillhet',),
'stillheter': ('stillhet',),
'stilling': ('stilling',),
'stillinga': ('stilling',),
'stillingen': ('stilling',),
'stillingene': ('stilling',),
'stillinger': ('stilling',),
'stillingsenergi': ('stillingsenergi',),
'stillingsenergien': ('stillingsenergi',),
'stillingsenergiene': ('stillingsenergi',),
'stillingsenergier': ('stillingsenergi',),
'stillingskrig': ('stillingskrig',),
'stillingskrigen': ('stillingskrig',),
'stillingskrigene': ('stillingskrig',),
'stillingskriger': ('stillingskrig',),
'stillingsstopp': ('stillingsstopp',),
'stillingsstoppa': ('stillingsstopp',),
'stillingsstoppen': ('stillingsstopp',),
'stillingsstoppene': ('stillingsstopp',),
'stillingsstoppet': ('stillingsstopp',),
'stillingtagen': ('stillingtagen',),
'stillingtaken': ('stillingtaken',),
'stillingtaing': ('stillingtaing',),
'stillingtainga': ('stillingtaing',),
'stillingtaingen': ('stillingtaing',),
'stillingtaingene': ('stillingtaing',),
'stillingtainger': ('stillingtaing',),
'stillingtaking': ('stillingtaking',),
'stillingtakinga': ('stillingtaking',),
'stillingtakingen': ('stillingtaking',),
'stillingtakingene': ('stillingtaking',),
'stillingtakinger': ('stillingtaking',),
'stilliss': ('stilliss',),
'stillissen': ('stilliss',),
'stillissene': ('stilliss',),
'stillisser': ('stilliss',),
'stillongs': ('stillongs',),
'stillongsen': ('stillongs',),
'stillongsene': ('stillongs',),
'stillskrue': ('stillskrue',),
'stillskruen': ('stillskrue',),
'stillskruene': ('stillskrue',),
'stillskruer': ('stillskrue',),
'stillskruve': ('stillskruve',),
'stillskruven': ('stillskruve',),
'stillskruvene': ('stillskruve',),
'stillskruver': ('stillskruve',),
'stillstand': ('stillstand',),
'stillstanden': ('stillstand',),
'stillstandene': ('stillstand',),
'stillstander': ('stillstand',),
'stikkekvefs': ('stikkekvefs',),
'stikkekvefsen': ('stikkekvefs',),
'stikkekvefsene': ('stikkekvefs',),
'stikkekvefser': ('stikkekvefs',),
'stipendia': ('stipendium',),
'stipendiene': ('stipendium',),
'stipendier': ('stipendium',),
'stipendiet': ('stipendium',),
'stipendium': ('stipendium',),
'stipend': ('stipend',),
'stipenda': ('stipend',),
'stipendene': ('stipend',),
'stipender': ('stipend',),
'stipendet': ('stipend',),
'storhending': ('storhending',),
'storhendinga': ('storhending',),
'storhendingen': ('storhending',),
'storhendingene': ('storhending',),
'storhendinger': ('storhending',),
'storhertug': ('storhertug',),
'storhertugen': ('storhertug',),
'storhertugene': ('storhertug',),
'storhertuger': ('storhertug',),
'storhet': ('storhet',),
'storheta': ('storhet',),
'storheten': ('storhet',),
'storhetene': ('storhet',),
'storheter': ('storhet',),
'storhetstid': ('storhetstid',),
'storhetstida': ('storhetstid',),
'storhetstiden': ('storhetstid',),
'storhetstidene': ('storhetstid',),
'storhetstider': ('storhetstid',),
'storhjerne': ('storhjerne',),
'storhjernen': ('storhjerne',),
'storhjernene': ('storhjerne',),
'storhjerner': ('storhjerne',),
'storing': ('storing',),
'storingen': ('storing',),
'storingene': ('storing',),
'storinger': ('storing',),
'stork': ('stork',),
'storken': ('stork',),
'storkene': ('stork',),
'storker': ('stork',),
'storkar': ('storkar',),
'storkaren': ('storkar',),
'storkarene': ('storkar',),
'storkarer': ('storkar',),
'storkenebb': ('storkenebb',),
'storkenebba': ('storkenebb',),
'storkenebben': ('storkenebb',),
'storkenebbene': ('storkenebb',),
'storkenebbet': ('storkenebb',),
'storkenebb': ('storkenebb',),
'storkenebba': ('storkenebb',),
'storkenebbene': ('storkenebb',),
'storkenebbet': ('storkenebb',),
'storkjøkken': ('storkjøkken',),
'storkjøkkena': ('storkjøkken',),
'storkjøkkenene': ('storkjøkken',),
'storkjøkkener': ('storkjøkken',),
'storkjøkkenet': ('storkjøkken',),
'storkobbe': ('storkobbe',),
'storkobben': ('storkobbe',),
'storkobbene': ('storkobbe',),
'storkobber': ('storkobbe',),
'storkommune': ('storkommune',),
'storkommunen': ('storkommune',),
'storkommunene': ('storkommune',),
'storkommuner': ('storkommune',),
'storkonvall': ('storkonvall',),
'storkonvallen': ('storkonvall',),
'storkonvallene': ('storkonvall',),
'storkonvaller': ('storkonvall',),
'storkors': ('storkors',),
'storkorsa': ('storkors',),
'storkorsene': ('storkors',),
'storkorset': ('storkors',),
'storlom': ('storlom',),
'storlommen': ('storlom',),
'storlommene': ('storlom',),
'storlommer': ('storlom',),
'storm': ('storm',),
'stormen': ('storm',),
'stormene': ('storm',),
'stormer': ('storm',),
'stormakt': ('stormakt',),
'stormakta': ('stormakt',),
'stormakten': ('stormakt',),
'stormaktene': ('stormakt',),
'stormakter': ('stormakt',),
'stormangrep': ('stormangrep',),
'stormangrepa': ('stormangrep',),
'stormangrepene': ('stormangrep',),
'stormangrepet': ('stormangrep',),
'stormann': ('stormann',),
'stormannen': ('stormann',),
'stormenn': ('stormann',),
'stormennene': ('stormann',),
'stormannsgalskap': ('stormannsgalskap',),
'stormannsgalskapen': ('stormannsgalskap',),
'stormannsgalskapene': ('stormannsgalskap',),
'stormannsgalskaper': ('stormannsgalskap',),
'stormast': ('stormast',),
'stormasta': ('stormast',),
'stormasten': ('stormast',),
'stormastene': ('stormast',),
'stormaster': ('stormast',),
'stormester': ('stormester',),
'stormestere': ('stormester',),
'stormesteren': ('stormester',),
'stormesterer': ('stormester',),
'stormesterne': ('stormester',),
'stormestre': ('stormester',),
'stormestrene': ('stormester',),
'stormestrer': ('stormester',),
'stormflo': ('stormflo',),
'stormfloa': ('stormflo',),
'stormfloen': ('stormflo',),
'stormfloene': ('stormflo',),
'stormfloer': ('stormflo',),
'stormfugl': ('stormfugl',),
'stormfuglen': ('stormfugl',),
'stormfuglene': ('stormfugl',),
'stormfugler': ('stormfugl',),
'stormkast': ('stormkast',),
'stormkasta': ('stormkast',),
'stormkastene': ('stormkast',),
'stormkastet': ('stormkast',),
'stormkrok': ('stormkrok',),
'stormkroken': ('stormkrok',),
'stormkrokene': ('stormkrok',),
'stormkroker': ('stormkrok',),
'stormkur': ('stormkur',),
'stormkuren': ('stormkur',),
'stormkurene': ('stormkur',),
'stormkurer': ('stormkur',),
'stormløp': ('stormløp',),
'stormløpa': ('stormløp',),
'stormløpene': ('stormløp',),
'stormløpet': ('stormløp',),
'stormogul': ('stormogul',),
'stormogulen': ('stormogul',),
'stormogulene': ('stormogul',),
'stormoguler': ('stormogul',),
'stormsentra': ('stormsentrum',),
'stormsentraene': ('stormsentrum',),
'stormsentre': ('stormsentrum',),
'stormsentrene': ('stormsentrum',),
'stormsentret': ('stormsentrum',),
'stormsentrum': ('stormsentrum',),
'stormsentrumet': ('stormsentrum',),
'stormskritt': ('stormskritt',),
'stormskritta': ('stormskritt',),
'stormskrittene': ('stormskritt',),
'stormskrittet': ('stormskritt',),
'stormsvala': ('stormsvale',),
'stormsvale': ('stormsvale',),
'stormsvalen': ('stormsvale',),
'stormsvalene': ('stormsvale',),
'stormsvaler': ('stormsvale',),
'stormtropp': ('stormtropp',),
'stormtroppen': ('stormtropp',),
'stormtroppene': ('stormtropp',),
'stormtropper': ('stormtropp',),
'stormvarsel': ('stormvarsel',),
'stormvarselet': ('stormvarsel',),
'stormvarsla': ('stormvarsel',),
'stormvarslene': ('stormvarsel',),
'stormvarsler': ('stormvarsel',),
'stormvarslet': ('stormvarsel',),
'stormvind': ('stormvind',),
'stormvinden': ('stormvind',),
'stormvindene': ('stormvind',),
'stormvinder': ('stormvind',),
'stålrørsmøblene': ('stålrørsmøbler',),
'stålrørsmøbler': ('stålrørsmøbler',),
'succès': ('succès',),
'succèsen': ('succès',),
'succèsene': ('succès',),
'succèser': ('succès',),
'svibellauk': ('svibellauk',),
'svibellauken': ('svibellauk',),
'svibellaukene': ('svibellauk',),
'svibellauker': ('svibellauk',),
'sæter': ('sæter',),
'sæteren': ('sæter',),
'sætra': ('sæter',),
'sætre': ('sæter',),
'sætrene': ('sæter',),
'sætrer': ('sæter',),
'taklauk': ('taklauk',),
'taklauken': ('taklauk',),
'taklaukene': ('taklauk',),
'taklauker': ('taklauk',),
'taklauk': ('taklauk',),
'taklauken': ('taklauk',),
'taklaukene': ('taklauk',),
'taklauker': ('taklauk',),
'taum': ('taum',),
'taumen': ('taum',),
'taumene': ('taum',),
'taumer': ('taum',),
'tidtager': ('tidtager',),
'tidtagere': ('tidtager',),
'tidtageren': ('tidtager',),
'tidtagerer': ('tidtager',),
'tidtagerne': ('tidtager',),
'tiroler': ('tiroler',),
'tirolere': ('tiroler',),
'tiroleren': ('tiroler',),
'tirolerer': ('tiroler',),
'tirolerne': ('tiroler',),
'taum': ('taum',),
'taumen': ('taum',),
'taumene': ('taum',),
'taumer': ('taum',),
'trekvefs': ('trekvefs',),
'trekvefsen': ('trekvefs',),
'trekvefsene': ('trekvefs',),
'trekvefser': ('trekvefs',),
'trekvefs': ('trekvefs',),
'trekvefsen': ('trekvefs',),
'trekvefsene': ('trekvefs',),
'trekvefser': ('trekvefs',),
'trick': ('trick',),
'tricka': ('trick',),
'trickene': ('trick',),
'tricket': ('trick',),
'tåreflaum': ('tåreflaum',),
'tåreflaumen': ('tåreflaum',),
'tåreflaumene': ('tåreflaum',),
'tåreflaumer': ('tåreflaum',),
'underlippa': ('underlippe',),
'underlippe': ('underlippe',),
'underlippen': ('underlippe',),
'underlippene': ('underlippe',),
'underlipper': ('underlippe',),
'vanerøker': ('vanerøker',),
'vanerøkere': ('vanerøker',),
'vanerøkeren': ('vanerøker',),
'vanerøkerer': ('vanerøker',),
'vanerøkerne': ('vanerøker',),
'vannflaum': ('vannflaum',),
'vannflaumen': ('vannflaum',),
'vannflaumene': ('vannflaum',),
'vannflaumer': ('vannflaum',),
'vassflaum': ('vassflaum',),
'vassflaumen': ('vassflaum',),
'vassflaumene': ('vassflaum',),
'vassflaumer': ('vassflaum',),
'kvefs': ('kvefs',),
'kvefsen': ('kvefs',),
'kvefsene': ('kvefs',),
'kvefser': ('kvefs',),
'vortebiter': ('vortebiter',),
'vortebitere': ('vortebiter',),
'vortebiteren': ('vortebiter',),
'vortebiterer': ('vortebiter',),
'vortebiterne': ('vortebiter',),
'vårflaum': ('vårflaum',),
'vårflaumen': ('vårflaum',),
'vårflaumene': ('vårflaum',),
'vårflaumer': ('vårflaum',),
'unntagelse': ('unntagelse',),
'unntagelsen': ('unntagelse',),
'unntagelsene': ('unntagelse',),
'unntagelser': ('unntagelse',),
'varmestova': ('varmestove',),
'varmestove': ('varmestove',),
'varmestoven': ('varmestove',),
'varmestovene': ('varmestove',),
'varmestover': ('varmestove',),
'WC': ('WC',),
'WCa': ('WC',),
'WCene': ('WC',),
'WCer': ('WC',),
'WCet': ('WC',),
'whiplash': ('whiplash',),
'whiplashen': ('whiplash',),
'whiplashene': ('whiplash',),
'whiplasher': ('whiplash',),
'yak': ('yak',),
'yaken': ('yak',),
'yakene': ('yak',),
'yaker': ('yak',),
'ynk': ('ynk',),
'ynka': ('ynk',),
'ynken': ('ynk',),
'ynkene': ('ynk',),
'ynket': ('ynk',),
'yoyo': ('yoyo',),
'yoyoen': ('yoyo',),
'yoyoene': ('yoyo',),
'yoyoer': ('yoyo',),
'crème de la crème': ('crème de la crème',),
'da capo': ('da capo',),
'da capoen': ('da capo',),
'da capoene': ('da capo',),
'da capoer': ('da capo',),
'desktop publishing': ('desktop publishing',),
'nomen actionis': ('nomen actionis',),
'brakknase': ('brakknase',),
'brakknasen': ('brakknase',),
'brakknasene': ('brakknase',),
'brakknaser': ('brakknase',),
'eidsavleggelse': ('eidsavleggelse',),
'eidsavleggelsen': ('eidsavleggelse',),
'eidsavleggelsene': ('eidsavleggelse',),
'eidsavleggelser': ('eidsavleggelse',),
'haukenase': ('haukenase',),
'haukenasen': ('haukenase',),
'haukenasene': ('haukenase',),
'haukenaser': ('haukenase',),
'lommeløkt': ('lommeløkt',),
'lommeløkta': ('lommeløkt',),
'lommeløkten': ('lommeløkt',),
'lommeløktene': ('lommeløkt',),
'lommeløkter': ('lommeløkt',),
'luftmoske': ('luftmoske',),
'luftmosken': ('luftmoske',),
'luftmoskene': ('luftmoske',),
'luftmosker': ('luftmoske',),
'lutoska': ('lutoske',),
'lutoske': ('lutoske',),
'lutosken': ('lutoske',),
'lutoskene': ('lutoske',),
'lutosker': ('lutoske',),
'måndagsbil': ('måndagsbil',),
'måndagsbilen': ('måndagsbil',),
'måndagsbilene': ('måndagsbil',),
'måndagsbiler': ('måndagsbil',),
'massingblåseinstrument': ('massingblåseinstrument',),
'massingblåseinstrumenta': ('massingblåseinstrument',),
'massingblåseinstrumentene': ('massingblåseinstrument',),
'massingblåseinstrumenter': ('massingblåseinstrument',),
'massingblåseinstrumentet': ('massingblåseinstrument',),
'mottagerapparat': ('mottagerapparat',),
'mottagerapparata': ('mottagerapparat',),
'mottagerapparatene': ('mottagerapparat',),
'mottagerapparater': ('mottagerapparat',),
'mottagerapparatet': ('mottagerapparat',),
'ørnenase': ('ørnenase',),
'ørnenasen': ('ørnenase',),
'ørnenasene': ('ørnenase',),
'ørnenaser': ('ørnenase',),
'oppstoppernase': ('oppstoppernase',),
'oppstoppernasen': ('oppstoppernase',),
'oppstoppernasene': ('oppstoppernase',),
'oppstoppernaser': ('oppstoppernase',),
'romernase': ('romernase',),
'romernasen': ('romernase',),
'romernasene': ('romernase',),
'romernaser': ('romernase',),
'stumpnase': ('stumpnase',),
'stumpnasen': ('stumpnase',),
'stumpnasene': ('stumpnase',),
'stumpnaser': ('stumpnase',),
'tjøra': ('tjøre',),
'tjøre': ('tjøre',),
'tjøren': ('tjøre',),
'tjørene': ('tjøre',),
'tjører': ('tjøre',),
'adskillelse': ('adskillelse',),
'adskillelsen': ('adskillelse',),
'adskillelsene': ('adskillelse',),
'adskillelser': ('adskillelse',),
'gruba': ('grube',),
'grube': ('grube',),
'gruben': ('grube',),
'grubene': ('grube',),
'gruber': ('grube',),
'juggel': ('juggel',),
'juggelet': ('juggel',),
'jugla': ('juggel',),
'juglene': ('juggel',),
'juglet': ('juggel',),
'sten': ('sten',),
'stenen': ('sten',),
'stenene': ('sten',),
'stener': ('sten',),
'varsko': ('varsko',),
'varskoa': ('varsko',),
'varskoene': ('varsko',),
'varskoet': ('varsko',),
'avskrivningskonti': ('avskrivningskonto',),
'avskrivningskontiene': ('avskrivningskonto',),
'avskrivningskonto': ('avskrivningskonto',),
'avskrivningskontoen': ('avskrivningskonto',),
'avskrivningskontoene': ('avskrivningskonto',),
'avskrivningskontoer': ('avskrivningskonto',),
'action': ('action',),
'addenda': ('addendum',),
'addendaene': ('addendum',),
'addendum': ('addendum',),
'addendumet': ('addendum',),
'administrasjonssjef': ('administrasjonssjef',),
'administrasjonssjefen': ('administrasjonssjef',),
'administrasjonssjefene': ('administrasjonssjef',),
'administrasjonssjefer': ('administrasjonssjef',),
'aggressor': ('aggressor',),
'aggressoren': ('aggressor',),
'aggressorene': ('aggressor',),
'aggressorer': ('aggressor',),
'akkreditering': ('akkreditering',),
'akkrediteringa': ('akkreditering',),
'akkrediteringen': ('akkreditering',),
'akkrediteringene': ('akkreditering',),
'akkrediteringer': ('akkreditering',),
'aksjonskomiteen': ('aksjonskomité',),
'aksjonskomiteene': ('aksjonskomité',),
'aksjonskomiteer': ('aksjonskomité',),
'aksjonskomité': ('aksjonskomité',),
'aksjonskomitéen': ('aksjonskomité',),
'aksjonskomitéene': ('aksjonskomité',),
'aksjonskomitéer': ('aksjonskomité',),
'alginat': ('alginat',),
'alginata': ('alginat',),
'alginatene': ('alginat',),
'alginater': ('alginat',),
'alginatet': ('alginat',),
'alleen': ('allé',),
'alleene': ('allé',),
'alleer': ('allé',),
'allé': ('allé',),
'alléen': ('allé',),
'alléene': ('allé',),
'alléer': ('allé',),
'allergen': ('allergen',),
'allergena': ('allergen',),
'allergenene': ('allergen',),
'allergener': ('allergen',),
'allergenet': ('allergen',),
'allmennspråk': ('allmennspråk',),
'allmennspråka': ('allmennspråk',),
'allmennspråkene': ('allmennspråk',),
'allmennspråket': ('allmennspråk',),
'ansvarlighet': ('ansvarlighet',),
'ansvarligheta': ('ansvarlighet',),
'ansvarligheten': ('ansvarlighet',),
'ansvarlighetene': ('ansvarlighet',),
'ansvarligheter': ('ansvarlighet',),
'armeen': ('armé',),
'armeene': ('armé',),
'armeer': ('armé',),
'armé': ('armé',),
'arméen': ('armé',),
'arméene': ('armé',),
'arméer': ('armé',),
'attacheen': ('attaché',),
'attacheene': ('attaché',),
'attacheer': ('attaché',),
'attaché': ('attaché',),
'attachéen': ('attaché',),
'attachéene': ('attaché',),
'attachéer': ('attaché',),
'attribusjon': ('attribusjon',),
'attribusjonen': ('attribusjon',),
'attribusjonene': ('attribusjon',),
'attribusjoner': ('attribusjon',),
'avliving': ('avliving',),
'avlivinga': ('avliving',),
'avlivingen': ('avliving',),
'avlivingene': ('avliving',),
'avlivinger': ('avliving',),
'børseløp': ('børseløp',),
'børseløpa': ('børseløp',),
'børseløpene': ('børseløp',),
'børseløpet': ('børseløp',),
'børsepipa': ('børsepipe',),
'børsepipe': ('børsepipe',),
'børsepipen': ('børsepipe',),
'børsepipene': ('børsepipe',),
'børsepiper': ('børsepipe',),
'baluba': ('baluba',),
'balubaen': ('baluba',),
'balubaene': ('baluba',),
'balubaer': ('baluba',),
'bannlysning': ('bannlysning',),
'bannlysninga': ('bannlysning',),
'bannlysningen': ('bannlysning',),
'bannlysningene': ('bannlysning',),
'bannlysninger': ('bannlysning',),
'barne-TV': ('barne-TV',),
'barnevernspedagog': ('barnevernspedagog',),
'barnevernspedagogen': ('barnevernspedagog',),
'barnevernspedagogene': ('barnevernspedagog',),
'barnevernspedagoger': ('barnevernspedagog',),
'baud': ('baud',),
'bauden': ('baud',),
'baudene': ('baud',),
'bauder': ('baud',),
'bedømmelseskomiteen': ('bedømmelseskomité',),
'bedømmelseskomiteene': ('bedømmelseskomité',),
'bedømmelseskomiteer': ('bedømmelseskomité',),
'bedømmelseskomité': ('bedømmelseskomité',),
'bedømmelseskomitéen': ('bedømmelseskomité',),
'bedømmelseskomitéene': ('bedømmelseskomité',),
'bedømmelseskomitéer': ('bedømmelseskomité',),
'befestning': ('befestning',),
'befestninga': ('befestning',),
'befestningen': ('befestning',),
'befestningene': ('befestning',),
'befestninger': ('befestning',),
'beiskhet': ('beiskhet',),
'beiskheta': ('beiskhet',),
'beiskheten': ('beiskhet',),
'beiskhetene': ('beiskhet',),
'beiskheter': ('beiskhet',),
'berggrunn': ('berggrunn',),
'berggrunnen': ('berggrunn',),
'berggrunnene': ('berggrunn',),
'berggrunner': ('berggrunn',),
'bergingslønn': ('bergingslønn',),
'bergingslønna': ('bergingslønn',),
'bergingslønnen': ('bergingslønn',),
'bergingslønnene': ('bergingslønn',),
'bergingslønner': ('bergingslønn',),
'beskhet': ('beskhet',),
'beskheta': ('beskhet',),
'beskheten': ('beskhet',),
'beskhetene': ('beskhet',),
'beskheter': ('beskhet',),
'bevernylon': ('bevernylon',),
'bevernylona': ('bevernylon',),
'bevernylonene': ('bevernylon',),
'bevernylonet': ('bevernylon',),
'blindtest': ('blindtest',),
'blindtesten': ('blindtest',),
'blindtestene': ('blindtest',),
'blindtester': ('blindtest',),
'blåhai': ('blåhai',),
'blåhaien': ('blåhai',),
'blåhaiene': ('blåhai',),
'blåhaier': ('blåhai',),
'blomsterdekoratør': ('blomsterdekoratør',),
'blomsterdekoratøren': ('blomsterdekoratør',),
'blomsterdekoratørene': ('blomsterdekoratør',),
'blomsterdekoratører': ('blomsterdekoratør',),
'bokkafeen': ('bokkafé',),
'bokkafeene': ('bokkafé',),
'bokkafeer': ('bokkafé',),
'bokkafé': ('bokkafé',),
'bokkaféen': ('bokkafé',),
'bokkaféene': ('bokkafé',),
'bokkaféer': ('bokkafé',),
'boksemat': ('boksemat',),
'boksematen': ('boksemat',),
'boksematene': ('boksemat',),
'boksemater': ('boksemat',),
'bokverk': ('bokverk',),
'bokverka': ('bokverk',),
'bokverkene': ('bokverk',),
'bokverker': ('bokverk',),
'bokverket': ('bokverk',),
'bolster': ('bolster',),
'bolsteret': ('bolster',),
'bolstra': ('bolster',),
'bolstre': ('bolster',),
'bolstrene': ('bolster',),
'bolstret': ('bolster',),
'bombekrater': ('bombekrater',),
'bombekrateret': ('bombekrater',),
'bombekratra': ('bombekrater',),
'bombekratre': ('bombekrater',),
'bombekratrene': ('bombekrater',),
'bombekratret': ('bombekrater',),
'bortelag': ('bortelag',),
'bortelaga': ('bortelag',),
'bortelagene': ('bortelag',),
'bortelaget': ('bortelag',),
'brukerprogram': ('brukerprogram',),
'brukerprogramma': ('brukerprogram',),
'brukerprogrammene': ('brukerprogram',),
'brukerprogrammer': ('brukerprogram',),
'brukerprogrammet': ('brukerprogram',),
'brukthandel': ('brukthandel',),
'brukthandelen': ('brukthandel',),
'brukthandlene': ('brukthandel',),
'brukthandler': ('brukthandel',),
'brukthandler': ('brukthandler',),
'brukthandlere': ('brukthandler',),
'brukthandleren': ('brukthandler',),
'brukthandlerer': ('brukthandler',),
'brukthandlerne': ('brukthandler',),
'brystpanel': ('brystpanel',),
'brystpanela': ('brystpanel',),
'brystpanelene': ('brystpanel',),
'brystpaneler': ('brystpanel',),
'brystpanelet': ('brystpanel',),
'buldring': ('buldring',),
'buldringa': ('buldring',),
'buldringen': ('buldring',),
'buldringene': ('buldring',),
'buldringer': ('buldring',),
'burmeser': ('burmeser',),
'burmesere': ('burmeser',),
'burmeseren': ('burmeser',),
'burmeserer': ('burmeser',),
'burmeserne': ('burmeser',),
'busslomma': ('busslomme',),
'busslomme': ('busslomme',),
'busslommen': ('busslomme',),
'busslommene': ('busslomme',),
'busslommer': ('busslomme',),
'byggekomiteen': ('byggekomité',),
'byggekomiteene': ('byggekomité',),
'byggekomiteer': ('byggekomité',),
'byggekomité': ('byggekomité',),
'byggekomitéen': ('byggekomité',),
'byggekomitéene': ('byggekomité',),
'byggekomitéer': ('byggekomité',),
'campingbil': ('campingbil',),
'campingbilen': ('campingbil',),
'campingbilene': ('campingbil',),
'campingbiler': ('campingbil',),
'consommeen': ('consommé',),
'consommeene': ('consommé',),
'consommeer': ('consommé',),
'consommé': ('consommé',),
'consomméen': ('consommé',),
'consomméene': ('consommé',),
'consomméer': ('consommé',),
'datalingvistikk': ('datalingvistikk',),
'datalingvistikken': ('datalingvistikk',),
'datalingvistikkene': ('datalingvistikk',),
'datalingvistikker': ('datalingvistikk',),
'dermatolog': ('dermatolog',),
'dermatologen': ('dermatolog',),
'dermatologene': ('dermatolog',),
'dermatologer': ('dermatolog',),
'destilleri': ('destilleri',),
'destilleria': ('destilleri',),
'destilleriene': ('destilleri',),
'destillerier': ('destilleri',),
'destilleriet': ('destilleri',),
'disp': ('disp',),
'dispen': ('disp',),
'dispene': ('disp',),
'disper': ('disp',),
'djevelutdriver': ('djevelutdriver',),
'djevelutdrivere': ('djevelutdriver',),
'djevelutdriveren': ('djevelutdriver',),
'djevelutdriverer': ('djevelutdriver',),
'djevelutdriverne': ('djevelutdriver',),
'dobb': ('dobb',),
'dobba': ('dobb',),
'dobben': ('dobb',),
'dobbene': ('dobb',),
'dobber': ('dobb',),
'dren': ('dren',),
'drenen': ('dren',),
'drenene': ('dren',),
'drener': ('dren',),
'dren': ('dren',),
'drena': ('dren',),
'drenene': ('dren',),
'drenet': ('dren',),
'drenasje': ('drenasje',),
'drenasjen': ('drenasje',),
'drenasjene': ('drenasje',),
'drenasjer': ('drenasje',),
'drever': ('drever',),
'drevere': ('drever',),
'dreveren': ('drever',),
'dreverer': ('drever',),
'dreverne': ('drever',),
'drog': ('drog',),
'droga': ('drog',),
'drogene': ('drog',),
'droget': ('drog',),
'egosentriker': ('egosentriker',),
'egosentrikere': ('egosentriker',),
'egosentrikeren': ('egosentriker',),
'egosentrikerer': ('egosentriker',),
'egosentrikerne': ('egosentriker',),
'eierskap': ('eierskap',),
'eierskapa': ('eierskap',),
'eierskapene': ('eierskap',),
'eierskapet': ('eierskap',),
'eksekutivkomiteen': ('eksekutivkomité',),
'eksekutivkomiteene': ('eksekutivkomité',),
'eksekutivkomiteer': ('eksekutivkomité',),
'eksekutivkomité': ('eksekutivkomité',),
'eksekutivkomitéen': ('eksekutivkomité',),
'eksekutivkomitéene': ('eksekutivkomité',),
'eksekutivkomitéer': ('eksekutivkomité',),
'eksponering': ('eksponering',),
'eksponeringa': ('eksponering',),
'eksponeringen': ('eksponering',),
'eksponeringene': ('eksponering',),
'eksponeringer': ('eksponering',),
'elitist': ('elitist',),
'elitisten': ('elitist',),
'elitistene': ('elitist',),
'elitister': ('elitist',),
'enkét': ('enkét',),
'enkéten': ('enkét',),
'enkétene': ('enkét',),
'enkéter': ('enkét',),
'epidemiologi': ('epidemiologi',),
'epidemiologien': ('epidemiologi',),
'epidemiologiene': ('epidemiologi',),
'epidemiologier': ('epidemiologi',),
'eplegelé': ('eplegelé',),
'eplegeléen': ('eplegelé',),
'eplegeléene': ('eplegelé',),
'eplegeléer': ('eplegelé',),
'ergometri': ('ergometri',),
'ergometrien': ('ergometri',),
'ergometriene': ('ergometri',),
'ergometrier': ('ergometri',),
'ergonom': ('ergonom',),
'ergonomen': ('ergonom',),
'ergonomene': ('ergonom',),
'ergonomer': ('ergonom',),
'esker': ('esker',),
'eskere': ('esker',),
'eskeren': ('esker',),
'eskerer': ('esker',),
'eskerne': ('esker',),
'etnosentrisme': ('etnosentrisme',),
'etnosentrismen': ('etnosentrisme',),
'etnosentrismene': ('etnosentrisme',),
'etnosentrismer': ('etnosentrisme',),
'føderalist': ('føderalist',),
'føderalisten': ('føderalist',),
'føderalistene': ('føderalist',),
'føderalister': ('føderalist',),
'fabrikasjonsnummer': ('fabrikasjonsnummer',),
'fabrikasjonsnummeret': ('fabrikasjonsnummer',),
'fabrikasjonsnumra': ('fabrikasjonsnummer',),
'fabrikasjonsnumre': ('fabrikasjonsnummer',),
'fabrikasjonsnumrene': ('fabrikasjonsnummer',),
'fallskjermhopping': ('fallskjermhopping',),
'fallskjermhoppinga': ('fallskjermhopping',),
'fallskjermhoppingen': ('fallskjermhopping',),
'fallskjermhoppingene': ('fallskjermhopping',),
'fallskjermhoppinger': ('fallskjermhopping',),
'fascinasjon': ('fascinasjon',),
'fascinasjonen': ('fascinasjon',),
'fascinasjonene': ('fascinasjon',),
'fascinasjoner': ('fascinasjon',),
'feiding': ('feiding',),
'feidinga': ('feiding',),
'feidingen': ('feiding',),
'feidingene': ('feiding',),
'feidinger': ('feiding',),
'festkomiteen': ('festkomité',),
'festkomiteene': ('festkomité',),
'festkomiteer': ('festkomité',),
'festkomité': ('festkomité',),
'festkomitéen': ('festkomité',),
'festkomitéene': ('festkomité',),
'festkomitéer': ('festkomité',),
'fiffighet': ('fiffighet',),
'fiffigheta': ('fiffighet',),
'fiffigheten': ('fiffighet',),
'fiffighetene': ('fiffighet',),
'fiffigheter': ('fiffighet',),
'finanskomiteen': ('finanskomité',),
'finanskomiteene': ('finanskomité',),
'finanskomiteer': ('finanskomité',),
'finanskomité': ('finanskomité',),
'finanskomitéen': ('finanskomité',),
'finanskomitéene': ('finanskomité',),
'finanskomitéer': ('finanskomité',),
'fireårsalder': ('fireårsalder',),
'fireårsaldere': ('fireårsalder',),
'fireårsalderen': ('fireårsalder',),
'fireårsalderne': ('fireårsalder',),
'fireårsaldre': ('fireårsalder',),
'fireårsaldrene': ('fireårsalder',),
'fireårsaldrer': ('fireårsalder',),
'fisketur': ('fisketur',),
'fisketuren': ('fisketur',),
'fisketurene': ('fisketur',),
'fisketurer': ('fisketur',),
'fôr': ('fôr',),
'fôra': ('fôr',),
'fôrene': ('fôr',),
'fôret': ('fôr',),
'fôring': ('fôring',),
'fôringa': ('fôring',),
'fôringen': ('fôring',),
'fôringene': ('fôring',),
'fôringer': ('fôring',),
'fåresopp': ('fåresopp',),
'fåresoppen': ('fåresopp',),
'fåresoppene': ('fåresopp',),
'fåresopper': ('fåresopp',),
'fjørestein': ('fjørestein',),
'fjøresteinen': ('fjørestein',),
'fjøresteinene': ('fjørestein',),
'fjøresteiner': ('fjørestein',),
'foil': ('foil',),
'foilen': ('foil',),
'foilene': ('foil',),
'foiler': ('foil',),
'foreldreansvar': ('foreldreansvar',),
'foreldreansvara': ('foreldreansvar',),
'foreldreansvarene': ('foreldreansvar',),
'foreldreansvaret': ('foreldreansvar',),
'foreldrerett': ('foreldrerett',),
'foreldreretten': ('foreldrerett',),
'foreldrerettene': ('foreldrerett',),
'foreldreretter': ('foreldrerett',),
'forflatning': ('forflatning',),
'forflatninga': ('forflatning',),
'forflatningen': ('forflatning',),
'forflatningene': ('forflatning',),
'forflatninger': ('forflatning',),
'forkortning': ('forkortning',),
'forkortninga': ('forkortning',),
'forkortningen': ('forkortning',),
'forkortningene': ('forkortning',),
'forkortninger': ('forkortning',),
'forstmann': ('forstmann',),
'forstmannen': ('forstmann',),
'forstmenn': ('forstmann',),
'forstmennene': ('forstmann',),
'fortauskafeen': ('fortauskafé',),
'fortauskafeene': ('fortauskafé',),
'fortauskafeer': ('fortauskafé',),
'fortauskafé': ('fortauskafé',),
'fortauskaféen': ('fortauskafé',),
'fortauskaféene': ('fortauskafé',),
'fortauskaféer': ('fortauskafé',),
'forverring': ('forverring',),
'forverringa': ('forverring',),
'forverringen': ('forverring',),
'forverringene': ('forverring',),
'forverringer': ('forverring',),
'fotogrammetri': ('fotogrammetri',),
'fotogrammetrien': ('fotogrammetri',),
'fotogrammetriene': ('fotogrammetri',),
'fotogrammetrier': ('fotogrammetri',),
'fremmedfrykt': ('fremmedfrykt',),
'fremmedfrykten': ('fremmedfrykt',),
'fremmedfryktene': ('fremmedfrykt',),
'fremmedfrykter': ('fremmedfrykt',),
'frikasseen': ('frikassé',),
'frikasseene': ('frikassé',),
'frikasseer': ('frikassé',),
'frikassé': ('frikassé',),
'frikasséen': ('frikassé',),
'frikasséene': ('frikassé',),
'frikasséer': ('frikassé',),
'frivillighet': ('frivillighet',),
'frivilligheta': ('frivillighet',),
'frivilligheten': ('frivillighet',),
'frivillighetene': ('frivillighet',),
'frivilligheter': ('frivillighet',),
'frontfigur': ('frontfigur',),
'frontfiguren': ('frontfigur',),
'frontfigurene': ('frontfigur',),
'frontfigurer': ('frontfigur',),
'funksjonalitet': ('funksjonalitet',),
'funksjonaliteten': ('funksjonalitet',),
'funksjonalitetene': ('funksjonalitet',),
'funksjonaliteter': ('funksjonalitet',),
'galneheia': ('galneheie',),
'galneheie': ('galneheie',),
'galneheien': ('galneheie',),
'galneheiene': ('galneheie',),
'galneheier': ('galneheie',),
'geleen': ('gelé',),
'geleene': ('gelé',),
'geleer': ('gelé',),
'gelé': ('gelé',),
'geléen': ('gelé',),
'geléene': ('gelé',),
'geléer': ('gelé',),
'geriatriker': ('geriatriker',),
'geriatrikere': ('geriatriker',),
'geriatrikeren': ('geriatriker',),
'geriatrikerer': ('geriatriker',),
'geriatrikerne': ('geriatriker',),
'geværløp': ('geværløp',),
'geværløpa': ('geværløp',),
'geværløpene': ('geværløp',),
'geværløpet': ('geværløp',),
'gårdsturisme': ('gårdsturisme',),
'gårdsturismen': ('gårdsturisme',),
'gårdsturismene': ('gårdsturisme',),
'gårdsturismer': ('gårdsturisme',),
'gjeterhund': ('gjeterhund',),
'gjeterhunden': ('gjeterhund',),
'gjeterhundene': ('gjeterhund',),
'gjeterhunder': ('gjeterhund',),
'gjevhet': ('gjevhet',),
'gjevheta': ('gjevhet',),
'gjevheten': ('gjevhet',),
'gjevhetene': ('gjevhet',),
'gjevheter': ('gjevhet',),
'glassblåsing': ('glassblåsing',),
'glassblåsinga': ('glassblåsing',),
'glassblåsingen': ('glassblåsing',),
'glassblåsingene': ('glassblåsing',),
'glassblåsinger': ('glassblåsing',),
'globalisering': ('globalisering',),
'globaliseringa': ('globalisering',),
'globaliseringen': ('globalisering',),
'globaliseringene': ('globalisering',),
'globaliseringer': ('globalisering',),
'golfer': ('golfer',),
'golfere': ('golfer',),
'golferen': ('golfer',),
'golferer': ('golfer',),
'golferne': ('golfer',),
'granul': ('granul',),
'granula': ('granul',),
'granulene': ('granul',),
'granuler': ('granul',),
'granulet': ('granul',),
'gravkapell': ('gravkapell',),
'gravkapella': ('gravkapell',),
'gravkapellene': ('gravkapell',),
'gravkapeller': ('gravkapell',),
'gravkapellet': ('gravkapell',),
'gravmonument': ('gravmonument',),
'gravmonumenta': ('gravmonument',),
'gravmonumentene': ('gravmonument',),
'gravmonumenter': ('gravmonument',),
'gravmonumentet': ('gravmonument',),
'green': ('green',),
'greenen': ('green',),
'greenene': ('green',),
'greener': ('green',),
'grådighet': ('grådighet',),
'grådigheta': ('grådighet',),
'grådigheten': ('grådighet',),
'grådighetene': ('grådighet',),
'grådigheter': ('grådighet',),
'gründer': ('gründer',),
'gründere': ('gründer',),
'gründeren': ('gründer',),
'gründerer': ('gründer',),
'gründerne': ('gründer',),
'grunnfondsbevis': ('grunnfondsbevis',),
'grunnfondsbevisa': ('grunnfondsbevis',),
'grunnfondsbevisene': ('grunnfondsbevis',),
'grunnfondsbeviser': ('grunnfondsbevis',),
'grunnfondsbeviset': ('grunnfondsbevis',),
'gytebestand': ('gytebestand',),
'gytebestanden': ('gytebestand',),
'gytebestandene': ('gytebestand',),
'gytebestander': ('gytebestand',),
'høyonn': ('høyonn',),
'høyonna': ('høyonn',),
'høyonnen': ('høyonn',),
'høyonnene': ('høyonn',),
'høyonner': ('høyonn',),
'hagemøbel': ('hagemøbel',),
'hagemøbelet': ('hagemøbel',),
'hagemøbla': ('hagemøbel',),
'hagemøblene': ('hagemøbel',),
'hagemøbler': ('hagemøbel',),
'hagemøblet': ('hagemøbel',),
'håndspålegger': ('håndspålegger',),
'håndspåleggere': ('håndspålegger',),
'håndspåleggeren': ('håndspålegger',),
'håndspåleggerer': ('håndspålegger',),
'håndspåleggerne': ('håndspålegger',),
'homofobi': ('homofobi',),
'homofobien': ('homofobi',),
'homofobiene': ('homofobi',),
'homofobier': ('homofobi',),
'hornsalt': ('hornsalt',),
'hornsalta': ('hornsalt',),
'hornsaltene': ('hornsalt',),
'hornsalter': ('hornsalt',),
'hornsaltet': ('hornsalt',),
'huslån': ('huslån',),
'huslåna': ('huslån',),
'huslånene': ('huslån',),
'huslånet': ('huslån',),
'hybridbil': ('hybridbil',),
'hybridbilen': ('hybridbil',),
'hybridbilene': ('hybridbil',),
'hybridbiler': ('hybridbil',),
'hydrolyse': ('hydrolyse',),
'hydrolysen': ('hydrolyse',),
'hydrolysene': ('hydrolyse',),
'hydrolyser': ('hydrolyse',),
'hylling': ('hylling',),
'hyllinga': ('hylling',),
'hyllingen': ('hylling',),
'hyllingene': ('hylling',),
'hyllinger': ('hylling',),
'hyttetur': ('hyttetur',),
'hytteturen': ('hyttetur',),
'hytteturene': ('hyttetur',),
'hytteturer': ('hyttetur',),
'ideen': ('idé',),
'ideene': ('idé',),
'ideer': ('idé',),
'idé': ('idé',),
'idéen': ('idé',),
'idéene': ('idé',),
'idéer': ('idé',),
'idéassosiasjon': ('idéassosiasjon',),
'idéassosiasjonen': ('idéassosiasjon',),
'idéassosiasjonene': ('idéassosiasjon',),
'idéassosiasjoner': ('idéassosiasjon',),
'idédebatt': ('idédebatt',),
'idédebatten': ('idédebatt',),
'idédebattene': ('idédebatt',),
'idédebatter': ('idédebatt',),
'idégrunnlag': ('idégrunnlag',),
'idégrunnlaga': ('idégrunnlag',),
'idégrunnlagene': ('idégrunnlag',),
'idégrunnlaget': ('idégrunnlag',),
'idéhistorie': ('idéhistorie',),
'idéhistorien': ('idéhistorie',),
'idéhistoriene': ('idéhistorie',),
'idéhistorier': ('idéhistorie',),
'idéskissa': ('idéskisse',),
'idéskisse': ('idéskisse',),
'idéskissen': ('idéskisse',),
'idéskissene': ('idéskisse',),
'idéskisser': ('idéskisse',),
'ID-kort': ('ID-kort',),
'ID-korta': ('ID-kort',),
'ID-kortene': ('ID-kort',),
'ID-kortet': ('ID-kort',),
'idrettsskade': ('idrettsskade',),
'idrettsskaden': ('idrettsskade',),
'idrettsskadene': ('idrettsskade',),
'idrettsskader': ('idrettsskade',),
'implementering': ('implementering',),
'implementeringa': ('implementering',),
'implementeringen': ('implementering',),
'implementeringene': ('implementering',),
'implementeringer': ('implementering',),
'industritråler': ('industritråler',),
'industritrålere': ('industritråler',),
'industritråleren': ('industritråler',),
'industritrålerer': ('industritråler',),
'industritrålerne': ('industritråler',),
'inkrement': ('inkrement',),
'inkrementa': ('inkrement',),
'inkrementene': ('inkrement',),
'inkrementer': ('inkrement',),
'inkrementet': ('inkrement',),
'inndragelse': ('inndragelse',),
'inndragelsen': ('inndragelse',),
'inndragelsene': ('inndragelse',),
'inndragelser': ('inndragelse',),
'innhopp': ('innhopp',),
'innhoppa': ('innhopp',),
'innhoppene': ('innhopp',),
'innhoppet': ('innhopp',),
'inntjening': ('inntjening',),
'inntjeninga': ('inntjening',),
'inntjeningen': ('inntjening',),
'inntjeningene': ('inntjening',),
'inntjeninger': ('inntjening',),
'inokulat': ('inokulat',),
'inokulata': ('inokulat',),
'inokulatene': ('inokulat',),
'inokulater': ('inokulat',),
'inokulatet': ('inokulat',),
'jurydomstol': ('jurydomstol',),
'jurydomstolen': ('jurydomstol',),
'jurydomstolene': ('jurydomstol',),
'jurydomstoler': ('jurydomstol',),
'jurymedlem': ('jurymedlem',),
'jurymedlemma': ('jurymedlem',),
'jurymedlemmene': ('jurymedlem',),
'jurymedlemmer': ('jurymedlem',),
'jurymedlemmet': ('jurymedlem',),
'justiskomiteen': ('justiskomité',),
'justiskomiteene': ('justiskomité',),
'justiskomiteer': ('justiskomité',),
'justiskomité': ('justiskomité',),
'justiskomitéen': ('justiskomité',),
'justiskomitéene': ('justiskomité',),
'justiskomitéer': ('justiskomité',),
'kabel-TV': ('kabel-TV',),
'kabel-TVen': ('kabel-TV',),
'kabel-TVene': ('kabel-TV',),
'kabel-TVer': ('kabel-TV',),
'kabel-tv': ('kabel-tv',),
'kabel-tven': ('kabel-tv',),
'kabel-tvene': ('kabel-tv',),
'kabel-tver': ('kabel-tv',),
'kafeen': ('kafé',),
'kafeene': ('kafé',),
'kafeer': ('kafé',),
'kafé': ('kafé',),
'kaféen': ('kafé',),
'kaféene': ('kafé',),
'kaféer': ('kafé',),
'kampsport': ('kampsport',),
'kampsporten': ('kampsport',),
'kampsportene': ('kampsport',),
'kampsporter': ('kampsport',),
'kanapeen': ('kanapé',),
'kanapeene': ('kanapé',),
'kanapeer': ('kanapé',),
'kanapé': ('kanapé',),
'kanapéen': ('kanapé',),
'kanapéene': ('kanapé',),
'kanapéer': ('kanapé',),
'kantori': ('kantori',),
'kantoria': ('kantori',),
'kantoriene': ('kantori',),
'kantoriet': ('kantori',),
'kapitel': ('kapitel',),
'kapitela': ('kapitel',),
'kapitelene': ('kapitel',),
'kapiteler': ('kapitel',),
'kapitelet': ('kapitel',),
'karismatiker': ('karismatiker',),
'karismatikere': ('karismatiker',),
'karismatikeren': ('karismatiker',),
'karismatikerer': ('karismatiker',),
'karismatikerne': ('karismatiker',),
'karreen': ('karré',),
'karreene': ('karré',),
'karreer': ('karré',),
'karré': ('karré',),
'karréen': ('karré',),
'karréene': ('karré',),
'karréer': ('karré',),
'kjøletårn': ('kjøletårn',),
'kjøletårna': ('kjøletårn',),
'kjøletårnene': ('kjøletårn',),
'kjøletårnet': ('kjøletårn',),
'kjøpmannskap': ('kjøpmannskap',),
'kjøpmannskapa': ('kjøpmannskap',),
'kjøpmannskapene': ('kjøpmannskap',),
'kjøpmannskapet': ('kjøpmannskap',),
'kjæledyr': ('kjæledyr',),
'kjæledyra': ('kjæledyr',),
'kjæledyrene': ('kjæledyr',),
'kjæledyret': ('kjæledyr',),
'klistremerka': ('klistremerke',),
'klistremerke': ('klistremerke',),
'klistremerkene': ('klistremerke',),
'klistremerker': ('klistremerke',),
'klistremerket': ('klistremerke',),
'knappsoleia': ('knappsoleie',),
'knappsoleie': ('knappsoleie',),
'knappsoleien': ('knappsoleie',),
'knappsoleiene': ('knappsoleie',),
'knappsoleier': ('knappsoleie',),
'koala': ('koala',),
'koalaen': ('koala',),
'koalaene': ('koala',),
'koalaer': ('koala',),
'kokkelimonke': ('kokkelimonke',),
'kokkelimonkeen': ('kokkelimonke',),
'kokkelimonkeene': ('kokkelimonke',),
'kokkelimonkeer': ('kokkelimonke',),
'kolorist': ('kolorist',),
'koloristen': ('kolorist',),
'koloristene': ('kolorist',),
'kolorister': ('kolorist',),
'komiteen': ('komité',),
'komiteene': ('komité',),
'komiteer': ('komité',),
'komité': ('komité',),
'komitéen': ('komité',),
'komitéene': ('komité',),
'komitéer': ('komité',),
'komitéinnstilling': ('komitéinnstilling',),
'komitéinnstillinga': ('komitéinnstilling',),
'komitéinnstillingen': ('komitéinnstilling',),
'komitéinnstillingene': ('komitéinnstilling',),
'komitéinnstillinger': ('komitéinnstilling',),
'kommunikea': ('kommuniké',),
'kommunikeene': ('kommuniké',),
'kommunikeer': ('kommuniké',),
'kommunikeet': ('kommuniké',),
'kommuniké': ('kommuniké',),
'kommunikéa': ('kommuniké',),
'kommunikéene': ('kommuniké',),
'kommunikéer': ('kommuniké',),
'kommunikéet': ('kommuniké',),
'konfidensialitet': ('konfidensialitet',),
'konfidensialiteten': ('konfidensialitet',),
'konfidensialitetene': ('konfidensialitet',),
'konfidensialiteter': ('konfidensialitet',),
'kontrastmiddel': ('kontrastmiddel',),
'kontrastmiddelet': ('kontrastmiddel',),
'kontrastmidla': ('kontrastmiddel',),
'kontrastmidlene': ('kontrastmiddel',),
'kontrastmidler': ('kontrastmiddel',),
'kontrastmidlet': ('kontrastmiddel',),
'kraftfôr': ('kraftfôr',),
'kraftfôra': ('kraftfôr',),
'kraftfôrene': ('kraftfôr',),
'kraftfôret': ('kraftfôr',),
'kremlolog': ('kremlolog',),
'kremlologen': ('kremlolog',),
'kremlologene': ('kremlolog',),
'kremlologer': ('kremlolog',),
'kremlologi': ('kremlologi',),
'kremlologien': ('kremlologi',),
'kremlologiene': ('kremlologi',),
'kremlologier': ('kremlologi',),
'kretsmester': ('kretsmester',),
'kretsmestere': ('kretsmester',),
'kretsmesteren': ('kretsmester',),
'kretsmesterer': ('kretsmester',),
'kretsmesterne': ('kretsmester',),
'kretsmestre': ('kretsmester',),
'kretsmestrene': ('kretsmester',),
'kretsmestrer': ('kretsmester',),
'kroppsspråk': ('kroppsspråk',),
'kroppsspråka': ('kroppsspråk',),
'kroppsspråkene': ('kroppsspråk',),
'kroppsspråket': ('kroppsspråk',),
'kryddermål': ('kryddermål',),
'kryddermåla': ('kryddermål',),
'kryddermålene': ('kryddermål',),
'kryddermålet': ('kryddermål',),
'kulturattacheen': ('kulturattaché',),
'kulturattacheene': ('kulturattaché',),
'kulturattacheer': ('kulturattaché',),
'kulturattaché': ('kulturattaché',),
'kulturattachéen': ('kulturattaché',),
'kulturattachéene': ('kulturattaché',),
'kulturattachéer': ('kulturattaché',),
'kulturdepartement': ('kulturdepartement',),
'kulturdepartementa': ('kulturdepartement',),
'kulturdepartementene': ('kulturdepartement',),
'kulturdepartementer': ('kulturdepartement',),
'kulturdepartementet': ('kulturdepartement',),
'kunstsmed': ('kunstsmed',),
'kunstsmeden': ('kunstsmed',),
'kunstsmedene': ('kunstsmed',),
'kunstsmeder': ('kunstsmed',),
'kvalitetssikring': ('kvalitetssikring',),
'kvalitetssikringa': ('kvalitetssikring',),
'kvalitetssikringen': ('kvalitetssikring',),
'kvalitetssikringene': ('kvalitetssikring',),
'kvalitetssikringer': ('kvalitetssikring',),
'kvitvara': ('kvitvare',),
'kvitvare': ('kvitvare',),
'kvitvaren': ('kvitvare',),
'kvitvarene': ('kvitvare',),
'kvitvarer': ('kvitvare',),
'kyssesjuka': ('kyssesjuke',),
'kyssesjuke': ('kyssesjuke',),
'kyssesjuken': ('kyssesjuke',),
'kyssesjukene': ('kyssesjuke',),
'kyssesjuker': ('kyssesjuke',),
'kyssesyka': ('kyssesyke',),
'kyssesyke': ('kyssesyke',),
'kyssesyken': ('kyssesyke',),
'kyssesykene': ('kyssesyke',),
'kyssesyker': ('kyssesyke',),
'lagja': ('lagje',),
'lagje': ('lagje',),
'lagjen': ('lagje',),
'lagjene': ('lagje',),
'lagjer': ('lagje',),
'lagjet': ('lagje',),
'lakselus': ('lakselus',),
'lakselusa': ('lakselus',),
'lakselusen': ('lakselus',),
'lakselusene': ('lakselus',),
'lammefrikasseen': ('lammefrikassé',),
'lammefrikasseene': ('lammefrikassé',),
'lammefrikasseer': ('lammefrikassé',),
'lammefrikassé': ('lammefrikassé',),
'lammefrikasséen': ('lammefrikassé',),
'lammefrikasséene': ('lammefrikassé',),
'lammefrikasséer': ('lammefrikassé',),
'langorv': ('langorv',),
'langorva': ('langorv',),
'langorvene': ('langorv',),
'langorvet': ('langorv',),
'lastebøya': ('lastebøye',),
'lastebøye': ('lastebøye',),
'lastebøyen': ('lastebøye',),
'lastebøyene': ('lastebøye',),
'lastebøyer': ('lastebøye',),
'legionærsyka': ('legionærsyke',),
'legionærsyke': ('legionærsyke',),
'legionærsyken': ('legionærsyke',),
'legionærsykene': ('legionærsyke',),
'legionærsyker': ('legionærsyke',),
'lev': ('lev',),
'leven': ('lev',),
'levene': ('lev',),
'lever': ('lev',),
'ligningsverdi': ('ligningsverdi',),
'ligningsverdien': ('ligningsverdi',),
'ligningsverdiene': ('ligningsverdi',),
'ligningsverdier': ('ligningsverdi',),
'likegyldighet': ('likegyldighet',),
'likegyldigheta': ('likegyldighet',),
'likegyldigheten': ('likegyldighet',),
'likegyldighetene': ('likegyldighet',),
'likegyldigheter': ('likegyldighet',),
'likningsverdi': ('likningsverdi',),
'likningsverdien': ('likningsverdi',),
'likningsverdiene': ('likningsverdi',),
'likningsverdier': ('likningsverdi',),
'lisenshaver': ('lisenshaver',),
'lisenshavere': ('lisenshaver',),
'lisenshaveren': ('lisenshaver',),
'lisenshaverer': ('lisenshaver',),
'lisenshaverne': ('lisenshaver',),
'litteraturvitenskap': ('litteraturvitenskap',),
'litteraturvitenskapen': ('litteraturvitenskap',),
'litteraturvitenskapene': ('litteraturvitenskap',),
'litteraturvitenskaper': ('litteraturvitenskap',),
'litteraturviter': ('litteraturviter',),
'litteraturvitere': ('litteraturviter',),
'litteraturviteren': ('litteraturviter',),
'litteraturviterer': ('litteraturviter',),
'litteraturviterne': ('litteraturviter',),
'livsverdi': ('livsverdi',),
'livsverdien': ('livsverdi',),
'livsverdiene': ('livsverdi',),
'livsverdier': ('livsverdi',),
'lobbyisme': ('lobbyisme',),
'lobbyismen': ('lobbyisme',),
'lobbyismene': ('lobbyisme',),
'lobbyismer': ('lobbyisme',),
'lokalfjernsyn': ('lokalfjernsyn',),
'lokalfjernsyna': ('lokalfjernsyn',),
'lokalfjernsynene': ('lokalfjernsyn',),
'lokalfjernsynet': ('lokalfjernsyn',),
'losholt': ('losholt',),
'losholten': ('losholt',),
'losholtene': ('losholt',),
'losholter': ('losholt',),
'lotto': ('lotto',),
'lottoen': ('lotto',),
'lottoene': ('lotto',),
'lottoer': ('lotto',),
'luktfjerner': ('luktfjerner',),
'luktfjernere': ('luktfjerner',),
'luktfjerneren': ('luktfjerner',),
'luktfjernerer': ('luktfjerner',),
'luktfjernerne': ('luktfjerner',),
'lyssetting': ('lyssetting',),
'lyssettinga': ('lyssetting',),
'lyssettingen': ('lyssetting',),
'lyssettingene': ('lyssetting',),
'lyssettinger': ('lyssetting',),
'makramea': ('makramé',),
'makrameen': ('makramé',),
'makrameene': ('makramé',),
'makrameer': ('makramé',),
'makrameet': ('makramé',),
'makramé': ('makramé',),
'makraméa': ('makramé',),
'makraméen': ('makramé',),
'makraméene': ('makramé',),
'makraméer': ('makramé',),
'makraméet': ('makramé',),
'makraméarbeid': ('makraméarbeid',),
'makraméarbeida': ('makraméarbeid',),
'makraméarbeidene': ('makraméarbeid',),
'makraméarbeidet': ('makraméarbeid',),
'marineattacheen': ('marineattaché',),
'marineattacheene': ('marineattaché',),
'marineattacheer': ('marineattaché',),
'marineattaché': ('marineattaché',),
'marineattachéen': ('marineattaché',),
'marineattachéene': ('marineattaché',),
'marineattachéer': ('marineattaché',),
'martini': ('martini',),
'martinien': ('martini',),
'martiniene': ('martini',),
'martinier': ('martini',),
'matineen': ('matiné',),
'matineene': ('matiné',),
'matineer': ('matiné',),
'matiné': ('matiné',),
'matinéen': ('matiné',),
'matinéene': ('matiné',),
'matinéer': ('matiné',),
'MC': ('MC',),
'megalomani': ('megalomani',),
'megalomanien': ('megalomani',),
'megalomaniene': ('megalomani',),
'megalomanier': ('megalomani',),
'mestring': ('mestring',),
'mestringa': ('mestring',),
'mestringen': ('mestring',),
'mestringene': ('mestring',),
'mestringer': ('mestring',),
'metadon': ('metadon',),
'metadona': ('metadon',),
'metadonene': ('metadon',),
'metadonet': ('metadon',),
'mikrofly': ('mikrofly',),
'mikroflya': ('mikrofly',),
'mikroflyene': ('mikrofly',),
'mikroflyet': ('mikrofly',),
'mikrofonstativ': ('mikrofonstativ',),
'mikrofonstativa': ('mikrofonstativ',),
'mikrofonstativene': ('mikrofonstativ',),
'mikrofonstativer': ('mikrofonstativ',),
'mikrofonstativet': ('mikrofonstativ',),
'militærattacheen': ('militærattaché',),
'militærattacheene': ('militærattaché',),
'militærattacheer': ('militærattaché',),
'militærattaché': ('militærattaché',),
'militærattachéen': ('militærattaché',),
'militærattachéene': ('militærattaché',),
'militærattachéer': ('militærattaché',),
'milliontedel': ('milliontedel',),
'milliontedelen': ('milliontedel',),
'milliontedelene': ('milliontedel',),
'milliontedeler': ('milliontedel',),
'minimalisme': ('minimalisme',),
'minimalismen': ('minimalisme',),
'minimalismene': ('minimalisme',),
'minimalismer': ('minimalisme',),
'minimalist': ('minimalist',),
'minimalisten': ('minimalist',),
'minimalistene': ('minimalist',),
'minimalister': ('minimalist',),
'misbilligelse': ('misbilligelse',),
'misbilligelsen': ('misbilligelse',),
'misbilligelsene': ('misbilligelse',),
'misbilligelser': ('misbilligelse',),
'misere': ('misere',),
'miseren': ('misere',),
'miserene': ('misere',),
'miserer': ('misere',),
'misligholdelse': ('misligholdelse',),
'misligholdelsen': ('misligholdelse',),
'misligholdelsene': ('misligholdelse',),
'misligholdelser': ('misligholdelse',),
'monotypi': ('monotypi',),
'monotypien': ('monotypi',),
'monotypiene': ('monotypi',),
'monotypier': ('monotypi',),
'moskeen': ('moské',),
'moskeene': ('moské',),
'moskeer': ('moské',),
'moské': ('moské',),
'moskéen': ('moské',),
'moskéene': ('moské',),
'moskéer': ('moské',),
'muflon': ('muflon',),
'muflonen': ('muflon',),
'muflonene': ('muflon',),
'mufloner': ('muflon',),
'mufti': ('mufti',),
'muftien': ('mufti',),
'muftiene': ('mufti',),
'muftier': ('mufti',),
'muse': ('muse',),
'musea': ('muse',),
'museene': ('muse',),
'museer': ('muse',),
'museet': ('muse',),
'narkolepsi': ('narkolepsi',),
'narkolepsien': ('narkolepsi',),
'narkolepsiene': ('narkolepsi',),
'narkolepsier': ('narkolepsi',),
'narkoreda': ('narkorede',),
'narkorede': ('narkorede',),
'narkoredene': ('narkorede',),
'narkoreder': ('narkorede',),
'narkoredet': ('narkorede',),
'narkoreir': ('narkoreir',),
'narkoreira': ('narkoreir',),
'narkoreirene': ('narkoreir',),
'narkoreiret': ('narkoreir',),
'nattehimlene': ('nattehimmel',),
'nattehimler': ('nattehimmel',),
'nattehimmel': ('nattehimmel',),
'nattehimmelen': ('nattehimmel',),
'natthimlene': ('natthimmel',),
'natthimler': ('natthimmel',),
'natthimmel': ('natthimmel',),
'natthimmelen': ('natthimmel',),
'nattkafeen': ('nattkafé',),
'nattkafeene': ('nattkafé',),
'nattkafeer': ('nattkafé',),
'nattkafé': ('nattkafé',),
'nattkaféen': ('nattkafé',),
'nattkaféene': ('nattkafé',),
'nattkaféer': ('nattkafé',),
'nedbemanning': ('nedbemanning',),
'nedbemanninga': ('nedbemanning',),
'nedbemanningen': ('nedbemanning',),
'nedbemanningene': ('nedbemanning',),
'nedbemanninger': ('nedbemanning',),
'nedbetaling': ('nedbetaling',),
'nedbetalinga': ('nedbetaling',),
'nedbetalingen': ('nedbetaling',),
'nedbetalingene': ('nedbetaling',),
'nedbetalinger': ('nedbetaling',),
'nedbetalingstid': ('nedbetalingstid',),
'nedbetalingstida': ('nedbetalingstid',),
'nedbetalingstiden': ('nedbetalingstid',),
'nedbetalingstidene': ('nedbetalingstid',),
'nedbetalingstider': ('nedbetalingstid',),
'nedbremsing': ('nedbremsing',),
'nedbremsinga': ('nedbremsing',),
'nedbremsingen': ('nedbremsing',),
'nedbremsingene': ('nedbremsing',),
'nedbremsinger': ('nedbremsing',),
'nederlagsstemning': ('nederlagsstemning',),
'nederlagsstemninga': ('nederlagsstemning',),
'nederlagsstemningen': ('nederlagsstemning',),
'nederlagsstemningene': ('nederlagsstemning',),
'nederlagsstemninger': ('nederlagsstemning',),
'nedfart': ('nedfart',),
'nedfarten': ('nedfart',),
'nedfartene': ('nedfart',),
'nedfarter': ('nedfart',),
'nedfôring': ('nedfôring',),
'nedfôringa': ('nedfôring',),
'nedfôringen': ('nedfôring',),
'nedfôringene': ('nedfôring',),
'nedfôringer': ('nedfôring',),
'nedstiging': ('nedstiging',),
'nedstiginga': ('nedstiging',),
'nedstigingen': ('nedstiging',),
'nedstigingene': ('nedstiging',),
'nedstiginger': ('nedstiging',),
'nekt': ('nekt',),
'nekten': ('nekt',),
'nektene': ('nekt',),
'nekter': ('nekt',),
'nisselua': ('nisselue',),
'nisselue': ('nisselue',),
'nisseluen': ('nisselue',),
'nisseluene': ('nisselue',),
'nisseluer': ('nisselue',),
'nynorskbruker': ('nynorskbruker',),
'nynorskbrukere': ('nynorskbruker',),
'nynorskbrukeren': ('nynorskbruker',),
'nynorskbrukerer': ('nynorskbruker',),
'nynorskbrukerne': ('nynorskbruker',),
'odysseen': ('odyssé',),
'odysseene': ('odyssé',),
'odysseer': ('odyssé',),
'odyssé': ('odyssé',),
'odysséen': ('odyssé',),
'odysséene': ('odyssé',),
'odysséer': ('odyssé',),
'offroader': ('offroader',),
'offroadere': ('offroader',),
'offroaderen': ('offroader',),
'offroaderer': ('offroader',),
'offroaderne': ('offroader',),
'offroadsykkel': ('offroadsykkel',),
'offroadsykkelen': ('offroadsykkel',),
'offroadsyklene': ('offroadsykkel',),
'offroadsykler': ('offroadsykkel',),
'olajakka': ('olajakke',),
'olajakke': ('olajakke',),
'olajakken': ('olajakke',),
'olajakkene': ('olajakke',),
'olajakker': ('olajakke',),
'onkologi': ('onkologi',),
'onkologien': ('onkologi',),
'onkologiene': ('onkologi',),
'onkologier': ('onkologi',),
'operativsystem': ('operativsystem',),
'operativsystema': ('operativsystem',),
'operativsystemene': ('operativsystem',),
'operativsystemer': ('operativsystem',),
'operativsystemet': ('operativsystem',),
'oppfølger': ('oppfølger',),
'oppfølgere': ('oppfølger',),
'oppfølgeren': ('oppfølger',),
'oppfølgerer': ('oppfølger',),
'oppfølgerne': ('oppfølger',),
'oppsigelsesvern': ('oppsigelsesvern',),
'oppsigelsesverna': ('oppsigelsesvern',),
'oppsigelsesvernene': ('oppsigelsesvern',),
'oppsigelsesvernet': ('oppsigelsesvern',),
'orkideen': ('orkidé',),
'orkideene': ('orkidé',),
'orkideer': ('orkidé',),
'orkidé': ('orkidé',),
'orkidéen': ('orkidé',),
'orkidéene': ('orkidé',),
'orkidéer': ('orkidé',),
'ostekaka': ('ostekake',),
'ostekake': ('ostekake',),
'ostekaken': ('ostekake',),
'ostekakene': ('ostekake',),
'ostekaker': ('ostekake',),
'osteoporose': ('osteoporose',),
'osteoporosen': ('osteoporose',),
'osteoporosene': ('osteoporose',),
'osteoporoser': ('osteoporose',),
'overgriper': ('overgriper',),
'overgripere': ('overgriper',),
'overgriperen': ('overgriper',),
'overgriperer': ('overgriper',),
'overgriperne': ('overgriper',),
'palea': ('palé',),
'paleene': ('palé',),
'paleer': ('palé',),
'paleet': ('palé',),
'palé': ('palé',),
'paléa': ('palé',),
'paléene': ('palé',),
'paléer': ('palé',),
'paléet': ('palé',),
'pappvin': ('pappvin',),
'pappvinen': ('pappvin',),
'pappvinene': ('pappvin',),
'pappviner': ('pappvin',),
'pateen': ('paté',),
'pateene': ('paté',),
'pateer': ('paté',),
'paté': ('paté',),
'patéen': ('paté',),
'patéene': ('paté',),
'patéer': ('paté',),
'peker': ('peker',),
'pekere': ('peker',),
'pekeren': ('peker',),
'pekerer': ('peker',),
'pekerne': ('peker',),
'pådrag': ('pådrag',),
'pådraga': ('pådrag',),
'pådragene': ('pådrag',),
'pådraget': ('pådrag',),
'påvirkning': ('påvirkning',),
'påvirkninga': ('påvirkning',),
'påvirkningen': ('påvirkning',),
'påvirkningene': ('påvirkning',),
'påvirkninger': ('påvirkning',),
'plantevern': ('plantevern',),
'planteverna': ('plantevern',),
'plantevernene': ('plantevern',),
'plantevernet': ('plantevern',),
'plantevernmiddel': ('plantevernmiddel',),
'plantevernmiddelet': ('plantevernmiddel',),
'plantevernmidla': ('plantevernmiddel',),
'plantevernmidlene': ('plantevernmiddel',),
'plantevernmidler': ('plantevernmiddel',),
'plantevernmidlet': ('plantevernmiddel',),
'plasthall': ('plasthall',),
'plasthallen': ('plasthall',),
'plasthallene': ('plasthall',),
'plasthaller': ('plasthall',),
'plisseen': ('plissé',),
'plisseene': ('plissé',),
'plisseer': ('plissé',),
'plissé': ('plissé',),
'plisséen': ('plissé',),
'plisséene': ('plissé',),
'plisséer': ('plissé',),
'plisséskjørt': ('plisséskjørt',),
'plisséskjørta': ('plisséskjørt',),
'plisséskjørtene': ('plisséskjørt',),
'plisséskjørtet': ('plisséskjørt',),
'portemoneen': ('portemoné',),
'portemoneene': ('portemoné',),
'portemoneer': ('portemoné',),
'portemoné': ('portemoné',),
'portemonéen': ('portemoné',),
'portemonéene': ('portemoné',),
'portemonéer': ('portemoné',),
'portrettør': ('portrettør',),
'portrettøren': ('portrettør',),
'portrettørene': ('portrettør',),
'portrettører': ('portrettør',),
'potensmiddel': ('potensmiddel',),
'potensmiddelet': ('potensmiddel',),
'potensmidla': ('potensmiddel',),
'potensmidlene': ('potensmiddel',),
'potensmidler': ('potensmiddel',),
'potensmidlet': ('potensmiddel',),
'presseattacheen': ('presseattaché',),
'presseattacheene': ('presseattaché',),
'presseattacheer': ('presseattaché',),
'presseattaché': ('presseattaché',),
'presseattachéen': ('presseattaché',),
'presseattachéene': ('presseattaché',),
'presseattachéer': ('presseattaché',),
'primalskrik': ('primalskrik',),
'primalskrika': ('primalskrik',),
'primalskrikene': ('primalskrik',),
'primalskriket': ('primalskrik',),
'protokollkomiteen': ('protokollkomité',),
'protokollkomiteene': ('protokollkomité',),
'protokollkomiteer': ('protokollkomité',),
'protokollkomité': ('protokollkomité',),
'protokollkomitéen': ('protokollkomité',),
'protokollkomitéene': ('protokollkomité',),
'protokollkomitéer': ('protokollkomité',),
'renommea': ('renommé',),
'renommeene': ('renommé',),
'renommeer': ('renommé',),
'renommeet': ('renommé',),
'renommé': ('renommé',),
'renomméa': ('renommé',),
'renomméene': ('renommé',),
'renomméer': ('renommé',),
'renomméet': ('renommé',),
'resitator': ('resitator',),
'resitatoren': ('resitator',),
'resitatorene': ('resitator',),
'resitatorer': ('resitator',),
'resymea': ('resymé',),
'resymeene': ('resymé',),
'resymeer': ('resymé',),
'resymeet': ('resymé',),
'resymé': ('resymé',),
'resyméa': ('resymé',),
'resyméene': ('resymé',),
'resyméer': ('resymé',),
'resyméet': ('resymé',),
'returporto': ('returporto',),
'returportoen': ('returporto',),
'returportoene': ('returporto',),
'returportoer': ('returporto',),
'returrett': ('returrett',),
'returretten': ('returrett',),
'returrettene': ('returrett',),
'returretter': ('returrett',),
'romtemperatur': ('romtemperatur',),
'romtemperaturen': ('romtemperatur',),
'romtemperaturene': ('romtemperatur',),
'romtemperaturer': ('romtemperatur',),
'rosévin': ('rosévin',),
'rosévinen': ('rosévin',),
'rosévinene': ('rosévin',),
'roséviner': ('rosévin',),
'ryddegutt': ('ryddegutt',),
'ryddegutten': ('ryddegutt',),
'ryddeguttene': ('ryddegutt',),
'ryddegutter': ('ryddegutt',),
'søkeord': ('søkeord',),
'søkeorda': ('søkeord',),
'søkeordene': ('søkeord',),
'søkeordet': ('søkeord',),
'særavtale': ('særavtale',),
'særavtalen': ('særavtale',),
'særavtalene': ('særavtale',),
'særavtaler': ('særavtale',),
'særbehandling': ('særbehandling',),
'særbehandlinga': ('særbehandling',),
'særbehandlingen': ('særbehandling',),
'særbehandlingene': ('særbehandling',),
'særbehandlinger': ('særbehandling',),
'salmonella': ('salmonella',),
'salmonellaen': ('salmonella',),
'salmonellaene': ('salmonella',),
'salmonellaer': ('salmonella',),
'samfunnsmedisin': ('samfunnsmedisin',),
'samfunnsmedisinen': ('samfunnsmedisin',),
'samfunnsmedisinene': ('samfunnsmedisin',),
'samfunnsmedisiner': ('samfunnsmedisin',),
'samleplata': ('samleplate',),
'samleplate': ('samleplate',),
'samleplaten': ('samleplate',),
'samleplatene': ('samleplate',),
'samleplater': ('samleplate',),
'satellitt-tv': ('satellitt-tv',),
'satellitt-tven': ('satellitt-tv',),
'satellitt-tvene': ('satellitt-tv',),
'satellitt-tver': ('satellitt-tv',),
'satellitt-TV': ('satellitt-TV',),
'satellitt-TVen': ('satellitt-TV',),
'satellitt-TVene': ('satellitt-TV',),
'satellitt-TVer': ('satellitt-TV',),
'satellittfjernsyn': ('satellittfjernsyn',),
'satellittfjernsyna': ('satellittfjernsyn',),
'satellittfjernsynene': ('satellittfjernsyn',),
'satellittfjernsynet': ('satellittfjernsyn',),
'sauesopp': ('sauesopp',),
'sauesoppen': ('sauesopp',),
'sauesoppene': ('sauesopp',),
'sauesopper': ('sauesopp',),
'seismolog': ('seismolog',),
'seismologen': ('seismolog',),
'seismologene': ('seismolog',),
'seismologer': ('seismolog',),
'seksualitet': ('seksualitet',),
'seksualiteten': ('seksualitet',),
'seksualitetene': ('seksualitet',),
'seksualiteter': ('seksualitet',),
'selskapsantrekk': ('selskapsantrekk',),
'selskapsantrekka': ('selskapsantrekk',),
'selskapsantrekkene': ('selskapsantrekk',),
'selskapsantrekket': ('selskapsantrekk',),
'selskapsmat': ('selskapsmat',),
'selskapsmaten': ('selskapsmat',),
'selskapsmatene': ('selskapsmat',),
'selskapsmater': ('selskapsmat',),
'setting': ('setting',),
'settinga': ('setting',),
'settingen': ('setting',),
'settingene': ('setting',),
'settinger': ('setting',),
'shekel': ('shekel',),
'shekelen': ('shekel',),
'sheklene': ('shekel',),
'sits': ('sits',),
'sitsen': ('sits',),
'sitsene': ('sits',),
'sitser': ('sits',),
'sittegruppa': ('sittegruppe',),
'sittegruppe': ('sittegruppe',),
'sittegruppen': ('sittegruppe',),
'sittegruppene': ('sittegruppe',),
'sittegrupper': ('sittegruppe',),
'situasjonskomedie': ('situasjonskomedie',),
'situasjonskomedien': ('situasjonskomedie',),
'situasjonskomediene': ('situasjonskomedie',),
'situasjonskomedier': ('situasjonskomedie',),
'sjøbod': ('sjøbod',),
'sjøboden': ('sjøbod',),
'sjøbodene': ('sjøbod',),
'sjøboder': ('sjøbod',),
'sjekklista': ('sjekkliste',),
'sjekkliste': ('sjekkliste',),
'sjekklisten': ('sjekkliste',),
'sjekklistene': ('sjekkliste',),
'sjekklister': ('sjekkliste',),
'sjekkpunkt': ('sjekkpunkt',),
'sjekkpunkta': ('sjekkpunkt',),
'sjekkpunktene': ('sjekkpunkt',),
'sjekkpunkter': ('sjekkpunkt',),
'sjekkpunktet': ('sjekkpunkt',),
'skadevolder': ('skadevolder',),
'skadevoldere': ('skadevolder',),
'skadevolderen': ('skadevolder',),
'skadevolderer': ('skadevolder',),
'skadevolderne': ('skadevolder',),
'skarabeen': ('skarabé',),
'skarabeene': ('skarabé',),
'skarabeer': ('skarabé',),
'skarabé': ('skarabé',),
'skarabéen': ('skarabé',),
'skarabéene': ('skarabé',),
'skarabéer': ('skarabé',),
'skjørhet': ('skjørhet',),
'skjørheta': ('skjørhet',),
'skjørheten': ('skjørhet',),
'skjørhetene': ('skjørhet',),
'skjørheter': ('skjørhet',),
'skogbrukskandidat': ('skogbrukskandidat',),
'skogbrukskandidaten': ('skogbrukskandidat',),
'skogbrukskandidatene': ('skogbrukskandidat',),
'skogbrukskandidater': ('skogbrukskandidat',),
'skoleverk': ('skoleverk',),
'skoleverka': ('skoleverk',),
'skoleverkene': ('skoleverk',),
'skoleverker': ('skoleverk',),
'skoleverket': ('skoleverk',),
'slaglinja': ('slaglinje',),
'slaglinje': ('slaglinje',),
'slaglinjen': ('slaglinje',),
'slaglinjene': ('slaglinje',),
'slaglinjer': ('slaglinje',),
'slippers': ('slippers',),
'slippersen': ('slippers',),
'slippersene': ('slippers',),
'slipperser': ('slippers',),
'SMS': ('SMS',),
'smugling': ('smugling',),
'smuglinga': ('smugling',),
'smuglingen': ('smugling',),
'smuglingene': ('smugling',),
'smuglinger': ('smugling',),
'solbærtoddi': ('solbærtoddi',),
'solbærtoddien': ('solbærtoddi',),
'solbærtoddiene': ('solbærtoddi',),
'solbærtoddier': ('solbærtoddi',),
'sorbitol': ('sorbitol',),
'sorbitolen': ('sorbitol',),
'sorbitolene': ('sorbitol',),
'sorbitoler': ('sorbitol',),
'spelt': ('spelt',),
'spelten': ('spelt',),
'speltene': ('spelt',),
'spelter': ('spelt',),
'spesialavfall': ('spesialavfall',),
'spesialavfalla': ('spesialavfall',),
'spesialavfallene': ('spesialavfall',),
'spesialavfallet': ('spesialavfall',),
'spjær': ('spjær',),
'spjæra': ('spjær',),
'spjærene': ('spjær',),
'spjæret': ('spjær',),
'støtteapparat': ('støtteapparat',),
'støtteapparata': ('støtteapparat',),
'støtteapparatene': ('støtteapparat',),
'støtteapparater': ('støtteapparat',),
'støtteapparatet': ('støtteapparat',),
'støttebandasje': ('støttebandasje',),
'støttebandasjen': ('støttebandasje',),
'støttebandasjene': ('støttebandasje',),
'støttebandasjer': ('støttebandasje',),
'stamkafeen': ('stamkafé',),
'stamkafeene': ('stamkafé',),
'stamkafeer': ('stamkafé',),
'stamkafé': ('stamkafé',),
'stamkaféen': ('stamkafé',),
'stamkaféene': ('stamkafé',),
'stamkaféer': ('stamkafé',),
'stavefeil': ('stavefeil',),
'stavefeilen': ('stavefeil',),
'stavefeilene': ('stavefeil',),
'stem': ('stem',),
'stemmen': ('stem',),
'stemmene': ('stem',),
'stemmer': ('stem',),
'stevnedag': ('stevnedag',),
'stevnedagen': ('stevnedag',),
'stevnedagene': ('stevnedag',),
'stevnedager': ('stevnedag',),
'stevnemøta': ('stevnemøte',),
'stevnemøte': ('stevnemøte',),
'stevnemøtene': ('stevnemøte',),
'stevnemøter': ('stevnemøte',),
'stevnemøtet': ('stevnemøte',),
'stortingskomiteen': ('stortingskomité',),
'stortingskomiteene': ('stortingskomité',),
'stortingskomiteer': ('stortingskomité',),
'stortingskomité': ('stortingskomité',),
'stortingskomitéen': ('stortingskomité',),
'stortingskomitéene': ('stortingskomité',),
'stortingskomitéer': ('stortingskomité',),
'strass': ('strass',),
'strassen': ('strass',),
'strassene': ('strass',),
'strasser': ('strass',),
'stråling': ('stråling',),
'strålinga': ('stråling',),
'strålingen': ('stråling',),
'strålingene': ('stråling',),
'strålinger': ('stråling',),
'super-G': ('super-G',),
'systemerer': ('systemerer',),
'systemerere': ('systemerer',),
'systemereren': ('systemerer',),
'systemererer': ('systemerer',),
'systemererne': ('systemerer',),
'tagging': ('tagging',),
'tagginga': ('tagging',),
'taggingen': ('tagging',),
'taggingene': ('tagging',),
'tagginger': ('tagging',),
'tagning': ('tagning',),
'tagninga': ('tagning',),
'tagningen': ('tagning',),
'tagningene': ('tagning',),
'tagninger': ('tagning',),
'taking': ('taking',),
'takinga': ('taking',),
'takingen': ('taking',),
'takingene': ('taking',),
'takinger': ('taking',),
'talsperson': ('talsperson',),
'talspersonen': ('talsperson',),
'talspersonene': ('talsperson',),
'talspersoner': ('talsperson',),
'teatervitenskap': ('teatervitenskap',),
'teatervitenskapen': ('teatervitenskap',),
'teatervitenskapene': ('teatervitenskap',),
'teatervitenskaper': ('teatervitenskap',),
'tekster': ('tekster',),
'tekstere': ('tekster',),
'teksteren': ('tekster',),
'teksterer': ('tekster',),
'teksterne': ('tekster',),
'telefonsalg': ('telefonsalg',),
'telefonsalga': ('telefonsalg',),
'telefonsalgene': ('telefonsalg',),
'telefonsalget': ('telefonsalg',),
'telemarksski': ('telemarksski',),
'telemarksskia': ('telemarksski',),
'telemarksskien': ('telemarksski',),
'telemarksskiene': ('telemarksski',),
'telemarksskier': ('telemarksski',),
'termikk': ('termikk',),
'termikken': ('termikk',),
'termikkene': ('termikk',),
'termikker': ('termikk',),
'tilbyder': ('tilbyder',),
'tilbydere': ('tilbyder',),
'tilbyderen': ('tilbyder',),
'tilbyderer': ('tilbyder',),
'tilbyderne': ('tilbyder',),
'tilegnelse': ('tilegnelse',),
'tilegnelsen': ('tilegnelse',),
'tilegnelsene': ('tilegnelse',),
'tilegnelser': ('tilegnelse',),
'tinglysning': ('tinglysning',),
'tinglysninga': ('tinglysning',),
'tinglysningen': ('tinglysning',),
'tinglysningene': ('tinglysning',),
'tinglysninger': ('tinglysning',),
'tingrett': ('tingrett',),
'tingretten': ('tingrett',),
'tingrettene': ('tingrett',),
'tingretter': ('tingrett',),
'tipser': ('tipser',),
'tipsere': ('tipser',),
'tipseren': ('tipser',),
'tipserer': ('tipser',),
'tipserne': ('tipser',),
'tåkeheim': ('tåkeheim',),
'tåkeheimen': ('tåkeheim',),
'tåkeheimene': ('tåkeheim',),
'tåkeheimer': ('tåkeheim',),
'togstasjon': ('togstasjon',),
'togstasjonen': ('togstasjon',),
'togstasjonene': ('togstasjon',),
'togstasjoner': ('togstasjon',),
'tollbod': ('tollbod',),
'tollboden': ('tollbod',),
'tollbodene': ('tollbod',),
'tollboder': ('tollbod',),
'trøtting': ('trøtting',),
'trøttingen': ('trøtting',),
'trøttingene': ('trøtting',),
'trøttinger': ('trøtting',),
'trøtting': ('trøtting',),
'trøttinga': ('trøtting',),
'trøttingen': ('trøtting',),
'trøttingene': ('trøtting',),
'trøttinger': ('trøtting',),
'tradisjonsbærer': ('tradisjonsbærer',),
'tradisjonsbærere': ('tradisjonsbærer',),
'tradisjonsbæreren': ('tradisjonsbærer',),
'tradisjonsbærerer': ('tradisjonsbærer',),
'tradisjonsbærerne': ('tradisjonsbærer',),
'trafikksikring': ('trafikksikring',),
'trafikksikringa': ('trafikksikring',),
'trafikksikringen': ('trafikksikring',),
'trafikksikringene': ('trafikksikring',),
'trafikksikringer': ('trafikksikring',),
'traseen': ('trasé',),
'traseene': ('trasé',),
'traseer': ('trasé',),
'trasé': ('trasé',),
'traséen': ('trasé',),
'traséene': ('trasé',),
'traséer': ('trasé',),
'tredveåring': ('tredveåring',),
'tredveåringen': ('tredveåring',),
'tredveåringene': ('tredveåring',),
'tredveåringer': ('tredveåring',),
'tredveårskrig': ('tredveårskrig',),
'tredveårskrigen': ('tredveårskrig',),
'tredveårskrigene': ('tredveårskrig',),
'tredveårskriger': ('tredveårskrig',),
'trippelseier': ('trippelseier',),
'trippelseiere': ('trippelseier',),
'trippelseieren': ('trippelseier',),
'trippelseierne': ('trippelseier',),
'trippelseire': ('trippelseier',),
'trippelseirene': ('trippelseier',),
'trippelseirer': ('trippelseier',),
'trofea': ('trofé',),
'trofeen': ('trofé',),
'trofeene': ('trofé',),
'trofeer': ('trofé',),
'trofeet': ('trofé',),
'trofé': ('trofé',),
'troféa': ('trofé',),
'troféen': ('trofé',),
'troféene': ('trofé',),
'troféer': ('trofé',),
'troféet': ('trofé',),
'trykkpressa': ('trykkpresse',),
'trykkpresse': ('trykkpresse',),
'trykkpressen': ('trykkpresse',),
'trykkpressene': ('trykkpresse',),
'trykkpresser': ('trykkpresse',),
'tupeen': ('tupé',),
'tupeene': ('tupé',),
'tupeer': ('tupé',),
'tupé': ('tupé',),
'tupéen': ('tupé',),
'tupéene': ('tupé',),
'tupéer': ('tupé',),
'turlangrenn': ('turlangrenn',),
'turlangrenna': ('turlangrenn',),
'turlangrennene': ('turlangrenn',),
'turlangrennet': ('turlangrenn',),
'turneen': ('turné',),
'turneene': ('turné',),
'turneer': ('turné',),
'turné': ('turné',),
'turnéen': ('turné',),
'turnéene': ('turné',),
'turnéer': ('turné',),
'TV-kanal': ('TV-kanal',),
'TV-kanalen': ('TV-kanal',),
'TV-kanalene': ('TV-kanal',),
'TV-kanaler': ('TV-kanal',),
'tv-kanal': ('tv-kanal',),
'tv-kanalen': ('tv-kanal',),
'tv-kanalene': ('tv-kanal',),
'tv-kanaler': ('tv-kanal',),
'udugelighet': ('udugelighet',),
'udugeligheta': ('udugelighet',),
'udugeligheten': ('udugelighet',),
'udugelighetene': ('udugelighet',),
'udugeligheter': ('udugelighet',),
'undergrunnskultur': ('undergrunnskultur',),
'undergrunnskulturen': ('undergrunnskultur',),
'undergrunnskulturene': ('undergrunnskultur',),
'undergrunnskulturer': ('undergrunnskultur',),
'unnaluring': ('unnaluring',),
'unnaluringa': ('unnaluring',),
'unnaluringen': ('unnaluring',),
'unnaluringene': ('unnaluring',),
'unnaluringer': ('unnaluring',),
'unnasluntring': ('unnasluntring',),
'unnasluntringa': ('unnasluntring',),
'unnasluntringen': ('unnasluntring',),
'unnasluntringene': ('unnasluntring',),
'unnasluntringer': ('unnasluntring',),
'utblåsning': ('utblåsning',),
'utblåsninga': ('utblåsning',),
'utblåsningen': ('utblåsning',),
'utblåsningene': ('utblåsning',),
'utblåsninger': ('utblåsning',),
'utdanningsdepartement': ('utdanningsdepartement',),
'utdanningsdepartementa': ('utdanningsdepartement',),
'utdanningsdepartementene': ('utdanningsdepartement',),
'utdanningsdepartementer': ('utdanningsdepartement',),
'utdanningsdepartementet': ('utdanningsdepartement',),
'uteplass': ('uteplass',),
'uteplassen': ('uteplass',),
'uteplassene': ('uteplass',),
'uteplasser': ('uteplass',),
'uteservering': ('uteservering',),
'uteserveringa': ('uteservering',),
'uteserveringen': ('uteservering',),
'uteserveringene': ('uteservering',),
'uteserveringer': ('uteservering',),
'utlysning': ('utlysning',),
'utlysninga': ('utlysning',),
'utlysningen': ('utlysning',),
'utlysningene': ('utlysning',),
'utlysninger': ('utlysning',),
'uttakingskonkurranse': ('uttakingskonkurranse',),
'uttakingskonkurransen': ('uttakingskonkurranse',),
'uttakingskonkurransene': ('uttakingskonkurranse',),
'uttakingskonkurranser': ('uttakingskonkurranse',),
'valgkomiteen': ('valgkomité',),
'valgkomiteene': ('valgkomité',),
'valgkomiteer': ('valgkomité',),
'valgkomité': ('valgkomité',),
'valgkomitéen': ('valgkomité',),
'valgkomitéene': ('valgkomité',),
'valgkomitéer': ('valgkomité',),
'varamedlem': ('varamedlem',),
'varamedlemma': ('varamedlem',),
'varamedlemmene': ('varamedlem',),
'varamedlemmer': ('varamedlem',),
'varamedlemmet': ('varamedlem',),
'varieteen': ('varieté',),
'varieteene': ('varieté',),
'varieteer': ('varieté',),
'varieté': ('varieté',),
'varietéen': ('varieté',),
'varietéene': ('varieté',),
'varietéer': ('varieté',),
'veddeløpsbane': ('veddeløpsbane',),
'veddeløpsbanen': ('veddeløpsbane',),
'veddeløpsbanene': ('veddeløpsbane',),
'veddeløpsbaner': ('veddeløpsbane',),
'veglys': ('veglys',),
'veglysa': ('veglys',),
'veglysene': ('veglys',),
'veglyset': ('veglys',),
'vegskulder': ('vegskulder',),
'vegskulderen': ('vegskulder',),
'vegskuldra': ('vegskulder',),
'vegskuldre': ('vegskulder',),
'vegskuldrene': ('vegskulder',),
'vegskuldrer': ('vegskulder',),
'veilys': ('veilys',),
'veilysa': ('veilys',),
'veilysene': ('veilys',),
'veilyset': ('veilys',),
'veiskulder': ('veiskulder',),
'veiskulderen': ('veiskulder',),
'veiskuldra': ('veiskulder',),
'veiskuldre': ('veiskulder',),
'veiskuldrene': ('veiskulder',),
'veiskuldrer': ('veiskulder',),
'veitraseen': ('veitrasé',),
'veitraseene': ('veitrasé',),
'veitraseer': ('veitrasé',),
'veitrasé': ('veitrasé',),
'veitraséen': ('veitrasé',),
'veitraséene': ('veitrasé',),
'veitraséer': ('veitrasé',),
'verdiskaping': ('verdiskaping',),
'verdiskapinga': ('verdiskaping',),
'verdiskapingen': ('verdiskaping',),
'verdiskapingene': ('verdiskaping',),
'verdiskapinger': ('verdiskaping',),
'verdiskapning': ('verdiskapning',),
'verdiskapninga': ('verdiskapning',),
'verdiskapningen': ('verdiskapning',),
'verdiskapningene': ('verdiskapning',),
'verdiskapninger': ('verdiskapning',),
'verdisyn': ('verdisyn',),
'verdisyna': ('verdisyn',),
'verdisynene': ('verdisyn',),
'verdisynet': ('verdisyn',),
'vernehjelm': ('vernehjelm',),
'vernehjelmen': ('vernehjelm',),
'vernehjelmene': ('vernehjelm',),
'vernehjelmer': ('vernehjelm',),
'vinkelsliper': ('vinkelsliper',),
'vinkelslipere': ('vinkelsliper',),
'vinkelsliperen': ('vinkelsliper',),
'vinkelsliperer': ('vinkelsliper',),
'vinkelsliperne': ('vinkelsliper',),
'vinylplata': ('vinylplate',),
'vinylplate': ('vinylplate',),
'vinylplaten': ('vinylplate',),
'vinylplatene': ('vinylplate',),
'vinylplater': ('vinylplate',),
'vårrull': ('vårrull',),
'vårrullen': ('vårrull',),
'vårrullene': ('vårrull',),
'vårruller': ('vårrull',),
'yrkesrettledning': ('yrkesrettledning',),
'yrkesrettledninga': ('yrkesrettledning',),
'yrkesrettledningen': ('yrkesrettledning',),
'yrkesrettledningene': ('yrkesrettledning',),
'yrkesrettledninger': ('yrkesrettledning',),
'zoom': ('zoom',),
'zoomen': ('zoom',),
'zoomene': ('zoom',),
'zoomer': ('zoom',),
'ønolog': ('ønolog',),
'ønologen': ('ønolog',),
'ønologene': ('ønolog',),
'ønologer': ('ønolog',),
'ønologi': ('ønologi',),
'ønologien': ('ønologi',),
'ønologiene': ('ønologi',),
'ønologier': ('ønologi',),
'øyespleis': ('øyespleis',),
'øyespleisen': ('øyespleis',),
'øyespleisene': ('øyespleis',),
'øyespleiser': ('øyespleis',),
'Østen': ('Østen',),
'åndrikhet': ('åndrikhet',),
'åndrikheta': ('åndrikhet',),
'åndrikheten': ('åndrikhet',),
'åndrikhetene': ('åndrikhet',),
'åndrikheter': ('åndrikhet',),
'kick': ('kick',),
'kicka': ('kick',),
'kickene': ('kick',),
'kicket': ('kick',),
'Kong': ('kong',),
'kong': ('kong',),
'healer': ('healer',),
'healere': ('healer',),
'healeren': ('healer',),
'healerer': ('healer',),
'healerne': ('healer',),
'barsking': ('barsking',),
'barskinga': ('barsking',),
'barskingen': ('barsking',),
'barskingene': ('barsking',),
'barskinger': ('barsking',),
'bayerøl': ('bayerøl',),
'bayerølen': ('bayerøl',),
'bayerølene': ('bayerøl',),
'beinka': ('beinke',),
'beinke': ('beinke',),
'beinken': ('beinke',),
'beinkene': ('beinke',),
'beinker': ('beinke',),
'bel': ('bel',),
'bela': ('bel',),
'belene': ('bel',),
'belet': ('bel',),
'benka': ('benke',),
'benke': ('benke',),
'benken': ('benke',),
'benkene': ('benke',),
'benker': ('benke',),
'biting': ('biting',),
'bitinga': ('biting',),
'bitingen': ('biting',),
'bitingene': ('biting',),
'bitinger': ('biting',),
'blinding': ('blinding',),
'blindinga': ('blinding',),
'blindingen': ('blinding',),
'blindingene': ('blinding',),
'blindinger': ('blinding',),
'bokkøl': ('bokkøl',),
'bokkølen': ('bokkøl',),
'bokkølene': ('bokkøl',),
'boksøl': ('boksøl',),
'boksølen': ('boksøl',),
'boksølene': ('boksøl',),
'botnskrapa': ('botnskrape',),
'botnskrape': ('botnskrape',),
'botnskrapen': ('botnskrape',),
'botnskrapene': ('botnskrape',),
'botnskraper': ('botnskrape',),
'bunnskrapa': ('bunnskrape',),
'bunnskrape': ('bunnskrape',),
'bunnskrapen': ('bunnskrape',),
'bunnskrapene': ('bunnskrape',),
'bunnskraper': ('bunnskrape',),
'bytting': ('bytting',),
'byttinga': ('bytting',),
'byttingen': ('bytting',),
'byttingene': ('bytting',),
'byttinger': ('bytting',),
'cubansk': ('cubansk',),
'cubansken': ('cubansk',),
'cubanskene': ('cubansk',),
'cubansker': ('cubansk',),
'då': ('då',),
'dåa': ('då',),
'dåen': ('då',),
'dåene': ('då',),
'dåer': ('då',),
'då': ('då',),
'dåa': ('då',),
'dåen': ('då',),
'dåene': ('då',),
'dåer': ('då',),
'eling': ('eling',),
'elinga': ('eling',),
'elingen': ('eling',),
'elingene': ('eling',),
'elinger': ('eling',),
'finansråd': ('finansråd',),
'finansråda': ('finansråd',),
'finansrådene': ('finansråd',),
'finansrådet': ('finansråd',),
'fløy': ('fløy',),
'fløya': ('fløy',),
'fløyene': ('fløy',),
'fløyet': ('fløy',),
'flikk': ('flikk',),
'flikka': ('flikk',),
'flikkene': ('flikk',),
'flikket': ('flikk',),
'floing': ('floing',),
'floinga': ('floing',),
'floingen': ('floing',),
'floingene': ('floing',),
'floinger': ('floing',),
'folkeferd': ('folkeferd',),
'folkeferda': ('folkeferd',),
'folkeferden': ('folkeferd',),
'folkeferdene': ('folkeferd',),
'folkeferder': ('folkeferd',),
'fryseri': ('fryseri',),
'fryseria': ('fryseri',),
'fryserien': ('fryseri',),
'fryseriene': ('fryseri',),
'fryserier': ('fryseri',),
'gin': ('gin',),
'gina': ('gin',),
'ginene': ('gin',),
'ginet': ('gin',),
'gjø': ('gjø',),
'gjøa': ('gjø',),
'gjøen': ('gjø',),
'gjøene': ('gjø',),
'gjøer': ('gjø',),
'godt': ('godt',),
'godtene': ('godt',),
'godter': ('godt',),
'godtet': ('godt',),
'grasing': ('grasing',),
'grasinga': ('grasing',),
'grasingen': ('grasing',),
'grasingene': ('grasing',),
'grasinger': ('grasing',),
'gulland': ('gulland',),
'gullanda': ('gulland',),
'gullanden': ('gulland',),
'gullendene': ('gulland',),
'gullender': ('gulland',),
'heilmjølk': ('heilmjølk',),
'heilmjølka': ('heilmjølk',),
'heilmjølken': ('heilmjølk',),
'heilmjølkene': ('heilmjølk',),
'heilmjølker': ('heilmjølk',),
'herd': ('herd',),
'herden': ('herd',),
'herdene': ('herd',),
'herder': ('herd',),
'herk': ('herk',),
'herken': ('herk',),
'herkene': ('herk',),
'herker': ('herk',),
'himling': ('himling',),
'himlinga': ('himling',),
'himlingen': ('himling',),
'himlingene': ('himling',),
'himlinger': ('himling',),
'iling': ('iling',),
'ilinga': ('iling',),
'ilingen': ('iling',),
'ilingene': ('iling',),
'ilinger': ('iling',),
'innbygd': ('innbygd',),
'innbygda': ('innbygd',),
'innbygden': ('innbygd',),
'innbygdene': ('innbygd',),
'innbygder': ('innbygd',),
'iterativ': ('iterativ',),
'iterativen': ('iterativ',),
'iterativene': ('iterativ',),
'iterativer': ('iterativ',),
'juleøl': ('juleøl',),
'juleølen': ('juleøl',),
'juleølene': ('juleøl',),
'kil': ('kil',),
'kila': ('kil',),
'kilene': ('kil',),
'kilet': ('kil',),
'kjerv': ('kjerv',),
'kjerven': ('kjerv',),
'kjervene': ('kjerv',),
'kjerver': ('kjerv',),
'kløkk': ('kløkk',),
'kløkka': ('kløkk',),
'kløkken': ('kløkk',),
'kløkkene': ('kløkk',),
'kløkker': ('kløkk',),
'kløkket': ('kløkk',),
'kløyva': ('kløyve',),
'kløyve': ('kløyve',),
'kløyven': ('kløyve',),
'kløyvene': ('kløyve',),
'kløyver': ('kløyve',),
'klekk': ('klekk',),
'klekka': ('klekk',),
'klekken': ('klekk',),
'klekkene': ('klekk',),
'klekker': ('klekk',),
'klekket': ('klekk',),
'klining': ('klining',),
'klininga': ('klining',),
'kliningen': ('klining',),
'kliningene': ('klining',),
'klininger': ('klining',),
'knyting': ('knyting',),
'knytinga': ('knyting',),
'knytingen': ('knyting',),
'knytingene': ('knyting',),
'knytinger': ('knyting',),
'kriminalpoliti': ('kriminalpoliti',),
'kriminalpolitien': ('kriminalpoliti',),
'kriminalpolitiene': ('kriminalpoliti',),
'kriminalpolitier': ('kriminalpoliti',),
'krymp': ('krymp',),
'krympa': ('krymp',),
'krympene': ('krymp',),
'krympet': ('krymp',),
'kubansk': ('kubansk',),
'kubansken': ('kubansk',),
'kubanskene': ('kubansk',),
'kubansker': ('kubansk',),
'kvelving': ('kvelving',),
'kvelvinga': ('kvelving',),
'kvelvingen': ('kvelving',),
'kvelvingene': ('kvelving',),
'kvelvinger': ('kvelving',),
'kyt': ('kyt',),
'kyta': ('kyt',),
'kyten': ('kyt',),
'kytene': ('kyt',),
'kyter': ('kyt',),
'lader': ('lader',),
'ladere': ('lader',),
'laderen': ('lader',),
'laderer': ('lader',),
'laderne': ('lader',),
'lasting': ('lasting',),
'lastinga': ('lasting',),
'lastingen': ('lasting',),
'lastingene': ('lasting',),
'lastinger': ('lasting',),
'lating': ('lating',),
'latinga': ('lating',),
'latingen': ('lating',),
'latingene': ('lating',),
'latinger': ('lating',),
'leding': ('leding',),
'ledinga': ('leding',),
'ledingen': ('leding',),
'ledingene': ('leding',),
'ledinger': ('leding',),
'lettøl': ('lettøl',),
'lettølen': ('lettøl',),
'lettølene': ('lettøl',),
'lokalplan': ('lokalplan',),
'lokalplanen': ('lokalplan',),
'lokalplanene': ('lokalplan',),
'lokalplaner': ('lokalplan',),
'lovprising': ('lovprising',),
'lovprisinga': ('lovprising',),
'lovprisingen': ('lovprising',),
'lovprisingene': ('lovprising',),
'lovprisinger': ('lovprising',),
'luring': ('luring',),
'luringa': ('luring',),
'luringen': ('luring',),
'luringene': ('luring',),
'luringer': ('luring',),
'lysning': ('lysning',),
'lysninga': ('lysning',),
'lysningen': ('lysning',),
'lysningene': ('lysning',),
'lysninger': ('lysning',),
'messing': ('messing',),
'messinga': ('messing',),
'messingen': ('messing',),
'messingene': ('messing',),
'messinger': ('messing',),
'militær': ('militær',),
'militæren': ('militær',),
'militærene': ('militær',),
'militærer': ('militær',),
'modal': ('modal',),
'modalen': ('modal',),
'modalene': ('modal',),
'modaler': ('modal',),
'nabokrangel': ('nabokrangel',),
'nabokrangelen': ('nabokrangel',),
'nabokrangelet': ('nabokrangel',),
'nabokrangla': ('nabokrangel',),
'nabokranglene': ('nabokrangel',),
'nabokrangler': ('nabokrangel',),
'nabokranglet': ('nabokrangel',),
'niding': ('niding',),
'nidinga': ('niding',),
'nidingen': ('niding',),
'nidingene': ('niding',),
'nidinger': ('niding',),
'nupping': ('nupping',),
'nuppinga': ('nupping',),
'nuppingen': ('nupping',),
'nuppingene': ('nupping',),
'nuppinger': ('nupping',),
'Ola': ('Ola',),
'omlasting': ('omlasting',),
'omlastinga': ('omlasting',),
'omlastingen': ('omlasting',),
'omlastingene': ('omlasting',),
'omlastinger': ('omlasting',),
'ordenspoliti': ('ordenspoliti',),
'ordenspolitien': ('ordenspoliti',),
'ordenspolitiene': ('ordenspoliti',),
'ordenspolitier': ('ordenspoliti',),
'Per': ('Per',),
'pilsnerøl': ('pilsnerøl',),
'pilsnerølen': ('pilsnerøl',),
'pilsnerølene': ('pilsnerøl',),
'pjusk': ('pjusk',),
'pjusken': ('pjusk',),
'pjuskene': ('pjusk',),
'pjusker': ('pjusk',),
'pseudonym': ('pseudonym',),
'pseudonymen': ('pseudonym',),
'pseudonymene': ('pseudonym',),
'pseudonymer': ('pseudonym',),
'psevdonym': ('psevdonym',),
'psevdonymen': ('psevdonym',),
'psevdonymene': ('psevdonym',),
'psevdonymer': ('psevdonym',),
'pusling': ('pusling',),
'puslinga': ('pusling',),
'puslingen': ('pusling',),
'puslingene': ('pusling',),
'puslinger': ('pusling',),
'rapping': ('rapping',),
'rappinga': ('rapping',),
'rappingen': ('rapping',),
'rappingene': ('rapping',),
'rappinger': ('rapping',),
'runding': ('runding',),
'rundinga': ('runding',),
'rundingen': ('runding',),
'rundingene': ('runding',),
'rundinger': ('runding',),
'rustning': ('rustning',),
'rustninga': ('rustning',),
'rustningen': ('rustning',),
'rustningene': ('rustning',),
'rustninger': ('rustning',),
'shopping': ('shopping',),
'shoppinga': ('shopping',),
'shoppingen': ('shopping',),
'shoppingene': ('shopping',),
'shoppinger': ('shopping',),
'sikling': ('sikling',),
'siklinga': ('sikling',),
'siklingen': ('sikling',),
'siklingene': ('sikling',),
'siklinger': ('sikling',),
'skål': ('skål',),
'skålen': ('skål',),
'skålene': ('skål',),
'skåler': ('skål',),
'spik': ('spik',),
'spika': ('spik',),
'spikene': ('spik',),
'spiket': ('spik',),
'støa': ('støe',),
'støe': ('støe',),
'støene': ('støe',),
'støer': ('støe',),
'støet': ('støe',),
'svarteper': ('svarteper',),
'svarteperen': ('svarteper',),
'svarteperene': ('svarteper',),
'svarteperer': ('svarteper',),
'topp-plan': ('topp-plan',),
'topp-planen': ('topp-plan',),
'topp-planene': ('topp-plan',),
'topp-planer': ('topp-plan',),
'topplan': ('topplan',),
'topplanen': ('topplan',),
'topplanene': ('topplan',),
'topplaner': ('topplan',),
'trafikkpoliti': ('trafikkpoliti',),
'trafikkpolitien': ('trafikkpoliti',),
'trafikkpolitiene': ('trafikkpoliti',),
'trafikkpolitier': ('trafikkpoliti',),
'trase': ('trase',),
'traseen': ('trase',),
'traseene': ('trase',),
'traseer': ('trase',),
'tukling': ('tukling',),
'tuklinga': ('tukling',),
'tuklingen': ('tukling',),
'tuklingene': ('tukling',),
'tuklinger': ('tukling',),
'tusling': ('tusling',),
'tuslinga': ('tusling',),
'tuslingen': ('tusling',),
'tuslingene': ('tusling',),
'tuslinger': ('tusling',),
'utrykningspoliti': ('utrykningspoliti',),
'utrykningspolitien': ('utrykningspoliti',),
'utrykningspolitiene': ('utrykningspoliti',),
'utrykningspolitier': ('utrykningspoliti',),
'vørterøl': ('vørterøl',),
'vørterølen': ('vørterøl',),
'vørterølene': ('vørterøl',),
'viktigper': ('viktigper',),
'viktigperen': ('viktigper',),
'viktigperene': ('viktigper',),
'viktigperer': ('viktigper',),
'vinkling': ('vinkling',),
'vinklinga': ('vinkling',),
'vinklingen': ('vinkling',),
'vinklingene': ('vinkling',),
'vinklinger': ('vinkling',),
'Per': ('Per',),
'nerd': ('nerd',),
'nerden': ('nerd',),
'nerdene': ('nerd',),
'nerder': ('nerd',),
'valium': ('valium',),
'valiuma': ('valium',),
'valiumen': ('valium',),
'valiumene': ('valium',),
'valiumet': ('valium',),
'bonnløysa': ('bonnløyse',),
'bonnløyse': ('bonnløyse',),
'bonnløysen': ('bonnløyse',),
'bonnløysene': ('bonnløyse',),
'bonnløyser': ('bonnløyse',),
'avisklypp': ('avisklypp',),
'avisklyppa': ('avisklypp',),
'avisklyppene': ('avisklypp',),
'avisklyppet': ('avisklypp',),
'avisklypparkiv': ('avisklypparkiv',),
'avisklypparkiva': ('avisklypparkiv',),
'avisklypparkivene': ('avisklypparkiv',),
'avisklypparkiver': ('avisklypparkiv',),
'avisklypparkivet': ('avisklypparkiv',),
'e-mail': ('e-mail',),
'e-mailen': ('e-mail',),
'e-mailene': ('e-mail',),
'e-mailer': ('e-mail',),
'gjentagelse': ('gjentagelse',),
'gjentagelsen': ('gjentagelse',),
'gjentagelsene': ('gjentagelse',),
'gjentagelser': ('gjentagelse',),
'graslauktua': ('graslauktue',),
'graslauktue': ('graslauktue',),
'graslauktuen': ('graslauktue',),
'graslauktuene': ('graslauktue',),
'graslauktuer': ('graslauktue',),
'gresslauktua': ('gresslauktue',),
'gresslauktue': ('gresslauktue',),
'gresslauktuen': ('gresslauktue',),
'gresslauktuene': ('gresslauktue',),
'gresslauktuer': ('gresslauktue',),
'iakttagelse': ('iakttagelse',),
'iakttagelsen': ('iakttagelse',),
'iakttagelsene': ('iakttagelse',),
'iakttagelser': ('iakttagelse',),
'meldrøya': ('meldrøye',),
'meldrøye': ('meldrøye',),
'meldrøyen': ('meldrøye',),
'meldrøyene': ('meldrøye',),
'meldrøyer': ('meldrøye',),
'overtagelse': ('overtagelse',),
'overtagelsen': ('overtagelse',),
'overtagelsene': ('overtagelse',),
'overtagelser': ('overtagelse',),
'uttagelse': ('uttagelse',),
'uttagelsen': ('uttagelse',),
'uttagelsene': ('uttagelse',),
'uttagelser': ('uttagelse',),
'vedtagelse': ('vedtagelse',),
'vedtagelsen': ('vedtagelse',),
'vedtagelsene': ('vedtagelse',),
'vedtagelser': ('vedtagelse',),
'gobelin': ('gobelin',),
'gobelina': ('gobelin',),
'gobelinene': ('gobelin',),
'gobeliner': ('gobelin',),
'gobelinet': ('gobelin',),
'Pål': ('Pål',),
'dart': ('dart',),
'darten': ('dart',),
'dartene': ('dart',),
'darter': ('dart',),
'catwalk': ('catwalk',),
'catwalken': ('catwalk',),
'catwalkene': ('catwalk',),
'catwalker': ('catwalk',),
'mail': ('mail',),
'mailen': ('mail',),
'mailene': ('mail',),
'mailer': ('mail',),
'cd': ('cd',),
'cden': ('cd',),
'cdene': ('cd',),
'cder': ('cd',),
'tights': ('tights',),
'tightsen': ('tights',),
'tightsene': ('tights',),
'tightser': ('tights',),
'DVD': ('DVD',),
'DVDen': ('DVD',),
'DVDene': ('DVD',),
'DVDer': ('DVD',),
'ecstasy': ('ecstasy',),
'ecstasyen': ('ecstasy',),
'ecstasyene': ('ecstasy',),
'ecstasyer': ('ecstasy',),
'tekno': ('tekno',),
'teknoen': ('tekno',),
'teknoene': ('tekno',),
'teknoer': ('tekno',),
'techno': ('techno',),
'technoen': ('techno',),
'technoene': ('techno',),
'technoer': ('techno',),
'euro': ('euro',),
'euroen': ('euro',),
'euroene': ('euro',),
'euroer': ('euro',),
'samfunnsforsking': ('samfunnsforsking',),
'samfunnsforskingen': ('samfunnsforsking',),
'samfunnsforskingene': ('samfunnsforsking',),
'samfunnsforskinger': ('samfunnsforsking',),
'skipslengd': ('skipslengd',),
'skipslengda': ('skipslengd',),
'skipslengden': ('skipslengd',),
'skipslengdene': ('skipslengd',),
'skipslengder': ('skipslengd',),
'skriftlesing': ('skriftlesing',),
'skriftlesinga': ('skriftlesing',),
'skriftlesingen': ('skriftlesing',),
'skriftlesingene': ('skriftlesing',),
'skriftlesinger': ('skriftlesing',),
'sladrekompas': ('sladrekompas',),
'sladrekompasa': ('sladrekompas',),
'sladrekompasen': ('sladrekompas',),
'sladrekompasene': ('sladrekompas',),
'sladrekompaser': ('sladrekompas',),
'sladrekompaset': ('sladrekompas',),
'sledemei': ('sledemei',),
'sledemeien': ('sledemei',),
'sledemeiene': ('sledemei',),
'sledemeier': ('sledemei',),
'slektsforsking': ('slektsforsking',),
'slektsforskinga': ('slektsforsking',),
'slektsforskingen': ('slektsforsking',),
'slektsforskingene': ('slektsforsking',),
'slektsforskinger': ('slektsforsking',),
'slingrekøy': ('slingrekøy',),
'slingrekøya': ('slingrekøy',),
'slingrekøyen': ('slingrekøy',),
'slingrekøyene': ('slingrekøy',),
'slingrekøyer': ('slingrekøy',),
'tagger': ('tagger',),
'taggere': ('tagger',),
'taggeren': ('tagger',),
'taggerer': ('tagger',),
'taggerne': ('tagger',),
'lunnende': ('lunnende',),
'da capo': ('da capo',),
'da capoa': ('da capo',),
'da capoene': ('da capo',),
'da capoer': ('da capo',),
'da capoet': ('da capo',),
'høgoktanbensin': ('høgoktanbensin',),
'høgoktanbensinen': ('høgoktanbensin',),
'høgoktanbensinene': ('høgoktanbensin',),
'høgoktanbensiner': ('høgoktanbensin',),
'dvd': ('dvd',),
'dvden': ('dvd',),
'dvdene': ('dvd',),
'dvder': ('dvd',),
'hiphop': ('hiphop',),
'hiphopen': ('hiphop',),
'hiphopene': ('hiphop',),
'hiphoper': ('hiphop',),
'Internett': ('Internett',),
'Internettet': ('Internettet',),
'kikk': ('kikk',),
'kikka': ('kikk',),
'kikket': ('kikk',),
'daks': ('daks',),
'daksen': ('daks',),
'daksene': ('daks',),
'dakser': ('daks',),
'masokisme': ('masokisme',),
'masokismen': ('masokisme',),
'masokismene': ('masokisme',),
'masokismer': ('masokisme',),
'masokist': ('masokist',),
'masokisten': ('masokist',),
'masokistene': ('masokist',),
'masokister': ('masokist',),
'sadomasokisme': ('sadomasokisme',),
'sadomasokismen': ('sadomasokisme',),
'sadomasokismene': ('sadomasokisme',),
'sadomasokismer': ('sadomasokisme',),
'sadomasokist': ('sadomasokist',),
'sadomasokisten': ('sadomasokist',),
'sadomasokistene': ('sadomasokist',),
'sadomasokister': ('sadomasokist',),
'nonsjalanse': ('nonsjalanse',),
'nonsjalansen': ('nonsjalanse',),
'nonsjalansene': ('nonsjalanse',),
'nonsjalanser': ('nonsjalanse',),
'gimmik': ('gimmik',),
'gimmiken': ('gimmik',),
'gimmikene': ('gimmik',),
'gimmiker': ('gimmik',),
'hikkory': ('hikkory',),
'hikkoryen': ('hikkory',),
'hikkoryene': ('hikkory',),
'hikkoryer': ('hikkory',),
'hikkoryski': ('hikkoryski',),
'hikkoryskia': ('hikkoryski',),
'hikkoryskien': ('hikkoryski',),
'hikkoryskiene': ('hikkoryski',),
'hikkoryskier': ('hikkoryski',),
'hikkorysåle': ('hikkorysåle',),
'hikkorysålen': ('hikkorysåle',),
'hikkorysålene': ('hikkorysåle',),
'hikkorysåler': ('hikkorysåle',),
'rekkert': ('rekkert',),
'rekkerten': ('rekkert',),
'rekkertene': ('rekkert',),
'rekkerter': ('rekkert',),
'tennisrekkert': ('tennisrekkert',),
'tennisrekkerten': ('tennisrekkert',),
'tennisrekkertene': ('tennisrekkert',),
'tennisrekkerter': ('tennisrekkert',),
'snaks': ('snaks',),
'snaksen': ('snaks',),
'snaksene': ('snaks',),
'snakser': ('snaks',),
'sørv': ('sørv',),
'sørven': ('sørv',),
'sørvene': ('sørv',),
'sørver': ('sørv',),
'sørver': ('sørver',),
'sørvere': ('sørver',),
'sørveren': ('sørver',),
'sørverer': ('sørver',),
'sørverne': ('sørver',),
'sellulitt': ('sellulitt',),
'sellulitten': ('sellulitt',),
'sellulittene': ('sellulitt',),
'sellulitter': ('sellulitt',),
'cellulitt': ('cellulitt',),
'cellulitten': ('cellulitt',),
'cellulittene': ('cellulitt',),
'cellulitter': ('cellulitt',),
'brunevara': ('brunevare',),
'brunevare': ('brunevare',),
'brunevaren': ('brunevare',),
'brunevarene': ('brunevare',),
'brunevarer': ('brunevare',),
'innmatpølsa': ('innmatpølse',),
'innmatpølse': ('innmatpølse',),
'innmatpølsen': ('innmatpølse',),
'innmatpølsene': ('innmatpølse',),
'innmatpølser': ('innmatpølse',),
'innmatspølsa': ('innmatspølse',),
'innmatspølse': ('innmatspølse',),
'innmatspølsen': ('innmatspølse',),
'innmatspølsene': ('innmatspølse',),
'innmatspølser': ('innmatspølse',),
'passepartout': ('passepartout',),
'passepartouten': ('passepartout',),
'passepartoutene': ('passepartout',),
'passepartouter': ('passepartout',),
'sauebukk': ('sauebukk',),
'sauebukken': ('sauebukk',),
'sauebukkene': ('sauebukk',),
'sauebukker': ('sauebukk',),
'sauelam': ('sauelam',),
'sauelamma': ('sauelam',),
'sauelammene': ('sauelam',),
'sauelammet': ('sauelam',),
'kause': ('kause',),
'kausen': ('kause',),
'kausene': ('kause',),
'kauser': ('kause',),
'tsjador': ('tsjador',),
'tsjadoren': ('tsjador',),
'tsjadorene': ('tsjador',),
'tsjadorer': ('tsjador',),
'tunell': ('tunell',),
'tunellen': ('tunell',),
'tunellene': ('tunell',),
'tuneller': ('tunell',),
'tympana': ('tympanon',),
'tympanaene': ('tympanon',),
'tympanene': ('tympanon',),
'tympaner': ('tympanon',),
'tympanon': ('tympanon',),
'tympanonet': ('tympanon',),
'øredobb': ('øredobb',),
'øredobba': ('øredobb',),
'øredobben': ('øredobb',),
'øredobbene': ('øredobb',),
'øredobber': ('øredobb',),
'boltit': ('boltit',),
'boltiten': ('boltit',),
'boltitene': ('boltit',),
'boltiter': ('boltit',),
'glysin': ('glysin',),
'glysinen': ('glysin',),
'glysinene': ('glysin',),
'glysiner': ('glysin',),
'sausenebb': ('sausenebb',),
'sausenebba': ('sausenebb',),
'sausenebbene': ('sausenebb',),
'sausenebbet': ('sausenebb',),
'smørnebba': ('smørnebbe',),
'smørnebbe': ('smørnebbe',),
'smørnebben': ('smørnebbe',),
'smørnebbene': ('smørnebbe',),
'smørnebber': ('smørnebbe',),
'smørnebb': ('smørnebb',),
'smørnebba': ('smørnebb',),
'smørnebben': ('smørnebb',),
'smørnebbene': ('smørnebb',),
'smørnebber': ('smørnebb',),
'tørråte': ('tørråte',),
'tørråten': ('tørråte',),
'tørråtene': ('tørråte',),
'tørråter': ('tørråte',),
'fikkel': ('fikkel',),
'fikkelet': ('fikkel',),
'fikla': ('fikkel',),
'fiklene': ('fikkel',),
'fiklet': ('fikkel',),
'juggel': ('juggel',),
'juggelet': ('juggel',),
'jugla': ('juggel',),
'juglene': ('juggel',),
'juglet': ('juggel',),
'kjekkel': ('kjekkel',),
'kjekkelet': ('kjekkel',),
'kjekla': ('kjekkel',),
'kjeklene': ('kjekkel',),
'kjeklet': ('kjekkel',),
'let': ('let',),
'leten': ('let',),
'letene': ('let',),
'leter': ('let',),
'hamlet': ('hamlet',),
'hamleten': ('hamlet',),
'hamletene': ('hamlet',),
'hamleter': ('hamlet',),
'ruggel': ('ruggel',),
'ruggelet': ('ruggel',),
'rugla': ('ruggel',),
'rugl': ('rugl',),
'rugla': ('rugl',),
'ruglene': ('rugl',),
'ruglet': ('rugl',),
'adferdsforskning': ('adferdsforskning',),
'adferdsforskninga': ('adferdsforskning',),
'adferdsforskningen': ('adferdsforskning',),
'adferdsforskningene': ('adferdsforskning',),
'adferdsforskninger': ('adferdsforskning',),
'adferdsforsking': ('adferdsforsking',),
'adferdsforskinga': ('adferdsforsking',),
'adferdsforskingen': ('adferdsforsking',),
'adferdsforskingene': ('adferdsforsking',),
'adferdsforskinger': ('adferdsforsking',),
'adferdsforstyrrelse': ('adferdsforstyrrelse',),
'adferdsforstyrrelsen': ('adferdsforstyrrelse',),
'adferdsforstyrrelsene': ('adferdsforstyrrelse',),
'adferdsforstyrrelser': ('adferdsforstyrrelse',),
'adferdsmønster': ('adferdsmønster',),
'adferdsmønsteret': ('adferdsmønster',),
'adferdsmønstra': ('adferdsmønster',),
'adferdsmønstre': ('adferdsmønster',),
'adferdsmønstrene': ('adferdsmønster',),
'adferdsmønstret': ('adferdsmønster',),
'adferdsnorm': ('adferdsnorm',),
'adferdsnormen': ('adferdsnorm',),
'adferdsnormene': ('adferdsnorm',),
'adferdsnormer': ('adferdsnorm',),
'adferdspsykologi': ('adferdspsykologi',),
'adferdspsykologien': ('adferdspsykologi',),
'adferdspsykologiene': ('adferdspsykologi',),
'adferdspsykologier': ('adferdspsykologi',),
'adferdsterapi': ('adferdsterapi',),
'adferdsterapien': ('adferdsterapi',),
'adferdsterapiene': ('adferdsterapi',),
'adferdsterapier': ('adferdsterapi',),
'adferdsvanske': ('adferdsvanske',),
'adferdsvansken': ('adferdsvanske',),
'adferdsvanskene': ('adferdsvanske',),
'adferdsvansker': ('adferdsvanske',),
'adkomstdokument': ('adkomstdokument',),
'adkomstdokumenta': ('adkomstdokument',),
'adkomstdokumentene': ('adkomstdokument',),
'adkomstdokumenter': ('adkomstdokument',),
'adkomstdokumentet': ('adkomstdokument',),
'adkomstvei': ('adkomstvei',),
'adkomstveien': ('adkomstvei',),
'adkomstveiene': ('adkomstvei',),
'adkomstveier': ('adkomstvei',),
'adkomstveg': ('adkomstveg',),
'adkomstvegen': ('adkomstveg',),
'adkomstvegene': ('adkomstveg',),
'adkomstveger': ('adkomstveg',),
'adspredelse': ('adspredelse',),
'adspredelsen': ('adspredelse',),
'adspredelsene': ('adspredelse',),
'adspredelser': ('adspredelse',),
'skuvseng': ('skuvseng',),
'skuvsenga': ('skuvseng',),
'skuvsengen': ('skuvseng',),
'skuvsengene': ('skuvseng',),
'skuvsenger': ('skuvseng',),
'træl': ('træl',),
'trælen': ('træl',),
'trælene': ('træl',),
'træler': ('træl',),
'skinnving': ('skinnving',),
'skinnvingen': ('skinnving',),
'skinnvingene': ('skinnving',),
'skinnvinger': ('skinnving',),
'skinnvinge': ('skinnvinge',),
'skinnvingen': ('skinnvinge',),
'skinnvingene': ('skinnvinge',),
'skinnvinger': ('skinnvinge',),
'anstøtssten': ('anstøtssten',),
'anstøtsstenen': ('anstøtssten',),
'anstøtsstenene': ('anstøtssten',),
'anstøtsstener': ('anstøtssten',),
'berserkergang': ('berserkergang',),
'berserkergangen': ('berserkergang',),
'berserkergangene': ('berserkergang',),
'berserkerganger': ('berserkergang',),
'boknafisk': ('boknafisk',),
'boknafisken': ('boknafisk',),
'boknafiskene': ('boknafisk',),
'boknafisker': ('boknafisk',),
'boknasild': ('boknasild',),
'boknasilda': ('boknasild',),
'boknasilden': ('boknasild',),
'boknasildene': ('boknasild',),
'boknasilder': ('boknasild',),
'dreiel': ('dreiel',),
'dreiela': ('dreiel',),
'dreielen': ('dreiel',),
'dreielene': ('dreiel',),
'dreieler': ('dreiel',),
'dreielet': ('dreiel',),
'farvel': ('farvel',),
'farvelen': ('farvel',),
'farvelene': ('farvel',),
'farveler': ('farvel',),
'farvellen': ('farvel',),
'farvellene': ('farvel',),
'farveller': ('farvel',),
'festemø': ('festemø',),
'festemøa': ('festemø',),
'festemøen': ('festemø',),
'festemøene': ('festemø',),
'festemøer': ('festemø',),
'fold': ('fold',),
'folda': ('fold',),
'foldene': ('fold',),
'foldet': ('fold',),
'flattjern': ('flattjern',),
'flattjerna': ('flattjern',),
'flattjernene': ('flattjern',),
'flattjernet': ('flattjern',),
'flattstål': ('flattstål',),
'flattståla': ('flattstål',),
'flattstålene': ('flattstål',),
'flattstålet': ('flattstål',),
'gjøksyra': ('gjøksyre',),
'gjøksyre': ('gjøksyre',),
'gjøksyren': ('gjøksyre',),
'gjøksyrene': ('gjøksyre',),
'gjøksyrer': ('gjøksyre',),
'gjøkesyra': ('gjøkesyre',),
'gjøkesyre': ('gjøkesyre',),
'gjøkesyren': ('gjøkesyre',),
'gjøkesyrene': ('gjøkesyre',),
'gjøkesyrer': ('gjøkesyre',),
'komla': ('komle',),
'komle': ('komle',),
'komlen': ('komle',),
'komlene': ('komle',),
'komler': ('komle',),
'kompa': ('kompe',),
'kompe': ('kompe',),
'kompen': ('kompe',),
'kompene': ('kompe',),
'komper': ('kompe',),
'hellebarderen': ('hellebardér',),
'hellebarderene': ('hellebardér',),
'hellebarderer': ('hellebardér',),
'hellebardér': ('hellebardér',),
'hellebardéren': ('hellebardér',),
'hellebardérene': ('hellebardér',),
'hellebardérer': ('hellebardér',),
'hellebarder': ('hellebarder',),
'hellebarderen': ('hellebarder',),
'hellebarderene': ('hellebarder',),
'hellebarderer': ('hellebarder',),
'hvitbjørn': ('hvitbjørn',),
'hvitbjørnen': ('hvitbjørn',),
'hvitbjørnene': ('hvitbjørn',),
'hvitbjørner': ('hvitbjørn',),
'hørselvern': ('hørselvern',),
'hørselverna': ('hørselvern',),
'hørselvernene': ('hørselvern',),
'hørselvernet': ('hørselvern',),
'brysthøgda': ('brysthøgde',),
'brysthøgde': ('brysthøgde',),
'brysthøgden': ('brysthøgde',),
'brysthøgdene': ('brysthøgde',),
'brysthøgder': ('brysthøgde',),
'fallhøgda': ('fallhøgde',),
'fallhøgde': ('fallhøgde',),
'fallhøgden': ('fallhøgde',),
'fallhøgdene': ('fallhøgde',),
'fallhøgder': ('fallhøgde',),
'flyhøgda': ('flyhøgde',),
'flyhøgde': ('flyhøgde',),
'flyhøgden': ('flyhøgde',),
'flyhøgdene': ('flyhøgde',),
'flyhøgder': ('flyhøgde',),
'gesimshøgda': ('gesimshøgde',),
'gesimshøgde': ('gesimshøgde',),
'gesimshøgden': ('gesimshøgde',),
'gesimshøgdene': ('gesimshøgde',),
'gesimshøgder': ('gesimshøgde',),
'middagshøgda': ('middagshøgde',),
'middagshøgde': ('middagshøgde',),
'middagshøgden': ('middagshøgde',),
'middagshøgdene': ('middagshøgde',),
'middagshøgder': ('middagshøgde',),
'middelhøgda': ('middelhøgde',),
'middelhøgde': ('middelhøgde',),
'middelhøgden': ('middelhøgde',),
'middelhøgdene': ('middelhøgde',),
'middelhøgder': ('middelhøgde',),
'middelshøgda': ('middelshøgde',),
'middelshøgde': ('middelshøgde',),
'middelshøgden': ('middelshøgde',),
'middelshøgdene': ('middelshøgde',),
'middelshøgder': ('middelshøgde',),
'nedbørhøgda': ('nedbørhøgde',),
'nedbørhøgde': ('nedbørhøgde',),
'nedbørhøgden': ('nedbørhøgde',),
'nedbørhøgdene': ('nedbørhøgde',),
'nedbørhøgder': ('nedbørhøgde',),
'nedbørshøgda': ('nedbørshøgde',),
'nedbørshøgde': ('nedbørshøgde',),
'nedbørshøgden': ('nedbørshøgde',),
'nedbørshøgdene': ('nedbørshøgde',),
'nedbørshøgder': ('nedbørshøgde',),
'takhøgda': ('takhøgde',),
'takhøgde': ('takhøgde',),
'takhøgden': ('takhøgde',),
'takhøgdene': ('takhøgde',),
'takhøgder': ('takhøgde',),
'høytaler': ('høytaler',),
'høytalere': ('høytaler',),
'høytaleren': ('høytaler',),
'høytalerne': ('høytaler',),
'jug': ('jug',),
'juga': ('jug',),
'jugene': ('jug',),
'juget': ('jug',),
'kid': ('kid',),
'kida': ('kid',),
'kidene': ('kid',),
'kidet': ('kid',),
'lagesild': ('lagesild',),
'lagesilda': ('lagesild',),
'lagesilden': ('lagesild',),
'lagesildene': ('lagesild',),
'lagesilder': ('lagesild',),
'lørja': ('lørje',),
'lørje': ('lørje',),
'lørjen': ('lørje',),
'lørjene': ('lørje',),
'lørjer': ('lørje',),
'marihånd': ('marihånd',),
'marihånda': ('marihånd',),
'marihånden': ('marihånd',),
'marihåndene': ('marihånd',),
'marihånder': ('marihånd',),
'milæpæl': ('milæpæl',),
'milæpælen': ('milæpæl',),
'milæpælene': ('milæpæl',),
'milæpæler': ('milæpæl',),
'pissprat': ('pissprat',),
'pissprata': ('pissprat',),
'pisspraten': ('pissprat',),
'pisspratene': ('pissprat',),
'pissprater': ('pissprat',),
'pisspratet': ('pissprat',),
'smalahova': ('smalahove',),
'smalahove': ('smalahove',),
'smalahovene': ('smalahove',),
'smalahover': ('smalahove',),
'smalahovet': ('smalahove',),
'spjære': ('spjære',),
'spjæren': ('spjære',),
'spjærene': ('spjære',),
'spjærer': ('spjære',),
'spottegjøk': ('spottegjøk',),
'spottegjøken': ('spottegjøk',),
'spottegjøkene': ('spottegjøk',),
'spottegjøker': ('spottegjøk',),
'stikkveps': ('stikkveps',),
'stikkvepsen': ('stikkveps',),
'stikkvepsene': ('stikkveps',),
'stikkvepser': ('stikkveps',),
'øyenstikker': ('øyenstikker',),
'øyenstikkere': ('øyenstikker',),
'øyenstikkeren': ('øyenstikker',),
'øyenstikkerne': ('øyenstikker',),
'løsdans': ('løsdans',),
'løsdansen': ('løsdans',),
'løsdansene': ('løsdans',),
'løsdanser': ('løsdans',),
'løskar': ('løskar',),
'løskaren': ('løskar',),
'løskarene': ('løskar',),
'løskarer': ('løskar',),
'gimmer': ('gimmer',),
'gimmeren': ('gimmer',),
'gimra': ('gimmer',),
'gimre': ('gimmer',),
'gimrene': ('gimmer',),
'gimrer': ('gimmer',),
'1. mai-demonstrasjon': ('1. mai-demonstrasjon',),
'1. mai-demonstrasjonen': ('1. mai-demonstrasjon',),
'1. mai-demonstrasjonene': ('1. mai-demonstrasjon',),
'1. mai-demonstrasjoner': ('1. mai-demonstrasjon',),
'1. mai-tog': ('1. mai-tog',),
'1. mai-toga': ('1. mai-tog',),
'1. mai-togene': ('1. mai-tog',),
'1. mai-toget': ('1. mai-tog',),
'17. mai-tale': ('17. mai-tale',),
'17. mai-talen': ('17. mai-tale',),
'17. mai-talene': ('17. mai-tale',),
'17. mai-taler': ('17. mai-tale',),
'17. mai-tog': ('17. mai-tog',),
'17. mai-toga': ('17. mai-tog',),
'17. mai-togene': ('17. mai-tog',),
'17. mai-toget': ('17. mai-tog',),
'A4': ('A4',),
'A4-sida': ('A4-side',),
'A4-side': ('A4-side',),
'A4-siden': ('A4-side',),
'A4-sidene': ('A4-side',),
'A4-sider': ('A4-side',),
'ablasjon': ('ablasjon',),
'ablasjonen': ('ablasjon',),
'ablasjonene': ('ablasjon',),
'ablasjoner': ('ablasjon',),
'acappellakor': ('acappellakor',),
'acappellakora': ('acappellakor',),
'acappellakorene': ('acappellakor',),
'acappellakoret': ('acappellakor',),
'acappellasang': ('acappellasang',),
'acappellasangen': ('acappellasang',),
'acappellasangene': ('acappellasang',),
'acappellasanger': ('acappellasang',),
'adhocdefinisjon': ('adhocdefinisjon',),
'adhocdefinisjonen': ('adhocdefinisjon',),
'adhocdefinisjonene': ('adhocdefinisjon',),
'adhocdefinisjoner': ('adhocdefinisjon',),
'adhockomite': ('adhockomite',),
'adhockomiteen': ('adhockomite',),
'adhockomiteene': ('adhockomite',),
'adhockomiteer': ('adhockomite',),
'aforistiker': ('aforistiker',),
'aforistikere': ('aforistiker',),
'aforistikeren': ('aforistiker',),
'aforistikerer': ('aforistiker',),
'aforistikerne': ('aforistiker',),
'afrodisiaka': ('afrodisiakum',),
'afrodisiakaene': ('afrodisiakum',),
'afrodisiakum': ('afrodisiakum',),
'afrodisiakumet': ('afrodisiakum',),
'agglomerasjon': ('agglomerasjon',),
'agglomerasjonen': ('agglomerasjon',),
'agglomerasjonene': ('agglomerasjon',),
'agglomerasjoner': ('agglomerasjon',),
'agglomerat': ('agglomerat',),
'agglomerata': ('agglomerat',),
'agglomeratene': ('agglomerat',),
'agglomerater': ('agglomerat',),
'agglomeratet': ('agglomerat',),
'aidsepidemi': ('aidsepidemi',),
'aidsepidemien': ('aidsepidemi',),
'aidsepidemiene': ('aidsepidemi',),
'aidsepidemier': ('aidsepidemi',),
'airbagg': ('airbagg',),
'airbaggen': ('airbagg',),
'airbaggene': ('airbagg',),
'airbagger': ('airbagg',),
'airedaleterrier': ('airedaleterrier',),
'airedaleterriere': ('airedaleterrier',),
'airedaleterrieren': ('airedaleterrier',),
'airedaleterrierer': ('airedaleterrier',),
'airedaleterrierne': ('airedaleterrier',),
'akkordeon': ('akkordeon',),
'akkordeona': ('akkordeon',),
'akkordeonene': ('akkordeon',),
'akkordeoner': ('akkordeon',),
'akkordeonet': ('akkordeon',),
'akkumulatorsella': ('akkumulatorselle',),
'akkumulatorselle': ('akkumulatorselle',),
'akkumulatorsellen': ('akkumulatorselle',),
'akkumulatorsellene': ('akkumulatorselle',),
'akkumulatorseller': ('akkumulatorselle',),
'akribi': ('akribi',),
'akribien': ('akribi',),
'akribiene': ('akribi',),
'akribier': ('akribi',),
'aksessoarene': ('aksessoarer',),
'aksessoarer': ('aksessoarer',),
'aksjebok': ('aksjebok',),
'aksjeboka': ('aksjebok',),
'aksjeboken': ('aksjebok',),
'aksjebøkene': ('aksjebok',),
'aksjebøker': ('aksjebok',),
'aksjonsforsking': ('aksjonsforsking',),
'aksjonsforskinga': ('aksjonsforsking',),
'aksjonsforskingen': ('aksjonsforsking',),
'aksjonsforskingene': ('aksjonsforsking',),
'aksjonsforskinger': ('aksjonsforsking',),
'aksjonsforskning': ('aksjonsforskning',),
'aksjonsforskninga': ('aksjonsforskning',),
'aksjonsforskningen': ('aksjonsforskning',),
'aksjonsforskningene': ('aksjonsforskning',),
'aksjonsforskninger': ('aksjonsforskning',),
'akterstevn': ('akterstevn',),
'akterstevnen': ('akterstevn',),
'akterstevnene': ('akterstevn',),
'akterstevner': ('akterstevn',),
'akvatint': ('akvatint',),
'akvatinten': ('akvatint',),
'akvatintene': ('akvatint',),
'akvatinter': ('akvatint',),
'akvatintetsning': ('akvatintetsning',),
'akvatintetsninga': ('akvatintetsning',),
'akvatintetsningen': ('akvatintetsning',),
'akvatintetsningene': ('akvatintetsning',),
'akvatintetsninger': ('akvatintetsning',),
'algesyra': ('algesyre',),
'algesyre': ('algesyre',),
'algesyren': ('algesyre',),
'algesyrene': ('algesyre',),
'algesyrer': ('algesyre',),
'alginsyra': ('alginsyre',),
'alginsyre': ('alginsyre',),
'alginsyren': ('alginsyre',),
'alginsyrene': ('alginsyre',),
'alginsyrer': ('alginsyre',),
'alikvant': ('alikvant',),
'alikvanten': ('alikvant',),
'alikvantene': ('alikvant',),
'alikvanter': ('alikvant',),
'alikvot': ('alikvot',),
'alikvoten': ('alikvot',),
'alikvotene': ('alikvot',),
'alikvoter': ('alikvot',),
'alikvottone': ('alikvottone',),
'alikvottoneen': ('alikvottone',),
'alikvottoneene': ('alikvottone',),
'alikvottoneer': ('alikvottone',),
'allmektighet': ('allmektighet',),
'allmektigheta': ('allmektighet',),
'allmektigheten': ('allmektighet',),
'allmektighetene': ('allmektighet',),
'allmektigheter': ('allmektighet',),
'allroundklassa': ('allroundklasse',),
'allroundklasse': ('allroundklasse',),
'allroundklassen': ('allroundklasse',),
'allroundklassene': ('allroundklasse',),
'allroundklasser': ('allroundklasse',),
'alunitt': ('alunitt',),
'alunitten': ('alunitt',),
'alunittene': ('alunitt',),
'alunitter': ('alunitt',),
'amfibiekjøretøy': ('amfibiekjøretøy',),
'amfibiekjøretøya': ('amfibiekjøretøy',),
'amfibiekjøretøyene': ('amfibiekjøretøy',),
'amfibiekjøretøyer': ('amfibiekjøretøy',),
'amfibiekjøretøyet': ('amfibiekjøretøy',),
'ammetåka': ('ammetåke',),
'ammetåke': ('ammetåke',),
'ammetåken': ('ammetåke',),
'ammetåkene': ('ammetåke',),
'ammetåker': ('ammetåke',),
'anamnese': ('anamnese',),
'anamnesen': ('anamnese',),
'anamnesene': ('anamnese',),
'anamneser': ('anamnese',),
'androfag': ('androfag',),
'androfagen': ('androfag',),
'androfagene': ('androfag',),
'androfager': ('androfag',),
'androfobi': ('androfobi',),
'androfobien': ('androfobi',),
'androfobiene': ('androfobi',),
'androfobier': ('androfobi',),
'anemiker': ('anemiker',),
'anemikere': ('anemiker',),
'anemikeren': ('anemiker',),
'anemikerer': ('anemiker',),
'anemikerne': ('anemiker',),
'angrepilla': ('angrepille',),
'angrepille': ('angrepille',),
'angrepillen': ('angrepille',),
'angrepillene': ('angrepille',),
'angrepiller': ('angrepille',),
'angretast': ('angretast',),
'angretasten': ('angretast',),
'angretastene': ('angretast',),
'angretaster': ('angretast',),
'ante': ('ante',),
'anten': ('ante',),
'antene': ('ante',),
'anter': ('ante',),
'antidepressiv': ('antidepressiv',),
'antidepressiva': ('antidepressiv',),
'antidepressivene': ('antidepressiv',),
'antidepressiver': ('antidepressiv',),
'antidepressivet': ('antidepressiv',),
'antraks': ('antraks',),
'antraksen': ('antraks',),
'antraksene': ('antraks',),
'antrakser': ('antraks',),
'appelsinhud': ('appelsinhud',),
'appelsinhuda': ('appelsinhud',),
'appelsinhuden': ('appelsinhud',),
'appelsinhudene': ('appelsinhud',),
'appelsinhuder': ('appelsinhud',),
'applikasjonsprogram': ('applikasjonsprogram',),
'applikasjonsprogramma': ('applikasjonsprogram',),
'applikasjonsprogrammene': ('applikasjonsprogram',),
'applikasjonsprogrammer': ('applikasjonsprogram',),
'applikasjonsprogrammet': ('applikasjonsprogram',),
'applikator': ('applikator',),
'applikatoren': ('applikator',),
'applikatorene': ('applikator',),
'applikatorer': ('applikator',),
'arketype': ('arketype',),
'arketypen': ('arketype',),
'arketypene': ('arketype',),
'arketyper': ('arketype',),
'armagnac': ('armagnac',),
'armagnacen': ('armagnac',),
'armagnacene': ('armagnac',),
'armagnacer': ('armagnac',),
'armékorps': ('armékorps',),
'armékorpsa': ('armékorps',),
'armékorpsene': ('armékorps',),
'armékorpset': ('armékorps',),
'aromastoff': ('aromastoff',),
'aromastoffa': ('aromastoff',),
'aromastoffene': ('aromastoff',),
'aromastoffer': ('aromastoff',),
'aromastoffet': ('aromastoff',),
'aromaterapi': ('aromaterapi',),
'aromaterapien': ('aromaterapi',),
'aromaterapiene': ('aromaterapi',),
'aromaterapier': ('aromaterapi',),
'artefakt': ('artefakt',),
'artefakten': ('artefakt',),
'artefaktene': ('artefakt',),
'artefakter': ('artefakt',),
'artrose': ('artrose',),
'artrosen': ('artrose',),
'artrosene': ('artrose',),
'artroser': ('artrose',),
'arytmi': ('arytmi',),
'arytmien': ('arytmi',),
'arytmiene': ('arytmi',),
'arytmier': ('arytmi',),
'asorisk': ('asorisk',),
'asoriske': ('asorisk',),
'asorisken': ('asorisk',),
'asoriskne': ('asorisk',),
'asterie': ('asterie',),
'asterien': ('asterie',),
'asteriene': ('asterie',),
'asterier': ('asterie',),
'asylant': ('asylant',),
'asylanten': ('asylant',),
'asylantene': ('asylant',),
'asylanter': ('asylant',),
'aupairarbeid': ('aupairarbeid',),
'aupairarbeida': ('aupairarbeid',),
'aupairarbeidene': ('aupairarbeid',),
'aupairarbeider': ('aupairarbeid',),
'aupairarbeidet': ('aupairarbeid',),
'aupairjenta': ('aupairjente',),
'aupairjente': ('aupairjente',),
'aupairjenten': ('aupairjente',),
'aupairjentene': ('aupairjente',),
'aupairjenter': ('aupairjente',),
'austegd': ('austegd',),
'austegden': ('austegd',),
'austegdene': ('austegd',),
'austegder': ('austegd',),
'austegde': ('austegde',),
'austegdeen': ('austegde',),
'austegdeene': ('austegde',),
'austegdeer': ('austegde',),
'avantgardisme': ('avantgardisme',),
'avantgardismen': ('avantgardisme',),
'avantgardismene': ('avantgardisme',),
'avantgardismer': ('avantgardisme',),
'avgiftingsanlegg': ('avgiftingsanlegg',),
'avgiftingsanlegga': ('avgiftingsanlegg',),
'avgiftingsanleggene': ('avgiftingsanlegg',),
'avgiftingsanlegget': ('avgiftingsanlegg',),
'avgiftningsanlegg': ('avgiftningsanlegg',),
'avgiftningsanlegga': ('avgiftningsanlegg',),
'avgiftningsanleggene': ('avgiftningsanlegg',),
'avgiftningsanlegget': ('avgiftningsanlegg',),
'avgiftsøking': ('avgiftsøking',),
'avgiftsøkinga': ('avgiftsøking',),
'avgiftsøkingen': ('avgiftsøking',),
'avgiftsøkingene': ('avgiftsøking',),
'avgiftsøkinger': ('avgiftsøking',),
'avlivingsmetode': ('avlivingsmetode',),
'avlivingsmetoden': ('avlivingsmetode',),
'avlivingsmetodene': ('avlivingsmetode',),
'avlivingsmetoder': ('avlivingsmetode',),
'avlivning': ('avlivning',),
'avlivninga': ('avlivning',),
'avlivningen': ('avlivning',),
'avlivningene': ('avlivning',),
'avlivninger': ('avlivning',),
'avlivningsmetode': ('avlivningsmetode',),
'avlivningsmetoden': ('avlivningsmetode',),
'avlivningsmetodene': ('avlivningsmetode',),
'avlivningsmetoder': ('avlivningsmetode',),
'av-og-på-knapp': ('av-og-på-knapp',),
'av-og-på-knappen': ('av-og-på-knapp',),
'av-og-på-knappene': ('av-og-på-knapp',),
'av-og-på-knapper': ('av-og-på-knapp',),
'avrop': ('avrop',),
'avropa': ('avrop',),
'avropene': ('avrop',),
'avropet': ('avrop',),
'babydoll': ('babydoll',),
'babydollen': ('babydoll',),
'babydollene': ('babydoll',),
'babydoller': ('babydoll',),
'badeolja': ('badeolje',),
'badeolje': ('badeolje',),
'badeoljen': ('badeolje',),
'badeoljene': ('badeolje',),
'badeoljer': ('badeolje',),
'bagg': ('bagg',),
'baggen': ('bagg',),
'baggene': ('bagg',),
'bagger': ('bagg',),
'baht': ('baht',),
'bahten': ('baht',),
'bahtene': ('baht',),
'bahter': ('baht',),
'bakalao': ('bakalao',),
'bakalaoen': ('bakalao',),
'bakalaoene': ('bakalao',),
'bakalaoer': ('bakalao',),
'bakomfilm': ('bakomfilm',),
'bakomfilmen': ('bakomfilm',),
'bakomfilmene': ('bakomfilm',),
'bakomfilmer': ('bakomfilm',),
'bakstevn': ('bakstevn',),
'bakstevnen': ('bakstevn',),
'bakstevnene': ('bakstevn',),
'bakstevner': ('bakstevn',),
'balaklava': ('balaklava',),
'balaklavaen': ('balaklava',),
'balaklavaene': ('balaklava',),
'balaklavaer': ('balaklava',),
'balkaner': ('balkaner',),
'balkanere': ('balkaner',),
'balkaneren': ('balkaner',),
'balkanerer': ('balkaner',),
'balkanerne': ('balkaner',),
'bananskott': ('bananskott',),
'bananskotta': ('bananskott',),
'bananskottene': ('bananskott',),
'bananskottet': ('bananskott',),
'bananskudd': ('bananskudd',),
'bananskudda': ('bananskudd',),
'bananskuddene': ('bananskudd',),
'bananskuddet': ('bananskudd',),
'bandoneon': ('bandoneon',),
'bandoneona': ('bandoneon',),
'bandoneonene': ('bandoneon',),
'bandoneoner': ('bandoneon',),
'bandoneonet': ('bandoneon',),
'bandoneonist': ('bandoneonist',),
'bandoneonisten': ('bandoneonist',),
'bandoneonistene': ('bandoneonist',),
'bandoneonister': ('bandoneonist',),
'bandspagetti': ('bandspagetti',),
'bandspagettien': ('bandspagetti',),
'bandspagettiene': ('bandspagetti',),
'bandspagettier': ('bandspagetti',),
'barne-tv': ('barne-tv',),
'barne-tv-en': ('barne-tv',),
'barne-tv-ene': ('barne-tv',),
'barne-tv-er': ('barne-tv',),
'barnevernsinstitusjon': ('barnevernsinstitusjon',),
'barnevernsinstitusjonen': ('barnevernsinstitusjon',),
'barnevernsinstitusjonene': ('barnevernsinstitusjon',),
'barnevernsinstitusjoner': ('barnevernsinstitusjon',),
'basehopp': ('basehopp',),
'basehoppa': ('basehopp',),
'basehoppene': ('basehopp',),
'basehoppet': ('basehopp',),
'basehopper': ('basehopper',),
'basehoppere': ('basehopper',),
'basehopperen': ('basehopper',),
'basehopperer': ('basehopper',),
'basehopperne': ('basehopper',),
'basehopping': ('basehopping',),
'basehoppinga': ('basehopping',),
'basehoppingen': ('basehopping',),
'basehoppingene': ('basehopping',),
'basehoppinger': ('basehopping',),
'basket': ('basket',),
'basketballsko': ('basketballsko',),
'basketballskoa': ('basketballsko',),
'basketballskoen': ('basketballsko',),
'basketballskoene': ('basketballsko',),
'basketballskor': ('basketballsko',),
'basketballskorne': ('basketballsko',),
'beagle': ('beagle',),
'beaglen': ('beagle',),
'beaglene': ('beagle',),
'beagler': ('beagle',),
'befestningsanlegg': ('befestningsanlegg',),
'befestningsanlegga': ('befestningsanlegg',),
'befestningsanleggene': ('befestningsanlegg',),
'befestningsanlegget': ('befestningsanlegg',),
'Bekhterevs sjukdom': ('Bekhterevs sjukdom',),
'Bekhterevs sykdom': ('Bekhterevs sykdom',),
'benskjørhet': ('benskjørhet',),
'benskjørheta': ('benskjørhet',),
'benskjørheten': ('benskjørhet',),
'benskjørhetene': ('benskjørhet',),
'benskjørheter': ('benskjørhet',),
'betablokker': ('betablokker',),
'betablokkere': ('betablokker',),
'betablokkeren': ('betablokker',),
'betablokkerer': ('betablokker',),
'betablokkerne': ('betablokker',),
'betalingsfjernsyn': ('betalingsfjernsyn',),
'betalingsfjernsyna': ('betalingsfjernsyn',),
'betalingsfjernsynene': ('betalingsfjernsyn',),
'betalingsfjernsynet': ('betalingsfjernsyn',),
'betal-TV': ('betal-TV',),
'betal-TV-en': ('betal-TV',),
'betal-TV-ene': ('betal-TV',),
'betal-TV-er': ('betal-TV',),
'betal-tv': ('betal-tv',),
'betal-tv-en': ('betal-tv',),
'betal-tv-ene': ('betal-tv',),
'betal-tv-er': ('betal-tv',),
'bigam': ('bigam',),
'bigama': ('bigam',),
'bigamene': ('bigam',),
'bigamer': ('bigam',),
'bigamet': ('bigam',),
'bildeelement': ('bildeelement',),
'bildeelementa': ('bildeelement',),
'bildeelementene': ('bildeelement',),
'bildeelementer': ('bildeelement',),
'bildeelementet': ('bildeelement',),
'billedelement': ('billedelement',),
'billedelementa': ('billedelement',),
'billedelementene': ('billedelement',),
'billedelementer': ('billedelement',),
'billedelementet': ('billedelement',),
'billiontedel': ('billiontedel',),
'billiontedelen': ('billiontedel',),
'billiontedelene': ('billiontedel',),
'billiontedeler': ('billiontedel',),
'bimbo': ('bimbo',),
'bimboen': ('bimbo',),
'bimboene': ('bimbo',),
'bimboer': ('bimbo',),
'biobrensel': ('biobrensel',),
'biobrenselet': ('biobrensel',),
'biobrensla': ('biobrensel',),
'biobrenslene': ('biobrensel',),
'biobrensler': ('biobrensel',),
'biobrenslet': ('biobrensel',),
'biodiversitet': ('biodiversitet',),
'biodiversiteten': ('biodiversitet',),
'biodiversitetene': ('biodiversitet',),
'biodiversiteter': ('biodiversitet',),
'biogenese': ('biogenese',),
'biogenesen': ('biogenese',),
'biogenesene': ('biogenese',),
'biogeneser': ('biogenese',),
'biogeografi': ('biogeografi',),
'biogeografien': ('biogeografi',),
'biogeografiene': ('biogeografi',),
'biogeografier': ('biogeografi',),
'biopati': ('biopati',),
'biopatien': ('biopati',),
'biopatiene': ('biopati',),
'biopatier': ('biopati',),
'biotype': ('biotype',),
'biotypen': ('biotype',),
'biotypene': ('biotype',),
'biotyper': ('biotype',),
'birdie': ('birdie',),
'birdien': ('birdie',),
'birdiene': ('birdie',),
'birdier': ('birdie',),
'birdieputt': ('birdieputt',),
'birdieputten': ('birdieputt',),
'birdieputtene': ('birdieputt',),
'birdieputter': ('birdieputt',),
'bisena': ('bisene',),
'bisene': ('bisene',),
'bisenen': ('bisene',),
'bisenene': ('bisene',),
'bisener': ('bisene',),
'blindsida': ('blindside',),
'blindside': ('blindside',),
'blindsiden': ('blindside',),
'blindsidene': ('blindside',),
'blindsider': ('blindside',),
'blodsella': ('blodselle',),
'blodselle': ('blodselle',),
'blodsellen': ('blodselle',),
'blodsellene': ('blodselle',),
'blodseller': ('blodselle',),
'bodylotion': ('bodylotion',),
'bodylotionen': ('bodylotion',),
'bodylotionene': ('bodylotion',),
'bodylotioner': ('bodylotion',),
'bogey': ('bogey',),
'bogeyen': ('bogey',),
'bogeyene': ('bogey',),
'bogeyer': ('bogey',),
'bongo': ('bongo',),
'bongoen': ('bongo',),
'bongoene': ('bongo',),
'bongoer': ('bongo',),
'boogiewoogie': ('boogiewoogie',),
'boogiewoogieen': ('boogiewoogie',),
'boogiewoogieene': ('boogiewoogie',),
'boogiewoogieer': ('boogiewoogie',),
'borgerlønn': ('borgerlønn',),
'borgerlønna': ('borgerlønn',),
'borgerlønnen': ('borgerlønn',),
'borgerlønnene': ('borgerlønn',),
'borgerlønner': ('borgerlønn',),
'borkaks': ('borkaks',),
'borkaksa': ('borkaks',),
'borkaksene': ('borkaks',),
'borkakset': ('borkaks',),
'bosnjak': ('bosnjak',),
'bosnjaken': ('bosnjak',),
'bosnjakene': ('bosnjak',),
'bosnjaker': ('bosnjak',),
'bossanova': ('bossanova',),
'bossanovaen': ('bossanova',),
'bossanovaene': ('bossanova',),
'bossanovaer': ('bossanova',),
'botnlinja': ('botnlinje',),
'botnlinje': ('botnlinje',),
'botnlinjen': ('botnlinje',),
'botnlinjene': ('botnlinje',),
'botnlinjer': ('botnlinje',),
'brasseri': ('brasseri',),
'brasseria': ('brasseri',),
'brasseriene': ('brasseri',),
'brasserier': ('brasseri',),
'brasseriet': ('brasseri',),
'brazzavillekongoleser': ('brazzavillekongoleser',),
'brazzavillekongolesere': ('brazzavillekongoleser',),
'brazzavillekongoleseren': ('brazzavillekongoleser',),
'brazzavillekongoleserer': ('brazzavillekongoleser',),
'brazzavillekongoleserne': ('brazzavillekongoleser',),
'bredband': ('bredband',),
'bredbanda': ('bredband',),
'bredbandene': ('bredband',),
'bredbandet': ('bredband',),
'bredbånd': ('bredbånd',),
'bredbånda': ('bredbånd',),
'bredbåndene': ('bredbånd',),
'bredbåndet': ('bredbånd',),
'bregleppa': ('bregleppe',),
'bregleppe': ('bregleppe',),
'bregleppen': ('bregleppe',),
'bregleppene': ('bregleppe',),
'breglepper': ('bregleppe',),
'breiband': ('breiband',),
'breibanda': ('breiband',),
'breibandene': ('breiband',),
'breibandet': ('breiband',),
'breibånd': ('breibånd',),
'breibånda': ('breibånd',),
'breibåndene': ('breibånd',),
'breibåndet': ('breibånd',),
'breikdans': ('breikdans',),
'breikdansen': ('breikdans',),
'breikdansene': ('breikdans',),
'breikdanser': ('breikdans',),
'bre-is': ('bre-is',),
'bre-isen': ('bre-is',),
'bre-isene': ('bre-is',),
'bre-iser': ('bre-is',),
'breitschwanz': ('breitschwanz',),
'breitschwanzen': ('breitschwanz',),
'breitschwanzene': ('breitschwanz',),
'breitschwanzer': ('breitschwanz',),
'brenselsella': ('brenselselle',),
'brenselselle': ('brenselselle',),
'brenselsellen': ('brenselselle',),
'brenselsellene': ('brenselselle',),
'brenselseller': ('brenselselle',),
'brenselssella': ('brenselsselle',),
'brenselsselle': ('brenselsselle',),
'brenselssellen': ('brenselsselle',),
'brenselssellene': ('brenselsselle',),
'brenselsseller': ('brenselsselle',),
'breport': ('breport',),
'breporten': ('breport',),
'breportene': ('breport',),
'breporter': ('breport',),
'brettkjører': ('brettkjører',),
'brettkjørere': ('brettkjører',),
'brettkjøreren': ('brettkjører',),
'brettkjørerne': ('brettkjører',),
'brevgiro': ('brevgiro',),
'brevgiroen': ('brevgiro',),
'brevgiroene': ('brevgiro',),
'brevgiroer': ('brevgiro',),
'brevkontroll': ('brevkontroll',),
'brevkontrollen': ('brevkontroll',),
'brevkontrollene': ('brevkontroll',),
'brevkontroller': ('brevkontroll',),
'broderramma': ('broderramme',),
'broderramme': ('broderramme',),
'broderrammen': ('broderramme',),
'broderrammene': ('broderramme',),
'broderrammer': ('broderramme',),
'brysselknipling': ('brysselknipling',),
'brysselkniplinga': ('brysselknipling',),
'brysselkniplingen': ('brysselknipling',),
'brysselkniplingene': ('brysselknipling',),
'brysselkniplinger': ('brysselknipling',),
'brysselteppa': ('brysselteppe',),
'brysselteppe': ('brysselteppe',),
'brysselteppene': ('brysselteppe',),
'brysseltepper': ('brysselteppe',),
'brysselteppet': ('brysselteppe',),
'brystmjølk': ('brystmjølk',),
'brystmjølka': ('brystmjølk',),
'brystmjølken': ('brystmjølk',),
'brystmjølkene': ('brystmjølk',),
'brystmjølker': ('brystmjølk',),
'brystningspanel': ('brystningspanel',),
'brystningspanela': ('brystningspanel',),
'brystningspanelene': ('brystningspanel',),
'brystningspaneler': ('brystningspanel',),
'brystningspanelet': ('brystningspanel',),
'brystpumpa': ('brystpumpe',),
'brystpumpe': ('brystpumpe',),
'brystpumpen': ('brystpumpe',),
'brystpumpene': ('brystpumpe',),
'brystpumper': ('brystpumpe',),
'brødtekst': ('brødtekst',),
'brødteksten': ('brødtekst',),
'brødtekstene': ('brødtekst',),
'brødtekster': ('brødtekst',),
'budo': ('budo',),
'budoen': ('budo',),
'budoene': ('budo',),
'budoer': ('budo',),
'bufferlager': ('bufferlager',),
'bufferlageret': ('bufferlager',),
'bufferlagra': ('bufferlager',),
'bufferlagre': ('bufferlager',),
'bufferlagrene': ('bufferlager',),
'bufferløsning': ('bufferløsning',),
'bufferløsninga': ('bufferløsning',),
'bufferløsningen': ('bufferløsning',),
'bufferløsningene': ('bufferløsning',),
'bufferløsninger': ('bufferløsning',),
'bukkert': ('bukkert',),
'bukkerta': ('bukkert',),
'bukkerten': ('bukkert',),
'bukkertene': ('bukkert',),
'bukkerter': ('bukkert',),
'bulleteng': ('bulleteng',),
'bulletengen': ('bulleteng',),
'bulletengene': ('bulleteng',),
'bulletenger': ('bulleteng',),
'bunnlinja': ('bunnlinje',),
'bunnlinje': ('bunnlinje',),
'bunnlinjen': ('bunnlinje',),
'bunnlinjene': ('bunnlinje',),
'bunnlinjer': ('bunnlinje',),
'buplass': ('buplass',),
'buplassen': ('buplass',),
'buplassene': ('buplass',),
'buplasser': ('buplass',),
'bureisingsbruk': ('bureisingsbruk',),
'bureisingsbruka': ('bureisingsbruk',),
'bureisingsbrukene': ('bureisingsbruk',),
'bureisingsbruket': ('bureisingsbruk',),
'burka': ('burka',),
'burkaen': ('burka',),
'burkaene': ('burka',),
'burkaer': ('burka',),
'båndspagetti': ('båndspagetti',),
'båndspagettien': ('båndspagetti',),
'båndspagettiene': ('båndspagetti',),
'båndspagettier': ('båndspagetti',),
'bånn': ('bånn',),
'C14-datering': ('C14-datering',),
'C14-dateringa': ('C14-datering',),
'C14-dateringen': ('C14-datering',),
'C14-dateringene': ('C14-datering',),
'C14-dateringer': ('C14-datering',),
'café-au-lait': ('café-au-lait',),
'café-au-laiten': ('café-au-lait',),
'café-au-laitene': ('café-au-lait',),
'café-au-laiter': ('café-au-lait',),
'callgirl': ('callgirl',),
'callgirlen': ('callgirl',),
'callgirlene': ('callgirl',),
'callgirler': ('callgirl',),
'carting': ('carting',),
'cartingen': ('carting',),
'cartingene': ('carting',),
'cartinger': ('carting',),
'cash-and-carry-prinsipp': ('cash-and-carry-prinsipp',),
'cash-and-carry-prinsippa': ('cash-and-carry-prinsipp',),
'cash-and-carry-prinsippene': ('cash-and-carry-prinsipp',),
'cash-and-carry-prinsipper': ('cash-and-carry-prinsipp',),
'cash-and-carry-prinsippet': ('cash-and-carry-prinsipp',),
'cd-plata': ('cd-plate',),
'cd-plate': ('cd-plate',),
'cd-platen': ('cd-plate',),
'cd-platene': ('cd-plate',),
'cd-plater': ('cd-plate',),
'CD-ROM': ('CD-ROM',),
'CD-ROM-en': ('CD-ROM',),
'CD-ROM-ene': ('CD-ROM',),
'CD-ROM-er': ('CD-ROM',),
'cd-rom': ('cd-rom',),
'cd-romen': ('cd-rom',),
'cd-romene': ('cd-rom',),
'cd-romer': ('cd-rom',),
'cd-speller': ('cd-speller',),
'cd-spellere': ('cd-speller',),
'cd-spelleren': ('cd-speller',),
'cd-spellerer': ('cd-speller',),
'cd-spellerne': ('cd-speller',),
'cd-spiller': ('cd-spiller',),
'cd-spillere': ('cd-spiller',),
'cd-spilleren': ('cd-spiller',),
'cd-spillerer': ('cd-spiller',),
'cd-spillerne': ('cd-spiller',),
'censor': ('censor',),
'censoren': ('censor',),
'censorene': ('censor',),
'censorer': ('censor',),
'ciabatta': ('ciabatta',),
'ciabattaen': ('ciabatta',),
'ciabattaene': ('ciabatta',),
'ciabattaer': ('ciabatta',),
'comebackforsøk': ('comebackforsøk',),
'comebackforsøka': ('comebackforsøk',),
'comebackforsøkene': ('comebackforsøk',),
'comebackforsøket': ('comebackforsøk',),
'crack': ('crack',),
'cracken': ('crack',),
'crackene': ('crack',),
'cracker': ('crack',),
'crème fraîche': ('crème fraîche',),
'crème fraîchen': ('crème fraîche',),
'crème fraîchene': ('crème fraîche',),
'crème fraîcher': ('crème fraîche',),
'crooner': ('crooner',),
'croonere': ('crooner',),
'crooneren': ('crooner',),
'croonerer': ('crooner',),
'croonerne': ('crooner',),
'curriculum vitae': ('curriculum vitae',),
'curriculum vitaene': ('curriculum vitae',),
'curriculum vitaer': ('curriculum vitae',),
'curriculum vitaet': ('curriculum vitae',),
'CV': ('CV',),
'CV-a': ('CV',),
'CV-en': ('CV',),
'CV-ene': ('CV',),
'CV-er': ('CV',),
'CV-et': ('CV',),
'cv': ('cv',),
'cv-a': ('cv',),
'cv-en': ('cv',),
'cv-ene': ('cv',),
'cv-er': ('cv',),
'cv-et': ('cv',),
'cyberpunk': ('cyberpunk',),
'cyberpunken': ('cyberpunk',),
'cyberpunkene': ('cyberpunk',),
'cyberpunker': ('cyberpunk',),
'cyberspace': ('cyberspace',),
'dagbokforfatter': ('dagbokforfatter',),
'dagbokforfattere': ('dagbokforfatter',),
'dagbokforfatteren': ('dagbokforfatter',),
'dagbokforfatterer': ('dagbokforfatter',),
'dagbokforfatterne': ('dagbokforfatter',),
'dagbokopptegnelse': ('dagbokopptegnelse',),
'dagbokopptegnelsen': ('dagbokopptegnelse',),
'dagbokopptegnelsene': ('dagbokopptegnelse',),
'dagbokopptegnelser': ('dagbokopptegnelse',),
'dagbot': ('dagbot',),
'dagbota': ('dagbot',),
'dagboten': ('dagbot',),
'dagbøtene': ('dagbot',),
'dagbøter': ('dagbot',),
'dagsing': ('dagsing',),
'dagsinga': ('dagsing',),
'dagsingen': ('dagsing',),
'dagsingene': ('dagsing',),
'dagsinger': ('dagsing',),
'dagsmarked': ('dagsmarked',),
'dagsmarkeda': ('dagsmarked',),
'dagsmarkedene': ('dagsmarked',),
'dagsmarkeder': ('dagsmarked',),
'dagsmarkedet': ('dagsmarked',),
'dakshund': ('dakshund',),
'dakshunden': ('dakshund',),
'dakshundene': ('dakshund',),
'dakshunder': ('dakshund',),
'daktylogi': ('daktylogi',),
'daktylogien': ('daktylogi',),
'daktylogiene': ('daktylogi',),
'daktylogier': ('daktylogi',),
'daktyloskopi': ('daktyloskopi',),
'daktyloskopien': ('daktyloskopi',),
'daktyloskopiene': ('daktyloskopi',),
'daktyloskopier': ('daktyloskopi',),
'danseteater': ('danseteater',),
'danseteateret': ('danseteater',),
'danseteatra': ('danseteater',),
'danseteatre': ('danseteater',),
'danseteatrene': ('danseteater',),
'danseteatret': ('danseteater',),
'datamatiker': ('datamatiker',),
'datamatikere': ('datamatiker',),
'datamatikeren': ('datamatiker',),
'datamatikerne': ('datamatiker',),
'dataorm': ('dataorm',),
'dataormen': ('dataorm',),
'dataormene': ('dataorm',),
'dataormer': ('dataorm',),
'dativsform': ('dativsform',),
'dativsforma': ('dativsform',),
'dativsformen': ('dativsform',),
'dativsformene': ('dativsform',),
'dativsformer': ('dativsform',),
'debattbok': ('debattbok',),
'debattboka': ('debattbok',),
'debattboken': ('debattbok',),
'debattbokene': ('debattbok',),
'debattboker': ('debattbok',),
'debrifing': ('debrifing',),
'debrifinga': ('debrifing',),
'debrifingen': ('debrifing',),
'debrifingene': ('debrifing',),
'debrifinger': ('debrifing',),
'dekningsområda': ('dekningsområde',),
'dekningsområde': ('dekningsområde',),
'dekningsområdene': ('dekningsområde',),
'dekningsområder': ('dekningsområde',),
'dekningsområdet': ('dekningsområde',),
'dekontaminasjon': ('dekontaminasjon',),
'dekontaminasjonen': ('dekontaminasjon',),
'dekontaminasjonene': ('dekontaminasjon',),
'dekontaminasjoner': ('dekontaminasjon',),
'dekontaminering': ('dekontaminering',),
'dekontamineringa': ('dekontaminering',),
'dekontamineringen': ('dekontaminering',),
'dekontamineringene': ('dekontaminering',),
'dekontamineringer': ('dekontaminering',),
'demerarasukker': ('demerarasukker',),
'demerarasukkera': ('demerarasukker',),
'demerarasukkere': ('demerarasukker',),
'demerarasukkeret': ('demerarasukker',),
'demerarasukkerne': ('demerarasukker',),
'dendrokronologi': ('dendrokronologi',),
'dendrokronologien': ('dendrokronologi',),
'dendrokronologiene': ('dendrokronologi',),
'dendrokronologier': ('dendrokronologi',),
'dendrologi': ('dendrologi',),
'dendrologien': ('dendrologi',),
'dendrologiene': ('dendrologi',),
'dendrologier': ('dendrologi',),
'dendrometer': ('dendrometer',),
'dendrometeret': ('dendrometer',),
'dendrometra': ('dendrometer',),
'dendrometre': ('dendrometer',),
'dendrometrene': ('dendrometer',),
'dendrometret': ('dendrometer',),
'desennia': ('desennium',),
'desenniene': ('desennium',),
'desennier': ('desennium',),
'desenniet': ('desennium',),
'desennium': ('desennium',),
'desennia': ('desennium',),
'desenniene': ('desennium',),
'desennier': ('desennium',),
'desenniet': ('desennium',),
'desennium': ('desennium',),
'diakonat': ('diakonat',),
'diakonata': ('diakonat',),
'diakonatene': ('diakonat',),
'diakonater': ('diakonat',),
'diakonatet': ('diakonat',),
'didaktiker': ('didaktiker',),
'didaktikere': ('didaktiker',),
'didaktikeren': ('didaktiker',),
'didaktikerer': ('didaktiker',),
'didaktikerne': ('didaktiker',),
'digital-TV': ('digital-TV',),
'digital-TV-en': ('digital-TV',),
'digital-TV-ene': ('digital-TV',),
'digital-TV-er': ('digital-TV',),
'digital-tv': ('digital-tv',),
'digital-tv-en': ('digital-tv',),
'digital-tv-ene': ('digital-tv',),
'digital-tv-er': ('digital-tv',),
'dildo': ('dildo',),
'dildoen': ('dildo',),
'dildoene': ('dildo',),
'dildoer': ('dildo',),
'dippedutt': ('dippedutt',),
'dippedutten': ('dippedutt',),
'dippeduttene': ('dippedutt',),
'dippedutter': ('dippedutt',),
'dispergeringsmiddel': ('dispergeringsmiddel',),
'dispergeringsmiddelet': ('dispergeringsmiddel',),
'dispergeringsmidla': ('dispergeringsmiddel',),
'dispergeringsmidlene': ('dispergeringsmiddel',),
'dispergeringsmidler': ('dispergeringsmiddel',),
'dispergeringsmidlet': ('dispergeringsmiddel',),
'diversitet': ('diversitet',),
'diversiteten': ('diversitet',),
'diversitetene': ('diversitet',),
'diversiteter': ('diversitet',),
'dixieland': ('dixieland',),
'dixielandorkester': ('dixielandorkester',),
'dixielandorkesteret': ('dixielandorkester',),
'dixielandorkestra': ('dixielandorkester',),
'dixielandorkestre': ('dixielandorkester',),
'dixielandorkestrene': ('dixielandorkester',),
'dixielandorkestret': ('dixielandorkester',),
'djevelbesvergelse': ('djevelbesvergelse',),
'djevelbesvergelsen': ('djevelbesvergelse',),
'djevelbesvergelsene': ('djevelbesvergelse',),
'djevelbesvergelser': ('djevelbesvergelse',),
'djevelbesverger': ('djevelbesverger',),
'djevelbesvergere': ('djevelbesverger',),
'djevelbesvergeren': ('djevelbesverger',),
'djevelbesvergerer': ('djevelbesverger',),
'djevelbesvergerne': ('djevelbesverger',),
'djevelfrykt': ('djevelfrykt',),
'djevelfrykten': ('djevelfrykt',),
'djevelfryktene': ('djevelfrykt',),
'djevelfrykter': ('djevelfrykt',),
'djevellua': ('djevellue',),
'djevellue': ('djevellue',),
'djevelluen': ('djevellue',),
'djevelluene': ('djevellue',),
'djevelluer': ('djevellue',),
'djevelmaner': ('djevelmaner',),
'djevelmanere': ('djevelmaner',),
'djevelmaneren': ('djevelmaner',),
'djevelmanerer': ('djevelmaner',),
'djevelmanerne': ('djevelmaner',),
'djevlelua': ('djevlelue',),
'djevlelue': ('djevlelue',),
'djevleluen': ('djevlelue',),
'djevleluene': ('djevlelue',),
'djevleluer': ('djevlelue',),
'dodra': ('dodre',),
'dodre': ('dodre',),
'dodren': ('dodre',),
'dodrene': ('dodre',),
'dodrer': ('dodre',),
'dokumentar': ('dokumentar',),
'dokumentaren': ('dokumentar',),
'dokumentarene': ('dokumentar',),
'dokumentarer': ('dokumentar',),
'domenenavn': ('domenenavn',),
'domenenavna': ('domenenavn',),
'domenenavnene': ('domenenavn',),
'domenenavnet': ('domenenavn',),
'dong': ('dong',),
'dongen': ('dong',),
'dongene': ('dong',),
'donger': ('dong',),
'dopingjeger': ('dopingjeger',),
'dopingjegere': ('dopingjeger',),
'dopingjegeren': ('dopingjeger',),
'dopingjegerer': ('dopingjeger',),
'dopingjegerne': ('dopingjeger',),
'dosimeter': ('dosimeter',),
'dosimeteret': ('dosimeter',),
'dosimetra': ('dosimeter',),
'dosimetre': ('dosimeter',),
'dosimetrene': ('dosimeter',),
'dosimetret': ('dosimeter',),
'dosimetri': ('dosimetri',),
'dosimetrien': ('dosimetri',),
'dosimetriene': ('dosimetri',),
'dosimetrier': ('dosimetri',),
'dreiesena': ('dreiesene',),
'dreiesene': ('dreiesene',),
'dreiesenen': ('dreiesene',),
'dreiesenene': ('dreiesene',),
'dreiesener': ('dreiesene',),
'dråk': ('dråk',),
'dråka': ('dråk',),
'dråkene': ('dråk',),
'dråket': ('dråk',),
'duatlon': ('duatlon',),
'duatlonen': ('duatlon',),
'duatlonene': ('duatlon',),
'duatloner': ('duatlon',),
'dublon': ('dublon',),
'dublonen': ('dublon',),
'dublonene': ('dublon',),
'dubloner': ('dublon',),
'duopol': ('duopol',),
'duopola': ('duopol',),
'duopolene': ('duopol',),
'duopoler': ('duopol',),
'duopolet': ('duopol',),
'duppeditt': ('duppeditt',),
'duppeditten': ('duppeditt',),
'duppedittene': ('duppeditt',),
'duppeditter': ('duppeditt',),
'DVD-speller': ('DVD-speller',),
'DVD-spellere': ('DVD-speller',),
'DVD-spelleren': ('DVD-speller',),
'DVD-spellerer': ('DVD-speller',),
'DVD-spellerne': ('DVD-speller',),
'dvd-speller': ('dvd-speller',),
'dvd-spellere': ('dvd-speller',),
'dvd-spelleren': ('dvd-speller',),
'dvd-spellerer': ('dvd-speller',),
'dvd-spellerne': ('dvd-speller',),
'DVD-spiller': ('DVD-spiller',),
'DVD-spillere': ('DVD-spiller',),
'DVD-spilleren': ('DVD-spiller',),
'DVD-spillerer': ('DVD-spiller',),
'DVD-spillerne': ('DVD-spiller',),
'dvd-spiller': ('dvd-spiller',),
'dvd-spillere': ('dvd-spiller',),
'dvd-spilleren': ('dvd-spiller',),
'dvd-spillerer': ('dvd-spiller',),
'dvd-spillerne': ('dvd-spiller',),
'dysfatiker': ('dysfatiker',),
'dysfatikere': ('dysfatiker',),
'dysfatikeren': ('dysfatiker',),
'dysfatikerer': ('dysfatiker',),
'dysfatikerne': ('dysfatiker',),
'dyspneen': ('dyspné',),
'dyspneene': ('dyspné',),
'dyspneer': ('dyspné',),
'dyspné': ('dyspné',),
'dyspnéen': ('dyspné',),
'dyspnéene': ('dyspné',),
'dyspnéer': ('dyspné',),
'düsseldorfer': ('düsseldorfer',),
'düsseldorfere': ('düsseldorfer',),
'düsseldorferen': ('düsseldorfer',),
'düsseldorferer': ('düsseldorfer',),
'düsseldorferne': ('düsseldorfer',),
'dødslinja': ('dødslinje',),
'dødslinje': ('dødslinje',),
'dødslinjen': ('dødslinje',),
'dødslinjene': ('dødslinje',),
'dødslinjer': ('dødslinje',),
'eagle': ('eagle',),
'e-brev': ('e-brev',),
'e-breva': ('e-brev',),
'e-brevene': ('e-brev',),
'e-brever': ('e-brev',),
'e-brevet': ('e-brev',),
'ecstasytablett': ('ecstasytablett',),
'ecstasytabletten': ('ecstasytablett',),
'ecstasytablettene': ('ecstasytablett',),
'ecstasytabletter': ('ecstasytablett',),
'eggsella': ('eggselle',),
'eggselle': ('eggselle',),
'eggsellen': ('eggselle',),
'eggsellene': ('eggselle',),
'eggseller': ('eggselle',),
'EKG-apparat': ('EKG-apparat',),
'EKG-apparata': ('EKG-apparat',),
'EKG-apparatene': ('EKG-apparat',),
'EKG-apparater': ('EKG-apparat',),
'EKG-apparatet': ('EKG-apparat',),
'ekg-apparat': ('ekg-apparat',),
'ekg-apparata': ('ekg-apparat',),
'ekg-apparatene': ('ekg-apparat',),
'ekg-apparater': ('ekg-apparat',),
'ekg-apparatet': ('ekg-apparat',),
'ekserptor': ('ekserptor',),
'ekserptoren': ('ekserptor',),
'ekserptorene': ('ekserptor',),
'ekserptorer': ('ekserptor',),
'eksitasjon': ('eksitasjon',),
'eksitasjonen': ('eksitasjon',),
'eksitasjonene': ('eksitasjon',),
'eksitasjoner': ('eksitasjon',),
'ekspedient': ('ekspedient',),
'ekspedienten': ('ekspedient',),
'ekspedientene': ('ekspedient',),
'ekspedienter': ('ekspedient',),
'ekstraksjon': ('ekstraksjon',),
'ekstraksjonen': ('ekstraksjon',),
'ekstraksjonene': ('ekstraksjon',),
'ekstraksjoner': ('ekstraksjon',),
'ekstremidrett': ('ekstremidrett',),
'ekstremidretten': ('ekstremidrett',),
'ekstremidrettene': ('ekstremidrett',),
'ekstremidretter': ('ekstremidrett',),
'ekstremsport': ('ekstremsport',),
'ekstremsporten': ('ekstremsport',),
'ekstremsportene': ('ekstremsport',),
'ekstremsporter': ('ekstremsport',),
'ekstroversjon': ('ekstroversjon',),
'ekstroversjonen': ('ekstroversjon',),
'ekstroversjonene': ('ekstroversjon',),
'ekstroversjoner': ('ekstroversjon',),
'ekstruder': ('ekstruder',),
'ekstrudere': ('ekstruder',),
'ekstruderen': ('ekstruder',),
'ekstruderer': ('ekstruder',),
'ekstruderne': ('ekstruder',),
'elektor': ('elektor',),
'elektoren': ('elektor',),
'elektorene': ('elektor',),
'elektorer': ('elektor',),
'elektrokardiograf': ('elektrokardiograf',),
'elektrokardiografen': ('elektrokardiograf',),
'elektrokardiografene': ('elektrokardiograf',),
'elektrokardiografer': ('elektrokardiograf',),
'elektroniker': ('elektroniker',),
'elektronikere': ('elektroniker',),
'elektronikeren': ('elektroniker',),
'elektronikerne': ('elektroniker',),
'elitisme': ('elitisme',),
'elitismen': ('elitisme',),
'elitismene': ('elitisme',),
'elitismer': ('elitisme',),
'ellevteplass': ('ellevteplass',),
'ellevteplassen': ('ellevteplass',),
'ellevteplassene': ('ellevteplass',),
'ellevteplasser': ('ellevteplass',),
'emblematikk': ('emblematikk',),
'emblematikken': ('emblematikk',),
'emblematikkene': ('emblematikk',),
'emblematikker': ('emblematikk',),
'eminens': ('eminens',),
'eminensen': ('eminens',),
'eminensene': ('eminens',),
'eminenser': ('eminens',),
'emirataraber': ('emirataraber',),
'emiratarabere': ('emirataraber',),
'emirataraberen': ('emirataraber',),
'emirataraberer': ('emirataraber',),
'emirataraberne': ('emirataraber',),
'empati': ('empati',),
'empatien': ('empati',),
'empatiene': ('empati',),
'empatier': ('empati',),
'enblocavskriving': ('enblocavskriving',),
'enblocavskrivinga': ('enblocavskriving',),
'enblocavskrivingen': ('enblocavskriving',),
'enblocavskrivingene': ('enblocavskriving',),
'enblocavskrivinger': ('enblocavskriving',),
'enblocavskrivning': ('enblocavskrivning',),
'enblocavskrivninga': ('enblocavskrivning',),
'enblocavskrivningen': ('enblocavskrivning',),
'enblocavskrivningene': ('enblocavskrivning',),
'enblocavskrivninger': ('enblocavskrivning',),
'encyklopedist': ('encyklopedist',),
'encyklopedisten': ('encyklopedist',),
'encyklopedistene': ('encyklopedist',),
'encyklopedister': ('encyklopedist',),
'enduro': ('enduro',),
'enduroen': ('enduro',),
'enduroene': ('enduro',),
'enduroer': ('enduro',),
'energiselskap': ('energiselskap',),
'energiselskapa': ('energiselskap',),
'energiselskapene': ('energiselskap',),
'energiselskaper': ('energiselskap',),
'energiselskapet': ('energiselskap',),
'enesella': ('eneselle',),
'eneselle': ('eneselle',),
'enesellen': ('eneselle',),
'enesellene': ('eneselle',),
'eneseller': ('eneselle',),
'ensyklika': ('ensyklika',),
'ensyklikaen': ('ensyklika',),
'ensyklikaene': ('ensyklika',),
'ensyklikaer': ('ensyklika',),
'ensyklopedi': ('ensyklopedi',),
'ensyklopedien': ('ensyklopedi',),
'ensyklopediene': ('ensyklopedi',),
'ensyklopedier': ('ensyklopedi',),
'ensyklopedist': ('ensyklopedist',),
'ensyklopedisten': ('ensyklopedist',),
'ensyklopedistene': ('ensyklopedist',),
'ensyklopedister': ('ensyklopedist',),
'enterteiner': ('enterteiner',),
'enterteinere': ('enterteiner',),
'enterteineren': ('enterteiner',),
'enterteinerer': ('enterteiner',),
'enterteinerne': ('enterteiner',),
'entreprenørskap': ('entreprenørskap',),
'entreprenørskapa': ('entreprenørskap',),
'entreprenørskapene': ('entreprenørskap',),
'entreprenørskapet': ('entreprenørskap',),
'epiduralbedøvelse': ('epiduralbedøvelse',),
'epiduralbedøvelseen': ('epiduralbedøvelse',),
'epiduralbedøvelseene': ('epiduralbedøvelse',),
'epiduralbedøvelseer': ('epiduralbedøvelse',),
'episenter': ('episenter',),
'episenteret': ('episenter',),
'episentra': ('episenter',),
'episentre': ('episenter',),
'episentrene': ('episenter',),
'episentret': ('episenter',),
'episentra': ('episentrum',),
'episentraene': ('episentrum',),
'episentre': ('episentrum',),
'episentrene': ('episentrum',),
'episentret': ('episentrum',),
'episentrum': ('episentrum',),
'episentrumet': ('episentrum',),
'epitelsella': ('epitelselle',),
'epitelselle': ('epitelselle',),
'epitelsellen': ('epitelselle',),
'epitelsellene': ('epitelselle',),
'epitelseller': ('epitelselle',),
'e-post': ('e-post',),
'e-posten': ('e-post',),
'e-postene': ('e-post',),
'e-poster': ('e-post',),
'e-postadresse': ('e-postadresse',),
'e-postadresseen': ('e-postadresse',),
'e-postadresseene': ('e-postadresse',),
'e-postadresseer': ('e-postadresse',),
'epsilon': ('epsilon',),
'epsilonen': ('epsilon',),
'epsilonene': ('epsilon',),
'epsiloner': ('epsilon',),
'etablerer': ('etablerer',),
'etablerere': ('etablerer',),
'etablereren': ('etablerer',),
'etablererne': ('etablerer',),
'etnisitet': ('etnisitet',),
'etnisiteten': ('etnisitet',),
'etnisitetene': ('etnisitet',),
'etnisiteter': ('etnisitet',),
'eudaimonisme': ('eudaimonisme',),
'eudaimonismen': ('eudaimonisme',),
'eudaimonismene': ('eudaimonisme',),
'eudaimonismer': ('eudaimonisme',),
'EU-land': ('EU-land',),
'EU-landa': ('EU-land',),
'EU-landene': ('EU-land',),
'EU-landet': ('EU-land',),
'EU-medlemskap': ('EU-medlemskap',),
'EU-medlemskapa': ('EU-medlemskap',),
'EU-medlemskapene': ('EU-medlemskap',),
'EU-medlemskapet': ('EU-medlemskap',),
'euroland': ('euroland',),
'eurolanda': ('euroland',),
'eurolandene': ('euroland',),
'eurolandet': ('euroland',),
'evertebrat': ('evertebrat',),
'evertebraten': ('evertebrat',),
'evertebratene': ('evertebrat',),
'evertebrater': ('evertebrat',),
'fabrikasjonsfeil': ('fabrikasjonsfeil',),
'fabrikasjonsfeila': ('fabrikasjonsfeil',),
'fabrikasjonsfeilen': ('fabrikasjonsfeil',),
'fabrikasjonsfeilene': ('fabrikasjonsfeil',),
'fairway': ('fairway',),
'fairwayen': ('fairway',),
'fairwayene': ('fairway',),
'fairwayer': ('fairway',),
'fait': ('fait',),
'faiten': ('fait',),
'faitene': ('fait',),
'faiter': ('fait',),
'faiter': ('faiter',),
'faitere': ('faiter',),
'faiteren': ('faiter',),
'faiterne': ('faiter',),
'falafel': ('falafel',),
'falafelen': ('falafel',),
'falafelene': ('falafel',),
'falafeler': ('falafel',),
'falloskult(us)': ('falloskult(us)',),
'falloskult(us)en': ('falloskult(us)',),
'falloskult(us)ene': ('falloskult(us)',),
'falloskult(us)er': ('falloskult(us)',),
'fangesella': ('fangeselle',),
'fangeselle': ('fangeselle',),
'fangesellen': ('fangeselle',),
'fangesellene': ('fangeselle',),
'fangeseller': ('fangeselle',),
'fantombilda': ('fantombilde',),
'fantombilde': ('fantombilde',),
'fantombildene': ('fantombilde',),
'fantombilder': ('fantombilde',),
'fantombildet': ('fantombilde',),
'fantomløp': ('fantomløp',),
'fantomløpa': ('fantomløp',),
'fantomløpene': ('fantomløp',),
'fantomløpet': ('fantomløp',),
'fantomtegning': ('fantomtegning',),
'fantomtegninga': ('fantomtegning',),
'fantomtegningen': ('fantomtegning',),
'fantomtegningene': ('fantomtegning',),
'fantomtegninger': ('fantomtegning',),
'fargesella': ('fargeselle',),
'fargeselle': ('fargeselle',),
'fargesellen': ('fargeselle',),
'fargesellene': ('fargeselle',),
'fargeseller': ('fargeselle',),
'farmerklubb': ('farmerklubb',),
'farmerklubben': ('farmerklubb',),
'farmerklubbene': ('farmerklubb',),
'farmerklubber': ('farmerklubb',),
'farmerlag': ('farmerlag',),
'farmerlaga': ('farmerlag',),
'farmerlagene': ('farmerlag',),
'farmerlaget': ('farmerlag',),
'fasinasjon': ('fasinasjon',),
'fasinasjonen': ('fasinasjon',),
'fasinasjonene': ('fasinasjon',),
'fasinasjoner': ('fasinasjon',),
'fasisme': ('fasisme',),
'fasismen': ('fasisme',),
'fasismene': ('fasisme',),
'fasismer': ('fasisme',),
'fasist': ('fasist',),
'fasisten': ('fasist',),
'fasistene': ('fasist',),
'fasister': ('fasist',),
'fastmerka': ('fastmerke',),
'fastmerke': ('fastmerke',),
'fastmerkene': ('fastmerke',),
'fastmerker': ('fastmerke',),
'fastmerket': ('fastmerke',),
'fastpunkt': ('fastpunkt',),
'fastpunkta': ('fastpunkt',),
'fastpunktene': ('fastpunkt',),
'fastpunkter': ('fastpunkt',),
'fastpunktet': ('fastpunkt',),
'fasttelefon': ('fasttelefon',),
'fasttelefonen': ('fasttelefon',),
'fasttelefonene': ('fasttelefon',),
'fasttelefoner': ('fasttelefon',),
'faunakriminalitet': ('faunakriminalitet',),
'faunakriminaliteten': ('faunakriminalitet',),
'faunakriminalitetene': ('faunakriminalitet',),
'faunakriminaliteter': ('faunakriminalitet',),
'feider': ('feider',),
'feidere': ('feider',),
'feideren': ('feider',),
'feiderne': ('feider',),
'feidingkontroll': ('feidingkontroll',),
'feidingkontrollen': ('feidingkontroll',),
'feidingkontrollene': ('feidingkontroll',),
'feidingkontroller': ('feidingkontroll',),
'femininitet': ('femininitet',),
'femininiteten': ('femininitet',),
'femininitetene': ('femininitet',),
'femininiteter': ('femininitet',),
'femkronemynt': ('femkronemynt',),
'femkronemynten': ('femkronemynt',),
'femkronemyntene': ('femkronemynt',),
'femkronemynter': ('femkronemynt',),
'femtiendedel': ('femtiendedel',),
'femtiendedelen': ('femtiendedel',),
'femtiendedelene': ('femtiendedel',),
'femtiendedeler': ('femtiendedel',),
'fengselssella': ('fengselsselle',),
'fengselsselle': ('fengselsselle',),
'fengselssellen': ('fengselsselle',),
'fengselssellene': ('fengselsselle',),
'fengselsseller': ('fengselsselle',),
'ferritt': ('ferritt',),
'ferritten': ('ferritt',),
'ferrittene': ('ferritt',),
'ferritter': ('ferritt',),
'fetaost': ('fetaost',),
'fetaosten': ('fetaost',),
'fetaostene': ('fetaost',),
'fetaoster': ('fetaost',),
'fettsella': ('fettselle',),
'fettselle': ('fettselle',),
'fettsellen': ('fettselle',),
'fettsellene': ('fettselle',),
'fettseller': ('fettselle',),
'fibromyalgi': ('fibromyalgi',),
'fibromyalgien': ('fibromyalgi',),
'fibromyalgiene': ('fibromyalgi',),
'fibromyalgier': ('fibromyalgi',),
'fideikommiss': ('fideikommiss',),
'fideikommissa': ('fideikommiss',),
'fideikommissene': ('fideikommiss',),
'fideikommisser': ('fideikommiss',),
'fideikommisset': ('fideikommiss',),
'fiduskunst': ('fiduskunst',),
'fiduskunsten': ('fiduskunst',),
'fiduskunstene': ('fiduskunst',),
'fiduskunster': ('fiduskunst',),
'fiffel': ('fiffel',),
'fiffela': ('fiffel',),
'fiffelene': ('fiffel',),
'fiffelet': ('fiffel',),
'filmografi': ('filmografi',),
'filmografien': ('filmografi',),
'filmografiene': ('filmografi',),
'filmografier': ('filmografi',),
'filtsbrett': ('filtsbrett',),
'filtsbretta': ('filtsbrett',),
'filtsbrettene': ('filtsbrett',),
'filtsbretter': ('filtsbrett',),
'filtsbrettet': ('filtsbrett',),
'finisj': ('finisj',),
'finisjen': ('finisj',),
'finisjene': ('finisj',),
'finisjer': ('finisj',),
'fireliterskanna': ('fireliterskanne',),
'fireliterskanne': ('fireliterskanne',),
'fireliterskannen': ('fireliterskanne',),
'fireliterskannene': ('fireliterskanne',),
'fireliterskanner': ('fireliterskanne',),
'firetakter': ('firetakter',),
'firetaktere': ('firetakter',),
'firetakteren': ('firetakter',),
'firetakterne': ('firetakter',),
'firhjulsdrift': ('firhjulsdrift',),
'firhjulsdrifta': ('firhjulsdrift',),
'firhjulsdriften': ('firhjulsdrift',),
'firhjulsdriftene': ('firhjulsdrift',),
'firhjulsdrifter': ('firhjulsdrift',),
'five-a-side': ('five-a-side',),
'fjernarbeid': ('fjernarbeid',),
'fjernarbeida': ('fjernarbeid',),
'fjernarbeidene': ('fjernarbeid',),
'fjernarbeidet': ('fjernarbeid',),
'fjøremakk': ('fjøremakk',),
'fjøremakken': ('fjøremakk',),
'fjøremakkene': ('fjøremakk',),
'fjøremakker': ('fjøremakk',),
'fjøremark': ('fjøremark',),
'fjøremarken': ('fjøremark',),
'fjøremarkene': ('fjøremark',),
'fjøremarker': ('fjøremark',),
'fjøremål': ('fjøremål',),
'fjøremåla': ('fjøremål',),
'fjøremålene': ('fjøremål',),
'fjøremålet': ('fjøremål',),
'fjøresand': ('fjøresand',),
'fjøresanden': ('fjøresand',),
'fjøresandene': ('fjøresand',),
'fjøresander': ('fjøresand',),
'flaggvind': ('flaggvind',),
'flaggvinden': ('flaggvind',),
'flaggvindene': ('flaggvind',),
'flaggvinder': ('flaggvind',),
'flaskemelk': ('flaskemelk',),
'flaskemelka': ('flaskemelk',),
'flaskemelken': ('flaskemelk',),
'flaskemelkene': ('flaskemelk',),
'flaskemelker': ('flaskemelk',),
'flaskemjølk': ('flaskemjølk',),
'flaskemjølka': ('flaskemjølk',),
'flaskemjølken': ('flaskemjølk',),
'flaskemjølkene': ('flaskemjølk',),
'flaskemjølker': ('flaskemjølk',),
'flatfisk': ('flatfisk',),
'flatfisken': ('flatfisk',),
'flatfiskene': ('flatfisk',),
'flatfisker': ('flatfisk',),
'flerfødsel': ('flerfødsel',),
'flerfødselen': ('flerfødsel',),
'flerfødslene': ('flerfødsel',),
'flerfødsler': ('flerfødsel',),
'flerling': ('flerling',),
'flerlingen': ('flerling',),
'flerlingene': ('flerling',),
'flerlinger': ('flerling',),
'fliselegger': ('fliselegger',),
'fliseleggere': ('fliselegger',),
'fliseleggeren': ('fliselegger',),
'fliseleggerne': ('fliselegger',),
'flislegger': ('flislegger',),
'flisleggere': ('flislegger',),
'flisleggeren': ('flislegger',),
'flisleggerne': ('flislegger',),
'flush': ('flush',),
'flushen': ('flush',),
'flushene': ('flush',),
'flusher': ('flush',),
'flygeregistrator': ('flygeregistrator',),
'flygeregistratoren': ('flygeregistrator',),
'flygeregistratorene': ('flygeregistrator',),
'flygeregistratorer': ('flygeregistrator',),
'flygning': ('flygning',),
'flygninga': ('flygning',),
'flygningen': ('flygning',),
'flygningene': ('flygning',),
'flygninger': ('flygning',),
'flyveblad': ('flyveblad',),
'flyveblada': ('flyveblad',),
'flyvebladene': ('flyveblad',),
'flyveblader': ('flyveblad',),
'flyvebladet': ('flyveblad',),
'flyvefisk': ('flyvefisk',),
'flyvefisken': ('flyvefisk',),
'flyvefiskene': ('flyvefisk',),
'flyvefisker': ('flyvefisk',),
'flyvehud': ('flyvehud',),
'flyvehuda': ('flyvehud',),
'flyvehuden': ('flyvehud',),
'flyvehudene': ('flyvehud',),
'flyvehuder': ('flyvehud',),
'flyveideen': ('flyveidé',),
'flyveideene': ('flyveidé',),
'flyveideer': ('flyveidé',),
'flyveidé': ('flyveidé',),
'flyveidéen': ('flyveidé',),
'flyveidéene': ('flyveidé',),
'flyveidéer': ('flyveidé',),
'flyveleder': ('flyveleder',),
'flyveledere': ('flyveleder',),
'flyvelederen': ('flyveleder',),
'flyvelederne': ('flyveleder',),
'flyvemaskin': ('flyvemaskin',),
'flyvemaskinen': ('flyvemaskin',),
'flyvemaskinene': ('flyvemaskin',),
'flyvemaskiner': ('flyvemaskin',),
'flyvende tallerken': ('flyvende tallerken',),
'flyvende tallerkenen': ('flyvende tallerken',),
'flyvende tallerkenene': ('flyvende tallerken',),
'flyvende tallerkener': ('flyvende tallerken',),
'flyveregistrator': ('flyveregistrator',),
'flyveregistratoren': ('flyveregistrator',),
'flyveregistratorene': ('flyveregistrator',),
'flyveregistratorer': ('flyveregistrator',),
'flyvesand': ('flyvesand',),
'flyvesanden': ('flyvesand',),
'flyvesandene': ('flyvesand',),
'flyvesander': ('flyvesand',),
'fobiker': ('fobiker',),
'fobikere': ('fobiker',),
'fobikeren': ('fobiker',),
'fobikerne': ('fobiker',),
'foldekniv': ('foldekniv',),
'foldekniven': ('foldekniv',),
'foldeknivene': ('foldekniv',),
'foldekniver': ('foldekniv',),
'follikkel': ('follikkel',),
'follikkelen': ('follikkel',),
'folliklene': ('follikkel',),
'follikler': ('follikkel',),
'fondant': ('fondant',),
'fondanten': ('fondant',),
'fondantene': ('fondant',),
'fondanter': ('fondant',),
'fonogram': ('fonogram',),
'fonogramma': ('fonogram',),
'fonogrammene': ('fonogram',),
'fonogrammer': ('fonogram',),
'fonogrammet': ('fonogram',),
'forstevn': ('forstevn',),
'forstevnen': ('forstevn',),
'forstevnene': ('forstevn',),
'forstevner': ('forstevn',),
'fotogram': ('fotogram',),
'fotogramma': ('fotogram',),
'fotogrammene': ('fotogram',),
'fotogrammer': ('fotogram',),
'fotogrammet': ('fotogram',),
'fotolyse': ('fotolyse',),
'fotolysen': ('fotolyse',),
'fotolysene': ('fotolyse',),
'fotolyser': ('fotolyse',),
'fotosella': ('fotoselle',),
'fotoselle': ('fotoselle',),
'fotosellen': ('fotoselle',),
'fotosellene': ('fotoselle',),
'fotoseller': ('fotoselle',),
'frampek': ('frampek',),
'frampeka': ('frampek',),
'frampekene': ('frampek',),
'frampeket': ('frampek',),
'framstevn': ('framstevn',),
'framstevnen': ('framstevn',),
'framstevnene': ('framstevn',),
'framstevner': ('framstevn',),
'frempek': ('frempek',),
'frempeka': ('frempek',),
'frempekene': ('frempek',),
'frempeket': ('frempek',),
'fremstevn': ('fremstevn',),
'fremstevnen': ('fremstevn',),
'fremstevnene': ('fremstevn',),
'fremstevner': ('fremstevn',),
'frislepp': ('frislepp',),
'frisleppa': ('frislepp',),
'frisleppene': ('frislepp',),
'frisleppet': ('frislepp',),
'frislipp': ('frislipp',),
'frislippa': ('frislipp',),
'frislippene': ('frislipp',),
'frislippet': ('frislipp',),
'ftalat': ('ftalat',),
'ftalata': ('ftalat',),
'ftalatene': ('ftalat',),
'ftalatet': ('ftalat',),
'fuktsperra': ('fuktsperre',),
'fuktsperre': ('fuktsperre',),
'fuktsperren': ('fuktsperre',),
'fuktsperrene': ('fuktsperre',),
'fuktsperrer': ('fuktsperre',),
'funksjonstast': ('funksjonstast',),
'funksjonstasten': ('funksjonstast',),
'funksjonstastene': ('funksjonstast',),
'funksjonstaster': ('funksjonstast',),
'fyllitt': ('fyllitt',),
'fyllitten': ('fyllitt',),
'fyllittene': ('fyllitt',),
'fyllitter': ('fyllitt',),
'føringsbåt': ('føringsbåt',),
'føringsbåten': ('føringsbåt',),
'føringsbåtene': ('føringsbåt',),
'føringsbåter': ('føringsbåt',),
'føringsoffiser': ('føringsoffiser',),
'føringsoffiseren': ('føringsoffiser',),
'føringsoffiserene': ('føringsoffiser',),
'føringsoffiserer': ('føringsoffiser',),
'førstevalg': ('førstevalg',),
'førstevalga': ('førstevalg',),
'førstevalgene': ('førstevalg',),
'førstevalget': ('førstevalg',),
'førtiendedel': ('førtiendedel',),
'førtiendedelen': ('førtiendedel',),
'førtiendedelene': ('førtiendedel',),
'førtiendedeler': ('førtiendedel',),
'føydalstat': ('føydalstat',),
'føydalstaten': ('føydalstat',),
'føydalstatene': ('føydalstat',),
'føydalstater': ('føydalstat',),
'føydalsystem': ('føydalsystem',),
'føydalsystema': ('føydalsystem',),
'føydalsystemene': ('føydalsystem',),
'føydalsystemet': ('føydalsystem',),
'gagg': ('gagg',),
'gaggen': ('gagg',),
'gaggene': ('gagg',),
'gagger': ('gagg',),
'gaid': ('gaid',),
'gaiden': ('gaid',),
'gaidene': ('gaid',),
'gaider': ('gaid',),
'galaktose': ('galaktose',),
'galaktosen': ('galaktose',),
'galaktosene': ('galaktose',),
'galaktoser': ('galaktose',),
'gallerist': ('gallerist',),
'galleristen': ('gallerist',),
'galleristene': ('gallerist',),
'gallerister': ('gallerist',),
'gardsturisme': ('gardsturisme',),
'gardsturismen': ('gardsturisme',),
'gardsturismene': ('gardsturisme',),
'gardsturismer': ('gardsturisme',),
'gebursdag': ('gebursdag',),
'gebursdagen': ('gebursdag',),
'gebursdagene': ('gebursdag',),
'gebursdager': ('gebursdag',),
'gekko': ('gekko',),
'gekkoen': ('gekko',),
'gekkoene': ('gekko',),
'gekkoer': ('gekko',),
'genitivform': ('genitivform',),
'genitivforma': ('genitivform',),
'genitivformen': ('genitivform',),
'genitivformene': ('genitivform',),
'genitivformer': ('genitivform',),
'genitiv-s': ('genitiv-s',),
'genitiv-s-en': ('genitiv-s',),
'genitiv-s-ene': ('genitiv-s',),
'genitiv-s-er': ('genitiv-s',),
'genterapi': ('genterapi',),
'genterapien': ('genterapi',),
'genterapiene': ('genterapi',),
'genterapier': ('genterapi',),
'geovarme': ('geovarme',),
'geovarmen': ('geovarme',),
'geovarmene': ('geovarme',),
'geovarmer': ('geovarme',),
'geriater': ('geriater',),
'geriatere': ('geriater',),
'geriateren': ('geriater',),
'geriaterne': ('geriater',),
'gjengroing': ('gjengroing',),
'gjengroinga': ('gjengroing',),
'gjengroingen': ('gjengroing',),
'gjengroingene': ('gjengroing',),
'gjengroinger': ('gjengroing',),
'gjerdesag': ('gjerdesag',),
'gjerdesaga': ('gjerdesag',),
'gjerdesagen': ('gjerdesag',),
'gjerdesagene': ('gjerdesag',),
'gjerdesager': ('gjerdesag',),
'glassblåseri': ('glassblåseri',),
'glassblåseria': ('glassblåseri',),
'glassblåseriene': ('glassblåseri',),
'glassblåserier': ('glassblåseri',),
'glassblåseriet': ('glassblåseri',),
'gluttsnipa': ('gluttsnipe',),
'gluttsnipe': ('gluttsnipe',),
'gluttsnipen': ('gluttsnipe',),
'gluttsnipene': ('gluttsnipe',),
'gluttsniper': ('gluttsnipe',),
'gobelengbroderi': ('gobelengbroderi',),
'gobelengbroderia': ('gobelengbroderi',),
'gobelengbroderiene': ('gobelengbroderi',),
'gobelengbroderier': ('gobelengbroderi',),
'gobelengbroderiet': ('gobelengbroderi',),
'gobelengtapet': ('gobelengtapet',),
'gobelengtapeta': ('gobelengtapet',),
'gobelengtapetene': ('gobelengtapet',),
'gobelengtapeter': ('gobelengtapet',),
'gobelengtapetet': ('gobelengtapet',),
'gobelengtrekk': ('gobelengtrekk',),
'gobelengtrekka': ('gobelengtrekk',),
'gobelengtrekkene': ('gobelengtrekk',),
'gobelengtrekket': ('gobelengtrekk',),
'gobelengvev': ('gobelengvev',),
'gobelengveva': ('gobelengvev',),
'gobelengvevene': ('gobelengvev',),
'gobelengvevet': ('gobelengvev',),
'GPS': ('GPS',),
'GPS-en': ('GPS',),
'GPS-ene': ('GPS',),
'GPS-er': ('GPS',),
'GPS-mottager': ('GPS-mottager',),
'GPS-mottagere': ('GPS-mottager',),
'GPS-mottageren': ('GPS-mottager',),
'GPS-mottagerne': ('GPS-mottager',),
'GPS-mottaker': ('GPS-mottaker',),
'GPS-mottakere': ('GPS-mottaker',),
'GPS-mottakeren': ('GPS-mottaker',),
'GPS-mottakerer': ('GPS-mottaker',),
'GPS-mottakerne': ('GPS-mottaker',),
'GPS-sender': ('GPS-sender',),
'GPS-sendere': ('GPS-sender',),
'GPS-senderen': ('GPS-sender',),
'GPS-senderne': ('GPS-sender',),
'grappa': ('grappa',),
'grappaen': ('grappa',),
'grappaene': ('grappa',),
'grappaer': ('grappa',),
'graps': ('graps',),
'grapsa': ('graps',),
'grapsene': ('graps',),
'grapset': ('graps',),
'grillvott': ('grillvott',),
'grillvotten': ('grillvott',),
'grillvottene': ('grillvott',),
'grillvotter': ('grillvott',),
'gruff': ('gruff',),
'gruffa': ('gruff',),
'gruffene': ('gruff',),
'gruffet': ('gruff',),
'grådighetskultur': ('grådighetskultur',),
'grådighetskulturen': ('grådighetskultur',),
'grådighetskulturene': ('grådighetskultur',),
'grådighetskulturer': ('grådighetskultur',),
'gråmarked': ('gråmarked',),
'gråmarkeda': ('gråmarked',),
'gråmarkedene': ('gråmarked',),
'gråmarkeder': ('gråmarked',),
'gråmarkedet': ('gråmarked',),
'guarani': ('guarani',),
'guaranien': ('guarani',),
'guaraniene': ('guarani',),
'guaranier': ('guarani',),
'guarani': ('guarani',),
'guaranien': ('guarani',),
'guaraniene': ('guarani',),
'guaranier': ('guarani',),
'gurkha': ('gurkha',),
'gurkhaen': ('gurkha',),
'gurkhaene': ('gurkha',),
'gurkhaer': ('gurkha',),
'gåfold': ('gåfold',),
'gåfolden': ('gåfold',),
'gåfoldene': ('gåfold',),
'gåfolder': ('gåfold',),
'gåsplitt': ('gåsplitt',),
'gåsplitten': ('gåsplitt',),
'gåsplittene': ('gåsplitt',),
'gåsplitter': ('gåsplitt',),
'hacker': ('hacker',),
'hackere': ('hacker',),
'hackeren': ('hacker',),
'hackerne': ('hacker',),
'hacking': ('hacking',),
'hackinga': ('hacking',),
'hackingen': ('hacking',),
'hackingene': ('hacking',),
'hackinger': ('hacking',),
'halalkjøtt': ('halalkjøtt',),
'halalkjøtta': ('halalkjøtt',),
'halalkjøttene': ('halalkjøtt',),
'halalkjøttet': ('halalkjøtt',),
'handikapp': ('handikapp',),
'handikappa': ('handikapp',),
'handikappene': ('handikapp',),
'handikapper': ('handikapp',),
'handikappet': ('handikapp',),
'handspålegger': ('handspålegger',),
'handspåleggere': ('handspålegger',),
'handspåleggeren': ('handspålegger',),
'handspåleggerne': ('handspålegger',),
'handtelling': ('handtelling',),
'handtellinga': ('handtelling',),
'handtellingen': ('handtelling',),
'handtellingene': ('handtelling',),
'handtellinger': ('handtelling',),
'hangglider': ('hangglider',),
'hangglidere': ('hangglider',),
'hangglideren': ('hangglider',),
'hanggliderer': ('hangglider',),
'hanggliderne': ('hangglider',),
'hanggliding': ('hanggliding',),
'hangglidinga': ('hanggliding',),
'hangglidingen': ('hanggliding',),
'hangglidingene': ('hanggliding',),
'hangglidinger': ('hanggliding',),
'hardhvete': ('hardhvete',),
'hardhveten': ('hardhvete',),
'hardhvetene': ('hardhvete',),
'hardhveter': ('hardhvete',),
'hardplast': ('hardplast',),
'hardplasten': ('hardplast',),
'hardplastene': ('hardplast',),
'hardplaster': ('hardplast',),
'healing': ('healing',),
'healingen': ('healing',),
'healingene': ('healing',),
'healinger': ('healing',),
'hedding': ('hedding',),
'heddingen': ('hedding',),
'heddingene': ('hedding',),
'heddinger': ('hedding',),
'heftstyrke': ('heftstyrke',),
'heftstyrken': ('heftstyrke',),
'heftstyrkene': ('heftstyrke',),
'heftstyrker': ('heftstyrke',),
'heimbesøk': ('heimbesøk',),
'heimbesøka': ('heimbesøk',),
'heimbesøkene': ('heimbesøk',),
'heimbesøket': ('heimbesøk',),
'heimebesøk': ('heimebesøk',),
'heimebesøka': ('heimebesøk',),
'heimebesøkene': ('heimebesøk',),
'heimebesøket': ('heimebesøk',),
'heimepleier': ('heimepleier',),
'heimepleiere': ('heimepleier',),
'heimepleieren': ('heimepleier',),
'heimepleierer': ('heimepleier',),
'heimepleierne': ('heimepleier',),
'heimesida': ('heimeside',),
'heimeside': ('heimeside',),
'heimesiden': ('heimeside',),
'heimesidene': ('heimeside',),
'heimesider': ('heimeside',),
'heimkommue': ('heimkommue',),
'heimkommuen': ('heimkommue',),
'heimkommuene': ('heimkommue',),
'heimkommuer': ('heimkommue',),
'helbreder': ('helbreder',),
'helbredere': ('helbreder',),
'helbrederen': ('helbreder',),
'helbrederne': ('helbreder',),
'hentesveis': ('hentesveis',),
'hentesveisen': ('hentesveis',),
'hentesveisene': ('hentesveis',),
'hentesveiser': ('hentesveis',),
'heuristikk': ('heuristikk',),
'heuristikken': ('heuristikk',),
'heuristikkene': ('heuristikk',),
'heuristikker': ('heuristikk',),
'hittlista': ('hittliste',),
'hittliste': ('hittliste',),
'hittlisten': ('hittliste',),
'hittlistene': ('hittliste',),
'hittlister': ('hittliste',),
'hittlåt': ('hittlåt',),
'hittlåta': ('hittlåt',),
'hittlåten': ('hittlåt',),
'hittlåtene': ('hittlåt',),
'hittlåter': ('hittlåt',),
'hjembesøk': ('hjembesøk',),
'hjembesøka': ('hjembesøk',),
'hjembesøkene': ('hjembesøk',),
'hjembesøket': ('hjembesøk',),
'hjemmepleier': ('hjemmepleier',),
'hjemmepleiere': ('hjemmepleier',),
'hjemmepleieren': ('hjemmepleier',),
'hjemmepleierer': ('hjemmepleier',),
'hjemmepleierne': ('hjemmepleier',),
'hjemmesida': ('hjemmeside',),
'hjemmeside': ('hjemmeside',),
'hjemmesiden': ('hjemmeside',),
'hjemmesidene': ('hjemmeside',),
'hjemmesider': ('hjemmeside',),
'hjortefamilie': ('hjortefamilie',),
'hjortefamilien': ('hjortefamilie',),
'hjortefamiliene': ('hjortefamilie',),
'hjortefamilier': ('hjortefamilie',),
'hodesett': ('hodesett',),
'hodesetta': ('hodesett',),
'hodesettene': ('hodesett',),
'hodesettet': ('hodesett',),
'holdup': ('holdup',),
'holdupen': ('holdup',),
'holdupene': ('holdup',),
'holduper': ('holdup',),
'hole-in-one': ('hole-in-one',),
'holisme': ('holisme',),
'holismen': ('holisme',),
'holismene': ('holisme',),
'holismer': ('holisme',),
'homeopat': ('homeopat',),
'homeopaten': ('homeopat',),
'homeopatene': ('homeopat',),
'homeopater': ('homeopat',),
'homeopati': ('homeopati',),
'homeopatien': ('homeopati',),
'homeopatiene': ('homeopati',),
'homeopatier': ('homeopati',),
'homologi': ('homologi',),
'homologien': ('homologi',),
'homologiene': ('homologi',),
'homologier': ('homologi',),
'horemamma': ('horemamma',),
'horemammaen': ('horemamma',),
'horemammaene': ('horemamma',),
'horemammaer': ('horemamma',),
'horeri': ('horeri',),
'horeria': ('horeri',),
'horeriene': ('horeri',),
'horeriet': ('horeri',),
'hotdog': ('hotdog',),
'hotdogen': ('hotdog',),
'hotdogene': ('hotdog',),
'hotdoger': ('hotdog',),
'hott': ('hott',),
'hotten': ('hott',),
'hottene': ('hott',),
'hotter': ('hott',),
'house': ('house',),
'housemusikk': ('housemusikk',),
'housemusikken': ('housemusikk',),
'housemusikkene': ('housemusikk',),
'housemusikker': ('housemusikk',),
'houseparty': ('houseparty',),
'housepartya': ('houseparty',),
'housepartyene': ('houseparty',),
'housepartyer': ('houseparty',),
'housepartyet': ('houseparty',),
'hovedsena': ('hovedsene',),
'hovedsene': ('hovedsene',),
'hovedsenen': ('hovedsene',),
'hovedsenene': ('hovedsene',),
'hovedsener': ('hovedsene',),
'hryvnja': ('hryvnja',),
'hryvnjaen': ('hryvnja',),
'hryvnjaene': ('hryvnja',),
'hryvnjaer': ('hryvnja',),
'hudvann': ('hudvann',),
'hudvanna': ('hudvann',),
'hudvannene': ('hudvann',),
'hudvannet': ('hudvann',),
'hudvatn': ('hudvatn',),
'hudvatna': ('hudvatn',),
'hudvatnene': ('hudvatn',),
'hudvatnet': ('hudvatn',),
'hundrededel': ('hundrededel',),
'hundrededelen': ('hundrededel',),
'hundrededelene': ('hundrededel',),
'hundrededeler': ('hundrededel',),
'hunndjevel': ('hunndjevel',),
'hunndjevelen': ('hunndjevel',),
'hunndjevelene': ('hunndjevel',),
'hunndjeveler': ('hunndjevel',),
'hutu': ('hutu',),
'hutuen': ('hutu',),
'hutuene': ('hutu',),
'hutuer': ('hutu',),
'hybelkanin': ('hybelkanin',),
'hybelkaninen': ('hybelkanin',),
'hybelkaninene': ('hybelkanin',),
'hybelkaniner': ('hybelkanin',),
'hydroterapi': ('hydroterapi',),
'hydroterapien': ('hydroterapi',),
'hydroterapiene': ('hydroterapi',),
'hydroterapier': ('hydroterapi',),
'hynda': ('hynde',),
'hynde': ('hynde',),
'hyndeen': ('hynde',),
'hyndeene': ('hynde',),
'hyndeer': ('hynde',),
'hyndene': ('hynde',),
'hynder': ('hynde',),
'hyndet': ('hynde',),
'hypertekst': ('hypertekst',),
'hyperteksten': ('hypertekst',),
'hypertekstene': ('hypertekst',),
'hypertekster': ('hypertekst',),
'hyposenter': ('hyposenter',),
'hyposenteret': ('hyposenter',),
'hyposentra': ('hyposenter',),
'hyposentre': ('hyposenter',),
'hyposentrene': ('hyposenter',),
'hyposentret': ('hyposenter',),
'hyposentra': ('hyposentrum',),
'hyposentraene': ('hyposentrum',),
'hyposentre': ('hyposentrum',),
'hyposentrene': ('hyposentrum',),
'hyposentret': ('hyposentrum',),
'hyposentrum': ('hyposentrum',),
'hyposentrumet': ('hyposentrum',),
'høgdehus': ('høgdehus',),
'høgdehusa': ('høgdehus',),
'høgdehusene': ('høgdehus',),
'høgdehuset': ('høgdehus',),
'høgdetrening': ('høgdetrening',),
'høgdetreninga': ('høgdetrening',),
'høgdetreningen': ('høgdetrening',),
'høgdetreningene': ('høgdetrening',),
'høgdetreninger': ('høgdetrening',),
'høghastighetsnett': ('høghastighetsnett',),
'høghastighetsnetta': ('høghastighetsnett',),
'høghastighetsnettene': ('høghastighetsnett',),
'høghastighetsnettet': ('høghastighetsnett',),
'høghastighetstog': ('høghastighetstog',),
'høghastighetstoga': ('høghastighetstog',),
'høghastighetstogene': ('høghastighetstog',),
'høghastighetstoget': ('høghastighetstog',),
'høydehus': ('høydehus',),
'høydehusa': ('høydehus',),
'høydehusene': ('høydehus',),
'høydehuset': ('høydehus',),
'høydetrening': ('høydetrening',),
'høydetreninga': ('høydetrening',),
'høydetreningen': ('høydetrening',),
'høydetreningene': ('høydetrening',),
'høydetreninger': ('høydetrening',),
'høyhastighetsnett': ('høyhastighetsnett',),
'høyhastighetsnetta': ('høyhastighetsnett',),
'høyhastighetsnettene': ('høyhastighetsnett',),
'høyhastighetsnettet': ('høyhastighetsnett',),
'høyhastighetstog': ('høyhastighetstog',),
'høyhastighetstoga': ('høyhastighetstog',),
'høyhastighetstogene': ('høyhastighetstog',),
'høyhastighetstoget': ('høyhastighetstog',),
'høytaleranlegg': ('høytaleranlegg',),
'høytaleranlegga': ('høytaleranlegg',),
'høytaleranleggene': ('høytaleranlegg',),
'høytaleranlegget': ('høytaleranlegg',),
'håndtelling': ('håndtelling',),
'håndtellinga': ('håndtelling',),
'håndtellingen': ('håndtelling',),
'håndtellingene': ('håndtelling',),
'håndtellinger': ('håndtelling',),
'hårkløver': ('hårkløver',),
'hårkløvere': ('hårkløver',),
'hårkløveren': ('hårkløver',),
'hårkløverne': ('hårkløver',),
'hårnål': ('hårnål',),
'hårnåla': ('hårnål',),
'hårnålen': ('hårnål',),
'hårnålene': ('hårnål',),
'hårnåler': ('hårnål',),
'id-kort': ('id-kort',),
'id-korta': ('id-kort',),
'id-kortene': ('id-kort',),
'id-kortet': ('id-kort',),
'ID-papir': ('ID-papir',),
'ID-papira': ('ID-papir',),
'ID-papirene': ('ID-papir',),
'ID-papirer': ('ID-papir',),
'ID-papiret': ('ID-papir',),
'id-papir': ('id-papir',),
'id-papira': ('id-papir',),
'id-papirene': ('id-papir',),
'id-papirer': ('id-papir',),
'id-papiret': ('id-papir',),
'imbesilitet': ('imbesilitet',),
'imbesiliteten': ('imbesilitet',),
'imbesilitetene': ('imbesilitet',),
'imbesiliteter': ('imbesilitet',),
'infinitivmerka': ('infinitivmerke',),
'infinitivmerke': ('infinitivmerke',),
'infinitivmerkene': ('infinitivmerke',),
'infinitivmerker': ('infinitivmerke',),
'infinitivmerket': ('infinitivmerke',),
'innfasing': ('innfasing',),
'innfasinga': ('innfasing',),
'innfasingen': ('innfasing',),
'innfasingene': ('innfasing',),
'innfasinger': ('innfasing',),
'innhopper': ('innhopper',),
'innhoppere': ('innhopper',),
'innhopperen': ('innhopper',),
'innhopperne': ('innhopper',),
'innsider': ('innsider',),
'innsidere': ('innsider',),
'innsideren': ('innsider',),
'innsiderne': ('innsider',),
'insentiv': ('insentiv',),
'insentiva': ('insentiv',),
'insentivene': ('insentiv',),
'insentiver': ('insentiv',),
'insentivet': ('insentiv',),
'insest': ('insest',),
'insesten': ('insest',),
'insestene': ('insest',),
'insester': ('insest',),
'insitament': ('insitament',),
'insitamenta': ('insitament',),
'insitamentene': ('insitament',),
'insitamenter': ('insitament',),
'insitamentet': ('insitament',),
'interferon': ('interferon',),
'interferona': ('interferon',),
'interferonene': ('interferon',),
'interferoner': ('interferon',),
'interferonet': ('interferon',),
'Internett-adresse': ('Internett-adresse',),
'Internett-adressea': ('Internett-adresse',),
'Internett-adresseen': ('Internett-adresse',),
'Internett-adresseene': ('Internett-adresse',),
'Internett-adresseer': ('Internett-adresse',),
'intimhygiene': ('intimhygiene',),
'intimhygienen': ('intimhygiene',),
'intimhygienene': ('intimhygiene',),
'intimhygiener': ('intimhygiene',),
'intimisering': ('intimisering',),
'intimiseringa': ('intimisering',),
'intimiseringen': ('intimisering',),
'intimiseringene': ('intimisering',),
'intimiseringer': ('intimisering',),
'intimmassasje': ('intimmassasje',),
'intimmassasjen': ('intimmassasje',),
'intimmassasjene': ('intimmassasje',),
'intimmassasjer': ('intimmassasje',),
'intranett': ('intranett',),
'intranetta': ('intranett',),
'intranettene': ('intranett',),
'intranettet': ('intranett',),
'inuittisk': ('inuittisk',),
'inuittisken': ('inuittisk',),
'inuittiskene': ('inuittisk',),
'inuittisker': ('inuittisk',),
'iota': ('iota',),
'iotaen': ('iota',),
'iotaene': ('iota',),
'iotaer': ('iota',),
'isenesettelse': ('isenesettelse',),
'isenesettelsen': ('isenesettelse',),
'isenesettelsene': ('isenesettelse',),
'isenesettelser': ('isenesettelse',),
'isenesetter': ('isenesetter',),
'isenesettere': ('isenesetter',),
'isenesetteren': ('isenesetter',),
'isenesetterne': ('isenesetter',),
'isenesetting': ('isenesetting',),
'isenesettinga': ('isenesetting',),
'isenesettingen': ('isenesetting',),
'isenesettingene': ('isenesetting',),
'isenesettinger': ('isenesetting',),
'islamisme': ('islamisme',),
'islamismen': ('islamisme',),
'islamismene': ('islamisme',),
'islamismer': ('islamisme',),
'islamist': ('islamist',),
'islamisten': ('islamist',),
'islamistene': ('islamist',),
'islamister': ('islamist',),
'islendingsaga': ('islendingsaga',),
'islendingsagaen': ('islendingsaga',),
'islendingsagaene': ('islendingsaga',),
'islendingsagaer': ('islendingsaga',),
'isop': ('isop',),
'isopen': ('isop',),
'isopene': ('isop',),
'isoper': ('isop',),
'isres': ('isres',),
'isresa': ('isres',),
'isresene': ('isres',),
'isreset': ('isres',),
'IT-næring': ('IT-næring',),
'IT-næringa': ('IT-næring',),
'IT-næringen': ('IT-næring',),
'IT-næringene': ('IT-næring',),
'IT-næringer': ('IT-næring',),
'it-næring': ('it-næring',),
'it-næringa': ('it-næring',),
'it-næringen': ('it-næring',),
'it-næringene': ('it-næring',),
'it-næringer': ('it-næring',),
'IT-revolusjon': ('IT-revolusjon',),
'IT-revolusjonen': ('IT-revolusjon',),
'IT-revolusjonene': ('IT-revolusjon',),
'IT-revolusjoner': ('IT-revolusjon',),
'it-revolusjon': ('it-revolusjon',),
'it-revolusjonen': ('it-revolusjon',),
'it-revolusjonene': ('it-revolusjon',),
'it-revolusjoner': ('it-revolusjon',),
'jackpot': ('jackpot',),
'jackpoten': ('jackpot',),
'jackpotene': ('jackpot',),
'jackpoter': ('jackpot',),
'jamsession': ('jamsession',),
'jamsessionen': ('jamsession',),
'jamsessionene': ('jamsession',),
'jamsessioner': ('jamsession',),
'jett': ('jett',),
'jetten': ('jett',),
'jettene': ('jett',),
'jetter': ('jett',),
'jettalder': ('jettalder',),
'jettaldere': ('jettalder',),
'jettalderen': ('jettalder',),
'jettalderne': ('jettalder',),
'jettaldre': ('jettalder',),
'jettaldrene': ('jettalder',),
'jettaldrer': ('jettalder',),
'jettfart': ('jettfart',),
'jettfarta': ('jettfart',),
'jettfarten': ('jettfart',),
'jettfartene': ('jettfart',),
'jettfarter': ('jettfart',),
'jettfly': ('jettfly',),
'jettflya': ('jettfly',),
'jettflyene': ('jettfly',),
'jettflyet': ('jettfly',),
'jettjager': ('jettjager',),
'jettjagere': ('jettjager',),
'jettjageren': ('jettjager',),
'jettjagerer': ('jettjager',),
'jettjagerne': ('jettjager',),
'jettmaskin': ('jettmaskin',),
'jettmaskinen': ('jettmaskin',),
'jettmaskinene': ('jettmaskin',),
'jettmaskiner': ('jettmaskin',),
'jettmotor': ('jettmotor',),
'jettmotoren': ('jettmotor',),
'jettmotorene': ('jettmotor',),
'jettmotorer': ('jettmotor',),
'jettsett': ('jettsett',),
'jettsetta': ('jettsett',),
'jettsettene': ('jettsett',),
'jettsettet': ('jettsett',),
'jettsetter': ('jettsetter',),
'jettsettere': ('jettsetter',),
'jettsetteren': ('jettsetter',),
'jettsetterne': ('jettsetter',),
'jettski': ('jettski',),
'jettskia': ('jettski',),
'jettskien': ('jettski',),
'jettskiene': ('jettski',),
'jettskier': ('jettski',),
'jettstrøm': ('jettstrøm',),
'jettstrømmen': ('jettstrøm',),
'jettstrømmene': ('jettstrøm',),
'jettstrømmer': ('jettstrøm',),
'jingle': ('jingle',),
'jinglen': ('jingle',),
'jinglene': ('jingle',),
'jingler': ('jingle',),
'jom kippur': ('jom kippur',),
'jukselapp': ('jukselapp',),
'jukselappen': ('jukselapp',),
'jukselappene': ('jukselapp',),
'jukselapper': ('jukselapp',),
'jumbojett': ('jumbojett',),
'jumbojetten': ('jumbojett',),
'jumbojettene': ('jumbojett',),
'jumbojetter': ('jumbojett',),
'kafir': ('kafir',),
'kafiren': ('kafir',),
'kafirene': ('kafir',),
'kafirer': ('kafir',),
'kajalstift': ('kajalstift',),
'kajalstiften': ('kajalstift',),
'kajalstiftene': ('kajalstift',),
'kajalstifter': ('kajalstift',),
'kaks': ('kaks',),
'kaksa': ('kaks',),
'kaksene': ('kaks',),
'kakset': ('kaks',),
'kalasjnikov': ('kalasjnikov',),
'kalasjnikoven': ('kalasjnikov',),
'kalasjnikovene': ('kalasjnikov',),
'kalasjnikover': ('kalasjnikov',),
'kalkunfilm': ('kalkunfilm',),
'kalkunfilmen': ('kalkunfilm',),
'kalkunfilmene': ('kalkunfilm',),
'kalkunfilmer': ('kalkunfilm',),
'kamikazeflyger': ('kamikazeflyger',),
'kamikazeflygere': ('kamikazeflyger',),
'kamikazeflygeren': ('kamikazeflyger',),
'kamikazeflygerer': ('kamikazeflyger',),
'kamikazeflygerne': ('kamikazeflyger',),
'kamtsjatkakrabba': ('kamtsjatkakrabbe',),
'kamtsjatkakrabbe': ('kamtsjatkakrabbe',),
'kamtsjatkakrabben': ('kamtsjatkakrabbe',),
'kamtsjatkakrabbene': ('kamtsjatkakrabbe',),
'kamtsjatkakrabber': ('kamtsjatkakrabbe',),
'kannabis': ('kannabis',),
'kannabisen': ('kannabis',),
'kannabisene': ('kannabis',),
'kannabiser': ('kannabis',),
'kanoner': ('kanoner',),
'kanonere': ('kanoner',),
'kanoneren': ('kanoner',),
'kanonerer': ('kanoner',),
'kanonerne': ('kanoner',),
'kapasitans': ('kapasitans',),
'kapasitansen': ('kapasitans',),
'kapasitansene': ('kapasitans',),
'kapasitanser': ('kapasitans',),
'kaps': ('kaps',),
'kapsen': ('kaps',),
'kapsene': ('kaps',),
'kapser': ('kaps',),
'karavan': ('karavan',),
'karavanen': ('karavan',),
'karavanene': ('karavan',),
'karavaner': ('karavan',),
'kardiolog': ('kardiolog',),
'kardiologen': ('kardiolog',),
'kardiologene': ('kardiolog',),
'kardiologer': ('kardiolog',),
'karting': ('karting',),
'kartingen': ('karting',),
'kartingene': ('karting',),
'kartinger': ('karting',),
'kasakhstaner': ('kasakhstaner',),
'kasakhstanere': ('kasakhstaner',),
'kasakhstaneren': ('kasakhstaner',),
'kasakhstanerne': ('kasakhstaner',),
'kaskett': ('kaskett',),
'kasketten': ('kaskett',),
'kaskettene': ('kaskett',),
'kasketter': ('kaskett',),
'kastemerka': ('kastemerke',),
'kastemerke': ('kastemerke',),
'kastemerkene': ('kastemerke',),
'kastemerker': ('kastemerke',),
'kastemerket': ('kastemerke',),
'keitering': ('keitering',),
'keiteringen': ('keitering',),
'keiteringene': ('keitering',),
'keiteringer': ('keitering',),
'kendo': ('kendo',),
'kendoen': ('kendo',),
'kendoene': ('kendo',),
'kendoer': ('kendo',),
'ketsjup': ('ketsjup',),
'ketsjupen': ('ketsjup',),
'ketsjupene': ('ketsjup',),
'ketsjuper': ('ketsjup',),
'keyboard': ('keyboard',),
'keyboarda': ('keyboard',),
'keyboardene': ('keyboard',),
'keyboardet': ('keyboard',),
'kickboksing': ('kickboksing',),
'kickboksinga': ('kickboksing',),
'kickboksingen': ('kickboksing',),
'kickboksingene': ('kickboksing',),
'kickboksinger': ('kickboksing',),
'kikert': ('kikert',),
'kikerta': ('kikert',),
'kikerten': ('kikert',),
'kikertene': ('kikert',),
'kikerter': ('kikert',),
'kildespråk': ('kildespråk',),
'kildespråka': ('kildespråk',),
'kildespråkene': ('kildespråk',),
'kildespråket': ('kildespråk',),
'kimsella': ('kimselle',),
'kimselle': ('kimselle',),
'kimsellen': ('kimselle',),
'kimsellene': ('kimselle',),
'kimseller': ('kimselle',),
'kinaplomma': ('kinaplomme',),
'kinaplomme': ('kinaplomme',),
'kinaplommen': ('kinaplomme',),
'kinaplommene': ('kinaplomme',),
'kinaplommer': ('kinaplomme',),
'kirkeasyl': ('kirkeasyl',),
'kirkeasyla': ('kirkeasyl',),
'kirkeasylene': ('kirkeasyl',),
'kirkeasyler': ('kirkeasyl',),
'kirkeasylet': ('kirkeasyl',),
'kirkeasylant': ('kirkeasylant',),
'kirkeasylanta': ('kirkeasylant',),
'kirkeasylantene': ('kirkeasylant',),
'kirkeasylanter': ('kirkeasylant',),
'kirkeasylantet': ('kirkeasylant',),
'kitsch': ('kitsch',),
'kitschen': ('kitsch',),
'kitschene': ('kitsch',),
'kitscher': ('kitsch',),
'kjeldesortering': ('kjeldesortering',),
'kjeldesorteringa': ('kjeldesortering',),
'kjeldesorteringen': ('kjeldesortering',),
'kjeldesorteringene': ('kjeldesortering',),
'kjeldesorteringer': ('kjeldesortering',),
'kjeldespråk': ('kjeldespråk',),
'kjeldespråka': ('kjeldespråk',),
'kjeldespråkene': ('kjeldespråk',),
'kjeldespråket': ('kjeldespråk',),
'kjeldevern': ('kjeldevern',),
'kjeldeverna': ('kjeldevern',),
'kjeldevernene': ('kjeldevern',),
'kjeldevernet': ('kjeldevern',),
'kjelkehockey': ('kjelkehockey',),
'kjelkehockeyen': ('kjelkehockey',),
'kjelkehockeyene': ('kjelkehockey',),
'kjelkehockeyer': ('kjelkehockey',),
'kjemoterapi': ('kjemoterapi',),
'kjemoterapien': ('kjemoterapi',),
'kjemoterapiene': ('kjemoterapi',),
'kjemoterapier': ('kjemoterapi',),
'kjertelfeber': ('kjertelfeber',),
'kjertelfebere': ('kjertelfeber',),
'kjertelfeberen': ('kjertelfeber',),
'kjertelfeberne': ('kjertelfeber',),
'kjertelfebre': ('kjertelfeber',),
'kjertelfebrene': ('kjertelfeber',),
'kjertelfebrer': ('kjertelfeber',),
'kjølebagg': ('kjølebagg',),
'kjølebaggen': ('kjølebagg',),
'kjølebaggene': ('kjølebagg',),
'kjølebagger': ('kjølebagg',),
'kjønnslemlestelse': ('kjønnslemlestelse',),
'kjønnslemlestelsen': ('kjønnslemlestelse',),
'kjønnslemlestelsene': ('kjønnslemlestelse',),
'kjønnslemlestelser': ('kjønnslemlestelse',),
'kjønnslemlesting': ('kjønnslemlesting',),
'kjønnslemlestinga': ('kjønnslemlesting',),
'kjønnslemlestingen': ('kjønnslemlesting',),
'kjønnslemlestingene': ('kjønnslemlesting',),
'kjønnslemlestinger': ('kjønnslemlesting',),
'kjønnssella': ('kjønnsselle',),
'kjønnsselle': ('kjønnsselle',),
'kjønnssellen': ('kjønnsselle',),
'kjønnssellene': ('kjønnsselle',),
'kjønnsseller': ('kjønnsselle',),
'klappskøyta': ('klappskøyte',),
'klappskøyte': ('klappskøyte',),
'klappskøyten': ('klappskøyte',),
'klappskøytene': ('klappskøyte',),
'klappskøyter': ('klappskøyte',),
'klasebomba': ('klasebombe',),
'klasebombe': ('klasebombe',),
'klasebomben': ('klasebombe',),
'klasebombene': ('klasebombe',),
'klasebomber': ('klasebombe',),
'klinsj': ('klinsj',),
'klinsjen': ('klinsj',),
'klinsjene': ('klinsj',),
'klinsjer': ('klinsj',),
'klokkeradio': ('klokkeradio',),
'klokkeradioen': ('klokkeradio',),
'klokkeradioene': ('klokkeradio',),
'klokkeradioer': ('klokkeradio',),
'kognisjon': ('kognisjon',),
'kognisjonen': ('kognisjon',),
'kognisjonene': ('kognisjon',),
'kognisjoner': ('kognisjon',),
'koil': ('koil',),
'koilen': ('koil',),
'koilene': ('koil',),
'koiler': ('koil',),
'kommunikator': ('kommunikator',),
'kommunikatoren': ('kommunikator',),
'kommunikatorene': ('kommunikator',),
'kommunikatorer': ('kommunikator',),
'komprimator': ('komprimator',),
'komprimatoren': ('komprimator',),
'komprimatorene': ('komprimator',),
'komprimatorer': ('komprimator',),
'kondolant': ('kondolant',),
'kondolanten': ('kondolant',),
'kondolantene': ('kondolant',),
'kondolanter': ('kondolant',),
'konfutsianisme': ('konfutsianisme',),
'konfutsianismen': ('konfutsianisme',),
'konfutsianismene': ('konfutsianisme',),
'konfutsianismer': ('konfutsianisme',),
'kongekrabba': ('kongekrabbe',),
'kongekrabbe': ('kongekrabbe',),
'kongekrabben': ('kongekrabbe',),
'kongekrabbene': ('kongekrabbe',),
'kongekrabber': ('kongekrabbe',),
'kongevann': ('kongevann',),
'kongevanna': ('kongevann',),
'kongevannene': ('kongevann',),
'kongevannet': ('kongevann',),
'kongevatn': ('kongevatn',),
'kongevatna': ('kongevatn',),
'kongevatnene': ('kongevatn',),
'kongevatnet': ('kongevatn',),
'konteiner': ('konteiner',),
'konteinere': ('konteiner',),
'konteineren': ('konteiner',),
'konteinerne': ('konteiner',),
'konteinerskip': ('konteinerskip',),
'konteinerskipa': ('konteinerskip',),
'konteinerskipene': ('konteinerskip',),
'konteinerskipet': ('konteinerskip',),
'konvensjonalbot': ('konvensjonalbot',),
'konvensjonalbota': ('konvensjonalbot',),
'konvensjonalboten': ('konvensjonalbot',),
'konvensjonalbøtene': ('konvensjonalbot',),
'konvensjonalbøter': ('konvensjonalbot',),
'korv': ('korv',),
'korven': ('korv',),
'korvene': ('korv',),
'korver': ('korv',),
'kosover': ('kosover',),
'kosovere': ('kosover',),
'kosoveren': ('kosover',),
'kosoverne': ('kosover',),
'krambod': ('krambod',),
'kramboden': ('krambod',),
'krambodene': ('krambod',),
'kramboder': ('krambod',),
'kreftsella': ('kreftselle',),
'kreftselle': ('kreftselle',),
'kreftsellen': ('kreftselle',),
'kreftsellene': ('kreftselle',),
'kreftseller': ('kreftselle',),
'krengetog': ('krengetog',),
'krengetoga': ('krengetog',),
'krengetogene': ('krengetog',),
'krengetoget': ('krengetog',),
'kryddereddik': ('kryddereddik',),
'kryddereddiken': ('kryddereddik',),
'kryddereddikene': ('kryddereddik',),
'kryddereddiker': ('kryddereddik',),
'kryologi': ('kryologi',),
'kryologien': ('kryologi',),
'kryologiene': ('kryologi',),
'kryologier': ('kryologi',),
'kryostat': ('kryostat',),
'kryostaten': ('kryostat',),
'kryostatene': ('kryostat',),
'kryostater': ('kryostat',),
'kryoteknikk': ('kryoteknikk',),
'kryoteknikken': ('kryoteknikk',),
'kryoteknikkene': ('kryoteknikk',),
'kryoteknikker': ('kryoteknikk',),
'krypsiv': ('krypsiv',),
'krypsiva': ('krypsiv',),
'krypsivene': ('krypsiv',),
'krypsivet': ('krypsiv',),
'kryptoanalysa': ('kryptoanalyse',),
'kryptoanalyse': ('kryptoanalyse',),
'kryptoanalysen': ('kryptoanalyse',),
'kryptoanalysene': ('kryptoanalyse',),
'kryptoanalyser': ('kryptoanalyse',),
'krysseierskap': ('krysseierskap',),
'krysseierskapa': ('krysseierskap',),
'krysseierskapene': ('krysseierskap',),
'krysseierskapet': ('krysseierskap',),
'krøllalfa': ('krøllalfa',),
'krøllalfaen': ('krøllalfa',),
'krøllalfaene': ('krøllalfa',),
'krøllalfaer': ('krøllalfa',),
'kullbrennner': ('kullbrennner',),
'kullbrennnere': ('kullbrennner',),
'kullbrennneren': ('kullbrennner',),
'kullbrennnerer': ('kullbrennner',),
'kullbrennnerne': ('kullbrennner',),
'kulørtvask': ('kulørtvask',),
'kulørtvaska': ('kulørtvask',),
'kulørtvasken': ('kulørtvask',),
'kulørtvaskene': ('kulørtvask',),
'kulørtvasker': ('kulørtvask',),
'kumkvat': ('kumkvat',),
'kumkvaten': ('kumkvat',),
'kumkvatene': ('kumkvat',),
'kumkvater': ('kumkvat',),
'kuna': ('kuna',),
'kunaen': ('kuna',),
'kunaene': ('kuna',),
'kunaer': ('kuna',),
'kvadragesima': ('kvadragesima',),
'kvantesprang': ('kvantesprang',),
'kvantespranga': ('kvantesprang',),
'kvantesprangene': ('kvantesprang',),
'kvantespranget': ('kvantesprang',),
'kvikkas': ('kvikkas',),
'kvikkasen': ('kvikkas',),
'kvikkasene': ('kvikkas',),
'kvikkaser': ('kvikkas',),
'kvitvask': ('kvitvask',),
'kvitvaska': ('kvitvask',),
'kvitvasken': ('kvitvask',),
'kvitvaskene': ('kvitvask',),
'kvitvasker': ('kvitvask',),
'kyborg': ('kyborg',),
'kyborgen': ('kyborg',),
'kyborgene': ('kyborg',),
'kyborger': ('kyborg',),
'kyria': ('kyrie',),
'kyrie': ('kyrie',),
'kyriene': ('kyrie',),
'kyrier': ('kyrie',),
'kyriet': ('kyrie',),
'laissezfairepolitikk': ('laissezfairepolitikk',),
'laissezfairepolitikken': ('laissezfairepolitikk',),
'laissezfairepolitikkene': ('laissezfairepolitikk',),
'laissezfairepolitikker': ('laissezfairepolitikk',),
'lambada': ('lambada',),
'lambadaen': ('lambada',),
'lambadaene': ('lambada',),
'lambadaer': ('lambada',),
'langseter': ('langseter',),
'langseteren': ('langseter',),
'langsetra': ('langseter',),
'langsetre': ('langseter',),
'langsetrene': ('langseter',),
'langsetrer': ('langseter',),
'langstøl': ('langstøl',),
'langstølen': ('langstøl',),
'langstølene': ('langstøl',),
'langstøler': ('langstøl',),
'laryngologi': ('laryngologi',),
'laryngologien': ('laryngologi',),
'laryngologiene': ('laryngologi',),
'laryngologier': ('laryngologi',),
'lemur': ('lemur',),
'lemuren': ('lemur',),
'lemurene': ('lemur',),
'lemurer': ('lemur',),
'leonberger': ('leonberger',),
'leonbergere': ('leonberger',),
'leonbergeren': ('leonberger',),
'leonbergerne': ('leonberger',),
'leu': ('leu',),
'leuen': ('leu',),
'leuene': ('leu',),
'leuer': ('leu',),
'leukocytt': ('leukocytt',),
'leukocytten': ('leukocytt',),
'leukocyttene': ('leukocytt',),
'leukocytter': ('leukocytt',),
'levitasjon': ('levitasjon',),
'levitasjonen': ('levitasjon',),
'levitasjonene': ('levitasjon',),
'levitasjoner': ('levitasjon',),
'levkemi': ('levkemi',),
'levkemien': ('levkemi',),
'levkemiene': ('levkemi',),
'levkemier': ('levkemi',),
'levkocytt': ('levkocytt',),
'levkocytten': ('levkocytt',),
'levkocyttene': ('levkocytt',),
'levkocytter': ('levkocytt',),
'ligg': ('ligg',),
'ligga': ('ligg',),
'liggene': ('ligg',),
'ligget': ('ligg',),
'likhund': ('likhund',),
'likhunden': ('likhund',),
'likhundene': ('likhund',),
'likhunder': ('likhund',),
'limbus': ('limbus',),
'limbusen': ('limbus',),
'limbusene': ('limbus',),
'limbuser': ('limbus',),
'lira': ('lira',),
'liraen': ('lira',),
'liraene': ('lira',),
'liraer': ('lira',),
'litas': ('litas',),
'litasen': ('litas',),
'litasene': ('litas',),
'litosfære': ('litosfære',),
'litosfæren': ('litosfære',),
'litosfærene': ('litosfære',),
'litosfærer': ('litosfære',),
'lobbying': ('lobbying',),
'lobbyinga': ('lobbying',),
'lobbyingen': ('lobbying',),
'lobbyingene': ('lobbying',),
'lobbyinger': ('lobbying',),
'luktesella': ('lukteselle',),
'lukteselle': ('lukteselle',),
'luktesellen': ('lukteselle',),
'luktesellene': ('lukteselle',),
'lukteseller': ('lukteselle',),
'luminescens': ('luminescens',),
'luminescensen': ('luminescens',),
'luminescensene': ('luminescens',),
'luminescenser': ('luminescens',),
'lykkepille': ('lykkepille',),
'lykkepillea': ('lykkepille',),
'lykkepilleen': ('lykkepille',),
'lykkepilleene': ('lykkepille',),
'lykkepilleer': ('lykkepille',),
'lymfesella': ('lymfeselle',),
'lymfeselle': ('lymfeselle',),
'lymfesellen': ('lymfeselle',),
'lymfesellene': ('lymfeselle',),
'lymfeseller': ('lymfeselle',),
'lysark': ('lysark',),
'lysarka': ('lysark',),
'lysarkene': ('lysark',),
'lysarket': ('lysark',),
'magefølelse': ('magefølelse',),
'magefølelsen': ('magefølelse',),
'magefølelsene': ('magefølelse',),
'magefølelser': ('magefølelse',),
'mahdi': ('mahdi',),
'mahdien': ('mahdi',),
'mahdiene': ('mahdi',),
'mahdier': ('mahdi',),
'makeup': ('makeup',),
'makeupen': ('makeup',),
'makeupene': ('makeup',),
'makeuper': ('makeup',),
'makrellterna': ('makrellterne',),
'makrellterne': ('makrellterne',),
'makrellternen': ('makrellterne',),
'makrellternene': ('makrellterne',),
'makrellterner': ('makrellterne',),
'maksidrosja': ('maksidrosje',),
'maksidrosje': ('maksidrosje',),
'maksidrosjen': ('maksidrosje',),
'maksidrosjene': ('maksidrosje',),
'maksidrosjer': ('maksidrosje',),
'maksis': ('maksis',),
'maksitaxi': ('maksitaxi',),
'maksitaxien': ('maksitaxi',),
'maksitaxiene': ('maksitaxi',),
'maksitaxier': ('maksitaxi',),
'malingsboks': ('malingsboks',),
'malingsboksen': ('malingsboks',),
'malingsboksene': ('malingsboks',),
'malingsbokser': ('malingsboks',),
'malingsflekk': ('malingsflekk',),
'malingsflekken': ('malingsflekk',),
'malingsflekkene': ('malingsflekk',),
'malingsflekker': ('malingsflekk',),
'malingsslitt': ('malingsslitt',),
'malingsslitta': ('malingsslitt',),
'malingsslittene': ('malingsslitt',),
'malingsslittet': ('malingsslitt',),
'malingsspann': ('malingsspann',),
'malingsspanna': ('malingsspann',),
'malingsspannene': ('malingsspann',),
'malingsspannet': ('malingsspann',),
'malingstape': ('malingstape',),
'malingstapen': ('malingstape',),
'malingstapene': ('malingstape',),
'malingstaper': ('malingstape',),
'malingsteip': ('malingsteip',),
'malingsteipen': ('malingsteip',),
'malingsteipene': ('malingsteip',),
'malingsteiper': ('malingsteip',),
'mambo': ('mambo',),
'mamboen': ('mambo',),
'mamboene': ('mambo',),
'mamboer': ('mambo',),
'maskintelling': ('maskintelling',),
'maskintellinga': ('maskintelling',),
'maskintellingen': ('maskintelling',),
'maskintellingene': ('maskintelling',),
'maskintellinger': ('maskintelling',),
'matpinsett': ('matpinsett',),
'matpinsetten': ('matpinsett',),
'matpinsettene': ('matpinsett',),
'matpinsetter': ('matpinsett',),
'mavefølelse': ('mavefølelse',),
'mavefølelsen': ('mavefølelse',),
'mavefølelsene': ('mavefølelse',),
'mavefølelser': ('mavefølelse',),
'meiningsterror': ('meiningsterror',),
'meiningsterroren': ('meiningsterror',),
'meiningsterrorene': ('meiningsterror',),
'meiningsterrorer': ('meiningsterror',),
'mekka': ('mekka',),
'mekkaene': ('mekka',),
'mekkaer': ('mekka',),
'mekkaet': ('mekka',),
'menneskeeterhai': ('menneskeeterhai',),
'menneskeeterhaien': ('menneskeeterhai',),
'menneskeeterhaiene': ('menneskeeterhai',),
'menneskeeterhaier': ('menneskeeterhai',),
'metallofon': ('metallofon',),
'metallofonen': ('metallofon',),
'metallofonene': ('metallofon',),
'metallofoner': ('metallofon',),
'meteoroide': ('meteoroide',),
'meteoroiden': ('meteoroide',),
'meteoroidene': ('meteoroide',),
'meteoroider': ('meteoroide',),
'midtlivskrise': ('midtlivskrise',),
'midtlivskrisea': ('midtlivskrise',),
'midtlivskriseen': ('midtlivskrise',),
'midtlivskriseene': ('midtlivskrise',),
'midtlivskriseer': ('midtlivskrise',),
'migrant': ('migrant',),
'migranten': ('migrant',),
'migrantene': ('migrant',),
'migranter': ('migrant',),
'migrantarbeider': ('migrantarbeider',),
'migrantarbeidere': ('migrantarbeider',),
'migrantarbeideren': ('migrantarbeider',),
'migrantarbeiderne': ('migrantarbeider',),
'miljømerking': ('miljømerking',),
'miljømerkinga': ('miljømerking',),
'miljømerkingen': ('miljømerking',),
'miljømerkingene': ('miljømerking',),
'miljømerkinger': ('miljømerking',),
'miljøstasjon': ('miljøstasjon',),
'miljøstasjonen': ('miljøstasjon',),
'miljøstasjonene': ('miljøstasjon',),
'miljøstasjoner': ('miljøstasjon',),
'millenniumfeiring': ('millenniumfeiring',),
'millenniumfeiringa': ('millenniumfeiring',),
'millenniumfeiringen': ('millenniumfeiring',),
'millenniumfeiringene': ('millenniumfeiring',),
'millenniumfeiringer': ('millenniumfeiring',),
'millenniumskifta': ('millenniumskifte',),
'millenniumskifte': ('millenniumskifte',),
'millenniumskiftene': ('millenniumskifte',),
'millenniumskifter': ('millenniumskifte',),
'millenniumskiftet': ('millenniumskifte',),
'milliardtedel': ('milliardtedel',),
'milliardtedelen': ('milliardtedel',),
'milliardtedelene': ('milliardtedel',),
'milliardtedeler': ('milliardtedel',),
'minbar': ('minbar',),
'minbaren': ('minbar',),
'minbarene': ('minbar',),
'minbarer': ('minbar',),
'minnebrikka': ('minnebrikke',),
'minnebrikke': ('minnebrikke',),
'minnebrikken': ('minnebrikke',),
'minnebrikkene': ('minnebrikke',),
'minnebrikker': ('minnebrikke',),
'mint': ('mint',),
'minten': ('mint',),
'mintene': ('mint',),
'minter': ('mint',),
'missiltorpedobåt': ('missiltorpedobåt',),
'missiltorpedobåten': ('missiltorpedobåt',),
'missiltorpedobåtene': ('missiltorpedobåt',),
'missiltorpedobåter': ('missiltorpedobåt',),
'monokrom': ('monokrom',),
'monokromen': ('monokrom',),
'monokromene': ('monokrom',),
'monokromer': ('monokrom',),
'monosakkarid': ('monosakkarid',),
'monosakkarida': ('monosakkarid',),
'monosakkaridene': ('monosakkarid',),
'monosakkarider': ('monosakkarid',),
'monosakkaridet': ('monosakkarid',),
'montessoriskole': ('montessoriskole',),
'montessoriskolen': ('montessoriskole',),
'montessoriskolene': ('montessoriskole',),
'montessoriskoler': ('montessoriskole',),
'morsella': ('morselle',),
'morselle': ('morselle',),
'morsellen': ('morselle',),
'morsellene': ('morselle',),
'morseller': ('morselle',),
'motbrann': ('motbrann',),
'motbrannen': ('motbrann',),
'motbrannene': ('motbrann',),
'motbranner': ('motbrann',),
'motivator': ('motivator',),
'motivatoren': ('motivator',),
'motivatorene': ('motivator',),
'motivatorer': ('motivator',),
'mottagerstasjon': ('mottagerstasjon',),
'mottagerstasjonen': ('mottagerstasjon',),
'mottagerstasjonene': ('mottagerstasjon',),
'mottagerstasjoner': ('mottagerstasjon',),
'mozzarella': ('mozzarella',),
'mozzarellaen': ('mozzarella',),
'mozzarellaene': ('mozzarella',),
'mozzarellaer': ('mozzarella',),
'multihandikapp': ('multihandikapp',),
'multihandikappa': ('multihandikapp',),
'multihandikappene': ('multihandikapp',),
'multihandikappet': ('multihandikapp',),
'multimediekunst': ('multimediekunst',),
'multimediekunsten': ('multimediekunst',),
'multimediekunstene': ('multimediekunst',),
'multimediekunster': ('multimediekunst',),
'multimediemaskin': ('multimediemaskin',),
'multimediemaskinen': ('multimediemaskin',),
'multimediemaskinene': ('multimediemaskin',),
'multimediemaskiner': ('multimediemaskin',),
'multimediene': ('multimedier',),
'multimedier': ('multimedier',),
'musarm': ('musarm',),
'musarmen': ('musarm',),
'musarmene': ('musarm',),
'musarmer': ('musarm',),
'musearm': ('musearm',),
'musearmen': ('musearm',),
'musearmene': ('musearm',),
'musearmer': ('musearm',),
'museknapp': ('museknapp',),
'museknappen': ('museknapp',),
'museknappene': ('museknapp',),
'museknapper': ('museknapp',),
'musematta': ('musematte',),
'musematte': ('musematte',),
'musematten': ('musematte',),
'musemattene': ('musematte',),
'musematter': ('musematte',),
'musesjuka': ('musesjuke',),
'musesjuke': ('musesjuke',),
'musesjuken': ('musesjuke',),
'musesjukene': ('musesjuke',),
'musesjuker': ('musesjuke',),
'musesyka': ('musesyke',),
'musesyke': ('musesyke',),
'musesyken': ('musesyke',),
'musesykene': ('musesyke',),
'musesyker': ('musesyke',),
'muskelsella': ('muskelselle',),
'muskelselle': ('muskelselle',),
'muskelsellen': ('muskelselle',),
'muskelsellene': ('muskelselle',),
'muskelseller': ('muskelselle',),
'musknapp': ('musknapp',),
'musknappen': ('musknapp',),
'musknappene': ('musknapp',),
'musknapper': ('musknapp',),
'musmatta': ('musmatte',),
'musmatte': ('musmatte',),
'musmatten': ('musmatte',),
'musmattene': ('musmatte',),
'musmatter': ('musmatte',),
'mussjuka': ('mussjuke',),
'mussjuke': ('mussjuke',),
'mussjuken': ('mussjuke',),
'mussjukene': ('mussjuke',),
'mussjuker': ('mussjuke',),
'mussyka': ('mussyke',),
'mussyke': ('mussyke',),
'mussyken': ('mussyke',),
'mussykene': ('mussyke',),
'mussyker': ('mussyke',),
'møteulykka': ('møteulykke',),
'møteulykke': ('møteulykke',),
'møteulykken': ('møteulykke',),
'møteulykkene': ('møteulykke',),
'møteulykker': ('møteulykke',),
'måltjuv': ('måltjuv',),
'måltjuven': ('måltjuv',),
'måltjuvene': ('måltjuv',),
'måltjuver': ('måltjuv',),
'måltyv': ('måltyv',),
'måltyven': ('måltyv',),
'måltyvene': ('måltyv',),
'måltyver': ('måltyv',),
'n.-rot': ('n.-rot',),
'n.-rota': ('n.-rot',),
'n.-roten': ('n.-rot',),
'n.-røttene': ('n.-rot',),
'n.-røtter': ('n.-rot',),
'nakensena': ('nakensene',),
'nakensene': ('nakensene',),
'nakensenen': ('nakensene',),
'nakensenene': ('nakensene',),
'nakensener': ('nakensene',),
'nanoteknologi': ('nanoteknologi',),
'nanoteknologien': ('nanoteknologi',),
'nanoteknologiene': ('nanoteknologi',),
'nanoteknologier': ('nanoteknologi',),
'naprapat': ('naprapat',),
'naprapaten': ('naprapat',),
'naprapatene': ('naprapat',),
'naprapater': ('naprapat',),
'naprapati': ('naprapati',),
'naprapatien': ('naprapati',),
'naprapatiene': ('naprapati',),
'naprapatier': ('naprapati',),
'narkotikakurer': ('narkotikakurer',),
'narkotikakureren': ('narkotikakurer',),
'narkotikakurerene': ('narkotikakurer',),
'narkotikakurerer': ('narkotikakurer',),
'nasjonsbygging': ('nasjonsbygging',),
'nasjonsbygginga': ('nasjonsbygging',),
'nasjonsbyggingen': ('nasjonsbygging',),
'nasjonsbyggingene': ('nasjonsbygging',),
'nasjonsbygginger': ('nasjonsbygging',),
'natoland': ('natoland',),
'natolanda': ('natoland',),
'natolandene': ('natoland',),
'natolandet': ('natoland',),
'nattbordskuffa': ('nattbordskuffe',),
'nattbordskuffe': ('nattbordskuffe',),
'nattbordskuffen': ('nattbordskuffe',),
'nattbordskuffene': ('nattbordskuffe',),
'nattbordskuffer': ('nattbordskuffe',),
'nattbordsskuff': ('nattbordsskuff',),
'nattbordsskuffen': ('nattbordsskuff',),
'nattbordsskuffene': ('nattbordsskuff',),
'nattbordsskuffer': ('nattbordsskuff',),
'nattbordsskuffa': ('nattbordsskuffe',),
'nattbordsskuffe': ('nattbordsskuffe',),
'nattbordsskuffen': ('nattbordsskuffe',),
'nattbordsskuffene': ('nattbordsskuffe',),
'nattbordsskuffer': ('nattbordsskuffe',),
'nattseif': ('nattseif',),
'nattseifen': ('nattseif',),
'nattseifene': ('nattseif',),
'nattseifer': ('nattseif',),
'naturterapi': ('naturterapi',),
'naturterapien': ('naturterapi',),
'naturterapiene': ('naturterapi',),
'naturterapier': ('naturterapi',),
'nebulose': ('nebulose',),
'nebulosen': ('nebulose',),
'nebulosene': ('nebulose',),
'nebuloser': ('nebulose',),
'nefelin': ('nefelin',),
'nefelina': ('nefelin',),
'nefelinene': ('nefelin',),
'nefelinet': ('nefelin',),
'neglerotbetennelse': ('neglerotbetennelse',),
'neglerotbetennelsen': ('neglerotbetennelse',),
'neglerotbetennelsene': ('neglerotbetennelse',),
'neglerotbetennelser': ('neglerotbetennelse',),
'nematode': ('nematode',),
'nematoden': ('nematode',),
'nematodene': ('nematode',),
'nematoder': ('nematode',),
'neslesella': ('nesleselle',),
'nesleselle': ('nesleselle',),
'neslesellen': ('nesleselle',),
'neslesellene': ('nesleselle',),
'nesleseller': ('nesleselle',),
'nettavis': ('nettavis',),
'nettavisa': ('nettavis',),
'nettavisen': ('nettavis',),
'nettavisene': ('nettavis',),
'nettaviser': ('nettavis',),
'nettbank': ('nettbank',),
'nettbanken': ('nettbank',),
'nettbankene': ('nettbank',),
'nettbanker': ('nettbank',),
'netthandel': ('netthandel',),
'netthandelen': ('netthandel',),
'netthandlene': ('netthandel',),
'netthandler': ('netthandel',),
'nettkafeen': ('nettkafé',),
'nettkafeene': ('nettkafé',),
'nettkafeer': ('nettkafé',),
'nettkafé': ('nettkafé',),
'nettkaféen': ('nettkafé',),
'nettkaféene': ('nettkafé',),
'nettkaféer': ('nettkafé',),
'nettportal': ('nettportal',),
'nettportalen': ('nettportal',),
'nettportalene': ('nettportal',),
'nettportaler': ('nettportal',),
'nettprat': ('nettprat',),
'nettpraten': ('nettprat',),
'nettpratene': ('nettprat',),
'nettprater': ('nettprat',),
'nettsurfer': ('nettsurfer',),
'nettsurfere': ('nettsurfer',),
'nettsurferen': ('nettsurfer',),
'nettsurferne': ('nettsurfer',),
'nikotinplaster': ('nikotinplaster',),
'nikotinplasteret': ('nikotinplaster',),
'nikotinplastra': ('nikotinplaster',),
'nikotinplastre': ('nikotinplaster',),
'nikotinplastrene': ('nikotinplaster',),
'nikotinplastret': ('nikotinplaster',),
'nitrosellulose': ('nitrosellulose',),
'nitrosellulosen': ('nitrosellulose',),
'nitrosellulosene': ('nitrosellulose',),
'nitroselluloser': ('nitrosellulose',),
'nittendedel': ('nittendedel',),
'nittendedelen': ('nittendedel',),
'nittendedelene': ('nittendedel',),
'nittendedeler': ('nittendedel',),
'nittiendedel': ('nittiendedel',),
'nittiendedelen': ('nittiendedel',),
'nittiendedelene': ('nittiendedel',),
'nittiendedeler': ('nittiendedel',),
'node': ('node',),
'noden': ('node',),
'nodene': ('node',),
'noder': ('node',),
'noisette': ('noisette',),
'noisetten': ('noisette',),
'noisettene': ('noisette',),
'noisetter': ('noisette',),
'noktyrn': ('noktyrn',),
'noktyrnen': ('noktyrn',),
'noktyrnene': ('noktyrn',),
'noktyrner': ('noktyrn',),
'nominativform': ('nominativform',),
'nominativforma': ('nominativform',),
'nominativformen': ('nominativform',),
'nominativformene': ('nominativform',),
'nominativformer': ('nominativform',),
'n-te-rot': ('n-te-rot',),
'n-te-rota': ('n-te-rot',),
'n-te-roten': ('n-te-rot',),
'n-te-røttene': ('n-te-rot',),
'n-te-røtter': ('n-te-rot',),
'nubbekjangs': ('nubbekjangs',),
'nubbekjangsen': ('nubbekjangs',),
'nubbekjangsene': ('nubbekjangs',),
'nubbekjangser': ('nubbekjangs',),
'nyfasisme': ('nyfasisme',),
'nyfasismen': ('nyfasisme',),
'nyfasismene': ('nyfasisme',),
'nyfasismer': ('nyfasisme',),
'nymfeparakitt': ('nymfeparakitt',),
'nymfeparakitten': ('nymfeparakitt',),
'nymfeparakittene': ('nymfeparakitt',),
'nymfeparakitter': ('nymfeparakitt',),
'nytt': ('nytt',),
'nøytrino': ('nøytrino',),
'nøytrinoa': ('nøytrino',),
'nøytrinoene': ('nøytrino',),
'nøytrinoer': ('nøytrino',),
'nøytrinoet': ('nøytrino',),
'oasis': ('oasis',),
'oasisen': ('oasis',),
'oasisene': ('oasis',),
'oasiser': ('oasis',),
'offpiste': ('offpiste',),
'offpistekjøring': ('offpistekjøring',),
'offpistekjøringa': ('offpistekjøring',),
'offpistekjøringen': ('offpistekjøring',),
'offpistekjøringene': ('offpistekjøring',),
'offpistekjøringer': ('offpistekjøring',),
'oksitansk': ('oksitansk',),
'oksitansken': ('oksitansk',),
'oksitanskene': ('oksitansk',),
'oksitansker': ('oksitansk',),
'olavsstake': ('olavsstake',),
'olavsstaken': ('olavsstake',),
'olavsstakene': ('olavsstake',),
'olavsstaker': ('olavsstake',),
'oldsaksamling': ('oldsaksamling',),
'oldsaksamlinga': ('oldsaksamling',),
'oldsaksamlingen': ('oldsaksamling',),
'oldsaksamlingene': ('oldsaksamling',),
'oldsaksamlinger': ('oldsaksamling',),
'oligopol': ('oligopol',),
'oligopola': ('oligopol',),
'oligopolene': ('oligopol',),
'oligopoler': ('oligopol',),
'oligopolet': ('oligopol',),
'olympiadeltager': ('olympiadeltager',),
'olympiadeltagere': ('olympiadeltager',),
'olympiadeltageren': ('olympiadeltager',),
'olympiadeltagerne': ('olympiadeltager',),
'omega-3-fettsyra': ('omega-3-fettsyre',),
'omega-3-fettsyre': ('omega-3-fettsyre',),
'omega-3-fettsyren': ('omega-3-fettsyre',),
'omega-3-fettsyrene': ('omega-3-fettsyre',),
'omega-3-fettsyrer': ('omega-3-fettsyre',),
'omsorgsyrka': ('omsorgsyrke',),
'omsorgsyrke': ('omsorgsyrke',),
'omsorgsyrkene': ('omsorgsyrke',),
'omsorgsyrker': ('omsorgsyrke',),
'omsorgsyrket': ('omsorgsyrke',),
'onkelbarn': ('onkelbarn',),
'onkelbarna': ('onkelbarn',),
'onkelbarnene': ('onkelbarn',),
'onkelbarnet': ('onkelbarn',),
'onkolog': ('onkolog',),
'onkologen': ('onkolog',),
'onkologene': ('onkolog',),
'onkologer': ('onkolog',),
'operatørskap': ('operatørskap',),
'operatørskapa': ('operatørskap',),
'operatørskapene': ('operatørskap',),
'operatørskapet': ('operatørskap',),
'opioid': ('opioid',),
'opioida': ('opioid',),
'opioidene': ('opioid',),
'opioider': ('opioid',),
'opioidet': ('opioid',),
'oppsiingsvern': ('oppsiingsvern',),
'oppsiingsverna': ('oppsiingsvern',),
'oppsiingsvernene': ('oppsiingsvern',),
'oppsiingsvernet': ('oppsiingsvern',),
'orbital': ('orbital',),
'orbitalen': ('orbital',),
'orbitalene': ('orbital',),
'orbitaler': ('orbital',),
'ordbokredaktør': ('ordbokredaktør',),
'ordbokredaktøren': ('ordbokredaktør',),
'ordbokredaktørene': ('ordbokredaktør',),
'ordbokredaktører': ('ordbokredaktør',),
'ordbokverk': ('ordbokverk',),
'ordbokverka': ('ordbokverk',),
'ordbokverkene': ('ordbokverk',),
'ordbokverker': ('ordbokverk',),
'ordbokverket': ('ordbokverk',),
'organisasjonskart': ('organisasjonskart',),
'organisasjonskarta': ('organisasjonskart',),
'organisasjonskartene': ('organisasjonskart',),
'organisasjonskartet': ('organisasjonskart',),
'organsa': ('organsa',),
'organsaen': ('organsa',),
'organsaene': ('organsa',),
'organsaer': ('organsa',),
'ortose': ('ortose',),
'ortosen': ('ortose',),
'ortosene': ('ortose',),
'ortoser': ('ortose',),
'osteopat': ('osteopat',),
'osteopaten': ('osteopat',),
'osteopatene': ('osteopat',),
'osteopater': ('osteopat',),
'osteopati': ('osteopati',),
'osteopatien': ('osteopati',),
'osteopatiene': ('osteopati',),
'osteopatier': ('osteopati',),
'ostinato': ('ostinato',),
'ostinatoa': ('ostinato',),
'ostinatoene': ('ostinato',),
'ostinatoer': ('ostinato',),
'ostinatoet': ('ostinato',),
'overhedd': ('overhedd',),
'overhedden': ('overhedd',),
'overheddene': ('overhedd',),
'overhedder': ('overhedd',),
'paella': ('paella',),
'paellaen': ('paella',),
'paellaene': ('paella',),
'paellaer': ('paella',),
'pakkbod': ('pakkbod',),
'pakkboden': ('pakkbod',),
'pakkbodene': ('pakkbod',),
'pakkboder': ('pakkbod',),
'paleotype': ('paleotype',),
'paleotypen': ('paleotype',),
'paleotypene': ('paleotype',),
'paleotyper': ('paleotype',),
'palimpsest': ('palimpsest',),
'palimpsesten': ('palimpsest',),
'palimpsestene': ('palimpsest',),
'palimpsester': ('palimpsest',),
'pallplassering': ('pallplassering',),
'pallplasseringa': ('pallplassering',),
'pallplasseringen': ('pallplassering',),
'pallplasseringene': ('pallplassering',),
'pallplasseringer': ('pallplassering',),
'panfobi': ('panfobi',),
'panfobien': ('panfobi',),
'panfobiene': ('panfobi',),
'panfobier': ('panfobi',),
'panteattest': ('panteattest',),
'panteattesten': ('panteattest',),
'panteattestene': ('panteattest',),
'panteattester': ('panteattest',),
'paparazzo': ('paparazzo',),
'paparazzoen': ('paparazzo',),
'paparazzoene': ('paparazzo',),
'paparazzoer': ('paparazzo',),
'paparazzobilda': ('paparazzobilde',),
'paparazzobilde': ('paparazzobilde',),
'paparazzobildene': ('paparazzobilde',),
'paparazzobilder': ('paparazzobilde',),
'paparazzobildet': ('paparazzobilde',),
'paparazzofotograf': ('paparazzofotograf',),
'paparazzofotografen': ('paparazzofotograf',),
'paparazzofotografene': ('paparazzofotograf',),
'paparazzofotografer': ('paparazzofotograf',),
'paraferer': ('paraferer',),
'paraferere': ('paraferer',),
'parafereren': ('paraferer',),
'parafererne': ('paraferer',),
'paraglider': ('paraglider',),
'paraglidere': ('paraglider',),
'paraglideren': ('paraglider',),
'paragliderne': ('paraglider',),
'paragliding': ('paragliding',),
'paraglidinga': ('paragliding',),
'paraglidingen': ('paragliding',),
'paraglidingene': ('paragliding',),
'paraglidinger': ('paragliding',),
'parakitt': ('parakitt',),
'parakitten': ('parakitt',),
'parakittene': ('parakitt',),
'parakitter': ('parakitt',),
'paralympier': ('paralympier',),
'paralympiere': ('paralympier',),
'paralympieren': ('paralympier',),
'paralympierne': ('paralympier',),
'parfait': ('parfait',),
'parfaiten': ('parfait',),
'parfaitene': ('parfait',),
'parfaiter': ('parfait',),
'parkettbord': ('parkettbord',),
'parkettborda': ('parkettbord',),
'parkettbordene': ('parkettbord',),
'parkettbordet': ('parkettbord',),
'partist': ('partist',),
'partisten': ('partist',),
'partistene': ('partist',),
'partister': ('partist',),
'parykkmaker': ('parykkmaker',),
'parykkmakere': ('parykkmaker',),
'parykkmakeren': ('parykkmaker',),
'parykkmakerne': ('parykkmaker',),
'pasjonsblomst': ('pasjonsblomst',),
'pasjonsblomsten': ('pasjonsblomst',),
'pasjonsblomstene': ('pasjonsblomst',),
'pasjonsblomster': ('pasjonsblomst',),
'pasteup': ('pasteup',),
'pasteupen': ('pasteup',),
'pasteupene': ('pasteup',),
'pasteuper': ('pasteup',),
'peeling': ('peeling',),
'peelingen': ('peeling',),
'peelingene': ('peeling',),
'peelinger': ('peeling',),
'peg': ('peg',),
'pegen': ('peg',),
'pegene': ('peg',),
'peger': ('peg',),
'pegg': ('pegg',),
'peggen': ('pegg',),
'peggene': ('pegg',),
'pegger': ('pegg',),
'peiser': ('peiser',),
'peisere': ('peiser',),
'peiseren': ('peiser',),
'peiserne': ('peiser',),
'pelsberederi': ('pelsberederi',),
'pelsberederia': ('pelsberederi',),
'pelsberederiene': ('pelsberederi',),
'pelsberederier': ('pelsberederi',),
'pelsberederiet': ('pelsberederi',),
'pelsberedning': ('pelsberedning',),
'pelsberedninga': ('pelsberedning',),
'pelsberedningen': ('pelsberedning',),
'pelsberedningene': ('pelsberedning',),
'pelsberedninger': ('pelsberedning',),
'pelsdyrfôr': ('pelsdyrfôr',),
'pelsdyrfôra': ('pelsdyrfôr',),
'pelsdyrfôrene': ('pelsdyrfôr',),
'pelsdyrfôret': ('pelsdyrfôr',),
'pengeflytter': ('pengeflytter',),
'pengeflyttere': ('pengeflytter',),
'pengeflytteren': ('pengeflytter',),
'pengeflytterer': ('pengeflytter',),
'pengeflytterne': ('pengeflytter',),
'penni': ('penni',),
'pennien': ('penni',),
'penniene': ('penni',),
'pennier': ('penni',),
'perlebroderi': ('perlebroderi',),
'perlebroderia': ('perlebroderi',),
'perlebroderiene': ('perlebroderi',),
'perlebroderier': ('perlebroderi',),
'perlebroderiet': ('perlebroderi',),
'personkjemi': ('personkjemi',),
'personkjemien': ('personkjemi',),
'personkjemiene': ('personkjemi',),
'personkjemier': ('personkjemi',),
'personsøking': ('personsøking',),
'personsøkinga': ('personsøking',),
'personsøkingen': ('personsøking',),
'personsøkingene': ('personsøking',),
'personsøkinger': ('personsøking',),
'pesto': ('pesto',),
'pestoen': ('pesto',),
'pestoene': ('pesto',),
'pestoer': ('pesto',),
'piercing': ('piercing',),
'piercinga': ('piercing',),
'piercingen': ('piercing',),
'piercingene': ('piercing',),
'piercinger': ('piercing',),
'piksel': ('piksel',),
'pikselen': ('piksel',),
'pikslene': ('piksel',),
'piksler': ('piksel',),
'pilker': ('pilker',),
'pilkere': ('pilker',),
'pilkeren': ('pilker',),
'pilkerne': ('pilker',),
'pilkestikka': ('pilkestikke',),
'pilkestikke': ('pilkestikke',),
'pilkestikken': ('pilkestikke',),
'pilkestikkene': ('pilkestikke',),
'pilkestikker': ('pilkestikke',),
'pilkogger': ('pilkogger',),
'pilkoggeret': ('pilkogger',),
'pilkogra': ('pilkogger',),
'pilkogre': ('pilkogger',),
'pilkogrene': ('pilkogger',),
'pingla': ('pingle',),
'pingle': ('pingle',),
'pinglen': ('pingle',),
'pinglene': ('pingle',),
'pingler': ('pingle',),
'pingpong': ('pingpong',),
'pingpongen': ('pingpong',),
'pingpongene': ('pingpong',),
'pingponger': ('pingpong',),
'pingpongball': ('pingpongball',),
'pingpongballen': ('pingpongball',),
'pingpongballene': ('pingpongball',),
'pingpongballer': ('pingpongball',),
'pinup': ('pinup',),
'pinupen': ('pinup',),
'pinupene': ('pinup',),
'pinuper': ('pinup',),
'pirsing': ('pirsing',),
'pirsinga': ('pirsing',),
'pirsingen': ('pirsing',),
'pirsingene': ('pirsing',),
'pirsinger': ('pirsing',),
'pistasj': ('pistasj',),
'pistasjen': ('pistasj',),
'pistasjene': ('pistasj',),
'pistasjer': ('pistasj',),
'pistasjis': ('pistasjis',),
'pistasjisen': ('pistasjis',),
'pistasjisene': ('pistasjis',),
'pistasjiser': ('pistasjis',),
'pistasjtre': ('pistasjtre',),
'pistasjtrea': ('pistasjtre',),
'pistasjtreet': ('pistasjtre',),
'pistasjtrær': ('pistasjtre',),
'pistasjtrærne': ('pistasjtre',),
'pitbull': ('pitbull',),
'pitbullen': ('pitbull',),
'pitbullene': ('pitbull',),
'pitbuller': ('pitbull',),
'pitbullterrier': ('pitbullterrier',),
'pitbullterriere': ('pitbullterrier',),
'pitbullterrieren': ('pitbullterrier',),
'pitbullterrierer': ('pitbullterrier',),
'pitbullterrierne': ('pitbullterrier',),
'pizzeria': ('pizzeria',),
'pizzeriaen': ('pizzeria',),
'pizzeriaene': ('pizzeria',),
'pizzeriaer': ('pizzeria',),
'plasebo': ('plasebo',),
'plaseboa': ('plasebo',),
'plaseboene': ('plasebo',),
'plaseboet': ('plasebo',),
'plaseboeffekt': ('plaseboeffekt',),
'plaseboeffekten': ('plaseboeffekt',),
'plaseboeffektene': ('plaseboeffekt',),
'plaseboeffekter': ('plaseboeffekt',),
'plastlakk': ('plastlakk',),
'plastlakken': ('plastlakk',),
'plastlakkene': ('plastlakk',),
'plastlakker': ('plastlakk',),
'plommestein': ('plommestein',),
'plommesteinen': ('plommestein',),
'plommesteinene': ('plommestein',),
'plommesteiner': ('plommestein',),
'plural': ('plural',),
'plurala': ('plural',),
'pluralen': ('plural',),
'pluralene': ('plural',),
'pluraler': ('plural',),
'pluralet': ('plural',),
'pneumokokk': ('pneumokokk',),
'pneumokokken': ('pneumokokk',),
'pneumokokkene': ('pneumokokk',),
'pneumokokker': ('pneumokokk',),
'pneumoni': ('pneumoni',),
'pneumonien': ('pneumoni',),
'pneumoniene': ('pneumoni',),
'pneumonier': ('pneumoni',),
'polarhund': ('polarhund',),
'polarhunden': ('polarhund',),
'polarhundene': ('polarhund',),
'polarhunder': ('polarhund',),
'polisj': ('polisj',),
'polisjen': ('polisj',),
'polisjene': ('polisj',),
'polisjer': ('polisj',),
'polysakkarid': ('polysakkarid',),
'polysakkarida': ('polysakkarid',),
'polysakkaridene': ('polysakkarid',),
'polysakkarider': ('polysakkarid',),
'polysakkaridet': ('polysakkarid',),
'polysem': ('polysem',),
'polysema': ('polysem',),
'polysemene': ('polysem',),
'polysemer': ('polysem',),
'polysemet': ('polysem',),
'populærkultur': ('populærkultur',),
'populærkulturen': ('populærkultur',),
'populærkulturene': ('populærkultur',),
'populærkulturer': ('populærkultur',),
'potetlompa': ('potetlompe',),
'potetlompe': ('potetlompe',),
'potetlompen': ('potetlompe',),
'potetlompene': ('potetlompe',),
'potetlomper': ('potetlompe',),
'presentatør': ('presentatør',),
'presentatøren': ('presentatør',),
'presentatørene': ('presentatør',),
'presentatører': ('presentatør',),
'primalterapi': ('primalterapi',),
'primalterapien': ('primalterapi',),
'primalterapiene': ('primalterapi',),
'primalterapier': ('primalterapi',),
'profanitet': ('profanitet',),
'profaniteten': ('profanitet',),
'profanitetene': ('profanitet',),
'profaniteter': ('profanitet',),
'prototype': ('prototype',),
'prototypen': ('prototype',),
'prototypene': ('prototype',),
'prototyper': ('prototype',),
'pulsklokke': ('pulsklokke',),
'pulsklokkea': ('pulsklokke',),
'pulsklokkeen': ('pulsklokke',),
'pulsklokkeene': ('pulsklokke',),
'pulsklokkeer': ('pulsklokke',),
'pumpekanne': ('pumpekanne',),
'pumpekannea': ('pumpekanne',),
'pumpekanneen': ('pumpekanne',),
'pumpekanneene': ('pumpekanne',),
'pumpekanneer': ('pumpekanne',),
'pungbjørn': ('pungbjørn',),
'pungbjørnen': ('pungbjørn',),
'pungbjørnene': ('pungbjørn',),
'pungbjørner': ('pungbjørn',),
'put': ('put',),
'puten': ('put',),
'putene': ('put',),
'puter': ('put',),
'pynteforkle': ('pynteforkle',),
'pynteforkleet': ('pynteforkle',),
'pynteforklær': ('pynteforkle',),
'pynteforklærne': ('pynteforkle',),
'pyntehandkle': ('pyntehandkle',),
'pyntehandkleet': ('pyntehandkle',),
'pyntehandklær': ('pyntehandkle',),
'pyntehandklærne': ('pyntehandkle',),
'pyntehåndkle': ('pyntehåndkle',),
'pyntehåndkleet': ('pyntehåndkle',),
'pyntehåndklær': ('pyntehåndkle',),
'pyntehåndklærne': ('pyntehåndkle',),
'pynteputa': ('pyntepute',),
'pyntepute': ('pyntepute',),
'pynteputen': ('pyntepute',),
'pynteputene': ('pyntepute',),
'pynteputer': ('pyntepute',),
'pyreneerhund': ('pyreneerhund',),
'pyreneerhunden': ('pyreneerhund',),
'pyreneerhundene': ('pyreneerhund',),
'pyreneerhunder': ('pyreneerhund',),
'pysjamas': ('pysjamas',),
'pysjamasen': ('pysjamas',),
'pysjamasene': ('pysjamas',),
'pysjamaser': ('pysjamas',),
'pølsebod': ('pølsebod',),
'pølseboden': ('pølsebod',),
'pølsebodene': ('pølsebod',),
'pølseboder': ('pølsebod',),
'på-knapp': ('på-knapp',),
'på-knappen': ('på-knapp',),
'på-knappene': ('på-knapp',),
'på-knapper': ('på-knapp',),
'raffinør': ('raffinør',),
'raffinøren': ('raffinør',),
'raffinørene': ('raffinør',),
'raffinører': ('raffinør',),
'rakettskjold': ('rakettskjold',),
'rakettskjolda': ('rakettskjold',),
'rakettskjoldene': ('rakettskjold',),
'rakettskjoldet': ('rakettskjold',),
'rammebutikkbilda': ('rammebutikkbilde',),
'rammebutikkbilde': ('rammebutikkbilde',),
'rammebutikkbildene': ('rammebutikkbilde',),
'rammebutikkbilder': ('rammebutikkbilde',),
'rammebutikkbildet': ('rammebutikkbilde',),
'rapper': ('rapper',),
'rappere': ('rapper',),
'rapperen': ('rapper',),
'rapperne': ('rapper',),
'rassballe': ('rassballe',),
'rassballen': ('rassballe',),
'rassballene': ('rassballe',),
'rassballer': ('rassballe',),
'rastafarianer': ('rastafarianer',),
'rastafarianere': ('rastafarianer',),
'rastafarianeren': ('rastafarianer',),
'rastafarianerne': ('rastafarianer',),
'rastafletta': ('rastaflette',),
'rastaflette': ('rastaflette',),
'rastafletten': ('rastaflette',),
'rastaflettene': ('rastaflette',),
'rastafletter': ('rastaflette',),
'rastafrisyra': ('rastafrisyre',),
'rastafrisyre': ('rastafrisyre',),
'rastafrisyren': ('rastafrisyre',),
'rastafrisyrene': ('rastafrisyre',),
'rastafrisyrer': ('rastafrisyre',),
'regntjukka': ('regntjukke',),
'regntjukke': ('regntjukke',),
'regntjukken': ('regntjukke',),
'regntjukkene': ('regntjukke',),
'regntjukker': ('regntjukke',),
'regntykka': ('regntykke',),
'regntykke': ('regntykke',),
'regntykken': ('regntykke',),
'regntykkene': ('regntykke',),
'regntykker': ('regntykke',),
'reklameinnslag': ('reklameinnslag',),
'reklameinnslaga': ('reklameinnslag',),
'reklameinnslagene': ('reklameinnslag',),
'reklameinnslaget': ('reklameinnslag',),
'reklamekampanje': ('reklamekampanje',),
'reklamekampanjen': ('reklamekampanje',),
'reklamekampanjene': ('reklamekampanje',),
'reklamekampanjer': ('reklamekampanje',),
'rensekrem': ('rensekrem',),
'rensekremen': ('rensekrem',),
'rensekremene': ('rensekrem',),
'rensekremer': ('rensekrem',),
'res': ('res',),
'resa': ('res',),
'resene': ('res',),
'reset': ('res',),
'reser': ('reser',),
'resere': ('reser',),
'reseren': ('reser',),
'reserne': ('reser',),
'reserbil': ('reserbil',),
'reserbilen': ('reserbil',),
'reserbilene': ('reserbil',),
'reserbiler': ('reserbil',),
'reserbåt': ('reserbåt',),
'reserbåten': ('reserbåt',),
'reserbåtene': ('reserbåt',),
'reserbåter': ('reserbåt',),
'resersykkel': ('resersykkel',),
'resersykkelen': ('resersykkel',),
'resersyklene': ('resersykkel',),
'resersykler': ('resersykkel',),
'rijal': ('rijal',),
'rijalen': ('rijal',),
'rijalene': ('rijal',),
'rijaler': ('rijal',),
'ringgit': ('ringgit',),
'ringgiten': ('ringgit',),
'ringgitene': ('ringgit',),
'ringgiter': ('ringgit',),
'ringgiti': ('ringgit',),
'rinkbandy': ('rinkbandy',),
'rinkbandyen': ('rinkbandy',),
'rinkbandyene': ('rinkbandy',),
'rinkbandyer': ('rinkbandy',),
'roadracing': ('roadracing',),
'roadracingen': ('roadracing',),
'roadracingene': ('roadracing',),
'roadracinger': ('roadracing',),
'roadster': ('roadster',),
'roadstere': ('roadster',),
'roadsteren': ('roadster',),
'roadsterne': ('roadster',),
'rodel': ('rodel',),
'rodelen': ('rodel',),
'rodlene': ('rodel',),
'rodler': ('rodel',),
'rollespell': ('rollespell',),
'rollespella': ('rollespell',),
'rollespellene': ('rollespell',),
'rollespellet': ('rollespell',),
'rotteraca': ('rotterace',),
'rotterace': ('rotterace',),
'rotteracene': ('rotterace',),
'rotteracet': ('rotterace',),
'rotteres': ('rotteres',),
'rotteresa': ('rotteres',),
'rotteresene': ('rotteres',),
'rottereset': ('rotteres',),
'rough': ('rough',),
'roughen': ('rough',),
'roughene': ('rough',),
'rougher': ('rough',),
'royal straight flush': ('royal straight flush',),
'royal straight flushen': ('royal straight flush',),
'royal straight flushene': ('royal straight flush',),
'royal straight flusher': ('royal straight flush',),
'rullator': ('rullator',),
'rullatoren': ('rullator',),
'rullatorene': ('rullator',),
'rullatorer': ('rullator',),
'rupiah': ('rupiah',),
'rupiahen': ('rupiah',),
'rupiahene': ('rupiah',),
'rupiaher': ('rupiah',),
'rusbrus': ('rusbrus',),
'rusbrusen': ('rusbrus',),
'rusbrusene': ('rusbrus',),
'rusbruser': ('rusbrus',),
'rusegrop': ('rusegrop',),
'rusegropa': ('rusegrop',),
'rusegropen': ('rusegrop',),
'rusegropene': ('rusegrop',),
'rusegroper': ('rusegrop',),
'ryggsekkturist': ('ryggsekkturist',),
'ryggsekkturisten': ('ryggsekkturist',),
'ryggsekkturistene': ('ryggsekkturist',),
'ryggsekkturister': ('ryggsekkturist',),
'rævhol': ('rævhol',),
'rævhola': ('rævhol',),
'rævholene': ('rævhol',),
'rævholet': ('rævhol',),
'rævhull': ('rævhull',),
'rævhulla': ('rævhull',),
'rævhullene': ('rævhull',),
'rævhuller': ('rævhull',),
'rævhullet': ('rævhull',),
'røkeplaster': ('røkeplaster',),
'røkeplasteret': ('røkeplaster',),
'røkeplastra': ('røkeplaster',),
'røkeplastre': ('røkeplaster',),
'røkeplastrene': ('røkeplaster',),
'røkeplastret': ('røkeplaster',),
'røykeplaster': ('røykeplaster',),
'røykeplasteret': ('røykeplaster',),
'røykeplastra': ('røykeplaster',),
'røykeplastre': ('røykeplaster',),
'røykeplastrene': ('røykeplaster',),
'røykeplastret': ('røykeplaster',),
'sadomasochist': ('sadomasochist',),
'sadomasochisten': ('sadomasochist',),
'sadomasochistene': ('sadomasochist',),
'sadomasochister': ('sadomasochist',),
'safteri': ('safteri',),
'safteria': ('safteri',),
'safteriene': ('safteri',),
'safterier': ('safteri',),
'safteriet': ('safteri',),
'salsa': ('salsa',),
'salsaen': ('salsa',),
'salsaene': ('salsa',),
'salsaer': ('salsa',),
'samform': ('samform',),
'samforma': ('samform',),
'samformen': ('samform',),
'samformene': ('samform',),
'samformer': ('samform',),
'samfunnsodontologi': ('samfunnsodontologi',),
'samfunnsodontologien': ('samfunnsodontologi',),
'samfunnsodontologiene': ('samfunnsodontologi',),
'samfunnsodontologier': ('samfunnsodontologi',),
'samleverk': ('samleverk',),
'samleverka': ('samleverk',),
'samleverkene': ('samleverk',),
'samleverker': ('samleverk',),
'samleverket': ('samleverk',),
'samskaping': ('samskaping',),
'samskapinga': ('samskaping',),
'samskapingen': ('samskaping',),
'samskapingene': ('samskaping',),
'samskapinger': ('samskaping',),
'sandvolleyball': ('sandvolleyball',),
'sandvolleyballa': ('sandvolleyball',),
'sandvolleyballene': ('sandvolleyball',),
'sandvolleyballer': ('sandvolleyball',),
'sandvolleyballet': ('sandvolleyball',),
'sashimi': ('sashimi',),
'sashimien': ('sashimi',),
'sashimiene': ('sashimi',),
'sashimier': ('sashimi',),
'scampi': ('scampi',),
'scampien': ('scampi',),
'scampiene': ('scampi',),
'scampier': ('scampi',),
'sciencefictionroman': ('sciencefictionroman',),
'sciencefictionromanen': ('sciencefictionroman',),
'sciencefictionromanene': ('sciencefictionroman',),
'sciencefictionromaner': ('sciencefictionroman',),
'scrapbook': ('scrapbook',),
'scrapbooken': ('scrapbook',),
'scrapbookene': ('scrapbook',),
'scrapbooker': ('scrapbook',),
'scrapbookn': ('scrapbook',),
'scrapbooks': ('scrapbook',),
'scrapbooksene': ('scrapbook',),
'scratch': ('scratch',),
'scratchen': ('scratch',),
'scratchene': ('scratch',),
'scratcher': ('scratch',),
'seboreen': ('seboré',),
'seboreene': ('seboré',),
'seboreer': ('seboré',),
'seboré': ('seboré',),
'seboréen': ('seboré',),
'seboréene': ('seboré',),
'seboréer': ('seboré',),
'seif': ('seif',),
'seifen': ('seif',),
'seifene': ('seif',),
'seifer': ('seif',),
'seiloner': ('seiloner',),
'seilonere': ('seiloner',),
'seiloneren': ('seiloner',),
'seilonerne': ('seiloner',),
'sekretesse': ('sekretesse',),
'sekretessen': ('sekretesse',),
'sekretessene': ('sekretesse',),
'sekretesser': ('sekretesse',),
'sekspakning': ('sekspakning',),
'sekspakninga': ('sekspakning',),
'sekspakningen': ('sekspakning',),
'sekspakningene': ('sekspakning',),
'sekspakninger': ('sekspakning',),
'sekstiendedel': ('sekstiendedel',),
'sekstiendedelen': ('sekstiendedel',),
'sekstiendedelene': ('sekstiendedel',),
'sekstiendedeler': ('sekstiendedel',),
'selebritet': ('selebritet',),
'selebriteten': ('selebritet',),
'selebritetene': ('selebritet',),
'selebriteter': ('selebritet',),
'sellebiologi': ('sellebiologi',),
'sellebiologien': ('sellebiologi',),
'sellebiologiene': ('sellebiologi',),
'sellebiologier': ('sellebiologi',),
'sellebro': ('sellebro',),
'sellebroa': ('sellebro',),
'sellebroen': ('sellebro',),
'sellebroene': ('sellebro',),
'sellebroer': ('sellebro',),
'sellebru': ('sellebru',),
'sellebrua': ('sellebru',),
'sellebruen': ('sellebru',),
'sellebruene': ('sellebru',),
'sellebruer': ('sellebru',),
'selledeling': ('selledeling',),
'selledelinga': ('selledeling',),
'selledelingen': ('selledeling',),
'selledelingene': ('selledeling',),
'selledelinger': ('selledeling',),
'sellegift': ('sellegift',),
'sellegifta': ('sellegift',),
'sellegiften': ('sellegift',),
'sellegiftene': ('sellegift',),
'sellegifter': ('sellegift',),
'sellekjerna': ('sellekjerne',),
'sellekjerne': ('sellekjerne',),
'sellekjernen': ('sellekjerne',),
'sellekjernene': ('sellekjerne',),
'sellekjerner': ('sellekjerne',),
'sellekultur': ('sellekultur',),
'sellekulturen': ('sellekultur',),
'sellekulturene': ('sellekultur',),
'sellekulturer': ('sellekultur',),
'sellelæra': ('sellelære',),
'sellelære': ('sellelære',),
'sellelæren': ('sellelære',),
'sellelærene': ('sellelære',),
'sellelærer': ('sellelære',),
'sellemembran': ('sellemembran',),
'sellemembranen': ('sellemembran',),
'sellemembranene': ('sellemembran',),
'sellemembraner': ('sellemembran',),
'sellestoff': ('sellestoff',),
'sellestoffa': ('sellestoff',),
'sellestoffene': ('sellestoff',),
'sellestoffer': ('sellestoff',),
'sellestoffet': ('sellestoff',),
'sellevev': ('sellevev',),
'selleveva': ('sellevev',),
'sellevevene': ('sellevev',),
'sellevevet': ('sellevev',),
'sellofan': ('sellofan',),
'sellofanen': ('sellofan',),
'sellofanene': ('sellofan',),
'sellofaner': ('sellofan',),
'sellularpatologi': ('sellularpatologi',),
'sellularpatologien': ('sellularpatologi',),
'sellularpatologiene': ('sellularpatologi',),
'sellularpatologier': ('sellularpatologi',),
'sellull': ('sellull',),
'sellulla': ('sellull',),
'sellullen': ('sellull',),
'sellullene': ('sellull',),
'selluller': ('sellull',),
'selluloid': ('selluloid',),
'selluloiden': ('selluloid',),
'selluloidene': ('selluloid',),
'selluloider': ('selluloid',),
'sellulose': ('sellulose',),
'sellulosen': ('sellulose',),
'sellulosene': ('sellulose',),
'selluloser': ('sellulose',),
'sellulosefabrikk': ('sellulosefabrikk',),
'sellulosefabrikken': ('sellulosefabrikk',),
'sellulosefabrikkene': ('sellulosefabrikk',),
'sellulosefabrikker': ('sellulosefabrikk',),
'sellulosefilm': ('sellulosefilm',),
'sellulosefilmen': ('sellulosefilm',),
'sellulosefilmene': ('sellulosefilm',),
'sellulosefilmer': ('sellulosefilm',),
'selluloselakk': ('selluloselakk',),
'selluloselakken': ('selluloselakk',),
'selluloselakkene': ('selluloselakk',),
'selluloselakker': ('selluloselakk',),
'selluloselim': ('selluloselim',),
'selluloselima': ('selluloselim',),
'selluloselimene': ('selluloselim',),
'selluloselimet': ('selluloselim',),
'sellulosemasse': ('sellulosemasse',),
'sellulosemassen': ('sellulosemasse',),
'sellulosemassene': ('sellulosemasse',),
'sellulosemasser': ('sellulosemasse',),
'sellulosenitrat': ('sellulosenitrat',),
'sellulosenitrata': ('sellulosenitrat',),
'sellulosenitratene': ('sellulosenitrat',),
'sellulosenitrater': ('sellulosenitrat',),
'sellulosenitratet': ('sellulosenitrat',),
'sellulosepapp': ('sellulosepapp',),
'sellulosepappen': ('sellulosepapp',),
'sellulosepappene': ('sellulosepapp',),
'sellulosepapper': ('sellulosepapp',),
'sellulosevatt': ('sellulosevatt',),
'sellulosevatten': ('sellulosevatt',),
'sellulosevattene': ('sellulosevatt',),
'sellulosevatter': ('sellulosevatt',),
'semiolog': ('semiolog',),
'semiologen': ('semiolog',),
'semiologene': ('semiolog',),
'semiologer': ('semiolog',),
'semiotiker': ('semiotiker',),
'semiotikere': ('semiotiker',),
'semiotikeren': ('semiotiker',),
'semiotikerne': ('semiotiker',),
'senario': ('senario',),
'senarioa': ('senario',),
'senarioene': ('senario',),
'senarioer': ('senario',),
'senarioet': ('senario',),
'sendeflata': ('sendeflate',),
'sendeflate': ('sendeflate',),
'sendeflaten': ('sendeflate',),
'sendeflatene': ('sendeflate',),
'sendeflater': ('sendeflate',),
'seneri': ('seneri',),
'seneria': ('seneri',),
'seneriene': ('seneri',),
'senerier': ('seneri',),
'seneriet': ('seneri',),
'senevant': ('senevant',),
'senevanten': ('senevant',),
'senevantene': ('senevant',),
'senevanter': ('senevant',),
'senograf': ('senograf',),
'senografen': ('senograf',),
'senografene': ('senograf',),
'senografer': ('senograf',),
'senografi': ('senografi',),
'senografien': ('senografi',),
'senografiene': ('senografi',),
'senografier': ('senografi',),
'sentiment': ('sentiment',),
'sentimenta': ('sentiment',),
'sentimentene': ('sentiment',),
'sentimenter': ('sentiment',),
'sentimentet': ('sentiment',),
'server': ('server',),
'servere': ('server',),
'serveren': ('server',),
'serverne': ('server',),
'sexisme': ('sexisme',),
'sexismen': ('sexisme',),
'sexismene': ('sexisme',),
'sexismer': ('sexisme',),
'sexist': ('sexist',),
'sexisten': ('sexist',),
'sexistene': ('sexist',),
'sexister': ('sexist',),
'sharia': ('sharia',),
'shinto': ('shinto',),
'siddis': ('siddis',),
'siddisen': ('siddis',),
'siddisene': ('siddis',),
'siddiser': ('siddis',),
'sientolog': ('sientolog',),
'sientologen': ('sientolog',),
'sientologene': ('sientolog',),
'sientologer': ('sientolog',),
'sientologi': ('sientologi',),
'sientologien': ('sientologi',),
'sientologiene': ('sientologi',),
'sientologier': ('sientologi',),
'sigarføring': ('sigarføring',),
'sigarføringa': ('sigarføring',),
'sigarføringen': ('sigarføring',),
'sigarføringene': ('sigarføring',),
'sigarføringer': ('sigarføring',),
'signalrenta': ('signalrente',),
'signalrente': ('signalrente',),
'signalrenten': ('signalrente',),
'signalrentene': ('signalrente',),
'signalrenter': ('signalrente',),
'signalstoff': ('signalstoff',),
'signalstoffa': ('signalstoff',),
'signalstoffene': ('signalstoff',),
'signalstoffer': ('signalstoff',),
'signalstoffet': ('signalstoff',),
'sikkerhetssella': ('sikkerhetsselle',),
'sikkerhetsselle': ('sikkerhetsselle',),
'sikkerhetssellen': ('sikkerhetsselle',),
'sikkerhetssellene': ('sikkerhetsselle',),
'sikkerhetsseller': ('sikkerhetsselle',),
'sirkapris': ('sirkapris',),
'sirkaprisen': ('sirkapris',),
'sirkaprisene': ('sirkapris',),
'sirkapriser': ('sirkapris',),
'sirkatall': ('sirkatall',),
'sirkatalla': ('sirkatall',),
'sirkatallene': ('sirkatall',),
'sirkatallet': ('sirkatall',),
'sirkumfleks': ('sirkumfleks',),
'sirkumfleksen': ('sirkumfleks',),
'sirkumfleksene': ('sirkumfleks',),
'sirkumflekser': ('sirkumfleks',),
'siserone': ('siserone',),
'siseronen': ('siserone',),
'siseronene': ('siserone',),
'siseroner': ('siserone',),
'sisilianer': ('sisilianer',),
'sisilianere': ('sisilianer',),
'sisilianeren': ('sisilianer',),
'sisilianerne': ('sisilianer',),
'sisterna': ('sisterne',),
'sisterne': ('sisterne',),
'sisternen': ('sisterne',),
'sisternene': ('sisterne',),
'sisterner': ('sisterne',),
'sitrongras': ('sitrongras',),
'sitrongrasa': ('sitrongras',),
'sitrongrasene': ('sitrongras',),
'sitrongraset': ('sitrongras',),
'sitrongress': ('sitrongress',),
'sitrongressa': ('sitrongress',),
'sitrongressene': ('sitrongress',),
'sitrongresset': ('sitrongress',),
'sjampanje': ('sjampanje',),
'sjampanjen': ('sjampanje',),
'sjampanjene': ('sjampanje',),
'sjampanjer': ('sjampanje',),
'sjampanjeglass': ('sjampanjeglass',),
'sjampanjeglassa': ('sjampanjeglass',),
'sjampanjeglassene': ('sjampanjeglass',),
'sjampanjeglasset': ('sjampanjeglass',),
'sjarter': ('sjarter',),
'sjarteret': ('sjarter',),
'sjartra': ('sjarter',),
'sjartre': ('sjarter',),
'sjartrene': ('sjarter',),
'sjartret': ('sjarter',),
'sjarterfly': ('sjarterfly',),
'sjarterflya': ('sjarterfly',),
'sjarterflyene': ('sjarterfly',),
'sjarterflyet': ('sjarterfly',),
'sjarterreisa': ('sjarterreise',),
'sjarterreise': ('sjarterreise',),
'sjarterreisen': ('sjarterreise',),
'sjarterreisene': ('sjarterreise',),
'sjarterreiser': ('sjarterreise',),
'sjartertur': ('sjartertur',),
'sjarterturen': ('sjartertur',),
'sjarterturene': ('sjartertur',),
'sjarterturer': ('sjartertur',),
'sjiaislam': ('sjiaislam',),
'sjæfer': ('sjæfer',),
'sjæfere': ('sjæfer',),
'sjæferen': ('sjæfer',),
'sjæferer': ('sjæfer',),
'sjæferne': ('sjæfer',),
'sjæferhund': ('sjæferhund',),
'sjæferhunden': ('sjæferhund',),
'sjæferhundene': ('sjæferhund',),
'sjæferhunder': ('sjæferhund',),
'sjåk': ('sjåk',),
'sjåken': ('sjåk',),
'sjåkene': ('sjåk',),
'sjåker': ('sjåk',),
'skatteflukt': ('skatteflukt',),
'skatteflukta': ('skatteflukt',),
'skatteflukten': ('skatteflukt',),
'skattefluktene': ('skatteflukt',),
'skatteflukter': ('skatteflukt',),
'skatteunndragning': ('skatteunndragning',),
'skatteunndragninga': ('skatteunndragning',),
'skatteunndragningen': ('skatteunndragning',),
'skatteunndragningene': ('skatteunndragning',),
'skatteunndragninger': ('skatteunndragning',),
'skaumaskin': ('skaumaskin',),
'skaumaskina': ('skaumaskin',),
'skaumaskinen': ('skaumaskin',),
'skaumaskinene': ('skaumaskin',),
'skaumaskiner': ('skaumaskin',),
'skausnipa': ('skausnipe',),
'skausnipe': ('skausnipe',),
'skausnipen': ('skausnipe',),
'skausnipene': ('skausnipe',),
'skausniper': ('skausnipe',),
'skeleton': ('skeleton',),
'skeletona': ('skeleton',),
'skeletonene': ('skeleton',),
'skeletoner': ('skeleton',),
'skeletonet': ('skeleton',),
'skilleark': ('skilleark',),
'skillearka': ('skilleark',),
'skillearkene': ('skilleark',),
'skillearket': ('skilleark',),
'skipp': ('skipp',),
'skippen': ('skipp',),
'skippene': ('skipp',),
'skipper': ('skipp',),
'skjermbrev': ('skjermbrev',),
'skjermbreva': ('skjermbrev',),
'skjermbrevene': ('skjermbrev',),
'skjermbrever': ('skjermbrev',),
'skjermbrevet': ('skjermbrev',),
'skjermsparer': ('skjermsparer',),
'skjermsparere': ('skjermsparer',),
'skjermspareren': ('skjermsparer',),
'skjermsparerne': ('skjermsparer',),
'skjørbuksurt': ('skjørbuksurt',),
'skjørbuksurta': ('skjørbuksurt',),
'skjørbuksurten': ('skjørbuksurt',),
'skjørbuksurtene': ('skjørbuksurt',),
'skjørbuksurter': ('skjørbuksurt',),
'skjørhetsgrad': ('skjørhetsgrad',),
'skjørhetsgraden': ('skjørhetsgrad',),
'skjørhetsgradene': ('skjørhetsgrad',),
'skjørhetsgrader': ('skjørhetsgrad',),
'skogsnipa': ('skogsnipe',),
'skogsnipe': ('skogsnipe',),
'skogsnipen': ('skogsnipe',),
'skogsnipene': ('skogsnipe',),
'skogsniper': ('skogsnipe',),
'skosdrift': ('skosdrift',),
'skosdrifta': ('skosdrift',),
'skosdriften': ('skosdrift',),
'skosdriftene': ('skosdrift',),
'skosdrifter': ('skosdrift',),
'skredhund': ('skredhund',),
'skredhunden': ('skredhund',),
'skredhundene': ('skredhund',),
'skredhunder': ('skredhund',),
'skript': ('skript',),
'skripta': ('skript',),
'skriptene': ('skript',),
'skriptet': ('skript',),
'skriverkarl': ('skriverkarl',),
'skriverkarlen': ('skriverkarl',),
'skriverkarlene': ('skriverkarl',),
'skriverkarler': ('skriverkarl',),
'skrotum': ('skrotum',),
'skup': ('skup',),
'skupa': ('skup',),
'skupene': ('skup',),
'skupet': ('skup',),
'skøyteski': ('skøyteski',),
'skøyteskia': ('skøyteski',),
'skøyteskien': ('skøyteski',),
'skøyteskiene': ('skøyteski',),
'skøyteskier': ('skøyteski',),
'slagsena': ('slagsene',),
'slagsene': ('slagsene',),
'slagsenen': ('slagsene',),
'slagsenene': ('slagsene',),
'slagsener': ('slagsene',),
'smakssella': ('smaksselle',),
'smaksselle': ('smaksselle',),
'smakssellen': ('smaksselle',),
'smakssellene': ('smaksselle',),
'smaksseller': ('smaksselle',),
'smartkort': ('smartkort',),
'smartkorta': ('smartkort',),
'smartkortene': ('smartkort',),
'smartkortet': ('smartkort',),
'smegma': ('smegma',),
'smegmaen': ('smegma',),
'smegmaene': ('smegma',),
'smegmaer': ('smegma',),
'snauskalle': ('snauskalle',),
'snauskallen': ('snauskalle',),
'snauskallene': ('snauskalle',),
'snauskaller': ('snauskalle',),
'snikekatt': ('snikekatt',),
'snikekatten': ('snikekatt',),
'snikekattene': ('snikekatt',),
'snikekatter': ('snikekatt',),
'snikfotograf': ('snikfotograf',),
'snikfotografen': ('snikfotograf',),
'snikfotografene': ('snikfotograf',),
'snikfotografer': ('snikfotograf',),
'snipefamilie': ('snipefamilie',),
'snipefamilien': ('snipefamilie',),
'snipefamiliene': ('snipefamilie',),
'snipefamilier': ('snipefamilie',),
'snøbrettkjører': ('snøbrettkjører',),
'snøbrettkjørere': ('snøbrettkjører',),
'snøbrettkjøreren': ('snøbrettkjører',),
'snøbrettkjørerer': ('snøbrettkjører',),
'snøbrettkjørerne': ('snøbrettkjører',),
'solanin': ('solanin',),
'solanina': ('solanin',),
'solaninene': ('solanin',),
'solaninet': ('solanin',),
'solhøgda': ('solhøgde',),
'solhøgde': ('solhøgde',),
'solhøgden': ('solhøgde',),
'solhøgdene': ('solhøgde',),
'solhøgder': ('solhøgde',),
'solhøyde': ('solhøyde',),
'solhøyden': ('solhøyde',),
'solhøydene': ('solhøyde',),
'solhøyder': ('solhøyde',),
'solsella': ('solselle',),
'solselle': ('solselle',),
'solsellen': ('solselle',),
'solsellene': ('solselle',),
'solseller': ('solselle',),
'solsellepanel': ('solsellepanel',),
'solsellepanela': ('solsellepanel',),
'solsellepanelene': ('solsellepanel',),
'solsellepaneler': ('solsellepanel',),
'solsellepanelet': ('solsellepanel',),
'somatiker': ('somatiker',),
'somatikere': ('somatiker',),
'somatikeren': ('somatiker',),
'somatikerne': ('somatiker',),
'somatikk': ('somatikk',),
'somatikken': ('somatikk',),
'somatikkene': ('somatikk',),
'somatikker': ('somatikk',),
'sommerkotelett': ('sommerkotelett',),
'sommerkoteletten': ('sommerkotelett',),
'sommerkotelettene': ('sommerkotelett',),
'sommerkoteletter': ('sommerkotelett',),
'sorbeen': ('sorbé',),
'sorbeene': ('sorbé',),
'sorbeer': ('sorbé',),
'sorbé': ('sorbé',),
'sorbéen': ('sorbé',),
'sorbéene': ('sorbé',),
'sorbéer': ('sorbé',),
'souvlaki': ('souvlaki',),
'souvlakien': ('souvlaki',),
'souvlakiene': ('souvlaki',),
'souvlakier': ('souvlaki',),
'speltbrød': ('speltbrød',),
'speltbrøda': ('speltbrød',),
'speltbrødene': ('speltbrød',),
'speltbrødet': ('speltbrød',),
'spenserjakka': ('spenserjakke',),
'spenserjakke': ('spenserjakke',),
'spenserjakken': ('spenserjakke',),
'spenserjakkene': ('spenserjakke',),
'spenserjakker': ('spenserjakke',),
'spenserkjole': ('spenserkjole',),
'spenserkjolen': ('spenserkjole',),
'spenserkjolene': ('spenserkjole',),
'spenserkjoler': ('spenserkjole',),
'sportsgymnastikk': ('sportsgymnastikk',),
'sportsgymnastikken': ('sportsgymnastikk',),
'sportsgymnastikkene': ('sportsgymnastikk',),
'sportsgymnastikker': ('sportsgymnastikk',),
'spot': ('spot',),
'spoten': ('spot',),
'spotene': ('spot',),
'spoter': ('spot',),
'spothandel': ('spothandel',),
'spothandelen': ('spothandel',),
'spothandlene': ('spothandel',),
'spothandler': ('spothandel',),
'spotpris': ('spotpris',),
'spotprisen': ('spotpris',),
'spotprisene': ('spotpris',),
'spotpriser': ('spotpris',),
'språkteknologi': ('språkteknologi',),
'språkteknologien': ('språkteknologi',),
'språkteknologiene': ('språkteknologi',),
'språkteknologier': ('språkteknologi',),
'språkvask': ('språkvask',),
'språkvasken': ('språkvask',),
'språkvaskene': ('språkvask',),
'språkvasker': ('språkvask',),
'språkvasking': ('språkvasking',),
'språkvaskinga': ('språkvasking',),
'språkvaskingen': ('språkvasking',),
'språkvaskingene': ('språkvasking',),
'språkvaskinger': ('språkvasking',),
'stallo': ('stallo',),
'stalloen': ('stallo',),
'stalloene': ('stallo',),
'stalloer': ('stallo',),
'startsperra': ('startsperre',),
'startsperre': ('startsperre',),
'startsperren': ('startsperre',),
'startsperrene': ('startsperre',),
'startsperrer': ('startsperre',),
'stavgang': ('stavgang',),
'stavgangen': ('stavgang',),
'stavgangene': ('stavgang',),
'stavganger': ('stavgang',),
'steinsetting': ('steinsetting',),
'steinsettinga': ('steinsetting',),
'steinsettingen': ('steinsetting',),
'steinsettingene': ('steinsetting',),
'steinsettinger': ('steinsetting',),
'stemmefiska': ('stemmefiske',),
'stemmefiske': ('stemmefiske',),
'stemmefiskene': ('stemmefiske',),
'stemmefisker': ('stemmefiske',),
'stemmefisket': ('stemmefiske',),
'stereotype': ('stereotype',),
'stereotypeen': ('stereotype',),
'stereotypeene': ('stereotype',),
'stereotypeer': ('stereotype',),
'stikkeflua': ('stikkeflue',),
'stikkeflue': ('stikkeflue',),
'stikkefluen': ('stikkeflue',),
'stikkefluene': ('stikkeflue',),
'stikkefluer': ('stikkeflue',),
'stillits': ('stillits',),
'stillitsen': ('stillits',),
'stillitsene': ('stillits',),
'stillitser': ('stillits',),
'stjernekrig': ('stjernekrig',),
'stjernekrigen': ('stjernekrig',),
'stjernekrigene': ('stjernekrig',),
'stjernekriger': ('stjernekrig',),
'stjernekrigsprogram': ('stjernekrigsprogram',),
'stjernekrigsprogramma': ('stjernekrigsprogram',),
'stjernekrigsprogrammene': ('stjernekrigsprogram',),
'stjernekrigsprogrammer': ('stjernekrigsprogram',),
'stjernekrigsprogrammet': ('stjernekrigsprogram',),
'stoda': ('stode',),
'stode': ('stode',),
'stoden': ('stode',),
'stodene': ('stode',),
'stoder': ('stode',),
'stormlykt': ('stormlykt',),
'stormlykta': ('stormlykt',),
'stormlykten': ('stormlykt',),
'stormlyktene': ('stormlykt',),
'stormlykter': ('stormlykt',),
'storvesir': ('storvesir',),
'storvesiren': ('storvesir',),
'storvesirene': ('storvesir',),
'storvesirer': ('storvesir',),
'strandkrabba': ('strandkrabbe',),
'strandkrabbe': ('strandkrabbe',),
'strandkrabben': ('strandkrabbe',),
'strandkrabbene': ('strandkrabbe',),
'strandkrabber': ('strandkrabbe',),
'studiovert': ('studiovert',),
'studioverten': ('studiovert',),
'studiovertene': ('studiovert',),
'studioverter': ('studiovert',),
'stunt': ('stunt',),
'stunta': ('stunt',),
'stuntene': ('stunt',),
'stuntet': ('stunt',),
'stuntreporter': ('stuntreporter',),
'stuntreportere': ('stuntreporter',),
'stuntreporteren': ('stuntreporter',),
'stuntreporterne': ('stuntreporter',),
'styling': ('styling',),
'stylingen': ('styling',),
'stylingene': ('styling',),
'stylinger': ('styling',),
'stylist': ('stylist',),
'stylisten': ('stylist',),
'stylistene': ('stylist',),
'stylister': ('stylist',),
'støtteark': ('støtteark',),
'støttearka': ('støtteark',),
'støttearkene': ('støtteark',),
'støttearket': ('støtteark',),
'sulfatsellulose': ('sulfatsellulose',),
'sulfatsellulosen': ('sulfatsellulose',),
'sulfatsellulosene': ('sulfatsellulose',),
'sulfatselluloser': ('sulfatsellulose',),
'sulfittsellulose': ('sulfittsellulose',),
'sulfittsellulosen': ('sulfittsellulose',),
'sulfittsellulosene': ('sulfittsellulose',),
'sulfittselluloser': ('sulfittsellulose',),
'sumo': ('sumo',),
'sumoen': ('sumo',),
'sumoene': ('sumo',),
'sumoer': ('sumo',),
'sunniislam': ('sunniislam',),
'sura': ('sura',),
'suraen': ('sura',),
'suraene': ('sura',),
'suraer': ('sura',),
'sure': ('sure',),
'sureen': ('sure',),
'sureene': ('sure',),
'sureer': ('sure',),
'sushi': ('sushi',),
'sushien': ('sushi',),
'sushiene': ('sushi',),
'sushier': ('sushi',),
'svalbardrein': ('svalbardrein',),
'svalbardreinen': ('svalbardrein',),
'svalbardreinene': ('svalbardrein',),
'svalbardreiner': ('svalbardrein',),
'svalbardskatt': ('svalbardskatt',),
'svalbardskatten': ('svalbardskatt',),
'svalbardskattene': ('svalbardskatt',),
'svalbardskatter': ('svalbardskatt',),
'svevestøv': ('svevestøv',),
'svevestøva': ('svevestøv',),
'svevestøvene': ('svevestøv',),
'svevestøvet': ('svevestøv',),
'syklamat': ('syklamat',),
'syklamata': ('syklamat',),
'syklamatene': ('syklamat',),
'syklamatet': ('syklamat',),
'symbal': ('symbal',),
'symbalen': ('symbal',),
'symbalene': ('symbal',),
'symbaler': ('symbal',),
'symbel': ('symbel',),
'symbelen': ('symbel',),
'symbelene': ('symbel',),
'symbeler': ('symbel',),
'systemprogram': ('systemprogram',),
'systemprogramma': ('systemprogram',),
'systemprogrammene': ('systemprogram',),
'systemprogrammer': ('systemprogram',),
'systemprogrammet': ('systemprogram',),
'syttendedel': ('syttendedel',),
'syttendedelen': ('syttendedel',),
'syttendedelene': ('syttendedel',),
'syttendedeler': ('syttendedel',),
'syttiendedel': ('syttiendedel',),
'syttiendedelen': ('syttiendedel',),
'syttiendedelene': ('syttiendedel',),
'syttiendedeler': ('syttiendedel',),
'syvdel': ('syvdel',),
'syvdelen': ('syvdel',),
'syvdelene': ('syvdel',),
'syvdeler': ('syvdel',),
'syvendedel': ('syvendedel',),
'syvendedelen': ('syvendedel',),
'syvendedelene': ('syvendedel',),
'syvendedeler': ('syvendedel',),
'syver': ('syver',),
'syvere': ('syver',),
'syveren': ('syver',),
'syverne': ('syver',),
'syvmilsfart': ('syvmilsfart',),
'syvmilsfarten': ('syvmilsfart',),
'syvmilsfartene': ('syvmilsfart',),
'syvmilsfarter': ('syvmilsfart',),
'syvmilsstøvlene': ('syvmilsstøvler',),
'syvmilsstøvler': ('syvmilsstøvler',),
'syvsover': ('syvsover',),
'syvsovere': ('syvsover',),
'syvsoveren': ('syvsover',),
'syvsoverer': ('syvsover',),
'syvsoverne': ('syvsover',),
'syvsoverdag': ('syvsoverdag',),
'syvsoverdagen': ('syvsoverdag',),
'syvsoverdagene': ('syvsoverdag',),
'syvsoverdager': ('syvsoverdag',),
'syvtall': ('syvtall',),
'syvtalla': ('syvtall',),
'syvtallene': ('syvtall',),
'syvtallet': ('syvtall',),
'syvtid': ('syvtid',),
'syvtida': ('syvtid',),
'syvtiden': ('syvtid',),
'syvtidene': ('syvtid',),
'syvtider': ('syvtid',),
'syvåring': ('syvåring',),
'syvåringen': ('syvåring',),
'syvåringene': ('syvåring',),
'syvåringer': ('syvåring',),
'syvårsalder': ('syvårsalder',),
'syvårsaldere': ('syvårsalder',),
'syvårsalderen': ('syvårsalder',),
'syvårsalderne': ('syvårsalder',),
'syvårsaldre': ('syvårsalder',),
'syvårsaldrene': ('syvårsalder',),
'syvårsaldrer': ('syvårsalder',),
'sædgiver': ('sædgiver',),
'sædgivere': ('sædgiver',),
'sædgiveren': ('sædgiver',),
'sædgiverne': ('sædgiver',),
'sædsella': ('sædselle',),
'sædselle': ('sædselle',),
'sædsellen': ('sædselle',),
'sædsellene': ('sædselle',),
'sædseller': ('sædselle',),
'søkemotor': ('søkemotor',),
'søkemotoren': ('søkemotor',),
'søkemotorene': ('søkemotor',),
'søkemotorer': ('søkemotor',),
'søkestreng': ('søkestreng',),
'søkestrengen': ('søkestreng',),
'søkestrengene': ('søkestreng',),
'søkestrenger': ('søkestreng',),
'sølibatkrav': ('sølibatkrav',),
'sølibatkrava': ('sølibatkrav',),
'sølibatkravene': ('sølibatkrav',),
'sølibatkravet': ('sølibatkrav',),
'sørvisbil': ('sørvisbil',),
'sørvisbilen': ('sørvisbil',),
'sørvisbilene': ('sørvisbil',),
'sørvisbiler': ('sørvisbil',),
'sørvisinstitusjon': ('sørvisinstitusjon',),
'sørvisinstitusjonen': ('sørvisinstitusjon',),
'sørvisinstitusjonene': ('sørvisinstitusjon',),
'sørvisinstitusjoner': ('sørvisinstitusjon',),
'sørviskontrakt': ('sørviskontrakt',),
'sørviskontrakten': ('sørviskontrakt',),
'sørviskontraktene': ('sørviskontrakt',),
'sørviskontrakter': ('sørviskontrakt',),
'sørvisnæring': ('sørvisnæring',),
'sørvisnæringa': ('sørvisnæring',),
'sørvisnæringen': ('sørvisnæring',),
'sørvisnæringene': ('sørvisnæring',),
'sørvisnæringer': ('sørvisnæring',),
'sørvisyrka': ('sørvisyrke',),
'sørvisyrke': ('sørvisyrke',),
'sørvisyrkene': ('sørvisyrke',),
'sørvisyrker': ('sørvisyrke',),
'sørvisyrket': ('sørvisyrke',),
'sålbenk': ('sålbenk',),
'sålbenken': ('sålbenk',),
'sålbenkene': ('sålbenk',),
'sålbenker': ('sålbenk',),
'såpeserie': ('såpeserie',),
'såpeserien': ('såpeserie',),
'såpeseriene': ('såpeserie',),
'såpeserier': ('såpeserie',),
'tabloid': ('tabloid',),
'tabloiden': ('tabloid',),
'tabloidene': ('tabloid',),
'tabloider': ('tabloid',),
'tabloidjournalistikk': ('tabloidjournalistikk',),
'tabloidjournalistikken': ('tabloidjournalistikk',),
'tabloidjournalistikkene': ('tabloidjournalistikk',),
'tabloidjournalistikker': ('tabloidjournalistikk',),
'taco': ('taco',),
'tacoen': ('taco',),
'tacoene': ('taco',),
'tacoer': ('taco',),
'taekwondo': ('taekwondo',),
'taekwondoen': ('taekwondo',),
'taekwondoene': ('taekwondo',),
'taekwondoer': ('taekwondo',),
'taispråk': ('taispråk',),
'taispråka': ('taispråk',),
'taispråkene': ('taispråk',),
'taispråket': ('taispråk',),
'takeoff': ('takeoff',),
'takeoffen': ('takeoff',),
'takeoffene': ('takeoff',),
'takeoffer': ('takeoff',),
'tamarind': ('tamarind',),
'tamarinden': ('tamarind',),
'tamarindene': ('tamarind',),
'tamarinder': ('tamarind',),
'tamarisk': ('tamarisk',),
'tamarisken': ('tamarisk',),
'tamariskene': ('tamarisk',),
'tamarisker': ('tamarisk',),
'tandemhopp': ('tandemhopp',),
'tandemhoppa': ('tandemhopp',),
'tandemhoppene': ('tandemhopp',),
'tandemhoppet': ('tandemhopp',),
'tankekorn': ('tankekorn',),
'tankekorna': ('tankekorn',),
'tankekornene': ('tankekorn',),
'tankekornet': ('tankekorn',),
'tanksgrav': ('tanksgrav',),
'tanksgrava': ('tanksgrav',),
'tanksgraven': ('tanksgrav',),
'tanksgravene': ('tanksgrav',),
'tanksgraver': ('tanksgrav',),
'tantebarn': ('tantebarn',),
'tantebarna': ('tantebarn',),
'tantebarnene': ('tantebarn',),
'tantebarnet': ('tantebarn',),
'tanteunge': ('tanteunge',),
'tanteungen': ('tanteunge',),
'tanteungene': ('tanteunge',),
'tanteunger': ('tanteunge',),
'tapas': ('tapas',),
'tapasen': ('tapas',),
'tapasene': ('tapas',),
'tapaser': ('tapas',),
'tapasbar': ('tapasbar',),
'tapasbaren': ('tapasbar',),
'tapasbarene': ('tapasbar',),
'tapasbarer': ('tapasbar',),
'tapetlim': ('tapetlim',),
'tapetlima': ('tapetlim',),
'tapetlimene': ('tapetlim',),
'tapetlimet': ('tapetlim',),
'tapetserkniv': ('tapetserkniv',),
'tapetserkniven': ('tapetserkniv',),
'tapetserknivene': ('tapetserkniv',),
'tapetserkniver': ('tapetserkniv',),
'tarantella': ('tarantella',),
'tarantellaen': ('tarantella',),
'tarantellaene': ('tarantella',),
'tarantellaer': ('tarantella',),
'taretråling': ('taretråling',),
'taretrålinga': ('taretråling',),
'taretrålingen': ('taretråling',),
'taretrålingene': ('taretråling',),
'taretrålinger': ('taretråling',),
'tarotkort': ('tarotkort',),
'tarotkorta': ('tarotkort',),
'tarotkortene': ('tarotkort',),
'tarotkortet': ('tarotkort',),
'teaterviter': ('teaterviter',),
'teatervitere': ('teaterviter',),
'teaterviteren': ('teaterviter',),
'teaterviterne': ('teaterviter',),
'telemark': ('telemark',),
'telemarksutstyr': ('telemarksutstyr',),
'telemarksutstyra': ('telemarksutstyr',),
'telemarksutstyrene': ('telemarksutstyr',),
'telemarksutstyret': ('telemarksutstyr',),
'telependling': ('telependling',),
'telependlinga': ('telependling',),
'telependlingen': ('telependling',),
'telependlingene': ('telependling',),
'telependlinger': ('telependling',),
'tellekant': ('tellekant',),
'tellekanten': ('tellekant',),
'tellekantene': ('tellekant',),
'tellekanter': ('tellekant',),
'tennisalbue': ('tennisalbue',),
'tennisalbuen': ('tennisalbue',),
'tennisalbuene': ('tennisalbue',),
'tennisalbuer': ('tennisalbue',),
'teppebombing': ('teppebombing',),
'teppebombinga': ('teppebombing',),
'teppebombingen': ('teppebombing',),
'teppebombingene': ('teppebombing',),
'teppebombinger': ('teppebombing',),
'thaiboksing': ('thaiboksing',),
'thaiboksinga': ('thaiboksing',),
'thaiboksingen': ('thaiboksing',),
'thaiboksingene': ('thaiboksing',),
'thaiboksinger': ('thaiboksing',),
'thaisilke': ('thaisilke',),
'thaisilken': ('thaisilke',),
'thaisilkene': ('thaisilke',),
'thaisilker': ('thaisilke',),
'tidlås': ('tidlås',),
'tidlåsen': ('tidlås',),
'tidlåsene': ('tidlås',),
'tidlåser': ('tidlås',),
'tidsklemma': ('tidsklemme',),
'tidsklemme': ('tidsklemme',),
'tidsklemmen': ('tidsklemme',),
'tidsklemmene': ('tidsklemme',),
'tidsklemmer': ('tidsklemme',),
'tidskonti': ('tidskonto',),
'tidskontiene': ('tidskonto',),
'tidskonto': ('tidskonto',),
'tidskontoen': ('tidskonto',),
'tidskontoene': ('tidskonto',),
'tidskontoer': ('tidskonto',),
'tifotkreps': ('tifotkreps',),
'tifotkrepsen': ('tifotkreps',),
'tifotkrepsene': ('tifotkreps',),
'tifotkrepser': ('tifotkreps',),
'tikronemynt': ('tikronemynt',),
'tikronemynten': ('tikronemynt',),
'tikronemyntene': ('tikronemynt',),
'tikronemynter': ('tikronemynt',),
'tiltakshaver': ('tiltakshaver',),
'tiltakshavere': ('tiltakshaver',),
'tiltakshaveren': ('tiltakshaver',),
'tiltakshaverne': ('tiltakshaver',),
'timoreser': ('timoreser',),
'timoresere': ('timoreser',),
'timoreseren': ('timoreser',),
'timoreserne': ('timoreser',),
'tinder': ('tinder',),
'tinderet': ('tinder',),
'tindra': ('tinder',),
'tindre': ('tinder',),
'tindrene': ('tinder',),
'tindret': ('tinder',),
'tiramisu': ('tiramisu',),
'tiramisuen': ('tiramisu',),
'tiramisuene': ('tiramisu',),
'tiramisuer': ('tiramisu',),
'tjuekrona': ('tjuekrone',),
'tjuekrone': ('tjuekrone',),
'tjuekronen': ('tjuekrone',),
'tjuekronene': ('tjuekrone',),
'tjuekroner': ('tjuekrone',),
'tjuekronemynt': ('tjuekronemynt',),
'tjuekronemynten': ('tjuekronemynt',),
'tjuekronemyntene': ('tjuekronemynt',),
'tjuekronemynter': ('tjuekronemynt',),
'tjuekroning': ('tjuekroning',),
'tjuekroningen': ('tjuekroning',),
'tjuekroningene': ('tjuekroning',),
'tjuekroninger': ('tjuekroning',),
'tjuendedel': ('tjuendedel',),
'tjuendedelen': ('tjuendedel',),
'tjuendedelene': ('tjuendedel',),
'tjuendedeler': ('tjuendedel',),
'toddy': ('toddy',),
'toddyen': ('toddy',),
'toddyene': ('toddy',),
'toddyer': ('toddy',),
'tohundrekroneseddel': ('tohundrekroneseddel',),
'tohundrekroneseddelen': ('tohundrekroneseddel',),
'tohundrekronesedlene': ('tohundrekroneseddel',),
'tohundrekronesedler': ('tohundrekroneseddel',),
'tohundrekroning': ('tohundrekroning',),
'tohundrekroningen': ('tohundrekroning',),
'tohundrekroningene': ('tohundrekroning',),
'tohundrekroninger': ('tohundrekroning',),
'tolar': ('tolar',),
'tolaren': ('tolar',),
'tolarene': ('tolar',),
'tolarer': ('tolar',),
'tomografi': ('tomografi',),
'tomografien': ('tomografi',),
'tomografiene': ('tomografi',),
'tomografier': ('tomografi',),
'tonsur': ('tonsur',),
'tonsuren': ('tonsur',),
'tonsurene': ('tonsur',),
'tonsurer': ('tonsur',),
'torgbod': ('torgbod',),
'torgboden': ('torgbod',),
'torgbodene': ('torgbod',),
'torgboder': ('torgbod',),
'tortilla': ('tortilla',),
'tortillaen': ('tortilla',),
'tortillaene': ('tortilla',),
'tortillaer': ('tortilla',),
'transendens': ('transendens',),
'transendensen': ('transendens',),
'transendensene': ('transendens',),
'transendenser': ('transendens',),
'transponder': ('transponder',),
'transpondere': ('transponder',),
'transponderen': ('transponder',),
'transponderne': ('transponder',),
'transsponder': ('transsponder',),
'transspondere': ('transsponder',),
'transsponderen': ('transsponder',),
'transsponderne': ('transsponder',),
'trebånner': ('trebånner',),
'trebånnere': ('trebånner',),
'trebånneren': ('trebånner',),
'trebånnerer': ('trebånner',),
'trebånnerne': ('trebånner',),
'trediagram': ('trediagram',),
'trediagramma': ('trediagram',),
'trediagrammene': ('trediagram',),
'trediagrammer': ('trediagram',),
'trediagrammet': ('trediagram',),
'trenchcoat': ('trenchcoat',),
'trenchcoaten': ('trenchcoat',),
'trenchcoatene': ('trenchcoat',),
'trenchcoater': ('trenchcoat',),
'treningsprodukt': ('treningsprodukt',),
'treningsprodukta': ('treningsprodukt',),
'treningsproduktene': ('treningsprodukt',),
'treningsprodukter': ('treningsprodukt',),
'treningsproduktet': ('treningsprodukt',),
'trettiendedel': ('trettiendedel',),
'trettiendedelen': ('trettiendedel',),
'trettiendedelene': ('trettiendedel',),
'trettiendedeler': ('trettiendedel',),
'triatlet': ('triatlet',),
'triatleten': ('triatlet',),
'triatletene': ('triatlet',),
'triatleter': ('triatlet',),
'triatloner': ('triatloner',),
'triatlonere': ('triatloner',),
'triatloneren': ('triatloner',),
'triatlonerne': ('triatloner',),
'trillebagg': ('trillebagg',),
'trillebaggen': ('trillebagg',),
'trillebaggene': ('trillebagg',),
'trillebagger': ('trillebagg',),
'trillekoffert': ('trillekoffert',),
'trillekofferten': ('trillekoffert',),
'trillekoffertene': ('trillekoffert',),
'trillekofferter': ('trillekoffert',),
'trilliondel': ('trilliondel',),
'trilliondelen': ('trilliondel',),
'trilliondelene': ('trilliondel',),
'trilliondeler': ('trilliondel',),
'trilliontedel': ('trilliontedel',),
'trilliontedelen': ('trilliontedel',),
'trilliontedelene': ('trilliontedel',),
'trilliontedeler': ('trilliontedel',),
'trondhjemitt': ('trondhjemitt',),
'trondhjemitten': ('trondhjemitt',),
'trondhjemittene': ('trondhjemitt',),
'trondhjemitter': ('trondhjemitt',),
'trunkering': ('trunkering',),
'trunkeringa': ('trunkering',),
'trunkeringen': ('trunkering',),
'trunkeringene': ('trunkering',),
'trunkeringer': ('trunkering',),
'trykkblyant': ('trykkblyant',),
'trykkblyanten': ('trykkblyant',),
'trykkblyantene': ('trykkblyant',),
'trykkblyanter': ('trykkblyant',),
'trålergast': ('trålergast',),
'trålergasten': ('trålergast',),
'trålergastene': ('trålergast',),
'trålergaster': ('trålergast',),
'tsjader': ('tsjader',),
'tsjadere': ('tsjader',),
'tsjaderen': ('tsjader',),
'tsjaderne': ('tsjader',),
'tsjetsjener': ('tsjetsjener',),
'tsjetsjenere': ('tsjetsjener',),
'tsjetsjeneren': ('tsjetsjener',),
'tsjetsjenerne': ('tsjetsjener',),
'tsunami': ('tsunami',),
'tsunamien': ('tsunami',),
'tsunamiene': ('tsunami',),
'tsunamier': ('tsunami',),
'tubb': ('tubb',),
'tubben': ('tubb',),
'tubbene': ('tubb',),
'tubber': ('tubb',),
'tuja': ('tuja',),
'tujaen': ('tuja',),
'tujaene': ('tuja',),
'tujaer': ('tuja',),
'turbojetmotor': ('turbojetmotor',),
'turbojetmotoren': ('turbojetmotor',),
'turbojetmotorene': ('turbojetmotor',),
'turbojetmotorer': ('turbojetmotor',),
'turbojettmotor': ('turbojettmotor',),
'turbojettmotoren': ('turbojettmotor',),
'turbojettmotorene': ('turbojettmotor',),
'turbojettmotorer': ('turbojettmotor',),
'tusendedel': ('tusendedel',),
'tusendedelen': ('tusendedel',),
'tusendedelene': ('tusendedel',),
'tusendedeler': ('tusendedel',),
'undergrunnsmusikk': ('undergrunnsmusikk',),
'undergrunnsmusikken': ('undergrunnsmusikk',),
'undergrunnsmusikkene': ('undergrunnsmusikk',),
'undergrunnsmusikker': ('undergrunnsmusikk',),
'unilateralisme': ('unilateralisme',),
'unilateralismen': ('unilateralisme',),
'unilateralismene': ('unilateralisme',),
'unilateralismer': ('unilateralisme',),
'unnamanøver': ('unnamanøver',),
'unnamanøvere': ('unnamanøver',),
'unnamanøveren': ('unnamanøver',),
'unnamanøverne': ('unnamanøver',),
'unnamanøvre': ('unnamanøver',),
'unnamanøvrene': ('unnamanøver',),
'unnamanøvrer': ('unnamanøver',),
'urbanist': ('urbanist',),
'urbanisten': ('urbanist',),
'urbanistene': ('urbanist',),
'urbanister': ('urbanist',),
'ursella': ('urselle',),
'urselle': ('urselle',),
'ursellen': ('urselle',),
'ursellene': ('urselle',),
'urseller': ('urselle',),
'USA-amerikaner': ('USA-amerikaner',),
'USA-amerikanere': ('USA-amerikaner',),
'USA-amerikaneren': ('USA-amerikaner',),
'USA-amerikanerne': ('USA-amerikaner',),
'utebruk': ('utebruk',),
'utebruka': ('utebruk',),
'utebruken': ('utebruk',),
'utebrukene': ('utebruk',),
'utebruker': ('utebruk',),
'utebruket': ('utebruk',),
'utemøbel': ('utemøbel',),
'utemøbelet': ('utemøbel',),
'utemøbla': ('utemøbel',),
'utemøblene': ('utemøbel',),
'utemøbler': ('utemøbel',),
'utemøblet': ('utemøbel',),
'utfasing': ('utfasing',),
'utfasinga': ('utfasing',),
'utfasingen': ('utfasing',),
'utfasingene': ('utfasing',),
'utfasinger': ('utfasing',),
'utriggerkano': ('utriggerkano',),
'utriggerkanoen': ('utriggerkano',),
'utriggerkanoene': ('utriggerkano',),
'utriggerkanoer': ('utriggerkano',),
'utsider': ('utsider',),
'utsidere': ('utsider',),
'utsideren': ('utsider',),
'utsiderne': ('utsider',),
'utsynning': ('utsynning',),
'utsynningen': ('utsynning',),
'utsynningene': ('utsynning',),
'utsynninger': ('utsynning',),
'uttaingskonkurranse': ('uttaingskonkurranse',),
'uttaingskonkurransen': ('uttaingskonkurranse',),
'uttaingskonkurransene': ('uttaingskonkurranse',),
'uttaingskonkurranser': ('uttaingskonkurranse',),
'UV-filter': ('UV-filter',),
'UV-filteret': ('UV-filter',),
'UV-filtra': ('UV-filter',),
'UV-filtre': ('UV-filter',),
'UV-filtrene': ('UV-filter',),
'UV-filtret': ('UV-filter',),
'UV-stråling': ('UV-stråling',),
'UV-strålinga': ('UV-stråling',),
'UV-strålingen': ('UV-stråling',),
'UV-strålingene': ('UV-stråling',),
'UV-strålinger': ('UV-stråling',),
'valgdagsmåling': ('valgdagsmåling',),
'valgdagsmålinga': ('valgdagsmåling',),
'valgdagsmålingen': ('valgdagsmåling',),
'valgdagsmålingene': ('valgdagsmåling',),
'valgdagsmålinger': ('valgdagsmåling',),
'vannbrett': ('vannbrett',),
'vannbretta': ('vannbrett',),
'vannbrettene': ('vannbrett',),
'vannbretter': ('vannbrett',),
'vannbrettet': ('vannbrett',),
'vanntunell': ('vanntunell',),
'vanntunellen': ('vanntunell',),
'vanntunellene': ('vanntunell',),
'vanntuneller': ('vanntunell',),
'vara': ('vara',),
'varaen': ('vara',),
'varaene': ('vara',),
'varaer': ('vara',),
'vassbrett': ('vassbrett',),
'vassbretta': ('vassbrett',),
'vassbrettene': ('vassbrett',),
'vassbretter': ('vassbrett',),
'vassbrettet': ('vassbrett',),
'vasstunell': ('vasstunell',),
'vasstunellen': ('vasstunell',),
'vasstunellene': ('vasstunell',),
'vasstuneller': ('vasstunell',),
'vasstunell': ('vasstunell',),
'vasstunellen': ('vasstunell',),
'vasstunellene': ('vasstunell',),
'vasstuneller': ('vasstunell',),
'vasstunell': ('vasstunell',),
'vasstunellen': ('vasstunell',),
'vasstunellene': ('vasstunell',),
'vasstuneller': ('vasstunell',),
'vebb': ('vebb',),
'vebben': ('vebb',),
'vebbene': ('vebb',),
'vebber': ('vebb',),
'vebbstoff': ('vebbstoff',),
'vebbstoffa': ('vebbstoff',),
'vebbstoffene': ('vebbstoff',),
'vebbstoffer': ('vebbstoff',),
'vebbstoffet': ('vebbstoff',),
'vebbutstyr': ('vebbutstyr',),
'vebbutstyra': ('vebbutstyr',),
'vebbutstyrene': ('vebbutstyr',),
'vebbutstyret': ('vebbutstyr',),
'vedsella': ('vedselle',),
'vedselle': ('vedselle',),
'vedsellen': ('vedselle',),
'vedsellene': ('vedselle',),
'vedseller': ('vedselle',),
'vegprising': ('vegprising',),
'vegprisinga': ('vegprising',),
'vegprisingen': ('vegprising',),
'vegprisingene': ('vegprising',),
'vegprisinger': ('vegprising',),
'vegtunell': ('vegtunell',),
'vegtunellen': ('vegtunell',),
'vegtunellene': ('vegtunell',),
'vegtuneller': ('vegtunell',),
'veiprising': ('veiprising',),
'veiprisinga': ('veiprising',),
'veiprisingen': ('veiprising',),
'veiprisingene': ('veiprising',),
'veiprisinger': ('veiprising',),
'veitunell': ('veitunell',),
'veitunellen': ('veitunell',),
'veitunellene': ('veitunell',),
'veituneller': ('veitunell',),
'videokonferanse': ('videokonferanse',),
'videokonferansen': ('videokonferanse',),
'videokonferansene': ('videokonferanse',),
'videokonferanser': ('videokonferanse',),
'viggetang': ('viggetang',),
'viggetanga': ('viggetang',),
'viggetangen': ('viggetang',),
'viggetangene': ('viggetang',),
'viggetanger': ('viggetang',),
'vikketang': ('vikketang',),
'vikketanga': ('vikketang',),
'vikketangen': ('vikketang',),
'vikketangene': ('vikketang',),
'vikketanger': ('vikketang',),
'vindtunell': ('vindtunell',),
'vindtunellen': ('vindtunell',),
'vindtunellene': ('vindtunell',),
'vindtuneller': ('vindtunell',),
'vippehuska': ('vippehuske',),
'vippehuske': ('vippehuske',),
'vippehusken': ('vippehuske',),
'vippehuskene': ('vippehuske',),
'vippehusker': ('vippehuske',),
'vokk': ('vokk',),
'vokken': ('vokk',),
'vokkene': ('vokk',),
'vokker': ('vokk',),
'volatilitet': ('volatilitet',),
'volatiliteten': ('volatilitet',),
'volatilitetene': ('volatilitet',),
'volatiliteter': ('volatilitet',),
'voluntarisme': ('voluntarisme',),
'voluntarismen': ('voluntarisme',),
'voluntarismene': ('voluntarisme',),
'voluntarismer': ('voluntarisme',),
'værdama': ('værdame',),
'værdame': ('værdame',),
'værdamen': ('værdame',),
'værdamene': ('værdame',),
'værdamer': ('værdame',),
'værmelder': ('værmelder',),
'værmeldere': ('værmelder',),
'værmelderen': ('værmelder',),
'værmelderne': ('værmelder',),
'walkietalkie': ('walkietalkie',),
'walkietalkien': ('walkietalkie',),
'walkietalkiene': ('walkietalkie',),
'walkietalkier': ('walkietalkie',),
'web': ('web',),
'weben': ('web',),
'webene': ('web',),
'weber': ('web',),
'webstoff': ('webstoff',),
'webstoffa': ('webstoff',),
'webstoffene': ('webstoff',),
'webstoffer': ('webstoff',),
'webstoffet': ('webstoff',),
'webutstyr': ('webutstyr',),
'webutstyra': ('webutstyr',),
'webutstyrene': ('webutstyr',),
'webutstyret': ('webutstyr',),
'wok': ('wok',),
'woken': ('wok',),
'wokene': ('wok',),
'woker': ('wok',),
'won': ('won',),
'wonen': ('won',),
'wonene': ('won',),
'woner': ('won',),
'worldcup': ('worldcup',),
'worldcupen': ('worldcup',),
'worldcupene': ('worldcup',),
'worldcuper': ('worldcup',),
'worldcuprenn': ('worldcuprenn',),
'worldcuprenna': ('worldcuprenn',),
'worldcuprennene': ('worldcuprenn',),
'worldcuprennet': ('worldcuprenn',),
'X-kromosom': ('X-kromosom',),
'X-kromosoma': ('X-kromosom',),
'X-kromosomene': ('X-kromosom',),
'X-kromosomer': ('X-kromosom',),
'X-kromosomet': ('X-kromosom',),
'yap': ('yap',),
'yapen': ('yap',),
'yapene': ('yap',),
'yaper': ('yap',),
'Y-kromosom': ('Y-kromosom',),
'Y-kromosoma': ('Y-kromosom',),
'Y-kromosomene': ('Y-kromosom',),
'Y-kromosomer': ('Y-kromosom',),
'Y-kromosomet': ('Y-kromosom',),
'ytringsrett': ('ytringsrett',),
'ytringsretten': ('ytringsrett',),
'ytringsrettene': ('ytringsrett',),
'ytringsretter': ('ytringsrett',),
'æresdrap': ('æresdrap',),
'æresdrapa': ('æresdrap',),
'æresdrapene': ('æresdrap',),
'æresdrapet': ('æresdrap',),
'øyhopping': ('øyhopping',),
'øyhoppinga': ('øyhopping',),
'øyhoppingen': ('øyhopping',),
'øyhoppingene': ('øyhopping',),
'øyhoppinger': ('øyhopping',),
'øyloffer': ('øyloffer',),
'øyloffere': ('øyloffer',),
'øylofferen': ('øyloffer',),
'øylofferne': ('øyloffer',),
'øyloffing': ('øyloffing',),
'øyloffinga': ('øyloffing',),
'øyloffingen': ('øyloffing',),
'øyloffingene': ('øyloffing',),
'øyloffinger': ('øyloffing',),
'ågerkarl': ('ågerkarl',),
'ågerkarlen': ('ågerkarl',),
'ågerkarlene': ('ågerkarl',),
'ågerkarler': ('ågerkarl',),
'åttetid': ('åttetid',),
'åttetida': ('åttetid',),
'åttetiden': ('åttetid',),
'åttetidene': ('åttetid',),
'åttetider': ('åttetid',),
'åttiendedel': ('åttiendedel',),
'åttiendedelen': ('åttiendedel',),
'åttiendedelene': ('åttiendedel',),
'åttiendedeler': ('åttiendedel',),
'BNI': ('BNI',),
'SMS-melding': ('SMS-melding',),
'SMS-meldinga': ('SMS-melding',),
'SMS-meldingen': ('SMS-melding',),
'SMS-meldingene': ('SMS-melding',),
'SMS-meldinger': ('SMS-melding',),
'baggvogn': ('baggvogn',),
'baggvogna': ('baggvogn',),
'baggvognen': ('baggvogn',),
'baggvognene': ('baggvogn',),
'baggvogner': ('baggvogn',),
'belegning': ('belegning',),
'belegninga': ('belegning',),
'belegningen': ('belegning',),
'belegningene': ('belegning',),
'belegninger': ('belegning',),
'blindflygning': ('blindflygning',),
'blindflygninga': ('blindflygning',),
'blindflygningen': ('blindflygning',),
'blindflygningene': ('blindflygning',),
'blindflygninger': ('blindflygning',),
'blindflyvning': ('blindflyvning',),
'blindflyvninga': ('blindflyvning',),
'blindflyvningen': ('blindflyvning',),
'blindflyvningene': ('blindflyvning',),
'blindflyvninger': ('blindflyvning',),
'carvingski': ('carvingski',),
'carvingskia': ('carvingski',),
'carvingskien': ('carvingski',),
'carvingskiene': ('carvingski',),
'carvingskier': ('carvingski',),
'drageflygning': ('drageflygning',),
'drageflygninga': ('drageflygning',),
'drageflygningen': ('drageflygning',),
'drageflygningene': ('drageflygning',),
'drageflygninger': ('drageflygning',),
'drageflyvning': ('drageflyvning',),
'drageflyvninga': ('drageflyvning',),
'drageflyvningen': ('drageflyvning',),
'drageflyvningene': ('drageflyvning',),
'drageflyvninger': ('drageflyvning',),
'formasjonsflygning': ('formasjonsflygning',),
'formasjonsflygninga': ('formasjonsflygning',),
'formasjonsflygningen': ('formasjonsflygning',),
'formasjonsflygningene': ('formasjonsflygning',),
'formasjonsflygninger': ('formasjonsflygning',),
'formasjonsflyvning': ('formasjonsflyvning',),
'formasjonsflyvninga': ('formasjonsflyvning',),
'formasjonsflyvningen': ('formasjonsflyvning',),
'formasjonsflyvningene': ('formasjonsflyvning',),
'formasjonsflyvninger': ('formasjonsflyvning',),
'gründervirksomhet': ('gründervirksomhet',),
'gründervirksomheta': ('gründervirksomhet',),
'gründervirksomheten': ('gründervirksomhet',),
'gründervirksomhetene': ('gründervirksomhet',),
'gründervirksomheter': ('gründervirksomhet',),
'hengflygning': ('hengflygning',),
'hengflygninga': ('hengflygning',),
'hengflygningen': ('hengflygning',),
'hengflygningene': ('hengflygning',),
'hengflygninger': ('hengflygning',),
'hengflyvning': ('hengflyvning',),
'hengflyvninga': ('hengflyvning',),
'hengflyvningen': ('hengflyvning',),
'hengflyvningene': ('hengflyvning',),
'hengflyvninger': ('hengflyvning',),
'innflygning': ('innflygning',),
'innflygninga': ('innflygning',),
'innflygningen': ('innflygning',),
'innflygningene': ('innflygning',),
'innflygninger': ('innflygning',),
'innflyvning': ('innflyvning',),
'innflyvninga': ('innflyvning',),
'innflyvningen': ('innflyvning',),
'innflyvningene': ('innflyvning',),
'innflyvninger': ('innflyvning',),
'instrumentflygning': ('instrumentflygning',),
'instrumentflygninga': ('instrumentflygning',),
'instrumentflygningen': ('instrumentflygning',),
'instrumentflygningene': ('instrumentflygning',),
'instrumentflygninger': ('instrumentflygning',),
'instrumentflyvning': ('instrumentflyvning',),
'instrumentflyvninga': ('instrumentflyvning',),
'instrumentflyvningen': ('instrumentflyvning',),
'instrumentflyvningene': ('instrumentflyvning',),
'instrumentflyvninger': ('instrumentflyvning',),
'karvingski': ('karvingski',),
'karvingskia': ('karvingski',),
'karvingskien': ('karvingski',),
'karvingskiene': ('karvingski',),
'karvingskier': ('karvingski',),
'molekylærvekt': ('molekylærvekt',),
'molekylærvekta': ('molekylærvekt',),
'molekylærvekten': ('molekylærvekt',),
'molekylærvektene': ('molekylærvekt',),
'molekylærvekter': ('molekylærvekt',),
'overflygning': ('overflygning',),
'overflygninga': ('overflygning',),
'overflygningen': ('overflygning',),
'overflygningene': ('overflygning',),
'overflygninger': ('overflygning',),
'overflyvning': ('overflyvning',),
'overflyvninga': ('overflyvning',),
'overflyvningen': ('overflyvning',),
'overflyvningene': ('overflyvning',),
'overflyvninger': ('overflyvning',),
'skiflygning': ('skiflygning',),
'skiflygninga': ('skiflygning',),
'skiflygningen': ('skiflygning',),
'skiflygningene': ('skiflygning',),
'skiflygninger': ('skiflygning',),
'skiflyvning': ('skiflyvning',),
'skiflyvninga': ('skiflyvning',),
'skiflyvningen': ('skiflyvning',),
'skiflyvningene': ('skiflyvning',),
'skiflyvninger': ('skiflyvning',),
'skoleflygning': ('skoleflygning',),
'skoleflygninga': ('skoleflygning',),
'skoleflygningen': ('skoleflygning',),
'skoleflygningene': ('skoleflygning',),
'skoleflygninger': ('skoleflygning',),
'skoleflyvning': ('skoleflyvning',),
'skoleflyvninga': ('skoleflyvning',),
'skoleflyvningen': ('skoleflyvning',),
'skoleflyvningene': ('skoleflyvning',),
'skoleflyvninger': ('skoleflyvning',),
'stenfrukt': ('stenfrukt',),
'stenfrukta': ('stenfrukt',),
'stenfrukten': ('stenfrukt',),
'stenfruktene': ('stenfrukt',),
'stenfrukter': ('stenfrukt',),
'svigersøster': ('svigersøster',),
'svigersøstera': ('svigersøster',),
'svigersøsteren': ('svigersøster',),
'svigersøstre': ('svigersøster',),
'svigersøstrene': ('svigersøster',),
'svigersøstrer': ('svigersøster',),
'tekstmelding': ('tekstmelding',),
'tekstmeldinga': ('tekstmelding',),
'tekstmeldingen': ('tekstmelding',),
'tekstmeldingene': ('tekstmelding',),
'tekstmeldinger': ('tekstmelding',),
'togvert': ('togvert',),
'togverten': ('togvert',),
'togvertene': ('togvert',),
'togverter': ('togvert',),
'universaltid': ('universaltid',),
'universaltida': ('universaltid',),
'universaltiden': ('universaltid',),
'universaltidene': ('universaltid',),
'universaltider': ('universaltid',),
'øvelsesflygning': ('øvelsesflygning',),
'øvelsesflygninga': ('øvelsesflygning',),
'øvelsesflygningen': ('øvelsesflygning',),
'øvelsesflygningene': ('øvelsesflygning',),
'øvelsesflygninger': ('øvelsesflygning',),
'øvelsesflyvning': ('øvelsesflyvning',),
'øvelsesflyvninga': ('øvelsesflyvning',),
'øvelsesflyvningen': ('øvelsesflyvning',),
'øvelsesflyvningene': ('øvelsesflyvning',),
'øvelsesflyvninger': ('øvelsesflyvning',),
'øvingsflygning': ('øvingsflygning',),
'øvingsflygninga': ('øvingsflygning',),
'øvingsflygningen': ('øvingsflygning',),
'øvingsflygningene': ('øvingsflygning',),
'øvingsflygninger': ('øvingsflygning',),
'øvingsflyvning': ('øvingsflyvning',),
'øvingsflyvninga': ('øvingsflyvning',),
'øvingsflyvningen': ('øvingsflyvning',),
'øvingsflyvningene': ('øvingsflyvning',),
'øvingsflyvninger': ('øvingsflyvning',),
'furunålsolja': ('furunålsolje',),
'furunålsolje': ('furunålsolje',),
'furunålsoljen': ('furunålsolje',),
'furunålsoljene': ('furunålsolje',),
'furunålsoljer': ('furunålsolje',),
'sanntid': ('sanntid',),
'sanntida': ('sanntid',),
'sanntiden': ('sanntid',),
'sanntidene': ('sanntid',),
'sanntider': ('sanntid',),
'molekylærkraft': ('molekylærkraft',),
'molekylærkrafta': ('molekylærkraft',),
'molekylærkraften': ('molekylærkraft',),
'molekylærkraftene': ('molekylærkraft',),
'molekylærkrafter': ('molekylærkraft',),
'gebursdagsgava': ('gebursdagsgave',),
'gebursdagsgave': ('gebursdagsgave',),
'gebursdagsgaven': ('gebursdagsgave',),
'gebursdagsgavene': ('gebursdagsgave',),
'gebursdagsgaver': ('gebursdagsgave',),
'glattsella': ('glattselle',),
'glattselle': ('glattselle',),
'glattsellen': ('glattselle',),
'glattsellene': ('glattselle',),
'glattseller': ('glattselle',),
'internettadressa': ('internettadresse',),
'internettadresse': ('internettadresse',),
'internettadressen': ('internettadresse',),
'internettadressene': ('internettadresse',),
'internettadresser': ('internettadresse',),
'kannabisplanta': ('kannabisplante',),
'kannabisplante': ('kannabisplante',),
'kannabisplanten': ('kannabisplante',),
'kannabisplantene': ('kannabisplante',),
'kannabisplanter': ('kannabisplante',),
'klassereisa': ('klassereise',),
'klassereise': ('klassereise',),
'klassereisen': ('klassereise',),
'klassereisene': ('klassereise',),
'klassereiser': ('klassereise',),
'legionærsjuka': ('legionærsjuke',),
'legionærsjuke': ('legionærsjuke',),
'legionærsjuken': ('legionærsjuke',),
'legionærsjukene': ('legionærsjuke',),
'legionærsjuker': ('legionærsjuke',),
'nettsida': ('nettside',),
'nettside': ('nettside',),
'nettsiden': ('nettside',),
'nettsidene': ('nettside',),
'nettsider': ('nettside',),
'anklet': ('anklet',),
'ankleten': ('anklet',),
'ankletene': ('anklet',),
'ankleter': ('anklet',),
'børek': ('børek',),
'børeken': ('børek',),
'børekene': ('børek',),
'børeker': ('børek',),
'lats': ('lats',),
'latsen': ('lats',),
'latsene': ('lats',),
'latser': ('lats',),
'Internett-kafeen': ('Internett-kafé',),
'Internett-kafeene': ('Internett-kafé',),
'Internett-kafeer': ('Internett-kafé',),
'Internett-kafé': ('Internett-kafé',),
'Internett-kaféen': ('Internett-kafé',),
'Internett-kaféene': ('Internett-kafé',),
'Internett-kaféer': ('Internett-kafé',),
'alsacevin': ('alsacevin',),
'alsacevinen': ('alsacevin',),
'alsacevinene': ('alsacevin',),
'alsaceviner': ('alsacevin',),
'arbitrasjør': ('arbitrasjør',),
'arbitrasjøren': ('arbitrasjør',),
'arbitrasjørene': ('arbitrasjør',),
'arbitrasjører': ('arbitrasjør',),
'avlastingsveg': ('avlastingsveg',),
'avlastingsvegen': ('avlastingsveg',),
'avlastingsvegene': ('avlastingsveg',),
'avlastingsveger': ('avlastingsveg',),
'avlastingsvei': ('avlastingsvei',),
'avlastingsveien': ('avlastingsvei',),
'avlastingsveiene': ('avlastingsvei',),
'avlastingsveier': ('avlastingsvei',),
'avlastningsveg': ('avlastningsveg',),
'avlastningsvegen': ('avlastningsveg',),
'avlastningsvegene': ('avlastningsveg',),
'avlastningsveger': ('avlastningsveg',),
'avlastningsvei': ('avlastningsvei',),
'avlastningsveien': ('avlastningsvei',),
'avlastningsveiene': ('avlastningsvei',),
'avlastningsveier': ('avlastningsvei',),
'bachelor': ('bachelor',),
'bacheloren': ('bachelor',),
'bachelorene': ('bachelor',),
'bachelorer': ('bachelor',),
'bachelorgrad': ('bachelorgrad',),
'bachelorgraden': ('bachelorgrad',),
'bachelorgradene': ('bachelorgrad',),
'bachelorgrader': ('bachelorgrad',),
'belegningsstein': ('belegningsstein',),
'belegningssteinen': ('belegningsstein',),
'belegningssteinene': ('belegningsstein',),
'belegningssteiner': ('belegningsstein',),
'blogg': ('blogg',),
'bloggen': ('blogg',),
'bloggene': ('blogg',),
'blogger': ('blogg',),
'bobil': ('bobil',),
'bobilen': ('bobil',),
'bobilene': ('bobil',),
'bobiler': ('bobil',),
'boksershorts': ('boksershorts',),
'boksershortsen': ('boksershorts',),
'boksershortsene': ('boksershorts',),
'boksershortser': ('boksershorts',),
'bonanza': ('bonanza',),
'bonanzaen': ('bonanza',),
'bonanzaene': ('bonanza',),
'bonanzaer': ('bonanza',),
'bubil': ('bubil',),
'bubilen': ('bubil',),
'bubilene': ('bubil',),
'bubiler': ('bubil',),
'drive-in-kino': ('drive-in-kino',),
'drive-in-kinoen': ('drive-in-kino',),
'drive-in-kinoene': ('drive-in-kino',),
'drive-in-kinoer': ('drive-in-kino',),
'drive-in-restaurant': ('drive-in-restaurant',),
'drive-in-restauranten': ('drive-in-restaurant',),
'drive-in-restaurantene': ('drive-in-restaurant',),
'drive-in-restauranter': ('drive-in-restaurant',),
'dystopi': ('dystopi',),
'dystopien': ('dystopi',),
'dystopiene': ('dystopi',),
'dystopier': ('dystopi',),
'fjæreplytt': ('fjæreplytt',),
'fjæreplytten': ('fjæreplytt',),
'fjæreplyttene': ('fjæreplytt',),
'fjæreplytter': ('fjæreplytt',),
'fjøreplytt': ('fjøreplytt',),
'fjøreplytten': ('fjøreplytt',),
'fjøreplyttene': ('fjøreplytt',),
'fjøreplytter': ('fjøreplytt',),
'grisebank': ('grisebank',),
'grisebanken': ('grisebank',),
'grisebankene': ('grisebank',),
'grisebanker': ('grisebank',),
'grunnkrets': ('grunnkrets',),
'grunnkretsen': ('grunnkrets',),
'grunnkretsene': ('grunnkrets',),
'grunnkretser': ('grunnkrets',),
'gymsokk': ('gymsokk',),
'gymsokken': ('gymsokk',),
'gymsokkene': ('gymsokk',),
'gymsokker': ('gymsokk',),
'gærenskap': ('gærenskap',),
'gærenskapen': ('gærenskap',),
'gærenskapene': ('gærenskap',),
'gærenskaper': ('gærenskap',),
'hidsjab': ('hidsjab',),
'hidsjaben': ('hidsjab',),
'hidsjabene': ('hidsjab',),
'hidsjaber': ('hidsjab',),
'hijab': ('hijab',),
'hijaben': ('hijab',),
'hijabene': ('hijab',),
'hijaber': ('hijab',),
'internettkafeen': ('internettkafé',),
'internettkafeene': ('internettkafé',),
'internettkafeer': ('internettkafé',),
'internettkafé': ('internettkafé',),
'internettkaféen': ('internettkafé',),
'internettkaféene': ('internettkafé',),
'internettkaféer': ('internettkafé',),
'kanalvert': ('kanalvert',),
'kanalverten': ('kanalvert',),
'kanalvertene': ('kanalvert',),
'kanalverter': ('kanalvert',),
'karneol': ('karneol',),
'karneolen': ('karneol',),
'karneolene': ('karneol',),
'karneoler': ('karneol',),
'kipa': ('kipa',),
'kipaen': ('kipa',),
'kipaene': ('kipa',),
'kipaer': ('kipa',),
'maggot': ('maggot',),
'maggoten': ('maggot',),
'maggotene': ('maggot',),
'maggoter': ('maggot',),
'mastergrad': ('mastergrad',),
'mastergraden': ('mastergrad',),
'mastergradene': ('mastergrad',),
'mastergrader': ('mastergrad',),
'merkepel': ('merkepel',),
'merkepelen': ('merkepel',),
'merkepelene': ('merkepel',),
'merkepeler': ('merkepel',),
'milepel': ('milepel',),
'milepelen': ('milepel',),
'milepelene': ('milepel',),
'milepeler': ('milepel',),
'molekylærstruktur': ('molekylærstruktur',),
'molekylærstrukturen': ('molekylærstruktur',),
'molekylærstrukturene': ('molekylærstruktur',),
'molekylærstrukturer': ('molekylærstruktur',),
'molekylærstruktur': ('molekylærstruktur',),
'molekylærstrukturen': ('molekylærstruktur',),
'molekylærstrukturene': ('molekylærstruktur',),
'molekylærstrukturer': ('molekylærstruktur',),
'motsats': ('motsats',),
'motsatsen': ('motsats',),
'motsatsene': ('motsats',),
'motsatser': ('motsats',),
'muffins': ('muffins',),
'muffinsen': ('muffins',),
'muffinsene': ('muffins',),
'muffinser': ('muffins',),
'nynorsking': ('nynorsking',),
'nynorskingen': ('nynorsking',),
'nynorskingene': ('nynorsking',),
'nynorskinger': ('nynorsking',),
'pailabb': ('pailabb',),
'pailabben': ('pailabb',),
'pailabbene': ('pailabb',),
'pailabber': ('pailabb',),
'pastrami': ('pastrami',),
'pastramien': ('pastrami',),
'pastramiene': ('pastrami',),
'pastramier': ('pastrami',),
'penetrasjon': ('penetrasjon',),
'penetrasjonen': ('penetrasjon',),
'penetrasjonene': ('penetrasjon',),
'penetrasjoner': ('penetrasjon',),
'prøvesten': ('prøvesten',),
'prøvestenen': ('prøvesten',),
'prøvestenene': ('prøvesten',),
'prøvestener': ('prøvesten',),
'pushup': ('pushup',),
'pushupen': ('pushup',),
'pushupene': ('pushup',),
'pushuper': ('pushup',),
'situp': ('situp',),
'situpen': ('situp',),
'situpene': ('situp',),
'situper': ('situp',),
'sjarterturist': ('sjarterturist',),
'sjarterturisten': ('sjarterturist',),
'sjarterturistene': ('sjarterturist',),
'sjarterturister': ('sjarterturist',),
'skalar': ('skalar',),
'skalaren': ('skalar',),
'skalarene': ('skalar',),
'skalarer': ('skalar',),
'skaubrukskandidat': ('skaubrukskandidat',),
'skaubrukskandidaten': ('skaubrukskandidat',),
'skaubrukskandidatene': ('skaubrukskandidat',),
'skaubrukskandidater': ('skaubrukskandidat',),
'solar plexus': ('solar plexus',),
'solar plexusen': ('solar plexus',),
'solar plexusene': ('solar plexus',),
'solar plexuser': ('solar plexus',),
'spanskvegg': ('spanskvegg',),
'spanskveggen': ('spanskvegg',),
'spanskveggene': ('spanskvegg',),
'spanskvegger': ('spanskvegg',),
'spellkonsoll': ('spellkonsoll',),
'spellkonsollen': ('spellkonsoll',),
'spellkonsollene': ('spellkonsoll',),
'spellkonsoller': ('spellkonsoll',),
'spellmaskin': ('spellmaskin',),
'spellmaskinen': ('spellmaskin',),
'spellmaskinene': ('spellmaskin',),
'spellmaskiner': ('spellmaskin',),
'spillkonsoll': ('spillkonsoll',),
'spillkonsollen': ('spillkonsoll',),
'spillkonsollene': ('spillkonsoll',),
'spillkonsoller': ('spillkonsoll',),
'spillmaskin': ('spillmaskin',),
'spillmaskinen': ('spillmaskin',),
'spillmaskinene': ('spillmaskin',),
'spillmaskiner': ('spillmaskin',),
'standup': ('standup',),
'standupen': ('standup',),
'standupene': ('standup',),
'standuper': ('standup',),
'stridrasjon': ('stridrasjon',),
'stridrasjonen': ('stridrasjon',),
'stridrasjonene': ('stridrasjon',),
'stridrasjoner': ('stridrasjon',),
'suppegjøk': ('suppegjøk',),
'suppegjøken': ('suppegjøk',),
'suppegjøkene': ('suppegjøk',),
'suppegjøker': ('suppegjøk',),
'svømmeidrett': ('svømmeidrett',),
'svømmeidretten': ('svømmeidrett',),
'svømmeidrettene': ('svømmeidrett',),
'svømmeidretter': ('svømmeidrett',),
'tabaskosaus': ('tabaskosaus',),
'tabaskosausen': ('tabaskosaus',),
'tabaskosausene': ('tabaskosaus',),
'tabaskosauser': ('tabaskosaus',),
'takning': ('takning',),
'takninga': ('takning',),
'takningen': ('takning',),
'takningene': ('takning',),
'takninger': ('takning',),
'tredevtedel': ('tredevtedel',),
'tredevtedelen': ('tredevtedel',),
'tredevtedelene': ('tredevtedel',),
'tredevtedeler': ('tredevtedel',),
'tredvedel': ('tredvedel',),
'tredvedelen': ('tredvedel',),
'tredvedelene': ('tredvedel',),
'tredvedeler': ('tredvedel',),
'tredveårsdag': ('tredveårsdag',),
'tredveårsdagen': ('tredveårsdag',),
'tredveårsdagene': ('tredveårsdag',),
'tredveårsdager': ('tredveårsdag',),
'tronpretendent': ('tronpretendent',),
'tronpretendenten': ('tronpretendent',),
'tronpretendentene': ('tronpretendent',),
'tronpretendenter': ('tronpretendent',),
'vegan': ('vegan',),
'veganen': ('vegan',),
'veganene': ('vegan',),
'veganer': ('vegan',),
'drive-in': ('drive-in',),
'drive-ina': ('drive-in',),
'drive-inen': ('drive-in',),
'drive-inene': ('drive-in',),
'drive-iner': ('drive-in',),
'drive-inet': ('drive-in',),
'analsex': ('analsex',),
'analsexen': ('analsex',),
'analsexene': ('analsex',),
'analsexer': ('analsex',),
'apologetikk': ('apologetikk',),
'apologetikken': ('apologetikk',),
'apologetikkene': ('apologetikk',),
'apologetikker': ('apologetikk',),
'berserker': ('berserker',),
'berserkere': ('berserker',),
'berserkeren': ('berserker',),
'berserkerer': ('berserker',),
'berserkerne': ('berserker',),
'dualitet': ('dualitet',),
'dualiteten': ('dualitet',),
'dualitetene': ('dualitet',),
'dualiteter': ('dualitet',),
'futsal': ('futsal',),
'futsalen': ('futsal',),
'futsalene': ('futsal',),
'futsaler': ('futsal',),
'inklusjon': ('inklusjon',),
'inklusjonen': ('inklusjon',),
'inklusjonene': ('inklusjon',),
'inklusjoner': ('inklusjon',),
'kols': ('kols',),
'kolsen': ('kols',),
'kolsene': ('kols',),
'kolser': ('kols',),
'letargi': ('letargi',),
'letargien': ('letargi',),
'letargiene': ('letargi',),
'letargier': ('letargi',),
'molekylærbiologi': ('molekylærbiologi',),
'molekylærbiologien': ('molekylærbiologi',),
'molekylærbiologiene': ('molekylærbiologi',),
'molekylærbiologier': ('molekylærbiologi',),
'munnsex': ('munnsex',),
'munnsexen': ('munnsex',),
'munnsexene': ('munnsex',),
'munnsexer': ('munnsex',),
'onomastikk': ('onomastikk',),
'onomastikken': ('onomastikk',),
'onomastikkene': ('onomastikk',),
'onomastikker': ('onomastikk',),
'oralsex': ('oralsex',),
'oralsexen': ('oralsex',),
'oralsexene': ('oralsex',),
'oralsexer': ('oralsex',),
'sars': ('sars',),
'sarsen': ('sars',),
'sarsene': ('sars',),
'sarser': ('sars',),
'lulesamisk': ('lulesamisk',),
'lulesamisken': ('lulesamisk',),
'lulesamiskene': ('lulesamisk',),
'lulesamisker': ('lulesamisk',),
'hjernetrim': ('hjernetrim',),
'hjernetrimmen': ('hjernetrim',),
'hjernetrimmene': ('hjernetrim',),
'hjernetrimmer': ('hjernetrim',),
'svigerbror': ('svigerbror',),
'svigerbroren': ('svigerbror',),
'svigerbrødre': ('svigerbror',),
'svigerbrødrene': ('svigerbror',),
'myrtistel': ('myrtistel',),
'myrtistelen': ('myrtistel',),
'myrtistlene': ('myrtistel',),
'myrtistler': ('myrtistel',),
'androide': ('androide',),
'androiden': ('androide',),
'androidene': ('androide',),
'androider': ('androide',),
'avfolkingskommune': ('avfolkingskommune',),
'avfolkingskommunen': ('avfolkingskommune',),
'avfolkingskommunene': ('avfolkingskommune',),
'avfolkingskommuner': ('avfolkingskommune',),
'avfolkningskommune': ('avfolkningskommune',),
'avfolkningskommunen': ('avfolkningskommune',),
'avfolkningskommunene': ('avfolkningskommune',),
'avfolkningskommuner': ('avfolkningskommune',),
'ballbinge': ('ballbinge',),
'ballbingen': ('ballbinge',),
'ballbingene': ('ballbinge',),
'ballbinger': ('ballbinge',),
'friskole': ('friskole',),
'friskolen': ('friskole',),
'friskolene': ('friskole',),
'friskoler': ('friskole',),
'høreevne': ('høreevne',),
'høreevnen': ('høreevne',),
'høreevnene': ('høreevne',),
'høreevner': ('høreevne',),
'kompostbinge': ('kompostbinge',),
'kompostbingen': ('kompostbinge',),
'kompostbingene': ('kompostbinge',),
'kompostbinger': ('kompostbinge',),
'konvallfamilie': ('konvallfamilie',),
'konvallfamilien': ('konvallfamilie',),
'konvallfamiliene': ('konvallfamilie',),
'konvallfamilier': ('konvallfamilie',),
'molekylmasse': ('molekylmasse',),
'molekylmassen': ('molekylmasse',),
'molekylmassene': ('molekylmasse',),
'molekylmasser': ('molekylmasse',),
'zombie': ('zombie',),
'zombien': ('zombie',),
'zombiene': ('zombie',),
'zombier': ('zombie',),
'fingerspissfølelse': ('fingerspissfølelse',),
'fingerspissfølelsen': ('fingerspissfølelse',),
'fingerspissfølelsene': ('fingerspissfølelse',),
'fingerspissfølelser': ('fingerspissfølelse',),
'stenfruktfamilie': ('stenfruktfamilie',),
'stenfruktfamilien': ('stenfruktfamilie',),
'stenfruktfamiliene': ('stenfruktfamilie',),
'stenfruktfamilier': ('stenfruktfamilie',),
'alsaser': ('alsaser',),
'alsasere': ('alsaser',),
'alsaseren': ('alsaser',),
'alsaserer': ('alsaser',),
'alsaserne': ('alsaser',),
'asorer': ('asorer',),
'asorere': ('asorer',),
'asoreren': ('asorer',),
'asorerer': ('asorer',),
'asorerne': ('asorer',),
'busetter': ('busetter',),
'busettere': ('busetter',),
'busetteren': ('busetter',),
'busetterer': ('busetter',),
'busetterne': ('busetter',),
'gasstanker': ('gasstanker',),
'gasstankere': ('gasstanker',),
'gasstankeren': ('gasstanker',),
'gasstankerne': ('gasstanker',),
'kamikazeflyver': ('kamikazeflyver',),
'kamikazeflyvere': ('kamikazeflyver',),
'kamikazeflyveren': ('kamikazeflyver',),
'kamikazeflyverne': ('kamikazeflyver',),
'kampflyver': ('kampflyver',),
'kampflyvere': ('kampflyver',),
'kampflyveren': ('kampflyver',),
'kampflyverne': ('kampflyver',),
'prøveflyver': ('prøveflyver',),
'prøveflyvere': ('prøveflyver',),
'prøveflyveren': ('prøveflyver',),
'prøveflyverne': ('prøveflyver',),
'råner': ('råner',),
'rånere': ('råner',),
'råneren': ('råner',),
'rånerne': ('råner',),
'skiflyver': ('skiflyver',),
'skiflyvere': ('skiflyver',),
'skiflyveren': ('skiflyver',),
'skiflyverne': ('skiflyver',),
'standupkomiker': ('standupkomiker',),
'standupkomikere': ('standupkomiker',),
'standupkomikeren': ('standupkomiker',),
'standupkomikerne': ('standupkomiker',),
'testflyver': ('testflyver',),
'testflyvere': ('testflyver',),
'testflyveren': ('testflyver',),
'testflyverne': ('testflyver',),
'tingrettsdommer': ('tingrettsdommer',),
'tingrettsdommere': ('tingrettsdommer',),
'tingrettsdommeren': ('tingrettsdommer',),
'tingrettsdommerne': ('tingrettsdommer',),
'trafikkflyver': ('trafikkflyver',),
'trafikkflyvere': ('trafikkflyver',),
'trafikkflyveren': ('trafikkflyver',),
'trafikkflyverne': ('trafikkflyver',),
'tettemiddel': ('tettemiddel',),
'tettemiddelet': ('tettemiddel',),
'tettemidla': ('tettemiddel',),
'tettemidlene': ('tettemiddel',),
'tettemidler': ('tettemiddel',),
'tettemidlet': ('tettemiddel',),
'erratum': ('erratum',),
'erratuma': ('erratum',),
'erratumene': ('erratum',),
'erratumet': ('erratum',),
'haraball': ('haraball',),
'haraballen': ('haraball',),
'haraballene': ('haraball',),
'haraballer': ('haraball',),
'helsetilsyn': ('helsetilsyn',),
'helsetilsyna': ('helsetilsyn',),
'helsetilsynene': ('helsetilsyn',),
'helsetilsynet': ('helsetilsyn',),
'strass-sett': ('strass-sett',),
'strass-setta': ('strass-sett',),
'strass-settene': ('strass-sett',),
'strass-settet': ('strass-sett',),
'tilvalg': ('tilvalg',),
'tilvalga': ('tilvalg',),
'tilvalgene': ('tilvalg',),
'tilvalget': ('tilvalg',),
'tredveår': ('tredveår',),
'tredveåra': ('tredveår',),
'tredveårene': ('tredveår',),
'tredveåret': ('tredveår',),
'kalsedon': ('kalsedon',),
'kalsedona': ('kalsedon',),
'kalsedonene': ('kalsedon',),
'kalsedonet': ('kalsedon',),
'stentøy': ('stentøy',),
'stentøya': ('stentøy',),
'stentøyene': ('stentøy',),
'stentøyet': ('stentøy',),
'gebursdagsbarn': ('gebursdagsbarn',),
'gebursdagsbarna': ('gebursdagsbarn',),
'gebursdagsbarnene': ('gebursdagsbarn',),
'gebursdagsbarnet': ('gebursdagsbarn',),
'dyreskua': ('dyreskue',),
'dyreskue': ('dyreskue',),
'dyreskuene': ('dyreskue',),
'dyreskuer': ('dyreskue',),
'dyreskuet': ('dyreskue',),
'dyrskua': ('dyrskue',),
'dyrskue': ('dyrskue',),
'dyrskuene': ('dyrskue',),
'dyrskuer': ('dyrskue',),
'dyrskuet': ('dyrskue',),
'tettemateriala': ('tettemateriale',),
'tettemateriale': ('tettemateriale',),
'tettematerialene': ('tettemateriale',),
'tettematerialer': ('tettemateriale',),
'tettematerialet': ('tettemateriale',),
'allmennaksjeselskap': ('allmennaksjeselskap',),
'allmennaksjeselskapa': ('allmennaksjeselskap',),
'allmennaksjeselskapene': ('allmennaksjeselskap',),
'allmennaksjeselskaper': ('allmennaksjeselskap',),
'allmennaksjeselskapet': ('allmennaksjeselskap',),
'dekrement': ('dekrement',),
'dekrementa': ('dekrement',),
'dekrementene': ('dekrement',),
'dekrementer': ('dekrement',),
'dekrementet': ('dekrement',),
'forladningsgevær': ('forladningsgevær',),
'forladningsgeværa': ('forladningsgevær',),
'forladningsgeværene': ('forladningsgevær',),
'forladningsgeværer': ('forladningsgevær',),
'forladningsgeværet': ('forladningsgevær',),
'helsedepartement': ('helsedepartement',),
'helsedepartementa': ('helsedepartement',),
'helsedepartementene': ('helsedepartement',),
'helsedepartementer': ('helsedepartement',),
'helsedepartementet': ('helsedepartement',),
'laktat': ('laktat',),
'laktata': ('laktat',),
'laktatene': ('laktat',),
'laktater': ('laktat',),
'laktatet': ('laktat',),
'melanin': ('melanin',),
'melanina': ('melanin',),
'melaninene': ('melanin',),
'melaniner': ('melanin',),
'melaninet': ('melanin',),
'nettsted': ('nettsted',),
'nettsteda': ('nettsted',),
'nettstedene': ('nettsted',),
'nettsteder': ('nettsted',),
'nettstedet': ('nettsted',),
'party': ('party',),
'partya': ('party',),
'partyene': ('party',),
'partyer': ('party',),
'partyet': ('party',),
'strassbroderi': ('strassbroderi',),
'strassbroderia': ('strassbroderi',),
'strassbroderiene': ('strassbroderi',),
'strassbroderier': ('strassbroderi',),
'strassbroderiet': ('strassbroderi',),
'tettematerial': ('tettematerial',),
'tettemateriala': ('tettematerial',),
'tettematerialene': ('tettematerial',),
'tettematerialer': ('tettematerial',),
'tettematerialet': ('tettematerial',),
'glidemiddel': ('glidemiddel',),
'glidemiddelet': ('glidemiddel',),
'glidemidla': ('glidemiddel',),
'glidemidlene': ('glidemiddel',),
'glidemidler': ('glidemiddel',),
'glidemidlet': ('glidemiddel',),
'stayups': ('stayups',),
'stayupsene': ('stayups',),
'fuglenek': ('fuglenek',),
'fugleneka': ('fuglenek',),
'fuglenekene': ('fuglenek',),
'fugleneket': ('fuglenek',),
'tjuedels': ('tjuedels',),
'tjuedelsen': ('tjuedels',),
'tjuedelsene': ('tjuedels',),
'tjuedelser': ('tjuedels',),
'sørvis': ('sørvis',),
'sørvisen': ('sørvis',),
'sørvisene': ('sørvis',),
'sørviser': ('sørvis',),
'sukkulent': ('sukkulent',),
'sukkulenten': ('sukkulent',),
'sukkulentene': ('sukkulent',),
'sukkulenter': ('sukkulent',),
'sukkulent': ('sukkulent',),
'sukkulenten': ('sukkulent',),
'sukkulentene': ('sukkulent',),
'sukkulenter': ('sukkulent',),
'skvåsj': ('skvåsj',),
'skvåsjen': ('skvåsj',),
'skvåsjene': ('skvåsj',),
'skvåsjer': ('skvåsj',),
'skvåsj': ('skvåsj',),
'skvåsjen': ('skvåsj',),
'skvåsjene': ('skvåsj',),
'skvåsjer': ('skvåsj',),
'lao': ('lao',),
'laoen': ('lao',),
'laoene': ('lao',),
'laoer': ('lao',),
'grovbygget': ('grovbygget',),
'grovbyggeten': ('grovbygget',),
'grovbyggetene': ('grovbygget',),
'grovbyggeter': ('grovbygget',),
'bosetter': ('bosetter',),
'bosettere': ('bosetter',),
'bosetteren': ('bosetter',),
'bosetterer': ('bosetter',),
'bosetterne': ('bosetter',),
'syvmilsstøvlene': ('syvmilsstøvler',),
'syvmilsstøvler': ('syvmilsstøvler',),
'marakas': ('marakas',),
'marakasen': ('marakas',),
'marakasene': ('marakas',),
'marakaser': ('marakas',),
'sausnebb': ('sausnebb',),
'sausnebba': ('sausnebb',),
'sausnebbene': ('sausnebb',),
'sausnebbet': ('sausnebb',),
'hospitalskip': ('hospitalskip',),
'hospitalskipa': ('hospitalskip',),
'hospitalskipene': ('hospitalskip',),
'hospitalskipet': ('hospitalskip',),
'KOLS': ('KOLS',),
'KOLS-en': ('KOLS',),
'KOLS-ene': ('KOLS',),
'KOLS-er': ('KOLS',),
'laotisk': ('laotisk',),
'laotisken': ('laotisk',),
'laotiskene': ('laotisk',),
'laotisker': ('laotisk',),
'tunellbane': ('tunellbane',),
'tunellbanen': ('tunellbane',),
'tunellbanene': ('tunellbane',),
'tunellbaner': ('tunellbane',),
'sjølfølga': ('sjølfølge',),
'sjølfølge': ('sjølfølge',),
'sjølfølgen': ('sjølfølge',),
'sjølfølgene': ('sjølfølge',),
'sjølfølger': ('sjølfølge',)
}
